//The Warming, Acidification and Sea-level Projector: WASP (October 2017)
//WASP is an 8-box representation of the Earth system for efficient very-large ensemble simulations.
//Coded by Philip Goodwin, This version 9-October-2017, ammended 22-September-2018

//Citations for use of code:

//This version of the WASP model:
//Goodwin, P., On the time evolution of climate sensitivity and future warming, (2018 in press), Earth’s Future, EFT2466, doi: 10.1029/2018EF000889.

//WASP Model description:

//Goodwin, P., A. Katavouta,, V. M. Roussenov, G. L. Foster, E. J. Rohling and R. G. Williams (2018), Pathways to 1.5 and 2 °C warming based on observational and geological constraints, Nature Geoscience

//Goodwin, P. (2016) How historic simulation-observation discrepancy affects future warming projections in a very large model ensemble, Climate Dynamics, CLDY-D-15-00368R2, doi: 10.1007/s00382-015-2960-z.

//Utilising the input distribution for climate sensitivity, S=1/lambda, from geological data requires citation of:
//Rohling, E. J. et al - Palaeosens Project Members (2012), Making sense of Palaeoclimate sensitivity, Nature 491, 683-691, doi:10.1038/nature11574.

//The theory behind how WASP calculated atmospheric CO2 and surface temperature anomaly is given here:
//Goodwin, P., R.G. Williams and A. Ridgwell (2015), Sensitivity of climate to cumulative carbon emissions due to compensation of ocean heat and carbon uptake, Nature Geoscience, Vol. 8, p29-34. doi:10.1038/ngeo2304.

//If you use the sea level component of WASP (commented out in the code), also cite:
//Goodwin, P., I. D. Haigh, E. J. Rohling, and A. Slangen (2017), A new approach to projecting 21st century sea-level changes and extremes, Earth’s Future, 5, doi:10.1002/2016EF000508.



////////////////////////////////////////////////////////////////////////////////////////////////////////////////

//Code compiled on a Mac Darwin environment, operating system OS X version 10.11.6, using command line compilation on the Terminal.
//To compile: place the files together in a directory. Add a folder called 'RESULTS' for the results files to be written into.
//Use compiler g++ and compile with command line: g++ -O3 -o filename Main_WASP_ESM.cpp

//This code has *not* been checked across a range of C++ compilers.



//This header file containes the future scenarios (RCP) and palaeo-distributions for climate sensitivity

#include <cmath>
#include <iostream>
#include <fstream>
#include <random>
#include <vector>


using namespace std;
//using std::vector;

//Define global variables//////////////
const int tmax=36001; //36000 takes us from 1750 to year 2500

std::vector<double> I_em;           //Cumulative carbon emissions (PgC)
std::vector<double> CO2;            //atmospheric CO2 mixing ratio
std::vector<double> RnonCO2;
std::vector<double> R_WMGHG_nonCO2;        //Radiative forcing from non-CO2 WMGHG agents
std::vector<double> R_volcanic;            //Radiative forcing from volanic activity
std::vector<double> R_aerosol;             //Radiative foricng from aerosols excluding volanism
std::vector<double> R_solar;
std::vector<double> AOD;                   //Aerosol optical depth at 550nm

std::vector<double> R_noise;

 /*
 double I_em[tmax];           //Cumulative carbon emissions (PgC)
 double CO2[tmax];            //atmospheric CO2 mixing ratio
 double RnonCO2[tmax];
 double R_WMGHG_nonCO2[tmax];        //Radiative forcing from non-CO2 WMGHG agents
 double R_volcanic[tmax];            //Radiative forcing from volanic activity
 double R_aerosol[tmax];             //Radiative foricng from aerosols excluding volanism
 double R_solar[tmax];
 double AOD[tmax];                   //Aerosol optical depth at 550nm

*/

 

//Annual emission rate of aerosol components ////////////////
std::vector<double> Aero_BC_em;
std::vector<double> Aero_OC_em;
std::vector<double> Aero_SOx_em;
std::vector<double> Aero_NOx_em;
std::vector<double> Aero_NH3_em;
std::vector<double> Aero_ENMVOC_em;

/////////////////////////////////////////////////////////////


//Other greenhouse concentrations and emissions
std::vector<double> N2O;
std::vector<double> N2O_em;
std::vector<double> CH4;
std::vector<double> CH4_em;


std::vector<double> CF4;
std::vector<double> CF4_em;
std::vector<double> C2F6;
std::vector<double> C2F6_em;
std::vector<double> C6F14;
std::vector<double> C6F14_em;
std::vector<double> HFC23;
std::vector<double> HFC23_em;
std::vector<double> HFC32;
std::vector<double> HFC32_em;
std::vector<double> HFC4310mee;
std::vector<double> HFC4310mee_em;
std::vector<double> HFC125;
std::vector<double> HFC125_em;
std::vector<double> HFC134a;
std::vector<double> HFC134a_em;
std::vector<double> HFC143a;
std::vector<double> HFC143a_em;
std::vector<double> HFC227ea;
std::vector<double> HFC227ea_em;
std::vector<double> HFC245fa;
std::vector<double> HFC245fa_em;
std::vector<double> SF6;
std::vector<double> SF6_em;
std::vector<double> CFC11;
std::vector<double> CFC11_em;
std::vector<double> CFC12;
std::vector<double> CFC12_em;
std::vector<double> CFC113;
std::vector<double> CFC113_em;
std::vector<double> CFC114;
std::vector<double> CFC114_em;
std::vector<double> CFC115;
std::vector<double> CFC115_em;
std::vector<double> CCl4;
std::vector<double> CCl4_em;
std::vector<double> MethylCholoroform;
std::vector<double> MethylCholoroform_em;
std::vector<double> HCFC22;
std::vector<double> HCFC22_em;
std::vector<double> HCFC141b;
std::vector<double> HCFC141b_em;
std::vector<double> HCFC142b;
std::vector<double> HCFC142b_em;
std::vector<double> Halon1211;
std::vector<double> Halon1211_em;
std::vector<double> Halon1202;
std::vector<double> Halon1202_em;
std::vector<double> Halon1301;
std::vector<double> Halon1301_em;
std::vector<double> Halon2402;
std::vector<double> Halon2402_em;
std::vector<double> CH3Br;
std::vector<double> CH3Br_em;
std::vector<double> CH3CCl3;
std::vector<double> CH3CCl3_em;
std::vector<double> CH3Cl;
std::vector<double> CH3Cl_em;

//These are the RF coefficients for minor nonCO2 agents in W/m2/ppb
double CF4_coeff;
double C2F6_coeff;
double C6F14_coeff;
double HFC23_coeff;
double HFC32_coeff;
double HFC4310mee_coeff;
double HFC125_coeff;
double HFC134a_coeff;
double HFC143a_coeff;
double HFC227ea_coeff;
double HFC245fa_coeff;
double SF6_coeff;
double CFC11_coeff;
double CFC12_coeff;
double CFC113_coeff;
double CFC114_coeff;
double CFC115_coeff;
double CCl4_coeff;
double Methylchloroform_coeff;
double HCFC22_coeff;
double HCFC141b_coeff;
double HCFC142b_coeff;
double Halon1211_coeff;
double Halon1202_coeff;
double Halon1301_coeff;
double Halon2402_coeff;
double CH3Br_coeff;
double CH3Cl_coeff;

void set_radiative_forcing_coeffs() //From Smith et al. (2018) - coefficients are for ppb and data is expressed in ppt, so all are divided by 1000.0
{
    CF4_coeff=   0.09/1000.0    ;
    C2F6_coeff=   0.25/1000.0    ;
    C6F14_coeff=    0.44/1000.0    ;
    HFC23_coeff=    0.18/1000.0    ;
    HFC32_coeff=    0.11/1000.0    ;
    HFC4310mee_coeff=    0.42/1000.0    ;
    HFC125_coeff=    0.23/1000.0    ;
    HFC134a_coeff=    0.16/1000.0    ;
    HFC143a_coeff=    0.16/1000.0    ;
    HFC227ea_coeff=    0.26/1000.0    ;
    HFC245fa_coeff=    0.24/1000.0    ;
    SF6_coeff=    0.57/1000.0    ;
    CFC11_coeff=    0.26/1000.0    ;
    CFC12_coeff=    0.32/1000.0    ;
    CFC113_coeff=    0.3/1000.0    ;
    CFC114_coeff=    0.31/1000.0    ;
    CFC115_coeff=    0.2/1000.0    ;
    CCl4_coeff=    0.17/1000.0    ;
    Methylchloroform_coeff=    0.07/1000.0    ;
    HCFC22_coeff=    0.21/1000.0    ;
    HCFC141b_coeff=    0.16/1000.0    ;
    HCFC142b_coeff=    0.19/1000.0    ;
    Halon1211_coeff=    0.29/1000.0    ;
    Halon1202_coeff=    0.27/1000.0    ;
    Halon1301_coeff=    0.3/1000.0   ;
    Halon2402_coeff=    0.3/1000.0    ;
    CH3Br_coeff=    0.004/1000.0    ;
    CH3Cl_coeff=    0.01/1000.0    ;
}

//Initialise global variables/////////////////
void InitialiseGlobalVectors()
{
    //use if define as vectors
    
    I_em.assign(tmax, 0.0);
    CO2.assign(tmax, 0.0);
    RnonCO2.assign(tmax, 0.0);
    R_WMGHG_nonCO2.assign(tmax, 0.0);
    R_volcanic.assign(tmax, 0.0);
    R_aerosol.assign(tmax, 0.0);
    R_solar.assign(tmax, 0.0);
    AOD.assign(tmax, 0.0);
    
    /*
    Aero_BC_em.assign(tmax, 0.0);
    Aero_OC_em.assign(tmax, 0.0);
    Aero_SOx_em.assign(tmax, 0.0);
    Aero_NOx_em.assign(tmax, 0.0);
    Aero_NH3_em.assign(tmax, 0.0);
    Aero_ENMVOC_em.assign(tmax, 0.0);
    
    N2O.assign(tmax, 0.0);
    N2O_em.assign(tmax, 0.0);
    CH4.assign(tmax, 0.0);
    CH4_em.assign(tmax, 0.0);
    CF4.assign(tmax, 0.0);
    CF4_em.assign(tmax, 0.0);
    C2F6.assign(tmax, 0.0);
    C2F6_em.assign(tmax, 0.0);
    HFC23.assign(tmax, 0.0);
    HFC23_em.assign(tmax, 0.0);
    HFC32.assign(tmax, 0.0);
    HFC32_em.assign(tmax, 0.0);
    HFC4310mee.assign(tmax, 0.0);
    HFC4310mee_em.assign(tmax, 0.0);
    HFC125.assign(tmax, 0.0);
    HFC125_em.assign(tmax, 0.0);
    HFC134a.assign(tmax, 0.0);
    HFC134a_em.assign(tmax, 0.0);
    HFC143a.assign(tmax, 0.0);
    HFC143a_em.assign(tmax, 0.0);
    HFC227ea.assign(tmax, 0.0);
    HFC227ea_em.assign(tmax, 0.0);
    HFC245fa.assign(tmax, 0.0);
    HFC245fa_em.assign(tmax, 0.0);
    SF6.assign(tmax, 0.0);
    SF6_em.assign(tmax, 0.0);
    CFC11.assign(tmax, 0.0);
    CFC11_em.assign(tmax, 0.0);
    CFC12.assign(tmax, 0.0);
    CFC12_em.assign(tmax, 0.0);
    CFC113.assign(tmax, 0.0);
    CFC113_em.assign(tmax, 0.0);
    CFC114.assign(tmax, 0.0);
    CFC114_em.assign(tmax, 0.0);
    CFC115.assign(tmax, 0.0);
    CFC115_em.assign(tmax, 0.0);
    CCl4.assign(tmax, 0.0);
    CCl4_em.assign(tmax, 0.0);
    MethylCholoroform.assign(tmax, 0.0);
    MethylCholoroform_em.assign(tmax, 0.0);
    HCFC22.assign(tmax, 0.0);
    HCFC22_em.assign(tmax, 0.0);
    HCFC141b.assign(tmax, 0.0);
    HCFC141b_em.assign(tmax, 0.0);
    HCFC142b.assign(tmax, 0.0);
    HCFC142b_em.assign(tmax, 0.0);
    Halon1211.assign(tmax, 0.0);
    Halon1211_em.assign(tmax, 0.0);
    Halon1202.assign(tmax, 0.0);
    Halon1202_em.assign(tmax, 0.0);
    Halon1301.assign(tmax, 0.0);
    Halon1301_em.assign(tmax, 0.0);
    Halon2402.assign(tmax, 0.0);
    Halon2402_em.assign(tmax, 0.0);
    CH3Br.assign(tmax, 0.0);
    CH3Br_em.assign(tmax, 0.0);
    CH3Cl.assign(tmax, 0.0);
    CH3Cl_em.assign(tmax, 0.0);*/
    
}

//Calculating radaitive forcing from non-CO2 agent concentrations
double getR_aerosol(int i_year, int i_t_step, double coeff_BC, double coeff_OC, double coeff_SOx, double coeff_NOx, double coeff_NH3, double coeff_VOC, int year_start, double RF_ind_2011)
{
    double RF=0.0;
    RF =  coeff_BC  * Aero_BC_em[i_year]
        + coeff_OC  * Aero_OC_em[i_year]
        + coeff_SOx * Aero_SOx_em[i_year]
        + coeff_NOx * Aero_NOx_em[i_year]
        + coeff_NH3 * Aero_NH3_em[i_year]
        + coeff_VOC * Aero_ENMVOC_em[i_year];
    
    double G_start = -1.95*log(1.0 + 0.0111*Aero_SOx_em[0] + 0.0139*(Aero_BC_em[0] + Aero_OC_em[0]));
    double G_now = -1.95*log(1.0 + 0.0111*Aero_SOx_em[i_year] + 0.0139*(Aero_BC_em[i_year] + Aero_OC_em[i_year]));
    double G_2011 = -1.95*log(1.0 + 0.0111*Aero_SOx_em[2011 - year_start] + 0.0139*(Aero_BC_em[2011 - year_start] + Aero_OC_em[2011 - year_start]));
    
    RF += RF_ind_2011 * (G_now - G_start)/(G_2011 - G_start);
    
    return RF;
}

void setR_solar_volcanic_1700(int t_steps_year)
{
    R_solar={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,-0.02835875,-0.02069375,0.007039375,0.046256875,0.073605,0.077258125,0.064894375,0.04433625,0.020348125,0.00144375,-0.009813125,-0.003950625,0.022645,0.05236875,0.05970125,0.05152875,0.041895,0.019495,-0.006033125,-0.0190575,-0.00597625,0.031189375,0.056993125,0.0586425,0.050159375,0.03401125,0.015911875,0.007214375,0.000695625,-0.013549375,-0.0292075,-0.0392525,-0.046291875,-0.05053125,-0.04930625,-0.03357375,-0.0133,-0.017819375,-0.034545,-0.039536875,-0.04272625,-0.053764375,-0.065043125,-0.0714175,-0.07532875,-0.0767375,-0.074204375,-0.067939375,-0.06085625,-0.054236875,-0.044174375,-0.0345275,-0.034759375,-0.0407925,-0.046659375,-0.0531475,-0.0564375,-0.055076875,-0.051795625,-0.04477375,-0.0320425,-0.01493625,0.003136875,0.01644125,0.023629375,0.02078125,0.003675,-0.016638125,-0.027890625,-0.017539375,0.023550625,0.071575,0.08537375,0.066346875,0.04472125,0.0242725,0.003486875,-0.011038125,-0.018256875,-0.013068125,0.003745,0.022365,0.04412625,0.065358125,0.064448125,0.046816875,0.035013125,0.0234325,0.004930625,-0.01411375,-0.026280625,-0.02471875,-0.00660625,0.0245875,0.054998125,0.065550625,0.05229875,0.030695,0.01407,0.0009975,-0.012429375,-0.0242375,-0.024600625,-0.0025725,0.03553375,0.06412875,0.06727,0.051760625,0.0265125,-2.1874985000000002e-05,-0.020846875,-0.031731875,-0.0351575,-0.036675625,-0.029553125,-0.00942375,0.01064,0.0210525,0.02190125,0.010583125,-0.010530625,-0.0316925,-0.044279375,-0.0505225,-0.0530425,-0.04025875,-0.01243375,0.01336125,0.034181875,0.04360125,0.02968,0.0023975,-0.01924125,-0.029859375,-0.036728125,-0.045101875,-0.05291125,-0.046388125,-0.01581125,0.00875,0.012630625,0.016485,0.017793125,0.013584375,0.0009231250099999999,-0.019236875,-0.034409375,-0.04139625,-0.03905125,-0.019149375,0.0196175,0.0578375,0.0783825,0.071505,0.0426475,0.013803125,-0.00765625,-0.02118375,-0.022185625,-0.009104375,0.01456,0.04036375,0.0554925,0.051016875,0.0412825,0.032589375,0.016454375,-0.00354375,-0.013908125,6.5625015e-05,0.0409325,0.081598125,0.09006375,0.0808325,0.073845625,0.064194375,0.050019375,0.030625,0.013610625,0.021004375,0.049966875,0.080705625,0.11165437,0.12945625,0.11637937,0.0807275,0.049030625,0.031810625,0.02046625,0.022115625,0.057264375,0.12487125,0.17792687,0.17952812,0.15146687,0.11563562,0.072270625,0.039375,0.02737,0.02680125,0.03808875,0.06435625,0.09177875,0.10839937,0.1176525,0.10840375,0.087416875,0.072148125,0.05096,0.0251475,0.0099925,0.0194775,0.0600775,0.12268812,0.17410312,0.19308187,0.17986937,0.14232312,0.09982,0.0546175,0.02268,0.021625625,0.047569375,0.1045625,0.16269312,0.17444,0.15460375,0.12536562,0.08502375,0.04853625,0.02604875,0.019718125,0.04291875,0.09258375,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.043176875,0.032265625,0.025655,0.07252875,0.14625187,0.18119062,0.19056187,0.17415125,0.13018687,0.086078125,0.059268125,0.076321079,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591,0.10375591};
    //Option 1 (average is zero)
    //R_volcanic={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.11622211,0.23244422,0.19744422,0.13181922,0.12744422,0.17994422,0.21494422,0.22806922,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.21056922,0.11869422,0.04431921900000001,0.10119422,0.18869422,0.22369422,0.22806922,0.12306922,-0.025680781,0.009319218800000001,0.14056922,0.20619422,0.21494422,0.19306922,0.18869422,0.21056922,0.22806922,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,-0.25755578,-1.3994308000000002,-1.8019308,-1.0100558000000002,-0.34068078,-0.14818078,-0.67755578,-2.1519307999999997,-2.6638057999999996,-1.4956808000000001,-0.36255578,0.09244421900000001,0.22369422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.23244422,0.22806922,0.19306922,-0.021305781,-0.39755578,-0.48505578,-0.18318078,-0.34505578,-0.98818078,-0.94880578,-0.34943078,0.04431921900000001,0.17994422,0.17994422,0.17556922,0.18869422,0.16681922,0.15369422,0.18431922,0.21494422,0.22806922,0.23244422,0.21599422,0.19200464,0.19303276,0.20879734,0.2235338,0.2317588,0.10118693,-0.35667141,-0.61027557,-0.29772557,0.028190052,0.15053693,0.13957026,0.05526401,0.06760151,0.15087964,0.19851609,0.21907859,0.22901714,0.23107339,0.22284839,0.21873589,0.2194213,0.2070838,0.19337547,0.20125776,0.19406089,0.15293589,0.14848068,0.18035255,0.20194318,0.21565151,0.22284839,0.11112547,-0.80253495,-1.5373016000000002,-0.94407349,-0.44851724,-0.32137245,-0.21102036,-0.27750578,-0.3316537,-0.2617412,-0.087645365,0.060061927,0.16938589,0.1618463,0.016537969,-0.064683906,0.037785885,0.15053693,0.20194318,0.19166193,-0.25694328,-0.65105786,-0.3563287,0.0021442188,0.1001588,0.07616921900000001,0.08782130199999999,0.15396401,0.18892026,0.19508901,-0.048576615,-0.15652974,0.055606719000000006,0.15944734,0.18754943,0.19611714,0.20194318,0.1947463,0.11078276,0.095703594,0.18103797,0.20228589,0.18926297,0.18926297,0.19714526,0.19508901,0.14573901,0.09604630199999999,0.12174943,0.14642443,0.11489526,0.12380568,0.16218901,0.16938589,0.18069526,0.17932443,0.16321714,0.16390255,0.18377964,0.19303276,0.17144214,0.16630151,0.18926297,0.19988693,0.2070838,0.1988588,0.19680255,0.18926297,0.18686401,0.1906338,0.18446505,0.17555464,0.18069526,0.2029713,0.2153088,0.22559005,0.23073068,0.22696089,0.15190776,0.060747344,-0.013963073000000001,-0.49546828,-0.85325578,-0.53248078,-0.15001828,-0.021502656000000002,-0.22027349,-0.29635474,-0.055430781,0.11420984,0.15327859,0.10632755,-0.040694323,-0.14110786,-0.017390156,0.13408693,0.10906922,0.09399005199999999,0.14813797,0.07959630200000001,-0.59142661,-0.87621724,-0.32000161,-0.023216197999999997,0.035044219,0.065887969,0.10598484,0.12928901,0.12654734,-0.81487245,-1.4197527,-0.68190161,-0.13151203,0.058691094000000006,0.12380568,0.15327859,0.18754943,0.21633693,0.22867443,0.23244422,0.23244422,0.23244422,0.23244422,0.18401834,0.06779623,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //Option 2, maximum is zero and average goes into future
    R_volcanic={-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.007506365,-0.007495294,-0.007491568,-0.007490323,-0.007489904,-0.03176153,-0.257391943,-0.12777055,-0.049545366,-0.021691776,-0.012263739,-0.009093495,-0.913130926,-0.633212161,-0.232299364,-0.083670374,-0.371739566,-0.423291717,-0.163707916,-0.060717424,-0.156889691,-0.104359003,-0.042151518,-0.019229483,-0.011437604,-0.008816032,-0.007935224,-0.007639354,-0.007539964,-0.007506575,-0.007495358,-0.007491589,-0.007490327,-1.800363349,-3.680801682,-1.515973236,-0.680509563,-0.289389801,-0.104720974,-0.040266147,-0.018504901,-0.011190048,-0.008732686,-0.007907223,-0.007629939,-0.007536797,-0.137113137,-0.236046893,-0.135706772,-0.052897894,-0.022849153,-0.012653943,-0.009224641,-0.008072483,-0.007685456,-0.007555447,-0.007511781,-0.00749711,-0.007492182,-3.558940174,-2.507082068,-0.905553661,-0.311815036,-0.109836634,-0.041874622,-3.535056941,-4.522065832,-1.712771796,-0.588697559,-0.203104991,-0.073216323,-0.132876867,-0.127819534,-0.463319759,-0.222913424,-0.082686978,-0.032878084,-0.016023785,-0.010356652,-0.008452746,-0.007813192,-2.437992641,-1.692020251,-0.612736584,-0.212589221,-1.85661457,-1.260977319,-0.45731116,-0.15989702,-0.058744405,-0.024709409,-0.013274104,-0.009432743,-0.00814238,-0.00770894,-0.007563334,-0.189716477,-0.133390531,-0.052722051,-0.022817462,-0.012506065,-0.008939241,-0.0137117,-0.177364785,-0.207364652,-0.080303445,-0.070996428,-0.238075371,-0.106964214,-0.03974861,-0.016482666,-0.077015816,-0.817051871,-0.451824948,-0.155252193,-0.050323171,-0.018841566,-0.008582864,-0.005103373,-0.003839675,-0.003301199,-0.003001643,-0.004417724,-0.20908207,-0.091876374,-0.074265708,-0.063144716,-0.023644793,-0.008841297,-0.004592735,-0.04086501,-0.045209521,-0.005815838,-0.517846093,-2.0083139,-0.835271753,-0.278497422,-0.218271514,-0.058244737,-0.00743313,-0.122950452,-0.295565797,-0.115621184,-0.006836437,-0.000409041,-0.000160995,-6.85782E-05,-2.76277E-05,-7.65767E-06,0,-2.36246E-06,-9.03551E-05,-0.1026546,-0.901979514,-0.457560879,-0.115668915,-0.018311611,-0.13122042,-0.067477829,-0.001474488,-0.001661848,-0.001852418,-0.441560486,-0.502683732,-0.172853594,-0.0291145,-0.004030282,-0.003068851,-0.003275727,-0.003491938,-0.003711333,-0.003933928,-0.105547463,-0.072314206,-0.004620829,-0.004856298,-0.005094978,-0.005336952,-0.029983545,-0.184792603,-0.013340081,-0.006336755,-0.150709419,-0.042881125,-0.007120753,-0.007388505,-0.007659522,-0.007933782,-0.008211303,-0.008492129,-0.008776206,-0.009063453,-0.009353945,-0.009647663,-0.009944658,-0.010244911,-0.010548445,-0.010855223,-0.01116524,-0.011478538,-0.011795076,-0.012114921,-0.012438029,-0.012764364,-0.013093993,-0.01342687,-0.013763033,-0.014102519,-0.014445286,-0.014791283,-0.015140575,-0.018409448,-0.174373562,-0.909066011,-0.813552436,-0.485981359,-0.076342387,-0.269589487,-0.192131047,-0.118392821,-0.11434196,-0.22538545,-0.144132386,-0.038023209,-0.090461378,-0.398221056,-0.150456108,-0.064798026,-0.042588491,-0.045940609,-0.084061883,-0.117514765,-0.34966788,-0.870846566,-0.422159875,-0.20496774,-0.193398621,-0.131082284,-0.083004106,-0.050636578,-0.052456728,-0.608070617,-1.876828788,-1.010336444,-0.274637048,-0.107944318,-0.047559814,-0.026349551,-0.022159457,-0.020010189,-0.018669623,-0.022409003,-0.016729782,-0.028101996,-0.02134875,-0.043444186,-0.068697927,-0.071832651,-0.059975005,-0.086567827,-0.055264485,-0.084195126,-0.054576858,-0.035580496,-0.053473676,-0.067451513,-0.081429349,-0.095407185,-0.109385022,-0.123362858,-0.137340694,-0.151318531,-0.165296367,-0.179274203,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204};
    
    
    //Option 3: average is zero and zero goes into the future
    //R_volcanic={-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.19325204,-0.007506365    -0.007495294    -0.007491568    -0.007490323    -0.007489904    -0.03176153    -0.257391943    -0.12777055    -0.049545366    -0.021691776    -0.012263739    -0.009093495    -0.913130926    -0.633212161    -0.232299364    -0.083670374    -0.371739566    -0.423291717    -0.163707916    -0.060717424    -0.156889691    -0.104359003    -0.042151518    -0.019229483    -0.011437604    -0.008816032    -0.007935224    -0.007639354    -0.007539964    -0.007506575    -0.007495358    -0.007491589    -0.007490327    -1.800363349    -3.680801682    -1.515973236    -0.680509563    -0.289389801    -0.104720974    -0.040266147    -0.018504901    -0.011190048    -0.008732686    -0.007907223    -0.007629939    -0.007536797    -0.137113137    -0.236046893    -0.135706772    -0.052897894    -0.022849153    -0.012653943    -0.009224641    -0.008072483    -0.007685456    -0.007555447    -0.007511781    -0.00749711    -0.007492182    -3.558940174    -2.507082068    -0.905553661    -0.311815036    -0.109836634    -0.041874622    -3.535056941    -4.522065832    -1.712771796    -0.588697559    -0.203104991    -0.073216323    -0.132876867    -0.127819534    -0.463319759    -0.222913424    -0.082686978    -0.032878084    -0.016023785    -0.010356652    -0.008452746    -0.007813192    -2.437992641    -1.692020251    -0.612736584    -0.212589221    -1.85661457    -1.260977319    -0.45731116    -0.15989702    -0.058744405    -0.024709409    -0.013274104    -0.009432743    -0.00814238    -0.00770894    -0.007563334    -0.189716477    -0.133390531    -0.052722051    -0.022817462    -0.012506065    -0.008939241    -0.0137117    -0.177364785    -0.207364652    -0.080303445    -0.070996428    -0.238075371    -0.106964214    -0.03974861    -0.016482666    -0.077015816    -0.817051871    -0.451824948    -0.155252193    -0.050323171    -0.018841566    -0.008582864    -0.005103373    -0.003839675    -0.003301199    -0.003001643    -0.004417724    -0.20908207    -0.091876374    -0.074265708    -0.063144716    -0.023644793    -0.008841297    -0.004592735    -0.04086501    -0.045209521    -0.005815838    -0.517846093    -2.0083139    -0.835271753    -0.278497422    -0.218271514    -0.058244737    -0.00743313    -0.122950452    -0.295565797    -0.115621184    -0.006836437    -0.000409041    -0.000160995    -6.85782E-05    -2.76277E-05    -7.65767E-06    0    -2.36246E-06    -9.03551E-05    -0.1026546    -0.901979514    -0.457560879    -0.115668915    -0.018311611    -0.13122042    -0.067477829    -0.001474488    -0.001661848    -0.001852418    -0.441560486    -0.502683732    -0.172853594    -0.0291145    -0.004030282    -0.003068851    -0.003275727    -0.003491938    -0.003711333    -0.003933928    -0.105547463    -0.072314206    -0.004620829    -0.004856298    -0.005094978    -0.005336952    -0.029983545    -0.184792603    -0.013340081    -0.006336755    -0.150709419    -0.042881125    -0.007120753    -0.007388505    -0.007659522    -0.007933782    -0.008211303    -0.008492129    -0.008776206    -0.009063453    -0.009353945    -0.009647663    -0.009944658    -0.010244911    -0.010548445    -0.010855223    -0.01116524    -0.011478538    -0.011795076    -0.012114921    -0.012438029    -0.012764364    -0.013093993    -0.01342687    -0.013763033    -0.014102519    -0.014445286    -0.014791283    -0.015140575    -0.018409448    -0.174373562    -0.909066011    -0.813552436    -0.485981359    -0.076342387    -0.269589487    -0.192131047    -0.118392821    -0.11434196    -0.22538545    -0.144132386    -0.038023209    -0.090461378    -0.398221056    -0.150456108    -0.064798026    -0.042588491    -0.045940609    -0.084061883    -0.117514765    -0.34966788    -0.870846566    -0.422159875    -0.20496774    -0.193398621    -0.131082284    -0.083004106    -0.050636578    -0.052456728    -0.608070617    -1.876828788    -1.010336444    -0.274637048    -0.107944318    -0.047559814    -0.026349551    -0.022159457    -0.020010189    -0.018669623    -0.022409003    -0.016729782    -0.028101996    -0.02134875    -0.043444186    -0.068697927    -0.071832651    -0.059975005    -0.086567827    -0.055264485    -0.084195126    -0.054576858    -0.035580496    -0.053473676    -0.067451513    -0.081429349    -0.095407185    -0.109385022    -0.123362858    -0.137340694    -0.151318531    -0.165296367    -0.179274203    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0};
    
    
    
    //Now convert R_solar and R_volcanic from annual timestep to model timestep
    //Define the dummy vector
    std::vector<double> Dummy;
    
    //First make RnonCO2 vector have at least tmax elements
    if(R_solar.size() < tmax)
    {
        for (int i = R_solar.size(); i < tmax; i++)
        {
            R_solar.push_back(R_solar[i-1]);
        }
         
    }
    
    
    Dummy.assign(tmax, 0.0);
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = R_solar[i];
    }
    //Now re-set original array by linearising between years
    
    int years=0;
    int count = 0;
    double annual_dRnonCO2;
    for(int i=0; i<tmax; i++)
    {
        annual_dRnonCO2 = Dummy[years+1]-Dummy[years]; //set annual emission rate
        
        R_solar[i] = Dummy[years] + double(count)*annual_dRnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //First make RnonCO2 vector have at least tmax elements
    if(R_volcanic.size() < tmax)
    {
        for (int i = R_volcanic.size(); i < tmax; i++)
        {
            R_volcanic.push_back(R_volcanic[i-1]);
        }
        
    }
    
    //re-assign dummy array to R_volcanic
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = R_volcanic[i];
    }
    //Now re-set original volcanic array by linearising between years
    
    years=0;
    count = 0;
    
    for(int i=0; i<tmax; i++)
    {
        annual_dRnonCO2 = Dummy[years+1]-Dummy[years]; //set annual emission rate
        
        R_volcanic[i] = Dummy[years] + double(count)*annual_dRnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
}

double getRnonCO2(int i_year, int i_t_step, double coeff_N2O, double coeff_CH4, double coeff_Halocarbons, int year_start, double PgCtoppm)
{
    double RF = 0.0;
    //Add in minor constituents
    RF += coeff_Halocarbons*(CF4_coeff*CF4[i_year] + C2F6_coeff*C2F6[i_year] + C6F14_coeff*C6F14[i_year] + HFC23_coeff*HFC23[i_year]+HFC32_coeff*HFC32[i_year] + HFC4310mee_coeff*HFC4310mee[i_year] + HFC125_coeff*HFC125[i_year] + HFC134a_coeff*HFC134a[i_year] + HFC143a_coeff*HFC134a[i_year] + HFC227ea_coeff*HFC227ea[i_year] + HFC245fa_coeff*HFC245fa[i_year] + SF6_coeff*SF6[i_year] + CFC11_coeff*CFC11[i_year] + CFC12_coeff*CFC12[i_year] + CFC113_coeff*CFC113[i_year] + CFC114_coeff*CFC114[i_year] + CFC115_coeff*CFC115[i_year] + CCl4_coeff*CCl4[i_year] + HCFC22_coeff*HCFC22[i_year] + HCFC141b_coeff*HCFC141b[i_year] + HCFC142b_coeff*HCFC142b[i_year] + Halon1211_coeff*Halon1211[i_year] + Halon1202_coeff*Halon1202[i_year] + Halon1301_coeff*Halon1301[i_year] + Halon2402_coeff*Halon2402[i_year] + CH3Br_coeff*CH3Br[i_year] + CH3Cl_coeff*CH3Cl[i_year]);
    
    
    //Add in N2O and CH4, using Etminan et al 2016. First define coefficients
    double a2 = -8.0e-6;
    double b2 = 4.2e-6;
    double c2 = -4.9e-6;
    double a3 = -1.3e-6;
    double b3 = -8.2e-6;
    
    //Add in the N2O forcing - coeff is an uncertainty multiplier
    RF += coeff_N2O*(( a2*0.5*(CO2[i_t_step] + CO2[0])*PgCtoppm + b2*0.5*(CH4[i_year]+CH4[0]) + c2*0.5*(N2O[i_year] + N2O[0]) + 0.117 )*(sqrt(N2O[i_year]) - sqrt(N2O[0])));
    
    //Add in CH4 forcing - coeff is an uncertianty multiplier
    RF += coeff_CH4*(a3*0.5*(CH4[i_year] + CH4[0] ) + b3*0.5*(N2O[i_year] + N2O[0]) + 0.043)* (sqrt(CH4[i_year]) - sqrt(CH4[0]));
    
    return RF;
}

//Random number functions////////////////////

//This function applies the Box-Muller Method - this routine generates two uniform random numbers and calculates only one of the random-normal numbers

double getRandomNormal(double mu, double sigma)
{
    double pi = acos(-1.0);
    
    double U, V;
    
    double Random_normal;
    
    U = double(rand())/double(RAND_MAX);
    V = double(rand())/double(RAND_MAX);
    
    Random_normal =  ( ( sqrt(-2.0*log(U))*cos(2*pi*V) ) * sigma ) + mu;
    
    return Random_normal;
}

double getRandomNormal2(double mu, double sigma, int seed)
{
    std::minstd_rand0 generator (seed);
    
    double pi = acos(-1.0);
    
    double U, V;
    
    double Random_normal;
    
    U = ( double(generator())/(double(generator.max())-double(generator.min() ) +1.0  ) );
    V = ( double(generator())/(double(generator.max())-double(generator.min() ) +1.0  ) );
    
    Random_normal =  ( ( sqrt(-2.0*log(U))*cos(2*pi*V) ) * sigma ) + mu;
    
    return Random_normal;
}




//Making Random Skew Normal distribution by linear sum of random normal and random half-normal.
double getRandomSkewNormnal(double mu, double sigma, double alpha)
{
    double pi = acos(-1.0);
    
    double U, V;
    
    double Random_Skew_Normal, Random_Normal, Random_Half_Normal;
    
    double delta;
    
    U = double(rand())/double(RAND_MAX);
    V = double(rand())/double(RAND_MAX);
    
    //Get random normal and random half-normal variables from Box Muller method
    
    Random_Normal =  ( sqrt(-2.0*log(U))*cos(2.0*pi*V) );
    Random_Half_Normal = ( sqrt(-2.0*log(U))*sin(2.0*pi*V) );
    if (Random_Half_Normal < 0.0)
    {
        Random_Half_Normal = -Random_Half_Normal;
    }
    
    //Now linearly combine via skew to get
    
    delta = (alpha / (sqrt(1.0 + (alpha*alpha))) );
    
    Random_Skew_Normal = delta * Random_Half_Normal  + ( sqrt(1.0-(delta*delta))*Random_Normal );
    
    
    //Subtract existing mean, then multiply by wanted stadard deviation divided by existing standard deviation, then add wanted mean
    Random_Skew_Normal = ( (Random_Skew_Normal - 1.0 * delta * sqrt(2.0/pi) ) * sigma /sqrt( (1.0 - 2.0*delta*delta/pi) ) ) + mu;
        
    return Random_Skew_Normal;
}

//Making Random Skew Normal distribution by linear sum of random normal and random half-normal.
double getRandomSkewNormnal2(double mu, double sigma, double alpha, int seed)
{
    
    std::minstd_rand0 generator (seed);
    
    double pi = acos(-1.0);
    
    double U, V;
    
    double Random_Skew_Normal, Random_Normal, Random_Half_Normal;
    
    double delta;
    
    U = ( double(generator())/(double(generator.max())-double(generator.min() ) +1.0  ) );
    V = ( double(generator())/(double(generator.max())-double(generator.min() ) +1.0  ) );
    
    //Get random normal and random half-normal variables from Box Muller method
    
    Random_Normal =  ( sqrt(-2.0*log(U))*cos(2.0*pi*V) );
    Random_Half_Normal = ( sqrt(-2.0*log(U))*sin(2.0*pi*V) );
    if (Random_Half_Normal < 0.0)
    {
        Random_Half_Normal = -Random_Half_Normal;
    }
    
    //Now linearly combine via skew to get
    
    delta = (alpha / (sqrt(1.0 + (alpha*alpha))) );
    
    Random_Skew_Normal = delta * Random_Half_Normal  + ( sqrt(1.0-(delta*delta))*Random_Normal );
    
    
    //Subtract existing mean, then multiply by wanted stadard deviation divided by existing standard deviation, then add wanted mean
    Random_Skew_Normal = ( (Random_Skew_Normal - 1.0 * delta * sqrt(2.0/pi) ) * sigma /sqrt( (1.0 - 2.0*delta*delta/pi) ) ) + mu;
    
    return Random_Skew_Normal;
}


double getRandomLinear(double Min, double Max)
{
    double value;
    
    value = Min + ( double(rand())/double(RAND_MAX) ) * (Max - Min);
    
    return value;
}

double getRandomLinear2(double Min, double Max, int seed)
{
    double value;
    
    std::minstd_rand0 generator (seed);
    
    value = Min + ( double(generator())/(double(generator.max())-double(generator.min() ) +1.0  ) ) * (Max - Min);
    
    //cout << generator() << '\t' << generator.max() << '\t' << generator.min() << '\t' << value << endl;
    
    return value;
}



//The terrestrial system functions
double getdCvdt(double pCO2, double pCO2init, double DeltaTemp, double Cv, double Cv0, double NPP0, double gamma, double dNPPdT)
{
    
    double dCvdt;
    
    //Alternatively could do with half saturation coefficients
    //double kc=29.0; //in ppm
    //double km=145.0; //in ppm
    
    
    
    
    
    double f1, f2;
    
    f1 = 1.0 + (dNPPdT/NPP0)*DeltaTemp;
    
    //Stability - f1 should not be less than 0
    if(f1 < 0.001)
    {
        f1 = 0.001;
    }
    //f2 = ( (pCO2 - kc)/(km + pCO2 - kc) ) / ( (pCO2init - kc)/(km + pCO2init - kc) );
    
    f2 = 1.0 + gamma*log(pCO2/pCO2init);
    
    dCvdt = NPP0*f1*f2 - NPP0*(Cv/Cv0);
    
    return dCvdt;
    
    
}

double getNPP(double pCO2, double pCO2init, double DeltaTemp, double Cv, double Cv0, double NPP0, double gamma, double dNPPdT)
{
    double dCvdt;
    
    //Alternatively could do with half saturation coefficients
    //double kc=29.0; //in ppm
    //double km=145.0; //in ppm
    
    
    
    
    
    double f1, f2;
    
    f1 = 1.0 + (dNPPdT/NPP0)*DeltaTemp;
    
    //Stability - f1 should not be less than 0
    if(f1 < 0.001)
    {
        f1 = 0.001;
    }
    //f2 = ( (pCO2 - kc)/(km + pCO2 - kc) ) / ( (pCO2init - kc)/(km + pCO2init - kc) );
    
    f2 = 1.0 + gamma*log(pCO2/pCO2init);
    
    return NPP0*f1*f2;
    
}

double getdCsdt(double Cv, double Cv0, double Cs, double Cs0, double NPP0, double DeltaTemp, double dtaudT)
{
    double dCsdt;
    double f3;
    
    
    f3 = (Cs0/NPP0) / ( (Cs0/NPP0) + (dtaudT*DeltaTemp) );
    //Stability - f3 should not be less than 0
    if(f3 < 0.001)
    {
        f3 = 0.001;
    }
    
    dCsdt = ( NPP0 * (Cv/Cv0) ) - ( NPP0 * (Cs/Cs0) * f3 );
    
    return dCsdt;
    
    
}

//The scenarios and palaeo input distributions

//This sets lambda from the log-normal palaeosens distribution (Rohling et al, Nature)
double get_lambda_palaeosens1(double random)
{
    double lambda_palaeosens = 0.0;
    double S=0;
    
    if(random >= 	0.000000E+00	) S=	0.01	;
    if(random >= 	1.701000E-14	) S=	0.02	;
    if(random >= 	3.298100E-13	) S=	0.03	;
    if(random >= 	9.384100E-13	) S=	0.04	;
    if(random >= 	5.841410E-12	) S=	0.05	;
    if(random >= 	1.503941E-11	) S=	0.06	;
    if(random >= 	9.417941E-11	) S=	0.07	;
    if(random >= 	5.539794E-10	) S=	0.08	;
    if(random >= 	2.557979E-09	) S=	0.09	;
    if(random >= 	9.586979E-09	) S=	0.1	;
    if(random >= 	3.040698E-08	) S=	0.11	;
    if(random >= 	0.0000000843	) S=	0.12	;
    if(random >= 	0.0000002094	) S=	0.13	;
    if(random >= 	0.0000004748	) S=	0.14	;
    if(random >= 	0.0000009969	) S=	0.15	;
    if(random >= 	0.0000019606	) S=	0.16	;
    if(random >= 	0.0000036456	) S=	0.17	;
    if(random >= 	0.0000064566	) S=	0.18	;
    if(random >= 	0.0000109606	) S=	0.19	;
    if(random >= 	0.0000179286	) S=	0.2	;
    if(random >= 	0.0000283786	) S=	0.21	;
    if(random >= 	0.0000436586	) S=	0.22	;
    if(random >= 	0.0000654586	) S=	0.23	;
    if(random >= 	0.0000959486	) S=	0.24	;
    if(random >= 	0.0001378286	) S=	0.25	;
    if(random >= 	0.0001944486	) S=	0.26	;
    if(random >= 	0.0002699186	) S=	0.27	;
    if(random >= 	0.0003692286	) S=	0.28	;
    if(random >= 	0.0004983286	) S=	0.29	;
    if(random >= 	0.0006644286	) S=	0.3	;
    if(random >= 	0.0008759286	) S=	0.31	;
    if(random >= 	0.0011425286	) S=	0.32	;
    if(random >= 	0.0014754286	) S=	0.33	;
    if(random >= 	0.0018873286	) S=	0.34	;
    if(random >= 	0.0023924286	) S=	0.35	;
    if(random >= 	0.0030063286	) S=	0.36	;
    if(random >= 	0.0037461286	) S=	0.37	;
    if(random >= 	0.0046302286	) S=	0.38	;
    if(random >= 	0.0056782286	) S=	0.39	;
    if(random >= 	0.0069112286	) S=	0.4	;
    if(random >= 	0.0083502286	) S=	0.41	;
    if(random >= 	0.0100182286	) S=	0.42	;
    if(random >= 	0.0119382286	) S=	0.43	;
    if(random >= 	0.0141352286	) S=	0.44	;
    if(random >= 	0.0166332286	) S=	0.45	;
    if(random >= 	0.0194582286	) S=	0.46	;
    if(random >= 	0.0226362286	) S=	0.47	;
    if(random >= 	0.0261932286	) S=	0.48	;
    if(random >= 	0.0301552286	) S=	0.49	;
    if(random >= 	0.0345482286	) S=	0.5	;
    if(random >= 	0.0393962286	) S=	0.51	;
    if(random >= 	0.0447212286	) S=	0.52	;
    if(random >= 	0.0505412286	) S=	0.53	;
    if(random >= 	0.0568742286	) S=	0.54	;
    if(random >= 	0.0637322286	) S=	0.55	;
    if(random >= 	0.0711232286	) S=	0.56	;
    if(random >= 	0.0790532286	) S=	0.57	;
    if(random >= 	0.0875222286	) S=	0.58	;
    if(random >= 	0.0965292286	) S=	0.59	;
    if(random >= 	0.1060682286	) S=	0.6	;
    if(random >= 	0.1160682286	) S=	0.61	;
    if(random >= 	0.1270682286	) S=	0.62	;
    if(random >= 	0.1380682286	) S=	0.63	;
    if(random >= 	0.1500682286	) S=	0.64	;
    if(random >= 	0.1620682286	) S=	0.65	;
    if(random >= 	0.1750682286	) S=	0.66	;
    if(random >= 	0.1880682286	) S=	0.67	;
    if(random >= 	0.2010682286	) S=	0.68	;
    if(random >= 	0.2150682286	) S=	0.69	;
    if(random >= 	0.2290682286	) S=	0.7	;
    if(random >= 	0.2440682286	) S=	0.71	;
    if(random >= 	0.2590682286	) S=	0.72	;
    if(random >= 	0.2740682286	) S=	0.73	;
    if(random >= 	0.2900682286	) S=	0.74	;
    if(random >= 	0.3060682286	) S=	0.75	;
    if(random >= 	0.3220682286	) S=	0.76	;
    if(random >= 	0.3380682286	) S=	0.77	;
    if(random >= 	0.3540682286	) S=	0.78	;
    if(random >= 	0.3700682286	) S=	0.79	;
    if(random >= 	0.3860682286	) S=	0.8	;
    if(random >= 	0.4020682286	) S=	0.81	;
    if(random >= 	0.4180682286	) S=	0.82	;
    if(random >= 	0.4340682286	) S=	0.83	;
    if(random >= 	0.4490682286	) S=	0.84	;
    if(random >= 	0.4640682286	) S=	0.85	;
    if(random >= 	0.4790682286	) S=	0.86	;
    if(random >= 	0.4940682286	) S=	0.87	;
    if(random >= 	0.5080682286	) S=	0.88	;
    if(random >= 	0.5220682286	) S=	0.89	;
    if(random >= 	0.5360682286	) S=	0.9	;
    if(random >= 	0.5490682286	) S=	0.91	;
    if(random >= 	0.5620682286	) S=	0.92	;
    if(random >= 	0.5750682286	) S=	0.93	;
    if(random >= 	0.5880682286	) S=	0.94	;
    if(random >= 	0.6000682286	) S=	0.95	;
    if(random >= 	0.6120682286	) S=	0.96	;
    if(random >= 	0.6240682286	) S=	0.97	;
    if(random >= 	0.6350682286	) S=	0.98	;
    if(random >= 	0.6460682286	) S=	0.99	;
    if(random >= 	0.6570682286	) S=	1	;
    if(random >= 	0.6670682286	) S=	1.01	;
    if(random >= 	0.6770682286	) S=	1.02	;
    if(random >= 	0.6868072286	) S=	1.03	;
    if(random >= 	0.6962522286	) S=	1.04	;
    if(random >= 	0.7054092286	) S=	1.05	;
    if(random >= 	0.7142832286	) S=	1.06	;
    if(random >= 	0.7228812286	) S=	1.07	;
    if(random >= 	0.7312092286	) S=	1.08	;
    if(random >= 	0.7392752286	) S=	1.09	;
    if(random >= 	0.7470852286	) S=	1.1	;
    if(random >= 	0.7546462286	) S=	1.11	;
    if(random >= 	0.7619652286	) S=	1.12	;
    if(random >= 	0.7690502286	) S=	1.13	;
    if(random >= 	0.7759082286	) S=	1.14	;
    if(random >= 	0.7825452286	) S=	1.15	;
    if(random >= 	0.7889692286	) S=	1.16	;
    if(random >= 	0.7951872286	) S=	1.17	;
    if(random >= 	0.8012052286	) S=	1.18	;
    if(random >= 	0.8070292286	) S=	1.19	;
    if(random >= 	0.8126672286	) S=	1.2	;
    if(random >= 	0.8181242286	) S=	1.21	;
    if(random >= 	0.8234062286	) S=	1.22	;
    if(random >= 	0.8285202286	) S=	1.23	;
    if(random >= 	0.8334702286	) S=	1.24	;
    if(random >= 	0.8382632286	) S=	1.25	;
    if(random >= 	0.8429032286	) S=	1.26	;
    if(random >= 	0.8473962286	) S=	1.27	;
    if(random >= 	0.8517472286	) S=	1.28	;
    if(random >= 	0.8559612286	) S=	1.29	;
    if(random >= 	0.8600422286	) S=	1.3	;
    if(random >= 	0.8639952286	) S=	1.31	;
    if(random >= 	0.8678242286	) S=	1.32	;
    if(random >= 	0.8715332286	) S=	1.33	;
    if(random >= 	0.8751262286	) S=	1.34	;
    if(random >= 	0.8786072286	) S=	1.35	;
    if(random >= 	0.8819802286	) S=	1.36	;
    if(random >= 	0.8852492286	) S=	1.37	;
    if(random >= 	0.8884172286	) S=	1.38	;
    if(random >= 	0.8914872286	) S=	1.39	;
    if(random >= 	0.8944632286	) S=	1.4	;
    if(random >= 	0.8973482286	) S=	1.41	;
    if(random >= 	0.9001452286	) S=	1.42	;
    if(random >= 	0.9028572286	) S=	1.43	;
    if(random >= 	0.9054862286	) S=	1.44	;
    if(random >= 	0.9080362286	) S=	1.45	;
    if(random >= 	0.9105092286	) S=	1.46	;
    if(random >= 	0.9129082286	) S=	1.47	;
    if(random >= 	0.9152352286	) S=	1.48	;
    if(random >= 	0.9174922286	) S=	1.49	;
    if(random >= 	0.9196822286	) S=	1.5	;
    if(random >= 	0.9218082286	) S=	1.51	;
    if(random >= 	0.9238712286	) S=	1.52	;
    if(random >= 	0.9258732286	) S=	1.53	;
    if(random >= 	0.9278172286	) S=	1.54	;
    if(random >= 	0.9297042286	) S=	1.55	;
    if(random >= 	0.9315362286	) S=	1.56	;
    if(random >= 	0.9333152286	) S=	1.57	;
    if(random >= 	0.9350432286	) S=	1.58	;
    if(random >= 	0.9367222286	) S=	1.59	;
    if(random >= 	0.9383532286	) S=	1.6	;
    if(random >= 	0.9399372286	) S=	1.61	;
    if(random >= 	0.9414772286	) S=	1.62	;
    if(random >= 	0.9429732286	) S=	1.63	;
    if(random >= 	0.9444272286	) S=	1.64	;
    if(random >= 	0.9458412286	) S=	1.65	;
    if(random >= 	0.9472162286	) S=	1.66	;
    if(random >= 	0.9485532286	) S=	1.67	;
    if(random >= 	0.9498532286	) S=	1.68	;
    if(random >= 	0.9511172286	) S=	1.69	;
    if(random >= 	0.9523472286	) S=	1.7	;
    if(random >= 	0.9535442286	) S=	1.71	;
    if(random >= 	0.9547082286	) S=	1.72	;
    if(random >= 	0.9558412286	) S=	1.73	;
    if(random >= 	0.9569442286	) S=	1.74	;
    if(random >= 	0.9580172286	) S=	1.75	;
    if(random >= 	0.9590622286	) S=	1.76	;
    if(random >= 	0.9600792286	) S=	1.77	;
    if(random >= 	0.9610699286	) S=	1.78	;
    if(random >= 	0.9620346286	) S=	1.79	;
    if(random >= 	0.9629743286	) S=	1.8	;
    if(random >= 	0.9638897286	) S=	1.81	;
    if(random >= 	0.9647815286	) S=	1.82	;
    if(random >= 	0.9656504286	) S=	1.83	;
    if(random >= 	0.9664972286	) S=	1.84	;
    if(random >= 	0.9673225286	) S=	1.85	;
    if(random >= 	0.9681269286	) S=	1.86	;
    if(random >= 	0.9689110286	) S=	1.87	;
    if(random >= 	0.9696754286	) S=	1.88	;
    if(random >= 	0.9704208286	) S=	1.89	;
    if(random >= 	0.9711475286	) S=	1.9	;
    if(random >= 	0.9718563286	) S=	1.91	;
    if(random >= 	0.9725476286	) S=	1.92	;
    if(random >= 	0.9732219286	) S=	1.93	;
    if(random >= 	0.9738797286	) S=	1.94	;
    if(random >= 	0.9745214286	) S=	1.95	;
    if(random >= 	0.9751476286	) S=	1.96	;
    if(random >= 	0.9757586286	) S=	1.97	;
    if(random >= 	0.9763548286	) S=	1.98	;
    if(random >= 	0.9769367286	) S=	1.99	;
    if(random >= 	0.9775047286	) S=	2	;
    if(random >= 	0.9780591286	) S=	2.01	;
    if(random >= 	0.9786004286	) S=	2.02	;
    if(random >= 	0.9791288286	) S=	2.03	;
    if(random >= 	0.9796448286	) S=	2.04	;
    if(random >= 	0.9801487286	) S=	2.05	;
    if(random >= 	0.9806407286	) S=	2.06	;
    if(random >= 	0.9811212286	) S=	2.07	;
    if(random >= 	0.9815905286	) S=	2.08	;
    if(random >= 	0.9820489286	) S=	2.09	;
    if(random >= 	0.9824967286	) S=	2.1	;
    if(random >= 	0.9829341286	) S=	2.11	;
    if(random >= 	0.9833614286	) S=	2.12	;
    if(random >= 	0.9837789286	) S=	2.13	;
    if(random >= 	0.9841867286	) S=	2.14	;
    if(random >= 	0.9845852286	) S=	2.15	;
    if(random >= 	0.9849747286	) S=	2.16	;
    if(random >= 	0.9853553286	) S=	2.17	;
    if(random >= 	0.9857273286	) S=	2.18	;
    if(random >= 	0.9860909286	) S=	2.19	;
    if(random >= 	0.9864463286	) S=	2.2	;
    if(random >= 	0.9867936286	) S=	2.21	;
    if(random >= 	0.9871331286	) S=	2.22	;
    if(random >= 	0.9874650286	) S=	2.23	;
    if(random >= 	0.9877895286	) S=	2.24	;
    if(random >= 	0.9881067286	) S=	2.25	;
    if(random >= 	0.9884168286	) S=	2.26	;
    if(random >= 	0.9887200286	) S=	2.27	;
    if(random >= 	0.9890165286	) S=	2.28	;
    if(random >= 	0.9893064286	) S=	2.29	;
    if(random >= 	0.9895899286	) S=	2.3	;
    if(random >= 	0.9898671286	) S=	2.31	;
    if(random >= 	0.9901382286	) S=	2.32	;
    if(random >= 	0.9904033286	) S=	2.33	;
    if(random >= 	0.9906626286	) S=	2.34	;
    if(random >= 	0.9909162286	) S=	2.35	;
    if(random >= 	0.9911643286	) S=	2.36	;
    if(random >= 	0.9914070286	) S=	2.37	;
    if(random >= 	0.9916444286	) S=	2.38	;
    if(random >= 	0.9918766286	) S=	2.39	;
    if(random >= 	0.9921037286	) S=	2.4	;
    if(random >= 	0.9923259286	) S=	2.41	;
    if(random >= 	0.9925432286	) S=	2.42	;
    if(random >= 	0.9927558286	) S=	2.43	;
    if(random >= 	0.9929638286	) S=	2.44	;
    if(random >= 	0.9931673286	) S=	2.45	;
    if(random >= 	0.9933664286	) S=	2.46	;
    if(random >= 	0.9935612286	) S=	2.47	;
    if(random >= 	0.9937518286	) S=	2.48	;
    if(random >= 	0.9939383286	) S=	2.49	;
    if(random >= 	0.9941208286	) S=	2.5	;
    if(random >= 	0.9942994286	) S=	2.51	;
    if(random >= 	0.9944741286	) S=	2.52	;
    if(random >= 	0.9946451286	) S=	2.53	;
    if(random >= 	0.9948125286	) S=	2.54	;
    if(random >= 	0.9949763286	) S=	2.55	;
    if(random >= 	0.9951366286	) S=	2.56	;
    if(random >= 	0.9952934286	) S=	2.57	;
    if(random >= 	0.9954469286	) S=	2.58	;
    if(random >= 	0.9955971286	) S=	2.59	;
    if(random >= 	0.9957442286	) S=	2.6	;
    if(random >= 	0.9958881286	) S=	2.61	;
    if(random >= 	0.9960290286	) S=	2.62	;
    if(random >= 	0.9961669286	) S=	2.63	;
    if(random >= 	0.9963019286	) S=	2.64	;
    if(random >= 	0.9964340286	) S=	2.65	;
    if(random >= 	0.9965633286	) S=	2.66	;
    if(random >= 	0.9966899286	) S=	2.67	;
    if(random >= 	0.9968138286	) S=	2.68	;
    if(random >= 	0.9969351286	) S=	2.69	;
    if(random >= 	0.9970538286	) S=	2.7	;
    if(random >= 	0.9971700286	) S=	2.71	;
    if(random >= 	0.9972838286	) S=	2.72	;
    if(random >= 	0.9973952286	) S=	2.73	;
    if(random >= 	0.9975043286	) S=	2.74	;
    if(random >= 	0.9976111286	) S=	2.75	;
    if(random >= 	0.9977156286	) S=	2.76	;
    if(random >= 	0.9978179286	) S=	2.77	;
    if(random >= 	0.9979181286	) S=	2.78	;
    if(random >= 	0.9980162086	) S=	2.79	;
    if(random >= 	0.9981122186	) S=	2.8	;
    if(random >= 	0.9982062586	) S=	2.81	;
    if(random >= 	0.9982983286	) S=	2.82	;
    if(random >= 	0.9983884786	) S=	2.83	;
    if(random >= 	0.9984767486	) S=	2.84	;
    if(random >= 	0.9985631786	) S=	2.85	;
    if(random >= 	0.9986478086	) S=	2.86	;
    if(random >= 	0.9987306786	) S=	2.87	;
    if(random >= 	0.9988118286	) S=	2.88	;
    if(random >= 	0.9988912986	) S=	2.89	;
    if(random >= 	0.9989691086	) S=	2.9	;
    if(random >= 	0.9990453086	) S=	2.91	;
    if(random >= 	0.9991199186	) S=	2.92	;
    if(random >= 	0.9991929886	) S=	2.93	;
    if(random >= 	0.9992645486	) S=	2.94	;
    if(random >= 	0.9993346286	) S=	2.95	;
    if(random >= 	0.9994032586	) S=	2.96	;
    if(random >= 	0.9994704686	) S=	2.97	;
    if(random >= 	0.9995362886	) S=	2.98	;
    if(random >= 	0.9996007486	) S=	2.99	;
    if(random >= 	0.9996638886	) S=	3	;
    if(random >= 	0.9997257186	) S=	3.01	;
    if(random >= 	0.9997862686	) S=	3.02	;
    if(random >= 	0.9998455786	) S=	3.03	;
    if(random >= 	0.9999036686	) S=	3.04	;
    if(random >= 	0.9999605586	) S=	3.05	;
    if(random >= 	1.0000162886	) S=	3.06	;
    if(random >= 	1.0000708686	) S=	3.07	;
    if(random >= 	1.0001243286	) S=	3.08	;
    if(random >= 	1.0001766986	) S=	3.09	;
    if(random >= 	1.0002279986	) S=	3.1	;
    if(random >= 	1.0002782386	) S=	3.11	;
    if(random >= 	1.0003274486	) S=	3.12	;
    if(random >= 	1.0003756586	) S=	3.13	;
    if(random >= 	1.0004228786	) S=	3.14	;
    if(random >= 	1.0004691286	) S=	3.15	;
    if(random >= 	1.0005144386	) S=	3.16	;
    if(random >= 	1.0005588286	) S=	3.17	;
    if(random >= 	1.0006023086	) S=	3.18	;
    if(random >= 	1.0006448986	) S=	3.19	;
    if(random >= 	1.0006866286	) S=	3.2	;
    if(random >= 	1.0007275086	) S=	3.21	;
    if(random >= 	1.0007675486	) S=	3.22	;
    if(random >= 	1.0008067886	) S=	3.23	;
    if(random >= 	1.0008452286	) S=	3.24	;
    if(random >= 	1.0008828786	) S=	3.25	;
    if(random >= 	1.0009197686	) S=	3.26	;
    if(random >= 	1.0009559086	) S=	3.27	;
    if(random >= 	1.0009913186	) S=	3.28	;
    if(random >= 	1.0010260186	) S=	3.29	;
    if(random >= 	1.0010600086	) S=	3.3	;
    if(random >= 	1.0010933086	) S=	3.31	;
    if(random >= 	1.0011259386	) S=	3.32	;
    if(random >= 	1.0011579086	) S=	3.33	;
    if(random >= 	1.0011892286	) S=	3.34	;
    if(random >= 	1.0012199286	) S=	3.35	;
    if(random >= 	1.0012499986	) S=	3.36	;
    if(random >= 	1.0012794586	) S=	3.37	;
    if(random >= 	1.0013083286	) S=	3.38	;
    if(random >= 	1.0013366186	) S=	3.39	;
    if(random >= 	1.0013643386	) S=	3.4	;
    if(random >= 	1.0013915086	) S=	3.41	;
    if(random >= 	1.0014181286	) S=	3.42	;
    if(random >= 	1.0014442086	) S=	3.43	;
    if(random >= 	1.0014697686	) S=	3.44	;
    if(random >= 	1.0014948186	) S=	3.45	;
    if(random >= 	1.0015193586	) S=	3.46	;
    if(random >= 	1.0015434086	) S=	3.47	;
    if(random >= 	1.0015669786	) S=	3.48	;
    if(random >= 	1.0015900786	) S=	3.49	;
    if(random >= 	1.0016127186	) S=	3.5	;
    if(random >= 	1.0016349086	) S=	3.51	;
    if(random >= 	1.0016566486	) S=	3.52	;
    if(random >= 	1.0016779586	) S=	3.53	;
    if(random >= 	1.0016988486	) S=	3.54	;
    if(random >= 	1.0017193186	) S=	3.55	;
    if(random >= 	1.0017393786	) S=	3.56	;
    if(random >= 	1.0017590386	) S=	3.57	;
    if(random >= 	1.0017783086	) S=	3.58	;
    if(random >= 	1.0017971986	) S=	3.59	;
    if(random >= 	1.0018157086	) S=	3.6	;
    if(random >= 	1.0018338486	) S=	3.61	;
    if(random >= 	1.0018516286	) S=	3.62	;
    if(random >= 	1.0018690586	) S=	3.63	;
    if(random >= 	1.0018861486	) S=	3.64	;
    if(random >= 	1.0019028986	) S=	3.65	;
    if(random >= 	1.0019193186	) S=	3.66	;
    if(random >= 	1.0019354086	) S=	3.67	;
    if(random >= 	1.0019511786	) S=	3.68	;
    if(random >= 	1.0019666486	) S=	3.69	;
    if(random >= 	1.0019818086	) S=	3.7	;
    if(random >= 	1.0019966686	) S=	3.71	;
    if(random >= 	1.0020112386	) S=	3.72	;
    if(random >= 	1.0020255186	) S=	3.73	;
    if(random >= 	1.0020395186	) S=	3.74	;
    if(random >= 	1.0020532386	) S=	3.75	;
    if(random >= 	1.0020666986	) S=	3.76	;
    if(random >= 	1.0020798886	) S=	3.77	;
    if(random >= 	1.0020928186	) S=	3.78	;
    if(random >= 	1.0021054986	) S=	3.79	;
    if(random >= 	1.0021179286	) S=	3.8	;
    if(random >= 	1.0021301186	) S=	3.81	;
    if(random >= 	1.0021420686	) S=	3.82	;
    if(random >= 	1.0021537786	) S=	3.83	;
    if(random >= 	1.0021652686	) S=	3.84	;
    if(random >= 	1.0021765286	) S=	3.85	;
    if(random >= 	1.0021875686	) S=	3.86	;
    if(random >= 	1.0021983886	) S=	3.87	;
    if(random >= 	1.0022089986	) S=	3.88	;
    if(random >= 	1.0022194086	) S=	3.89	;
    if(random >= 	1.0022296086	) S=	3.9	;
    if(random >= 	1.0022396086	) S=	3.91	;
    if(random >= 	1.0022494136	) S=	3.92	;
    if(random >= 	1.0022590316	) S=	3.93	;
    if(random >= 	1.0022684636	) S=	3.94	;
    if(random >= 	1.0022777106	) S=	3.95	;
    if(random >= 	1.0022867796	) S=	3.96	;
    if(random >= 	1.0022956716	) S=	3.97	;
    if(random >= 	1.0023043876	) S=	3.98	;
    if(random >= 	1.0023129356	) S=	3.99	;
    if(random >= 	1.0023213226	) S=	4.0	;
    if(random >= 	1.0023295426	) S=	4.01	;
    if(random >= 	1.0023376076	) S=	4.02	;
    if(random >= 	1.0023455156	) S=	4.03	;
    if(random >= 	1.0023532706	) S=	4.04	;
    if(random >= 	1.0023608766	) S=	4.05	;
    if(random >= 	1.0023683356	) S=	4.06	;
    if(random >= 	1.0023756506	) S=	4.07	;
    if(random >= 	1.0023828256	) S=	4.08	;
    if(random >= 	1.0023898626	) S=	4.09	;
    if(random >= 	1.0023967646	) S=	4.1	;
    if(random >= 	1.0024035326	) S=	4.11	;
    if(random >= 	1.0024101716	) S=	4.12	;
    if(random >= 	1.0024166826	) S=	4.13	;
    if(random >= 	1.0024230696	) S=	4.14	;
    if(random >= 	1.0024293336	) S=	4.15	;
    if(random >= 	1.0024354776	) S=	4.16	;
    if(random >= 	1.0024415046	) S=	4.17	;
    if(random >= 	1.0024474166	) S=	4.18	;
    if(random >= 	1.0024532146	) S=	4.19	;
    if(random >= 	1.0024589016	) S=	4.2	;
    if(random >= 	1.0024644806	) S=	4.21	;
    if(random >= 	1.0024699536	) S=	4.22	;
    if(random >= 	1.0024753226	) S=	4.23	;
    if(random >= 	1.0024805886	) S=	4.24	;
    if(random >= 	1.0024857546	) S=	4.25	;
    if(random >= 	1.0024908226	) S=	4.26	;
    if(random >= 	1.0024957936	) S=	4.27	;
    if(random >= 	1.0025006706	) S=	4.28	;
    if(random >= 	1.0025054546	) S=	4.29	;
    if(random >= 	1.0025101476	) S=	4.3	;
    if(random >= 	1.0025147516	) S=	4.31	;
    if(random >= 	1.0025192686	) S=	4.32	;
    if(random >= 	1.0025236996	) S=	4.33	;
    if(random >= 	1.0025280476	) S=	4.34	;
    if(random >= 	1.0025323126	) S=	4.35	;
    if(random >= 	1.0025364976	) S=	4.36	;
    if(random >= 	1.0025406036	) S=	4.37	;
    if(random >= 	1.0025446316	) S=	4.38	;
    if(random >= 	1.0025485836	) S=	4.39	;
    if(random >= 	1.0025524616	) S=	4.4	;
    if(random >= 	1.0025562666	) S=	4.41	;
    if(random >= 	1.0025600006	) S=	4.42	;
    if(random >= 	1.0025636636	) S=	4.43	;
    if(random >= 	1.0025672586	) S=	4.44	;
    if(random >= 	1.0025707856	) S=	4.45	;
    if(random >= 	1.0025742456	) S=	4.46	;
    if(random >= 	1.0025776406	) S=	4.47	;
    if(random >= 	1.0025809726	) S=	4.48	;
    if(random >= 	1.0025842426	) S=	4.49	;
    if(random >= 	1.0025874516	) S=	4.5	;
    if(random >= 	1.0025906006	) S=	4.51	;
    if(random >= 	1.0025936906	) S=	4.52	;
    if(random >= 	1.0025967226	) S=	4.53	;
    if(random >= 	1.0025996986	) S=	4.54	;
    if(random >= 	1.0026026186	) S=	4.55	;
    if(random >= 	1.0026054846	) S=	4.56	;
    if(random >= 	1.0026082966	) S=	4.57	;
    if(random >= 	1.0026110566	) S=	4.58	;
    if(random >= 	1.0026137646	) S=	4.59	;
    if(random >= 	1.0026164226	) S=	4.6	;
    if(random >= 	1.0026190306	) S=	4.61	;
    if(random >= 	1.0026215906	) S=	4.62	;
    if(random >= 	1.0026241036	) S=	4.63	;
    if(random >= 	1.0026265696	) S=	4.64	;
    if(random >= 	1.0026289896	) S=	4.65	;
    if(random >= 	1.0026313656	) S=	4.66	;
    if(random >= 	1.0026336976	) S=	4.67	;
    if(random >= 	1.0026359866	) S=	4.68	;
    if(random >= 	1.0026382336	) S=	4.69	;
    if(random >= 	1.0026404386	) S=	4.7	;
    if(random >= 	1.0026426026	) S=	4.71	;
    if(random >= 	1.0026447266	) S=	4.72	;
    if(random >= 	1.0026468116	) S=	4.73	;
    if(random >= 	1.0026488586	) S=	4.74	;
    if(random >= 	1.0026508676	) S=	4.75	;
    if(random >= 	1.0026528396	) S=	4.76	;
    if(random >= 	1.0026547756	) S=	4.77	;
    if(random >= 	1.0026566756	) S=	4.78	;
    if(random >= 	1.0026585416	) S=	4.79	;
    if(random >= 	1.0026603736	) S=	4.8	;
    if(random >= 	1.0026621716	) S=	4.81	;
    if(random >= 	1.0026639366	) S=	4.82	;
    if(random >= 	1.0026656696	) S=	4.83	;
    if(random >= 	1.0026673706	) S=	4.84	;
    if(random >= 	1.0026690406	) S=	4.85	;
    if(random >= 	1.0026706806	) S=	4.86	;
    if(random >= 	1.0026722896	) S=	4.87	;
    if(random >= 	1.0026738696	) S=	4.88	;
    if(random >= 	1.0026754206	) S=	4.89	;
    if(random >= 	1.0026769436	) S=	4.9	;
    if(random >= 	1.0026784386	) S=	4.91	;
    if(random >= 	1.0026799066	) S=	4.92	;
    if(random >= 	1.0026813486	) S=	4.93	;
    if(random >= 	1.0026827646	) S=	4.94	;
    if(random >= 	1.0026841546	) S=	4.95	;
    if(random >= 	1.0026855186	) S=	4.96	;
    if(random >= 	1.0026868586	) S=	4.97	;
    if(random >= 	1.0026881736	) S=	4.98	;
    if(random >= 	1.0026894646	) S=	4.99	;
    if(random >= 	1.0026907336	) S=	5	;
    if(random >= 	1.0026919796	) S=	5.01	;
    if(random >= 	1.0026932026	) S=	5.02	;
    if(random >= 	1.0026944036	) S=	5.03	;
    if(random >= 	1.0026955826	) S=	5.04	;
    if(random >= 	1.0026967406	) S=	5.05	;
    if(random >= 	1.0026978776	) S=	5.06	;
    if(random >= 	1.0026989946	) S=	5.07	;
    if(random >= 	1.0027000906	) S=	5.08	;
    if(random >= 	1.0027011676	) S=	5.09	;
    if(random >= 	1.0027022256	) S=	5.1	;
    if(random >= 	1.0027032646	) S=	5.11	;
    if(random >= 	1.0027042846	) S=	5.12	;
    if(random >= 	1.0027052866	) S=	5.13	;
    if(random >= 	1.0027062705	) S=	5.14	;
    if(random >= 	1.0027072364	) S=	5.15	;
    if(random >= 	1.0027081850	) S=	5.16	;
    if(random >= 	1.0027091170	) S=	5.17	;
    if(random >= 	1.0027100325	) S=	5.18	;
    if(random >= 	1.0027109316	) S=	5.19	;
    if(random >= 	1.0027118143	) S=	5.2	;
    if(random >= 	1.0027126813	) S=	5.21	;
    if(random >= 	1.0027135333	) S=	5.22	;
    if(random >= 	1.0027143697	) S=	5.23	;
    if(random >= 	1.0027151912	) S=	5.24	;
    if(random >= 	1.0027159986	) S=	5.25	;
    if(random >= 	1.0027167912	) S=	5.26	;
    if(random >= 	1.0027175697	) S=	5.27	;
    if(random >= 	1.0027183346	) S=	5.28	;
    if(random >= 	1.0027190859	) S=	5.29	;
    if(random >= 	1.0027198239	) S=	5.3	;
    if(random >= 	1.0027205489	) S=	5.31	;
    if(random >= 	1.0027212611	) S=	5.32	;
    if(random >= 	1.0027219607	) S=	5.33	;
    if(random >= 	1.0027226479	) S=	5.34	;
    if(random >= 	1.0027233230	) S=	5.35	;
    if(random >= 	1.0027239862	) S=	5.36	;
    if(random >= 	1.0027246377	) S=	5.37	;
    if(random >= 	1.0027252777	) S=	5.38	;
    if(random >= 	1.0027259065	) S=	5.39	;
    if(random >= 	1.0027265242	) S=	5.4	;
    if(random >= 	1.0027271310	) S=	5.41	;
    if(random >= 	1.0027277272	) S=	5.42	;
    if(random >= 	1.0027283129	) S=	5.43	;
    if(random >= 	1.0027288884	) S=	5.44	;
    if(random >= 	1.0027294538	) S=	5.45	;
    if(random >= 	1.0027300093	) S=	5.46	;
    if(random >= 	1.0027305550	) S=	5.47	;
    if(random >= 	1.0027310912	) S=	5.48	;
    if(random >= 	1.0027316180	) S=	5.49	;
    if(random >= 	1.0027321356	) S=	5.5	;
    if(random >= 	1.0027326442	) S=	5.51	;
    if(random >= 	1.0027331439	) S=	5.52	;
    if(random >= 	1.0027336349	) S=	5.53	;
    if(random >= 	1.0027341173	) S=	5.54	;
    if(random >= 	1.0027345914	) S=	5.55	;
    if(random >= 	1.0027350572	) S=	5.56	;
    if(random >= 	1.0027355149	) S=	5.57	;
    if(random >= 	1.0027359646	) S=	5.58	;
    if(random >= 	1.0027364065	) S=	5.59	;
    if(random >= 	1.0027368408	) S=	5.6	;
    if(random >= 	1.0027372675	) S=	5.61	;
    if(random >= 	1.0027376868	) S=	5.62	;
    if(random >= 	1.0027380989	) S=	5.63	;
    if(random >= 	1.0027385038	) S=	5.64	;
    if(random >= 	1.0027389018	) S=	5.65	;
    if(random >= 	1.0027392929	) S=	5.66	;
    if(random >= 	1.0027396772	) S=	5.67	;
    if(random >= 	1.0027400549	) S=	5.68	;
    if(random >= 	1.0027404261	) S=	5.69	;
    if(random >= 	1.0027407909	) S=	5.7	;
    if(random >= 	1.0027411494	) S=	5.71	;
    if(random >= 	1.0027415017	) S=	5.72	;
    if(random >= 	1.0027418480	) S=	5.73	;
    if(random >= 	1.0027421883	) S=	5.74	;
    if(random >= 	1.0027425228	) S=	5.75	;
    if(random >= 	1.0027428516	) S=	5.76	;
    if(random >= 	1.0027431747	) S=	5.77	;
    if(random >= 	1.0027434923	) S=	5.78	;
    if(random >= 	1.0027438044	) S=	5.79	;
    if(random >= 	1.0027441112	) S=	5.8	;
    if(random >= 	1.0027444127	) S=	5.81	;
    if(random >= 	1.0027447091	) S=	5.82	;
    if(random >= 	1.0027450005	) S=	5.83	;
    if(random >= 	1.0027452869	) S=	5.84	;
    if(random >= 	1.0027455683	) S=	5.85	;
    if(random >= 	1.0027458450	) S=	5.86	;
    if(random >= 	1.0027461170	) S=	5.87	;
    if(random >= 	1.0027463843	) S=	5.88	;
    if(random >= 	1.0027466471	) S=	5.89	;
    if(random >= 	1.0027469054	) S=	5.9	;
    if(random >= 	1.0027471593	) S=	5.91	;
    if(random >= 	1.0027474089	) S=	5.92	;
    if(random >= 	1.0027476543	) S=	5.93	;
    if(random >= 	1.0027478955	) S=	5.94	;
    if(random >= 	1.0027481326	) S=	5.95	;
    if(random >= 	1.0027483658	) S=	5.96	;
    if(random >= 	1.0027485950	) S=	5.97	;
    if(random >= 	1.0027488203	) S=	5.98	;
    if(random >= 	1.0027490418	) S=	5.99	;
    if(random >= 	1.0027492596	) S=	6.0	;
    if(random >= 	1.0027494737	) S=	6.01	;
    if(random >= 	1.0027496842	) S=	6.02	;
    if(random >= 	1.0027498912	) S=	6.03	;
    if(random >= 	1.0027500947	) S=	6.04	;
    if(random >= 	1.0027502947	) S=	6.05	;
    if(random >= 	1.0027504913	) S=	6.06	;
    if(random >= 	1.0027506847	) S=	6.07	;
    if(random >= 	1.0027508748	) S=	6.08	;
    if(random >= 	1.0027510617	) S=	6.09	;
    if(random >= 	1.0027512455	) S=	6.1	;
    if(random >= 	1.0027514262	) S=	6.11	;
    if(random >= 	1.0027516039	) S=	6.12	;
    if(random >= 	1.0027517786	) S=	6.13	;
    if(random >= 	1.0027519504	) S=	6.14	;
    if(random >= 	1.0027521193	) S=	6.15	;
    if(random >= 	1.0027522854	) S=	6.16	;
    if(random >= 	1.0027524487	) S=	6.17	;
    if(random >= 	1.0027526093	) S=	6.18	;
    if(random >= 	1.0027527672	) S=	6.19	;
    if(random >= 	1.0027529225	) S=	6.2	;
    if(random >= 	1.0027530752	) S=	6.21	;
    if(random >= 	1.0027532254	) S=	6.22	;
    if(random >= 	1.0027533731	) S=	6.23	;
    if(random >= 	1.0027535183	) S=	6.24	;
    if(random >= 	1.0027536611	) S=	6.25	;
    if(random >= 	1.0027538015	) S=	6.26	;
    if(random >= 	1.0027539396	) S=	6.27	;
    if(random >= 	1.0027540754	) S=	6.28	;
    if(random >= 	1.0027542090	) S=	6.29	;
    if(random >= 	1.0027543404	) S=	6.3	;
    if(random >= 	1.0027544696	) S=	6.31	;
    if(random >= 	1.0027545966	) S=	6.32	;
    if(random >= 	1.0027547216	) S=	6.33	;
    if(random >= 	1.0027548445	) S=	6.34	;
    if(random >= 	1.0027549654	) S=	6.35	;
    if(random >= 	1.0027550843	) S=	6.36	;
    if(random >= 	1.0027552012	) S=	6.37	;
    if(random >= 	1.0027553162	) S=	6.38	;
    if(random >= 	1.0027554293	) S=	6.39	;
    if(random >= 	1.0027555405	) S=	6.4	;
    if(random >= 	1.0027556499	) S=	6.41	;
    if(random >= 	1.0027557575	) S=	6.42	;
    if(random >= 	1.0027558633	) S=	6.43	;
    if(random >= 	1.0027559674	) S=	6.44	;
    if(random >= 	1.0027560698	) S=	6.45	;
    if(random >= 	1.0027561706	) S=	6.46	;
    if(random >= 	1.0027562697	) S=	6.47	;
    if(random >= 	1.0027563672	) S=	6.48	;
    if(random >= 	1.0027564631	) S=	6.49	;
    if(random >= 	1.0027565574	) S=	6.5	;
    if(random >= 	1.0027566502	) S=	6.51	;
    if(random >= 	1.0027567415	) S=	6.52	;
    if(random >= 	1.0027568313	) S=	6.53	;
    if(random >= 	1.0027569196	) S=	6.54	;
    if(random >= 	1.0027570065	) S=	6.55	;
    if(random >= 	1.0027570920	) S=	6.56	;
    if(random >= 	1.0027571761	) S=	6.57	;
    if(random >= 	1.0027572588	) S=	6.58	;
    if(random >= 	1.0027573402	) S=	6.59	;
    if(random >= 	1.0027574202	) S=	6.6	;
    if(random >= 	1.0027574990	) S=	6.61	;
    if(random >= 	1.0027575764	) S=	6.62	;
    if(random >= 	1.0027576527	) S=	6.63	;
    if(random >= 	1.0027577276	) S=	6.64	;
    if(random >= 	1.0027578014	) S=	6.65	;
    if(random >= 	1.0027578740	) S=	6.66	;
    if(random >= 	1.0027579454	) S=	6.67	;
    if(random >= 	1.0027580156	) S=	6.68	;
    if(random >= 	1.0027580847	) S=	6.69	;
    if(random >= 	1.0027581527	) S=	6.7	;
    if(random >= 	1.0027582197	) S=	6.71	;
    if(random >= 	1.0027582855	) S=	6.72	;
    if(random >= 	1.0027583503	) S=	6.73	;
    if(random >= 	1.0027584140	) S=	6.74	;
    if(random >= 	1.0027584767	) S=	6.75	;
    if(random >= 	1.0027585385	) S=	6.76	;
    if(random >= 	1.0027585992	) S=	6.77	;
    if(random >= 	1.0027586589	) S=	6.78	;
    if(random >= 	1.0027587177	) S=	6.79	;
    if(random >= 	1.0027587756	) S=	6.8	;
    if(random >= 	1.0027588325	) S=	6.81	;
    if(random >= 	1.0027588885	) S=	6.82	;
    if(random >= 	1.0027589436	) S=	6.83	;
    if(random >= 	1.0027589979	) S=	6.84	;
    if(random >= 	1.0027590512	) S=	6.85	;
    if(random >= 	1.0027591037	) S=	6.86	;
    if(random >= 	1.0027591554	) S=	6.87	;
    if(random >= 	1.0027592063	) S=	6.88	;
    if(random >= 	1.0027592563	) S=	6.89	;
    if(random >= 	1.0027593056	) S=	6.9	;
    if(random >= 	1.0027593541	) S=	6.91	;
    if(random >= 	1.0027594018	) S=	6.92	;
    if(random >= 	1.0027594487	) S=	6.93	;
    if(random >= 	1.0027594949	) S=	6.94	;
    if(random >= 	1.0027595404	) S=	6.95	;
    if(random >= 	1.0027595851	) S=	6.96	;
    if(random >= 	1.0027596292	) S=	6.97	;
    if(random >= 	1.0027596725	) S=	6.98	;
    if(random >= 	1.0027597152	) S=	6.99	;
    if(random >= 	1.0027597571	) S=	7.0	;
    if(random >= 	1.0027597985	) S=	7.01	;
    if(random >= 	1.0027598391	) S=	7.02	;
    if(random >= 	1.0027598792	) S=	7.03	;
    if(random >= 	1.0027599186	) S=	7.04	;
    if(random >= 	1.0027599573	) S=	7.05	;
    if(random >= 	1.0027599955	) S=	7.06	;
    if(random >= 	1.0027600331	) S=	7.07	;
    if(random >= 	1.0027600700	) S=	7.08	;
    if(random >= 	1.0027601064	) S=	7.09	;
    if(random >= 	1.0027601423	) S=	7.1	;
    if(random >= 	1.0027601775	) S=	7.11	;
    if(random >= 	1.0027602122	) S=	7.12	;
    if(random >= 	1.0027602464	) S=	7.13	;
    if(random >= 	1.0027602800	) S=	7.14	;
    if(random >= 	1.0027603131	) S=	7.15	;
    if(random >= 	1.0027603457	) S=	7.16	;
    if(random >= 	1.0027603778	) S=	7.17	;
    if(random >= 	1.0027604093	) S=	7.18	;
    if(random >= 	1.0027604404	) S=	7.19	;
    if(random >= 	1.0027604710	) S=	7.2	;
    if(random >= 	1.0027605011	) S=	7.21	;
    if(random >= 	1.0027605308	) S=	7.22	;
    if(random >= 	1.0027605599	) S=	7.23	;
    if(random >= 	1.0027605887	) S=	7.24	;
    if(random >= 	1.0027606170	) S=	7.25	;
    if(random >= 	1.0027606448	) S=	7.26	;
    if(random >= 	1.0027606722	) S=	7.27	;
    if(random >= 	1.0027606992	) S=	7.28	;
    if(random >= 	1.0027607258	) S=	7.29	;
    if(random >= 	1.0027607519	) S=	7.3	;
    if(random >= 	1.0027607777	) S=	7.31	;
    if(random >= 	1.0027608030	) S=	7.32	;
    if(random >= 	1.0027608280	) S=	7.33	;
    if(random >= 	1.0027608526	) S=	7.34	;
    if(random >= 	1.0027608768	) S=	7.35	;
    if(random >= 	1.0027609006	) S=	7.36	;
    if(random >= 	1.0027609240	) S=	7.37	;
    if(random >= 	1.0027609471	) S=	7.38	;
    if(random >= 	1.0027609698	) S=	7.39	;
    if(random >= 	1.0027609922	) S=	7.4	;
    if(random >= 	1.0027610143	) S=	7.41	;
    if(random >= 	1.0027610360	) S=	7.42	;
    if(random >= 	1.0027610573	) S=	7.43	;
    if(random >= 	1.0027610784	) S=	7.44	;
    if(random >= 	1.0027610991	) S=	7.45	;
    if(random >= 	1.0027611195	) S=	7.46	;
    if(random >= 	1.0027611396	) S=	7.47	;
    if(random >= 	1.0027611594	) S=	7.48	;
    if(random >= 	1.0027611788	) S=	7.49	;
    if(random >= 	1.0027611980	) S=	7.5	;
    if(random >= 	1.0027612169	) S=	7.51	;
    if(random >= 	1.0027612355	) S=	7.52	;
    if(random >= 	1.0027612538	) S=	7.53	;
    if(random >= 	1.0027612718	) S=	7.54	;
    if(random >= 	1.0027612896	) S=	7.55	;
    if(random >= 	1.0027613070	) S=	7.56	;
    if(random >= 	1.0027613243	) S=	7.57	;
    if(random >= 	1.0027613412	) S=	7.58	;
    if(random >= 	1.0027613579	) S=	7.59	;
    if(random >= 	1.0027613744	) S=	7.6	;
    if(random >= 	1.0027613905	) S=	7.61	;
    if(random >= 	1.0027614065	) S=	7.62	;
    if(random >= 	1.0027614222	) S=	7.63	;
    if(random >= 	1.0027614377	) S=	7.64	;
    if(random >= 	1.0027614529	) S=	7.65	;
    if(random >= 	1.0027614679	) S=	7.66	;
    if(random >= 	1.0027614827	) S=	7.67	;
    if(random >= 	1.0027614972	) S=	7.68	;
    if(random >= 	1.0027615116	) S=	7.69	;
    if(random >= 	1.0027615257	) S=	7.7	;
    if(random >= 	1.0027615396	) S=	7.71	;
    if(random >= 	1.0027615533	) S=	7.72	;
    if(random >= 	1.0027615667	) S=	7.73	;
    if(random >= 	1.0027615800	) S=	7.74	;
    if(random >= 	1.0027615931	) S=	7.75	;
    if(random >= 	1.0027616060	) S=	7.76	;
    if(random >= 	1.0027616187	) S=	7.77	;
    if(random >= 	1.0027616312	) S=	7.78	;
    if(random >= 	1.0027616435	) S=	7.79	;
    if(random >= 	1.0027616556	) S=	7.8	;
    if(random >= 	1.0027616675	) S=	7.81	;
    if(random >= 	1.0027616793	) S=	7.82	;
    if(random >= 	1.0027616909	) S=	7.83	;
    if(random >= 	1.0027617023	) S=	7.84	;
    if(random >= 	1.0027617135	) S=	7.85	;
    if(random >= 	1.0027617246	) S=	7.86	;
    if(random >= 	1.0027617355	) S=	7.87	;
    if(random >= 	1.0027617463	) S=	7.88	;
    if(random >= 	1.0027617568	) S=	7.89	;
    if(random >= 	1.0027617673	) S=	7.9	;
    if(random >= 	1.0027617775	) S=	7.91	;
    if(random >= 	1.0027617877	) S=	7.92	;
    if(random >= 	1.0027617976	) S=	7.93	;
    if(random >= 	1.0027618075	) S=	7.94	;
    if(random >= 	1.0027618171	) S=	7.95	;
    if(random >= 	1.0027618267	) S=	7.96	;
    if(random >= 	1.0027618360	) S=	7.97	;
    if(random >= 	1.0027618453	) S=	7.98	;
    if(random >= 	1.0027618544	) S=	7.99	;
    if(random >= 	1.0027618634	) S=	8.0	;
    if(random >= 	1.0027618722	) S=	8.01	;
    if(random >= 	1.0027618809	) S=	8.02	;
    if(random >= 	1.0027618895	) S=	8.03	;
    if(random >= 	1.0027618979	) S=	8.04	;
    if(random >= 	1.0027619063	) S=	8.05	;
    if(random >= 	1.0027619145	) S=	8.06	;
    if(random >= 	1.0027619226	) S=	8.07	;
    if(random >= 	1.0027619305	) S=	8.08	;
    if(random >= 	1.0027619384	) S=	8.09	;
    if(random >= 	1.0027619461	) S=	8.1	;
    if(random >= 	1.0027619537	) S=	8.11	;
    if(random >= 	1.0027619612	) S=	8.12	;
    if(random >= 	1.0027619686	) S=	8.13	;
    if(random >= 	1.0027619759	) S=	8.14	;
    if(random >= 	1.0027619831	) S=	8.15	;
    if(random >= 	1.0027619901	) S=	8.16	;
    if(random >= 	1.0027619971	) S=	8.17	;
    if(random >= 	1.0027620040	) S=	8.18	;
    if(random >= 	1.0027620107	) S=	8.19	;
    if(random >= 	1.0027620174	) S=	8.2	;
    if(random >= 	1.0027620240	) S=	8.21	;
    if(random >= 	1.0027620305	) S=	8.22	;
    if(random >= 	1.0027620368	) S=	8.23	;
    if(random >= 	1.0027620431	) S=	8.24	;
    if(random >= 	1.0027620493	) S=	8.25	;
    if(random >= 	1.0027620554	) S=	8.26	;
    if(random >= 	1.0027620614	) S=	8.27	;
    if(random >= 	1.0027620673	) S=	8.28	;
    if(random >= 	1.0027620732	) S=	8.29	;
    if(random >= 	1.0027620789	) S=	8.3	;
    if(random >= 	1.0027620846	) S=	8.31	;
    if(random >= 	1.0027620902	) S=	8.32	;
    if(random >= 	1.0027620957	) S=	8.33	;
    if(random >= 	1.0027621011	) S=	8.34	;
    if(random >= 	1.0027621065	) S=	8.35	;
    if(random >= 	1.0027621117	) S=	8.36	;
    if(random >= 	1.0027621169	) S=	8.37	;
    if(random >= 	1.0027621220	) S=	8.38	;
    if(random >= 	1.0027621271	) S=	8.39	;
    if(random >= 	1.0027621321	) S=	8.4	;
    if(random >= 	1.0027621369	) S=	8.41	;
    if(random >= 	1.0027621418	) S=	8.42	;
    if(random >= 	1.0027621465	) S=	8.43	;
    if(random >= 	1.0027621512	) S=	8.44	;
    if(random >= 	1.0027621558	) S=	8.45	;
    if(random >= 	1.0027621604	) S=	8.46	;
    if(random >= 	1.0027621649	) S=	8.47	;
    if(random >= 	1.0027621693	) S=	8.48	;
    if(random >= 	1.0027621737	) S=	8.49	;
    if(random >= 	1.0027621780	) S=	8.5	;
    if(random >= 	1.0027621822	) S=	8.51	;
    if(random >= 	1.0027621864	) S=	8.52	;
    if(random >= 	1.0027621905	) S=	8.53	;
    if(random >= 	1.0027621945	) S=	8.54	;
    if(random >= 	1.0027621985	) S=	8.55	;
    if(random >= 	1.0027622025	) S=	8.56	;
    if(random >= 	1.0027622063	) S=	8.57	;
    if(random >= 	1.0027622102	) S=	8.58	;
    if(random >= 	1.0027622139	) S=	8.59	;
    if(random >= 	1.0027622177	) S=	8.6	;
    if(random >= 	1.0027622213	) S=	8.61	;
    if(random >= 	1.0027622249	) S=	8.62	;
    if(random >= 	1.0027622285	) S=	8.63	;
    if(random >= 	1.0027622320	) S=	8.64	;
    if(random >= 	1.0027622355	) S=	8.65	;
    if(random >= 	1.0027622389	) S=	8.66	;
    if(random >= 	1.0027622422	) S=	8.67	;
    if(random >= 	1.0027622455	) S=	8.68	;
    if(random >= 	1.0027622488	) S=	8.69	;
    if(random >= 	1.0027622520	) S=	8.7	;
    if(random >= 	1.0027622552	) S=	8.71	;
    if(random >= 	1.0027622583	) S=	8.72	;
    if(random >= 	1.0027622614	) S=	8.73	;
    if(random >= 	1.0027622645	) S=	8.74	;
    if(random >= 	1.0027622675	) S=	8.75	;
    if(random >= 	1.0027622704	) S=	8.76	;
    if(random >= 	1.0027622733	) S=	8.77	;
    if(random >= 	1.0027622762	) S=	8.78	;
    if(random >= 	1.0027622790	) S=	8.79	;
    if(random >= 	1.0027622818	) S=	8.8	;
    if(random >= 	1.0027622846	) S=	8.81	;
    if(random >= 	1.0027622873	) S=	8.82	;
    if(random >= 	1.0027622899	) S=	8.83	;
    if(random >= 	1.0027622926	) S=	8.84	;
    if(random >= 	1.0027622952	) S=	8.85	;
    if(random >= 	1.0027622977	) S=	8.86	;
    if(random >= 	1.0027623003	) S=	8.87	;
    if(random >= 	1.0027623028	) S=	8.88	;
    if(random >= 	1.0027623052	) S=	8.89	;
    if(random >= 	1.0027623076	) S=	8.9	;
    if(random >= 	1.0027623100	) S=	8.91	;
    if(random >= 	1.0027623124	) S=	8.92	;
    if(random >= 	1.0027623147	) S=	8.93	;
    if(random >= 	1.0027623170	) S=	8.94	;
    if(random >= 	1.0027623192	) S=	8.95	;
    if(random >= 	1.0027623215	) S=	8.96	;
    if(random >= 	1.0027623237	) S=	8.97	;
    if(random >= 	1.0027623259	) S=	8.98	;
    if(random >= 	1.0027623280	) S=	8.99	;
    if(random >= 	1.0027623302	) S=	9.0	;
    if(random >= 	1.0027623323	) S=	9.01	;
    
    //cout << random << '\t' << S << endl;
    
    lambda_palaeosens = 1.0/S;
    
    return lambda_palaeosens;
    
}

//This sets lambda from the linear-error palaeosens distribution (Rohling et al, Nature)
double get_lambda_palaeosens2(double random)
{
    double lambda_palaeosens = 0.0;
    double S=0;
    
    
    if(random >= 	0.00000000000000E+00	) S=	-2.2	;
    if(random >= 	1.14800000000000E-15	) S=	-2.19	;
    if(random >= 	2.51600000000000E-15	) S=	-2.18	;
    if(random >= 	4.14500000000000E-15	) S=	-2.17	;
    if(random >= 	6.08300000000000E-15	) S=	-2.16	;
    if(random >= 	8.38800000000000E-15	) S=	-2.15	;
    if(random >= 	1.11280000000000E-14	) S=	-2.14	;
    if(random >= 	1.43820000000000E-14	) S=	-2.13	;
    if(random >= 	1.82450000000000E-14	) S=	-2.12	;
    if(random >= 	2.28290000000000E-14	) S=	-2.11	;
    if(random >= 	2.82650000000000E-14	) S=	-2.1	;
    if(random >= 	3.47080000000000E-14	) S=	-2.09	;
    if(random >= 	4.23380000000000E-14	) S=	-2.08	;
    if(random >= 	5.13710000000000E-14	) S=	-2.07	;
    if(random >= 	6.20610000000000E-14	) S=	-2.06	;
    if(random >= 	7.47010000000000E-14	) S=	-2.05	;
    if(random >= 	8.96410000000000E-14	) S=	-2.04	;
    if(random >= 	1.07291000000000E-13	) S=	-2.03	;
    if(random >= 	1.28121000000000E-13	) S=	-2.02	;
    if(random >= 	1.52701000000000E-13	) S=	-2.01	;
    if(random >= 	1.81691000000000E-13	) S=	-2	;
    if(random >= 	2.15851000000000E-13	) S=	-1.99	;
    if(random >= 	2.56091000000000E-13	) S=	-1.98	;
    if(random >= 	3.03461000000000E-13	) S=	-1.97	;
    if(random >= 	3.59191000000000E-13	) S=	-1.96	;
    if(random >= 	4.24731000000000E-13	) S=	-1.95	;
    if(random >= 	5.01721000000000E-13	) S=	-1.94	;
    if(random >= 	5.92191000000000E-13	) S=	-1.93	;
    if(random >= 	6.98391000000000E-13	) S=	-1.92	;
    if(random >= 	8.22991000000000E-13	) S=	-1.91	;
    if(random >= 	9.69091000000000E-13	) S=	-1.9	;
    if(random >= 	1.14029100000000E-12	) S=	-1.89	;
    if(random >= 	1.34089100000000E-12	) S=	-1.88	;
    if(random >= 	1.57569100000000E-12	) S=	-1.87	;
    if(random >= 	1.85039100000000E-12	) S=	-1.86	;
    if(random >= 	2.17159100000000E-12	) S=	-1.85	;
    if(random >= 	2.54699100000000E-12	) S=	-1.84	;
    if(random >= 	2.98549100000000E-12	) S=	-1.83	;
    if(random >= 	3.49739100000000E-12	) S=	-1.82	;
    if(random >= 	4.09459100000000E-12	) S=	-1.81	;
    if(random >= 	4.79109100000000E-12	) S=	-1.8	;
    if(random >= 	5.60269100000000E-12	) S=	-1.79	;
    if(random >= 	6.54779100000000E-12	) S=	-1.78	;
    if(random >= 	7.64779100000000E-12	) S=	-1.77	;
    if(random >= 	8.92879100000000E-12	) S=	-1.76	;
    if(random >= 	1.04177910000000E-11	) S=	-1.75	;
    if(random >= 	1.21487910000000E-11	) S=	-1.74	;
    if(random >= 	1.41587910000000E-11	) S=	-1.73	;
    if(random >= 	1.64927910000000E-11	) S=	-1.72	;
    if(random >= 	1.92007910000000E-11	) S=	-1.71	;
    if(random >= 	2.23407910000000E-11	) S=	-1.7	;
    if(random >= 	2.59807910000000E-11	) S=	-1.69	;
    if(random >= 	3.01967910000000E-11	) S=	-1.68	;
    if(random >= 	3.50777910000000E-11	) S=	-1.67	;
    if(random >= 	4.07257910000000E-11	) S=	-1.66	;
    if(random >= 	4.72567910000000E-11	) S=	-1.65	;
    if(random >= 	5.48037910000000E-11	) S=	-1.64	;
    if(random >= 	6.35247910000000E-11	) S=	-1.63	;
    if(random >= 	7.35947910000000E-11	) S=	-1.62	;
    if(random >= 	8.52147910000000E-11	) S=	-1.61	;
    if(random >= 	9.86147910000000E-11	) S=	-1.6	;
    if(random >= 	1.14054791000000E-10	) S=	-1.59	;
    if(random >= 	1.31844791000000E-10	) S=	-1.58	;
    if(random >= 	1.52324791000000E-10	) S=	-1.57	;
    if(random >= 	1.75894791000000E-10	) S=	-1.56	;
    if(random >= 	2.03014791000000E-10	) S=	-1.55	;
    if(random >= 	2.34184791000000E-10	) S=	-1.54	;
    if(random >= 	2.69994791000000E-10	) S=	-1.53	;
    if(random >= 	3.11114791000000E-10	) S=	-1.52	;
    if(random >= 	3.58304791000000E-10	) S=	-1.51	;
    if(random >= 	4.12434791000000E-10	) S=	-1.5	;
    if(random >= 	4.74494791000000E-10	) S=	-1.49	;
    if(random >= 	5.45624791000000E-10	) S=	-1.48	;
    if(random >= 	6.27054791000000E-10	) S=	-1.47	;
    if(random >= 	7.20274791000000E-10	) S=	-1.46	;
    if(random >= 	8.26874791000000E-10	) S=	-1.45	;
    if(random >= 	9.48774791000000E-10	) S=	-1.44	;
    if(random >= 	1.08807479100000E-09	) S=	-1.43	;
    if(random >= 	1.24717479100000E-09	) S=	-1.42	;
    if(random >= 	1.42877479100000E-09	) S=	-1.41	;
    if(random >= 	1.63597479100000E-09	) S=	-1.4	;
    if(random >= 	1.87227479100000E-09	) S=	-1.39	;
    if(random >= 	2.14157479100000E-09	) S=	-1.38	;
    if(random >= 	2.44827479100000E-09	) S=	-1.37	;
    if(random >= 	2.79747479100000E-09	) S=	-1.36	;
    if(random >= 	3.19487479100000E-09	) S=	-1.35	;
    if(random >= 	3.64687479100000E-09	) S=	-1.34	;
    if(random >= 	4.16067479100000E-09	) S=	-1.33	;
    if(random >= 	4.74437479100000E-09	) S=	-1.32	;
    if(random >= 	5.40717479100000E-09	) S=	-1.31	;
    if(random >= 	6.15977479100000E-09	) S=	-1.3	;
    if(random >= 	7.01277479100000E-09	) S=	-1.29	;
    if(random >= 	7.98027479100000E-09	) S=	-1.28	;
    if(random >= 	9.07627479100000E-09	) S=	-1.27	;
    if(random >= 	1.03182747910000E-08	) S=	-1.26	;
    if(random >= 	1.17232747910000E-08	) S=	-1.25	;
    if(random >= 	1.33132747910000E-08	) S=	-1.24	;
    if(random >= 	1.51112747910000E-08	) S=	-1.23	;
    if(random >= 	1.71442747910000E-08	) S=	-1.22	;
    if(random >= 	1.94402747910000E-08	) S=	-1.21	;
    if(random >= 	2.20332747910000E-08	) S=	-1.2	;
    if(random >= 	2.49592747910000E-08	) S=	-1.19	;
    if(random >= 	2.82592747910000E-08	) S=	-1.18	;
    if(random >= 	3.19802747910000E-08	) S=	-1.17	;
    if(random >= 	3.61732747910000E-08	) S=	-1.16	;
    if(random >= 	4.08942747910000E-08	) S=	-1.15	;
    if(random >= 	4.62092747910000E-08	) S=	-1.14	;
    if(random >= 	5.21892747910000E-08	) S=	-1.13	;
    if(random >= 	5.89132747910000E-08	) S=	-1.12	;
    if(random >= 	6.64692747910000E-08	) S=	-1.11	;
    if(random >= 	7.49582747910000E-08	) S=	-1.1	;
    if(random >= 	8.44932747910000E-08	) S=	-1.09	;
    if(random >= 	9.51932747910000E-08	) S=	-1.08	;
    if(random >= 	1.07203274791000E-07	) S=	-1.07	;
    if(random >= 	1.20663274791000E-07	) S=	-1.06	;
    if(random >= 	1.35743274791000E-07	) S=	-1.05	;
    if(random >= 	1.52633274791000E-07	) S=	-1.04	;
    if(random >= 	1.71543274791000E-07	) S=	-1.03	;
    if(random >= 	1.92713274791000E-07	) S=	-1.02	;
    if(random >= 	2.16383274791000E-07	) S=	-1.01	;
    if(random >= 	2.42843274791000E-07	) S=	-1	;
    if(random >= 	2.72413274791000E-07	) S=	-0.99	;
    if(random >= 	3.05433274791000E-07	) S=	-0.98	;
    if(random >= 	3.42293274791000E-07	) S=	-0.97	;
    if(random >= 	3.83423274791000E-07	) S=	-0.96	;
    if(random >= 	4.29293274791000E-07	) S=	-0.95	;
    if(random >= 	4.80423274791000E-07	) S=	-0.94	;
    if(random >= 	5.37403274791000E-07	) S=	-0.93	;
    if(random >= 	6.00853274791000E-07	) S=	-0.92	;
    if(random >= 	6.71473274791000E-07	) S=	-0.91	;
    if(random >= 	7.50043274791000E-07	) S=	-0.9	;
    if(random >= 	8.37423274791000E-07	) S=	-0.89	;
    if(random >= 	9.34543274791000E-07	) S=	-0.88	;
    if(random >= 	1.04244327479100E-06	) S=	-0.87	;
    if(random >= 	1.16234327479100E-06	) S=	-0.86	;
    if(random >= 	1.29534327479100E-06	) S=	-0.85	;
    if(random >= 	1.44294327479100E-06	) S=	-0.84	;
    if(random >= 	1.60664327479100E-06	) S=	-0.83	;
    if(random >= 	1.78804327479100E-06	) S=	-0.82	;
    if(random >= 	1.98904327479100E-06	) S=	-0.81	;
    if(random >= 	2.21164327479100E-06	) S=	-0.8	;
    if(random >= 	2.45794327479100E-06	) S=	-0.79	;
    if(random >= 	2.73054327479100E-06	) S=	-0.78	;
    if(random >= 	3.03194327479100E-06	) S=	-0.77	;
    if(random >= 	3.36514327479100E-06	) S=	-0.76	;
    if(random >= 	3.73334327479100E-06	) S=	-0.75	;
    if(random >= 	4.13994327479100E-06	) S=	-0.74	;
    if(random >= 	4.58874327479100E-06	) S=	-0.73	;
    if(random >= 	5.08394327479100E-06	) S=	-0.72	;
    if(random >= 	5.63014327479100E-06	) S=	-0.71	;
    if(random >= 	6.23224327479100E-06	) S=	-0.7	;
    if(random >= 	6.89574327479100E-06	) S=	-0.69	;
    if(random >= 	7.62664327479100E-06	) S=	-0.68	;
    if(random >= 	8.43124327479100E-06	) S=	-0.67	;
    if(random >= 	9.31684327479100E-06	) S=	-0.66	;
    if(random >= 	1.02909432747910E-05	) S=	-0.65	;
    if(random >= 	1.13619432747910E-05	) S=	-0.64	;
    if(random >= 	1.25389432747910E-05	) S=	-0.63	;
    if(random >= 	1.38319432747910E-05	) S=	-0.62	;
    if(random >= 	1.52519432747910E-05	) S=	-0.61	;
    if(random >= 	1.68109432747910E-05	) S=	-0.6	;
    if(random >= 	1.85219432747910E-05	) S=	-0.59	;
    if(random >= 	2.03979432747910E-05	) S=	-0.58	;
    if(random >= 	2.24549432747910E-05	) S=	-0.57	;
    if(random >= 	2.47089432747910E-05	) S=	-0.56	;
    if(random >= 	2.71779432747910E-05	) S=	-0.55	;
    if(random >= 	2.98829432747910E-05	) S=	-0.54	;
    if(random >= 	3.28429432747910E-05	) S=	-0.53	;
    if(random >= 	3.60819432747910E-05	) S=	-0.52	;
    if(random >= 	3.96249432747910E-05	) S=	-0.51	;
    if(random >= 	4.34989432747910E-05	) S=	-0.5	;
    if(random >= 	4.77329432747910E-05	) S=	-0.49	;
    if(random >= 	5.23599432747910E-05	) S=	-0.48	;
    if(random >= 	5.74129432747910E-05	) S=	-0.47	;
    if(random >= 	6.29299432747910E-05	) S=	-0.46	;
    if(random >= 	6.89519432747910E-05	) S=	-0.45	;
    if(random >= 	7.55229432747910E-05	) S=	-0.44	;
    if(random >= 	8.26909432747910E-05	) S=	-0.43	;
    if(random >= 	9.05069432747910E-05	) S=	-0.42	;
    if(random >= 	9.90269432747910E-05	) S=	-0.41	;
    if(random >= 	1.08310943274791E-04	) S=	-0.4	;
    if(random >= 	1.18430943274791E-04	) S=	-0.39	;
    if(random >= 	1.29450943274791E-04	) S=	-0.38	;
    if(random >= 	1.41450943274791E-04	) S=	-0.37	;
    if(random >= 	1.54510943274791E-04	) S=	-0.36	;
    if(random >= 	1.68720943274791E-04	) S=	-0.35	;
    if(random >= 	1.84180943274791E-04	) S=	-0.34	;
    if(random >= 	2.01000943274791E-04	) S=	-0.33	;
    if(random >= 	2.19290943274791E-04	) S=	-0.32	;
    if(random >= 	2.39180943274791E-04	) S=	-0.31	;
    if(random >= 	2.60790943274791E-04	) S=	-0.3	;
    if(random >= 	2.84280943274791E-04	) S=	-0.29	;
    if(random >= 	3.09800943274791E-04	) S=	-0.28	;
    if(random >= 	3.37530943274791E-04	) S=	-0.27	;
    if(random >= 	3.67650943274791E-04	) S=	-0.26	;
    if(random >= 	4.00350943274791E-04	) S=	-0.25	;
    if(random >= 	4.35860943274791E-04	) S=	-0.24	;
    if(random >= 	4.74400943274791E-04	) S=	-0.23	;
    if(random >= 	5.16240943274791E-04	) S=	-0.22	;
    if(random >= 	5.61650943274791E-04	) S=	-0.21	;
    if(random >= 	6.10920943274791E-04	) S=	-0.2	;
    if(random >= 	6.64360943274791E-04	) S=	-0.19	;
    if(random >= 	7.22340943274791E-04	) S=	-0.18	;
    if(random >= 	7.85220943274791E-04	) S=	-0.17	;
    if(random >= 	8.53410943274791E-04	) S=	-0.16	;
    if(random >= 	9.27340943274791E-04	) S=	-0.15	;
    if(random >= 	1.00748094327479E-03	) S=	-0.14	;
    if(random >= 	1.09435094327479E-03	) S=	-0.13	;
    if(random >= 	1.18849094327479E-03	) S=	-0.12	;
    if(random >= 	1.29049094327479E-03	) S=	-0.11	;
    if(random >= 	1.40099094327479E-03	) S=	-0.1	;
    if(random >= 	1.52069094327479E-03	) S=	-0.09	;
    if(random >= 	1.65029094327479E-03	) S=	-0.08	;
    if(random >= 	1.79059094327479E-03	) S=	-0.07	;
    if(random >= 	1.94249094327479E-03	) S=	-0.06	;
    if(random >= 	2.10689094327479E-03	) S=	-0.05	;
    if(random >= 	2.28479094327479E-03	) S=	-0.04	;
    if(random >= 	2.47719094327479E-03	) S=	-0.03	;
    if(random >= 	2.68529094327479E-03	) S=	-0.02	;
    if(random >= 	2.91019094327479E-03	) S=	-0.01	;
    if(random >= 	3.15329094327479E-03	) S=	0	;
    if(random >= 	3.41599094327479E-03	) S=	0.01	;
    if(random >= 	3.69969094327479E-03	) S=	0.02	;
    if(random >= 	4.00599094327479E-03	) S=	0.03	;
    if(random >= 	4.33659094327479E-03	) S=	0.04	;
    if(random >= 	4.69319094327479E-03	) S=	0.05	;
    if(random >= 	5.07779094327479E-03	) S=	0.06	;
    if(random >= 	5.49239094327479E-03	) S=	0.07	;
    if(random >= 	5.93909094327479E-03	) S=	0.08	;
    if(random >= 	6.42009094327479E-03	) S=	0.09	;
    if(random >= 	6.93779094327479E-03	) S=	0.1	;
    if(random >= 	7.49479094327479E-03	) S=	0.11	;
    if(random >= 	8.09379094327479E-03	) S=	0.12	;
    if(random >= 	8.73739094327479E-03	) S=	0.13	;
    if(random >= 	9.42869094327479E-03	) S=	0.14	;
    if(random >= 	1.01706909432748E-02	) S=	0.15	;
    if(random >= 	1.09666909432748E-02	) S=	0.16	;
    if(random >= 	1.18199909432748E-02	) S=	0.17	;
    if(random >= 	1.27342909432748E-02	) S=	0.18	;
    if(random >= 	1.37131909432748E-02	) S=	0.19	;
    if(random >= 	1.47601909432748E-02	) S=	0.2	;
    if(random >= 	1.58801909432748E-02	) S=	0.21	;
    if(random >= 	1.70771909432748E-02	) S=	0.22	;
    if(random >= 	1.83551909432748E-02	) S=	0.23	;
    if(random >= 	1.97191909432748E-02	) S=	0.24	;
    if(random >= 	2.11731909432748E-02	) S=	0.25	;
    if(random >= 	2.27221909432748E-02	) S=	0.26	;
    if(random >= 	2.43721909432748E-02	) S=	0.27	;
    if(random >= 	2.61281909432748E-02	) S=	0.28	;
    if(random >= 	2.79951909432748E-02	) S=	0.29	;
    if(random >= 	2.99801909432748E-02	) S=	0.3	;
    if(random >= 	3.20881909432748E-02	) S=	0.31	;
    if(random >= 	3.43251909432748E-02	) S=	0.32	;
    if(random >= 	3.66981909432748E-02	) S=	0.33	;
    if(random >= 	3.92141909432748E-02	) S=	0.34	;
    if(random >= 	4.18801909432748E-02	) S=	0.35	;
    if(random >= 	4.47031909432748E-02	) S=	0.36	;
    if(random >= 	4.76901909432748E-02	) S=	0.37	;
    if(random >= 	5.08491909432748E-02	) S=	0.38	;
    if(random >= 	5.41881909432748E-02	) S=	0.39	;
    if(random >= 	5.77151909432748E-02	) S=	0.4	;
    if(random >= 	6.14381909432748E-02	) S=	0.41	;
    if(random >= 	6.53661909432748E-02	) S=	0.42	;
    if(random >= 	6.95071909432748E-02	) S=	0.43	;
    if(random >= 	7.38691909432748E-02	) S=	0.44	;
    if(random >= 	7.84611909432748E-02	) S=	0.45	;
    if(random >= 	8.32921909432748E-02	) S=	0.46	;
    if(random >= 	8.83701909432748E-02	) S=	0.47	;
    if(random >= 	9.37031909432748E-02	) S=	0.48	;
    if(random >= 	9.92981909432748E-02	) S=	0.49	;
    if(random >= 	1.05164190943275E-01	) S=	0.5	;
    if(random >= 	1.11307190943275E-01	) S=	0.51	;
    if(random >= 	1.17734190943275E-01	) S=	0.52	;
    if(random >= 	1.24451190943275E-01	) S=	0.53	;
    if(random >= 	1.31463190943275E-01	) S=	0.54	;
    if(random >= 	1.38776190943275E-01	) S=	0.55	;
    if(random >= 	1.46393190943275E-01	) S=	0.56	;
    if(random >= 	1.54317190943275E-01	) S=	0.57	;
    if(random >= 	1.62552190943275E-01	) S=	0.58	;
    if(random >= 	1.71100190943275E-01	) S=	0.59	;
    if(random >= 	1.79961190943275E-01	) S=	0.6	;
    if(random >= 	1.89137190943275E-01	) S=	0.61	;
    if(random >= 	1.98627190943275E-01	) S=	0.62	;
    if(random >= 	2.08433190943275E-01	) S=	0.63	;
    if(random >= 	2.18433190943275E-01	) S=	0.64	;
    if(random >= 	2.28433190943275E-01	) S=	0.65	;
    if(random >= 	2.39433190943275E-01	) S=	0.66	;
    if(random >= 	2.50433190943275E-01	) S=	0.67	;
    if(random >= 	2.61433190943275E-01	) S=	0.68	;
    if(random >= 	2.73433190943275E-01	) S=	0.69	;
    if(random >= 	2.85433190943275E-01	) S=	0.7	;
    if(random >= 	2.97433190943275E-01	) S=	0.71	;
    if(random >= 	3.09433190943275E-01	) S=	0.72	;
    if(random >= 	3.21433190943275E-01	) S=	0.73	;
    if(random >= 	3.34433190943275E-01	) S=	0.74	;
    if(random >= 	3.47433190943275E-01	) S=	0.75	;
    if(random >= 	3.60433190943275E-01	) S=	0.76	;
    if(random >= 	3.73433190943275E-01	) S=	0.77	;
    if(random >= 	3.86433190943275E-01	) S=	0.78	;
    if(random >= 	3.99433190943275E-01	) S=	0.79	;
    if(random >= 	4.12433190943275E-01	) S=	0.8	;
    if(random >= 	4.25433190943275E-01	) S=	0.81	;
    if(random >= 	4.38433190943275E-01	) S=	0.82	;
    if(random >= 	4.51433190943275E-01	) S=	0.83	;
    if(random >= 	4.64433190943275E-01	) S=	0.84	;
    if(random >= 	4.77433190943275E-01	) S=	0.85	;
    if(random >= 	4.90433190943275E-01	) S=	0.86	;
    if(random >= 	5.03433190943275E-01	) S=	0.87	;
    if(random >= 	5.16433190943275E-01	) S=	0.88	;
    if(random >= 	5.29433190943275E-01	) S=	0.89	;
    if(random >= 	5.42433190943275E-01	) S=	0.9	;
    if(random >= 	5.54433190943275E-01	) S=	0.91	;
    if(random >= 	5.66433190943275E-01	) S=	0.92	;
    if(random >= 	5.78433190943275E-01	) S=	0.93	;
    if(random >= 	5.90433190943275E-01	) S=	0.94	;
    if(random >= 	6.02433190943275E-01	) S=	0.95	;
    if(random >= 	6.14433190943275E-01	) S=	0.96	;
    if(random >= 	6.26433190943275E-01	) S=	0.97	;
    if(random >= 	6.37433190943275E-01	) S=	0.98	;
    if(random >= 	6.48433190943275E-01	) S=	0.99	;
    if(random >= 	6.59433190943275E-01	) S=	1	;
    if(random >= 	6.70433190943275E-01	) S=	1.01	;
    if(random >= 	6.80433190943275E-01	) S=	1.02	;
    if(random >= 	6.90290190943275E-01	) S=	1.03	;
    if(random >= 	6.99917190943275E-01	) S=	1.04	;
    if(random >= 	7.09314190943275E-01	) S=	1.05	;
    if(random >= 	7.18482190943275E-01	) S=	1.06	;
    if(random >= 	7.27422190943275E-01	) S=	1.07	;
    if(random >= 	7.36136190943275E-01	) S=	1.08	;
    if(random >= 	7.44626190943275E-01	) S=	1.09	;
    if(random >= 	7.52894190943275E-01	) S=	1.1	;
    if(random >= 	7.60943190943275E-01	) S=	1.11	;
    if(random >= 	7.68775190943275E-01	) S=	1.12	;
    if(random >= 	7.76394190943275E-01	) S=	1.13	;
    if(random >= 	7.83804190943275E-01	) S=	1.14	;
    if(random >= 	7.91007190943275E-01	) S=	1.15	;
    if(random >= 	7.98008190943275E-01	) S=	1.16	;
    if(random >= 	8.04811190943275E-01	) S=	1.17	;
    if(random >= 	8.11420190943275E-01	) S=	1.18	;
    if(random >= 	8.17838190943275E-01	) S=	1.19	;
    if(random >= 	8.24070190943275E-01	) S=	1.2	;
    if(random >= 	8.30119190943275E-01	) S=	1.21	;
    if(random >= 	8.35990190943275E-01	) S=	1.22	;
    if(random >= 	8.41686190943275E-01	) S=	1.23	;
    if(random >= 	8.47211190943275E-01	) S=	1.24	;
    if(random >= 	8.52570190943275E-01	) S=	1.25	;
    if(random >= 	8.57766190943275E-01	) S=	1.26	;
    if(random >= 	8.62802190943275E-01	) S=	1.27	;
    if(random >= 	8.67683190943275E-01	) S=	1.28	;
    if(random >= 	8.72412190943275E-01	) S=	1.29	;
    if(random >= 	8.76993190943275E-01	) S=	1.3	;
    if(random >= 	8.81429190943275E-01	) S=	1.31	;
    if(random >= 	8.85723190943275E-01	) S=	1.32	;
    if(random >= 	8.89879190943275E-01	) S=	1.33	;
    if(random >= 	8.93901190943275E-01	) S=	1.34	;
    if(random >= 	8.97792190943275E-01	) S=	1.35	;
    if(random >= 	9.01555190943275E-01	) S=	1.36	;
    if(random >= 	9.05194190943275E-01	) S=	1.37	;
    if(random >= 	9.08711190943275E-01	) S=	1.38	;
    if(random >= 	9.12110190943275E-01	) S=	1.39	;
    if(random >= 	9.15394190943275E-01	) S=	1.4	;
    if(random >= 	9.18567190943275E-01	) S=	1.41	;
    if(random >= 	9.21632190943275E-01	) S=	1.42	;
    if(random >= 	9.24592190943275E-01	) S=	1.43	;
    if(random >= 	9.27449190943275E-01	) S=	1.44	;
    if(random >= 	9.30207190943275E-01	) S=	1.45	;
    if(random >= 	9.32869190943275E-01	) S=	1.46	;
    if(random >= 	9.35438190943275E-01	) S=	1.47	;
    if(random >= 	9.37916190943275E-01	) S=	1.48	;
    if(random >= 	9.40307190943275E-01	) S=	1.49	;
    if(random >= 	9.42613190943275E-01	) S=	1.5	;
    if(random >= 	9.44837190943275E-01	) S=	1.51	;
    if(random >= 	9.46981190943275E-01	) S=	1.52	;
    if(random >= 	9.49048190943275E-01	) S=	1.53	;
    if(random >= 	9.51041190943275E-01	) S=	1.54	;
    if(random >= 	9.52962190943275E-01	) S=	1.55	;
    if(random >= 	9.54813190943275E-01	) S=	1.56	;
    if(random >= 	9.56597190943275E-01	) S=	1.57	;
    if(random >= 	9.58316190943275E-01	) S=	1.58	;
    if(random >= 	9.59972190943275E-01	) S=	1.59	;
    if(random >= 	9.61567190943275E-01	) S=	1.6	;
    if(random >= 	9.63104190943275E-01	) S=	1.61	;
    if(random >= 	9.64584190943275E-01	) S=	1.62	;
    if(random >= 	9.66010190943275E-01	) S=	1.63	;
    if(random >= 	9.67383190943275E-01	) S=	1.64	;
    if(random >= 	9.68705190943275E-01	) S=	1.65	;
    if(random >= 	9.69978190943275E-01	) S=	1.66	;
    if(random >= 	9.71203190943275E-01	) S=	1.67	;
    if(random >= 	9.72382190943275E-01	) S=	1.68	;
    if(random >= 	9.73517190943275E-01	) S=	1.69	;
    if(random >= 	9.74609190943275E-01	) S=	1.7	;
    if(random >= 	9.75660190943275E-01	) S=	1.71	;
    if(random >= 	9.76671190943275E-01	) S=	1.72	;
    if(random >= 	9.77643790943275E-01	) S=	1.73	;
    if(random >= 	9.78579190943276E-01	) S=	1.74	;
    if(random >= 	9.79478790943276E-01	) S=	1.75	;
    if(random >= 	9.80343690943275E-01	) S=	1.76	;
    if(random >= 	9.81175290943275E-01	) S=	1.77	;
    if(random >= 	9.81974590943275E-01	) S=	1.78	;
    if(random >= 	9.82742690943275E-01	) S=	1.79	;
    if(random >= 	9.83480790943275E-01	) S=	1.8	;
    if(random >= 	9.84189790943275E-01	) S=	1.81	;
    if(random >= 	9.84870790943275E-01	) S=	1.82	;
    if(random >= 	9.85524590943275E-01	) S=	1.83	;
    if(random >= 	9.86152290943276E-01	) S=	1.84	;
    if(random >= 	9.86754790943275E-01	) S=	1.85	;
    if(random >= 	9.87332890943275E-01	) S=	1.86	;
    if(random >= 	9.87887490943275E-01	) S=	1.87	;
    if(random >= 	9.88419290943275E-01	) S=	1.88	;
    if(random >= 	9.88929290943275E-01	) S=	1.89	;
    if(random >= 	9.89418090943275E-01	) S=	1.9	;
    if(random >= 	9.89886490943275E-01	) S=	1.91	;
    if(random >= 	9.90335190943275E-01	) S=	1.92	;
    if(random >= 	9.90764890943275E-01	) S=	1.93	;
    if(random >= 	9.91176190943275E-01	) S=	1.94	;
    if(random >= 	9.91569790943275E-01	) S=	1.95	;
    if(random >= 	9.91946390943275E-01	) S=	1.96	;
    if(random >= 	9.92306590943275E-01	) S=	1.97	;
    if(random >= 	9.92650890943275E-01	) S=	1.98	;
    if(random >= 	9.92979990943275E-01	) S=	1.99	;
    if(random >= 	9.93294390943275E-01	) S=	2	;
    if(random >= 	9.93594690943275E-01	) S=	2.01	;
    if(random >= 	9.93881290943275E-01	) S=	2.02	;
    if(random >= 	9.94154790943275E-01	) S=	2.03	;
    if(random >= 	9.94415690943275E-01	) S=	2.04	;
    if(random >= 	9.94664390943275E-01	) S=	2.05	;
    if(random >= 	9.94901490943275E-01	) S=	2.06	;
    if(random >= 	9.95127290943275E-01	) S=	2.07	;
    if(random >= 	9.95342390943275E-01	) S=	2.08	;
    if(random >= 	9.95547090943275E-01	) S=	2.09	;
    if(random >= 	9.95741890943275E-01	) S=	2.1	;
    if(random >= 	9.95927190943276E-01	) S=	2.11	;
    if(random >= 	9.96103290943276E-01	) S=	2.12	;
    if(random >= 	9.96270590943276E-01	) S=	2.13	;
    if(random >= 	9.96429490943275E-01	) S=	2.14	;
    if(random >= 	9.96580290943275E-01	) S=	2.15	;
    if(random >= 	9.96723390943275E-01	) S=	2.16	;
    if(random >= 	9.96859190943275E-01	) S=	2.17	;
    if(random >= 	9.96987890943275E-01	) S=	2.18	;
    if(random >= 	9.97109890943275E-01	) S=	2.19	;
    if(random >= 	9.97225390943275E-01	) S=	2.2	;
    if(random >= 	9.97334690943275E-01	) S=	2.21	;
    if(random >= 	9.97438090943275E-01	) S=	2.22	;
    if(random >= 	9.97535900943275E-01	) S=	2.23	;
    if(random >= 	9.97628380943275E-01	) S=	2.24	;
    if(random >= 	9.97715750943275E-01	) S=	2.25	;
    if(random >= 	9.97798230943275E-01	) S=	2.26	;
    if(random >= 	9.97876060943275E-01	) S=	2.27	;
    if(random >= 	9.97949480943275E-01	) S=	2.28	;
    if(random >= 	9.98018690943275E-01	) S=	2.29	;
    if(random >= 	9.98083910943275E-01	) S=	2.3	;
    if(random >= 	9.98145330943275E-01	) S=	2.31	;
    if(random >= 	9.98203150943275E-01	) S=	2.32	;
    if(random >= 	9.98257550943275E-01	) S=	2.33	;
    if(random >= 	9.98308700943275E-01	) S=	2.34	;
    if(random >= 	9.98356770943275E-01	) S=	2.35	;
    if(random >= 	9.98401930943275E-01	) S=	2.36	;
    if(random >= 	9.98444320943275E-01	) S=	2.37	;
    if(random >= 	9.98484100943275E-01	) S=	2.38	;
    if(random >= 	9.98521400943275E-01	) S=	2.39	;
    if(random >= 	9.98556360943275E-01	) S=	2.4	;
    if(random >= 	9.98589110943275E-01	) S=	2.41	;
    if(random >= 	9.98619770943275E-01	) S=	2.42	;
    if(random >= 	9.98648460943275E-01	) S=	2.43	;
    if(random >= 	9.98675290943275E-01	) S=	2.44	;
    if(random >= 	9.98700370943275E-01	) S=	2.45	;
    if(random >= 	9.98723800943275E-01	) S=	2.46	;
    if(random >= 	9.98745680943275E-01	) S=	2.47	;
    if(random >= 	9.98766090943275E-01	) S=	2.48	;
    if(random >= 	9.98785130943275E-01	) S=	2.49	;
    if(random >= 	9.98802870943275E-01	) S=	2.5	;
    if(random >= 	9.98819400943275E-01	) S=	2.51	;
    if(random >= 	9.98834790943275E-01	) S=	2.52	;
    if(random >= 	9.98849110943275E-01	) S=	2.53	;
    if(random >= 	9.98862430943275E-01	) S=	2.54	;
    if(random >= 	9.98874810943275E-01	) S=	2.55	;
    if(random >= 	9.98886310943275E-01	) S=	2.56	;
    if(random >= 	9.98896980943275E-01	) S=	2.57	;
    if(random >= 	9.98906882943275E-01	) S=	2.58	;
    if(random >= 	9.98916066943275E-01	) S=	2.59	;
    if(random >= 	9.98924577943275E-01	) S=	2.6	;
    if(random >= 	9.98932461943275E-01	) S=	2.61	;
    if(random >= 	9.98939757943275E-01	) S=	2.62	;
    if(random >= 	9.98946509943275E-01	) S=	2.63	;
    if(random >= 	9.98952752943275E-01	) S=	2.64	;
    if(random >= 	9.98958521943275E-01	) S=	2.65	;
    if(random >= 	9.98963849943275E-01	) S=	2.66	;
    if(random >= 	9.98968766943275E-01	) S=	2.67	;
    if(random >= 	9.98973302943275E-01	) S=	2.68	;
    if(random >= 	9.98977484943275E-01	) S=	2.69	;
    if(random >= 	9.98981337943275E-01	) S=	2.7	;
    if(random >= 	9.98984885943276E-01	) S=	2.71	;
    if(random >= 	9.98988150943276E-01	) S=	2.72	;
    if(random >= 	9.98991153943276E-01	) S=	2.73	;
    if(random >= 	9.98993914943275E-01	) S=	2.74	;
    if(random >= 	9.98996450943275E-01	) S=	2.75	;
    if(random >= 	9.98998779943275E-01	) S=	2.76	;
    if(random >= 	9.99000916943275E-01	) S=	2.77	;
    if(random >= 	9.99002875943275E-01	) S=	2.78	;
    if(random >= 	9.99004671943275E-01	) S=	2.79	;
    if(random >= 	9.99006316943275E-01	) S=	2.8	;
    if(random >= 	9.99007821943275E-01	) S=	2.81	;
    if(random >= 	9.99009198943275E-01	) S=	2.82	;
    if(random >= 	9.99010457943275E-01	) S=	2.83	;
    if(random >= 	9.99011608943275E-01	) S=	2.84	;
    if(random >= 	9.99012659943275E-01	) S=	2.85	;
    if(random >= 	9.99013618643276E-01	) S=	2.86	;
    if(random >= 	9.99014493543276E-01	) S=	2.87	;
    if(random >= 	9.99015291043276E-01	) S=	2.88	;
    if(random >= 	9.99016017443276E-01	) S=	2.89	;
    if(random >= 	9.99016678743276E-01	) S=	2.9	;
    if(random >= 	9.99017280443276E-01	) S=	2.91	;
    if(random >= 	9.99017827543276E-01	) S=	2.92	;
    if(random >= 	9.99018324743276E-01	) S=	2.93	;
    if(random >= 	9.99018776343276E-01	) S=	2.94	;
    if(random >= 	9.99019186243276E-01	) S=	2.95	;
    if(random >= 	9.99019558143276E-01	) S=	2.96	;
    if(random >= 	9.99019895343276E-01	) S=	2.97	;
    if(random >= 	9.99020200843276E-01	) S=	2.98	;
    if(random >= 	9.99020477443276E-01	) S=	2.99	;
    if(random >= 	9.99020727743276E-01	) S=	3	;
    if(random >= 	9.99020954143276E-01	) S=	3.01	;
    if(random >= 	9.99021158743276E-01	) S=	3.02	;
    if(random >= 	9.99021343543276E-01	) S=	3.03	;
    if(random >= 	9.99021510443276E-01	) S=	3.04	;
    if(random >= 	9.99021660943276E-01	) S=	3.05	;
    if(random >= 	9.99021796743276E-01	) S=	3.06	;
    if(random >= 	9.99021919043276E-01	) S=	3.07	;
    if(random >= 	9.99022029243276E-01	) S=	3.08	;
    if(random >= 	9.99022128353276E-01	) S=	3.09	;
    if(random >= 	9.99022217543276E-01	) S=	3.1	;
    if(random >= 	9.99022297693276E-01	) S=	3.11	;
    if(random >= 	9.99022369693276E-01	) S=	3.12	;
    if(random >= 	9.99022434343276E-01	) S=	3.13	;
    if(random >= 	9.99022492353276E-01	) S=	3.14	;
    if(random >= 	9.99022544373276E-01	) S=	3.15	;
    if(random >= 	9.99022590993276E-01	) S=	3.16	;
    if(random >= 	9.99022632743276E-01	) S=	3.17	;
    if(random >= 	9.99022670113276E-01	) S=	3.18	;
    if(random >= 	9.99022703543276E-01	) S=	3.19	;
    if(random >= 	9.99022733423276E-01	) S=	3.2	;
    if(random >= 	9.99022760123276E-01	) S=	3.21	;
    if(random >= 	9.99022783963276E-01	) S=	3.22	;
    if(random >= 	9.99022805233276E-01	) S=	3.23	;
    if(random >= 	9.99022824203276E-01	) S=	3.24	;
    if(random >= 	9.99022841113276E-01	) S=	3.25	;
    if(random >= 	9.99022856173276E-01	) S=	3.26	;
    if(random >= 	9.99022869573276E-01	) S=	3.27	;
    if(random >= 	9.99022881493276E-01	) S=	3.28	;
    if(random >= 	9.99022892093276E-01	) S=	3.29	;
    if(random >= 	9.99022901510276E-01	) S=	3.3	;
    if(random >= 	9.99022909875276E-01	) S=	3.31	;
    if(random >= 	9.99022917295275E-01	) S=	3.32	;
    if(random >= 	9.99022923877275E-01	) S=	3.33	;
    if(random >= 	9.99022929710275E-01	) S=	3.34	;
    if(random >= 	9.99022934877275E-01	) S=	3.35	;
    if(random >= 	9.99022939451275E-01	) S=	3.36	;
    if(random >= 	9.99022943498275E-01	) S=	3.37	;
    if(random >= 	9.99022947075275E-01	) S=	3.38	;
    if(random >= 	9.99022950236275E-01	) S=	3.39	;
    if(random >= 	9.99022953027275E-01	) S=	3.4	;
    if(random >= 	9.99022955490275E-01	) S=	3.41	;
    if(random >= 	9.99022957662275E-01	) S=	3.42	;
    if(random >= 	9.99022959577275E-01	) S=	3.43	;
    if(random >= 	9.99022961263275E-01	) S=	3.44	;
    if(random >= 	9.99022962748276E-01	) S=	3.45	;
    if(random >= 	9.99022964054275E-01	) S=	3.46	;
    if(random >= 	9.99022965203275E-01	) S=	3.47	;
    if(random >= 	9.99022966212275E-01	) S=	3.48	;
    if(random >= 	9.99022967098375E-01	) S=	3.49	;
    if(random >= 	9.99022967876176E-01	) S=	3.5	;
    if(random >= 	9.99022968558176E-01	) S=	3.51	;
    if(random >= 	9.99022969155876E-01	) S=	3.52	;
    if(random >= 	9.99022969679376E-01	) S=	3.53	;
    if(random >= 	9.99022970137675E-01	) S=	3.54	;
    if(random >= 	9.99022970538676E-01	) S=	3.55	;
    if(random >= 	9.99022970889275E-01	) S=	3.56	;
    if(random >= 	9.99022971195575E-01	) S=	3.57	;
    if(random >= 	9.99022971463076E-01	) S=	3.58	;
    if(random >= 	9.99022971696576E-01	) S=	3.59	;
    if(random >= 	9.99022971900176E-01	) S=	3.6	;
    if(random >= 	9.99022972077676E-01	) S=	3.61	;
    if(random >= 	9.99022972232276E-01	) S=	3.62	;
    if(random >= 	9.99022972366876E-01	) S=	3.63	;
    if(random >= 	9.99022972483976E-01	) S=	3.64	;
    if(random >= 	9.99022972585776E-01	) S=	3.65	;
    if(random >= 	9.99022972674226E-01	) S=	3.66	;
    if(random >= 	9.99022972751036E-01	) S=	3.67	;
    if(random >= 	9.99022972817666E-01	) S=	3.68	;
    if(random >= 	9.99022972875476E-01	) S=	3.69	;
    if(random >= 	9.99022972925576E-01	) S=	3.7	;
    if(random >= 	9.99022972968976E-01	) S=	3.71	;
    if(random >= 	9.99022973006546E-01	) S=	3.72	;
    if(random >= 	9.99022973039046E-01	) S=	3.73	;
    if(random >= 	9.99022973067145E-01	) S=	3.74	;
    if(random >= 	9.99022973091426E-01	) S=	3.75	;
    if(random >= 	9.99022973112396E-01	) S=	3.76	;
    if(random >= 	9.99022973130485E-01	) S=	3.77	;
    if(random >= 	9.99022973146095E-01	) S=	3.78	;
    if(random >= 	9.99022973159545E-01	) S=	3.79	;
    if(random >= 	9.99022973171135E-01	) S=	3.8	;
    if(random >= 	9.99022973181110E-01	) S=	3.81	;
    if(random >= 	9.99022973189689E-01	) S=	3.82	;
    if(random >= 	9.99022973197068E-01	) S=	3.83	;
    if(random >= 	9.99022973203408E-01	) S=	3.84	;
    if(random >= 	9.99022973208852E-01	) S=	3.85	;
    if(random >= 	9.99022973213525E-01	) S=	3.86	;
    if(random >= 	9.99022973217532E-01	) S=	3.87	;
    if(random >= 	9.99022973220967E-01	) S=	3.88	;
    if(random >= 	9.99022973223909E-01	) S=	3.89	;
    if(random >= 	9.99022973226428E-01	) S=	3.9	;
    if(random >= 	9.99022973228583E-01	) S=	3.91	;
    if(random >= 	9.99022973230425E-01	) S=	3.92	;
    if(random >= 	9.99022973231999E-01	) S=	3.93	;
    if(random >= 	9.99022973233343E-01	) S=	3.94	;
    if(random >= 	9.99022973234490E-01	) S=	3.95	;
    if(random >= 	9.99022973235468E-01	) S=	3.96	;
    if(random >= 	9.99022973236301E-01	) S=	3.97	;
    if(random >= 	9.99022973237011E-01	) S=	3.98	;
    if(random >= 	9.99022973237615E-01	) S=	3.99	;
    if(random >= 	9.99022973238129E-01	) S=	4	;
    if(random >= 	9.99022973238567E-01	) S=	4.01	;
    if(random >= 	9.99022973238938E-01	) S=	4.02	;
    if(random >= 	9.99022973239254E-01	) S=	4.03	;
    if(random >= 	9.99022973239521E-01	) S=	4.04	;
    if(random >= 	9.99022973239749E-01	) S=	4.05	;
    if(random >= 	9.99022973239941E-01	) S=	4.06	;
    if(random >= 	9.99022973240104E-01	) S=	4.07	;
    if(random >= 	9.99022973240242E-01	) S=	4.08	;
    if(random >= 	9.99022973240359E-01	) S=	4.09	;
    if(random >= 	9.99022973240457E-01	) S=	4.1	;
    if(random >= 	9.99022973240541E-01	) S=	4.11	;
    if(random >= 	9.99022973240611E-01	) S=	4.12	;
    if(random >= 	9.99022973240670E-01	) S=	4.13	;
    if(random >= 	9.99022973240721E-01	) S=	4.14	;
    if(random >= 	9.99022973240763E-01	) S=	4.15	;
    if(random >= 	9.99022973240798E-01	) S=	4.16	;
    if(random >= 	9.99022973240828E-01	) S=	4.17	;
    if(random >= 	9.99022973240853E-01	) S=	4.18	;
    if(random >= 	9.99022973240875E-01	) S=	4.19	;
    if(random >= 	9.99022973240892E-01	) S=	4.2	;
    if(random >= 	9.99022973240907E-01	) S=	4.21	;
    if(random >= 	9.99022973240920E-01	) S=	4.22	;
    if(random >= 	9.99022973240930E-01	) S=	4.23	;
    if(random >= 	9.99022973240939E-01	) S=	4.24	;
    if(random >= 	9.99022973240947E-01	) S=	4.25	;
    if(random >= 	9.99022973240953E-01	) S=	4.26	;
    if(random >= 	9.99022973240958E-01	) S=	4.27	;
    if(random >= 	9.99022973240962E-01	) S=	4.28	;
    if(random >= 	9.99022973240966E-01	) S=	4.29	;
    if(random >= 	9.99022973240969E-01	) S=	4.3	;
    if(random >= 	9.99022973240972E-01	) S=	4.31	;
    if(random >= 	9.99022973240974E-01	) S=	4.32	;
    if(random >= 	9.99022973240975E-01	) S=	4.33	;
    if(random >= 	9.99022973240977E-01	) S=	4.34	;
    if(random >= 	9.99022973240978E-01	) S=	4.35	;
    if(random >= 	9.99022973240979E-01	) S=	4.36	;
    
    //cout << random << '\t' << S << endl;
    
    lambda_palaeosens = 1.0/S;
    
    return lambda_palaeosens;
    
}


void convertI_em(int t_steps_year) //converts emission scenarios when more than 1 time step per year
{
    //First make I_em vector have at least tmax elements
    if(I_em.size() < tmax)
    {
        for (int i = I_em.size(); i < tmax; i++)
        {
            I_em.push_back(I_em[i-1]);
        }
        
    }
    //First set a dummy vector equal to I_em;
    std::vector<double> I_em_dummy;
    I_em_dummy.assign(tmax, 0.0);
    for (int i = 0; i<tmax; i++)
    {
        I_em_dummy[i] = I_em[i];
    }
    //Now re-set original Iem array by linearising between years
    
    int years=0;
    int count = 0;
    double annual_em;
    for(int i=0; i<tmax; i++)
    {
        annual_em = I_em_dummy[years+1]-I_em_dummy[years]; //set annual emission rate
        
        I_em[i] = I_em_dummy[years] + double(count)*annual_em/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    
}

void convertCO2(int t_steps_year) //converts emission scenarios when more than 1 time step per year
{
    //First make CO2 vector have at least tmax elements
    if(CO2.size() < tmax)
    {
        for (int i = CO2.size(); i < tmax; i++)
        {
            CO2.push_back(CO2[i-1]);
        }

    }
    //Then set a dummy vector equal to CO2;
    std::vector<double> CO2_dummy;
    CO2_dummy.assign(tmax, 0.0);
    for (int i = 0; i<tmax; i++)
    {
        CO2_dummy[i] = CO2[i];
    }
    //Now re-set original CO2 array by linearising between years
    int years=0;
    int count = 0;
    double annual_dCO2;
    for(int i=0; i<tmax; i++)
    {
        annual_dCO2 = CO2_dummy[years+1]-CO2_dummy[years]; //set annual emission rate
        
        CO2[i] = CO2_dummy[years] + double(count)*annual_dCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    
}

void convertRnonCO2(int t_steps_year) //converts RnonCO2 when mpre than 1 time step per year
{
    //First make RnonCO2 vector have at least tmax elements
    if(RnonCO2.size() < tmax)
    {
        for (int i = RnonCO2.size(); i < tmax; i++)
        {
            RnonCO2.push_back(RnonCO2[i-1]);
        }
        
    }
    //Then set a dummy vector equal to RnonCO2
    std::vector<double> Dummy;
    Dummy.assign(tmax, 0.0);
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = RnonCO2[i];
    }
    //Now re-set original array by linearising between years
    
    int years=0;
    int count = 0;
    double annual_dRnonCO2;
    for(int i=0; i<tmax; i++)
    {
        annual_dRnonCO2 = Dummy[years+1]-Dummy[years]; //set annual emission rate
        
        RnonCO2[i] = Dummy[years] + double(count)*annual_dRnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    
    
    
    
}

void convertAOD(int t_steps_month) //converts RnonCO2 when mpre than 1 time step per year
{
    //First make CO2 vector have at least tmax elements
    if(AOD.size() < tmax)
    {
        for (int i = AOD.size(); i < tmax; i++)
        {
            AOD.push_back(AOD[i-1]);
        }
        
    }
    //Then set a dummy vector equal to I_em;
    std::vector<double> Dummy;
    Dummy.assign(tmax, 0.0);
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = AOD[i];
    }
    //Now re-set original array by linearising between years
    
    int years=0;
    int count = 0;
    double annual_dRnonCO2;
    for(int i=0; i<tmax; i++)
    {
        annual_dRnonCO2 = Dummy[years+1]-Dummy[years];
        
        AOD[i] = Dummy[years] + double(count)*annual_dRnonCO2/double(t_steps_month);
        
        count++;
        
        if(count == (t_steps_month))
        {
            count=0;
            years++;
        }
        
        
    }
    
}

void convert_nonCO2(int t_steps_month) //converts RnonCO2 when more than 1 time step per year
{
    //Initialise Dummy vector
    std::vector<double> Dummy;
    Dummy.assign(tmax, 0.0);
    
    //First make Annual vectors have at least tmax elements
    if(CH4.size() < tmax)
    {
        for (int i = CH4.size(); i < tmax; i++)
        {
            CH4.push_back(CH4[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = CH4[i];
    }
    //Now re-set original array by linearising between years
    
    int years=0;
    int count = 0;
    double annual_dnonCO2;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        CH4[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_month);
        
        count++;
        
        if(count == (t_steps_month))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(N2O.size() < tmax)
    {
        for (int i = N2O.size(); i < tmax; i++)
        {
            N2O.push_back(N2O[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = N2O[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        N2O[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_month);
        
        count++;
        
        if(count == (t_steps_month))
        {
            count=0;
            years++;
        }
        
        
    }

    
    
    
}
void convert_AerosolEmissions(int t_steps_year) //converts RnonCO2 when more than 1 time step per year
{
    //Initialise Dummy vector
    std::vector<double> Dummy;
    Dummy.assign(tmax, 0.0);
    int years=0;
    int count = 0;
    double annual_dnonCO2;
    
    //First make Annual vectors have at least tmax elements
    if(Aero_BC_em.size() < tmax)
    {
        for (int i = Aero_BC_em.size(); i < tmax; i++)
        {
            Aero_BC_em.push_back(Aero_BC_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_BC_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_BC_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(Aero_OC_em.size() < tmax)
    {
        for (int i = Aero_OC_em.size(); i < tmax; i++)
        {
            Aero_OC_em.push_back(Aero_OC_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_OC_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_OC_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(Aero_SOx_em.size() < tmax)
    {
        for (int i = Aero_SOx_em.size(); i < tmax; i++)
        {
            Aero_SOx_em.push_back(Aero_SOx_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_SOx_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_SOx_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(Aero_NOx_em.size() < tmax)
    {
        for (int i = Aero_NOx_em.size(); i < tmax; i++)
        {
            Aero_NOx_em.push_back(Aero_NOx_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_NOx_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_NOx_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(Aero_NH3_em.size() < tmax)
    {
        for (int i = Aero_NH3_em.size(); i < tmax; i++)
        {
            Aero_NH3_em.push_back(Aero_NH3_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_NH3_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_NH3_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    //Repeat for other non-CO2 concentrations
    //First make Annual vectors have at least tmax elements
    if(Aero_ENMVOC_em.size() < tmax)
    {
        for (int i = Aero_ENMVOC_em.size(); i < tmax; i++)
        {
            Aero_ENMVOC_em.push_back(Aero_ENMVOC_em[i-1]);
        }
        
    }
    
    //Then set Dummay array vector to annual vector
    for (int i = 0; i<tmax; i++)
    {
        Dummy[i] = Aero_ENMVOC_em[i];
    }
    //Now re-set original array by linearising between years
    
    years=0;
    count = 0;
    for(int i=0; i<tmax; i++)
    {
        annual_dnonCO2 = Dummy[years+1]-Dummy[years];
        
        Aero_ENMVOC_em[i] = Dummy[years] + double(count)*annual_dnonCO2/double(t_steps_year);
        
        count++;
        
        if(count == (t_steps_year))
        {
            count=0;
            years++;
        }
        
        
    }
    
    
    
}



double getRateINDCs(double yearEm)//Fawcett et al (2015) analysis of CO2 emissions from INDC
{
    double EmRate2030= 10.67 + 0.96; //Fawcett et al (2015) + constant 2014 land use change contribution which is average 2010-2014 from Carbon Budget 2015.
    
    double EmRate2014= 9.80+1.09;
    
    double RateEm = 0.0; //is in PgC yr-1
    
    if(yearEm < 2014.0)
    {
        yearEm = 2014.0;
    }
    
    if(yearEm <= 2031.0) //Linear increase to 2030
    {
        RateEm =  EmRate2014 + (EmRate2030-EmRate2014)* ( (yearEm - 2014.0)/(2031.0-2014.0) );
    }
    if(yearEm > 2031.0) //Constant after 2030.
    {
        RateEm = EmRate2030;
    }
    
    return RateEm;
    
}

double getRateINDCs2017(double yearEm)//Fawcett et al (2015) analysis of CO2 emissions from INDC
{
    double EmRate2030= 10.67 + 0.96; //Fawcett et al (2015) + constant 2014 land use change contribution which is average 2010-2014 from Carbon Budget 2015.
    
    double EmRate2017= 9.87+1.39;
    
    double RateEm = 0.0; //is in PgC yr-1
    
    if(yearEm < 2017.0)
    {
        yearEm = 2017.0;
    }
    
    if(yearEm <= 2031.0) //Linear increase to 2030
    {
        RateEm =  EmRate2017 + (EmRate2030-EmRate2017)* ( (yearEm - 2017.0)/(2031.0-2017.0) );
    }
    if(yearEm > 2031.0) //Constant after 2030.
    {
        RateEm = EmRate2030;
    }
    
    return RateEm;
    
}


//Function returns the annual emission rate from The Carbon Budget 2015, LeQuere et al (2015).
double getRateCarbonBudget(double yearEm)
{
    double RateEm=0.0; //is in PgC per year
    
    if(yearEm<2006.0)
    {
        RateEm = 8.08+1.02;
    }
    if(yearEm>=2006.0 && yearEm <2007.0)
    {
        RateEm = 6.36+1.09;
    }
    if(yearEm>=2007.0 && yearEm <2008.0)
    {
        RateEm = 8.53+0.97;
    }
    if(yearEm>=2008.0 && yearEm <2009.0)
    {
        RateEm = 8.74+0.67;
    }
    if(yearEm>=2009.0 && yearEm <2010.0)
    {
        RateEm = 8.70+0.76;
    }
    if(yearEm>=2010.0 && yearEm <2011.0)
    {
        RateEm = 9.14+0.88;
    }
    if(yearEm>=2011.0 && yearEm <2012.0)
    {
        RateEm = 9.45+0.91;
    }
    if(yearEm>=2012.0 && yearEm <2013.0)
    {
        RateEm = 9.58+0.97;
    }
    if(yearEm>=2013.0 && yearEm <2014.0)
    {
        RateEm = 9.74+0.92;
    }
    if(yearEm>=2014.0)
    {
        RateEm = 9.80+1.09;
    }
    return RateEm;
}
void setCO2_1pcent(double coeff)
{
    CO2[	0	]=	278.0	/coeff;
    CO2[	1	]=	280.78	/coeff;
    CO2[	2	]=	283.5878	/coeff;
    CO2[	3	]=	286.423678	/coeff;
    CO2[	4	]=	289.2879148	/coeff;
    CO2[	5	]=	292.1807939	/coeff;
    CO2[	6	]=	295.1026019	/coeff;
    CO2[	7	]=	298.0536279	/coeff;
    CO2[	8	]=	301.0341642	/coeff;
    CO2[	9	]=	304.0445058	/coeff;
    CO2[	10	]=	307.0849509	/coeff;
    CO2[	11	]=	310.1558004	/coeff;
    CO2[	12	]=	313.2573584	/coeff;
    CO2[	13	]=	316.389932	/coeff;
    CO2[	14	]=	319.5538313	/coeff;
    CO2[	15	]=	322.7493696	/coeff;
    CO2[	16	]=	325.9768633	/coeff;
    CO2[	17	]=	329.2366319	/coeff;
    CO2[	18	]=	332.5289982	/coeff;
    CO2[	19	]=	335.8542882	/coeff;
    CO2[	20	]=	339.2128311	/coeff;
    CO2[	21	]=	342.6049594	/coeff;
    CO2[	22	]=	346.031009	/coeff;
    CO2[	23	]=	349.4913191	/coeff;
    CO2[	24	]=	352.9862323	/coeff;
    CO2[	25	]=	356.5160946	/coeff;
    CO2[	26	]=	360.0812556	/coeff;
    CO2[	27	]=	363.6820681	/coeff;
    CO2[	28	]=	367.3188888	/coeff;
    CO2[	29	]=	370.9920777	/coeff;
    CO2[	30	]=	374.7019985	/coeff;
    CO2[	31	]=	378.4490184	/coeff;
    CO2[	32	]=	382.2335086	/coeff;
    CO2[	33	]=	386.0558437	/coeff;
    CO2[	34	]=	389.9164022	/coeff;
    CO2[	35	]=	393.8155662	/coeff;
    CO2[	36	]=	397.7537218	/coeff;
    CO2[	37	]=	401.7312591	/coeff;
    CO2[	38	]=	405.7485716	/coeff;
    CO2[	39	]=	409.8060574	/coeff;
    CO2[	40	]=	413.9041179	/coeff;
    CO2[	41	]=	418.0431591	/coeff;
    CO2[	42	]=	422.2235907	/coeff;
    CO2[	43	]=	426.4458266	/coeff;
    CO2[	44	]=	430.7102849	/coeff;
    CO2[	45	]=	435.0173877	/coeff;
    CO2[	46	]=	439.3675616	/coeff;
    CO2[	47	]=	443.7612372	/coeff;
    CO2[	48	]=	448.1988496	/coeff;
    CO2[	49	]=	452.6808381	/coeff;
    CO2[	50	]=	457.2076465	/coeff;
    CO2[	51	]=	461.7797229	/coeff;
    CO2[	52	]=	466.3975202	/coeff;
    CO2[	53	]=	471.0614954	/coeff;
    CO2[	54	]=	475.7721103	/coeff;
    CO2[	55	]=	480.5298314	/coeff;
    CO2[	56	]=	485.3351297	/coeff;
    CO2[	57	]=	490.188481	/coeff;
    CO2[	58	]=	495.0903658	/coeff;
    CO2[	59	]=	500.0412695	/coeff;
    CO2[	60	]=	505.0416822	/coeff;
    CO2[	61	]=	510.092099	/coeff;
    CO2[	62	]=	515.19302	/coeff;
    CO2[	63	]=	520.3449502	/coeff;
    CO2[	64	]=	525.5483997	/coeff;
    CO2[	65	]=	530.8038837	/coeff;
    CO2[	66	]=	536.1119225	/coeff;
    CO2[	67	]=	541.4730418	/coeff;
    CO2[	68	]=	546.8877722	/coeff;
    CO2[	69	]=	552.3566499	/coeff;
    CO2[	70	]=	557.8802164	/coeff;
    CO2[	71	]=	563.4590186	/coeff;
    CO2[	72	]=	569.0936088	/coeff;
    CO2[	73	]=	574.7845449	/coeff;
    CO2[	74	]=	580.5323903	/coeff;
    CO2[	75	]=	586.3377142	/coeff;
    CO2[	76	]=	592.2010913	/coeff;
    CO2[	77	]=	598.1231023	/coeff;
    CO2[	78	]=	604.1043333	/coeff;
    CO2[	79	]=	610.1453766	/coeff;
    CO2[	80	]=	616.2468304	/coeff;
    CO2[	81	]=	622.4092987	/coeff;
    CO2[	82	]=	628.6333917	/coeff;
    CO2[	83	]=	634.9197256	/coeff;
    CO2[	84	]=	641.2689228	/coeff;
    CO2[	85	]=	647.6816121	/coeff;
    CO2[	86	]=	654.1584282	/coeff;
    CO2[	87	]=	660.7000125	/coeff;
    CO2[	88	]=	667.3070126	/coeff;
    CO2[	89	]=	673.9800827	/coeff;
    CO2[	90	]=	680.7198836	/coeff;
    CO2[	91	]=	687.5270824	/coeff;
    CO2[	92	]=	694.4023532	/coeff;
    CO2[	93	]=	701.3463767	/coeff;
    CO2[	94	]=	708.3598405	/coeff;
    CO2[	95	]=	715.4434389	/coeff;
    CO2[	96	]=	722.5978733	/coeff;
    CO2[	97	]=	729.823852	/coeff;
    CO2[	98	]=	737.1220906	/coeff;
    CO2[	99	]=	744.4933115	/coeff;
    CO2[	100	]=	751.9382446	/coeff;
    CO2[	101	]=	759.457627	/coeff;
    CO2[	102	]=	767.0522033	/coeff;
    CO2[	103	]=	774.7227253	/coeff;
    CO2[	104	]=	782.4699526	/coeff;
    CO2[	105	]=	790.2946521	/coeff;
    CO2[	106	]=	798.1975986	/coeff;
    CO2[	107	]=	806.1795746	/coeff;
    CO2[	108	]=	814.2413704	/coeff;
    CO2[	109	]=	822.3837841	/coeff;
    CO2[	110	]=	830.6076219	/coeff;
    CO2[	111	]=	838.9136981	/coeff;
    CO2[	112	]=	847.3028351	/coeff;
    CO2[	113	]=	855.7758635	/coeff;
    CO2[	114	]=	864.3336221	/coeff;
    CO2[	115	]=	872.9769583	/coeff;
    CO2[	116	]=	881.7067279	/coeff;
    CO2[	117	]=	890.5237952	/coeff;
    CO2[	118	]=	899.4290331	/coeff;
    CO2[	119	]=	908.4233235	/coeff;
    CO2[	120	]=	917.5075567	/coeff;
    CO2[	121	]=	926.6826323	/coeff;
    CO2[	122	]=	935.9494586	/coeff;
    CO2[	123	]=	945.3089532	/coeff;
    CO2[	124	]=	954.7620427	/coeff;
    CO2[	125	]=	964.3096631	/coeff;
    CO2[	126	]=	973.9527598	/coeff;
    CO2[	127	]=	983.6922874	/coeff;
    CO2[	128	]=	993.5292102	/coeff;
    CO2[	129	]=	1003.464502	/coeff;
    CO2[	130	]=	1013.499147	/coeff;
    CO2[	131	]=	1023.634139	/coeff;
    CO2[	132	]=	1033.87048	/coeff;
    CO2[	133	]=	1044.209185	/coeff;
    CO2[	134	]=	1054.651277	/coeff;
    CO2[	135	]=	1065.19779	/coeff;
    CO2[	136	]=	1075.849768	/coeff;
    CO2[	137	]=	1086.608265	/coeff;
    CO2[	138	]=	1097.474348	/coeff;
    CO2[	139	]=	1108.449091	/coeff;
    CO2[	140	]=	1119.533582	/coeff;
    CO2[	141	]=	1130.728918	/coeff;
    CO2[	142	]=	1142.036207	/coeff;
    CO2[	143	]=	1153.456569	/coeff;
    CO2[	144	]=	1164.991135	/coeff;
    CO2[	145	]=	1176.641046	/coeff;
    CO2[	146	]=	1188.407457	/coeff;
    CO2[	147	]=	1200.291531	/coeff;
    CO2[	148	]=	1212.294447	/coeff;
    CO2[	149	]=	1224.417391	/coeff;
    CO2[	150	]=	1236.661565	/coeff;
    CO2[	151	]=	1249.028181	/coeff;
    
    for(int i = 152; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
    
}

void setCO2_1pcent4Xext(double coeff)
{
    CO2[	0	]=	278.0	/coeff;
    CO2[	1	]=	280.78	/coeff;
    CO2[	2	]=	283.5878	/coeff;
    CO2[	3	]=	286.423678	/coeff;
    CO2[	4	]=	289.2879148	/coeff;
    CO2[	5	]=	292.1807939	/coeff;
    CO2[	6	]=	295.1026019	/coeff;
    CO2[	7	]=	298.0536279	/coeff;
    CO2[	8	]=	301.0341642	/coeff;
    CO2[	9	]=	304.0445058	/coeff;
    CO2[	10	]=	307.0849509	/coeff;
    CO2[	11	]=	310.1558004	/coeff;
    CO2[	12	]=	313.2573584	/coeff;
    CO2[	13	]=	316.389932	/coeff;
    CO2[	14	]=	319.5538313	/coeff;
    CO2[	15	]=	322.7493696	/coeff;
    CO2[	16	]=	325.9768633	/coeff;
    CO2[	17	]=	329.2366319	/coeff;
    CO2[	18	]=	332.5289982	/coeff;
    CO2[	19	]=	335.8542882	/coeff;
    CO2[	20	]=	339.2128311	/coeff;
    CO2[	21	]=	342.6049594	/coeff;
    CO2[	22	]=	346.031009	/coeff;
    CO2[	23	]=	349.4913191	/coeff;
    CO2[	24	]=	352.9862323	/coeff;
    CO2[	25	]=	356.5160946	/coeff;
    CO2[	26	]=	360.0812556	/coeff;
    CO2[	27	]=	363.6820681	/coeff;
    CO2[	28	]=	367.3188888	/coeff;
    CO2[	29	]=	370.9920777	/coeff;
    CO2[	30	]=	374.7019985	/coeff;
    CO2[	31	]=	378.4490184	/coeff;
    CO2[	32	]=	382.2335086	/coeff;
    CO2[	33	]=	386.0558437	/coeff;
    CO2[	34	]=	389.9164022	/coeff;
    CO2[	35	]=	393.8155662	/coeff;
    CO2[	36	]=	397.7537218	/coeff;
    CO2[	37	]=	401.7312591	/coeff;
    CO2[	38	]=	405.7485716	/coeff;
    CO2[	39	]=	409.8060574	/coeff;
    CO2[	40	]=	413.9041179	/coeff;
    CO2[	41	]=	418.0431591	/coeff;
    CO2[	42	]=	422.2235907	/coeff;
    CO2[	43	]=	426.4458266	/coeff;
    CO2[	44	]=	430.7102849	/coeff;
    CO2[	45	]=	435.0173877	/coeff;
    CO2[	46	]=	439.3675616	/coeff;
    CO2[	47	]=	443.7612372	/coeff;
    CO2[	48	]=	448.1988496	/coeff;
    CO2[	49	]=	452.6808381	/coeff;
    CO2[	50	]=	457.2076465	/coeff;
    CO2[	51	]=	461.7797229	/coeff;
    CO2[	52	]=	466.3975202	/coeff;
    CO2[	53	]=	471.0614954	/coeff;
    CO2[	54	]=	475.7721103	/coeff;
    CO2[	55	]=	480.5298314	/coeff;
    CO2[	56	]=	485.3351297	/coeff;
    CO2[	57	]=	490.188481	/coeff;
    CO2[	58	]=	495.0903658	/coeff;
    CO2[	59	]=	500.0412695	/coeff;
    CO2[	60	]=	505.0416822	/coeff;
    CO2[	61	]=	510.092099	/coeff;
    CO2[	62	]=	515.19302	/coeff;
    CO2[	63	]=	520.3449502	/coeff;
    CO2[	64	]=	525.5483997	/coeff;
    CO2[	65	]=	530.8038837	/coeff;
    CO2[	66	]=	536.1119225	/coeff;
    CO2[	67	]=	541.4730418	/coeff;
    CO2[	68	]=	546.8877722	/coeff;
    CO2[	69	]=	552.3566499	/coeff;
    CO2[	70	]=	557.8802164	/coeff;
    CO2[	71	]=	563.4590186	/coeff;
    CO2[	72	]=	569.0936088	/coeff;
    CO2[	73	]=	574.7845449	/coeff;
    CO2[	74	]=	580.5323903	/coeff;
    CO2[	75	]=	586.3377142	/coeff;
    CO2[	76	]=	592.2010913	/coeff;
    CO2[	77	]=	598.1231023	/coeff;
    CO2[	78	]=	604.1043333	/coeff;
    CO2[	79	]=	610.1453766	/coeff;
    CO2[	80	]=	616.2468304	/coeff;
    CO2[	81	]=	622.4092987	/coeff;
    CO2[	82	]=	628.6333917	/coeff;
    CO2[	83	]=	634.9197256	/coeff;
    CO2[	84	]=	641.2689228	/coeff;
    CO2[	85	]=	647.6816121	/coeff;
    CO2[	86	]=	654.1584282	/coeff;
    CO2[	87	]=	660.7000125	/coeff;
    CO2[	88	]=	667.3070126	/coeff;
    CO2[	89	]=	673.9800827	/coeff;
    CO2[	90	]=	680.7198836	/coeff;
    CO2[	91	]=	687.5270824	/coeff;
    CO2[	92	]=	694.4023532	/coeff;
    CO2[	93	]=	701.3463767	/coeff;
    CO2[	94	]=	708.3598405	/coeff;
    CO2[	95	]=	715.4434389	/coeff;
    CO2[	96	]=	722.5978733	/coeff;
    CO2[	97	]=	729.823852	/coeff;
    CO2[	98	]=	737.1220906	/coeff;
    CO2[	99	]=	744.4933115	/coeff;
    CO2[	100	]=	751.9382446	/coeff;
    CO2[	101	]=	759.457627	/coeff;
    CO2[	102	]=	767.0522033	/coeff;
    CO2[	103	]=	774.7227253	/coeff;
    CO2[	104	]=	782.4699526	/coeff;
    CO2[	105	]=	790.2946521	/coeff;
    CO2[	106	]=	798.1975986	/coeff;
    CO2[	107	]=	806.1795746	/coeff;
    CO2[	108	]=	814.2413704	/coeff;
    CO2[	109	]=	822.3837841	/coeff;
    CO2[	110	]=	830.6076219	/coeff;
    CO2[	111	]=	838.9136981	/coeff;
    CO2[	112	]=	847.3028351	/coeff;
    CO2[	113	]=	855.7758635	/coeff;
    CO2[	114	]=	864.3336221	/coeff;
    CO2[	115	]=	872.9769583	/coeff;
    CO2[	116	]=	881.7067279	/coeff;
    CO2[	117	]=	890.5237952	/coeff;
    CO2[	118	]=	899.4290331	/coeff;
    CO2[	119	]=	908.4233235	/coeff;
    CO2[	120	]=	917.5075567	/coeff;
    CO2[	121	]=	926.6826323	/coeff;
    CO2[	122	]=	935.9494586	/coeff;
    CO2[	123	]=	945.3089532	/coeff;
    CO2[	124	]=	954.7620427	/coeff;
    CO2[	125	]=	964.3096631	/coeff;
    CO2[	126	]=	973.9527598	/coeff;
    CO2[	127	]=	983.6922874	/coeff;
    CO2[	128	]=	993.5292102	/coeff;
    CO2[	129	]=	1003.464502	/coeff;
    CO2[	130	]=	1013.499147	/coeff;
    CO2[	131	]=	1023.634139	/coeff;
    CO2[	132	]=	1033.87048	/coeff;
    CO2[	133	]=	1044.209185	/coeff;
    CO2[	134	]=	1054.651277	/coeff;
    CO2[	135	]=	1065.19779	/coeff;
    CO2[	136	]=	1075.849768	/coeff;
    CO2[	137	]=	1086.608265	/coeff;
    CO2[	138	]=	1097.474348	/coeff;
    CO2[	139	]=	1108.449091	/coeff;
    CO2[	140	]=	1112.0	/coeff;
    
    
    for(int i = 141; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
}

void setCO2_abrupt2X(double coeff)
{
    CO2[0] = 278.0/coeff;
    CO2[1] = 2.0*CO2[0];
    
    for(int i = 2; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
}

void setCO2_abrupt4X(double coeff)
{
    CO2[0] = 278.0/coeff;
    CO2[1] = 4.0*CO2[0];
    
    for(int i = 2; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
}

void setCO2_abrupt0_5X(double coeff)
{
    CO2[0] = 278.0/coeff;
    CO2[1] = 0.5*CO2[0];
    
    for(int i = 2; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }}



void setCO2RCP3PD(double coeff)
{
    CO2[	0	]=	278.05158	/coeff;
    CO2[	1	]=	278.10615	/coeff;
    CO2[	2	]=	278.22039	/coeff;
    CO2[	3	]=	278.34305	/coeff;
    CO2[	4	]=	278.47058	/coeff;
    CO2[	5	]=	278.60047	/coeff;
    CO2[	6	]=	278.73275	/coeff;
    CO2[	7	]=	278.86881	/coeff;
    CO2[	8	]=	279.00907	/coeff;
    CO2[	9	]=	279.15318	/coeff;
    CO2[	10	]=	279.30180	/coeff;
    CO2[	11	]=	279.45680	/coeff;
    CO2[	12	]=	279.61808	/coeff;
    CO2[	13	]=	279.78192	/coeff;
    CO2[	14	]=	279.94320	/coeff;
    CO2[	15	]=	280.09740	/coeff;
    CO2[	16	]=	280.24280	/coeff;
    CO2[	17	]=	280.38168	/coeff;
    CO2[	18	]=	280.51832	/coeff;
    CO2[	19	]=	280.65720	/coeff;
    CO2[	20	]=	280.80260	/coeff;
    CO2[	21	]=	280.95680	/coeff;
    CO2[	22	]=	281.11808	/coeff;
    CO2[	23	]=	281.28192	/coeff;
    CO2[	24	]=	281.44320	/coeff;
    CO2[	25	]=	281.59820	/coeff;
    CO2[	26	]=	281.74682	/coeff;
    CO2[	27	]=	281.89093	/coeff;
    CO2[	28	]=	282.03119	/coeff;
    CO2[	29	]=	282.16725	/coeff;
    CO2[	30	]=	282.29901	/coeff;
    CO2[	31	]=	282.42680	/coeff;
    CO2[	32	]=	282.55093	/coeff;
    CO2[	33	]=	282.67123	/coeff;
    CO2[	34	]=	282.78730	/coeff;
    CO2[	35	]=	282.89901	/coeff;
    CO2[	36	]=	283.00677	/coeff;
    CO2[	37	]=	283.11093	/coeff;
    CO2[	38	]=	283.21129	/coeff;
    CO2[	39	]=	283.30737	/coeff;
    CO2[	40	]=	283.39963	/coeff;
    CO2[	41	]=	283.48978	/coeff;
    CO2[	42	]=	283.57796	/coeff;
    CO2[	43	]=	283.66116	/coeff;
    CO2[	44	]=	283.73511	/coeff;
    CO2[	45	]=	283.79676	/coeff;
    CO2[	46	]=	283.84667	/coeff;
    CO2[	47	]=	283.88853	/coeff;
    CO2[	48	]=	283.92613	/coeff;
    CO2[	49	]=	283.96267	/coeff;
    CO2[	50	]=	284.00107	/coeff;
    CO2[	51	]=	284.04267	/coeff;
    CO2[	52	]=	284.08613	/coeff;
    CO2[	53	]=	284.12853	/coeff;
    CO2[	54	]=	284.16667	/coeff;
    CO2[	55	]=	284.19820	/coeff;
    CO2[	56	]=	284.22333	/coeff;
    CO2[	57	]=	284.24427	/coeff;
    CO2[	58	]=	284.26307	/coeff;
    CO2[	59	]=	284.28133	/coeff;
    CO2[	60	]=	284.30027	/coeff;
    CO2[	61	]=	284.32000	/coeff;
    CO2[	62	]=	284.34000	/coeff;
    CO2[	63	]=	284.36000	/coeff;
    CO2[	64	]=	284.38000	/coeff;
    CO2[	65	]=	284.40000	/coeff;
    CO2[	66	]=	284.38500	/coeff;
    CO2[	67	]=	284.28000	/coeff;
    CO2[	68	]=	284.12500	/coeff;
    CO2[	69	]=	283.97500	/coeff;
    CO2[	70	]=	283.82500	/coeff;
    CO2[	71	]=	283.67500	/coeff;
    CO2[	72	]=	283.52500	/coeff;
    CO2[	73	]=	283.42500	/coeff;
    CO2[	74	]=	283.40000	/coeff;
    CO2[	75	]=	283.40000	/coeff;
    CO2[	76	]=	283.42500	/coeff;
    CO2[	77	]=	283.50000	/coeff;
    CO2[	78	]=	283.60000	/coeff;
    CO2[	79	]=	283.72500	/coeff;
    CO2[	80	]=	283.90000	/coeff;
    CO2[	81	]=	284.07500	/coeff;
    CO2[	82	]=	284.22500	/coeff;
    CO2[	83	]=	284.40000	/coeff;
    CO2[	84	]=	284.57500	/coeff;
    CO2[	85	]=	284.72500	/coeff;
    CO2[	86	]=	284.87500	/coeff;
    CO2[	87	]=	285.00000	/coeff;
    CO2[	88	]=	285.12500	/coeff;
    CO2[	89	]=	285.27500	/coeff;
    CO2[	90	]=	285.42500	/coeff;
    CO2[	91	]=	285.57500	/coeff;
    CO2[	92	]=	285.72500	/coeff;
    CO2[	93	]=	285.90000	/coeff;
    CO2[	94	]=	286.07500	/coeff;
    CO2[	95	]=	286.22500	/coeff;
    CO2[	96	]=	286.37500	/coeff;
    CO2[	97	]=	286.50000	/coeff;
    CO2[	98	]=	286.62500	/coeff;
    CO2[	99	]=	286.77500	/coeff;
    CO2[	100	]=	286.90000	/coeff;
    CO2[	101	]=	287.00000	/coeff;
    CO2[	102	]=	287.10000	/coeff;
    CO2[	103	]=	287.22500	/coeff;
    CO2[	104	]=	287.37500	/coeff;
    CO2[	105	]=	287.52500	/coeff;
    CO2[	106	]=	287.70000	/coeff;
    CO2[	107	]=	287.90000	/coeff;
    CO2[	108	]=	288.12500	/coeff;
    CO2[	109	]=	288.40000	/coeff;
    CO2[	110	]=	288.70000	/coeff;
    CO2[	111	]=	289.02500	/coeff;
    CO2[	112	]=	289.40000	/coeff;
    CO2[	113	]=	289.80000	/coeff;
    CO2[	114	]=	290.22500	/coeff;
    CO2[	115	]=	290.70000	/coeff;
    CO2[	116	]=	291.20000	/coeff;
    CO2[	117	]=	291.67500	/coeff;
    CO2[	118	]=	292.12500	/coeff;
    CO2[	119	]=	292.57500	/coeff;
    CO2[	120	]=	292.97500	/coeff;
    CO2[	121	]=	293.30000	/coeff;
    CO2[	122	]=	293.57500	/coeff;
    CO2[	123	]=	293.80000	/coeff;
    CO2[	124	]=	294.00000	/coeff;
    CO2[	125	]=	294.17500	/coeff;
    CO2[	126	]=	294.32500	/coeff;
    CO2[	127	]=	294.47500	/coeff;
    CO2[	128	]=	294.60000	/coeff;
    CO2[	129	]=	294.70000	/coeff;
    CO2[	130	]=	294.80000	/coeff;
    CO2[	131	]=	294.90000	/coeff;
    CO2[	132	]=	295.02500	/coeff;
    CO2[	133	]=	295.22500	/coeff;
    CO2[	134	]=	295.50000	/coeff;
    CO2[	135	]=	295.80000	/coeff;
    CO2[	136	]=	296.12500	/coeff;
    CO2[	137	]=	296.47500	/coeff;
    CO2[	138	]=	296.82500	/coeff;
    CO2[	139	]=	297.20000	/coeff;
    CO2[	140	]=	297.62500	/coeff;
    CO2[	141	]=	298.07500	/coeff;
    CO2[	142	]=	298.50000	/coeff;
    CO2[	143	]=	298.90000	/coeff;
    CO2[	144	]=	299.30000	/coeff;
    CO2[	145	]=	299.70000	/coeff;
    CO2[	146	]=	300.07500	/coeff;
    CO2[	147	]=	300.42500	/coeff;
    CO2[	148	]=	300.77500	/coeff;
    CO2[	149	]=	301.10000	/coeff;
    CO2[	150	]=	301.40000	/coeff;
    CO2[	151	]=	301.72500	/coeff;
    CO2[	152	]=	302.07500	/coeff;
    CO2[	153	]=	302.40000	/coeff;
    CO2[	154	]=	302.70000	/coeff;
    CO2[	155	]=	303.02500	/coeff;
    CO2[	156	]=	303.40000	/coeff;
    CO2[	157	]=	303.77500	/coeff;
    CO2[	158	]=	304.12500	/coeff;
    CO2[	159	]=	304.52500	/coeff;
    CO2[	160	]=	304.97500	/coeff;
    CO2[	161	]=	305.40000	/coeff;
    CO2[	162	]=	305.82500	/coeff;
    CO2[	163	]=	306.30000	/coeff;
    CO2[	164	]=	306.77500	/coeff;
    CO2[	165	]=	307.22500	/coeff;
    CO2[	166	]=	307.70000	/coeff;
    CO2[	167	]=	308.17500	/coeff;
    CO2[	168	]=	308.60000	/coeff;
    CO2[	169	]=	309.00000	/coeff;
    CO2[	170	]=	309.40000	/coeff;
    CO2[	171	]=	309.75000	/coeff;
    CO2[	172	]=	310.00000	/coeff;
    CO2[	173	]=	310.17500	/coeff;
    CO2[	174	]=	310.30000	/coeff;
    CO2[	175	]=	310.37500	/coeff;
    CO2[	176	]=	310.37500	/coeff;
    CO2[	177	]=	310.30000	/coeff;
    CO2[	178	]=	310.20000	/coeff;
    CO2[	179	]=	310.12500	/coeff;
    CO2[	180	]=	310.10000	/coeff;
    CO2[	181	]=	310.12500	/coeff;
    CO2[	182	]=	310.20000	/coeff;
    CO2[	183	]=	310.32500	/coeff;
    CO2[	184	]=	310.50000	/coeff;
    CO2[	185	]=	310.75000	/coeff;
    CO2[	186	]=	311.10000	/coeff;
    CO2[	187	]=	311.50000	/coeff;
    CO2[	188	]=	311.92500	/coeff;
    CO2[	189	]=	312.42500	/coeff;
    CO2[	190	]=	313.00000	/coeff;
    CO2[	191	]=	313.60000	/coeff;
    CO2[	192	]=	314.22500	/coeff;
    CO2[	193	]=	314.84750	/coeff;
    CO2[	194	]=	315.50000	/coeff;
    CO2[	195	]=	316.27250	/coeff;
    CO2[	196	]=	317.07500	/coeff;
    CO2[	197	]=	317.79500	/coeff;
    CO2[	198	]=	318.39750	/coeff;
    CO2[	199	]=	318.92500	/coeff;
    CO2[	200	]=	319.64750	/coeff;
    CO2[	201	]=	320.64750	/coeff;
    CO2[	202	]=	321.60500	/coeff;
    CO2[	203	]=	322.63500	/coeff;
    CO2[	204	]=	323.90250	/coeff;
    CO2[	205	]=	324.98500	/coeff;
    CO2[	206	]=	325.85500	/coeff;
    CO2[	207	]=	327.14000	/coeff;
    CO2[	208	]=	328.67750	/coeff;
    CO2[	209	]=	329.74250	/coeff;
    CO2[	210	]=	330.58500	/coeff;
    CO2[	211	]=	331.74750	/coeff;
    CO2[	212	]=	333.27250	/coeff;
    CO2[	213	]=	334.84750	/coeff;
    CO2[	214	]=	336.52500	/coeff;
    CO2[	215	]=	338.36000	/coeff;
    CO2[	216	]=	339.72750	/coeff;
    CO2[	217	]=	340.79250	/coeff;
    CO2[	218	]=	342.19750	/coeff;
    CO2[	219	]=	343.78250	/coeff;
    CO2[	220	]=	345.28250	/coeff;
    CO2[	221	]=	346.79750	/coeff;
    CO2[	222	]=	348.64500	/coeff;
    CO2[	223	]=	350.73750	/coeff;
    CO2[	224	]=	352.48750	/coeff;
    CO2[	225	]=	353.85500	/coeff;
    CO2[	226	]=	355.01750	/coeff;
    CO2[	227	]=	355.88500	/coeff;
    CO2[	228	]=	356.77750	/coeff;
    CO2[	229	]=	358.12750	/coeff;
    CO2[	230	]=	359.83750	/coeff;
    CO2[	231	]=	361.46250	/coeff;
    CO2[	232	]=	363.15500	/coeff;
    CO2[	233	]=	365.32250	/coeff;
    CO2[	234	]=	367.34750	/coeff;
    CO2[	235	]=	368.86500	/coeff;
    CO2[	236	]=	370.46750	/coeff;
    CO2[	237	]=	372.52250	/coeff;
    CO2[	238	]=	374.76000	/coeff;
    CO2[	239	]=	376.81250	/coeff;
    CO2[	240	]=	378.81250	/coeff;
    CO2[	241	]=	380.82750	/coeff;
    CO2[	242	]=	382.77750	/coeff;
    CO2[	243	]=	384.80000	/coeff;
    CO2[	244	]=	387.00054	/coeff;
    CO2[	245	]=	389.28521	/coeff;
    CO2[	246	]=	391.56252	/coeff;
    CO2[	247	]=	393.84273	/coeff;
    CO2[	248	]=	396.11734	/coeff;
    CO2[	249	]=	398.39568	/coeff;
    CO2[	250	]=	400.68068	/coeff;
    CO2[	251	]=	402.96830	/coeff;
    CO2[	252	]=	405.25182	/coeff;
    CO2[	253	]=	407.52882	/coeff;
    CO2[	254	]=	409.80029	/coeff;
    CO2[	255	]=	412.06783	/coeff;
    CO2[	256	]=	414.32565	/coeff;
    CO2[	257	]=	416.51662	/coeff;
    CO2[	258	]=	418.60322	/coeff;
    CO2[	259	]=	420.60132	/coeff;
    CO2[	260	]=	422.51575	/coeff;
    CO2[	261	]=	424.34901	/coeff;
    CO2[	262	]=	426.09675	/coeff;
    CO2[	263	]=	427.75232	/coeff;
    CO2[	264	]=	429.31381	/coeff;
    CO2[	265	]=	430.78315	/coeff;
    CO2[	266	]=	432.16344	/coeff;
    CO2[	267	]=	433.43618	/coeff;
    CO2[	268	]=	434.59273	/coeff;
    CO2[	269	]=	435.65302	/coeff;
    CO2[	270	]=	436.62804	/coeff;
    CO2[	271	]=	437.52158	/coeff;
    CO2[	272	]=	438.33433	/coeff;
    CO2[	273	]=	439.06015	/coeff;
    CO2[	274	]=	439.69061	/coeff;
    CO2[	275	]=	440.22240	/coeff;
    CO2[	276	]=	440.65666	/coeff;
    CO2[	277	]=	441.02476	/coeff;
    CO2[	278	]=	441.34651	/coeff;
    CO2[	279	]=	441.62100	/coeff;
    CO2[	280	]=	441.86440	/coeff;
    CO2[	281	]=	442.08482	/coeff;
    CO2[	282	]=	442.28340	/coeff;
    CO2[	283	]=	442.45830	/coeff;
    CO2[	284	]=	442.60091	/coeff;
    CO2[	285	]=	442.70046	/coeff;
    CO2[	286	]=	442.75184	/coeff;
    CO2[	287	]=	442.76100	/coeff;
    CO2[	288	]=	442.73417	/coeff;
    CO2[	289	]=	442.66263	/coeff;
    CO2[	290	]=	442.54767	/coeff;
    CO2[	291	]=	442.40642	/coeff;
    CO2[	292	]=	442.24833	/coeff;
    CO2[	293	]=	442.07535	/coeff;
    CO2[	294	]=	441.88625	/coeff;
    CO2[	295	]=	441.67274	/coeff;
    CO2[	296	]=	441.42415	/coeff;
    CO2[	297	]=	441.13450	/coeff;
    CO2[	298	]=	440.80284	/coeff;
    CO2[	299	]=	440.43041	/coeff;
    CO2[	300	]=	440.01021	/coeff;
    CO2[	301	]=	439.54473	/coeff;
    CO2[	302	]=	439.05222	/coeff;
    CO2[	303	]=	438.54291	/coeff;
    CO2[	304	]=	438.01932	/coeff;
    CO2[	305	]=	437.48062	/coeff;
    CO2[	306	]=	436.91878	/coeff;
    CO2[	307	]=	436.34251	/coeff;
    CO2[	308	]=	435.76436	/coeff;
    CO2[	309	]=	435.18189	/coeff;
    CO2[	310	]=	434.59500	/coeff;
    CO2[	311	]=	433.99542	/coeff;
    CO2[	312	]=	433.38456	/coeff;
    CO2[	313	]=	432.77961	/coeff;
    CO2[	314	]=	432.18978	/coeff;
    CO2[	315	]=	431.61659	/coeff;
    CO2[	316	]=	431.05847	/coeff;
    CO2[	317	]=	430.51026	/coeff;
    CO2[	318	]=	429.96413	/coeff;
    CO2[	319	]=	429.41411	/coeff;
    CO2[	320	]=	428.85906	/coeff;
    CO2[	321	]=	428.29910	/coeff;
    CO2[	322	]=	427.72652	/coeff;
    CO2[	323	]=	427.14308	/coeff;
    CO2[	324	]=	426.56607	/coeff;
    CO2[	325	]=	426.00472	/coeff;
    CO2[	326	]=	425.46065	/coeff;
    CO2[	327	]=	424.93745	/coeff;
    CO2[	328	]=	424.43129	/coeff;
    CO2[	329	]=	423.93083	/coeff;
    CO2[	330	]=	423.43058	/coeff;
    CO2[	331	]=	422.92945	/coeff;
    CO2[	332	]=	422.42761	/coeff;
    CO2[	333	]=	421.91753	/coeff;
    CO2[	334	]=	421.40111	/coeff;
    CO2[	335	]=	420.89546	/coeff;
    CO2[	336	]=	420.40998	/coeff;
    CO2[	337	]=	419.94532	/coeff;
    CO2[	338	]=	419.49831	/coeff;
    CO2[	339	]=	419.05981	/coeff;
    CO2[	340	]=	418.61902	/coeff;
    CO2[	341	]=	418.17082	/coeff;
    CO2[	342	]=	417.71454	/coeff;
    CO2[	343	]=	417.25070	/coeff;
    CO2[	344	]=	416.77219	/coeff;
    CO2[	345	]=	416.28127	/coeff;
    CO2[	346	]=	415.79518	/coeff;
    CO2[	347	]=	415.32319	/coeff;
    CO2[	348	]=	414.86696	/coeff;
    CO2[	349	]=	414.42496	/coeff;
    CO2[	350	]=	413.98893	/coeff;
    CO2[	351	]=	413.54867	/coeff;
    CO2[	352	]=	413.09942	/coeff;
    CO2[	353	]=	412.64076	/coeff;
    CO2[	354	]=	412.17338	/coeff;
    CO2[	355	]=	411.69045	/coeff;
    CO2[	356	]=	411.19435	/coeff;
    CO2[	357	]=	410.70228	/coeff;
    CO2[	358	]=	410.22339	/coeff;
    CO2[	359	]=	409.75930	/coeff;
    CO2[	360	]=	409.30847	/coeff;
    CO2[	361	]=	408.86270	/coeff;
    CO2[	362	]=	408.41656	/coeff;
    CO2[	363	]=	407.96956	/coeff;
    CO2[	364	]=	407.52073	/coeff;
    CO2[	365	]=	407.07051	/coeff;
    CO2[	366	]=	406.61189	/coeff;
    CO2[	367	]=	406.14707	/coeff;
    CO2[	368	]=	405.69286	/coeff;
    CO2[	369	]=	405.25809	/coeff;
    CO2[	370	]=	404.84413	/coeff;
    CO2[	371	]=	404.44922	/coeff;
    CO2[	372	]=	404.06507	/coeff;
    CO2[	373	]=	403.68161	/coeff;
    CO2[	374	]=	403.29415	/coeff;
    CO2[	375	]=	402.90226	/coeff;
    CO2[	376	]=	402.50662	/coeff;
    CO2[	377	]=	402.10056	/coeff;
    CO2[	378	]=	401.68653	/coeff;
    CO2[	379	]=	401.28131	/coeff;
    CO2[	380	]=	400.89375	/coeff;
    CO2[	381	]=	400.52523	/coeff;
    CO2[	382	]=	400.17404	/coeff;
    CO2[	383	]=	399.83204	/coeff;
    CO2[	384	]=	399.48930	/coeff;
    CO2[	385	]=	399.14131	/coeff;
    CO2[	386	]=	398.78772	/coeff;
    CO2[	387	]=	398.42927	/coeff;
    CO2[	388	]=	398.05950	/coeff;
    CO2[	389	]=	397.68091	/coeff;
    CO2[	390	]=	397.31021	/coeff;
    CO2[	391	]=	396.95616	/coeff;
    CO2[	392	]=	396.62009	/coeff;
    CO2[	393	]=	396.30030	/coeff;
    CO2[	394	]=	395.98871	/coeff;
    CO2[	395	]=	395.67554	/coeff;
    CO2[	396	]=	395.35634	/coeff;
    CO2[	397	]=	395.03085	/coeff;
    CO2[	398	]=	394.69985	/coeff;
    CO2[	399	]=	394.35700	/coeff;
    CO2[	400	]=	394.00489	/coeff;
    CO2[	401	]=	393.66010	/coeff;
    CO2[	402	]=	393.33128	/coeff;
    CO2[	403	]=	393.01974	/coeff;
    CO2[	404	]=	392.72374	/coeff;
    CO2[	405	]=	392.43525	/coeff;
    CO2[	406	]=	392.14460	/coeff;
    CO2[	407	]=	391.84744	/coeff;
    CO2[	408	]=	391.54354	/coeff;
    CO2[	409	]=	391.23370	/coeff;
    CO2[	410	]=	390.91172	/coeff;
    CO2[	411	]=	390.58024	/coeff;
    CO2[	412	]=	390.25571	/coeff;
    CO2[	413	]=	389.94668	/coeff;
    CO2[	414	]=	389.65441	/coeff;
    CO2[	415	]=	389.37713	/coeff;
    CO2[	416	]=	389.10687	/coeff;
    CO2[	417	]=	388.83404	/coeff;
    CO2[	418	]=	388.55437	/coeff;
    CO2[	419	]=	388.26765	/coeff;
    CO2[	420	]=	387.97473	/coeff;
    CO2[	421	]=	387.66950	/coeff;
    CO2[	422	]=	387.35465	/coeff;
    CO2[	423	]=	387.04651	/coeff;
    CO2[	424	]=	386.75353	/coeff;
    CO2[	425	]=	386.47692	/coeff;
    CO2[	426	]=	386.21487	/coeff;
    CO2[	427	]=	385.95946	/coeff;
    CO2[	428	]=	385.70118	/coeff;
    CO2[	429	]=	385.43582	/coeff;
    CO2[	430	]=	385.16322	/coeff;
    CO2[	431	]=	384.88424	/coeff;
    CO2[	432	]=	384.59286	/coeff;
    CO2[	433	]=	384.29183	/coeff;
    CO2[	434	]=	383.99735	/coeff;
    CO2[	435	]=	383.71778	/coeff;
    CO2[	436	]=	383.45425	/coeff;
    CO2[	437	]=	383.20495	/coeff;
    CO2[	438	]=	382.96197	/coeff;
    CO2[	439	]=	382.71591	/coeff;
    CO2[	440	]=	382.46260	/coeff;
    CO2[	441	]=	382.20191	/coeff;
    CO2[	442	]=	381.93471	/coeff;
    CO2[	443	]=	381.65510	/coeff;
    CO2[	444	]=	381.36585	/coeff;
    CO2[	445	]=	381.08304	/coeff;
    CO2[	446	]=	380.81494	/coeff;
    CO2[	447	]=	380.56263	/coeff;
    CO2[	448	]=	380.32426	/coeff;
    CO2[	449	]=	380.09195	/coeff;
    CO2[	450	]=	379.85638	/coeff;
    CO2[	451	]=	379.61345	/coeff;
    CO2[	452	]=	379.36304	/coeff;
    CO2[	453	]=	379.10604	/coeff;
    CO2[	454	]=	378.83665	/coeff;
    CO2[	455	]=	378.55765	/coeff;
    CO2[	456	]=	378.28503	/coeff;
    CO2[	457	]=	378.02696	/coeff;
    CO2[	458	]=	377.78445	/coeff;
    CO2[	459	]=	377.55563	/coeff;
    CO2[	460	]=	377.33266	/coeff;
    CO2[	461	]=	377.10629	/coeff;
    CO2[	462	]=	376.87246	/coeff;
    CO2[	463	]=	376.63109	/coeff;
    CO2[	464	]=	376.38308	/coeff;
    CO2[	465	]=	376.12271	/coeff;
    CO2[	466	]=	375.85281	/coeff;
    CO2[	467	]=	375.58923	/coeff;
    CO2[	468	]=	375.34006	/coeff;
    CO2[	469	]=	375.10628	/coeff;
    CO2[	470	]=	374.88595	/coeff;
    CO2[	471	]=	374.67128	/coeff;
    CO2[	472	]=	374.45310	/coeff;
    CO2[	473	]=	374.22739	/coeff;
    CO2[	474	]=	373.99410	/coeff;
    CO2[	475	]=	373.75412	/coeff;
    CO2[	476	]=	373.50184	/coeff;
    CO2[	477	]=	373.24011	/coeff;
    CO2[	478	]=	372.98467	/coeff;
    CO2[	479	]=	372.74353	/coeff;
    CO2[	480	]=	372.51759	/coeff;
    CO2[	481	]=	372.30492	/coeff;
    CO2[	482	]=	372.09773	/coeff;
    CO2[	483	]=	371.88692	/coeff;
    CO2[	484	]=	371.66854	/coeff;
    CO2[	485	]=	371.44254	/coeff;
    CO2[	486	]=	371.20984	/coeff;
    CO2[	487	]=	370.96489	/coeff;
    CO2[	488	]=	370.71059	/coeff;
    CO2[	489	]=	370.46256	/coeff;
    CO2[	490	]=	370.22872	/coeff;
    CO2[	491	]=	370.00993	/coeff;
    CO2[	492	]=	369.80422	/coeff;
    CO2[	493	]=	369.60385	/coeff;
    CO2[	494	]=	369.39976	/coeff;
    CO2[	495	]=	369.18806	/coeff;
    CO2[	496	]=	368.96871	/coeff;
    CO2[	497	]=	368.74266	/coeff;
    CO2[	498	]=	368.50442	/coeff;
    CO2[	499	]=	368.25693	/coeff;
    CO2[	500	]=	368.01570	/coeff;
    CO2[	501	]=	367.78857	/coeff;
    CO2[	502	]=	367.57635	/coeff;
    CO2[	503	]=	367.37703	/coeff;
    CO2[	504	]=	367.18290	/coeff;
    CO2[	505	]=	366.98498	/coeff;
    CO2[	506	]=	366.77941	/coeff;
    CO2[	507	]=	366.56619	/coeff;
    CO2[	508	]=	366.34625	/coeff;
    CO2[	509	]=	366.11421	/coeff;
    CO2[	510	]=	365.87300	/coeff;
    CO2[	511	]=	365.63806	/coeff;
    CO2[	512	]=	365.41713	/coeff;
    CO2[	513	]=	365.21098	/coeff;
    CO2[	514	]=	365.01757	/coeff;
    CO2[	515	]=	364.82921	/coeff;
    CO2[	516	]=	364.63699	/coeff;
    CO2[	517	]=	364.43710	/coeff;
    CO2[	518	]=	364.22954	/coeff;
    CO2[	519	]=	364.01526	/coeff;
    CO2[	520	]=	363.78896	/coeff;
    CO2[	521	]=	363.55360	/coeff;
    CO2[	522	]=	363.32451	/coeff;
    CO2[	523	]=	363.10935	/coeff;
    CO2[	524	]=	362.90884	/coeff;
    CO2[	525	]=	362.72091	/coeff;
    CO2[	526	]=	362.53791	/coeff;
    CO2[	527	]=	362.35099	/coeff;
    CO2[	528	]=	362.15637	/coeff;
    CO2[	529	]=	361.95408	/coeff;
    CO2[	530	]=	361.74508	/coeff;
    CO2[	531	]=	361.52413	/coeff;
    CO2[	532	]=	361.29423	/coeff;
    CO2[	533	]=	361.07060	/coeff;
    CO2[	534	]=	360.86083	/coeff;
    CO2[	535	]=	360.66558	/coeff;
    CO2[	536	]=	360.48278	/coeff;
    CO2[	537	]=	360.30479	/coeff;
    CO2[	538	]=	360.12281	/coeff;
    CO2[	539	]=	359.93311	/coeff;
    CO2[	540	]=	359.73574	/coeff;
    CO2[	541	]=	359.53167	/coeff;
    CO2[	542	]=	359.31573	/coeff;
    CO2[	543	]=	359.09095	/coeff;
    CO2[	544	]=	358.87244	/coeff;
    CO2[	545	]=	358.66772	/coeff;
    CO2[	546	]=	358.47742	/coeff;
    CO2[	547	]=	358.29942	/coeff;
    CO2[	548	]=	358.12611	/coeff;
    CO2[	549	]=	357.94876	/coeff;
    CO2[	550	]=	357.76367	/coeff;
    CO2[	551	]=	357.57092	/coeff;
    CO2[	552	]=	357.37148	/coeff;
    CO2[	553	]=	357.16025	/coeff;
    CO2[	554	]=	356.94027	/coeff;
    CO2[	555	]=	356.72659	/coeff;
    CO2[	556	]=	356.52662	/coeff;
    CO2[	557	]=	356.34097	/coeff;
    CO2[	558	]=	356.16748	/coeff;
    CO2[	559	]=	355.99857	/coeff;
    CO2[	560	]=	355.82557	/coeff;
    CO2[	561	]=	355.64482	/coeff;
    CO2[	562	]=	355.45642	/coeff;
    CO2[	563	]=	355.26133	/coeff;
    CO2[	564	]=	355.05453	/coeff;
    CO2[	565	]=	354.83910	/coeff;
    CO2[	566	]=	354.62997	/coeff;
    CO2[	567	]=	354.43449	/coeff;
    CO2[	568	]=	354.25322	/coeff;
    CO2[	569	]=	354.08399	/coeff;
    CO2[	570	]=	353.91923	/coeff;
    CO2[	571	]=	353.75033	/coeff;
    CO2[	572	]=	353.57367	/coeff;
    CO2[	573	]=	353.38936	/coeff;
    CO2[	574	]=	353.19838	/coeff;
    CO2[	575	]=	352.99578	/coeff;
    CO2[	576	]=	352.78464	/coeff;
    CO2[	577	]=	352.57981	/coeff;
    CO2[	578	]=	352.38859	/coeff;
    CO2[	579	]=	352.21147	/coeff;
    CO2[	580	]=	352.04626	/coeff;
    CO2[	581	]=	351.88542	/coeff;
    CO2[	582	]=	351.72039	/coeff;
    CO2[	583	]=	351.54760	/coeff;
    CO2[	584	]=	351.36717	/coeff;
    CO2[	585	]=	351.18007	/coeff;
    CO2[	586	]=	350.98144	/coeff;
    CO2[	587	]=	350.77437	/coeff;
    CO2[	588	]=	350.57364	/coeff;
    CO2[	589	]=	350.38645	/coeff;
    CO2[	590	]=	350.21326	/coeff;
    CO2[	591	]=	350.05186	/coeff;
    CO2[	592	]=	349.89473	/coeff;
    CO2[	593	]=	349.73338	/coeff;
    CO2[	594	]=	349.56425	/coeff;
    CO2[	595	]=	349.38748	/coeff;
    CO2[	596	]=	349.20408	/coeff;
    CO2[	597	]=	349.00921	/coeff;
    CO2[	598	]=	348.80602	/coeff;
    CO2[	599	]=	348.60917	/coeff;
    CO2[	600	]=	348.42581	/coeff;
    CO2[	601	]=	348.25637	/coeff;
    CO2[	602	]=	348.09859	/coeff;
    CO2[	603	]=	347.94498	/coeff;
    CO2[	604	]=	347.78711	/coeff;
    CO2[	605	]=	347.62145	/coeff;
    CO2[	606	]=	347.44817	/coeff;
    CO2[	607	]=	347.26827	/coeff;
    CO2[	608	]=	347.07699	/coeff;
    CO2[	609	]=	346.87749	/coeff;
    CO2[	610	]=	346.68435	/coeff;
    CO2[	611	]=	346.50464	/coeff;
    CO2[	612	]=	346.33875	/coeff;
    CO2[	613	]=	346.18441	/coeff;
    CO2[	614	]=	346.03416	/coeff;
    CO2[	615	]=	345.87960	/coeff;
    CO2[	616	]=	345.71725	/coeff;
    CO2[	617	]=	345.54729	/coeff;
    CO2[	618	]=	345.37072	/coeff;
    CO2[	619	]=	345.18286	/coeff;
    CO2[	620	]=	344.98687	/coeff;
    CO2[	621	]=	344.79727	/coeff;
    CO2[	622	]=	344.62105	/coeff;
    CO2[	623	]=	344.45856	/coeff;
    CO2[	624	]=	344.30750	/coeff;
    CO2[	625	]=	344.16044	/coeff;
    CO2[	626	]=	344.00903	/coeff;
    CO2[	627	]=	343.84983	/coeff;
    CO2[	628	]=	343.68304	/coeff;
    CO2[	629	]=	343.50965	/coeff;
    CO2[	630	]=	343.32505	/coeff;
    CO2[	631	]=	343.13243	/coeff;
    CO2[	632	]=	342.94620	/coeff;
    CO2[	633	]=	342.77331	/coeff;
    CO2[	634	]=	342.61407	/coeff;
    CO2[	635	]=	342.46614	/coeff;
    CO2[	636	]=	342.32213	/coeff;
    CO2[	637	]=	342.17373	/coeff;
    CO2[	638	]=	342.01754	/coeff;
    CO2[	639	]=	341.85376	/coeff;
    CO2[	640	]=	341.68342	/coeff;
    CO2[	641	]=	341.50194	/coeff;
    CO2[	642	]=	341.31253	/coeff;
    CO2[	643	]=	341.12955	/coeff;
    CO2[	644	]=	340.95985	/coeff;
    CO2[	645	]=	340.80371	/coeff;
    CO2[	646	]=	340.65878	/coeff;
    CO2[	647	]=	340.51768	/coeff;
    CO2[	648	]=	340.37215	/coeff;
    CO2[	649	]=	340.21884	/coeff;
    CO2[	650	]=	340.05795	/coeff;
    CO2[	651	]=	339.89052	/coeff;
    CO2[	652	]=	339.71203	/coeff;
    CO2[	653	]=	339.52571	/coeff;
    CO2[	654	]=	339.34583	/coeff;
    CO2[	655	]=	339.17919	/coeff;
    CO2[	656	]=	339.02602	/coeff;
    CO2[	657	]=	338.88397	/coeff;
    CO2[	658	]=	338.74565	/coeff;
    CO2[	659	]=	338.60288	/coeff;
    CO2[	660	]=	338.45232	/coeff;
    CO2[	661	]=	338.29420	/coeff;
    CO2[	662	]=	338.12955	/coeff;
    CO2[	663	]=	337.95392	/coeff;
    CO2[	664	]=	337.77057	/coeff;
    CO2[	665	]=	337.59367	/coeff;
    CO2[	666	]=	337.42997	/coeff;
    CO2[	667	]=	337.27966	/coeff;
    CO2[	668	]=	337.14036	/coeff;
    CO2[	669	]=	337.00472	/coeff;
    CO2[	670	]=	336.86458	/coeff;
    CO2[	671	]=	336.71666	/coeff;
    CO2[	672	]=	336.56120	/coeff;
    CO2[	673	]=	336.39922	/coeff;
    CO2[	674	]=	336.22635	/coeff;
    CO2[	675	]=	336.04585	/coeff;
    CO2[	676	]=	335.87182	/coeff;
    CO2[	677	]=	335.71094	/coeff;
    CO2[	678	]=	335.56338	/coeff;
    CO2[	679	]=	335.42672	/coeff;
    CO2[	680	]=	335.29364	/coeff;
    CO2[	681	]=	335.15604	/coeff;
    CO2[	682	]=	335.01065	/coeff;
    CO2[	683	]=	334.85773	/coeff;
    CO2[	684	]=	334.69833	/coeff;
    CO2[	685	]=	334.52811	/coeff;
    CO2[	686	]=	334.35035	/coeff;
    CO2[	687	]=	334.17908	/coeff;
    CO2[	688	]=	334.02092	/coeff;
    CO2[	689	]=	333.87600	/coeff;
    CO2[	690	]=	333.74189	/coeff;
    CO2[	691	]=	333.61127	/coeff;
    CO2[	692	]=	333.47610	/coeff;
    CO2[	693	]=	333.33315	/coeff;
    CO2[	694	]=	333.18269	/coeff;
    CO2[	695	]=	333.02576	/coeff;
    CO2[	696	]=	332.85808	/coeff;
    CO2[	697	]=	332.68296	/coeff;
    CO2[	698	]=	332.51436	/coeff;
    CO2[	699	]=	332.35883	/coeff;
    CO2[	700	]=	332.21645	/coeff;
    CO2[	701	]=	332.08479	/coeff;
    CO2[	702	]=	331.95654	/coeff;
    CO2[	703	]=	331.82371	/coeff;
    CO2[	704	]=	331.68311	/coeff;
    CO2[	705	]=	331.53500	/coeff;
    CO2[	706	]=	331.38045	/coeff;
    CO2[	707	]=	331.21523	/coeff;
    CO2[	708	]=	331.04267	/coeff;
    CO2[	709	]=	330.87664	/coeff;
    CO2[	710	]=	330.72364	/coeff;
    CO2[	711	]=	330.58372	/coeff;
    CO2[	712	]=	330.45441	/coeff;
    CO2[	713	]=	330.32845	/coeff;
    CO2[	714	]=	330.19788	/coeff;
    CO2[	715	]=	330.05953	/coeff;
    CO2[	716	]=	329.91370	/coeff;
    CO2[	717	]=	329.76144	/coeff;
    CO2[	718	]=	329.59860	/coeff;
    CO2[	719	]=	329.42850	/coeff;
    CO2[	720	]=	329.26495	/coeff;
    CO2[	721	]=	329.11439	/coeff;
    CO2[	722	]=	328.97684	/coeff;
    CO2[	723	]=	328.84981	/coeff;
    CO2[	724	]=	328.72606	/coeff;
    CO2[	725	]=	328.59766	/coeff;
    CO2[	726	]=	328.46149	/coeff;
    CO2[	727	]=	328.31785	/coeff;
    CO2[	728	]=	328.16781	/coeff;
    CO2[	729	]=	328.00726	/coeff;
    CO2[	730	]=	327.83954	/coeff;
    CO2[	731	]=	327.67840	/coeff;
    CO2[	732	]=	327.53021	/coeff;
    CO2[	733	]=	327.39495	/coeff;
    CO2[	734	]=	327.27012	/coeff;
    CO2[	735	]=	327.20980	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
    
}
void setCO2RCP45(double coeff)
{
    CO2[	0	]=	278.05158	/coeff;
    CO2[	1	]=	278.10615	/coeff;
    CO2[	2	]=	278.22039	/coeff;
    CO2[	3	]=	278.34305	/coeff;
    CO2[	4	]=	278.47058	/coeff;
    CO2[	5	]=	278.60047	/coeff;
    CO2[	6	]=	278.73275	/coeff;
    CO2[	7	]=	278.86881	/coeff;
    CO2[	8	]=	279.00907	/coeff;
    CO2[	9	]=	279.15318	/coeff;
    CO2[	10	]=	279.30180	/coeff;
    CO2[	11	]=	279.45680	/coeff;
    CO2[	12	]=	279.61808	/coeff;
    CO2[	13	]=	279.78192	/coeff;
    CO2[	14	]=	279.94320	/coeff;
    CO2[	15	]=	280.09740	/coeff;
    CO2[	16	]=	280.24280	/coeff;
    CO2[	17	]=	280.38168	/coeff;
    CO2[	18	]=	280.51832	/coeff;
    CO2[	19	]=	280.65720	/coeff;
    CO2[	20	]=	280.80260	/coeff;
    CO2[	21	]=	280.95680	/coeff;
    CO2[	22	]=	281.11808	/coeff;
    CO2[	23	]=	281.28192	/coeff;
    CO2[	24	]=	281.44320	/coeff;
    CO2[	25	]=	281.59820	/coeff;
    CO2[	26	]=	281.74682	/coeff;
    CO2[	27	]=	281.89093	/coeff;
    CO2[	28	]=	282.03119	/coeff;
    CO2[	29	]=	282.16725	/coeff;
    CO2[	30	]=	282.29901	/coeff;
    CO2[	31	]=	282.42680	/coeff;
    CO2[	32	]=	282.55093	/coeff;
    CO2[	33	]=	282.67123	/coeff;
    CO2[	34	]=	282.78730	/coeff;
    CO2[	35	]=	282.89901	/coeff;
    CO2[	36	]=	283.00677	/coeff;
    CO2[	37	]=	283.11093	/coeff;
    CO2[	38	]=	283.21129	/coeff;
    CO2[	39	]=	283.30737	/coeff;
    CO2[	40	]=	283.39963	/coeff;
    CO2[	41	]=	283.48978	/coeff;
    CO2[	42	]=	283.57796	/coeff;
    CO2[	43	]=	283.66116	/coeff;
    CO2[	44	]=	283.73511	/coeff;
    CO2[	45	]=	283.79676	/coeff;
    CO2[	46	]=	283.84667	/coeff;
    CO2[	47	]=	283.88853	/coeff;
    CO2[	48	]=	283.92613	/coeff;
    CO2[	49	]=	283.96267	/coeff;
    CO2[	50	]=	284.00107	/coeff;
    CO2[	51	]=	284.04267	/coeff;
    CO2[	52	]=	284.08613	/coeff;
    CO2[	53	]=	284.12853	/coeff;
    CO2[	54	]=	284.16667	/coeff;
    CO2[	55	]=	284.19820	/coeff;
    CO2[	56	]=	284.22333	/coeff;
    CO2[	57	]=	284.24427	/coeff;
    CO2[	58	]=	284.26307	/coeff;
    CO2[	59	]=	284.28133	/coeff;
    CO2[	60	]=	284.30027	/coeff;
    CO2[	61	]=	284.32000	/coeff;
    CO2[	62	]=	284.34000	/coeff;
    CO2[	63	]=	284.36000	/coeff;
    CO2[	64	]=	284.38000	/coeff;
    CO2[	65	]=	284.40000	/coeff;
    CO2[	66	]=	284.38500	/coeff;
    CO2[	67	]=	284.28000	/coeff;
    CO2[	68	]=	284.12500	/coeff;
    CO2[	69	]=	283.97500	/coeff;
    CO2[	70	]=	283.82500	/coeff;
    CO2[	71	]=	283.67500	/coeff;
    CO2[	72	]=	283.52500	/coeff;
    CO2[	73	]=	283.42500	/coeff;
    CO2[	74	]=	283.40000	/coeff;
    CO2[	75	]=	283.40000	/coeff;
    CO2[	76	]=	283.42500	/coeff;
    CO2[	77	]=	283.50000	/coeff;
    CO2[	78	]=	283.60000	/coeff;
    CO2[	79	]=	283.72500	/coeff;
    CO2[	80	]=	283.90000	/coeff;
    CO2[	81	]=	284.07500	/coeff;
    CO2[	82	]=	284.22500	/coeff;
    CO2[	83	]=	284.40000	/coeff;
    CO2[	84	]=	284.57500	/coeff;
    CO2[	85	]=	284.72500	/coeff;
    CO2[	86	]=	284.87500	/coeff;
    CO2[	87	]=	285.00000	/coeff;
    CO2[	88	]=	285.12500	/coeff;
    CO2[	89	]=	285.27500	/coeff;
    CO2[	90	]=	285.42500	/coeff;
    CO2[	91	]=	285.57500	/coeff;
    CO2[	92	]=	285.72500	/coeff;
    CO2[	93	]=	285.90000	/coeff;
    CO2[	94	]=	286.07500	/coeff;
    CO2[	95	]=	286.22500	/coeff;
    CO2[	96	]=	286.37500	/coeff;
    CO2[	97	]=	286.50000	/coeff;
    CO2[	98	]=	286.62500	/coeff;
    CO2[	99	]=	286.77500	/coeff;
    CO2[	100	]=	286.90000	/coeff;
    CO2[	101	]=	287.00000	/coeff;
    CO2[	102	]=	287.10000	/coeff;
    CO2[	103	]=	287.22500	/coeff;
    CO2[	104	]=	287.37500	/coeff;
    CO2[	105	]=	287.52500	/coeff;
    CO2[	106	]=	287.70000	/coeff;
    CO2[	107	]=	287.90000	/coeff;
    CO2[	108	]=	288.12500	/coeff;
    CO2[	109	]=	288.40000	/coeff;
    CO2[	110	]=	288.70000	/coeff;
    CO2[	111	]=	289.02500	/coeff;
    CO2[	112	]=	289.40000	/coeff;
    CO2[	113	]=	289.80000	/coeff;
    CO2[	114	]=	290.22500	/coeff;
    CO2[	115	]=	290.70000	/coeff;
    CO2[	116	]=	291.20000	/coeff;
    CO2[	117	]=	291.67500	/coeff;
    CO2[	118	]=	292.12500	/coeff;
    CO2[	119	]=	292.57500	/coeff;
    CO2[	120	]=	292.97500	/coeff;
    CO2[	121	]=	293.30000	/coeff;
    CO2[	122	]=	293.57500	/coeff;
    CO2[	123	]=	293.80000	/coeff;
    CO2[	124	]=	294.00000	/coeff;
    CO2[	125	]=	294.17500	/coeff;
    CO2[	126	]=	294.32500	/coeff;
    CO2[	127	]=	294.47500	/coeff;
    CO2[	128	]=	294.60000	/coeff;
    CO2[	129	]=	294.70000	/coeff;
    CO2[	130	]=	294.80000	/coeff;
    CO2[	131	]=	294.90000	/coeff;
    CO2[	132	]=	295.02500	/coeff;
    CO2[	133	]=	295.22500	/coeff;
    CO2[	134	]=	295.50000	/coeff;
    CO2[	135	]=	295.80000	/coeff;
    CO2[	136	]=	296.12500	/coeff;
    CO2[	137	]=	296.47500	/coeff;
    CO2[	138	]=	296.82500	/coeff;
    CO2[	139	]=	297.20000	/coeff;
    CO2[	140	]=	297.62500	/coeff;
    CO2[	141	]=	298.07500	/coeff;
    CO2[	142	]=	298.50000	/coeff;
    CO2[	143	]=	298.90000	/coeff;
    CO2[	144	]=	299.30000	/coeff;
    CO2[	145	]=	299.70000	/coeff;
    CO2[	146	]=	300.07500	/coeff;
    CO2[	147	]=	300.42500	/coeff;
    CO2[	148	]=	300.77500	/coeff;
    CO2[	149	]=	301.10000	/coeff;
    CO2[	150	]=	301.40000	/coeff;
    CO2[	151	]=	301.72500	/coeff;
    CO2[	152	]=	302.07500	/coeff;
    CO2[	153	]=	302.40000	/coeff;
    CO2[	154	]=	302.70000	/coeff;
    CO2[	155	]=	303.02500	/coeff;
    CO2[	156	]=	303.40000	/coeff;
    CO2[	157	]=	303.77500	/coeff;
    CO2[	158	]=	304.12500	/coeff;
    CO2[	159	]=	304.52500	/coeff;
    CO2[	160	]=	304.97500	/coeff;
    CO2[	161	]=	305.40000	/coeff;
    CO2[	162	]=	305.82500	/coeff;
    CO2[	163	]=	306.30000	/coeff;
    CO2[	164	]=	306.77500	/coeff;
    CO2[	165	]=	307.22500	/coeff;
    CO2[	166	]=	307.70000	/coeff;
    CO2[	167	]=	308.17500	/coeff;
    CO2[	168	]=	308.60000	/coeff;
    CO2[	169	]=	309.00000	/coeff;
    CO2[	170	]=	309.40000	/coeff;
    CO2[	171	]=	309.75000	/coeff;
    CO2[	172	]=	310.00000	/coeff;
    CO2[	173	]=	310.17500	/coeff;
    CO2[	174	]=	310.30000	/coeff;
    CO2[	175	]=	310.37500	/coeff;
    CO2[	176	]=	310.37500	/coeff;
    CO2[	177	]=	310.30000	/coeff;
    CO2[	178	]=	310.20000	/coeff;
    CO2[	179	]=	310.12500	/coeff;
    CO2[	180	]=	310.10000	/coeff;
    CO2[	181	]=	310.12500	/coeff;
    CO2[	182	]=	310.20000	/coeff;
    CO2[	183	]=	310.32500	/coeff;
    CO2[	184	]=	310.50000	/coeff;
    CO2[	185	]=	310.75000	/coeff;
    CO2[	186	]=	311.10000	/coeff;
    CO2[	187	]=	311.50000	/coeff;
    CO2[	188	]=	311.92500	/coeff;
    CO2[	189	]=	312.42500	/coeff;
    CO2[	190	]=	313.00000	/coeff;
    CO2[	191	]=	313.60000	/coeff;
    CO2[	192	]=	314.22500	/coeff;
    CO2[	193	]=	314.84750	/coeff;
    CO2[	194	]=	315.50000	/coeff;
    CO2[	195	]=	316.27250	/coeff;
    CO2[	196	]=	317.07500	/coeff;
    CO2[	197	]=	317.79500	/coeff;
    CO2[	198	]=	318.39750	/coeff;
    CO2[	199	]=	318.92500	/coeff;
    CO2[	200	]=	319.64750	/coeff;
    CO2[	201	]=	320.64750	/coeff;
    CO2[	202	]=	321.60500	/coeff;
    CO2[	203	]=	322.63500	/coeff;
    CO2[	204	]=	323.90250	/coeff;
    CO2[	205	]=	324.98500	/coeff;
    CO2[	206	]=	325.85500	/coeff;
    CO2[	207	]=	327.14000	/coeff;
    CO2[	208	]=	328.67750	/coeff;
    CO2[	209	]=	329.74250	/coeff;
    CO2[	210	]=	330.58500	/coeff;
    CO2[	211	]=	331.74750	/coeff;
    CO2[	212	]=	333.27250	/coeff;
    CO2[	213	]=	334.84750	/coeff;
    CO2[	214	]=	336.52500	/coeff;
    CO2[	215	]=	338.36000	/coeff;
    CO2[	216	]=	339.72750	/coeff;
    CO2[	217	]=	340.79250	/coeff;
    CO2[	218	]=	342.19750	/coeff;
    CO2[	219	]=	343.78250	/coeff;
    CO2[	220	]=	345.28250	/coeff;
    CO2[	221	]=	346.79750	/coeff;
    CO2[	222	]=	348.64500	/coeff;
    CO2[	223	]=	350.73750	/coeff;
    CO2[	224	]=	352.48750	/coeff;
    CO2[	225	]=	353.85500	/coeff;
    CO2[	226	]=	355.01750	/coeff;
    CO2[	227	]=	355.88500	/coeff;
    CO2[	228	]=	356.77750	/coeff;
    CO2[	229	]=	358.12750	/coeff;
    CO2[	230	]=	359.83750	/coeff;
    CO2[	231	]=	361.46250	/coeff;
    CO2[	232	]=	363.15500	/coeff;
    CO2[	233	]=	365.32250	/coeff;
    CO2[	234	]=	367.34750	/coeff;
    CO2[	235	]=	368.86500	/coeff;
    CO2[	236	]=	370.46750	/coeff;
    CO2[	237	]=	372.52250	/coeff;
    CO2[	238	]=	374.76000	/coeff;
    CO2[	239	]=	376.81250	/coeff;
    CO2[	240	]=	378.81250	/coeff;
    CO2[	241	]=	380.82750	/coeff;
    CO2[	242	]=	382.77750	/coeff;
    CO2[	243	]=	384.80000	/coeff;
    CO2[	244	]=	386.95160	/coeff;
    CO2[	245	]=	389.12785	/coeff;
    CO2[	246	]=	391.27357	/coeff;
    CO2[	247	]=	393.42110	/coeff;
    CO2[	248	]=	395.58283	/coeff;
    CO2[	249	]=	397.76408	/coeff;
    CO2[	250	]=	399.96631	/coeff;
    CO2[	251	]=	402.18432	/coeff;
    CO2[	252	]=	404.41077	/coeff;
    CO2[	253	]=	406.64292	/coeff;
    CO2[	254	]=	408.88170	/coeff;
    CO2[	255	]=	411.12868	/coeff;
    CO2[	256	]=	413.37804	/coeff;
    CO2[	257	]=	415.63944	/coeff;
    CO2[	258	]=	417.93551	/coeff;
    CO2[	259	]=	420.27395	/coeff;
    CO2[	260	]=	422.65593	/coeff;
    CO2[	261	]=	425.07983	/coeff;
    CO2[	262	]=	427.53791	/coeff;
    CO2[	263	]=	430.02060	/coeff;
    CO2[	264	]=	432.52340	/coeff;
    CO2[	265	]=	435.04594	/coeff;
    CO2[	266	]=	437.58886	/coeff;
    CO2[	267	]=	440.13137	/coeff;
    CO2[	268	]=	442.66419	/coeff;
    CO2[	269	]=	445.20699	/coeff;
    CO2[	270	]=	447.76978	/coeff;
    CO2[	271	]=	450.35539	/coeff;
    CO2[	272	]=	452.96337	/coeff;
    CO2[	273	]=	455.58649	/coeff;
    CO2[	274	]=	458.21520	/coeff;
    CO2[	275	]=	460.84499	/coeff;
    CO2[	276	]=	463.47549	/coeff;
    CO2[	277	]=	466.09336	/coeff;
    CO2[	278	]=	468.67807	/coeff;
    CO2[	279	]=	471.23389	/coeff;
    CO2[	280	]=	473.78031	/coeff;
    CO2[	281	]=	476.32819	/coeff;
    CO2[	282	]=	478.88085	/coeff;
    CO2[	283	]=	481.43826	/coeff;
    CO2[	284	]=	483.99308	/coeff;
    CO2[	285	]=	486.53532	/coeff;
    CO2[	286	]=	489.06035	/coeff;
    CO2[	287	]=	491.53558	/coeff;
    CO2[	288	]=	493.93186	/coeff;
    CO2[	289	]=	496.24365	/coeff;
    CO2[	290	]=	498.47436	/coeff;
    CO2[	291	]=	500.64502	/coeff;
    CO2[	292	]=	502.76788	/coeff;
    CO2[	293	]=	504.84729	/coeff;
    CO2[	294	]=	506.88408	/coeff;
    CO2[	295	]=	508.87135	/coeff;
    CO2[	296	]=	510.79905	/coeff;
    CO2[	297	]=	512.64717	/coeff;
    CO2[	298	]=	514.40151	/coeff;
    CO2[	299	]=	516.06461	/coeff;
    CO2[	300	]=	517.62854	/coeff;
    CO2[	301	]=	519.09606	/coeff;
    CO2[	302	]=	520.48828	/coeff;
    CO2[	303	]=	521.81772	/coeff;
    CO2[	304	]=	523.08871	/coeff;
    CO2[	305	]=	524.30217	/coeff;
    CO2[	306	]=	525.45089	/coeff;
    CO2[	307	]=	526.50901	/coeff;
    CO2[	308	]=	527.45707	/coeff;
    CO2[	309	]=	528.29593	/coeff;
    CO2[	310	]=	529.02718	/coeff;
    CO2[	311	]=	529.64253	/coeff;
    CO2[	312	]=	530.14419	/coeff;
    CO2[	313	]=	530.55341	/coeff;
    CO2[	314	]=	530.88313	/coeff;
    CO2[	315	]=	531.13797	/coeff;
    CO2[	316	]=	531.31935	/coeff;
    CO2[	317	]=	531.48991	/coeff;
    CO2[	318	]=	531.70213	/coeff;
    CO2[	319	]=	531.94208	/coeff;
    CO2[	320	]=	532.20472	/coeff;
    CO2[	321	]=	532.48672	/coeff;
    CO2[	322	]=	532.77553	/coeff;
    CO2[	323	]=	533.06978	/coeff;
    CO2[	324	]=	533.38792	/coeff;
    CO2[	325	]=	533.74072	/coeff;
    CO2[	326	]=	534.13086	/coeff;
    CO2[	327	]=	534.55754	/coeff;
    CO2[	328	]=	535.01142	/coeff;
    CO2[	329	]=	535.47962	/coeff;
    CO2[	330	]=	535.95487	/coeff;
    CO2[	331	]=	536.43510	/coeff;
    CO2[	332	]=	536.91986	/coeff;
    CO2[	333	]=	537.39855	/coeff;
    CO2[	334	]=	537.87136	/coeff;
    CO2[	335	]=	538.35830	/coeff;
    CO2[	336	]=	538.87150	/coeff;
    CO2[	337	]=	539.38819	/coeff;
    CO2[	338	]=	539.88381	/coeff;
    CO2[	339	]=	540.35213	/coeff;
    CO2[	340	]=	540.78203	/coeff;
    CO2[	341	]=	541.16804	/coeff;
    CO2[	342	]=	541.50962	/coeff;
    CO2[	343	]=	541.80769	/coeff;
    CO2[	344	]=	542.05261	/coeff;
    CO2[	345	]=	542.24555	/coeff;
    CO2[	346	]=	542.40767	/coeff;
    CO2[	347	]=	542.55941	/coeff;
    CO2[	348	]=	542.71221	/coeff;
    CO2[	349	]=	542.86612	/coeff;
    CO2[	350	]=	543.01262	/coeff;
    CO2[	351	]=	543.13926	/coeff;
    CO2[	352	]=	543.23925	/coeff;
    CO2[	353	]=	543.31105	/coeff;
    CO2[	354	]=	543.35475	/coeff;
    CO2[	355	]=	543.35993	/coeff;
    CO2[	356	]=	543.32712	/coeff;
    CO2[	357	]=	543.28815	/coeff;
    CO2[	358	]=	543.26597	/coeff;
    CO2[	359	]=	543.26382	/coeff;
    CO2[	360	]=	543.28162	/coeff;
    CO2[	361	]=	543.31031	/coeff;
    CO2[	362	]=	543.33700	/coeff;
    CO2[	363	]=	543.35452	/coeff;
    CO2[	364	]=	543.36102	/coeff;
    CO2[	365	]=	543.35628	/coeff;
    CO2[	366	]=	543.32954	/coeff;
    CO2[	367	]=	543.28277	/coeff;
    CO2[	368	]=	543.23814	/coeff;
    CO2[	369	]=	543.20814	/coeff;
    CO2[	370	]=	543.19691	/coeff;
    CO2[	371	]=	543.20476	/coeff;
    CO2[	372	]=	543.22301	/coeff;
    CO2[	373	]=	543.23901	/coeff;
    CO2[	374	]=	543.24580	/coeff;
    CO2[	375	]=	543.24169	/coeff;
    CO2[	376	]=	543.22663	/coeff;
    CO2[	377	]=	543.18977	/coeff;
    CO2[	378	]=	543.13128	/coeff;
    CO2[	379	]=	543.07193	/coeff;
    CO2[	380	]=	543.02451	/coeff;
    CO2[	381	]=	542.99340	/coeff;
    CO2[	382	]=	542.97911	/coeff;
    CO2[	383	]=	542.97309	/coeff;
    CO2[	384	]=	542.96279	/coeff;
    CO2[	385	]=	542.95532	/coeff;
    CO2[	386	]=	542.95532	/coeff;
    CO2[	387	]=	542.95532	/coeff;
    CO2[	388	]=	542.95532	/coeff;
    CO2[	389	]=	542.95532	/coeff;
    CO2[	390	]=	542.95532	/coeff;
    CO2[	391	]=	542.95532	/coeff;
    CO2[	392	]=	542.95532	/coeff;
    CO2[	393	]=	542.95532	/coeff;
    CO2[	394	]=	542.95532	/coeff;
    CO2[	395	]=	542.95532	/coeff;
    CO2[	396	]=	542.95532	/coeff;
    CO2[	397	]=	542.95532	/coeff;
    CO2[	398	]=	542.95532	/coeff;
    CO2[	399	]=	542.95532	/coeff;
    CO2[	400	]=	542.95532	/coeff;
    CO2[	401	]=	542.95532	/coeff;
    CO2[	402	]=	542.95532	/coeff;
    CO2[	403	]=	542.95532	/coeff;
    CO2[	404	]=	542.95532	/coeff;
    CO2[	405	]=	542.95532	/coeff;
    CO2[	406	]=	542.95532	/coeff;
    CO2[	407	]=	542.95532	/coeff;
    CO2[	408	]=	542.95532	/coeff;
    CO2[	409	]=	542.95532	/coeff;
    CO2[	410	]=	542.95532	/coeff;
    CO2[	411	]=	542.95532	/coeff;
    CO2[	412	]=	542.95532	/coeff;
    CO2[	413	]=	542.95532	/coeff;
    CO2[	414	]=	542.95532	/coeff;
    CO2[	415	]=	542.95532	/coeff;
    CO2[	416	]=	542.95532	/coeff;
    CO2[	417	]=	542.95532	/coeff;
    CO2[	418	]=	542.95532	/coeff;
    CO2[	419	]=	542.95532	/coeff;
    CO2[	420	]=	542.95532	/coeff;
    CO2[	421	]=	542.95532	/coeff;
    CO2[	422	]=	542.95532	/coeff;
    CO2[	423	]=	542.95532	/coeff;
    CO2[	424	]=	542.95532	/coeff;
    CO2[	425	]=	542.95532	/coeff;
    CO2[	426	]=	542.95532	/coeff;
    CO2[	427	]=	542.95532	/coeff;
    CO2[	428	]=	542.95532	/coeff;
    CO2[	429	]=	542.95532	/coeff;
    CO2[	430	]=	542.95532	/coeff;
    CO2[	431	]=	542.95532	/coeff;
    CO2[	432	]=	542.95532	/coeff;
    CO2[	433	]=	542.95532	/coeff;
    CO2[	434	]=	542.95532	/coeff;
    CO2[	435	]=	542.95532	/coeff;
    CO2[	436	]=	542.95532	/coeff;
    CO2[	437	]=	542.95532	/coeff;
    CO2[	438	]=	542.95532	/coeff;
    CO2[	439	]=	542.95532	/coeff;
    CO2[	440	]=	542.95532	/coeff;
    CO2[	441	]=	542.95532	/coeff;
    CO2[	442	]=	542.95532	/coeff;
    CO2[	443	]=	542.95532	/coeff;
    CO2[	444	]=	542.95532	/coeff;
    CO2[	445	]=	542.95532	/coeff;
    CO2[	446	]=	542.95532	/coeff;
    CO2[	447	]=	542.95532	/coeff;
    CO2[	448	]=	542.95532	/coeff;
    CO2[	449	]=	542.95532	/coeff;
    CO2[	450	]=	542.95532	/coeff;
    CO2[	451	]=	542.95532	/coeff;
    CO2[	452	]=	542.95532	/coeff;
    CO2[	453	]=	542.95532	/coeff;
    CO2[	454	]=	542.95532	/coeff;
    CO2[	455	]=	542.95532	/coeff;
    CO2[	456	]=	542.95532	/coeff;
    CO2[	457	]=	542.95532	/coeff;
    CO2[	458	]=	542.95532	/coeff;
    CO2[	459	]=	542.95532	/coeff;
    CO2[	460	]=	542.95532	/coeff;
    CO2[	461	]=	542.95532	/coeff;
    CO2[	462	]=	542.95532	/coeff;
    CO2[	463	]=	542.95532	/coeff;
    CO2[	464	]=	542.95532	/coeff;
    CO2[	465	]=	542.95532	/coeff;
    CO2[	466	]=	542.95532	/coeff;
    CO2[	467	]=	542.95532	/coeff;
    CO2[	468	]=	542.95532	/coeff;
    CO2[	469	]=	542.95532	/coeff;
    CO2[	470	]=	542.95532	/coeff;
    CO2[	471	]=	542.95532	/coeff;
    CO2[	472	]=	542.95532	/coeff;
    CO2[	473	]=	542.95532	/coeff;
    CO2[	474	]=	542.95532	/coeff;
    CO2[	475	]=	542.95532	/coeff;
    CO2[	476	]=	542.95532	/coeff;
    CO2[	477	]=	542.95532	/coeff;
    CO2[	478	]=	542.95532	/coeff;
    CO2[	479	]=	542.95532	/coeff;
    CO2[	480	]=	542.95532	/coeff;
    CO2[	481	]=	542.95532	/coeff;
    CO2[	482	]=	542.95532	/coeff;
    CO2[	483	]=	542.95532	/coeff;
    CO2[	484	]=	542.95532	/coeff;
    CO2[	485	]=	542.95532	/coeff;
    CO2[	486	]=	542.95532	/coeff;
    CO2[	487	]=	542.95532	/coeff;
    CO2[	488	]=	542.95532	/coeff;
    CO2[	489	]=	542.95532	/coeff;
    CO2[	490	]=	542.95532	/coeff;
    CO2[	491	]=	542.95532	/coeff;
    CO2[	492	]=	542.95532	/coeff;
    CO2[	493	]=	542.95532	/coeff;
    CO2[	494	]=	542.95532	/coeff;
    CO2[	495	]=	542.95532	/coeff;
    CO2[	496	]=	542.95532	/coeff;
    CO2[	497	]=	542.95532	/coeff;
    CO2[	498	]=	542.95532	/coeff;
    CO2[	499	]=	542.95532	/coeff;
    CO2[	500	]=	542.95532	/coeff;
    CO2[	501	]=	542.95532	/coeff;
    CO2[	502	]=	542.95532	/coeff;
    CO2[	503	]=	542.95532	/coeff;
    CO2[	504	]=	542.95532	/coeff;
    CO2[	505	]=	542.95532	/coeff;
    CO2[	506	]=	542.95532	/coeff;
    CO2[	507	]=	542.95532	/coeff;
    CO2[	508	]=	542.95532	/coeff;
    CO2[	509	]=	542.95532	/coeff;
    CO2[	510	]=	542.95532	/coeff;
    CO2[	511	]=	542.95532	/coeff;
    CO2[	512	]=	542.95532	/coeff;
    CO2[	513	]=	542.95532	/coeff;
    CO2[	514	]=	542.95532	/coeff;
    CO2[	515	]=	542.95532	/coeff;
    CO2[	516	]=	542.95532	/coeff;
    CO2[	517	]=	542.95532	/coeff;
    CO2[	518	]=	542.95532	/coeff;
    CO2[	519	]=	542.95532	/coeff;
    CO2[	520	]=	542.95532	/coeff;
    CO2[	521	]=	542.95532	/coeff;
    CO2[	522	]=	542.95532	/coeff;
    CO2[	523	]=	542.95532	/coeff;
    CO2[	524	]=	542.95532	/coeff;
    CO2[	525	]=	542.95532	/coeff;
    CO2[	526	]=	542.95532	/coeff;
    CO2[	527	]=	542.95532	/coeff;
    CO2[	528	]=	542.95532	/coeff;
    CO2[	529	]=	542.95532	/coeff;
    CO2[	530	]=	542.95532	/coeff;
    CO2[	531	]=	542.95532	/coeff;
    CO2[	532	]=	542.95532	/coeff;
    CO2[	533	]=	542.95532	/coeff;
    CO2[	534	]=	542.95532	/coeff;
    CO2[	535	]=	542.95532	/coeff;
    CO2[	536	]=	542.95532	/coeff;
    CO2[	537	]=	542.95532	/coeff;
    CO2[	538	]=	542.95532	/coeff;
    CO2[	539	]=	542.95532	/coeff;
    CO2[	540	]=	542.95532	/coeff;
    CO2[	541	]=	542.95532	/coeff;
    CO2[	542	]=	542.95532	/coeff;
    CO2[	543	]=	542.95532	/coeff;
    CO2[	544	]=	542.95532	/coeff;
    CO2[	545	]=	542.95532	/coeff;
    CO2[	546	]=	542.95532	/coeff;
    CO2[	547	]=	542.95532	/coeff;
    CO2[	548	]=	542.95532	/coeff;
    CO2[	549	]=	542.95532	/coeff;
    CO2[	550	]=	542.95532	/coeff;
    CO2[	551	]=	542.95532	/coeff;
    CO2[	552	]=	542.95532	/coeff;
    CO2[	553	]=	542.95532	/coeff;
    CO2[	554	]=	542.95532	/coeff;
    CO2[	555	]=	542.95532	/coeff;
    CO2[	556	]=	542.95532	/coeff;
    CO2[	557	]=	542.95532	/coeff;
    CO2[	558	]=	542.95532	/coeff;
    CO2[	559	]=	542.95532	/coeff;
    CO2[	560	]=	542.95532	/coeff;
    CO2[	561	]=	542.95532	/coeff;
    CO2[	562	]=	542.95532	/coeff;
    CO2[	563	]=	542.95532	/coeff;
    CO2[	564	]=	542.95532	/coeff;
    CO2[	565	]=	542.95532	/coeff;
    CO2[	566	]=	542.95532	/coeff;
    CO2[	567	]=	542.95532	/coeff;
    CO2[	568	]=	542.95532	/coeff;
    CO2[	569	]=	542.95532	/coeff;
    CO2[	570	]=	542.95532	/coeff;
    CO2[	571	]=	542.95532	/coeff;
    CO2[	572	]=	542.95532	/coeff;
    CO2[	573	]=	542.95532	/coeff;
    CO2[	574	]=	542.95532	/coeff;
    CO2[	575	]=	542.95532	/coeff;
    CO2[	576	]=	542.95532	/coeff;
    CO2[	577	]=	542.95532	/coeff;
    CO2[	578	]=	542.95532	/coeff;
    CO2[	579	]=	542.95532	/coeff;
    CO2[	580	]=	542.95532	/coeff;
    CO2[	581	]=	542.95532	/coeff;
    CO2[	582	]=	542.95532	/coeff;
    CO2[	583	]=	542.95532	/coeff;
    CO2[	584	]=	542.95532	/coeff;
    CO2[	585	]=	542.95532	/coeff;
    CO2[	586	]=	542.95532	/coeff;
    CO2[	587	]=	542.95532	/coeff;
    CO2[	588	]=	542.95532	/coeff;
    CO2[	589	]=	542.95532	/coeff;
    CO2[	590	]=	542.95532	/coeff;
    CO2[	591	]=	542.95532	/coeff;
    CO2[	592	]=	542.95532	/coeff;
    CO2[	593	]=	542.95532	/coeff;
    CO2[	594	]=	542.95532	/coeff;
    CO2[	595	]=	542.95532	/coeff;
    CO2[	596	]=	542.95532	/coeff;
    CO2[	597	]=	542.95532	/coeff;
    CO2[	598	]=	542.95532	/coeff;
    CO2[	599	]=	542.95532	/coeff;
    CO2[	600	]=	542.95532	/coeff;
    CO2[	601	]=	542.95532	/coeff;
    CO2[	602	]=	542.95532	/coeff;
    CO2[	603	]=	542.95532	/coeff;
    CO2[	604	]=	542.95532	/coeff;
    CO2[	605	]=	542.95532	/coeff;
    CO2[	606	]=	542.95532	/coeff;
    CO2[	607	]=	542.95532	/coeff;
    CO2[	608	]=	542.95532	/coeff;
    CO2[	609	]=	542.95532	/coeff;
    CO2[	610	]=	542.95532	/coeff;
    CO2[	611	]=	542.95532	/coeff;
    CO2[	612	]=	542.95532	/coeff;
    CO2[	613	]=	542.95532	/coeff;
    CO2[	614	]=	542.95532	/coeff;
    CO2[	615	]=	542.95532	/coeff;
    CO2[	616	]=	542.95532	/coeff;
    CO2[	617	]=	542.95532	/coeff;
    CO2[	618	]=	542.95532	/coeff;
    CO2[	619	]=	542.95532	/coeff;
    CO2[	620	]=	542.95532	/coeff;
    CO2[	621	]=	542.95532	/coeff;
    CO2[	622	]=	542.95532	/coeff;
    CO2[	623	]=	542.95532	/coeff;
    CO2[	624	]=	542.95532	/coeff;
    CO2[	625	]=	542.95532	/coeff;
    CO2[	626	]=	542.95532	/coeff;
    CO2[	627	]=	542.95532	/coeff;
    CO2[	628	]=	542.95532	/coeff;
    CO2[	629	]=	542.95532	/coeff;
    CO2[	630	]=	542.95532	/coeff;
    CO2[	631	]=	542.95532	/coeff;
    CO2[	632	]=	542.95532	/coeff;
    CO2[	633	]=	542.95532	/coeff;
    CO2[	634	]=	542.95532	/coeff;
    CO2[	635	]=	542.95532	/coeff;
    CO2[	636	]=	542.95532	/coeff;
    CO2[	637	]=	542.95532	/coeff;
    CO2[	638	]=	542.95532	/coeff;
    CO2[	639	]=	542.95532	/coeff;
    CO2[	640	]=	542.95532	/coeff;
    CO2[	641	]=	542.95532	/coeff;
    CO2[	642	]=	542.95532	/coeff;
    CO2[	643	]=	542.95532	/coeff;
    CO2[	644	]=	542.95532	/coeff;
    CO2[	645	]=	542.95532	/coeff;
    CO2[	646	]=	542.95532	/coeff;
    CO2[	647	]=	542.95532	/coeff;
    CO2[	648	]=	542.95532	/coeff;
    CO2[	649	]=	542.95532	/coeff;
    CO2[	650	]=	542.95532	/coeff;
    CO2[	651	]=	542.95532	/coeff;
    CO2[	652	]=	542.95532	/coeff;
    CO2[	653	]=	542.95532	/coeff;
    CO2[	654	]=	542.95532	/coeff;
    CO2[	655	]=	542.95532	/coeff;
    CO2[	656	]=	542.95532	/coeff;
    CO2[	657	]=	542.95532	/coeff;
    CO2[	658	]=	542.95532	/coeff;
    CO2[	659	]=	542.95532	/coeff;
    CO2[	660	]=	542.95532	/coeff;
    CO2[	661	]=	542.95532	/coeff;
    CO2[	662	]=	542.95532	/coeff;
    CO2[	663	]=	542.95532	/coeff;
    CO2[	664	]=	542.95532	/coeff;
    CO2[	665	]=	542.95532	/coeff;
    CO2[	666	]=	542.95532	/coeff;
    CO2[	667	]=	542.95532	/coeff;
    CO2[	668	]=	542.95532	/coeff;
    CO2[	669	]=	542.95532	/coeff;
    CO2[	670	]=	542.95532	/coeff;
    CO2[	671	]=	542.95532	/coeff;
    CO2[	672	]=	542.95532	/coeff;
    CO2[	673	]=	542.95532	/coeff;
    CO2[	674	]=	542.95532	/coeff;
    CO2[	675	]=	542.95532	/coeff;
    CO2[	676	]=	542.95532	/coeff;
    CO2[	677	]=	542.95532	/coeff;
    CO2[	678	]=	542.95532	/coeff;
    CO2[	679	]=	542.95532	/coeff;
    CO2[	680	]=	542.95532	/coeff;
    CO2[	681	]=	542.95532	/coeff;
    CO2[	682	]=	542.95532	/coeff;
    CO2[	683	]=	542.95532	/coeff;
    CO2[	684	]=	542.95532	/coeff;
    CO2[	685	]=	542.95532	/coeff;
    CO2[	686	]=	542.95532	/coeff;
    CO2[	687	]=	542.95532	/coeff;
    CO2[	688	]=	542.95532	/coeff;
    CO2[	689	]=	542.95532	/coeff;
    CO2[	690	]=	542.95532	/coeff;
    CO2[	691	]=	542.95532	/coeff;
    CO2[	692	]=	542.95532	/coeff;
    CO2[	693	]=	542.95532	/coeff;
    CO2[	694	]=	542.95532	/coeff;
    CO2[	695	]=	542.95532	/coeff;
    CO2[	696	]=	542.95532	/coeff;
    CO2[	697	]=	542.95532	/coeff;
    CO2[	698	]=	542.95532	/coeff;
    CO2[	699	]=	542.95532	/coeff;
    CO2[	700	]=	542.95532	/coeff;
    CO2[	701	]=	542.95532	/coeff;
    CO2[	702	]=	542.95532	/coeff;
    CO2[	703	]=	542.95532	/coeff;
    CO2[	704	]=	542.95532	/coeff;
    CO2[	705	]=	542.95532	/coeff;
    CO2[	706	]=	542.95532	/coeff;
    CO2[	707	]=	542.95532	/coeff;
    CO2[	708	]=	542.95532	/coeff;
    CO2[	709	]=	542.95532	/coeff;
    CO2[	710	]=	542.95532	/coeff;
    CO2[	711	]=	542.95532	/coeff;
    CO2[	712	]=	542.95532	/coeff;
    CO2[	713	]=	542.95532	/coeff;
    CO2[	714	]=	542.95532	/coeff;
    CO2[	715	]=	542.95532	/coeff;
    CO2[	716	]=	542.95532	/coeff;
    CO2[	717	]=	542.95532	/coeff;
    CO2[	718	]=	542.95532	/coeff;
    CO2[	719	]=	542.95532	/coeff;
    CO2[	720	]=	542.95532	/coeff;
    CO2[	721	]=	542.95532	/coeff;
    CO2[	722	]=	542.95532	/coeff;
    CO2[	723	]=	542.95532	/coeff;
    CO2[	724	]=	542.95532	/coeff;
    CO2[	725	]=	542.95532	/coeff;
    CO2[	726	]=	542.95532	/coeff;
    CO2[	727	]=	542.95532	/coeff;
    CO2[	728	]=	542.95532	/coeff;
    CO2[	729	]=	542.95532	/coeff;
    CO2[	730	]=	542.95532	/coeff;
    CO2[	731	]=	542.95532	/coeff;
    CO2[	732	]=	542.95532	/coeff;
    CO2[	733	]=	542.95532	/coeff;
    CO2[	734	]=	542.95532	/coeff;
    CO2[	735	]=	542.95532	/coeff;
    
    
    for(int i = 736; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
}

void setCO2RCP45_plusGCB(double coeff)
{
    CO2[    0    ]=    278.05158    /coeff;
    CO2[    1    ]=    278.10615    /coeff;
    CO2[    2    ]=    278.22039    /coeff;
    CO2[    3    ]=    278.34305    /coeff;
    CO2[    4    ]=    278.47058    /coeff;
    CO2[    5    ]=    278.60047    /coeff;
    CO2[    6    ]=    278.73275    /coeff;
    CO2[    7    ]=    278.86881    /coeff;
    CO2[    8    ]=    279.00907    /coeff;
    CO2[    9    ]=    279.15318    /coeff;
    CO2[    10    ]=    279.30180    /coeff;
    CO2[    11    ]=    279.45680    /coeff;
    CO2[    12    ]=    279.61808    /coeff;
    CO2[    13    ]=    279.78192    /coeff;
    CO2[    14    ]=    279.94320    /coeff;
    CO2[    15    ]=    280.09740    /coeff;
    CO2[    16    ]=    280.24280    /coeff;
    CO2[    17    ]=    280.38168    /coeff;
    CO2[    18    ]=    280.51832    /coeff;
    CO2[    19    ]=    280.65720    /coeff;
    CO2[    20    ]=    280.80260    /coeff;
    CO2[    21    ]=    280.95680    /coeff;
    CO2[    22    ]=    281.11808    /coeff;
    CO2[    23    ]=    281.28192    /coeff;
    CO2[    24    ]=    281.44320    /coeff;
    CO2[    25    ]=    281.59820    /coeff;
    CO2[    26    ]=    281.74682    /coeff;
    CO2[    27    ]=    281.89093    /coeff;
    CO2[    28    ]=    282.03119    /coeff;
    CO2[    29    ]=    282.16725    /coeff;
    CO2[    30    ]=    282.29901    /coeff;
    CO2[    31    ]=    282.42680    /coeff;
    CO2[    32    ]=    282.55093    /coeff;
    CO2[    33    ]=    282.67123    /coeff;
    CO2[    34    ]=    282.78730    /coeff;
    CO2[    35    ]=    282.89901    /coeff;
    CO2[    36    ]=    283.00677    /coeff;
    CO2[    37    ]=    283.11093    /coeff;
    CO2[    38    ]=    283.21129    /coeff;
    CO2[    39    ]=    283.30737    /coeff;
    CO2[    40    ]=    283.39963    /coeff;
    CO2[    41    ]=    283.48978    /coeff;
    CO2[    42    ]=    283.57796    /coeff;
    CO2[    43    ]=    283.66116    /coeff;
    CO2[    44    ]=    283.73511    /coeff;
    CO2[    45    ]=    283.79676    /coeff;
    CO2[    46    ]=    283.84667    /coeff;
    CO2[    47    ]=    283.88853    /coeff;
    CO2[    48    ]=    283.92613    /coeff;
    CO2[    49    ]=    283.96267    /coeff;
    CO2[    50    ]=    284.00107    /coeff;
    CO2[    51    ]=    284.04267    /coeff;
    CO2[    52    ]=    284.08613    /coeff;
    CO2[    53    ]=    284.12853    /coeff;
    CO2[    54    ]=    284.16667    /coeff;
    CO2[    55    ]=    284.19820    /coeff;
    CO2[    56    ]=    284.22333    /coeff;
    CO2[    57    ]=    284.24427    /coeff;
    CO2[    58    ]=    284.26307    /coeff;
    CO2[    59    ]=    284.28133    /coeff;
    CO2[    60    ]=    284.30027    /coeff;
    CO2[    61    ]=    284.32000    /coeff;
    CO2[    62    ]=    284.34000    /coeff;
    CO2[    63    ]=    284.36000    /coeff;
    CO2[    64    ]=    284.38000    /coeff;
    CO2[    65    ]=    284.40000    /coeff;
    CO2[    66    ]=    284.38500    /coeff;
    CO2[    67    ]=    284.28000    /coeff;
    CO2[    68    ]=    284.12500    /coeff;
    CO2[    69    ]=    283.97500    /coeff;
    CO2[    70    ]=    283.82500    /coeff;
    CO2[    71    ]=    283.67500    /coeff;
    CO2[    72    ]=    283.52500    /coeff;
    CO2[    73    ]=    283.42500    /coeff;
    CO2[    74    ]=    283.40000    /coeff;
    CO2[    75    ]=    283.40000    /coeff;
    CO2[    76    ]=    283.42500    /coeff;
    CO2[    77    ]=    283.50000    /coeff;
    CO2[    78    ]=    283.60000    /coeff;
    CO2[    79    ]=    283.72500    /coeff;
    CO2[    80    ]=    283.90000    /coeff;
    CO2[    81    ]=    284.07500    /coeff;
    CO2[    82    ]=    284.22500    /coeff;
    CO2[    83    ]=    284.40000    /coeff;
    CO2[    84    ]=    284.57500    /coeff;
    CO2[    85    ]=    284.72500    /coeff;
    CO2[    86    ]=    284.87500    /coeff;
    CO2[    87    ]=    285.00000    /coeff;
    CO2[    88    ]=    285.12500    /coeff;
    CO2[    89    ]=    285.27500    /coeff;
    CO2[    90    ]=    285.42500    /coeff;
    CO2[    91    ]=    285.57500    /coeff;
    CO2[    92    ]=    285.72500    /coeff;
    CO2[    93    ]=    285.90000    /coeff;
    CO2[    94    ]=    286.07500    /coeff;
    CO2[    95    ]=    286.22500    /coeff;
    CO2[    96    ]=    286.37500    /coeff;
    CO2[    97    ]=    286.50000    /coeff;
    CO2[    98    ]=    286.62500    /coeff;
    CO2[    99    ]=    286.77500    /coeff;
    CO2[    100    ]=    286.90000    /coeff;
    CO2[    101    ]=    287.00000    /coeff;
    CO2[    102    ]=    287.10000    /coeff;
    CO2[    103    ]=    287.22500    /coeff;
    CO2[    104    ]=    287.37500    /coeff;
    CO2[    105    ]=    287.52500    /coeff;
    CO2[    106    ]=    287.70000    /coeff;
    CO2[    107    ]=    287.90000    /coeff;
    CO2[    108    ]=    288.12500    /coeff;
    CO2[    109    ]=    288.40000    /coeff;
    CO2[    110    ]=    288.70000    /coeff;
    CO2[    111    ]=    289.02500    /coeff;
    CO2[    112    ]=    289.40000    /coeff;
    CO2[    113    ]=    289.80000    /coeff;
    CO2[    114    ]=    290.22500    /coeff;
    CO2[    115    ]=    290.70000    /coeff;
    CO2[    116    ]=    291.20000    /coeff;
    CO2[    117    ]=    291.67500    /coeff;
    CO2[    118    ]=    292.12500    /coeff;
    CO2[    119    ]=    292.57500    /coeff;
    CO2[    120    ]=    292.97500    /coeff;
    CO2[    121    ]=    293.30000    /coeff;
    CO2[    122    ]=    293.57500    /coeff;
    CO2[    123    ]=    293.80000    /coeff;
    CO2[    124    ]=    294.00000    /coeff;
    CO2[    125    ]=    294.17500    /coeff;
    CO2[    126    ]=    294.32500    /coeff;
    CO2[    127    ]=    294.47500    /coeff;
    CO2[    128    ]=    294.60000    /coeff;
    CO2[    129    ]=    294.70000    /coeff;
    CO2[    130    ]=    294.80000    /coeff;
    CO2[    131    ]=    294.90000    /coeff;
    CO2[    132    ]=    295.02500    /coeff;
    CO2[    133    ]=    295.22500    /coeff;
    CO2[    134    ]=    295.50000    /coeff;
    CO2[    135    ]=    295.80000    /coeff;
    CO2[    136    ]=    296.12500    /coeff;
    CO2[    137    ]=    296.47500    /coeff;
    CO2[    138    ]=    296.82500    /coeff;
    CO2[    139    ]=    297.20000    /coeff;
    CO2[    140    ]=    297.62500    /coeff;
    CO2[    141    ]=    298.07500    /coeff;
    CO2[    142    ]=    298.50000    /coeff;
    CO2[    143    ]=    298.90000    /coeff;
    CO2[    144    ]=    299.30000    /coeff;
    CO2[    145    ]=    299.70000    /coeff;
    CO2[    146    ]=    300.07500    /coeff;
    CO2[    147    ]=    300.42500    /coeff;
    CO2[    148    ]=    300.77500    /coeff;
    CO2[    149    ]=    301.10000    /coeff;
    CO2[    150    ]=    301.40000    /coeff;
    CO2[    151    ]=    301.72500    /coeff;
    CO2[    152    ]=    302.07500    /coeff;
    CO2[    153    ]=    302.40000    /coeff;
    CO2[    154    ]=    302.70000    /coeff;
    CO2[    155    ]=    303.02500    /coeff;
    CO2[    156    ]=    303.40000    /coeff;
    CO2[    157    ]=    303.77500    /coeff;
    CO2[    158    ]=    304.12500    /coeff;
    CO2[    159    ]=    304.52500    /coeff;
    CO2[    160    ]=    304.97500    /coeff;
    CO2[    161    ]=    305.40000    /coeff;
    CO2[    162    ]=    305.82500    /coeff;
    CO2[    163    ]=    306.30000    /coeff;
    CO2[    164    ]=    306.77500    /coeff;
    CO2[    165    ]=    307.22500    /coeff;
    CO2[    166    ]=    307.70000    /coeff;
    CO2[    167    ]=    308.17500    /coeff;
    CO2[    168    ]=    308.60000    /coeff;
    CO2[    169    ]=    309.00000    /coeff;
    CO2[    170    ]=    309.40000    /coeff;
    CO2[    171    ]=    309.75000    /coeff;
    CO2[    172    ]=    310.00000    /coeff;
    CO2[    173    ]=    310.17500    /coeff;
    CO2[    174    ]=    310.30000    /coeff;
    CO2[    175    ]=    310.37500    /coeff;
    CO2[    176    ]=    310.37500    /coeff;
    CO2[    177    ]=    310.30000    /coeff;
    CO2[    178    ]=    310.20000    /coeff;
    CO2[    179    ]=    310.12500    /coeff;
    CO2[    180    ]=    310.10000    /coeff;
    CO2[    181    ]=    310.12500    /coeff;
    CO2[    182    ]=    310.20000    /coeff;
    CO2[    183    ]=    310.32500    /coeff;
    CO2[    184    ]=    310.50000    /coeff;
    CO2[    185    ]=    310.75000    /coeff;
    CO2[    186    ]=    311.10000    /coeff;
    CO2[    187    ]=    311.50000    /coeff;
    CO2[    188    ]=    311.92500    /coeff;
    CO2[    189    ]=    312.42500    /coeff;
    CO2[    190    ]=    313.00000    /coeff;
    CO2[    191    ]=    313.60000    /coeff;
    CO2[    192    ]=    314.22500    /coeff;
    CO2[    193    ]=    314.84750    /coeff;
    CO2[    194    ]=    315.50000    /coeff;
    CO2[    195    ]=    316.27250    /coeff;
    CO2[    196    ]=    317.07500    /coeff;
    CO2[    197    ]=    317.79500    /coeff;
    CO2[    198    ]=    318.39750    /coeff;
    CO2[    199    ]=    318.92500    /coeff;
    CO2[    200    ]=    319.64750    /coeff;
    CO2[    201    ]=    320.64750    /coeff;
    CO2[    202    ]=    321.60500    /coeff;
    CO2[    203    ]=    322.63500    /coeff;
    CO2[    204    ]=    323.90250    /coeff;
    CO2[    205    ]=    324.98500    /coeff;
    CO2[    206    ]=    325.85500    /coeff;
    CO2[    207    ]=    327.14000    /coeff;
    CO2[    208    ]=    328.67750    /coeff;
    CO2[    209    ]=    329.74250    /coeff;
    CO2[    210    ]=    330.58500    /coeff;
    CO2[    211    ]=    331.74750    /coeff;
    CO2[    212    ]=    333.27250    /coeff;
    CO2[    213    ]=    334.84750    /coeff;
    CO2[    214    ]=    336.52500    /coeff;
    CO2[    215    ]=    338.36000    /coeff;
    CO2[    216    ]=    339.72750    /coeff;
    CO2[    217    ]=    340.79250    /coeff;
    CO2[    218    ]=    342.19750    /coeff;
    CO2[    219    ]=    343.78250    /coeff;
    CO2[    220    ]=    345.28250    /coeff;
    CO2[    221    ]=    346.79750    /coeff;
    CO2[    222    ]=    348.64500    /coeff;
    CO2[    223    ]=    350.73750    /coeff;
    CO2[    224    ]=    352.48750    /coeff;
    CO2[    225    ]=    353.85500    /coeff;
    CO2[    226    ]=    355.01750    /coeff;
    CO2[    227    ]=    355.88500    /coeff;
    CO2[    228    ]=    356.77750    /coeff;
    CO2[    229    ]=    358.12750    /coeff;
    CO2[    230    ]=    359.83750    /coeff;
    CO2[    231    ]=    361.46250    /coeff;
    CO2[    232    ]=    363.15500    /coeff;
    CO2[    233    ]=    365.32250    /coeff;
    CO2[    234    ]=    367.34750    /coeff;
    CO2[    235    ]=    368.86500    /coeff;
    CO2[    236    ]=    370.46750    /coeff;
    CO2[    237    ]=    372.52250    /coeff;
    CO2[    238    ]=    374.76000    /coeff;
    CO2[    239    ]=    376.81250    /coeff;
    CO2[    240    ]=    378.81250    /coeff;
    CO2[    241    ]=    CO2[240] + 3.75;//380.82750    /coeff;
    CO2[    242    ]=    CO2[241] + 4.43;//382.77750    /coeff;
    CO2[    243    ]=    CO2[242] + 3.75;//384.80000    /coeff;
    CO2[    244    ]=    CO2[243] + 3.43;//386.95160    /coeff;
    CO2[    245    ]=    CO2[244] + 5.17;//389.12785    /coeff;
    CO2[    246    ]=    CO2[245] + 3.58;//391.27357    /coeff;
    CO2[    247    ]=    CO2[246] + 5.05;//393.42110    /coeff;
    CO2[    248    ]=    CO2[247] + 5.13;//395.58283    /coeff;
    CO2[    249    ]=    CO2[248] + 4.32;//397.76408    /coeff;
    CO2[    250    ]=    CO2[249] + 6.19;//399.96631    /coeff;
    CO2[    251    ]=    CO2[250] + 6.04;//402.18432    /coeff;
    CO2[    252    ]=    CO2[251] + 4.64;//404.41077    /coeff;
    CO2[    253    ]=    406.64292    /coeff;
    CO2[    254    ]=    408.88170    /coeff;
    CO2[    255    ]=    411.12868    /coeff;
    CO2[    256    ]=    413.37804    /coeff;
    CO2[    257    ]=    415.63944    /coeff;
    CO2[    258    ]=    417.93551    /coeff;
    CO2[    259    ]=    420.27395    /coeff;
    CO2[    260    ]=    422.65593    /coeff;
    CO2[    261    ]=    425.07983    /coeff;
    CO2[    262    ]=    427.53791    /coeff;
    CO2[    263    ]=    430.02060    /coeff;
    CO2[    264    ]=    432.52340    /coeff;
    CO2[    265    ]=    435.04594    /coeff;
    CO2[    266    ]=    437.58886    /coeff;
    CO2[    267    ]=    440.13137    /coeff;
    CO2[    268    ]=    442.66419    /coeff;
    CO2[    269    ]=    445.20699    /coeff;
    CO2[    270    ]=    447.76978    /coeff;
    CO2[    271    ]=    450.35539    /coeff;
    CO2[    272    ]=    452.96337    /coeff;
    CO2[    273    ]=    455.58649    /coeff;
    CO2[    274    ]=    458.21520    /coeff;
    CO2[    275    ]=    460.84499    /coeff;
    CO2[    276    ]=    463.47549    /coeff;
    CO2[    277    ]=    466.09336    /coeff;
    CO2[    278    ]=    468.67807    /coeff;
    CO2[    279    ]=    471.23389    /coeff;
    CO2[    280    ]=    473.78031    /coeff;
    CO2[    281    ]=    476.32819    /coeff;
    CO2[    282    ]=    478.88085    /coeff;
    CO2[    283    ]=    481.43826    /coeff;
    CO2[    284    ]=    483.99308    /coeff;
    CO2[    285    ]=    486.53532    /coeff;
    CO2[    286    ]=    489.06035    /coeff;
    CO2[    287    ]=    491.53558    /coeff;
    CO2[    288    ]=    493.93186    /coeff;
    CO2[    289    ]=    496.24365    /coeff;
    CO2[    290    ]=    498.47436    /coeff;
    CO2[    291    ]=    500.64502    /coeff;
    CO2[    292    ]=    502.76788    /coeff;
    CO2[    293    ]=    504.84729    /coeff;
    CO2[    294    ]=    506.88408    /coeff;
    CO2[    295    ]=    508.87135    /coeff;
    CO2[    296    ]=    510.79905    /coeff;
    CO2[    297    ]=    512.64717    /coeff;
    CO2[    298    ]=    514.40151    /coeff;
    CO2[    299    ]=    516.06461    /coeff;
    CO2[    300    ]=    517.62854    /coeff;
    CO2[    301    ]=    519.09606    /coeff;
    CO2[    302    ]=    520.48828    /coeff;
    CO2[    303    ]=    521.81772    /coeff;
    CO2[    304    ]=    523.08871    /coeff;
    CO2[    305    ]=    524.30217    /coeff;
    CO2[    306    ]=    525.45089    /coeff;
    CO2[    307    ]=    526.50901    /coeff;
    CO2[    308    ]=    527.45707    /coeff;
    CO2[    309    ]=    528.29593    /coeff;
    CO2[    310    ]=    529.02718    /coeff;
    CO2[    311    ]=    529.64253    /coeff;
    CO2[    312    ]=    530.14419    /coeff;
    CO2[    313    ]=    530.55341    /coeff;
    CO2[    314    ]=    530.88313    /coeff;
    CO2[    315    ]=    531.13797    /coeff;
    CO2[    316    ]=    531.31935    /coeff;
    CO2[    317    ]=    531.48991    /coeff;
    CO2[    318    ]=    531.70213    /coeff;
    CO2[    319    ]=    531.94208    /coeff;
    CO2[    320    ]=    532.20472    /coeff;
    CO2[    321    ]=    532.48672    /coeff;
    CO2[    322    ]=    532.77553    /coeff;
    CO2[    323    ]=    533.06978    /coeff;
    CO2[    324    ]=    533.38792    /coeff;
    CO2[    325    ]=    533.74072    /coeff;
    CO2[    326    ]=    534.13086    /coeff;
    CO2[    327    ]=    534.55754    /coeff;
    CO2[    328    ]=    535.01142    /coeff;
    CO2[    329    ]=    535.47962    /coeff;
    CO2[    330    ]=    535.95487    /coeff;
    CO2[    331    ]=    536.43510    /coeff;
    CO2[    332    ]=    536.91986    /coeff;
    CO2[    333    ]=    537.39855    /coeff;
    CO2[    334    ]=    537.87136    /coeff;
    CO2[    335    ]=    538.35830    /coeff;
    CO2[    336    ]=    538.87150    /coeff;
    CO2[    337    ]=    539.38819    /coeff;
    CO2[    338    ]=    539.88381    /coeff;
    CO2[    339    ]=    540.35213    /coeff;
    CO2[    340    ]=    540.78203    /coeff;
    CO2[    341    ]=    541.16804    /coeff;
    CO2[    342    ]=    541.50962    /coeff;
    CO2[    343    ]=    541.80769    /coeff;
    CO2[    344    ]=    542.05261    /coeff;
    CO2[    345    ]=    542.24555    /coeff;
    CO2[    346    ]=    542.40767    /coeff;
    CO2[    347    ]=    542.55941    /coeff;
    CO2[    348    ]=    542.71221    /coeff;
    CO2[    349    ]=    542.86612    /coeff;
    CO2[    350    ]=    543.01262    /coeff;
    CO2[    351    ]=    543.13926    /coeff;
    CO2[    352    ]=    543.23925    /coeff;
    CO2[    353    ]=    543.31105    /coeff;
    CO2[    354    ]=    543.35475    /coeff;
    CO2[    355    ]=    543.35993    /coeff;
    CO2[    356    ]=    543.32712    /coeff;
    CO2[    357    ]=    543.28815    /coeff;
    CO2[    358    ]=    543.26597    /coeff;
    CO2[    359    ]=    543.26382    /coeff;
    CO2[    360    ]=    543.28162    /coeff;
    CO2[    361    ]=    543.31031    /coeff;
    CO2[    362    ]=    543.33700    /coeff;
    CO2[    363    ]=    543.35452    /coeff;
    CO2[    364    ]=    543.36102    /coeff;
    CO2[    365    ]=    543.35628    /coeff;
    CO2[    366    ]=    543.32954    /coeff;
    CO2[    367    ]=    543.28277    /coeff;
    CO2[    368    ]=    543.23814    /coeff;
    CO2[    369    ]=    543.20814    /coeff;
    CO2[    370    ]=    543.19691    /coeff;
    CO2[    371    ]=    543.20476    /coeff;
    CO2[    372    ]=    543.22301    /coeff;
    CO2[    373    ]=    543.23901    /coeff;
    CO2[    374    ]=    543.24580    /coeff;
    CO2[    375    ]=    543.24169    /coeff;
    CO2[    376    ]=    543.22663    /coeff;
    CO2[    377    ]=    543.18977    /coeff;
    CO2[    378    ]=    543.13128    /coeff;
    CO2[    379    ]=    543.07193    /coeff;
    CO2[    380    ]=    543.02451    /coeff;
    CO2[    381    ]=    542.99340    /coeff;
    CO2[    382    ]=    542.97911    /coeff;
    CO2[    383    ]=    542.97309    /coeff;
    CO2[    384    ]=    542.96279    /coeff;
    CO2[    385    ]=    542.95532    /coeff;
    CO2[    386    ]=    542.95532    /coeff;
    CO2[    387    ]=    542.95532    /coeff;
    CO2[    388    ]=    542.95532    /coeff;
    CO2[    389    ]=    542.95532    /coeff;
    CO2[    390    ]=    542.95532    /coeff;
    CO2[    391    ]=    542.95532    /coeff;
    CO2[    392    ]=    542.95532    /coeff;
    CO2[    393    ]=    542.95532    /coeff;
    CO2[    394    ]=    542.95532    /coeff;
    CO2[    395    ]=    542.95532    /coeff;
    CO2[    396    ]=    542.95532    /coeff;
    CO2[    397    ]=    542.95532    /coeff;
    CO2[    398    ]=    542.95532    /coeff;
    CO2[    399    ]=    542.95532    /coeff;
    CO2[    400    ]=    542.95532    /coeff;
    CO2[    401    ]=    542.95532    /coeff;
    CO2[    402    ]=    542.95532    /coeff;
    CO2[    403    ]=    542.95532    /coeff;
    CO2[    404    ]=    542.95532    /coeff;
    CO2[    405    ]=    542.95532    /coeff;
    CO2[    406    ]=    542.95532    /coeff;
    CO2[    407    ]=    542.95532    /coeff;
    CO2[    408    ]=    542.95532    /coeff;
    CO2[    409    ]=    542.95532    /coeff;
    CO2[    410    ]=    542.95532    /coeff;
    CO2[    411    ]=    542.95532    /coeff;
    CO2[    412    ]=    542.95532    /coeff;
    CO2[    413    ]=    542.95532    /coeff;
    CO2[    414    ]=    542.95532    /coeff;
    CO2[    415    ]=    542.95532    /coeff;
    CO2[    416    ]=    542.95532    /coeff;
    CO2[    417    ]=    542.95532    /coeff;
    CO2[    418    ]=    542.95532    /coeff;
    CO2[    419    ]=    542.95532    /coeff;
    CO2[    420    ]=    542.95532    /coeff;
    CO2[    421    ]=    542.95532    /coeff;
    CO2[    422    ]=    542.95532    /coeff;
    CO2[    423    ]=    542.95532    /coeff;
    CO2[    424    ]=    542.95532    /coeff;
    CO2[    425    ]=    542.95532    /coeff;
    CO2[    426    ]=    542.95532    /coeff;
    CO2[    427    ]=    542.95532    /coeff;
    CO2[    428    ]=    542.95532    /coeff;
    CO2[    429    ]=    542.95532    /coeff;
    CO2[    430    ]=    542.95532    /coeff;
    CO2[    431    ]=    542.95532    /coeff;
    CO2[    432    ]=    542.95532    /coeff;
    CO2[    433    ]=    542.95532    /coeff;
    CO2[    434    ]=    542.95532    /coeff;
    CO2[    435    ]=    542.95532    /coeff;
    CO2[    436    ]=    542.95532    /coeff;
    CO2[    437    ]=    542.95532    /coeff;
    CO2[    438    ]=    542.95532    /coeff;
    CO2[    439    ]=    542.95532    /coeff;
    CO2[    440    ]=    542.95532    /coeff;
    CO2[    441    ]=    542.95532    /coeff;
    CO2[    442    ]=    542.95532    /coeff;
    CO2[    443    ]=    542.95532    /coeff;
    CO2[    444    ]=    542.95532    /coeff;
    CO2[    445    ]=    542.95532    /coeff;
    CO2[    446    ]=    542.95532    /coeff;
    CO2[    447    ]=    542.95532    /coeff;
    CO2[    448    ]=    542.95532    /coeff;
    CO2[    449    ]=    542.95532    /coeff;
    CO2[    450    ]=    542.95532    /coeff;
    CO2[    451    ]=    542.95532    /coeff;
    CO2[    452    ]=    542.95532    /coeff;
    CO2[    453    ]=    542.95532    /coeff;
    CO2[    454    ]=    542.95532    /coeff;
    CO2[    455    ]=    542.95532    /coeff;
    CO2[    456    ]=    542.95532    /coeff;
    CO2[    457    ]=    542.95532    /coeff;
    CO2[    458    ]=    542.95532    /coeff;
    CO2[    459    ]=    542.95532    /coeff;
    CO2[    460    ]=    542.95532    /coeff;
    CO2[    461    ]=    542.95532    /coeff;
    CO2[    462    ]=    542.95532    /coeff;
    CO2[    463    ]=    542.95532    /coeff;
    CO2[    464    ]=    542.95532    /coeff;
    CO2[    465    ]=    542.95532    /coeff;
    CO2[    466    ]=    542.95532    /coeff;
    CO2[    467    ]=    542.95532    /coeff;
    CO2[    468    ]=    542.95532    /coeff;
    CO2[    469    ]=    542.95532    /coeff;
    CO2[    470    ]=    542.95532    /coeff;
    CO2[    471    ]=    542.95532    /coeff;
    CO2[    472    ]=    542.95532    /coeff;
    CO2[    473    ]=    542.95532    /coeff;
    CO2[    474    ]=    542.95532    /coeff;
    CO2[    475    ]=    542.95532    /coeff;
    CO2[    476    ]=    542.95532    /coeff;
    CO2[    477    ]=    542.95532    /coeff;
    CO2[    478    ]=    542.95532    /coeff;
    CO2[    479    ]=    542.95532    /coeff;
    CO2[    480    ]=    542.95532    /coeff;
    CO2[    481    ]=    542.95532    /coeff;
    CO2[    482    ]=    542.95532    /coeff;
    CO2[    483    ]=    542.95532    /coeff;
    CO2[    484    ]=    542.95532    /coeff;
    CO2[    485    ]=    542.95532    /coeff;
    CO2[    486    ]=    542.95532    /coeff;
    CO2[    487    ]=    542.95532    /coeff;
    CO2[    488    ]=    542.95532    /coeff;
    CO2[    489    ]=    542.95532    /coeff;
    CO2[    490    ]=    542.95532    /coeff;
    CO2[    491    ]=    542.95532    /coeff;
    CO2[    492    ]=    542.95532    /coeff;
    CO2[    493    ]=    542.95532    /coeff;
    CO2[    494    ]=    542.95532    /coeff;
    CO2[    495    ]=    542.95532    /coeff;
    CO2[    496    ]=    542.95532    /coeff;
    CO2[    497    ]=    542.95532    /coeff;
    CO2[    498    ]=    542.95532    /coeff;
    CO2[    499    ]=    542.95532    /coeff;
    CO2[    500    ]=    542.95532    /coeff;
    CO2[    501    ]=    542.95532    /coeff;
    CO2[    502    ]=    542.95532    /coeff;
    CO2[    503    ]=    542.95532    /coeff;
    CO2[    504    ]=    542.95532    /coeff;
    CO2[    505    ]=    542.95532    /coeff;
    CO2[    506    ]=    542.95532    /coeff;
    CO2[    507    ]=    542.95532    /coeff;
    CO2[    508    ]=    542.95532    /coeff;
    CO2[    509    ]=    542.95532    /coeff;
    CO2[    510    ]=    542.95532    /coeff;
    CO2[    511    ]=    542.95532    /coeff;
    CO2[    512    ]=    542.95532    /coeff;
    CO2[    513    ]=    542.95532    /coeff;
    CO2[    514    ]=    542.95532    /coeff;
    CO2[    515    ]=    542.95532    /coeff;
    CO2[    516    ]=    542.95532    /coeff;
    CO2[    517    ]=    542.95532    /coeff;
    CO2[    518    ]=    542.95532    /coeff;
    CO2[    519    ]=    542.95532    /coeff;
    CO2[    520    ]=    542.95532    /coeff;
    CO2[    521    ]=    542.95532    /coeff;
    CO2[    522    ]=    542.95532    /coeff;
    CO2[    523    ]=    542.95532    /coeff;
    CO2[    524    ]=    542.95532    /coeff;
    CO2[    525    ]=    542.95532    /coeff;
    CO2[    526    ]=    542.95532    /coeff;
    CO2[    527    ]=    542.95532    /coeff;
    CO2[    528    ]=    542.95532    /coeff;
    CO2[    529    ]=    542.95532    /coeff;
    CO2[    530    ]=    542.95532    /coeff;
    CO2[    531    ]=    542.95532    /coeff;
    CO2[    532    ]=    542.95532    /coeff;
    CO2[    533    ]=    542.95532    /coeff;
    CO2[    534    ]=    542.95532    /coeff;
    CO2[    535    ]=    542.95532    /coeff;
    CO2[    536    ]=    542.95532    /coeff;
    CO2[    537    ]=    542.95532    /coeff;
    CO2[    538    ]=    542.95532    /coeff;
    CO2[    539    ]=    542.95532    /coeff;
    CO2[    540    ]=    542.95532    /coeff;
    CO2[    541    ]=    542.95532    /coeff;
    CO2[    542    ]=    542.95532    /coeff;
    CO2[    543    ]=    542.95532    /coeff;
    CO2[    544    ]=    542.95532    /coeff;
    CO2[    545    ]=    542.95532    /coeff;
    CO2[    546    ]=    542.95532    /coeff;
    CO2[    547    ]=    542.95532    /coeff;
    CO2[    548    ]=    542.95532    /coeff;
    CO2[    549    ]=    542.95532    /coeff;
    CO2[    550    ]=    542.95532    /coeff;
    CO2[    551    ]=    542.95532    /coeff;
    CO2[    552    ]=    542.95532    /coeff;
    CO2[    553    ]=    542.95532    /coeff;
    CO2[    554    ]=    542.95532    /coeff;
    CO2[    555    ]=    542.95532    /coeff;
    CO2[    556    ]=    542.95532    /coeff;
    CO2[    557    ]=    542.95532    /coeff;
    CO2[    558    ]=    542.95532    /coeff;
    CO2[    559    ]=    542.95532    /coeff;
    CO2[    560    ]=    542.95532    /coeff;
    CO2[    561    ]=    542.95532    /coeff;
    CO2[    562    ]=    542.95532    /coeff;
    CO2[    563    ]=    542.95532    /coeff;
    CO2[    564    ]=    542.95532    /coeff;
    CO2[    565    ]=    542.95532    /coeff;
    CO2[    566    ]=    542.95532    /coeff;
    CO2[    567    ]=    542.95532    /coeff;
    CO2[    568    ]=    542.95532    /coeff;
    CO2[    569    ]=    542.95532    /coeff;
    CO2[    570    ]=    542.95532    /coeff;
    CO2[    571    ]=    542.95532    /coeff;
    CO2[    572    ]=    542.95532    /coeff;
    CO2[    573    ]=    542.95532    /coeff;
    CO2[    574    ]=    542.95532    /coeff;
    CO2[    575    ]=    542.95532    /coeff;
    CO2[    576    ]=    542.95532    /coeff;
    CO2[    577    ]=    542.95532    /coeff;
    CO2[    578    ]=    542.95532    /coeff;
    CO2[    579    ]=    542.95532    /coeff;
    CO2[    580    ]=    542.95532    /coeff;
    CO2[    581    ]=    542.95532    /coeff;
    CO2[    582    ]=    542.95532    /coeff;
    CO2[    583    ]=    542.95532    /coeff;
    CO2[    584    ]=    542.95532    /coeff;
    CO2[    585    ]=    542.95532    /coeff;
    CO2[    586    ]=    542.95532    /coeff;
    CO2[    587    ]=    542.95532    /coeff;
    CO2[    588    ]=    542.95532    /coeff;
    CO2[    589    ]=    542.95532    /coeff;
    CO2[    590    ]=    542.95532    /coeff;
    CO2[    591    ]=    542.95532    /coeff;
    CO2[    592    ]=    542.95532    /coeff;
    CO2[    593    ]=    542.95532    /coeff;
    CO2[    594    ]=    542.95532    /coeff;
    CO2[    595    ]=    542.95532    /coeff;
    CO2[    596    ]=    542.95532    /coeff;
    CO2[    597    ]=    542.95532    /coeff;
    CO2[    598    ]=    542.95532    /coeff;
    CO2[    599    ]=    542.95532    /coeff;
    CO2[    600    ]=    542.95532    /coeff;
    CO2[    601    ]=    542.95532    /coeff;
    CO2[    602    ]=    542.95532    /coeff;
    CO2[    603    ]=    542.95532    /coeff;
    CO2[    604    ]=    542.95532    /coeff;
    CO2[    605    ]=    542.95532    /coeff;
    CO2[    606    ]=    542.95532    /coeff;
    CO2[    607    ]=    542.95532    /coeff;
    CO2[    608    ]=    542.95532    /coeff;
    CO2[    609    ]=    542.95532    /coeff;
    CO2[    610    ]=    542.95532    /coeff;
    CO2[    611    ]=    542.95532    /coeff;
    CO2[    612    ]=    542.95532    /coeff;
    CO2[    613    ]=    542.95532    /coeff;
    CO2[    614    ]=    542.95532    /coeff;
    CO2[    615    ]=    542.95532    /coeff;
    CO2[    616    ]=    542.95532    /coeff;
    CO2[    617    ]=    542.95532    /coeff;
    CO2[    618    ]=    542.95532    /coeff;
    CO2[    619    ]=    542.95532    /coeff;
    CO2[    620    ]=    542.95532    /coeff;
    CO2[    621    ]=    542.95532    /coeff;
    CO2[    622    ]=    542.95532    /coeff;
    CO2[    623    ]=    542.95532    /coeff;
    CO2[    624    ]=    542.95532    /coeff;
    CO2[    625    ]=    542.95532    /coeff;
    CO2[    626    ]=    542.95532    /coeff;
    CO2[    627    ]=    542.95532    /coeff;
    CO2[    628    ]=    542.95532    /coeff;
    CO2[    629    ]=    542.95532    /coeff;
    CO2[    630    ]=    542.95532    /coeff;
    CO2[    631    ]=    542.95532    /coeff;
    CO2[    632    ]=    542.95532    /coeff;
    CO2[    633    ]=    542.95532    /coeff;
    CO2[    634    ]=    542.95532    /coeff;
    CO2[    635    ]=    542.95532    /coeff;
    CO2[    636    ]=    542.95532    /coeff;
    CO2[    637    ]=    542.95532    /coeff;
    CO2[    638    ]=    542.95532    /coeff;
    CO2[    639    ]=    542.95532    /coeff;
    CO2[    640    ]=    542.95532    /coeff;
    CO2[    641    ]=    542.95532    /coeff;
    CO2[    642    ]=    542.95532    /coeff;
    CO2[    643    ]=    542.95532    /coeff;
    CO2[    644    ]=    542.95532    /coeff;
    CO2[    645    ]=    542.95532    /coeff;
    CO2[    646    ]=    542.95532    /coeff;
    CO2[    647    ]=    542.95532    /coeff;
    CO2[    648    ]=    542.95532    /coeff;
    CO2[    649    ]=    542.95532    /coeff;
    CO2[    650    ]=    542.95532    /coeff;
    CO2[    651    ]=    542.95532    /coeff;
    CO2[    652    ]=    542.95532    /coeff;
    CO2[    653    ]=    542.95532    /coeff;
    CO2[    654    ]=    542.95532    /coeff;
    CO2[    655    ]=    542.95532    /coeff;
    CO2[    656    ]=    542.95532    /coeff;
    CO2[    657    ]=    542.95532    /coeff;
    CO2[    658    ]=    542.95532    /coeff;
    CO2[    659    ]=    542.95532    /coeff;
    CO2[    660    ]=    542.95532    /coeff;
    CO2[    661    ]=    542.95532    /coeff;
    CO2[    662    ]=    542.95532    /coeff;
    CO2[    663    ]=    542.95532    /coeff;
    CO2[    664    ]=    542.95532    /coeff;
    CO2[    665    ]=    542.95532    /coeff;
    CO2[    666    ]=    542.95532    /coeff;
    CO2[    667    ]=    542.95532    /coeff;
    CO2[    668    ]=    542.95532    /coeff;
    CO2[    669    ]=    542.95532    /coeff;
    CO2[    670    ]=    542.95532    /coeff;
    CO2[    671    ]=    542.95532    /coeff;
    CO2[    672    ]=    542.95532    /coeff;
    CO2[    673    ]=    542.95532    /coeff;
    CO2[    674    ]=    542.95532    /coeff;
    CO2[    675    ]=    542.95532    /coeff;
    CO2[    676    ]=    542.95532    /coeff;
    CO2[    677    ]=    542.95532    /coeff;
    CO2[    678    ]=    542.95532    /coeff;
    CO2[    679    ]=    542.95532    /coeff;
    CO2[    680    ]=    542.95532    /coeff;
    CO2[    681    ]=    542.95532    /coeff;
    CO2[    682    ]=    542.95532    /coeff;
    CO2[    683    ]=    542.95532    /coeff;
    CO2[    684    ]=    542.95532    /coeff;
    CO2[    685    ]=    542.95532    /coeff;
    CO2[    686    ]=    542.95532    /coeff;
    CO2[    687    ]=    542.95532    /coeff;
    CO2[    688    ]=    542.95532    /coeff;
    CO2[    689    ]=    542.95532    /coeff;
    CO2[    690    ]=    542.95532    /coeff;
    CO2[    691    ]=    542.95532    /coeff;
    CO2[    692    ]=    542.95532    /coeff;
    CO2[    693    ]=    542.95532    /coeff;
    CO2[    694    ]=    542.95532    /coeff;
    CO2[    695    ]=    542.95532    /coeff;
    CO2[    696    ]=    542.95532    /coeff;
    CO2[    697    ]=    542.95532    /coeff;
    CO2[    698    ]=    542.95532    /coeff;
    CO2[    699    ]=    542.95532    /coeff;
    CO2[    700    ]=    542.95532    /coeff;
    CO2[    701    ]=    542.95532    /coeff;
    CO2[    702    ]=    542.95532    /coeff;
    CO2[    703    ]=    542.95532    /coeff;
    CO2[    704    ]=    542.95532    /coeff;
    CO2[    705    ]=    542.95532    /coeff;
    CO2[    706    ]=    542.95532    /coeff;
    CO2[    707    ]=    542.95532    /coeff;
    CO2[    708    ]=    542.95532    /coeff;
    CO2[    709    ]=    542.95532    /coeff;
    CO2[    710    ]=    542.95532    /coeff;
    CO2[    711    ]=    542.95532    /coeff;
    CO2[    712    ]=    542.95532    /coeff;
    CO2[    713    ]=    542.95532    /coeff;
    CO2[    714    ]=    542.95532    /coeff;
    CO2[    715    ]=    542.95532    /coeff;
    CO2[    716    ]=    542.95532    /coeff;
    CO2[    717    ]=    542.95532    /coeff;
    CO2[    718    ]=    542.95532    /coeff;
    CO2[    719    ]=    542.95532    /coeff;
    CO2[    720    ]=    542.95532    /coeff;
    CO2[    721    ]=    542.95532    /coeff;
    CO2[    722    ]=    542.95532    /coeff;
    CO2[    723    ]=    542.95532    /coeff;
    CO2[    724    ]=    542.95532    /coeff;
    CO2[    725    ]=    542.95532    /coeff;
    CO2[    726    ]=    542.95532    /coeff;
    CO2[    727    ]=    542.95532    /coeff;
    CO2[    728    ]=    542.95532    /coeff;
    CO2[    729    ]=    542.95532    /coeff;
    CO2[    730    ]=    542.95532    /coeff;
    CO2[    731    ]=    542.95532    /coeff;
    CO2[    732    ]=    542.95532    /coeff;
    CO2[    733    ]=    542.95532    /coeff;
    CO2[    734    ]=    542.95532    /coeff;
    CO2[    735    ]=    542.95532    /coeff;
    
    
    for(int i = 736; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
}

void setCO2RCP6(double coeff)
{
    CO2[	0	]=	278.05158	/coeff;
    CO2[	1	]=	278.10615	/coeff;
    CO2[	2	]=	278.22039	/coeff;
    CO2[	3	]=	278.34305	/coeff;
    CO2[	4	]=	278.47058	/coeff;
    CO2[	5	]=	278.60047	/coeff;
    CO2[	6	]=	278.73275	/coeff;
    CO2[	7	]=	278.86881	/coeff;
    CO2[	8	]=	279.00907	/coeff;
    CO2[	9	]=	279.15318	/coeff;
    CO2[	10	]=	279.30180	/coeff;
    CO2[	11	]=	279.45680	/coeff;
    CO2[	12	]=	279.61808	/coeff;
    CO2[	13	]=	279.78192	/coeff;
    CO2[	14	]=	279.94320	/coeff;
    CO2[	15	]=	280.09740	/coeff;
    CO2[	16	]=	280.24280	/coeff;
    CO2[	17	]=	280.38168	/coeff;
    CO2[	18	]=	280.51832	/coeff;
    CO2[	19	]=	280.65720	/coeff;
    CO2[	20	]=	280.80260	/coeff;
    CO2[	21	]=	280.95680	/coeff;
    CO2[	22	]=	281.11808	/coeff;
    CO2[	23	]=	281.28192	/coeff;
    CO2[	24	]=	281.44320	/coeff;
    CO2[	25	]=	281.59820	/coeff;
    CO2[	26	]=	281.74682	/coeff;
    CO2[	27	]=	281.89093	/coeff;
    CO2[	28	]=	282.03119	/coeff;
    CO2[	29	]=	282.16725	/coeff;
    CO2[	30	]=	282.29901	/coeff;
    CO2[	31	]=	282.42680	/coeff;
    CO2[	32	]=	282.55093	/coeff;
    CO2[	33	]=	282.67123	/coeff;
    CO2[	34	]=	282.78730	/coeff;
    CO2[	35	]=	282.89901	/coeff;
    CO2[	36	]=	283.00677	/coeff;
    CO2[	37	]=	283.11093	/coeff;
    CO2[	38	]=	283.21129	/coeff;
    CO2[	39	]=	283.30737	/coeff;
    CO2[	40	]=	283.39963	/coeff;
    CO2[	41	]=	283.48978	/coeff;
    CO2[	42	]=	283.57796	/coeff;
    CO2[	43	]=	283.66116	/coeff;
    CO2[	44	]=	283.73511	/coeff;
    CO2[	45	]=	283.79676	/coeff;
    CO2[	46	]=	283.84667	/coeff;
    CO2[	47	]=	283.88853	/coeff;
    CO2[	48	]=	283.92613	/coeff;
    CO2[	49	]=	283.96267	/coeff;
    CO2[	50	]=	284.00107	/coeff;
    CO2[	51	]=	284.04267	/coeff;
    CO2[	52	]=	284.08613	/coeff;
    CO2[	53	]=	284.12853	/coeff;
    CO2[	54	]=	284.16667	/coeff;
    CO2[	55	]=	284.19820	/coeff;
    CO2[	56	]=	284.22333	/coeff;
    CO2[	57	]=	284.24427	/coeff;
    CO2[	58	]=	284.26307	/coeff;
    CO2[	59	]=	284.28133	/coeff;
    CO2[	60	]=	284.30027	/coeff;
    CO2[	61	]=	284.32000	/coeff;
    CO2[	62	]=	284.34000	/coeff;
    CO2[	63	]=	284.36000	/coeff;
    CO2[	64	]=	284.38000	/coeff;
    CO2[	65	]=	284.40000	/coeff;
    CO2[	66	]=	284.38500	/coeff;
    CO2[	67	]=	284.28000	/coeff;
    CO2[	68	]=	284.12500	/coeff;
    CO2[	69	]=	283.97500	/coeff;
    CO2[	70	]=	283.82500	/coeff;
    CO2[	71	]=	283.67500	/coeff;
    CO2[	72	]=	283.52500	/coeff;
    CO2[	73	]=	283.42500	/coeff;
    CO2[	74	]=	283.40000	/coeff;
    CO2[	75	]=	283.40000	/coeff;
    CO2[	76	]=	283.42500	/coeff;
    CO2[	77	]=	283.50000	/coeff;
    CO2[	78	]=	283.60000	/coeff;
    CO2[	79	]=	283.72500	/coeff;
    CO2[	80	]=	283.90000	/coeff;
    CO2[	81	]=	284.07500	/coeff;
    CO2[	82	]=	284.22500	/coeff;
    CO2[	83	]=	284.40000	/coeff;
    CO2[	84	]=	284.57500	/coeff;
    CO2[	85	]=	284.72500	/coeff;
    CO2[	86	]=	284.87500	/coeff;
    CO2[	87	]=	285.00000	/coeff;
    CO2[	88	]=	285.12500	/coeff;
    CO2[	89	]=	285.27500	/coeff;
    CO2[	90	]=	285.42500	/coeff;
    CO2[	91	]=	285.57500	/coeff;
    CO2[	92	]=	285.72500	/coeff;
    CO2[	93	]=	285.90000	/coeff;
    CO2[	94	]=	286.07500	/coeff;
    CO2[	95	]=	286.22500	/coeff;
    CO2[	96	]=	286.37500	/coeff;
    CO2[	97	]=	286.50000	/coeff;
    CO2[	98	]=	286.62500	/coeff;
    CO2[	99	]=	286.77500	/coeff;
    CO2[	100	]=	286.90000	/coeff;
    CO2[	101	]=	287.00000	/coeff;
    CO2[	102	]=	287.10000	/coeff;
    CO2[	103	]=	287.22500	/coeff;
    CO2[	104	]=	287.37500	/coeff;
    CO2[	105	]=	287.52500	/coeff;
    CO2[	106	]=	287.70000	/coeff;
    CO2[	107	]=	287.90000	/coeff;
    CO2[	108	]=	288.12500	/coeff;
    CO2[	109	]=	288.40000	/coeff;
    CO2[	110	]=	288.70000	/coeff;
    CO2[	111	]=	289.02500	/coeff;
    CO2[	112	]=	289.40000	/coeff;
    CO2[	113	]=	289.80000	/coeff;
    CO2[	114	]=	290.22500	/coeff;
    CO2[	115	]=	290.70000	/coeff;
    CO2[	116	]=	291.20000	/coeff;
    CO2[	117	]=	291.67500	/coeff;
    CO2[	118	]=	292.12500	/coeff;
    CO2[	119	]=	292.57500	/coeff;
    CO2[	120	]=	292.97500	/coeff;
    CO2[	121	]=	293.30000	/coeff;
    CO2[	122	]=	293.57500	/coeff;
    CO2[	123	]=	293.80000	/coeff;
    CO2[	124	]=	294.00000	/coeff;
    CO2[	125	]=	294.17500	/coeff;
    CO2[	126	]=	294.32500	/coeff;
    CO2[	127	]=	294.47500	/coeff;
    CO2[	128	]=	294.60000	/coeff;
    CO2[	129	]=	294.70000	/coeff;
    CO2[	130	]=	294.80000	/coeff;
    CO2[	131	]=	294.90000	/coeff;
    CO2[	132	]=	295.02500	/coeff;
    CO2[	133	]=	295.22500	/coeff;
    CO2[	134	]=	295.50000	/coeff;
    CO2[	135	]=	295.80000	/coeff;
    CO2[	136	]=	296.12500	/coeff;
    CO2[	137	]=	296.47500	/coeff;
    CO2[	138	]=	296.82500	/coeff;
    CO2[	139	]=	297.20000	/coeff;
    CO2[	140	]=	297.62500	/coeff;
    CO2[	141	]=	298.07500	/coeff;
    CO2[	142	]=	298.50000	/coeff;
    CO2[	143	]=	298.90000	/coeff;
    CO2[	144	]=	299.30000	/coeff;
    CO2[	145	]=	299.70000	/coeff;
    CO2[	146	]=	300.07500	/coeff;
    CO2[	147	]=	300.42500	/coeff;
    CO2[	148	]=	300.77500	/coeff;
    CO2[	149	]=	301.10000	/coeff;
    CO2[	150	]=	301.40000	/coeff;
    CO2[	151	]=	301.72500	/coeff;
    CO2[	152	]=	302.07500	/coeff;
    CO2[	153	]=	302.40000	/coeff;
    CO2[	154	]=	302.70000	/coeff;
    CO2[	155	]=	303.02500	/coeff;
    CO2[	156	]=	303.40000	/coeff;
    CO2[	157	]=	303.77500	/coeff;
    CO2[	158	]=	304.12500	/coeff;
    CO2[	159	]=	304.52500	/coeff;
    CO2[	160	]=	304.97500	/coeff;
    CO2[	161	]=	305.40000	/coeff;
    CO2[	162	]=	305.82500	/coeff;
    CO2[	163	]=	306.30000	/coeff;
    CO2[	164	]=	306.77500	/coeff;
    CO2[	165	]=	307.22500	/coeff;
    CO2[	166	]=	307.70000	/coeff;
    CO2[	167	]=	308.17500	/coeff;
    CO2[	168	]=	308.60000	/coeff;
    CO2[	169	]=	309.00000	/coeff;
    CO2[	170	]=	309.40000	/coeff;
    CO2[	171	]=	309.75000	/coeff;
    CO2[	172	]=	310.00000	/coeff;
    CO2[	173	]=	310.17500	/coeff;
    CO2[	174	]=	310.30000	/coeff;
    CO2[	175	]=	310.37500	/coeff;
    CO2[	176	]=	310.37500	/coeff;
    CO2[	177	]=	310.30000	/coeff;
    CO2[	178	]=	310.20000	/coeff;
    CO2[	179	]=	310.12500	/coeff;
    CO2[	180	]=	310.10000	/coeff;
    CO2[	181	]=	310.12500	/coeff;
    CO2[	182	]=	310.20000	/coeff;
    CO2[	183	]=	310.32500	/coeff;
    CO2[	184	]=	310.50000	/coeff;
    CO2[	185	]=	310.75000	/coeff;
    CO2[	186	]=	311.10000	/coeff;
    CO2[	187	]=	311.50000	/coeff;
    CO2[	188	]=	311.92500	/coeff;
    CO2[	189	]=	312.42500	/coeff;
    CO2[	190	]=	313.00000	/coeff;
    CO2[	191	]=	313.60000	/coeff;
    CO2[	192	]=	314.22500	/coeff;
    CO2[	193	]=	314.84750	/coeff;
    CO2[	194	]=	315.50000	/coeff;
    CO2[	195	]=	316.27250	/coeff;
    CO2[	196	]=	317.07500	/coeff;
    CO2[	197	]=	317.79500	/coeff;
    CO2[	198	]=	318.39750	/coeff;
    CO2[	199	]=	318.92500	/coeff;
    CO2[	200	]=	319.64750	/coeff;
    CO2[	201	]=	320.64750	/coeff;
    CO2[	202	]=	321.60500	/coeff;
    CO2[	203	]=	322.63500	/coeff;
    CO2[	204	]=	323.90250	/coeff;
    CO2[	205	]=	324.98500	/coeff;
    CO2[	206	]=	325.85500	/coeff;
    CO2[	207	]=	327.14000	/coeff;
    CO2[	208	]=	328.67750	/coeff;
    CO2[	209	]=	329.74250	/coeff;
    CO2[	210	]=	330.58500	/coeff;
    CO2[	211	]=	331.74750	/coeff;
    CO2[	212	]=	333.27250	/coeff;
    CO2[	213	]=	334.84750	/coeff;
    CO2[	214	]=	336.52500	/coeff;
    CO2[	215	]=	338.36000	/coeff;
    CO2[	216	]=	339.72750	/coeff;
    CO2[	217	]=	340.79250	/coeff;
    CO2[	218	]=	342.19750	/coeff;
    CO2[	219	]=	343.78250	/coeff;
    CO2[	220	]=	345.28250	/coeff;
    CO2[	221	]=	346.79750	/coeff;
    CO2[	222	]=	348.64500	/coeff;
    CO2[	223	]=	350.73750	/coeff;
    CO2[	224	]=	352.48750	/coeff;
    CO2[	225	]=	353.85500	/coeff;
    CO2[	226	]=	355.01750	/coeff;
    CO2[	227	]=	355.88500	/coeff;
    CO2[	228	]=	356.77750	/coeff;
    CO2[	229	]=	358.12750	/coeff;
    CO2[	230	]=	359.83750	/coeff;
    CO2[	231	]=	361.46250	/coeff;
    CO2[	232	]=	363.15500	/coeff;
    CO2[	233	]=	365.32250	/coeff;
    CO2[	234	]=	367.34750	/coeff;
    CO2[	235	]=	368.86500	/coeff;
    CO2[	236	]=	370.46750	/coeff;
    CO2[	237	]=	372.52250	/coeff;
    CO2[	238	]=	374.76000	/coeff;
    CO2[	239	]=	376.81250	/coeff;
    CO2[	240	]=	378.81250	/coeff;
    CO2[	241	]=	380.82750	/coeff;
    CO2[	242	]=	382.77750	/coeff;
    CO2[	243	]=	384.80000	/coeff;
    CO2[	244	]=	386.93455	/coeff;
    CO2[	245	]=	389.07150	/coeff;
    CO2[	246	]=	391.16650	/coeff;
    CO2[	247	]=	393.24066	/coeff;
    CO2[	248	]=	395.29786	/coeff;
    CO2[	249	]=	397.34576	/coeff;
    CO2[	250	]=	399.38717	/coeff;
    CO2[	251	]=	401.41789	/coeff;
    CO2[	252	]=	403.43127	/coeff;
    CO2[	253	]=	405.42513	/coeff;
    CO2[	254	]=	407.40083	/coeff;
    CO2[	255	]=	409.36026	/coeff;
    CO2[	256	]=	411.29764	/coeff;
    CO2[	257	]=	413.21903	/coeff;
    CO2[	258	]=	415.14445	/coeff;
    CO2[	259	]=	417.08292	/coeff;
    CO2[	260	]=	419.03635	/coeff;
    CO2[	261	]=	421.00380	/coeff;
    CO2[	262	]=	422.97812	/coeff;
    CO2[	263	]=	424.95028	/coeff;
    CO2[	264	]=	426.91631	/coeff;
    CO2[	265	]=	428.87629	/coeff;
    CO2[	266	]=	430.83200	/coeff;
    CO2[	267	]=	432.80746	/coeff;
    CO2[	268	]=	434.83148	/coeff;
    CO2[	269	]=	436.91619	/coeff;
    CO2[	270	]=	439.06785	/coeff;
    CO2[	271	]=	441.28581	/coeff;
    CO2[	272	]=	443.56720	/coeff;
    CO2[	273	]=	445.90288	/coeff;
    CO2[	274	]=	448.28176	/coeff;
    CO2[	275	]=	450.69811	/coeff;
    CO2[	276	]=	453.15021	/coeff;
    CO2[	277	]=	455.64509	/coeff;
    CO2[	278	]=	458.18181	/coeff;
    CO2[	279	]=	460.76247	/coeff;
    CO2[	280	]=	463.40530	/coeff;
    CO2[	281	]=	466.11968	/coeff;
    CO2[	282	]=	468.90757	/coeff;
    CO2[	283	]=	471.76784	/coeff;
    CO2[	284	]=	474.69236	/coeff;
    CO2[	285	]=	477.67043	/coeff;
    CO2[	286	]=	480.69694	/coeff;
    CO2[	287	]=	483.77696	/coeff;
    CO2[	288	]=	486.91560	/coeff;
    CO2[	289	]=	490.10250	/coeff;
    CO2[	290	]=	493.33845	/coeff;
    CO2[	291	]=	496.64173	/coeff;
    CO2[	292	]=	500.02229	/coeff;
    CO2[	293	]=	503.48287	/coeff;
    CO2[	294	]=	507.02296	/coeff;
    CO2[	295	]=	510.63443	/coeff;
    CO2[	296	]=	514.30531	/coeff;
    CO2[	297	]=	518.02671	/coeff;
    CO2[	298	]=	521.79702	/coeff;
    CO2[	299	]=	525.61935	/coeff;
    CO2[	300	]=	529.48604	/coeff;
    CO2[	301	]=	533.39980	/coeff;
    CO2[	302	]=	537.38147	/coeff;
    CO2[	303	]=	541.44308	/coeff;
    CO2[	304	]=	545.58888	/coeff;
    CO2[	305	]=	549.81989	/coeff;
    CO2[	306	]=	554.12904	/coeff;
    CO2[	307	]=	558.48622	/coeff;
    CO2[	308	]=	562.86724	/coeff;
    CO2[	309	]=	567.27205	/coeff;
    CO2[	310	]=	571.70141	/coeff;
    CO2[	311	]=	576.14574	/coeff;
    CO2[	312	]=	580.60640	/coeff;
    CO2[	313	]=	585.10462	/coeff;
    CO2[	314	]=	589.65317	/coeff;
    CO2[	315	]=	594.25683	/coeff;
    CO2[	316	]=	598.91790	/coeff;
    CO2[	317	]=	603.53811	/coeff;
    CO2[	318	]=	608.01988	/coeff;
    CO2[	319	]=	612.36372	/coeff;
    CO2[	320	]=	616.57173	/coeff;
    CO2[	321	]=	620.64773	/coeff;
    CO2[	322	]=	624.58304	/coeff;
    CO2[	323	]=	628.38085	/coeff;
    CO2[	324	]=	632.06458	/coeff;
    CO2[	325	]=	635.64876	/coeff;
    CO2[	326	]=	639.14086	/coeff;
    CO2[	327	]=	642.59729	/coeff;
    CO2[	328	]=	646.06094	/coeff;
    CO2[	329	]=	649.51513	/coeff;
    CO2[	330	]=	652.95074	/coeff;
    CO2[	331	]=	656.36419	/coeff;
    CO2[	332	]=	659.75421	/coeff;
    CO2[	333	]=	663.10742	/coeff;
    CO2[	334	]=	666.42313	/coeff;
    CO2[	335	]=	669.72317	/coeff;
    CO2[	336	]=	673.02173	/coeff;
    CO2[	337	]=	676.29128	/coeff;
    CO2[	338	]=	679.50127	/coeff;
    CO2[	339	]=	682.64541	/coeff;
    CO2[	340	]=	685.71141	/coeff;
    CO2[	341	]=	688.69282	/coeff;
    CO2[	342	]=	691.58868	/coeff;
    CO2[	343	]=	694.39983	/coeff;
    CO2[	344	]=	697.11406	/coeff;
    CO2[	345	]=	699.73157	/coeff;
    CO2[	346	]=	702.27614	/coeff;
    CO2[	347	]=	704.76390	/coeff;
    CO2[	348	]=	707.20265	/coeff;
    CO2[	349	]=	709.59530	/coeff;
    CO2[	350	]=	711.93394	/coeff;
    CO2[	351	]=	714.20507	/coeff;
    CO2[	352	]=	716.40081	/coeff;
    CO2[	353	]=	718.51915	/coeff;
    CO2[	354	]=	720.56005	/coeff;
    CO2[	355	]=	722.51007	/coeff;
    CO2[	356	]=	724.36814	/coeff;
    CO2[	357	]=	726.15805	/coeff;
    CO2[	358	]=	727.89640	/coeff;
    CO2[	359	]=	729.59084	/coeff;
    CO2[	360	]=	731.24405	/coeff;
    CO2[	361	]=	732.84773	/coeff;
    CO2[	362	]=	734.38928	/coeff;
    CO2[	363	]=	735.86182	/coeff;
    CO2[	364	]=	737.26278	/coeff;
    CO2[	365	]=	738.59171	/coeff;
    CO2[	366	]=	739.83434	/coeff;
    CO2[	367	]=	740.98904	/coeff;
    CO2[	368	]=	742.07980	/coeff;
    CO2[	369	]=	743.12350	/coeff;
    CO2[	370	]=	744.12799	/coeff;
    CO2[	371	]=	745.09601	/coeff;
    CO2[	372	]=	746.01899	/coeff;
    CO2[	373	]=	746.88224	/coeff;
    CO2[	374	]=	747.67691	/coeff;
    CO2[	375	]=	748.40031	/coeff;
    CO2[	376	]=	749.05184	/coeff;
    CO2[	377	]=	749.61690	/coeff;
    CO2[	378	]=	750.09334	/coeff;
    CO2[	379	]=	750.50572	/coeff;
    CO2[	380	]=	750.87141	/coeff;
    CO2[	381	]=	751.19813	/coeff;
    CO2[	382	]=	751.48890	/coeff;
    CO2[	383	]=	751.73512	/coeff;
    CO2[	384	]=	751.92185	/coeff;
    CO2[	385	]=	751.99877	/coeff;
    CO2[	386	]=	751.99877	/coeff;
    CO2[	387	]=	751.99877	/coeff;
    CO2[	388	]=	751.99877	/coeff;
    CO2[	389	]=	751.99877	/coeff;
    CO2[	390	]=	751.99877	/coeff;
    CO2[	391	]=	751.99877	/coeff;
    CO2[	392	]=	751.99877	/coeff;
    CO2[	393	]=	751.99877	/coeff;
    CO2[	394	]=	751.99877	/coeff;
    CO2[	395	]=	751.99877	/coeff;
    CO2[	396	]=	751.99877	/coeff;
    CO2[	397	]=	751.99877	/coeff;
    CO2[	398	]=	751.99877	/coeff;
    CO2[	399	]=	751.99877	/coeff;
    CO2[	400	]=	751.99877	/coeff;
    CO2[	401	]=	751.99877	/coeff;
    CO2[	402	]=	751.99877	/coeff;
    CO2[	403	]=	751.99877	/coeff;
    CO2[	404	]=	751.99877	/coeff;
    CO2[	405	]=	751.99877	/coeff;
    CO2[	406	]=	751.99877	/coeff;
    CO2[	407	]=	751.99877	/coeff;
    CO2[	408	]=	751.99877	/coeff;
    CO2[	409	]=	751.99877	/coeff;
    CO2[	410	]=	751.99877	/coeff;
    CO2[	411	]=	751.99877	/coeff;
    CO2[	412	]=	751.99877	/coeff;
    CO2[	413	]=	751.99877	/coeff;
    CO2[	414	]=	751.99877	/coeff;
    CO2[	415	]=	751.99877	/coeff;
    CO2[	416	]=	751.99877	/coeff;
    CO2[	417	]=	751.99877	/coeff;
    CO2[	418	]=	751.99877	/coeff;
    CO2[	419	]=	751.99877	/coeff;
    CO2[	420	]=	751.99877	/coeff;
    CO2[	421	]=	751.99877	/coeff;
    CO2[	422	]=	751.99877	/coeff;
    CO2[	423	]=	751.99877	/coeff;
    CO2[	424	]=	751.99877	/coeff;
    CO2[	425	]=	751.99877	/coeff;
    CO2[	426	]=	751.99877	/coeff;
    CO2[	427	]=	751.99877	/coeff;
    CO2[	428	]=	751.99877	/coeff;
    CO2[	429	]=	751.99877	/coeff;
    CO2[	430	]=	751.99877	/coeff;
    CO2[	431	]=	751.99877	/coeff;
    CO2[	432	]=	751.99877	/coeff;
    CO2[	433	]=	751.99877	/coeff;
    CO2[	434	]=	751.99877	/coeff;
    CO2[	435	]=	751.99877	/coeff;
    CO2[	436	]=	751.99877	/coeff;
    CO2[	437	]=	751.99877	/coeff;
    CO2[	438	]=	751.99877	/coeff;
    CO2[	439	]=	751.99877	/coeff;
    CO2[	440	]=	751.99877	/coeff;
    CO2[	441	]=	751.99877	/coeff;
    CO2[	442	]=	751.99877	/coeff;
    CO2[	443	]=	751.99877	/coeff;
    CO2[	444	]=	751.99877	/coeff;
    CO2[	445	]=	751.99877	/coeff;
    CO2[	446	]=	751.99877	/coeff;
    CO2[	447	]=	751.99877	/coeff;
    CO2[	448	]=	751.99877	/coeff;
    CO2[	449	]=	751.99877	/coeff;
    CO2[	450	]=	751.99877	/coeff;
    CO2[	451	]=	751.99877	/coeff;
    CO2[	452	]=	751.99877	/coeff;
    CO2[	453	]=	751.99877	/coeff;
    CO2[	454	]=	751.99877	/coeff;
    CO2[	455	]=	751.99877	/coeff;
    CO2[	456	]=	751.99877	/coeff;
    CO2[	457	]=	751.99877	/coeff;
    CO2[	458	]=	751.99877	/coeff;
    CO2[	459	]=	751.99877	/coeff;
    CO2[	460	]=	751.99877	/coeff;
    CO2[	461	]=	751.99877	/coeff;
    CO2[	462	]=	751.99877	/coeff;
    CO2[	463	]=	751.99877	/coeff;
    CO2[	464	]=	751.99877	/coeff;
    CO2[	465	]=	751.99877	/coeff;
    CO2[	466	]=	751.99877	/coeff;
    CO2[	467	]=	751.99877	/coeff;
    CO2[	468	]=	751.99877	/coeff;
    CO2[	469	]=	751.99877	/coeff;
    CO2[	470	]=	751.99877	/coeff;
    CO2[	471	]=	751.99877	/coeff;
    CO2[	472	]=	751.99877	/coeff;
    CO2[	473	]=	751.99877	/coeff;
    CO2[	474	]=	751.99877	/coeff;
    CO2[	475	]=	751.99877	/coeff;
    CO2[	476	]=	751.99877	/coeff;
    CO2[	477	]=	751.99877	/coeff;
    CO2[	478	]=	751.99877	/coeff;
    CO2[	479	]=	751.99877	/coeff;
    CO2[	480	]=	751.99877	/coeff;
    CO2[	481	]=	751.99877	/coeff;
    CO2[	482	]=	751.99877	/coeff;
    CO2[	483	]=	751.99877	/coeff;
    CO2[	484	]=	751.99877	/coeff;
    CO2[	485	]=	751.99877	/coeff;
    CO2[	486	]=	751.99877	/coeff;
    CO2[	487	]=	751.99877	/coeff;
    CO2[	488	]=	751.99877	/coeff;
    CO2[	489	]=	751.99877	/coeff;
    CO2[	490	]=	751.99877	/coeff;
    CO2[	491	]=	751.99877	/coeff;
    CO2[	492	]=	751.99877	/coeff;
    CO2[	493	]=	751.99877	/coeff;
    CO2[	494	]=	751.99877	/coeff;
    CO2[	495	]=	751.99877	/coeff;
    CO2[	496	]=	751.99877	/coeff;
    CO2[	497	]=	751.99877	/coeff;
    CO2[	498	]=	751.99877	/coeff;
    CO2[	499	]=	751.99877	/coeff;
    CO2[	500	]=	751.99877	/coeff;
    CO2[	501	]=	751.99877	/coeff;
    CO2[	502	]=	751.99877	/coeff;
    CO2[	503	]=	751.99877	/coeff;
    CO2[	504	]=	751.99877	/coeff;
    CO2[	505	]=	751.99877	/coeff;
    CO2[	506	]=	751.99877	/coeff;
    CO2[	507	]=	751.99877	/coeff;
    CO2[	508	]=	751.99877	/coeff;
    CO2[	509	]=	751.99877	/coeff;
    CO2[	510	]=	751.99877	/coeff;
    CO2[	511	]=	751.99877	/coeff;
    CO2[	512	]=	751.99877	/coeff;
    CO2[	513	]=	751.99877	/coeff;
    CO2[	514	]=	751.99877	/coeff;
    CO2[	515	]=	751.99877	/coeff;
    CO2[	516	]=	751.99877	/coeff;
    CO2[	517	]=	751.99877	/coeff;
    CO2[	518	]=	751.99877	/coeff;
    CO2[	519	]=	751.99877	/coeff;
    CO2[	520	]=	751.99877	/coeff;
    CO2[	521	]=	751.99877	/coeff;
    CO2[	522	]=	751.99877	/coeff;
    CO2[	523	]=	751.99877	/coeff;
    CO2[	524	]=	751.99877	/coeff;
    CO2[	525	]=	751.99877	/coeff;
    CO2[	526	]=	751.99877	/coeff;
    CO2[	527	]=	751.99877	/coeff;
    CO2[	528	]=	751.99877	/coeff;
    CO2[	529	]=	751.99877	/coeff;
    CO2[	530	]=	751.99877	/coeff;
    CO2[	531	]=	751.99877	/coeff;
    CO2[	532	]=	751.99877	/coeff;
    CO2[	533	]=	751.99877	/coeff;
    CO2[	534	]=	751.99877	/coeff;
    CO2[	535	]=	751.99877	/coeff;
    CO2[	536	]=	751.99877	/coeff;
    CO2[	537	]=	751.99877	/coeff;
    CO2[	538	]=	751.99877	/coeff;
    CO2[	539	]=	751.99877	/coeff;
    CO2[	540	]=	751.99877	/coeff;
    CO2[	541	]=	751.99877	/coeff;
    CO2[	542	]=	751.99877	/coeff;
    CO2[	543	]=	751.99877	/coeff;
    CO2[	544	]=	751.99877	/coeff;
    CO2[	545	]=	751.99877	/coeff;
    CO2[	546	]=	751.99877	/coeff;
    CO2[	547	]=	751.99877	/coeff;
    CO2[	548	]=	751.99877	/coeff;
    CO2[	549	]=	751.99877	/coeff;
    CO2[	550	]=	751.99877	/coeff;
    CO2[	551	]=	751.99877	/coeff;
    CO2[	552	]=	751.99877	/coeff;
    CO2[	553	]=	751.99877	/coeff;
    CO2[	554	]=	751.99877	/coeff;
    CO2[	555	]=	751.99877	/coeff;
    CO2[	556	]=	751.99877	/coeff;
    CO2[	557	]=	751.99877	/coeff;
    CO2[	558	]=	751.99877	/coeff;
    CO2[	559	]=	751.99877	/coeff;
    CO2[	560	]=	751.99877	/coeff;
    CO2[	561	]=	751.99877	/coeff;
    CO2[	562	]=	751.99877	/coeff;
    CO2[	563	]=	751.99877	/coeff;
    CO2[	564	]=	751.99877	/coeff;
    CO2[	565	]=	751.99877	/coeff;
    CO2[	566	]=	751.99877	/coeff;
    CO2[	567	]=	751.99877	/coeff;
    CO2[	568	]=	751.99877	/coeff;
    CO2[	569	]=	751.99877	/coeff;
    CO2[	570	]=	751.99877	/coeff;
    CO2[	571	]=	751.99877	/coeff;
    CO2[	572	]=	751.99877	/coeff;
    CO2[	573	]=	751.99877	/coeff;
    CO2[	574	]=	751.99877	/coeff;
    CO2[	575	]=	751.99877	/coeff;
    CO2[	576	]=	751.99877	/coeff;
    CO2[	577	]=	751.99877	/coeff;
    CO2[	578	]=	751.99877	/coeff;
    CO2[	579	]=	751.99877	/coeff;
    CO2[	580	]=	751.99877	/coeff;
    CO2[	581	]=	751.99877	/coeff;
    CO2[	582	]=	751.99877	/coeff;
    CO2[	583	]=	751.99877	/coeff;
    CO2[	584	]=	751.99877	/coeff;
    CO2[	585	]=	751.99877	/coeff;
    CO2[	586	]=	751.99877	/coeff;
    CO2[	587	]=	751.99877	/coeff;
    CO2[	588	]=	751.99877	/coeff;
    CO2[	589	]=	751.99877	/coeff;
    CO2[	590	]=	751.99877	/coeff;
    CO2[	591	]=	751.99877	/coeff;
    CO2[	592	]=	751.99877	/coeff;
    CO2[	593	]=	751.99877	/coeff;
    CO2[	594	]=	751.99877	/coeff;
    CO2[	595	]=	751.99877	/coeff;
    CO2[	596	]=	751.99877	/coeff;
    CO2[	597	]=	751.99877	/coeff;
    CO2[	598	]=	751.99877	/coeff;
    CO2[	599	]=	751.99877	/coeff;
    CO2[	600	]=	751.99877	/coeff;
    CO2[	601	]=	751.99877	/coeff;
    CO2[	602	]=	751.99877	/coeff;
    CO2[	603	]=	751.99877	/coeff;
    CO2[	604	]=	751.99877	/coeff;
    CO2[	605	]=	751.99877	/coeff;
    CO2[	606	]=	751.99877	/coeff;
    CO2[	607	]=	751.99877	/coeff;
    CO2[	608	]=	751.99877	/coeff;
    CO2[	609	]=	751.99877	/coeff;
    CO2[	610	]=	751.99877	/coeff;
    CO2[	611	]=	751.99877	/coeff;
    CO2[	612	]=	751.99877	/coeff;
    CO2[	613	]=	751.99877	/coeff;
    CO2[	614	]=	751.99877	/coeff;
    CO2[	615	]=	751.99877	/coeff;
    CO2[	616	]=	751.99877	/coeff;
    CO2[	617	]=	751.99877	/coeff;
    CO2[	618	]=	751.99877	/coeff;
    CO2[	619	]=	751.99877	/coeff;
    CO2[	620	]=	751.99877	/coeff;
    CO2[	621	]=	751.99877	/coeff;
    CO2[	622	]=	751.99877	/coeff;
    CO2[	623	]=	751.99877	/coeff;
    CO2[	624	]=	751.99877	/coeff;
    CO2[	625	]=	751.99877	/coeff;
    CO2[	626	]=	751.99877	/coeff;
    CO2[	627	]=	751.99877	/coeff;
    CO2[	628	]=	751.99877	/coeff;
    CO2[	629	]=	751.99877	/coeff;
    CO2[	630	]=	751.99877	/coeff;
    CO2[	631	]=	751.99877	/coeff;
    CO2[	632	]=	751.99877	/coeff;
    CO2[	633	]=	751.99877	/coeff;
    CO2[	634	]=	751.99877	/coeff;
    CO2[	635	]=	751.99877	/coeff;
    CO2[	636	]=	751.99877	/coeff;
    CO2[	637	]=	751.99877	/coeff;
    CO2[	638	]=	751.99877	/coeff;
    CO2[	639	]=	751.99877	/coeff;
    CO2[	640	]=	751.99877	/coeff;
    CO2[	641	]=	751.99877	/coeff;
    CO2[	642	]=	751.99877	/coeff;
    CO2[	643	]=	751.99877	/coeff;
    CO2[	644	]=	751.99877	/coeff;
    CO2[	645	]=	751.99877	/coeff;
    CO2[	646	]=	751.99877	/coeff;
    CO2[	647	]=	751.99877	/coeff;
    CO2[	648	]=	751.99877	/coeff;
    CO2[	649	]=	751.99877	/coeff;
    CO2[	650	]=	751.99877	/coeff;
    CO2[	651	]=	751.99877	/coeff;
    CO2[	652	]=	751.99877	/coeff;
    CO2[	653	]=	751.99877	/coeff;
    CO2[	654	]=	751.99877	/coeff;
    CO2[	655	]=	751.99877	/coeff;
    CO2[	656	]=	751.99877	/coeff;
    CO2[	657	]=	751.99877	/coeff;
    CO2[	658	]=	751.99877	/coeff;
    CO2[	659	]=	751.99877	/coeff;
    CO2[	660	]=	751.99877	/coeff;
    CO2[	661	]=	751.99877	/coeff;
    CO2[	662	]=	751.99877	/coeff;
    CO2[	663	]=	751.99877	/coeff;
    CO2[	664	]=	751.99877	/coeff;
    CO2[	665	]=	751.99877	/coeff;
    CO2[	666	]=	751.99877	/coeff;
    CO2[	667	]=	751.99877	/coeff;
    CO2[	668	]=	751.99877	/coeff;
    CO2[	669	]=	751.99877	/coeff;
    CO2[	670	]=	751.99877	/coeff;
    CO2[	671	]=	751.99877	/coeff;
    CO2[	672	]=	751.99877	/coeff;
    CO2[	673	]=	751.99877	/coeff;
    CO2[	674	]=	751.99877	/coeff;
    CO2[	675	]=	751.99877	/coeff;
    CO2[	676	]=	751.99877	/coeff;
    CO2[	677	]=	751.99877	/coeff;
    CO2[	678	]=	751.99877	/coeff;
    CO2[	679	]=	751.99877	/coeff;
    CO2[	680	]=	751.99877	/coeff;
    CO2[	681	]=	751.99877	/coeff;
    CO2[	682	]=	751.99877	/coeff;
    CO2[	683	]=	751.99877	/coeff;
    CO2[	684	]=	751.99877	/coeff;
    CO2[	685	]=	751.99877	/coeff;
    CO2[	686	]=	751.99877	/coeff;
    CO2[	687	]=	751.99877	/coeff;
    CO2[	688	]=	751.99877	/coeff;
    CO2[	689	]=	751.99877	/coeff;
    CO2[	690	]=	751.99877	/coeff;
    CO2[	691	]=	751.99877	/coeff;
    CO2[	692	]=	751.99877	/coeff;
    CO2[	693	]=	751.99877	/coeff;
    CO2[	694	]=	751.99877	/coeff;
    CO2[	695	]=	751.99877	/coeff;
    CO2[	696	]=	751.99877	/coeff;
    CO2[	697	]=	751.99877	/coeff;
    CO2[	698	]=	751.99877	/coeff;
    CO2[	699	]=	751.99877	/coeff;
    CO2[	700	]=	751.99877	/coeff;
    CO2[	701	]=	751.99877	/coeff;
    CO2[	702	]=	751.99877	/coeff;
    CO2[	703	]=	751.99877	/coeff;
    CO2[	704	]=	751.99877	/coeff;
    CO2[	705	]=	751.99877	/coeff;
    CO2[	706	]=	751.99877	/coeff;
    CO2[	707	]=	751.99877	/coeff;
    CO2[	708	]=	751.99877	/coeff;
    CO2[	709	]=	751.99877	/coeff;
    CO2[	710	]=	751.99877	/coeff;
    CO2[	711	]=	751.99877	/coeff;
    CO2[	712	]=	751.99877	/coeff;
    CO2[	713	]=	751.99877	/coeff;
    CO2[	714	]=	751.99877	/coeff;
    CO2[	715	]=	751.99877	/coeff;
    CO2[	716	]=	751.99877	/coeff;
    CO2[	717	]=	751.99877	/coeff;
    CO2[	718	]=	751.99877	/coeff;
    CO2[	719	]=	751.99877	/coeff;
    CO2[	720	]=	751.99877	/coeff;
    CO2[	721	]=	751.99877	/coeff;
    CO2[	722	]=	751.99877	/coeff;
    CO2[	723	]=	751.99877	/coeff;
    CO2[	724	]=	751.99877	/coeff;
    CO2[	725	]=	751.99877	/coeff;
    CO2[	726	]=	751.99877	/coeff;
    CO2[	727	]=	751.99877	/coeff;
    CO2[	728	]=	751.99877	/coeff;
    CO2[	729	]=	751.99877	/coeff;
    CO2[	730	]=	751.99877	/coeff;
    CO2[	731	]=	751.99877	/coeff;
    CO2[	732	]=	751.99877	/coeff;
    CO2[	733	]=	751.99877	/coeff;
    CO2[	734	]=	751.99877	/coeff;
    CO2[	735	]=	751.99877	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
    
}

void setCO2RCP85(double coeff)
{
    CO2[	0	]=	278.05158	/coeff;
    CO2[	1	]=	278.10615	/coeff;
    CO2[	2	]=	278.22039	/coeff;
    CO2[	3	]=	278.34305	/coeff;
    CO2[	4	]=	278.47058	/coeff;
    CO2[	5	]=	278.60047	/coeff;
    CO2[	6	]=	278.73275	/coeff;
    CO2[	7	]=	278.86881	/coeff;
    CO2[	8	]=	279.00907	/coeff;
    CO2[	9	]=	279.15318	/coeff;
    CO2[	10	]=	279.30180	/coeff;
    CO2[	11	]=	279.45680	/coeff;
    CO2[	12	]=	279.61808	/coeff;
    CO2[	13	]=	279.78192	/coeff;
    CO2[	14	]=	279.94320	/coeff;
    CO2[	15	]=	280.09740	/coeff;
    CO2[	16	]=	280.24280	/coeff;
    CO2[	17	]=	280.38168	/coeff;
    CO2[	18	]=	280.51832	/coeff;
    CO2[	19	]=	280.65720	/coeff;
    CO2[	20	]=	280.80260	/coeff;
    CO2[	21	]=	280.95680	/coeff;
    CO2[	22	]=	281.11808	/coeff;
    CO2[	23	]=	281.28192	/coeff;
    CO2[	24	]=	281.44320	/coeff;
    CO2[	25	]=	281.59820	/coeff;
    CO2[	26	]=	281.74682	/coeff;
    CO2[	27	]=	281.89093	/coeff;
    CO2[	28	]=	282.03119	/coeff;
    CO2[	29	]=	282.16725	/coeff;
    CO2[	30	]=	282.29901	/coeff;
    CO2[	31	]=	282.42680	/coeff;
    CO2[	32	]=	282.55093	/coeff;
    CO2[	33	]=	282.67123	/coeff;
    CO2[	34	]=	282.78730	/coeff;
    CO2[	35	]=	282.89901	/coeff;
    CO2[	36	]=	283.00677	/coeff;
    CO2[	37	]=	283.11093	/coeff;
    CO2[	38	]=	283.21129	/coeff;
    CO2[	39	]=	283.30737	/coeff;
    CO2[	40	]=	283.39963	/coeff;
    CO2[	41	]=	283.48978	/coeff;
    CO2[	42	]=	283.57796	/coeff;
    CO2[	43	]=	283.66116	/coeff;
    CO2[	44	]=	283.73511	/coeff;
    CO2[	45	]=	283.79676	/coeff;
    CO2[	46	]=	283.84667	/coeff;
    CO2[	47	]=	283.88853	/coeff;
    CO2[	48	]=	283.92613	/coeff;
    CO2[	49	]=	283.96267	/coeff;
    CO2[	50	]=	284.00107	/coeff;
    CO2[	51	]=	284.04267	/coeff;
    CO2[	52	]=	284.08613	/coeff;
    CO2[	53	]=	284.12853	/coeff;
    CO2[	54	]=	284.16667	/coeff;
    CO2[	55	]=	284.19820	/coeff;
    CO2[	56	]=	284.22333	/coeff;
    CO2[	57	]=	284.24427	/coeff;
    CO2[	58	]=	284.26307	/coeff;
    CO2[	59	]=	284.28133	/coeff;
    CO2[	60	]=	284.30027	/coeff;
    CO2[	61	]=	284.32000	/coeff;
    CO2[	62	]=	284.34000	/coeff;
    CO2[	63	]=	284.36000	/coeff;
    CO2[	64	]=	284.38000	/coeff;
    CO2[	65	]=	284.40000	/coeff;
    CO2[	66	]=	284.38500	/coeff;
    CO2[	67	]=	284.28000	/coeff;
    CO2[	68	]=	284.12500	/coeff;
    CO2[	69	]=	283.97500	/coeff;
    CO2[	70	]=	283.82500	/coeff;
    CO2[	71	]=	283.67500	/coeff;
    CO2[	72	]=	283.52500	/coeff;
    CO2[	73	]=	283.42500	/coeff;
    CO2[	74	]=	283.40000	/coeff;
    CO2[	75	]=	283.40000	/coeff;
    CO2[	76	]=	283.42500	/coeff;
    CO2[	77	]=	283.50000	/coeff;
    CO2[	78	]=	283.60000	/coeff;
    CO2[	79	]=	283.72500	/coeff;
    CO2[	80	]=	283.90000	/coeff;
    CO2[	81	]=	284.07500	/coeff;
    CO2[	82	]=	284.22500	/coeff;
    CO2[	83	]=	284.40000	/coeff;
    CO2[	84	]=	284.57500	/coeff;
    CO2[	85	]=	284.72500	/coeff;
    CO2[	86	]=	284.87500	/coeff;
    CO2[	87	]=	285.00000	/coeff;
    CO2[	88	]=	285.12500	/coeff;
    CO2[	89	]=	285.27500	/coeff;
    CO2[	90	]=	285.42500	/coeff;
    CO2[	91	]=	285.57500	/coeff;
    CO2[	92	]=	285.72500	/coeff;
    CO2[	93	]=	285.90000	/coeff;
    CO2[	94	]=	286.07500	/coeff;
    CO2[	95	]=	286.22500	/coeff;
    CO2[	96	]=	286.37500	/coeff;
    CO2[	97	]=	286.50000	/coeff;
    CO2[	98	]=	286.62500	/coeff;
    CO2[	99	]=	286.77500	/coeff;
    CO2[	100	]=	286.90000	/coeff;
    CO2[	101	]=	287.00000	/coeff;
    CO2[	102	]=	287.10000	/coeff;
    CO2[	103	]=	287.22500	/coeff;
    CO2[	104	]=	287.37500	/coeff;
    CO2[	105	]=	287.52500	/coeff;
    CO2[	106	]=	287.70000	/coeff;
    CO2[	107	]=	287.90000	/coeff;
    CO2[	108	]=	288.12500	/coeff;
    CO2[	109	]=	288.40000	/coeff;
    CO2[	110	]=	288.70000	/coeff;
    CO2[	111	]=	289.02500	/coeff;
    CO2[	112	]=	289.40000	/coeff;
    CO2[	113	]=	289.80000	/coeff;
    CO2[	114	]=	290.22500	/coeff;
    CO2[	115	]=	290.70000	/coeff;
    CO2[	116	]=	291.20000	/coeff;
    CO2[	117	]=	291.67500	/coeff;
    CO2[	118	]=	292.12500	/coeff;
    CO2[	119	]=	292.57500	/coeff;
    CO2[	120	]=	292.97500	/coeff;
    CO2[	121	]=	293.30000	/coeff;
    CO2[	122	]=	293.57500	/coeff;
    CO2[	123	]=	293.80000	/coeff;
    CO2[	124	]=	294.00000	/coeff;
    CO2[	125	]=	294.17500	/coeff;
    CO2[	126	]=	294.32500	/coeff;
    CO2[	127	]=	294.47500	/coeff;
    CO2[	128	]=	294.60000	/coeff;
    CO2[	129	]=	294.70000	/coeff;
    CO2[	130	]=	294.80000	/coeff;
    CO2[	131	]=	294.90000	/coeff;
    CO2[	132	]=	295.02500	/coeff;
    CO2[	133	]=	295.22500	/coeff;
    CO2[	134	]=	295.50000	/coeff;
    CO2[	135	]=	295.80000	/coeff;
    CO2[	136	]=	296.12500	/coeff;
    CO2[	137	]=	296.47500	/coeff;
    CO2[	138	]=	296.82500	/coeff;
    CO2[	139	]=	297.20000	/coeff;
    CO2[	140	]=	297.62500	/coeff;
    CO2[	141	]=	298.07500	/coeff;
    CO2[	142	]=	298.50000	/coeff;
    CO2[	143	]=	298.90000	/coeff;
    CO2[	144	]=	299.30000	/coeff;
    CO2[	145	]=	299.70000	/coeff;
    CO2[	146	]=	300.07500	/coeff;
    CO2[	147	]=	300.42500	/coeff;
    CO2[	148	]=	300.77500	/coeff;
    CO2[	149	]=	301.10000	/coeff;
    CO2[	150	]=	301.40000	/coeff;
    CO2[	151	]=	301.72500	/coeff;
    CO2[	152	]=	302.07500	/coeff;
    CO2[	153	]=	302.40000	/coeff;
    CO2[	154	]=	302.70000	/coeff;
    CO2[	155	]=	303.02500	/coeff;
    CO2[	156	]=	303.40000	/coeff;
    CO2[	157	]=	303.77500	/coeff;
    CO2[	158	]=	304.12500	/coeff;
    CO2[	159	]=	304.52500	/coeff;
    CO2[	160	]=	304.97500	/coeff;
    CO2[	161	]=	305.40000	/coeff;
    CO2[	162	]=	305.82500	/coeff;
    CO2[	163	]=	306.30000	/coeff;
    CO2[	164	]=	306.77500	/coeff;
    CO2[	165	]=	307.22500	/coeff;
    CO2[	166	]=	307.70000	/coeff;
    CO2[	167	]=	308.17500	/coeff;
    CO2[	168	]=	308.60000	/coeff;
    CO2[	169	]=	309.00000	/coeff;
    CO2[	170	]=	309.40000	/coeff;
    CO2[	171	]=	309.75000	/coeff;
    CO2[	172	]=	310.00000	/coeff;
    CO2[	173	]=	310.17500	/coeff;
    CO2[	174	]=	310.30000	/coeff;
    CO2[	175	]=	310.37500	/coeff;
    CO2[	176	]=	310.37500	/coeff;
    CO2[	177	]=	310.30000	/coeff;
    CO2[	178	]=	310.20000	/coeff;
    CO2[	179	]=	310.12500	/coeff;
    CO2[	180	]=	310.10000	/coeff;
    CO2[	181	]=	310.12500	/coeff;
    CO2[	182	]=	310.20000	/coeff;
    CO2[	183	]=	310.32500	/coeff;
    CO2[	184	]=	310.50000	/coeff;
    CO2[	185	]=	310.75000	/coeff;
    CO2[	186	]=	311.10000	/coeff;
    CO2[	187	]=	311.50000	/coeff;
    CO2[	188	]=	311.92500	/coeff;
    CO2[	189	]=	312.42500	/coeff;
    CO2[	190	]=	313.00000	/coeff;
    CO2[	191	]=	313.60000	/coeff;
    CO2[	192	]=	314.22500	/coeff;
    CO2[	193	]=	314.84750	/coeff;
    CO2[	194	]=	315.50000	/coeff;
    CO2[	195	]=	316.27250	/coeff;
    CO2[	196	]=	317.07500	/coeff;
    CO2[	197	]=	317.79500	/coeff;
    CO2[	198	]=	318.39750	/coeff;
    CO2[	199	]=	318.92500	/coeff;
    CO2[	200	]=	319.64750	/coeff;
    CO2[	201	]=	320.64750	/coeff;
    CO2[	202	]=	321.60500	/coeff;
    CO2[	203	]=	322.63500	/coeff;
    CO2[	204	]=	323.90250	/coeff;
    CO2[	205	]=	324.98500	/coeff;
    CO2[	206	]=	325.85500	/coeff;
    CO2[	207	]=	327.14000	/coeff;
    CO2[	208	]=	328.67750	/coeff;
    CO2[	209	]=	329.74250	/coeff;
    CO2[	210	]=	330.58500	/coeff;
    CO2[	211	]=	331.74750	/coeff;
    CO2[	212	]=	333.27250	/coeff;
    CO2[	213	]=	334.84750	/coeff;
    CO2[	214	]=	336.52500	/coeff;
    CO2[	215	]=	338.36000	/coeff;
    CO2[	216	]=	339.72750	/coeff;
    CO2[	217	]=	340.79250	/coeff;
    CO2[	218	]=	342.19750	/coeff;
    CO2[	219	]=	343.78250	/coeff;
    CO2[	220	]=	345.28250	/coeff;
    CO2[	221	]=	346.79750	/coeff;
    CO2[	222	]=	348.64500	/coeff;
    CO2[	223	]=	350.73750	/coeff;
    CO2[	224	]=	352.48750	/coeff;
    CO2[	225	]=	353.85500	/coeff;
    CO2[	226	]=	355.01750	/coeff;
    CO2[	227	]=	355.88500	/coeff;
    CO2[	228	]=	356.77750	/coeff;
    CO2[	229	]=	358.12750	/coeff;
    CO2[	230	]=	359.83750	/coeff;
    CO2[	231	]=	361.46250	/coeff;
    CO2[	232	]=	363.15500	/coeff;
    CO2[	233	]=	365.32250	/coeff;
    CO2[	234	]=	367.34750	/coeff;
    CO2[	235	]=	368.86500	/coeff;
    CO2[	236	]=	370.46750	/coeff;
    CO2[	237	]=	372.52250	/coeff;
    CO2[	238	]=	374.76000	/coeff;
    CO2[	239	]=	376.81250	/coeff;
    CO2[	240	]=	378.81250	/coeff;
    CO2[	241	]=	380.82750	/coeff;
    CO2[	242	]=	382.77750	/coeff;
    CO2[	243	]=	384.80000	/coeff;
    CO2[	244	]=	387.01226	/coeff;
    CO2[	245	]=	389.32416	/coeff;
    CO2[	246	]=	391.63801	/coeff;
    CO2[	247	]=	394.00866	/coeff;
    CO2[	248	]=	396.46384	/coeff;
    CO2[	249	]=	399.00402	/coeff;
    CO2[	250	]=	401.62793	/coeff;
    CO2[	251	]=	404.32819	/coeff;
    CO2[	252	]=	407.09588	/coeff;
    CO2[	253	]=	409.92701	/coeff;
    CO2[	254	]=	412.82151	/coeff;
    CO2[	255	]=	415.78022	/coeff;
    CO2[	256	]=	418.79629	/coeff;
    CO2[	257	]=	421.86439	/coeff;
    CO2[	258	]=	424.99469	/coeff;
    CO2[	259	]=	428.19734	/coeff;
    CO2[	260	]=	431.47473	/coeff;
    CO2[	261	]=	434.82619	/coeff;
    CO2[	262	]=	438.24456	/coeff;
    CO2[	263	]=	441.72080	/coeff;
    CO2[	264	]=	445.25085	/coeff;
    CO2[	265	]=	448.83485	/coeff;
    CO2[	266	]=	452.47359	/coeff;
    CO2[	267	]=	456.17700	/coeff;
    CO2[	268	]=	459.96398	/coeff;
    CO2[	269	]=	463.85181	/coeff;
    CO2[	270	]=	467.85003	/coeff;
    CO2[	271	]=	471.96047	/coeff;
    CO2[	272	]=	476.18237	/coeff;
    CO2[	273	]=	480.50799	/coeff;
    CO2[	274	]=	484.92724	/coeff;
    CO2[	275	]=	489.43545	/coeff;
    CO2[	276	]=	494.03235	/coeff;
    CO2[	277	]=	498.72970	/coeff;
    CO2[	278	]=	503.52959	/coeff;
    CO2[	279	]=	508.43266	/coeff;
    CO2[	280	]=	513.45614	/coeff;
    CO2[	281	]=	518.61062	/coeff;
    CO2[	282	]=	523.90006	/coeff;
    CO2[	283	]=	529.32418	/coeff;
    CO2[	284	]=	534.87520	/coeff;
    CO2[	285	]=	540.54279	/coeff;
    CO2[	286	]=	546.32201	/coeff;
    CO2[	287	]=	552.21189	/coeff;
    CO2[	288	]=	558.21220	/coeff;
    CO2[	289	]=	564.31311	/coeff;
    CO2[	290	]=	570.51669	/coeff;
    CO2[	291	]=	576.84343	/coeff;
    CO2[	292	]=	583.30471	/coeff;
    CO2[	293	]=	589.90539	/coeff;
    CO2[	294	]=	596.64656	/coeff;
    CO2[	295	]=	603.52045	/coeff;
    CO2[	296	]=	610.51650	/coeff;
    CO2[	297	]=	617.60526	/coeff;
    CO2[	298	]=	624.76367	/coeff;
    CO2[	299	]=	631.99471	/coeff;
    CO2[	300	]=	639.29052	/coeff;
    CO2[	301	]=	646.65274	/coeff;
    CO2[	302	]=	654.09843	/coeff;
    CO2[	303	]=	661.64491	/coeff;
    CO2[	304	]=	669.30474	/coeff;
    CO2[	305	]=	677.07762	/coeff;
    CO2[	306	]=	684.95429	/coeff;
    CO2[	307	]=	692.90196	/coeff;
    CO2[	308	]=	700.89416	/coeff;
    CO2[	309	]=	708.93159	/coeff;
    CO2[	310	]=	717.01548	/coeff;
    CO2[	311	]=	725.13597	/coeff;
    CO2[	312	]=	733.30667	/coeff;
    CO2[	313	]=	741.52368	/coeff;
    CO2[	314	]=	749.80466	/coeff;
    CO2[	315	]=	758.18230	/coeff;
    CO2[	316	]=	766.64451	/coeff;
    CO2[	317	]=	775.17446	/coeff;
    CO2[	318	]=	783.75141	/coeff;
    CO2[	319	]=	792.36578	/coeff;
    CO2[	320	]=	801.01880	/coeff;
    CO2[	321	]=	809.71464	/coeff;
    CO2[	322	]=	818.42214	/coeff;
    CO2[	323	]=	827.15719	/coeff;
    CO2[	324	]=	835.95594	/coeff;
    CO2[	325	]=	844.80471	/coeff;
    CO2[	326	]=	853.72536	/coeff;
    CO2[	327	]=	862.72597	/coeff;
    CO2[	328	]=	871.77680	/coeff;
    CO2[	329	]=	880.86435	/coeff;
    CO2[	330	]=	889.98162	/coeff;
    CO2[	331	]=	899.12407	/coeff;
    CO2[	332	]=	908.28871	/coeff;
    CO2[	333	]=	917.47137	/coeff;
    CO2[	334	]=	926.66527	/coeff;
    CO2[	335	]=	935.87437	/coeff;
    CO2[	336	]=	945.13213	/coeff;
    CO2[	337	]=	954.46620	/coeff;
    CO2[	338	]=	963.83906	/coeff;
    CO2[	339	]=	973.24080	/coeff;
    CO2[	340	]=	982.68037	/coeff;
    CO2[	341	]=	992.14288	/coeff;
    CO2[	342	]=	1001.63110	/coeff;
    CO2[	343	]=	1011.11910	/coeff;
    CO2[	344	]=	1020.60850	/coeff;
    CO2[	345	]=	1030.10040	/coeff;
    CO2[	346	]=	1039.58920	/coeff;
    CO2[	347	]=	1049.12330	/coeff;
    CO2[	348	]=	1058.70020	/coeff;
    CO2[	349	]=	1068.32160	/coeff;
    CO2[	350	]=	1077.99950	/coeff;
    CO2[	351	]=	1087.69990	/coeff;
    CO2[	352	]=	1097.43030	/coeff;
    CO2[	353	]=	1107.17650	/coeff;
    CO2[	354	]=	1116.91220	/coeff;
    CO2[	355	]=	1126.65920	/coeff;
    CO2[	356	]=	1136.40150	/coeff;
    CO2[	357	]=	1146.13440	/coeff;
    CO2[	358	]=	1155.90640	/coeff;
    CO2[	359	]=	1165.74010	/coeff;
    CO2[	360	]=	1175.61760	/coeff;
    CO2[	361	]=	1185.52950	/coeff;
    CO2[	362	]=	1195.48330	/coeff;
    CO2[	363	]=	1205.47720	/coeff;
    CO2[	364	]=	1215.46610	/coeff;
    CO2[	365	]=	1225.45300	/coeff;
    CO2[	366	]=	1235.44930	/coeff;
    CO2[	367	]=	1245.41900	/coeff;
    CO2[	368	]=	1255.39700	/coeff;
    CO2[	369	]=	1265.42110	/coeff;
    CO2[	370	]=	1275.48430	/coeff;
    CO2[	371	]=	1285.59430	/coeff;
    CO2[	372	]=	1295.76320	/coeff;
    CO2[	373	]=	1305.96250	/coeff;
    CO2[	374	]=	1316.17080	/coeff;
    CO2[	375	]=	1326.39360	/coeff;
    CO2[	376	]=	1336.62830	/coeff;
    CO2[	377	]=	1346.85940	/coeff;
    CO2[	378	]=	1357.07270	/coeff;
    CO2[	379	]=	1367.27970	/coeff;
    CO2[	380	]=	1377.50970	/coeff;
    CO2[	381	]=	1387.79300	/coeff;
    CO2[	382	]=	1398.13760	/coeff;
    CO2[	383	]=	1408.52260	/coeff;
    CO2[	384	]=	1418.94670	/coeff;
    CO2[	385	]=	1429.39690	/coeff;
    CO2[	386	]=	1439.83540	/coeff;
    CO2[	387	]=	1450.21110	/coeff;
    CO2[	388	]=	1460.47930	/coeff;
    CO2[	389	]=	1470.59150	/coeff;
    CO2[	390	]=	1480.55640	/coeff;
    CO2[	391	]=	1490.45520	/coeff;
    CO2[	392	]=	1500.29940	/coeff;
    CO2[	393	]=	1510.05730	/coeff;
    CO2[	394	]=	1519.73320	/coeff;
    CO2[	395	]=	1529.32760	/coeff;
    CO2[	396	]=	1538.82740	/coeff;
    CO2[	397	]=	1548.22140	/coeff;
    CO2[	398	]=	1557.50250	/coeff;
    CO2[	399	]=	1566.68380	/coeff;
    CO2[	400	]=	1575.70930	/coeff;
    CO2[	401	]=	1584.57920	/coeff;
    CO2[	402	]=	1593.38900	/coeff;
    CO2[	403	]=	1602.14440	/coeff;
    CO2[	404	]=	1610.82320	/coeff;
    CO2[	405	]=	1619.41890	/coeff;
    CO2[	406	]=	1627.92830	/coeff;
    CO2[	407	]=	1636.34230	/coeff;
    CO2[	408	]=	1644.65440	/coeff;
    CO2[	409	]=	1652.86210	/coeff;
    CO2[	410	]=	1660.94720	/coeff;
    CO2[	411	]=	1668.87140	/coeff;
    CO2[	412	]=	1676.64910	/coeff;
    CO2[	413	]=	1684.34790	/coeff;
    CO2[	414	]=	1691.98550	/coeff;
    CO2[	415	]=	1699.55430	/coeff;
    CO2[	416	]=	1707.05420	/coeff;
    CO2[	417	]=	1714.46710	/coeff;
    CO2[	418	]=	1721.78570	/coeff;
    CO2[	419	]=	1728.99860	/coeff;
    CO2[	420	]=	1736.07300	/coeff;
    CO2[	421	]=	1743.02040	/coeff;
    CO2[	422	]=	1749.82720	/coeff;
    CO2[	423	]=	1756.48450	/coeff;
    CO2[	424	]=	1763.04690	/coeff;
    CO2[	425	]=	1769.54200	/coeff;
    CO2[	426	]=	1775.97200	/coeff;
    CO2[	427	]=	1782.32810	/coeff;
    CO2[	428	]=	1788.59850	/coeff;
    CO2[	429	]=	1794.76050	/coeff;
    CO2[	430	]=	1800.79990	/coeff;
    CO2[	431	]=	1806.73340	/coeff;
    CO2[	432	]=	1812.52010	/coeff;
    CO2[	433	]=	1818.14230	/coeff;
    CO2[	434	]=	1823.64980	/coeff;
    CO2[	435	]=	1829.05560	/coeff;
    CO2[	436	]=	1834.37330	/coeff;
    CO2[	437	]=	1839.61220	/coeff;
    CO2[	438	]=	1844.78120	/coeff;
    CO2[	439	]=	1849.86820	/coeff;
    CO2[	440	]=	1854.84900	/coeff;
    CO2[	441	]=	1859.71060	/coeff;
    CO2[	442	]=	1864.44690	/coeff;
    CO2[	443	]=	1869.03620	/coeff;
    CO2[	444	]=	1873.46720	/coeff;
    CO2[	445	]=	1877.78400	/coeff;
    CO2[	446	]=	1881.99470	/coeff;
    CO2[	447	]=	1886.10970	/coeff;
    CO2[	448	]=	1890.15540	/coeff;
    CO2[	449	]=	1894.13130	/coeff;
    CO2[	450	]=	1898.01230	/coeff;
    CO2[	451	]=	1901.77660	/coeff;
    CO2[	452	]=	1905.42350	/coeff;
    CO2[	453	]=	1908.96030	/coeff;
    CO2[	454	]=	1912.34450	/coeff;
    CO2[	455	]=	1915.54650	/coeff;
    CO2[	456	]=	1918.62170	/coeff;
    CO2[	457	]=	1921.61260	/coeff;
    CO2[	458	]=	1924.52270	/coeff;
    CO2[	459	]=	1927.35200	/coeff;
    CO2[	460	]=	1930.10000	/coeff;
    CO2[	461	]=	1932.75130	/coeff;
    CO2[	462	]=	1935.29260	/coeff;
    CO2[	463	]=	1937.71270	/coeff;
    CO2[	464	]=	1940.01030	/coeff;
    CO2[	465	]=	1942.15830	/coeff;
    CO2[	466	]=	1944.15720	/coeff;
    CO2[	467	]=	1946.02780	/coeff;
    CO2[	468	]=	1947.77620	/coeff;
    CO2[	469	]=	1949.43920	/coeff;
    CO2[	470	]=	1951.01210	/coeff;
    CO2[	471	]=	1952.51380	/coeff;
    CO2[	472	]=	1953.94330	/coeff;
    CO2[	473	]=	1955.27180	/coeff;
    CO2[	474	]=	1956.46040	/coeff;
    CO2[	475	]=	1957.49290	/coeff;
    CO2[	476	]=	1958.42800	/coeff;
    CO2[	477	]=	1959.18970	/coeff;
    CO2[	478	]=	1959.77070	/coeff;
    CO2[	479	]=	1960.28470	/coeff;
    CO2[	480	]=	1960.72880	/coeff;
    CO2[	481	]=	1961.06740	/coeff;
    CO2[	482	]=	1961.31940	/coeff;
    CO2[	483	]=	1961.49570	/coeff;
    CO2[	484	]=	1961.56830	/coeff;
    CO2[	485	]=	1961.57740	/coeff;
    CO2[	486	]=	1961.57740	/coeff;
    CO2[	487	]=	1961.57740	/coeff;
    CO2[	488	]=	1961.57740	/coeff;
    CO2[	489	]=	1961.57740	/coeff;
    CO2[	490	]=	1961.57740	/coeff;
    CO2[	491	]=	1961.57740	/coeff;
    CO2[	492	]=	1961.57740	/coeff;
    CO2[	493	]=	1961.57740	/coeff;
    CO2[	494	]=	1961.57740	/coeff;
    CO2[	495	]=	1961.57740	/coeff;
    CO2[	496	]=	1961.57740	/coeff;
    CO2[	497	]=	1961.57740	/coeff;
    CO2[	498	]=	1961.57740	/coeff;
    CO2[	499	]=	1961.57740	/coeff;
    CO2[	500	]=	1961.57740	/coeff;
    CO2[	501	]=	1961.57740	/coeff;
    CO2[	502	]=	1961.57740	/coeff;
    CO2[	503	]=	1961.57740	/coeff;
    CO2[	504	]=	1961.57740	/coeff;
    CO2[	505	]=	1961.57740	/coeff;
    CO2[	506	]=	1961.57740	/coeff;
    CO2[	507	]=	1961.57740	/coeff;
    CO2[	508	]=	1961.57740	/coeff;
    CO2[	509	]=	1961.57740	/coeff;
    CO2[	510	]=	1961.57740	/coeff;
    CO2[	511	]=	1961.57740	/coeff;
    CO2[	512	]=	1961.57740	/coeff;
    CO2[	513	]=	1961.57740	/coeff;
    CO2[	514	]=	1961.57740	/coeff;
    CO2[	515	]=	1961.57740	/coeff;
    CO2[	516	]=	1961.57740	/coeff;
    CO2[	517	]=	1961.57740	/coeff;
    CO2[	518	]=	1961.57740	/coeff;
    CO2[	519	]=	1961.57740	/coeff;
    CO2[	520	]=	1961.57740	/coeff;
    CO2[	521	]=	1961.57740	/coeff;
    CO2[	522	]=	1961.57740	/coeff;
    CO2[	523	]=	1961.57740	/coeff;
    CO2[	524	]=	1961.57740	/coeff;
    CO2[	525	]=	1961.57740	/coeff;
    CO2[	526	]=	1961.57740	/coeff;
    CO2[	527	]=	1961.57740	/coeff;
    CO2[	528	]=	1961.57740	/coeff;
    CO2[	529	]=	1961.57740	/coeff;
    CO2[	530	]=	1961.57740	/coeff;
    CO2[	531	]=	1961.57740	/coeff;
    CO2[	532	]=	1961.57740	/coeff;
    CO2[	533	]=	1961.57740	/coeff;
    CO2[	534	]=	1961.57740	/coeff;
    CO2[	535	]=	1961.57740	/coeff;
    CO2[	536	]=	1961.57740	/coeff;
    CO2[	537	]=	1961.57740	/coeff;
    CO2[	538	]=	1961.57740	/coeff;
    CO2[	539	]=	1961.57740	/coeff;
    CO2[	540	]=	1961.57740	/coeff;
    CO2[	541	]=	1961.57740	/coeff;
    CO2[	542	]=	1961.57740	/coeff;
    CO2[	543	]=	1961.57740	/coeff;
    CO2[	544	]=	1961.57740	/coeff;
    CO2[	545	]=	1961.57740	/coeff;
    CO2[	546	]=	1961.57740	/coeff;
    CO2[	547	]=	1961.57740	/coeff;
    CO2[	548	]=	1961.57740	/coeff;
    CO2[	549	]=	1961.57740	/coeff;
    CO2[	550	]=	1961.57740	/coeff;
    CO2[	551	]=	1961.57740	/coeff;
    CO2[	552	]=	1961.57740	/coeff;
    CO2[	553	]=	1961.57740	/coeff;
    CO2[	554	]=	1961.57740	/coeff;
    CO2[	555	]=	1961.57740	/coeff;
    CO2[	556	]=	1961.57740	/coeff;
    CO2[	557	]=	1961.57740	/coeff;
    CO2[	558	]=	1961.57740	/coeff;
    CO2[	559	]=	1961.57740	/coeff;
    CO2[	560	]=	1961.57740	/coeff;
    CO2[	561	]=	1961.57740	/coeff;
    CO2[	562	]=	1961.57740	/coeff;
    CO2[	563	]=	1961.57740	/coeff;
    CO2[	564	]=	1961.57740	/coeff;
    CO2[	565	]=	1961.57740	/coeff;
    CO2[	566	]=	1961.57740	/coeff;
    CO2[	567	]=	1961.57740	/coeff;
    CO2[	568	]=	1961.57740	/coeff;
    CO2[	569	]=	1961.57740	/coeff;
    CO2[	570	]=	1961.57740	/coeff;
    CO2[	571	]=	1961.57740	/coeff;
    CO2[	572	]=	1961.57740	/coeff;
    CO2[	573	]=	1961.57740	/coeff;
    CO2[	574	]=	1961.57740	/coeff;
    CO2[	575	]=	1961.57740	/coeff;
    CO2[	576	]=	1961.57740	/coeff;
    CO2[	577	]=	1961.57740	/coeff;
    CO2[	578	]=	1961.57740	/coeff;
    CO2[	579	]=	1961.57740	/coeff;
    CO2[	580	]=	1961.57740	/coeff;
    CO2[	581	]=	1961.57740	/coeff;
    CO2[	582	]=	1961.57740	/coeff;
    CO2[	583	]=	1961.57740	/coeff;
    CO2[	584	]=	1961.57740	/coeff;
    CO2[	585	]=	1961.57740	/coeff;
    CO2[	586	]=	1961.57740	/coeff;
    CO2[	587	]=	1961.57740	/coeff;
    CO2[	588	]=	1961.57740	/coeff;
    CO2[	589	]=	1961.57740	/coeff;
    CO2[	590	]=	1961.57740	/coeff;
    CO2[	591	]=	1961.57740	/coeff;
    CO2[	592	]=	1961.57740	/coeff;
    CO2[	593	]=	1961.57740	/coeff;
    CO2[	594	]=	1961.57740	/coeff;
    CO2[	595	]=	1961.57740	/coeff;
    CO2[	596	]=	1961.57740	/coeff;
    CO2[	597	]=	1961.57740	/coeff;
    CO2[	598	]=	1961.57740	/coeff;
    CO2[	599	]=	1961.57740	/coeff;
    CO2[	600	]=	1961.57740	/coeff;
    CO2[	601	]=	1961.57740	/coeff;
    CO2[	602	]=	1961.57740	/coeff;
    CO2[	603	]=	1961.57740	/coeff;
    CO2[	604	]=	1961.57740	/coeff;
    CO2[	605	]=	1961.57740	/coeff;
    CO2[	606	]=	1961.57740	/coeff;
    CO2[	607	]=	1961.57740	/coeff;
    CO2[	608	]=	1961.57740	/coeff;
    CO2[	609	]=	1961.57740	/coeff;
    CO2[	610	]=	1961.57740	/coeff;
    CO2[	611	]=	1961.57740	/coeff;
    CO2[	612	]=	1961.57740	/coeff;
    CO2[	613	]=	1961.57740	/coeff;
    CO2[	614	]=	1961.57740	/coeff;
    CO2[	615	]=	1961.57740	/coeff;
    CO2[	616	]=	1961.57740	/coeff;
    CO2[	617	]=	1961.57740	/coeff;
    CO2[	618	]=	1961.57740	/coeff;
    CO2[	619	]=	1961.57740	/coeff;
    CO2[	620	]=	1961.57740	/coeff;
    CO2[	621	]=	1961.57740	/coeff;
    CO2[	622	]=	1961.57740	/coeff;
    CO2[	623	]=	1961.57740	/coeff;
    CO2[	624	]=	1961.57740	/coeff;
    CO2[	625	]=	1961.57740	/coeff;
    CO2[	626	]=	1961.57740	/coeff;
    CO2[	627	]=	1961.57740	/coeff;
    CO2[	628	]=	1961.57740	/coeff;
    CO2[	629	]=	1961.57740	/coeff;
    CO2[	630	]=	1961.57740	/coeff;
    CO2[	631	]=	1961.57740	/coeff;
    CO2[	632	]=	1961.57740	/coeff;
    CO2[	633	]=	1961.57740	/coeff;
    CO2[	634	]=	1961.57740	/coeff;
    CO2[	635	]=	1961.57740	/coeff;
    CO2[	636	]=	1961.57740	/coeff;
    CO2[	637	]=	1961.57740	/coeff;
    CO2[	638	]=	1961.57740	/coeff;
    CO2[	639	]=	1961.57740	/coeff;
    CO2[	640	]=	1961.57740	/coeff;
    CO2[	641	]=	1961.57740	/coeff;
    CO2[	642	]=	1961.57740	/coeff;
    CO2[	643	]=	1961.57740	/coeff;
    CO2[	644	]=	1961.57740	/coeff;
    CO2[	645	]=	1961.57740	/coeff;
    CO2[	646	]=	1961.57740	/coeff;
    CO2[	647	]=	1961.57740	/coeff;
    CO2[	648	]=	1961.57740	/coeff;
    CO2[	649	]=	1961.57740	/coeff;
    CO2[	650	]=	1961.57740	/coeff;
    CO2[	651	]=	1961.57740	/coeff;
    CO2[	652	]=	1961.57740	/coeff;
    CO2[	653	]=	1961.57740	/coeff;
    CO2[	654	]=	1961.57740	/coeff;
    CO2[	655	]=	1961.57740	/coeff;
    CO2[	656	]=	1961.57740	/coeff;
    CO2[	657	]=	1961.57740	/coeff;
    CO2[	658	]=	1961.57740	/coeff;
    CO2[	659	]=	1961.57740	/coeff;
    CO2[	660	]=	1961.57740	/coeff;
    CO2[	661	]=	1961.57740	/coeff;
    CO2[	662	]=	1961.57740	/coeff;
    CO2[	663	]=	1961.57740	/coeff;
    CO2[	664	]=	1961.57740	/coeff;
    CO2[	665	]=	1961.57740	/coeff;
    CO2[	666	]=	1961.57740	/coeff;
    CO2[	667	]=	1961.57740	/coeff;
    CO2[	668	]=	1961.57740	/coeff;
    CO2[	669	]=	1961.57740	/coeff;
    CO2[	670	]=	1961.57740	/coeff;
    CO2[	671	]=	1961.57740	/coeff;
    CO2[	672	]=	1961.57740	/coeff;
    CO2[	673	]=	1961.57740	/coeff;
    CO2[	674	]=	1961.57740	/coeff;
    CO2[	675	]=	1961.57740	/coeff;
    CO2[	676	]=	1961.57740	/coeff;
    CO2[	677	]=	1961.57740	/coeff;
    CO2[	678	]=	1961.57740	/coeff;
    CO2[	679	]=	1961.57740	/coeff;
    CO2[	680	]=	1961.57740	/coeff;
    CO2[	681	]=	1961.57740	/coeff;
    CO2[	682	]=	1961.57740	/coeff;
    CO2[	683	]=	1961.57740	/coeff;
    CO2[	684	]=	1961.57740	/coeff;
    CO2[	685	]=	1961.57740	/coeff;
    CO2[	686	]=	1961.57740	/coeff;
    CO2[	687	]=	1961.57740	/coeff;
    CO2[	688	]=	1961.57740	/coeff;
    CO2[	689	]=	1961.57740	/coeff;
    CO2[	690	]=	1961.57740	/coeff;
    CO2[	691	]=	1961.57740	/coeff;
    CO2[	692	]=	1961.57740	/coeff;
    CO2[	693	]=	1961.57740	/coeff;
    CO2[	694	]=	1961.57740	/coeff;
    CO2[	695	]=	1961.57740	/coeff;
    CO2[	696	]=	1961.57740	/coeff;
    CO2[	697	]=	1961.57740	/coeff;
    CO2[	698	]=	1961.57740	/coeff;
    CO2[	699	]=	1961.57740	/coeff;
    CO2[	700	]=	1961.57740	/coeff;
    CO2[	701	]=	1961.57740	/coeff;
    CO2[	702	]=	1961.57740	/coeff;
    CO2[	703	]=	1961.57740	/coeff;
    CO2[	704	]=	1961.57740	/coeff;
    CO2[	705	]=	1961.57740	/coeff;
    CO2[	706	]=	1961.57740	/coeff;
    CO2[	707	]=	1961.57740	/coeff;
    CO2[	708	]=	1961.57740	/coeff;
    CO2[	709	]=	1961.57740	/coeff;
    CO2[	710	]=	1961.57740	/coeff;
    CO2[	711	]=	1961.57740	/coeff;
    CO2[	712	]=	1961.57740	/coeff;
    CO2[	713	]=	1961.57740	/coeff;
    CO2[	714	]=	1961.57740	/coeff;
    CO2[	715	]=	1961.57740	/coeff;
    CO2[	716	]=	1961.57740	/coeff;
    CO2[	717	]=	1961.57740	/coeff;
    CO2[	718	]=	1961.57740	/coeff;
    CO2[	719	]=	1961.57740	/coeff;
    CO2[	720	]=	1961.57740	/coeff;
    CO2[	721	]=	1961.57740	/coeff;
    CO2[	722	]=	1961.57740	/coeff;
    CO2[	723	]=	1961.57740	/coeff;
    CO2[	724	]=	1961.57740	/coeff;
    CO2[	725	]=	1961.57740	/coeff;
    CO2[	726	]=	1961.57740	/coeff;
    CO2[	727	]=	1961.57740	/coeff;
    CO2[	728	]=	1961.57740	/coeff;
    CO2[	729	]=	1961.57740	/coeff;
    CO2[	730	]=	1961.57740	/coeff;
    CO2[	731	]=	1961.57740	/coeff;
    CO2[	732	]=	1961.57740	/coeff;
    CO2[	733	]=	1961.57740	/coeff;
    CO2[	734	]=	1961.57740	/coeff;
    CO2[	735	]=	1961.57740	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        CO2[i] = CO2[i-1];
    }
    
}


void setIemB1()
{
    
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	389.15496	;
    I_em[	246	]=	398.57916	;
    I_em[	247	]=	408.13344	;
    I_em[	248	]=	417.82572	;
    I_em[	249	]=	427.64328	;
    I_em[	250	]=	437.60232	;
    I_em[	251	]=	447.69672	;
    I_em[	252	]=	457.9332	;
    I_em[	253	]=	468.29316	;
    I_em[	254	]=	478.79112	;
    I_em[	255	]=	489.40452	;
    I_em[	256	]=	500.09304	;
    I_em[	257	]=	510.81924	;
    I_em[	258	]=	521.60208	;
    I_em[	259	]=	532.41972	;
    I_em[	260	]=	543.2898	;
    I_em[	261	]=	554.21028	;
    I_em[	262	]=	565.18656	;
    I_em[	263	]=	576.19752	;
    I_em[	264	]=	587.26176	;
    I_em[	265	]=	598.3752	;
    I_em[	266	]=	609.54888	;
    I_em[	267	]=	620.77332	;
    I_em[	268	]=	632.07012	;
    I_em[	269	]=	643.43124	;
    I_em[	270	]=	654.84444	;
    I_em[	271	]=	666.32304	;
    I_em[	272	]=	677.86716	;
    I_em[	273	]=	689.4642	;
    I_em[	274	]=	701.12724	;
    I_em[	275	]=	712.83156	;
    I_em[	276	]=	724.50948	;
    I_em[	277	]=	736.14636	;
    I_em[	278	]=	747.73176	;
    I_em[	279	]=	759.28188	;
    I_em[	280	]=	770.79816	;
    I_em[	281	]=	782.25936	;
    I_em[	282	]=	793.67844	;
    I_em[	283	]=	805.05696	;
    I_em[	284	]=	816.3954	;
    I_em[	285	]=	827.66088	;
    I_em[	286	]=	838.79736	;
    I_em[	287	]=	849.78036	;
    I_em[	288	]=	860.613	;
    I_em[	289	]=	871.28376	;
    I_em[	290	]=	881.79552	;
    I_em[	291	]=	892.15896	;
    I_em[	292	]=	902.36472	;
    I_em[	293	]=	912.41316	;
    I_em[	294	]=	922.31664	;
    I_em[	295	]=	932.05716	;
    I_em[	296	]=	941.64252	;
    I_em[	297	]=	951.07536	;
    I_em[	298	]=	960.34992	;
    I_em[	299	]=	969.46152	;
    I_em[	300	]=	978.42072	;
    I_em[	301	]=	987.22632	;
    I_em[	302	]=	995.87712	;
    I_em[	303	]=	1004.36832	;
    I_em[	304	]=	1012.69512	;
    I_em[	305	]=	1020.88032	;
    I_em[	306	]=	1028.90952	;
    I_em[	307	]=	1036.78632	;
    I_em[	308	]=	1044.51792	;
    I_em[	309	]=	1052.10672	;
    I_em[	310	]=	1059.54192	;
    I_em[	311	]=	1066.83192	;
    I_em[	312	]=	1073.98392	;
    I_em[	313	]=	1080.97272	;
    I_em[	314	]=	1087.82832	;
    I_em[	315	]=	1094.52552	;
    I_em[	316	]=	1101.08592	;
    I_em[	317	]=	1107.51432	;
    I_em[	318	]=	1113.79752	;
    I_em[	319	]=	1119.95112	;
    I_em[	320	]=	1125.95712	;
    I_em[	321	]=	1131.83232	;
    I_em[	322	]=	1137.56352	;
    I_em[	323	]=	1143.16032	;
    I_em[	324	]=	1148.62512	;
    I_em[	325	]=	1153.95672	;
    I_em[	326	]=	1159.16952	;
    I_em[	327	]=	1164.26352	;
    I_em[	328	]=	1169.26152	;
    I_em[	329	]=	1174.13952	;
    I_em[	330	]=	1178.92032	;
    I_em[	331	]=	1183.58232	;
    I_em[	332	]=	1188.13872	;
    I_em[	333	]=	1192.58952	;
    I_em[	334	]=	1196.93352	;
    I_em[	335	]=	1201.16352	;
    I_em[	336	]=	1205.31912	;
    I_em[	337	]=	1209.37992	;
    I_em[	338	]=	1213.35792	;
    I_em[	339	]=	1217.24592	;
    I_em[	340	]=	1221.05352	;
    I_em[	341	]=	1224.77472	;
    I_em[	342	]=	1228.42152	;
    I_em[	343	]=	1231.96872	;
    I_em[	344	]=	1235.44512	;
    I_em[	345	]=	1238.81952	;
    I_em[	346	]=	1242.12432	;
    I_em[	347	]=	1245.34272	;
    I_em[	348	]=	1248.47352	;
    I_em[	349	]=	1251.52032	;
    I_em[	350	]=	1254.48072	;
    I_em[	351	]=	1257.35592	;
    I_em[	352	]=	1260.14112	;
    I_em[	353	]=	1262.85432	;
    I_em[	354	]=	1265.48112	;
    I_em[	355	]=	1268.01792	;
    I_em[	356	]=	1270.47072	;
    I_em[	357	]=	1272.83712	;
    I_em[	358	]=	1275.13032	;
    I_em[	359	]=	1277.32032	;
    I_em[	360	]=	1279.43832	;
    I_em[	361	]=	1281.46992	;
    I_em[	362	]=	1283.42352	;
    I_em[	363	]=	1285.28232	;
    I_em[	364	]=	1287.06192	;
    I_em[	365	]=	1288.74792	;
    I_em[	366	]=	1290.36072	;
    I_em[	367	]=	1291.87752	;
    I_em[	368	]=	1293.32112	;
    I_em[	369	]=	1294.67832	;
    I_em[	370	]=	1295.94552	;
    I_em[	371	]=	1297.12752	;
    I_em[	372	]=	1298.22432	;
    I_em[	373	]=	1299.24552	;
    I_em[	374	]=	1300.16712	;
    I_em[	375	]=	1301.01912	;
    I_em[	376	]=	1301.77752	;
    I_em[	377	]=	1302.46032	;
    I_em[	378	]=	1303.04352	;
    I_em[	379	]=	1303.55232	;
    I_em[	380	]=	1303.98672	;
    I_em[	381	]=	1304.31792	;
    I_em[	382	]=	1304.57712	;
    I_em[	383	]=	1304.73912	;
    I_em[	384	]=	1304.82792	;
    I_em[	385	]=	1304.84232	;
    
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
}

void setIemA1T()//A1T
{
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	389.19348	;
    I_em[	246	]=	398.66364	;
    I_em[	247	]=	408.2292	;
    I_em[	248	]=	417.86556	;
    I_em[	249	]=	427.60812	;
    I_em[	250	]=	437.427	;
    I_em[	251	]=	447.33804	;
    I_em[	252	]=	457.32936	;
    I_em[	253	]=	467.41524	;
    I_em[	254	]=	477.59052	;
    I_em[	255	]=	487.87452	;
    I_em[	256	]=	498.34212	;
    I_em[	257	]=	509.02896	;
    I_em[	258	]=	519.9354	;
    I_em[	259	]=	531.04944	;
    I_em[	260	]=	542.37048	;
    I_em[	261	]=	553.90836	;
    I_em[	262	]=	565.65504	;
    I_em[	263	]=	577.61028	;
    I_em[	264	]=	589.78032	;
    I_em[	265	]=	602.1402	;
    I_em[	266	]=	614.55252	;
    I_em[	267	]=	626.9904	;
    I_em[	268	]=	639.45696	;
    I_em[	269	]=	651.94716	;
    I_em[	270	]=	664.47012	;
    I_em[	271	]=	677.02176	;
    I_em[	272	]=	689.59392	;
    I_em[	273	]=	702.18384	;
    I_em[	274	]=	714.81816	;
    I_em[	275	]=	727.45236	;
    I_em[	276	]=	740.07	;
    I_em[	277	]=	752.65056	;
    I_em[	278	]=	765.18396	;
    I_em[	279	]=	777.67584	;
    I_em[	280	]=	790.14108	;
    I_em[	281	]=	802.55484	;
    I_em[	282	]=	814.938	;
    I_em[	283	]=	827.28372	;
    I_em[	284	]=	839.58168	;
    I_em[	285	]=	851.84532	;
    I_em[	286	]=	864.01968	;
    I_em[	287	]=	876.10512	;
    I_em[	288	]=	888.11088	;
    I_em[	289	]=	900.01284	;
    I_em[	290	]=	911.8392	;
    I_em[	291	]=	923.57748	;
    I_em[	292	]=	935.22624	;
    I_em[	293	]=	946.77672	;
    I_em[	294	]=	958.25352	;
    I_em[	295	]=	969.62232	;
    I_em[	296	]=	980.85672	;
    I_em[	297	]=	991.93632	;
    I_em[	298	]=	1002.86832	;
    I_em[	299	]=	1013.65032	;
    I_em[	300	]=	1024.27632	;
    I_em[	301	]=	1034.75232	;
    I_em[	302	]=	1045.08912	;
    I_em[	303	]=	1055.26512	;
    I_em[	304	]=	1065.28632	;
    I_em[	305	]=	1075.16712	;
    I_em[	306	]=	1084.85832	;
    I_em[	307	]=	1094.35392	;
    I_em[	308	]=	1103.67912	;
    I_em[	309	]=	1112.81832	;
    I_em[	310	]=	1121.76192	;
    I_em[	311	]=	1130.52432	;
    I_em[	312	]=	1139.09832	;
    I_em[	313	]=	1147.49472	;
    I_em[	314	]=	1155.70392	;
    I_em[	315	]=	1163.72712	;
    I_em[	316	]=	1171.56912	;
    I_em[	317	]=	1179.24672	;
    I_em[	318	]=	1186.73112	;
    I_em[	319	]=	1194.04992	;
    I_em[	320	]=	1201.18512	;
    I_em[	321	]=	1208.15832	;
    I_em[	322	]=	1214.93952	;
    I_em[	323	]=	1221.54552	;
    I_em[	324	]=	1227.98472	;
    I_em[	325	]=	1234.24272	;
    I_em[	326	]=	1240.30392	;
    I_em[	327	]=	1246.16832	;
    I_em[	328	]=	1251.85152	;
    I_em[	329	]=	1257.33072	;
    I_em[	330	]=	1262.61672	;
    I_em[	331	]=	1267.71072	;
    I_em[	332	]=	1272.60912	;
    I_em[	333	]=	1277.31672	;
    I_em[	334	]=	1281.82992	;
    I_em[	335	]=	1286.16912	;
    I_em[	336	]=	1290.40032	;
    I_em[	337	]=	1294.54392	;
    I_em[	338	]=	1298.60352	;
    I_em[	339	]=	1302.57432	;
    I_em[	340	]=	1306.45992	;
    I_em[	341	]=	1310.24952	;
    I_em[	342	]=	1313.96592	;
    I_em[	343	]=	1317.59712	;
    I_em[	344	]=	1321.13232	;
    I_em[	345	]=	1324.59192	;
    I_em[	346	]=	1327.96032	;
    I_em[	347	]=	1331.23392	;
    I_em[	348	]=	1334.43192	;
    I_em[	349	]=	1337.54352	;
    I_em[	350	]=	1340.56512	;
    I_em[	351	]=	1343.49312	;
    I_em[	352	]=	1346.34192	;
    I_em[	353	]=	1349.10792	;
    I_em[	354	]=	1351.78872	;
    I_em[	355	]=	1354.36992	;
    I_em[	356	]=	1356.87792	;
    I_em[	357	]=	1359.28872	;
    I_em[	358	]=	1361.62512	;
    I_em[	359	]=	1363.87392	;
    I_em[	360	]=	1366.02192	;
    I_em[	361	]=	1368.09312	;
    I_em[	362	]=	1370.08032	;
    I_em[	363	]=	1371.98232	;
    I_em[	364	]=	1373.79792	;
    I_em[	365	]=	1375.52592	;
    I_em[	366	]=	1377.16272	;
    I_em[	367	]=	1378.71312	;
    I_em[	368	]=	1380.18672	;
    I_em[	369	]=	1381.57272	;
    I_em[	370	]=	1382.85912	;
    I_em[	371	]=	1384.07112	;
    I_em[	372	]=	1385.19672	;
    I_em[	373	]=	1386.22392	;
    I_em[	374	]=	1387.18512	;
    I_em[	375	]=	1388.04912	;
    I_em[	376	]=	1388.82072	;
    I_em[	377	]=	1389.51192	;
    I_em[	378	]=	1390.11672	;
    I_em[	379	]=	1390.63152	;
    I_em[	380	]=	1391.06112	;
    I_em[	381	]=	1391.40672	;
    I_em[	382	]=	1391.66592	;
    I_em[	383	]=	1391.83872	;
    I_em[	384	]=	1391.92272	;
    I_em[	385	]=	1391.93592	;
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
}

void setIemA1AIM() //A1AIM
{
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	389.94564	;
    I_em[	246	]=	400.99968	;
    I_em[	247	]=	412.23576	;
    I_em[	248	]=	423.64464	;
    I_em[	249	]=	435.23136	;
    I_em[	250	]=	446.99688	;
    I_em[	251	]=	458.93532	;
    I_em[	252	]=	471.05028	;
    I_em[	253	]=	483.34632	;
    I_em[	254	]=	495.81564	;
    I_em[	255	]=	508.46208	;
    I_em[	256	]=	521.29356	;
    I_em[	257	]=	534.30516	;
    I_em[	258	]=	547.49688	;
    I_em[	259	]=	560.88312	;
    I_em[	260	]=	574.44324	;
    I_em[	261	]=	588.20304	;
    I_em[	262	]=	602.12796	;
    I_em[	263	]=	616.25412	;
    I_em[	264	]=	630.552	;
    I_em[	265	]=	645.02652	;
    I_em[	266	]=	659.604	;
    I_em[	267	]=	674.268	;
    I_em[	268	]=	689.01648	;
    I_em[	269	]=	703.85472	;
    I_em[	270	]=	718.77372	;
    I_em[	271	]=	733.785	;
    I_em[	272	]=	748.8786	;
    I_em[	273	]=	764.05452	;
    I_em[	274	]=	779.331	;
    I_em[	275	]=	794.68524	;
    I_em[	276	]=	810.14304	;
    I_em[	277	]=	825.7038	;
    I_em[	278	]=	841.37148	;
    I_em[	279	]=	857.13468	;
    I_em[	280	]=	873.00744	;
    I_em[	281	]=	888.9888	;
    I_em[	282	]=	905.0688	;
    I_em[	283	]=	921.25176	;
    I_em[	284	]=	937.54272	;
    I_em[	285	]=	953.89752	;
    I_em[	286	]=	970.24992	;
    I_em[	287	]=	986.57352	;
    I_em[	288	]=	1002.84192	;
    I_em[	289	]=	1019.07432	;
    I_em[	290	]=	1035.28392	;
    I_em[	291	]=	1051.43472	;
    I_em[	292	]=	1067.56512	;
    I_em[	293	]=	1083.64272	;
    I_em[	294	]=	1099.69632	;
    I_em[	295	]=	1115.69592	;
    I_em[	296	]=	1131.68472	;
    I_em[	297	]=	1147.63032	;
    I_em[	298	]=	1163.55912	;
    I_em[	299	]=	1179.45672	;
    I_em[	300	]=	1195.32792	;
    I_em[	301	]=	1211.16552	;
    I_em[	302	]=	1226.98872	;
    I_em[	303	]=	1242.77232	;
    I_em[	304	]=	1258.52592	;
    I_em[	305	]=	1274.25432	;
    I_em[	306	]=	1289.93592	;
    I_em[	307	]=	1305.55152	;
    I_em[	308	]=	1321.12272	;
    I_em[	309	]=	1336.64592	;
    I_em[	310	]=	1352.10552	;
    I_em[	311	]=	1367.50872	;
    I_em[	312	]=	1382.85792	;
    I_em[	313	]=	1398.15072	;
    I_em[	314	]=	1413.39792	;
    I_em[	315	]=	1428.58032	;
    I_em[	316	]=	1443.67032	;
    I_em[	317	]=	1458.67992	;
    I_em[	318	]=	1473.60072	;
    I_em[	319	]=	1488.44472	;
    I_em[	320	]=	1503.18312	;
    I_em[	321	]=	1517.84112	;
    I_em[	322	]=	1532.40672	;
    I_em[	323	]=	1546.89552	;
    I_em[	324	]=	1561.28472	;
    I_em[	325	]=	1575.58872	;
    I_em[	326	]=	1589.80872	;
    I_em[	327	]=	1603.94832	;
    I_em[	328	]=	1618.01592	;
    I_em[	329	]=	1631.98392	;
    I_em[	330	]=	1645.87872	;
    I_em[	331	]=	1659.70272	;
    I_em[	332	]=	1673.43552	;
    I_em[	333	]=	1687.09152	;
    I_em[	334	]=	1700.66472	;
    I_em[	335	]=	1714.11792	;
    I_em[	336	]=	1727.34672	;
    I_em[	337	]=	1740.29952	;
    I_em[	338	]=	1752.97152	;
    I_em[	339	]=	1765.38912	;
    I_em[	340	]=	1777.52832	;
    I_em[	341	]=	1789.40472	;
    I_em[	342	]=	1801.00632	;
    I_em[	343	]=	1812.33192	;
    I_em[	344	]=	1823.39592	;
    I_em[	345	]=	1834.18872	;
    I_em[	346	]=	1844.71392	;
    I_em[	347	]=	1854.96792	;
    I_em[	348	]=	1864.94952	;
    I_em[	349	]=	1874.66112	;
    I_em[	350	]=	1884.10392	;
    I_em[	351	]=	1893.28872	;
    I_em[	352	]=	1902.18192	;
    I_em[	353	]=	1910.82192	;
    I_em[	354	]=	1919.18592	;
    I_em[	355	]=	1927.27512	;
    I_em[	356	]=	1935.09912	;
    I_em[	357	]=	1942.65672	;
    I_em[	358	]=	1949.94312	;
    I_em[	359	]=	1956.96432	;
    I_em[	360	]=	1963.70592	;
    I_em[	361	]=	1970.17872	;
    I_em[	362	]=	1976.38632	;
    I_em[	363	]=	1982.32752	;
    I_em[	364	]=	1987.99752	;
    I_em[	365	]=	1993.39272	;
    I_em[	366	]=	1998.52272	;
    I_em[	367	]=	2003.37192	;
    I_em[	368	]=	2007.96552	;
    I_em[	369	]=	2012.27952	;
    I_em[	370	]=	2016.32952	;
    I_em[	371	]=	2020.10472	;
    I_em[	372	]=	2023.61592	;
    I_em[	373	]=	2026.84992	;
    I_em[	374	]=	2029.81752	;
    I_em[	375	]=	2032.51872	;
    I_em[	376	]=	2034.95472	;
    I_em[	377	]=	2037.10512	;
    I_em[	378	]=	2038.99512	;
    I_em[	379	]=	2040.61152	;
    I_em[	380	]=	2041.96032	;
    I_em[	381	]=	2043.04512	;
    I_em[	382	]=	2043.85392	;
    I_em[	383	]=	2044.39032	;
    I_em[	384	]=	2044.66272	;
    I_em[	385	]=	2044.71552	;
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
    
    
}

void setIemB2() //B2 MESSAGE
{
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	388.88856	;
    I_em[	246	]=	397.70748	;
    I_em[	247	]=	406.55148	;
    I_em[	248	]=	415.4142	;
    I_em[	249	]=	424.30428	;
    I_em[	250	]=	433.22916	;
    I_em[	251	]=	442.18092	;
    I_em[	252	]=	451.15464	;
    I_em[	253	]=	460.15356	;
    I_em[	254	]=	469.18248	;
    I_em[	255	]=	478.25532	;
    I_em[	256	]=	487.38624	;
    I_em[	257	]=	496.61724	;
    I_em[	258	]=	505.9266	;
    I_em[	259	]=	515.31396	;
    I_em[	260	]=	524.79396	;
    I_em[	261	]=	534.35172	;
    I_em[	262	]=	544.0014	;
    I_em[	263	]=	553.73136	;
    I_em[	264	]=	563.55732	;
    I_em[	265	]=	573.45264	;
    I_em[	266	]=	583.43568	;
    I_em[	267	]=	593.49228	;
    I_em[	268	]=	603.62976	;
    I_em[	269	]=	613.85616	;
    I_em[	270	]=	624.15	;
    I_em[	271	]=	634.52736	;
    I_em[	272	]=	644.9814	;
    I_em[	273	]=	655.52688	;
    I_em[	274	]=	666.1434	;
    I_em[	275	]=	676.82292	;
    I_em[	276	]=	687.55068	;
    I_em[	277	]=	698.3142	;
    I_em[	278	]=	709.10616	;
    I_em[	279	]=	719.92332	;
    I_em[	280	]=	730.77288	;
    I_em[	281	]=	741.6624	;
    I_em[	282	]=	752.57256	;
    I_em[	283	]=	763.52904	;
    I_em[	284	]=	774.50232	;
    I_em[	285	]=	785.51724	;
    I_em[	286	]=	796.5774	;
    I_em[	287	]=	807.68928	;
    I_em[	288	]=	818.85132	;
    I_em[	289	]=	830.0508	;
    I_em[	290	]=	841.3158	;
    I_em[	291	]=	852.60852	;
    I_em[	292	]=	863.964	;
    I_em[	293	]=	875.3724	;
    I_em[	294	]=	886.821	;
    I_em[	295	]=	898.31604	;
    I_em[	296	]=	909.83208	;
    I_em[	297	]=	921.34572	;
    I_em[	298	]=	932.88972	;
    I_em[	299	]=	944.42988	;
    I_em[	300	]=	955.99284	;
    I_em[	301	]=	967.56312	;
    I_em[	302	]=	979.15632	;
    I_em[	303	]=	990.74472	;
    I_em[	304	]=	1002.35832	;
    I_em[	305	]=	1013.98272	;
    I_em[	306	]=	1025.65992	;
    I_em[	307	]=	1037.38872	;
    I_em[	308	]=	1049.17392	;
    I_em[	309	]=	1061.00472	;
    I_em[	310	]=	1072.89672	;
    I_em[	311	]=	1084.83672	;
    I_em[	312	]=	1096.82952	;
    I_em[	313	]=	1108.88472	;
    I_em[	314	]=	1120.98912	;
    I_em[	315	]=	1133.14512	;
    I_em[	316	]=	1145.37432	;
    I_em[	317	]=	1157.65872	;
    I_em[	318	]=	1170.00192	;
    I_em[	319	]=	1182.42672	;
    I_em[	320	]=	1194.89832	;
    I_em[	321	]=	1207.44432	;
    I_em[	322	]=	1220.04552	;
    I_em[	323	]=	1232.71872	;
    I_em[	324	]=	1245.44832	;
    I_em[	325	]=	1258.24992	;
    I_em[	326	]=	1271.09952	;
    I_em[	327	]=	1283.99952	;
    I_em[	328	]=	1296.95952	;
    I_em[	329	]=	1309.96752	;
    I_em[	330	]=	1323.02232	;
    I_em[	331	]=	1336.13832	;
    I_em[	332	]=	1349.31312	;
    I_em[	333	]=	1362.52512	;
    I_em[	334	]=	1375.80072	;
    I_em[	335	]=	1389.07512	;
    I_em[	336	]=	1402.14072	;
    I_em[	337	]=	1414.92792	;
    I_em[	338	]=	1427.45592	;
    I_em[	339	]=	1439.71512	;
    I_em[	340	]=	1451.70552	;
    I_em[	341	]=	1463.43432	;
    I_em[	342	]=	1474.90152	;
    I_em[	343	]=	1486.09392	;
    I_em[	344	]=	1497.01632	;
    I_em[	345	]=	1507.67592	;
    I_em[	346	]=	1518.07872	;
    I_em[	347	]=	1528.20432	;
    I_em[	348	]=	1538.05872	;
    I_em[	349	]=	1547.66232	;
    I_em[	350	]=	1556.98992	;
    I_em[	351	]=	1566.04512	;
    I_em[	352	]=	1574.84352	;
    I_em[	353	]=	1583.37552	;
    I_em[	354	]=	1591.63632	;
    I_em[	355	]=	1599.62952	;
    I_em[	356	]=	1607.35752	;
    I_em[	357	]=	1614.81912	;
    I_em[	358	]=	1622.02392	;
    I_em[	359	]=	1628.95032	;
    I_em[	360	]=	1635.61632	;
    I_em[	361	]=	1642.00512	;
    I_em[	362	]=	1648.14192	;
    I_em[	363	]=	1654.00752	;
    I_em[	364	]=	1659.59952	;
    I_em[	365	]=	1664.94072	;
    I_em[	366	]=	1669.99872	;
    I_em[	367	]=	1674.79392	;
    I_em[	368	]=	1679.33232	;
    I_em[	369	]=	1683.59592	;
    I_em[	370	]=	1687.59672	;
    I_em[	371	]=	1691.32512	;
    I_em[	372	]=	1694.78592	;
    I_em[	373	]=	1697.98872	;
    I_em[	374	]=	1700.91912	;
    I_em[	375	]=	1703.59152	;
    I_em[	376	]=	1705.98312	;
    I_em[	377	]=	1708.11432	;
    I_em[	378	]=	1709.98392	;
    I_em[	379	]=	1711.58472	;
    I_em[	380	]=	1712.91552	;
    I_em[	381	]=	1713.98112	;
    I_em[	382	]=	1714.78872	;
    I_em[	383	]=	1715.31672	;
    I_em[	384	]=	1715.58912	;
    I_em[	385	]=	1715.62512	;
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
}

void setIemA2() //A2 ASF
{
    
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	389.31768	;
    I_em[	246	]=	399.17064	;
    I_em[	247	]=	409.2888	;
    I_em[	248	]=	419.68056	;
    I_em[	249	]=	430.3302	;
    I_em[	250	]=	441.255	;
    I_em[	251	]=	452.43564	;
    I_em[	252	]=	463.89204	;
    I_em[	253	]=	475.62444	;
    I_em[	254	]=	487.61604	;
    I_em[	255	]=	499.872	;
    I_em[	256	]=	512.37336	;
    I_em[	257	]=	525.12888	;
    I_em[	258	]=	538.12944	;
    I_em[	259	]=	551.37744	;
    I_em[	260	]=	564.87432	;
    I_em[	261	]=	578.62272	;
    I_em[	262	]=	592.6098	;
    I_em[	263	]=	606.85128	;
    I_em[	264	]=	621.33576	;
    I_em[	265	]=	636.04776	;
    I_em[	266	]=	650.91336	;
    I_em[	267	]=	665.91276	;
    I_em[	268	]=	681.04884	;
    I_em[	269	]=	696.32148	;
    I_em[	270	]=	711.7266	;
    I_em[	271	]=	727.25856	;
    I_em[	272	]=	742.9392	;
    I_em[	273	]=	758.75292	;
    I_em[	274	]=	774.6924	;
    I_em[	275	]=	790.7712	;
    I_em[	276	]=	806.991	;
    I_em[	277	]=	823.33884	;
    I_em[	278	]=	839.82984	;
    I_em[	279	]=	856.4526	;
    I_em[	280	]=	873.20544	;
    I_em[	281	]=	890.09496	;
    I_em[	282	]=	907.12932	;
    I_em[	283	]=	924.28992	;
    I_em[	284	]=	941.57832	;
    I_em[	285	]=	959.02272	;
    I_em[	286	]=	976.62312	;
    I_em[	287	]=	994.39992	;
    I_em[	288	]=	1012.36152	;
    I_em[	289	]=	1030.47672	;
    I_em[	290	]=	1048.78032	;
    I_em[	291	]=	1067.25072	;
    I_em[	292	]=	1085.88672	;
    I_em[	293	]=	1104.70032	;
    I_em[	294	]=	1123.69032	;
    I_em[	295	]=	1142.86152	;
    I_em[	296	]=	1162.18512	;
    I_em[	297	]=	1181.70192	;
    I_em[	298	]=	1201.37712	;
    I_em[	299	]=	1221.23472	;
    I_em[	300	]=	1241.25792	;
    I_em[	301	]=	1261.45512	;
    I_em[	302	]=	1281.83352	;
    I_em[	303	]=	1302.37392	;
    I_em[	304	]=	1323.09312	;
    I_em[	305	]=	1343.99712	;
    I_em[	306	]=	1365.11832	;
    I_em[	307	]=	1386.47232	;
    I_em[	308	]=	1408.06872	;
    I_em[	309	]=	1429.88712	;
    I_em[	310	]=	1451.94552	;
    I_em[	311	]=	1474.22952	;
    I_em[	312	]=	1496.75712	;
    I_em[	313	]=	1519.51872	;
    I_em[	314	]=	1542.49992	;
    I_em[	315	]=	1565.73552	;
    I_em[	316	]=	1589.24472	;
    I_em[	317	]=	1613.05272	;
    I_em[	318	]=	1637.15592	;
    I_em[	319	]=	1661.56032	;
    I_em[	320	]=	1686.25152	;
    I_em[	321	]=	1711.23192	;
    I_em[	322	]=	1736.51472	;
    I_em[	323	]=	1762.08552	;
    I_em[	324	]=	1787.94672	;
    I_em[	325	]=	1814.10072	;
    I_em[	326	]=	1840.55712	;
    I_em[	327	]=	1867.30392	;
    I_em[	328	]=	1894.34832	;
    I_em[	329	]=	1921.68072	;
    I_em[	330	]=	1949.29992	;
    I_em[	331	]=	1977.22032	;
    I_em[	332	]=	2005.43592	;
    I_em[	333	]=	2033.93472	;
    I_em[	334	]=	2062.74192	;
    I_em[	335	]=	2091.68592	;
    I_em[	336	]=	2120.19552	;
    I_em[	337	]=	2148.12312	;
    I_em[	338	]=	2175.46992	;
    I_em[	339	]=	2202.23352	;
    I_em[	340	]=	2228.42352	;
    I_em[	341	]=	2254.02792	;
    I_em[	342	]=	2279.04792	;
    I_em[	343	]=	2303.48712	;
    I_em[	344	]=	2327.33472	;
    I_em[	345	]=	2350.61712	;
    I_em[	346	]=	2373.30912	;
    I_em[	347	]=	2395.41912	;
    I_em[	348	]=	2416.94352	;
    I_em[	349	]=	2437.89192	;
    I_em[	350	]=	2458.25472	;
    I_em[	351	]=	2478.04152	;
    I_em[	352	]=	2497.24032	;
    I_em[	353	]=	2515.85472	;
    I_em[	354	]=	2533.89792	;
    I_em[	355	]=	2551.35552	;
    I_em[	356	]=	2568.22272	;
    I_em[	357	]=	2584.52112	;
    I_em[	358	]=	2600.23152	;
    I_em[	359	]=	2615.35992	;
    I_em[	360	]=	2629.90392	;
    I_em[	361	]=	2643.87432	;
    I_em[	362	]=	2657.25432	;
    I_em[	363	]=	2670.06072	;
    I_em[	364	]=	2682.27072	;
    I_em[	365	]=	2693.90952	;
    I_em[	366	]=	2704.96392	;
    I_em[	367	]=	2715.44472	;
    I_em[	368	]=	2725.33632	;
    I_em[	369	]=	2734.64472	;
    I_em[	370	]=	2743.36992	;
    I_em[	371	]=	2751.51552	;
    I_em[	372	]=	2759.07912	;
    I_em[	373	]=	2766.06072	;
    I_em[	374	]=	2772.47112	;
    I_em[	375	]=	2778.28752	;
    I_em[	376	]=	2783.52312	;
    I_em[	377	]=	2788.17552	;
    I_em[	378	]=	2792.24952	;
    I_em[	379	]=	2795.74032	;
    I_em[	380	]=	2798.65272	;
    I_em[	381	]=	2800.98312	;
    I_em[	382	]=	2802.73392	;
    I_em[	383	]=	2803.89192	;
    I_em[	384	]=	2804.48352	;
    I_em[	385	]=	2804.58072	;
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
}

void setIemA1G() //A1G MINICAM
{
    
    I_em[	0	]=	0	;
    I_em[	1	]=	0.05964	;
    I_em[	2	]=	0.1398	;
    I_em[	3	]=	0.22596	;
    I_em[	4	]=	0.31704	;
    I_em[	5	]=	0.4272	;
    I_em[	6	]=	0.54372	;
    I_em[	7	]=	0.65484	;
    I_em[	8	]=	0.79512	;
    I_em[	9	]=	0.93084	;
    I_em[	10	]=	1.0836	;
    I_em[	11	]=	1.24404	;
    I_em[	12	]=	1.41072	;
    I_em[	13	]=	1.596	;
    I_em[	14	]=	1.78764	;
    I_em[	15	]=	1.98612	;
    I_em[	16	]=	2.20344	;
    I_em[	17	]=	2.42736	;
    I_em[	18	]=	2.65788	;
    I_em[	19	]=	2.9076	;
    I_em[	20	]=	3.16428	;
    I_em[	21	]=	3.42744	;
    I_em[	22	]=	3.71016	;
    I_em[	23	]=	3.99996	;
    I_em[	24	]=	4.3086	;
    I_em[	25	]=	4.62492	;
    I_em[	26	]=	4.9482	;
    I_em[	27	]=	5.2788	;
    I_em[	28	]=	5.6286	;
    I_em[	29	]=	5.99808	;
    I_em[	30	]=	6.37368	;
    I_em[	31	]=	6.75768	;
    I_em[	32	]=	7.1604	;
    I_em[	33	]=	7.57068	;
    I_em[	34	]=	7.99836	;
    I_em[	35	]=	8.43192	;
    I_em[	36	]=	8.86992	;
    I_em[	37	]=	9.32244	;
    I_em[	38	]=	9.79008	;
    I_em[	39	]=	10.24692	;
    I_em[	40	]=	10.72944	;
    I_em[	41	]=	11.19828	;
    I_em[	42	]=	11.6814	;
    I_em[	43	]=	12.16056	;
    I_em[	44	]=	12.63504	;
    I_em[	45	]=	13.12128	;
    I_em[	46	]=	13.60092	;
    I_em[	47	]=	14.08596	;
    I_em[	48	]=	14.57832	;
    I_em[	49	]=	15.06552	;
    I_em[	50	]=	15.53028	;
    I_em[	51	]=	15.987	;
    I_em[	52	]=	16.44636	;
    I_em[	53	]=	16.88448	;
    I_em[	54	]=	17.31324	;
    I_em[	55	]=	17.74812	;
    I_em[	56	]=	18.1638	;
    I_em[	57	]=	18.5868	;
    I_em[	58	]=	18.993	;
    I_em[	59	]=	19.39536	;
    I_em[	60	]=	19.79844	;
    I_em[	61	]=	20.18088	;
    I_em[	62	]=	20.5818	;
    I_em[	63	]=	20.97864	;
    I_em[	64	]=	21.39036	;
    I_em[	65	]=	21.7956	;
    I_em[	66	]=	22.19124	;
    I_em[	67	]=	22.59084	;
    I_em[	68	]=	23.01876	;
    I_em[	69	]=	23.4558	;
    I_em[	70	]=	23.89236	;
    I_em[	71	]=	24.34584	;
    I_em[	72	]=	24.81348	;
    I_em[	73	]=	25.28928	;
    I_em[	74	]=	25.79352	;
    I_em[	75	]=	26.29644	;
    I_em[	76	]=	26.82348	;
    I_em[	77	]=	27.36588	;
    I_em[	78	]=	27.91392	;
    I_em[	79	]=	28.45692	;
    I_em[	80	]=	29.01024	;
    I_em[	81	]=	29.56068	;
    I_em[	82	]=	30.10248	;
    I_em[	83	]=	30.64116	;
    I_em[	84	]=	31.1826	;
    I_em[	85	]=	31.70844	;
    I_em[	86	]=	32.22432	;
    I_em[	87	]=	32.74824	;
    I_em[	88	]=	33.261	;
    I_em[	89	]=	33.7584	;
    I_em[	90	]=	34.24728	;
    I_em[	91	]=	34.7394	;
    I_em[	92	]=	35.2296	;
    I_em[	93	]=	35.70468	;
    I_em[	94	]=	36.18876	;
    I_em[	95	]=	36.67728	;
    I_em[	96	]=	37.15356	;
    I_em[	97	]=	37.64484	;
    I_em[	98	]=	38.14512	;
    I_em[	99	]=	38.65104	;
    I_em[	100	]=	39.16596	;
    I_em[	101	]=	39.69048	;
    I_em[	102	]=	40.25304	;
    I_em[	103	]=	40.81452	;
    I_em[	104	]=	41.38848	;
    I_em[	105	]=	41.98668	;
    I_em[	106	]=	42.59844	;
    I_em[	107	]=	43.22364	;
    I_em[	108	]=	43.87644	;
    I_em[	109	]=	44.5446	;
    I_em[	110	]=	45.24132	;
    I_em[	111	]=	45.96576	;
    I_em[	112	]=	46.70664	;
    I_em[	113	]=	47.47488	;
    I_em[	114	]=	48.26052	;
    I_em[	115	]=	49.07304	;
    I_em[	116	]=	49.89756	;
    I_em[	117	]=	50.74668	;
    I_em[	118	]=	51.6174	;
    I_em[	119	]=	52.52496	;
    I_em[	120	]=	53.44236	;
    I_em[	121	]=	54.37872	;
    I_em[	122	]=	55.31028	;
    I_em[	123	]=	56.27124	;
    I_em[	124	]=	57.23604	;
    I_em[	125	]=	58.21404	;
    I_em[	126	]=	59.19108	;
    I_em[	127	]=	60.16548	;
    I_em[	128	]=	61.13448	;
    I_em[	129	]=	62.09316	;
    I_em[	130	]=	63.05544	;
    I_em[	131	]=	64.00908	;
    I_em[	132	]=	64.97076	;
    I_em[	133	]=	65.9184	;
    I_em[	134	]=	66.8808	;
    I_em[	135	]=	67.85916	;
    I_em[	136	]=	68.84688	;
    I_em[	137	]=	69.84612	;
    I_em[	138	]=	70.8606	;
    I_em[	139	]=	71.90436	;
    I_em[	140	]=	72.978	;
    I_em[	141	]=	74.06772	;
    I_em[	142	]=	75.1842	;
    I_em[	143	]=	76.31172	;
    I_em[	144	]=	77.44872	;
    I_em[	145	]=	78.61656	;
    I_em[	146	]=	79.77912	;
    I_em[	147	]=	80.96988	;
    I_em[	148	]=	82.16496	;
    I_em[	149	]=	83.37708	;
    I_em[	150	]=	84.59028	;
    I_em[	151	]=	85.81836	;
    I_em[	152	]=	87.0486	;
    I_em[	153	]=	88.29108	;
    I_em[	154	]=	89.53416	;
    I_em[	155	]=	90.77748	;
    I_em[	156	]=	92.04228	;
    I_em[	157	]=	93.29652	;
    I_em[	158	]=	94.55892	;
    I_em[	159	]=	95.81508	;
    I_em[	160	]=	97.07772	;
    I_em[	161	]=	98.33064	;
    I_em[	162	]=	99.5736	;
    I_em[	163	]=	100.80156	;
    I_em[	164	]=	102.04488	;
    I_em[	165	]=	103.25256	;
    I_em[	166	]=	104.46156	;
    I_em[	167	]=	105.66264	;
    I_em[	168	]=	106.86984	;
    I_em[	169	]=	108.05976	;
    I_em[	170	]=	109.26132	;
    I_em[	171	]=	110.46276	;
    I_em[	172	]=	111.66828	;
    I_em[	173	]=	112.8816	;
    I_em[	174	]=	114.10488	;
    I_em[	175	]=	115.3536	;
    I_em[	176	]=	116.60928	;
    I_em[	177	]=	117.89436	;
    I_em[	178	]=	119.21808	;
    I_em[	179	]=	120.5664	;
    I_em[	180	]=	121.95792	;
    I_em[	181	]=	123.37824	;
    I_em[	182	]=	124.85712	;
    I_em[	183	]=	126.36912	;
    I_em[	184	]=	127.93056	;
    I_em[	185	]=	129.5412	;
    I_em[	186	]=	131.21652	;
    I_em[	187	]=	132.93384	;
    I_em[	188	]=	134.721	;
    I_em[	189	]=	136.56708	;
    I_em[	190	]=	138.48744	;
    I_em[	191	]=	140.4726	;
    I_em[	192	]=	142.53708	;
    I_em[	193	]=	144.6876	;
    I_em[	194	]=	146.97636	;
    I_em[	195	]=	149.69388	;
    I_em[	196	]=	152.28828	;
    I_em[	197	]=	154.93656	;
    I_em[	198	]=	157.24776	;
    I_em[	199	]=	159.33492	;
    I_em[	200	]=	161.59884	;
    I_em[	201	]=	164.87568	;
    I_em[	202	]=	167.87496	;
    I_em[	203	]=	171.05784	;
    I_em[	204	]=	175.10496	;
    I_em[	205	]=	178.72056	;
    I_em[	206	]=	181.67772	;
    I_em[	207	]=	185.3754	;
    I_em[	208	]=	190.51704	;
    I_em[	209	]=	194.08548	;
    I_em[	210	]=	197.26212	;
    I_em[	211	]=	200.862	;
    I_em[	212	]=	205.59096	;
    I_em[	213	]=	210.60324	;
    I_em[	214	]=	215.30448	;
    I_em[	215	]=	220.44912	;
    I_em[	216	]=	225.07044	;
    I_em[	217	]=	229.32912	;
    I_em[	218	]=	234.34128	;
    I_em[	219	]=	239.66664	;
    I_em[	220	]=	244.60728	;
    I_em[	221	]=	249.29916	;
    I_em[	222	]=	254.93004	;
    I_em[	223	]=	261.65832	;
    I_em[	224	]=	267.27372	;
    I_em[	225	]=	272.10456	;
    I_em[	226	]=	276.95856	;
    I_em[	227	]=	280.80648	;
    I_em[	228	]=	284.45292	;
    I_em[	229	]=	289.51176	;
    I_em[	230	]=	294.01644	;
    I_em[	231	]=	299.29944	;
    I_em[	232	]=	304.23168	;
    I_em[	233	]=	311.2686	;
    I_em[	234	]=	318.06756	;
    I_em[	235	]=	323.31228	;
    I_em[	236	]=	328.76628	;
    I_em[	237	]=	335.19948	;
    I_em[	238	]=	342.56232	;
    I_em[	239	]=	349.15008	;
    I_em[	240	]=	355.75632	;
    I_em[	241	]=	362.64336	;
    I_em[	242	]=	369.14064	;
    I_em[	243	]=	375.83124	;
    I_em[	244	]=	381.7788	;
    I_em[	245	]=	389.39724	;
    I_em[	246	]=	399.43932	;
    I_em[	247	]=	409.7826	;
    I_em[	248	]=	420.42456	;
    I_em[	249	]=	431.36148	;
    I_em[	250	]=	442.59828	;
    I_em[	251	]=	454.14	;
    I_em[	252	]=	465.97032	;
    I_em[	253	]=	478.11744	;
    I_em[	254	]=	490.55496	;
    I_em[	255	]=	503.298	;
    I_em[	256	]=	516.38604	;
    I_em[	257	]=	529.81344	;
    I_em[	258	]=	543.59832	;
    I_em[	259	]=	557.71332	;
    I_em[	260	]=	572.18352	;
    I_em[	261	]=	586.98876	;
    I_em[	262	]=	602.14788	;
    I_em[	263	]=	617.65476	;
    I_em[	264	]=	633.49884	;
    I_em[	265	]=	649.70052	;
    I_em[	266	]=	666.27768	;
    I_em[	267	]=	683.22828	;
    I_em[	268	]=	700.55184	;
    I_em[	269	]=	718.26432	;
    I_em[	270	]=	736.34664	;
    I_em[	271	]=	754.80708	;
    I_em[	272	]=	773.65956	;
    I_em[	273	]=	792.8766	;
    I_em[	274	]=	812.47464	;
    I_em[	275	]=	832.45788	;
    I_em[	276	]=	852.82752	;
    I_em[	277	]=	873.59508	;
    I_em[	278	]=	894.75132	;
    I_em[	279	]=	916.29672	;
    I_em[	280	]=	938.23752	;
    I_em[	281	]=	960.58272	;
    I_em[	282	]=	983.30112	;
    I_em[	283	]=	1006.42752	;
    I_em[	284	]=	1029.94032	;
    I_em[	285	]=	1053.80832	;
    I_em[	286	]=	1077.89352	;
    I_em[	287	]=	1102.15992	;
    I_em[	288	]=	1126.61112	;
    I_em[	289	]=	1151.22672	;
    I_em[	290	]=	1176.03192	;
    I_em[	291	]=	1201.00872	;
    I_em[	292	]=	1226.17032	;
    I_em[	293	]=	1251.50832	;
    I_em[	294	]=	1277.03352	;
    I_em[	295	]=	1302.72072	;
    I_em[	296	]=	1328.58312	;
    I_em[	297	]=	1354.59672	;
    I_em[	298	]=	1380.77592	;
    I_em[	299	]=	1407.10272	;
    I_em[	300	]=	1433.59392	;
    I_em[	301	]=	1460.24952	;
    I_em[	302	]=	1487.05152	;
    I_em[	303	]=	1514.02272	;
    I_em[	304	]=	1541.15472	;
    I_em[	305	]=	1568.44152	;
    I_em[	306	]=	1595.87232	;
    I_em[	307	]=	1623.44352	;
    I_em[	308	]=	1651.15152	;
    I_em[	309	]=	1678.99992	;
    I_em[	310	]=	1706.98872	;
    I_em[	311	]=	1735.10952	;
    I_em[	312	]=	1763.37552	;
    I_em[	313	]=	1791.78912	;
    I_em[	314	]=	1820.34072	;
    I_em[	315	]=	1848.99672	;
    I_em[	316	]=	1877.65872	;
    I_em[	317	]=	1906.29192	;
    I_em[	318	]=	1934.91072	;
    I_em[	319	]=	1963.49712	;
    I_em[	320	]=	1992.05232	;
    I_em[	321	]=	2020.58352	;
    I_em[	322	]=	2049.08952	;
    I_em[	323	]=	2077.57632	;
    I_em[	324	]=	2106.03552	;
    I_em[	325	]=	2134.46832	;
    I_em[	326	]=	2162.87952	;
    I_em[	327	]=	2191.26672	;
    I_em[	328	]=	2219.65032	;
    I_em[	329	]=	2247.99672	;
    I_em[	330	]=	2276.33352	;
    I_em[	331	]=	2304.66312	;
    I_em[	332	]=	2332.95672	;
    I_em[	333	]=	2361.24192	;
    I_em[	334	]=	2389.50552	;
    I_em[	335	]=	2417.65872	;
    I_em[	336	]=	2445.32952	;
    I_em[	337	]=	2472.44832	;
    I_em[	338	]=	2498.98992	;
    I_em[	339	]=	2524.97352	;
    I_em[	340	]=	2550.39192	;
    I_em[	341	]=	2575.24632	;
    I_em[	342	]=	2599.53912	;
    I_em[	343	]=	2623.25712	;
    I_em[	344	]=	2646.42432	;
    I_em[	345	]=	2669.02152	;
    I_em[	346	]=	2691.04512	;
    I_em[	347	]=	2712.50592	;
    I_em[	348	]=	2733.40872	;
    I_em[	349	]=	2753.74032	;
    I_em[	350	]=	2773.51272	;
    I_em[	351	]=	2792.71632	;
    I_em[	352	]=	2811.36192	;
    I_em[	353	]=	2829.43392	;
    I_em[	354	]=	2846.94552	;
    I_em[	355	]=	2863.88952	;
    I_em[	356	]=	2880.27432	;
    I_em[	357	]=	2896.08912	;
    I_em[	358	]=	2911.34712	;
    I_em[	359	]=	2926.03632	;
    I_em[	360	]=	2940.15672	;
    I_em[	361	]=	2953.70712	;
    I_em[	362	]=	2966.70072	;
    I_em[	363	]=	2979.13512	;
    I_em[	364	]=	2990.99112	;
    I_em[	365	]=	3002.28792	;
    I_em[	366	]=	3013.02552	;
    I_em[	367	]=	3023.19072	;
    I_em[	368	]=	3032.78712	;
    I_em[	369	]=	3041.82672	;
    I_em[	370	]=	3050.30952	;
    I_em[	371	]=	3058.21032	;
    I_em[	372	]=	3065.55552	;
    I_em[	373	]=	3072.34272	;
    I_em[	374	]=	3078.54792	;
    I_em[	375	]=	3084.20712	;
    I_em[	376	]=	3089.28312	;
    I_em[	377	]=	3093.80472	;
    I_em[	378	]=	3097.75632	;
    I_em[	379	]=	3101.15112	;
    I_em[	380	]=	3103.97832	;
    I_em[	381	]=	3106.23672	;
    I_em[	382	]=	3107.93952	;
    I_em[	383	]=	3109.06272	;
    I_em[	384	]=	3109.62912	;
    I_em[	385	]=	3109.72272	;
    for(int i = 386; i<tmax; i++)
    {
        I_em[i] = I_em[i-1];
    }
}
    
//Now Non_CO2 radiative forcing
void setRnonCO2_RCP3PD(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005145555	;
    RnonCO2[	2	]=	0.009090068	;
    RnonCO2[	3	]=	0.007768629	;
    RnonCO2[	4	]=	0.006256789	;
    RnonCO2[	5	]=	0.004769658	;
    RnonCO2[	6	]=	0.002906336	;
    RnonCO2[	7	]=	0.001080178	;
    RnonCO2[	8	]=	-0.000291468	;
    RnonCO2[	9	]=	-0.001612412	;
    RnonCO2[	10	]=	-0.00288359	;
    RnonCO2[	11	]=	-0.00410611	;
    RnonCO2[	12	]=	-0.005282233	;
    RnonCO2[	13	]=	-0.006413549	;
    RnonCO2[	14	]=	-0.007501746	;
    RnonCO2[	15	]=	-0.008551056	;
    RnonCO2[	16	]=	-0.010019335	;
    RnonCO2[	17	]=	-0.011459991	;
    RnonCO2[	18	]=	-0.012417579	;
    RnonCO2[	19	]=	-0.013333977	;
    RnonCO2[	20	]=	-0.014201345	;
    RnonCO2[	21	]=	-0.015012487	;
    RnonCO2[	22	]=	-0.015760238	;
    RnonCO2[	23	]=	-0.016437067	;
    RnonCO2[	24	]=	-0.017035543	;
    RnonCO2[	25	]=	-0.017549544	;
    RnonCO2[	26	]=	-0.018434793	;
    RnonCO2[	27	]=	-0.019238993	;
    RnonCO2[	28	]=	-0.019510794	;
    RnonCO2[	29	]=	-0.019709367	;
    RnonCO2[	30	]=	-0.019838439	;
    RnonCO2[	31	]=	-0.019901316	;
    RnonCO2[	32	]=	-0.020355353	;
    RnonCO2[	33	]=	-0.020749651	;
    RnonCO2[	34	]=	-0.020634193	;
    RnonCO2[	35	]=	-0.02091346	;
    RnonCO2[	36	]=	-0.021125633	;
    RnonCO2[	37	]=	-0.02171132	;
    RnonCO2[	38	]=	-0.021774359	;
    RnonCO2[	39	]=	-0.020873209	;
    RnonCO2[	40	]=	-0.02036553	;
    RnonCO2[	41	]=	-0.020256367	;
    RnonCO2[	42	]=	-0.020105185	;
    RnonCO2[	43	]=	-0.01947287	;
    RnonCO2[	44	]=	-0.018814746	;
    RnonCO2[	45	]=	-0.018134946	;
    RnonCO2[	46	]=	-0.017872094	;
    RnonCO2[	47	]=	-0.017576381	;
    RnonCO2[	48	]=	-0.016804485	;
    RnonCO2[	49	]=	-0.016001407	;
    RnonCO2[	50	]=	-0.015606441	;
    RnonCO2[	51	]=	-0.015619264	;
    RnonCO2[	52	]=	-0.015600061	;
    RnonCO2[	53	]=	-0.015116575	;
    RnonCO2[	54	]=	-0.014172313	;
    RnonCO2[	55	]=	-0.013205379	;
    RnonCO2[	56	]=	-0.012216093	;
    RnonCO2[	57	]=	-0.011635129	;
    RnonCO2[	58	]=	-0.011459514	;
    RnonCO2[	59	]=	-0.010829842	;
    RnonCO2[	60	]=	-0.010175791	;
    RnonCO2[	61	]=	-0.009499636	;
    RnonCO2[	62	]=	-0.00879934	;
    RnonCO2[	63	]=	-0.008077943	;
    RnonCO2[	64	]=	-0.006912545	;
    RnonCO2[	65	]=	-0.008242223	;
    RnonCO2[	66	]=	-0.009135821	;
    RnonCO2[	67	]=	-0.007501052	;
    RnonCO2[	68	]=	-0.006687418	;
    RnonCO2[	69	]=	-0.005858015	;
    RnonCO2[	70	]=	-0.005005979	;
    RnonCO2[	71	]=	-0.005767925	;
    RnonCO2[	72	]=	-0.006086639	;
    RnonCO2[	73	]=	-0.005137938	;
    RnonCO2[	74	]=	-0.004558881	;
    RnonCO2[	75	]=	-0.004336125	;
    RnonCO2[	76	]=	-0.004045198	;
    RnonCO2[	77	]=	-0.003665109	;
    RnonCO2[	78	]=	-0.003220213	;
    RnonCO2[	79	]=	-0.002760518	;
    RnonCO2[	80	]=	-0.003527376	;
    RnonCO2[	81	]=	-0.003576651	;
    RnonCO2[	82	]=	-0.003275283	;
    RnonCO2[	83	]=	-0.003386771	;
    RnonCO2[	84	]=	-0.003510917	;
    RnonCO2[	85	]=	-0.004646356	;
    RnonCO2[	86	]=	-0.003691576	;
    RnonCO2[	87	]=	-0.009505158	;
    RnonCO2[	88	]=	-0.016364432	;
    RnonCO2[	89	]=	-0.017996784	;
    RnonCO2[	90	]=	-0.019670058	;
    RnonCO2[	91	]=	-0.020430126	;
    RnonCO2[	92	]=	-0.021643321	;
    RnonCO2[	93	]=	-0.02142206	;
    RnonCO2[	94	]=	-0.022552345	;
    RnonCO2[	95	]=	-0.031588211	;
    RnonCO2[	96	]=	-0.046252985	;
    RnonCO2[	97	]=	-0.042365448	;
    RnonCO2[	98	]=	-0.033665717	;
    RnonCO2[	99	]=	-0.034555638	;
    RnonCO2[	100	]=	-0.037298509	;
    RnonCO2[	101	]=	-0.046083195	;
    RnonCO2[	102	]=	-0.05558168	;
    RnonCO2[	103	]=	-0.057464266	;
    RnonCO2[	104	]=	-0.053606449	;
    RnonCO2[	105	]=	-0.05168834	;
    RnonCO2[	106	]=	-0.061304945	;
    RnonCO2[	107	]=	-0.086608149	;
    RnonCO2[	108	]=	-0.108195137	;
    RnonCO2[	109	]=	-0.112259625	;
    RnonCO2[	110	]=	-0.111643119	;
    RnonCO2[	111	]=	-0.108991576	;
    RnonCO2[	112	]=	-0.10203489	;
    RnonCO2[	113	]=	-0.098533227	;
    RnonCO2[	114	]=	-0.101949678	;
    RnonCO2[	115	]=	-0.114562053	;
    RnonCO2[	116	]=	-0.123024156	;
    RnonCO2[	117	]=	-0.119809652	;
    RnonCO2[	118	]=	-0.118941351	;
    RnonCO2[	119	]=	-0.120181779	;
    RnonCO2[	120	]=	-0.117316831	;
    RnonCO2[	121	]=	-0.115023243	;
    RnonCO2[	122	]=	-0.116983521	;
    RnonCO2[	123	]=	-0.125997633	;
    RnonCO2[	124	]=	-0.129568227	;
    RnonCO2[	125	]=	-0.131248987	;
    RnonCO2[	126	]=	-0.137316696	;
    RnonCO2[	127	]=	-0.141273792	;
    RnonCO2[	128	]=	-0.144231375	;
    RnonCO2[	129	]=	-0.147973341	;
    RnonCO2[	130	]=	-0.153688224	;
    RnonCO2[	131	]=	-0.15652816	;
    RnonCO2[	132	]=	-0.157109013	;
    RnonCO2[	133	]=	-0.158858513	;
    RnonCO2[	134	]=	-0.162186704	;
    RnonCO2[	135	]=	-0.165318228	;
    RnonCO2[	136	]=	-0.171733193	;
    RnonCO2[	137	]=	-0.178096644	;
    RnonCO2[	138	]=	-0.183870407	;
    RnonCO2[	139	]=	-0.189730028	;
    RnonCO2[	140	]=	-0.194221589	;
    RnonCO2[	141	]=	-0.201576481	;
    RnonCO2[	142	]=	-0.208859035	;
    RnonCO2[	143	]=	-0.207375441	;
    RnonCO2[	144	]=	-0.202571711	;
    RnonCO2[	145	]=	-0.204126848	;
    RnonCO2[	146	]=	-0.201876709	;
    RnonCO2[	147	]=	-0.195147841	;
    RnonCO2[	148	]=	-0.191449584	;
    RnonCO2[	149	]=	-0.183770215	;
    RnonCO2[	150	]=	-0.173476305	;
    RnonCO2[	151	]=	-0.170909799	;
    RnonCO2[	152	]=	-0.171515561	;
    RnonCO2[	153	]=	-0.169079801	;
    RnonCO2[	154	]=	-0.159414516	;
    RnonCO2[	155	]=	-0.155013584	;
    RnonCO2[	156	]=	-0.151089869	;
    RnonCO2[	157	]=	-0.144432651	;
    RnonCO2[	158	]=	-0.152359798	;
    RnonCO2[	159	]=	-0.158148636	;
    RnonCO2[	160	]=	-0.155277608	;
    RnonCO2[	161	]=	-0.152617947	;
    RnonCO2[	162	]=	-0.154120923	;
    RnonCO2[	163	]=	-0.156019482	;
    RnonCO2[	164	]=	-0.155886394	;
    RnonCO2[	165	]=	-0.152021034	;
    RnonCO2[	166	]=	-0.141834688	;
    RnonCO2[	167	]=	-0.13108946	;
    RnonCO2[	168	]=	-0.125408882	;
    RnonCO2[	169	]=	-0.125515632	;
    RnonCO2[	170	]=	-0.125194614	;
    RnonCO2[	171	]=	-0.126120729	;
    RnonCO2[	172	]=	-0.12532345	;
    RnonCO2[	173	]=	-0.115303554	;
    RnonCO2[	174	]=	-0.10787249	;
    RnonCO2[	175	]=	-0.109257271	;
    RnonCO2[	176	]=	-0.113724728	;
    RnonCO2[	177	]=	-0.117421621	;
    RnonCO2[	178	]=	-0.11813163	;
    RnonCO2[	179	]=	-0.119629474	;
    RnonCO2[	180	]=	-0.119789192	;
    RnonCO2[	181	]=	-0.124270593	;
    RnonCO2[	182	]=	-0.135220142	;
    RnonCO2[	183	]=	-0.145282294	;
    RnonCO2[	184	]=	-0.1490379	;
    RnonCO2[	185	]=	-0.154219559	;
    RnonCO2[	186	]=	-0.178760049	;
    RnonCO2[	187	]=	-0.203310188	;
    RnonCO2[	188	]=	-0.212758852	;
    RnonCO2[	189	]=	-0.221219612	;
    RnonCO2[	190	]=	-0.230341307	;
    RnonCO2[	191	]=	-0.239337924	;
    RnonCO2[	192	]=	-0.247524974	;
    RnonCO2[	193	]=	-0.250847198	;
    RnonCO2[	194	]=	-0.245200212	;
    RnonCO2[	195	]=	-0.237476895	;
    RnonCO2[	196	]=	-0.24791739	;
    RnonCO2[	197	]=	-0.261719365	;
    RnonCO2[	198	]=	-0.263179809	;
    RnonCO2[	199	]=	-0.263298027	;
    RnonCO2[	200	]=	-0.261139159	;
    RnonCO2[	201	]=	-0.257781723	;
    RnonCO2[	202	]=	-0.255724839	;
    RnonCO2[	203	]=	-0.25169763	;
    RnonCO2[	204	]=	-0.241647721	;
    RnonCO2[	205	]=	-0.221452127	;
    RnonCO2[	206	]=	-0.196790013	;
    RnonCO2[	207	]=	-0.182093765	;
    RnonCO2[	208	]=	-0.174745229	;
    RnonCO2[	209	]=	-0.16714548	;
    RnonCO2[	210	]=	-0.159384584	;
    RnonCO2[	211	]=	-0.156373877	;
    RnonCO2[	212	]=	-0.153042015	;
    RnonCO2[	213	]=	-0.139817455	;
    RnonCO2[	214	]=	-0.125210902	;
    RnonCO2[	215	]=	-0.119848303	;
    RnonCO2[	216	]=	-0.119430668	;
    RnonCO2[	217	]=	-0.123211365	;
    RnonCO2[	218	]=	-0.125809708	;
    RnonCO2[	219	]=	-0.120193155	;
    RnonCO2[	220	]=	-0.110911249	;
    RnonCO2[	221	]=	-0.102402229	;
    RnonCO2[	222	]=	-0.096562536	;
    RnonCO2[	223	]=	-0.086930587	;
    RnonCO2[	224	]=	-0.072710932	;
    RnonCO2[	225	]=	-0.05997191	;
    RnonCO2[	226	]=	-0.058006544	;
    RnonCO2[	227	]=	-0.065604043	;
    RnonCO2[	228	]=	-0.067949961	;
    RnonCO2[	229	]=	-0.065994527	;
    RnonCO2[	230	]=	-0.058283284	;
    RnonCO2[	231	]=	-0.04756956	;
    RnonCO2[	232	]=	-0.049208339	;
    RnonCO2[	233	]=	-0.056699684	;
    RnonCO2[	234	]=	-0.059531967	;
    RnonCO2[	235	]=	-0.065638041	;
    RnonCO2[	236	]=	-0.069976074	;
    RnonCO2[	237	]=	-0.065660736	;
    RnonCO2[	238	]=	-0.060876733	;
    RnonCO2[	239	]=	-0.057486962	;
    RnonCO2[	240	]=	-0.052586013	;
    RnonCO2[	241	]=	-0.042941813	;
    RnonCO2[	242	]=	-0.030744718	;
    RnonCO2[	243	]=	-0.017809043	;
    RnonCO2[	244	]=	-0.004130627	;
    RnonCO2[	245	]=	0.011524255	;
    RnonCO2[	246	]=	0.030489302	;
    RnonCO2[	247	]=	0.05014081	;
    RnonCO2[	248	]=	0.067538237	;
    RnonCO2[	249	]=	0.082834842	;
    RnonCO2[	250	]=	0.096507674	;
    RnonCO2[	251	]=	0.10872806	;
    RnonCO2[	252	]=	0.119627461	;
    RnonCO2[	253	]=	0.129321759	;
    RnonCO2[	254	]=	0.138477337	;
    RnonCO2[	255	]=	0.145950472	;
    RnonCO2[	256	]=	0.150358206	;
    RnonCO2[	257	]=	0.152908292	;
    RnonCO2[	258	]=	0.154993814	;
    RnonCO2[	259	]=	0.157280133	;
    RnonCO2[	260	]=	0.159876589	;
    RnonCO2[	261	]=	0.162771652	;
    RnonCO2[	262	]=	0.165935075	;
    RnonCO2[	263	]=	0.169331817	;
    RnonCO2[	264	]=	0.172938007	;
    RnonCO2[	265	]=	0.175565587	;
    RnonCO2[	266	]=	0.176019044	;
    RnonCO2[	267	]=	0.176093924	;
    RnonCO2[	268	]=	0.176987578	;
    RnonCO2[	269	]=	0.178093057	;
    RnonCO2[	270	]=	0.179425591	;
    RnonCO2[	271	]=	0.180988877	;
    RnonCO2[	272	]=	0.182779529	;
    RnonCO2[	273	]=	0.184783219	;
    RnonCO2[	274	]=	0.186973518	;
    RnonCO2[	275	]=	0.18815089	;
    RnonCO2[	276	]=	0.187102261	;
    RnonCO2[	277	]=	0.184735629	;
    RnonCO2[	278	]=	0.181929696	;
    RnonCO2[	279	]=	0.178661362	;
    RnonCO2[	280	]=	0.174994888	;
    RnonCO2[	281	]=	0.170975598	;
    RnonCO2[	282	]=	0.166654116	;
    RnonCO2[	283	]=	0.16212844	;
    RnonCO2[	284	]=	0.157462204	;
    RnonCO2[	285	]=	0.151799657	;
    RnonCO2[	286	]=	0.144259517	;
    RnonCO2[	287	]=	0.13582153	;
    RnonCO2[	288	]=	0.127542922	;
    RnonCO2[	289	]=	0.119424904	;
    RnonCO2[	290	]=	0.111420416	;
    RnonCO2[	291	]=	0.10353929	;
    RnonCO2[	292	]=	0.095784605	;
    RnonCO2[	293	]=	0.088157588	;
    RnonCO2[	294	]=	0.080662353	;
    RnonCO2[	295	]=	0.074117031	;
    RnonCO2[	296	]=	0.069346782	;
    RnonCO2[	297	]=	0.065440076	;
    RnonCO2[	298	]=	0.061757366	;
    RnonCO2[	299	]=	0.058553736	;
    RnonCO2[	300	]=	0.055746195	;
    RnonCO2[	301	]=	0.053274915	;
    RnonCO2[	302	]=	0.051135541	;
    RnonCO2[	303	]=	0.049319228	;
    RnonCO2[	304	]=	0.047816059	;
    RnonCO2[	305	]=	0.047030318	;
    RnonCO2[	306	]=	0.047344319	;
    RnonCO2[	307	]=	0.048299122	;
    RnonCO2[	308	]=	0.04943385	;
    RnonCO2[	309	]=	0.050715671	;
    RnonCO2[	310	]=	0.0521283	;
    RnonCO2[	311	]=	0.053621844	;
    RnonCO2[	312	]=	0.05516537	;
    RnonCO2[	313	]=	0.056779921	;
    RnonCO2[	314	]=	0.058478875	;
    RnonCO2[	315	]=	0.059888399	;
    RnonCO2[	316	]=	0.060629189	;
    RnonCO2[	317	]=	0.061309456	;
    RnonCO2[	318	]=	0.062260672	;
    RnonCO2[	319	]=	0.06320141	;
    RnonCO2[	320	]=	0.064129242	;
    RnonCO2[	321	]=	0.065041548	;
    RnonCO2[	322	]=	0.065901312	;
    RnonCO2[	323	]=	0.066688978	;
    RnonCO2[	324	]=	0.067434448	;
    RnonCO2[	325	]=	0.068235885	;
    RnonCO2[	326	]=	0.069192689	;
    RnonCO2[	327	]=	0.070176058	;
    RnonCO2[	328	]=	0.071111938	;
    RnonCO2[	329	]=	0.072068475	;
    RnonCO2[	330	]=	0.073036663	;
    RnonCO2[	331	]=	0.074013231	;
    RnonCO2[	332	]=	0.074994935	;
    RnonCO2[	333	]=	0.075944888	;
    RnonCO2[	334	]=	0.076842806	;
    RnonCO2[	335	]=	0.076570091	;
    RnonCO2[	336	]=	0.073996001	;
    RnonCO2[	337	]=	0.070865472	;
    RnonCO2[	338	]=	0.068420938	;
    RnonCO2[	339	]=	0.066145907	;
    RnonCO2[	340	]=	0.064015257	;
    RnonCO2[	341	]=	0.062010361	;
    RnonCO2[	342	]=	0.060118713	;
    RnonCO2[	343	]=	0.058329335	;
    RnonCO2[	344	]=	0.056598323	;
    RnonCO2[	345	]=	0.054899378	;
    RnonCO2[	346	]=	0.053256032	;
    RnonCO2[	347	]=	0.051684028	;
    RnonCO2[	348	]=	0.050196156	;
    RnonCO2[	349	]=	0.048807185	;
    RnonCO2[	350	]=	0.047512835	;
    RnonCO2[	351	]=	0.046296455	;
    RnonCO2[	352	]=	0.045146887	;
    RnonCO2[	353	]=	0.044057934	;
    RnonCO2[	354	]=	0.043024796	;
    RnonCO2[	355	]=	0.042008614	;
    RnonCO2[	356	]=	0.040988061	;
    RnonCO2[	357	]=	0.039990186	;
    RnonCO2[	358	]=	0.039034443	;
    RnonCO2[	359	]=	0.038136373	;
    RnonCO2[	360	]=	0.037307082	;
    RnonCO2[	361	]=	0.036533216	;
    RnonCO2[	362	]=	0.035794144	;
    RnonCO2[	363	]=	0.035080656	;
    RnonCO2[	364	]=	0.034388489	;
    RnonCO2[	365	]=	0.033714148	;
    RnonCO2[	366	]=	0.033020341	;
    RnonCO2[	367	]=	0.032287006	;
    RnonCO2[	368	]=	0.031542283	;
    RnonCO2[	369	]=	0.030806257	;
    RnonCO2[	370	]=	0.030094998	;
    RnonCO2[	371	]=	0.029426589	;
    RnonCO2[	372	]=	0.028800011	;
    RnonCO2[	373	]=	0.028201386	;
    RnonCO2[	374	]=	0.027622153	;
    RnonCO2[	375	]=	0.027058686	;
    RnonCO2[	376	]=	0.026507668	;
    RnonCO2[	377	]=	0.025932742	;
    RnonCO2[	378	]=	0.025314145	;
    RnonCO2[	379	]=	0.024680521	;
    RnonCO2[	380	]=	0.02405179	;
    RnonCO2[	381	]=	0.023444463	;
    RnonCO2[	382	]=	0.022876762	;
    RnonCO2[	383	]=	0.022347732	;
    RnonCO2[	384	]=	0.02184406	;
    RnonCO2[	385	]=	0.021356977	;
    RnonCO2[	386	]=	0.020883323	;
    RnonCO2[	387	]=	0.020420138	;
    RnonCO2[	388	]=	0.019930802	;
    RnonCO2[	389	]=	0.01939644	;
    RnonCO2[	390	]=	0.0188452	;
    RnonCO2[	391	]=	0.018296944	;
    RnonCO2[	392	]=	0.017768763	;
    RnonCO2[	393	]=	0.017278489	;
    RnonCO2[	394	]=	0.01682528	;
    RnonCO2[	395	]=	0.016395648	;
    RnonCO2[	396	]=	0.015981599	;
    RnonCO2[	397	]=	0.015579655	;
    RnonCO2[	398	]=	0.01518669	;
    RnonCO2[	399	]=	0.014766694	;
    RnonCO2[	400	]=	0.014300633	;
    RnonCO2[	401	]=	0.013816767	;
    RnonCO2[	402	]=	0.013335132	;
    RnonCO2[	403	]=	0.012872182	;
    RnonCO2[	404	]=	0.012446022	;
    RnonCO2[	405	]=	0.012055953	;
    RnonCO2[	406	]=	0.011688624	;
    RnonCO2[	407	]=	0.011335763	;
    RnonCO2[	408	]=	0.010993987	;
    RnonCO2[	409	]=	0.010660417	;
    RnonCO2[	410	]=	0.010299162	;
    RnonCO2[	411	]=	0.00989118	;
    RnonCO2[	412	]=	0.009464652	;
    RnonCO2[	413	]=	0.009039623	;
    RnonCO2[	414	]=	0.008632569	;
    RnonCO2[	415	]=	0.008261461	;
    RnonCO2[	416	]=	0.007925489	;
    RnonCO2[	417	]=	0.007611611	;
    RnonCO2[	418	]=	0.007311291	;
    RnonCO2[	419	]=	0.007021657	;
    RnonCO2[	420	]=	0.006739261	;
    RnonCO2[	421	]=	0.006428648	;
    RnonCO2[	422	]=	0.00607091	;
    RnonCO2[	423	]=	0.005694103	;
    RnonCO2[	424	]=	0.005318119	;
    RnonCO2[	425	]=	0.004959447	;
    RnonCO2[	426	]=	0.004636049	;
    RnonCO2[	427	]=	0.004347021	;
    RnonCO2[	428	]=	0.004079385	;
    RnonCO2[	429	]=	0.00382504	;
    RnonCO2[	430	]=	0.003580394	;
    RnonCO2[	431	]=	0.003342669	;
    RnonCO2[	432	]=	0.003076327	;
    RnonCO2[	433	]=	0.00276219	;
    RnonCO2[	434	]=	0.002428561	;
    RnonCO2[	435	]=	0.002095293	;
    RnonCO2[	436	]=	0.001778879	;
    RnonCO2[	437	]=	0.001496989	;
    RnonCO2[	438	]=	0.001249057	;
    RnonCO2[	439	]=	0.00102177	;
    RnonCO2[	440	]=	0.000807344	;
    RnonCO2[	441	]=	0.000602153	;
    RnonCO2[	442	]=	0.000403545	;
    RnonCO2[	443	]=	0.000175641	;
    RnonCO2[	444	]=	-0.000100305	;
    RnonCO2[	445	]=	-0.000396193	;
    RnonCO2[	446	]=	-0.00069209	;
    RnonCO2[	447	]=	-0.000971786	;
    RnonCO2[	448	]=	-0.001217351	;
    RnonCO2[	449	]=	-0.001429421	;
    RnonCO2[	450	]=	-0.001621204	;
    RnonCO2[	451	]=	-0.00180072	;
    RnonCO2[	452	]=	-0.001971341	;
    RnonCO2[	453	]=	-0.002136017	;
    RnonCO2[	454	]=	-0.002330385	;
    RnonCO2[	455	]=	-0.00257275	;
    RnonCO2[	456	]=	-0.002835529	;
    RnonCO2[	457	]=	-0.003098864	;
    RnonCO2[	458	]=	-0.003346138	;
    RnonCO2[	459	]=	-0.003559862	;
    RnonCO2[	460	]=	-0.003740454	;
    RnonCO2[	461	]=	-0.003901281	;
    RnonCO2[	462	]=	-0.00405017	;
    RnonCO2[	463	]=	-0.00419066	;
    RnonCO2[	464	]=	-0.004325436	;
    RnonCO2[	465	]=	-0.00449015	;
    RnonCO2[	466	]=	-0.00470337	;
    RnonCO2[	467	]=	-0.004937067	;
    RnonCO2[	468	]=	-0.005171618	;
    RnonCO2[	469	]=	-0.005390849	;
    RnonCO2[	470	]=	-0.005576447	;
    RnonCO2[	471	]=	-0.005729591	;
    RnonCO2[	472	]=	-0.005863231	;
    RnonCO2[	473	]=	-0.005985416	;
    RnonCO2[	474	]=	-0.006099425	;
    RnonCO2[	475	]=	-0.006207957	;
    RnonCO2[	476	]=	-0.006346669	;
    RnonCO2[	477	]=	-0.006534243	;
    RnonCO2[	478	]=	-0.006742512	;
    RnonCO2[	479	]=	-0.006951957	;
    RnonCO2[	480	]=	-0.007146001	;
    RnonCO2[	481	]=	-0.007307361	;
    RnonCO2[	482	]=	-0.007436262	;
    RnonCO2[	483	]=	-0.007545934	;
    RnonCO2[	484	]=	-0.007644501	;
    RnonCO2[	485	]=	-0.007735122	;
    RnonCO2[	486	]=	-0.007820801	;
    RnonCO2[	487	]=	-0.007936748	;
    RnonCO2[	488	]=	-0.008101617	;
    RnonCO2[	489	]=	-0.008287551	;
    RnonCO2[	490	]=	-0.008474862	;
    RnonCO2[	491	]=	-0.008647147	;
    RnonCO2[	492	]=	-0.00878687	;
    RnonCO2[	493	]=	-0.008894579	;
    RnonCO2[	494	]=	-0.008983349	;
    RnonCO2[	495	]=	-0.009061228	;
    RnonCO2[	496	]=	-0.009131254	;
    RnonCO2[	497	]=	-0.009196735	;
    RnonCO2[	498	]=	-0.009292563	;
    RnonCO2[	499	]=	-0.009437653	;
    RnonCO2[	500	]=	-0.009603896	;
    RnonCO2[	501	]=	-0.009771736	;
    RnonCO2[	502	]=	-0.009924803	;
    RnonCO2[	503	]=	-0.010045599	;
    RnonCO2[	504	]=	-0.010134561	;
    RnonCO2[	505	]=	-0.010204736	;
    RnonCO2[	506	]=	-0.010264242	;
    RnonCO2[	507	]=	-0.010316427	;
    RnonCO2[	508	]=	-0.010364035	;
    RnonCO2[	509	]=	-0.010442352	;
    RnonCO2[	510	]=	-0.010569824	;
    RnonCO2[	511	]=	-0.010718688	;
    RnonCO2[	512	]=	-0.010869385	;
    RnonCO2[	513	]=	-0.011005583	;
    RnonCO2[	514	]=	-0.011109531	;
    RnonCO2[	515	]=	-0.011182135	;
    RnonCO2[	516	]=	-0.011236114	;
    RnonCO2[	517	]=	-0.01127965	;
    RnonCO2[	518	]=	-0.011315818	;
    RnonCO2[	519	]=	-0.011347524	;
    RnonCO2[	520	]=	-0.011410299	;
    RnonCO2[	521	]=	-0.011522401	;
    RnonCO2[	522	]=	-0.011655994	;
    RnonCO2[	523	]=	-0.01179167	;
    RnonCO2[	524	]=	-0.011912844	;
    RnonCO2[	525	]=	-0.012002101	;
    RnonCO2[	526	]=	-0.01206008	;
    RnonCO2[	527	]=	-0.012099752	;
    RnonCO2[	528	]=	-0.012129063	;
    RnonCO2[	529	]=	-0.012151257	;
    RnonCO2[	530	]=	-0.012169254	;
    RnonCO2[	531	]=	-0.01221823	;
    RnonCO2[	532	]=	-0.012316698	;
    RnonCO2[	533	]=	-0.012436908	;
    RnonCO2[	534	]=	-0.012559166	;
    RnonCO2[	535	]=	-0.01266708	;
    RnonCO2[	536	]=	-0.012743282	;
    RnonCO2[	537	]=	-0.012788581	;
    RnonCO2[	538	]=	-0.012815601	;
    RnonCO2[	539	]=	-0.012832346	;
    RnonCO2[	540	]=	-0.012842079	;
    RnonCO2[	541	]=	-0.012847885	;
    RnonCO2[	542	]=	-0.01288472	;
    RnonCO2[	543	]=	-0.012971203	;
    RnonCO2[	544	]=	-0.013079385	;
    RnonCO2[	545	]=	-0.013189886	;
    RnonCO2[	546	]=	-0.013286215	;
    RnonCO2[	547	]=	-0.013351053	;
    RnonCO2[	548	]=	-0.013384779	;
    RnonCO2[	549	]=	-0.013400708	;
    RnonCO2[	550	]=	-0.013406301	;
    RnonCO2[	551	]=	-0.013405137	;
    RnonCO2[	552	]=	-0.013400171	;
    RnonCO2[	553	]=	-0.013426426	;
    RnonCO2[	554	]=	-0.013502179	;
    RnonCO2[	555	]=	-0.013599889	;
    RnonCO2[	556	]=	-0.013699748	;
    RnonCO2[	557	]=	-0.013785919	;
    RnonCO2[	558	]=	-0.013840533	;
    RnonCO2[	559	]=	-0.013864285	;
    RnonCO2[	560	]=	-0.01387013	;
    RnonCO2[	561	]=	-0.013866028	;
    RnonCO2[	562	]=	-0.01385543	;
    RnonCO2[	563	]=	-0.013840702	;
    RnonCO2[	564	]=	-0.013857385	;
    RnonCO2[	565	]=	-0.013923857	;
    RnonCO2[	566	]=	-0.014012244	;
    RnonCO2[	567	]=	-0.014102918	;
    RnonCO2[	568	]=	-0.014179798	;
    RnonCO2[	569	]=	-0.014225518	;
    RnonCO2[	570	]=	-0.014240334	;
    RnonCO2[	571	]=	-0.014237589	;
    RnonCO2[	572	]=	-0.014224837	;
    RnonCO2[	573	]=	-0.014205399	;
    RnonCO2[	574	]=	-0.014182411	;
    RnonCO2[	575	]=	-0.014190714	;
    RnonCO2[	576	]=	-0.014248788	;
    RnonCO2[	577	]=	-0.014328737	;
    RnonCO2[	578	]=	-0.014411267	;
    RnonCO2[	579	]=	-0.014480209	;
    RnonCO2[	580	]=	-0.014517947	;
    RnonCO2[	581	]=	-0.014524897	;
    RnonCO2[	582	]=	-0.014514334	;
    RnonCO2[	583	]=	-0.014493857	;
    RnonCO2[	584	]=	-0.014467111	;
    RnonCO2[	585	]=	-0.014436334	;
    RnonCO2[	586	]=	-0.014437332	;
    RnonCO2[	587	]=	-0.014487922	;
    RnonCO2[	588	]=	-0.014560651	;
    RnonCO2[	589	]=	-0.014636114	;
    RnonCO2[	590	]=	-0.014697742	;
    RnonCO2[	591	]=	-0.014728282	;
    RnonCO2[	592	]=	-0.014728466	;
    RnonCO2[	593	]=	-0.014711034	;
    RnonCO2[	594	]=	-0.014683784	;
    RnonCO2[	595	]=	-0.014650073	;
    RnonCO2[	596	]=	-0.01461292	;
    RnonCO2[	597	]=	-0.014607102	;
    RnonCO2[	598	]=	-0.014651305	;
    RnonCO2[	599	]=	-0.014717451	;
    RnonCO2[	600	]=	-0.014786334	;
    RnonCO2[	601	]=	-0.014841909	;
    RnonCO2[	602	]=	-0.014866216	;
    RnonCO2[	603	]=	-0.01485999	;
    RnonCO2[	604	]=	-0.014836665	;
    RnonCO2[	605	]=	-0.014803311	;
    RnonCO2[	606	]=	-0.01476361	;
    RnonCO2[	607	]=	-0.014720443	;
    RnonCO2[	608	]=	-0.014708782	;
    RnonCO2[	609	]=	-0.014747257	;
    RnonCO2[	610	]=	-0.014807788	;
    RnonCO2[	611	]=	-0.014870907	;
    RnonCO2[	612	]=	-0.014920638	;
    RnonCO2[	613	]=	-0.014939388	;
    RnonCO2[	614	]=	-0.014927899	;
    RnonCO2[	615	]=	-0.014898904	;
    RnonCO2[	616	]=	-0.014860286	;
    RnonCO2[	617	]=	-0.014815439	;
    RnonCO2[	618	]=	-0.014766948	;
    RnonCO2[	619	]=	-0.014750129	;
    RnonCO2[	620	]=	-0.014783246	;
    RnonCO2[	621	]=	-0.014838687	;
    RnonCO2[	622	]=	-0.01489688	;
    RnonCO2[	623	]=	-0.014941608	;
    RnonCO2[	624	]=	-0.01495534	;
    RnonCO2[	625	]=	-0.01493898	;
    RnonCO2[	626	]=	-0.014905173	;
    RnonCO2[	627	]=	-0.014861843	;
    RnonCO2[	628	]=	-0.014812246	;
    RnonCO2[	629	]=	-0.014759136	;
    RnonCO2[	630	]=	-0.014737706	;
    RnonCO2[	631	]=	-0.014766316	;
    RnonCO2[	632	]=	-0.014817052	;
    RnonCO2[	633	]=	-0.014870707	;
    RnonCO2[	634	]=	-0.014910982	;
    RnonCO2[	635	]=	-0.014920408	;
    RnonCO2[	636	]=	-0.014899737	;
    RnonCO2[	637	]=	-0.01486168	;
    RnonCO2[	638	]=	-0.014814047	;
    RnonCO2[	639	]=	-0.014760264	;
    RnonCO2[	640	]=	-0.014703101	;
    RnonCO2[	641	]=	-0.014677622	;
    RnonCO2[	642	]=	-0.014701968	;
    RnonCO2[	643	]=	-0.014748709	;
    RnonCO2[	644	]=	-0.014798386	;
    RnonCO2[	645	]=	-0.014834769	;
    RnonCO2[	646	]=	-0.014840302	;
    RnonCO2[	647	]=	-0.014815738	;
    RnonCO2[	648	]=	-0.014773851	;
    RnonCO2[	649	]=	-0.014722489	;
    RnonCO2[	650	]=	-0.014664941	;
    RnonCO2[	651	]=	-0.014604148	;
    RnonCO2[	652	]=	-0.014575037	;
    RnonCO2[	653	]=	-0.014595844	;
    RnonCO2[	654	]=	-0.014639003	;
    RnonCO2[	655	]=	-0.014684956	;
    RnonCO2[	656	]=	-0.014717709	;
    RnonCO2[	657	]=	-0.01471993	;
    RnonCO2[	658	]=	-0.014691899	;
    RnonCO2[	659	]=	-0.01464661	;
    RnonCO2[	660	]=	-0.014591952	;
    RnonCO2[	661	]=	-0.014531227	;
    RnonCO2[	662	]=	-0.014466919	;
    RnonCO2[	663	]=	-0.014434447	;
    RnonCO2[	664	]=	-0.014452139	;
    RnonCO2[	665	]=	-0.01449198	;
    RnonCO2[	666	]=	-0.01453495	;
    RnonCO2[	667	]=	-0.014564499	;
    RnonCO2[	668	]=	-0.014563524	;
    RnonCO2[	669	]=	-0.014532622	;
    RnonCO2[	670	]=	-0.014484372	;
    RnonCO2[	671	]=	-0.014426698	;
    RnonCO2[	672	]=	-0.014363081	;
    RnonCO2[	673	]=	-0.014295855	;
    RnonCO2[	674	]=	-0.014260617	;
    RnonCO2[	675	]=	-0.014275311	;
    RnonCO2[	676	]=	-0.014312424	;
    RnonCO2[	677	]=	-0.014352369	;
    RnonCO2[	678	]=	-0.014379311	;
    RnonCO2[	679	]=	-0.014375581	;
    RnonCO2[	680	]=	-0.014341777	;
    RnonCO2[	681	]=	-0.014290853	;
    RnonCO2[	682	]=	-0.014230613	;
    RnonCO2[	683	]=	-0.014164232	;
    RnonCO2[	684	]=	-0.014094539	;
    RnonCO2[	685	]=	-0.014056662	;
    RnonCO2[	686	]=	-0.014068798	;
    RnonCO2[	687	]=	-0.014103305	;
    RnonCO2[	688	]=	-0.014140826	;
    RnonCO2[	689	]=	-0.014165127	;
    RnonCO2[	690	]=	-0.014159093	;
    RnonCO2[	691	]=	-0.014122839	;
    RnonCO2[	692	]=	-0.014069537	;
    RnonCO2[	693	]=	-0.014007026	;
    RnonCO2[	694	]=	-0.013938337	;
    RnonCO2[	695	]=	-0.013866314	;
    RnonCO2[	696	]=	-0.013826092	;
    RnonCO2[	697	]=	-0.013835798	;
    RnonCO2[	698	]=	-0.013868149	;
    RnonCO2[	699	]=	-0.013903374	;
    RnonCO2[	700	]=	-0.013925486	;
    RnonCO2[	701	]=	-0.013917285	;
    RnonCO2[	702	]=	-0.013878879	;
    RnonCO2[	703	]=	-0.013823501	;
    RnonCO2[	704	]=	-0.013758861	;
    RnonCO2[	705	]=	-0.013688005	;
    RnonCO2[	706	]=	-0.013613954	;
    RnonCO2[	707	]=	-0.013571686	;
    RnonCO2[	708	]=	-0.01357958	;
    RnonCO2[	709	]=	-0.013609746	;
    RnonCO2[	710	]=	-0.013643134	;
    RnonCO2[	711	]=	-0.013663356	;
    RnonCO2[	712	]=	-0.013652965	;
    RnonCO2[	713	]=	-0.013612713	;
    RnonCO2[	714	]=	-0.013555565	;
    RnonCO2[	715	]=	-0.013488941	;
    RnonCO2[	716	]=	-0.013416226	;
    RnonCO2[	717	]=	-0.013340293	;
    RnonCO2[	718	]=	-0.013296285	;
    RnonCO2[	719	]=	-0.013302182	;
    RnonCO2[	720	]=	-0.013330624	;
    RnonCO2[	721	]=	-0.01336199	;
    RnonCO2[	722	]=	-0.013380463	;
    RnonCO2[	723	]=	-0.013368513	;
    RnonCO2[	724	]=	-0.013326726	;
    RnonCO2[	725	]=	-0.013267632	;
    RnonCO2[	726	]=	-0.013199498	;
    RnonCO2[	727	]=	-0.013125074	;
    RnonCO2[	728	]=	-0.013047572	;
    RnonCO2[	729	]=	-0.013001972	;
    RnonCO2[	730	]=	-0.013006178	;
    RnonCO2[	731	]=	-0.01303304	;
    RnonCO2[	732	]=	-0.013063014	;
    RnonCO2[	733	]=	-0.01307972	;
    RnonCO2[	734	]=	-0.013066198	;
    RnonCO2[	735	]=	-0.013050088	;
    
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
    
}




void setRnonCO2_RCP45(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005145555	;
    RnonCO2[	2	]=	0.009090068	;
    RnonCO2[	3	]=	0.007768629	;
    RnonCO2[	4	]=	0.006256789	;
    RnonCO2[	5	]=	0.004769658	;
    RnonCO2[	6	]=	0.002906336	;
    RnonCO2[	7	]=	0.001080178	;
    RnonCO2[	8	]=	-0.000291468	;
    RnonCO2[	9	]=	-0.001612412	;
    RnonCO2[	10	]=	-0.00288359	;
    RnonCO2[	11	]=	-0.00410611	;
    RnonCO2[	12	]=	-0.005282233	;
    RnonCO2[	13	]=	-0.006413549	;
    RnonCO2[	14	]=	-0.007501746	;
    RnonCO2[	15	]=	-0.008551056	;
    RnonCO2[	16	]=	-0.010019335	;
    RnonCO2[	17	]=	-0.011459991	;
    RnonCO2[	18	]=	-0.012417579	;
    RnonCO2[	19	]=	-0.013333977	;
    RnonCO2[	20	]=	-0.014201345	;
    RnonCO2[	21	]=	-0.015012487	;
    RnonCO2[	22	]=	-0.015760238	;
    RnonCO2[	23	]=	-0.016437067	;
    RnonCO2[	24	]=	-0.017035543	;
    RnonCO2[	25	]=	-0.017549544	;
    RnonCO2[	26	]=	-0.018434793	;
    RnonCO2[	27	]=	-0.019238993	;
    RnonCO2[	28	]=	-0.019510794	;
    RnonCO2[	29	]=	-0.019709367	;
    RnonCO2[	30	]=	-0.019838439	;
    RnonCO2[	31	]=	-0.019901316	;
    RnonCO2[	32	]=	-0.020355353	;
    RnonCO2[	33	]=	-0.020749651	;
    RnonCO2[	34	]=	-0.020634193	;
    RnonCO2[	35	]=	-0.02091346	;
    RnonCO2[	36	]=	-0.021125633	;
    RnonCO2[	37	]=	-0.02171132	;
    RnonCO2[	38	]=	-0.021774359	;
    RnonCO2[	39	]=	-0.020873209	;
    RnonCO2[	40	]=	-0.02036553	;
    RnonCO2[	41	]=	-0.020256367	;
    RnonCO2[	42	]=	-0.020105185	;
    RnonCO2[	43	]=	-0.01947287	;
    RnonCO2[	44	]=	-0.018814746	;
    RnonCO2[	45	]=	-0.018134946	;
    RnonCO2[	46	]=	-0.017872094	;
    RnonCO2[	47	]=	-0.017576381	;
    RnonCO2[	48	]=	-0.016804485	;
    RnonCO2[	49	]=	-0.016001407	;
    RnonCO2[	50	]=	-0.015606441	;
    RnonCO2[	51	]=	-0.015619264	;
    RnonCO2[	52	]=	-0.015600061	;
    RnonCO2[	53	]=	-0.015116575	;
    RnonCO2[	54	]=	-0.014172313	;
    RnonCO2[	55	]=	-0.013205379	;
    RnonCO2[	56	]=	-0.012216093	;
    RnonCO2[	57	]=	-0.011635129	;
    RnonCO2[	58	]=	-0.011459514	;
    RnonCO2[	59	]=	-0.010829842	;
    RnonCO2[	60	]=	-0.010175791	;
    RnonCO2[	61	]=	-0.009499636	;
    RnonCO2[	62	]=	-0.00879934	;
    RnonCO2[	63	]=	-0.008077943	;
    RnonCO2[	64	]=	-0.006912545	;
    RnonCO2[	65	]=	-0.008242223	;
    RnonCO2[	66	]=	-0.009135821	;
    RnonCO2[	67	]=	-0.007501052	;
    RnonCO2[	68	]=	-0.006687418	;
    RnonCO2[	69	]=	-0.005858015	;
    RnonCO2[	70	]=	-0.005005979	;
    RnonCO2[	71	]=	-0.005767925	;
    RnonCO2[	72	]=	-0.006086639	;
    RnonCO2[	73	]=	-0.005137938	;
    RnonCO2[	74	]=	-0.004558881	;
    RnonCO2[	75	]=	-0.004336125	;
    RnonCO2[	76	]=	-0.004045198	;
    RnonCO2[	77	]=	-0.003665109	;
    RnonCO2[	78	]=	-0.003220213	;
    RnonCO2[	79	]=	-0.002760518	;
    RnonCO2[	80	]=	-0.003527376	;
    RnonCO2[	81	]=	-0.003576651	;
    RnonCO2[	82	]=	-0.003275283	;
    RnonCO2[	83	]=	-0.003386771	;
    RnonCO2[	84	]=	-0.003510917	;
    RnonCO2[	85	]=	-0.004646356	;
    RnonCO2[	86	]=	-0.003691576	;
    RnonCO2[	87	]=	-0.009505158	;
    RnonCO2[	88	]=	-0.016364432	;
    RnonCO2[	89	]=	-0.017996784	;
    RnonCO2[	90	]=	-0.019670058	;
    RnonCO2[	91	]=	-0.020430126	;
    RnonCO2[	92	]=	-0.021643321	;
    RnonCO2[	93	]=	-0.02142206	;
    RnonCO2[	94	]=	-0.022552345	;
    RnonCO2[	95	]=	-0.031588211	;
    RnonCO2[	96	]=	-0.046252985	;
    RnonCO2[	97	]=	-0.042365448	;
    RnonCO2[	98	]=	-0.033665717	;
    RnonCO2[	99	]=	-0.034555638	;
    RnonCO2[	100	]=	-0.037298509	;
    RnonCO2[	101	]=	-0.046083195	;
    RnonCO2[	102	]=	-0.05558168	;
    RnonCO2[	103	]=	-0.057464266	;
    RnonCO2[	104	]=	-0.053606449	;
    RnonCO2[	105	]=	-0.05168834	;
    RnonCO2[	106	]=	-0.061304945	;
    RnonCO2[	107	]=	-0.086608149	;
    RnonCO2[	108	]=	-0.108195137	;
    RnonCO2[	109	]=	-0.112259625	;
    RnonCO2[	110	]=	-0.111643119	;
    RnonCO2[	111	]=	-0.108991576	;
    RnonCO2[	112	]=	-0.10203489	;
    RnonCO2[	113	]=	-0.098533227	;
    RnonCO2[	114	]=	-0.101949678	;
    RnonCO2[	115	]=	-0.114562053	;
    RnonCO2[	116	]=	-0.123024156	;
    RnonCO2[	117	]=	-0.119809652	;
    RnonCO2[	118	]=	-0.118941351	;
    RnonCO2[	119	]=	-0.120181779	;
    RnonCO2[	120	]=	-0.117316831	;
    RnonCO2[	121	]=	-0.115023243	;
    RnonCO2[	122	]=	-0.116983521	;
    RnonCO2[	123	]=	-0.125997633	;
    RnonCO2[	124	]=	-0.129568227	;
    RnonCO2[	125	]=	-0.131248987	;
    RnonCO2[	126	]=	-0.137316696	;
    RnonCO2[	127	]=	-0.141273792	;
    RnonCO2[	128	]=	-0.144231375	;
    RnonCO2[	129	]=	-0.147973341	;
    RnonCO2[	130	]=	-0.153688224	;
    RnonCO2[	131	]=	-0.15652816	;
    RnonCO2[	132	]=	-0.157109013	;
    RnonCO2[	133	]=	-0.158858513	;
    RnonCO2[	134	]=	-0.162186704	;
    RnonCO2[	135	]=	-0.165318228	;
    RnonCO2[	136	]=	-0.171733193	;
    RnonCO2[	137	]=	-0.178096644	;
    RnonCO2[	138	]=	-0.183870407	;
    RnonCO2[	139	]=	-0.189730028	;
    RnonCO2[	140	]=	-0.194221589	;
    RnonCO2[	141	]=	-0.201576481	;
    RnonCO2[	142	]=	-0.208859035	;
    RnonCO2[	143	]=	-0.207375441	;
    RnonCO2[	144	]=	-0.202571711	;
    RnonCO2[	145	]=	-0.204126848	;
    RnonCO2[	146	]=	-0.201876709	;
    RnonCO2[	147	]=	-0.195147841	;
    RnonCO2[	148	]=	-0.191449584	;
    RnonCO2[	149	]=	-0.183770215	;
    RnonCO2[	150	]=	-0.173476305	;
    RnonCO2[	151	]=	-0.170909799	;
    RnonCO2[	152	]=	-0.171515561	;
    RnonCO2[	153	]=	-0.169079801	;
    RnonCO2[	154	]=	-0.159414516	;
    RnonCO2[	155	]=	-0.155013584	;
    RnonCO2[	156	]=	-0.151089869	;
    RnonCO2[	157	]=	-0.144432651	;
    RnonCO2[	158	]=	-0.152359798	;
    RnonCO2[	159	]=	-0.158148636	;
    RnonCO2[	160	]=	-0.155277608	;
    RnonCO2[	161	]=	-0.152617947	;
    RnonCO2[	162	]=	-0.154120923	;
    RnonCO2[	163	]=	-0.156019482	;
    RnonCO2[	164	]=	-0.155886394	;
    RnonCO2[	165	]=	-0.152021034	;
    RnonCO2[	166	]=	-0.141834688	;
    RnonCO2[	167	]=	-0.13108946	;
    RnonCO2[	168	]=	-0.125408882	;
    RnonCO2[	169	]=	-0.125515632	;
    RnonCO2[	170	]=	-0.125194614	;
    RnonCO2[	171	]=	-0.126120729	;
    RnonCO2[	172	]=	-0.12532345	;
    RnonCO2[	173	]=	-0.115303554	;
    RnonCO2[	174	]=	-0.10787249	;
    RnonCO2[	175	]=	-0.109257271	;
    RnonCO2[	176	]=	-0.113724728	;
    RnonCO2[	177	]=	-0.117421621	;
    RnonCO2[	178	]=	-0.11813163	;
    RnonCO2[	179	]=	-0.119629474	;
    RnonCO2[	180	]=	-0.119789192	;
    RnonCO2[	181	]=	-0.124270593	;
    RnonCO2[	182	]=	-0.135220142	;
    RnonCO2[	183	]=	-0.145282294	;
    RnonCO2[	184	]=	-0.1490379	;
    RnonCO2[	185	]=	-0.154219559	;
    RnonCO2[	186	]=	-0.178760049	;
    RnonCO2[	187	]=	-0.203310188	;
    RnonCO2[	188	]=	-0.212758852	;
    RnonCO2[	189	]=	-0.221219612	;
    RnonCO2[	190	]=	-0.230341307	;
    RnonCO2[	191	]=	-0.239337924	;
    RnonCO2[	192	]=	-0.247524974	;
    RnonCO2[	193	]=	-0.250847198	;
    RnonCO2[	194	]=	-0.245200212	;
    RnonCO2[	195	]=	-0.237476895	;
    RnonCO2[	196	]=	-0.24791739	;
    RnonCO2[	197	]=	-0.261719365	;
    RnonCO2[	198	]=	-0.263179809	;
    RnonCO2[	199	]=	-0.263298027	;
    RnonCO2[	200	]=	-0.261139159	;
    RnonCO2[	201	]=	-0.257781723	;
    RnonCO2[	202	]=	-0.255724839	;
    RnonCO2[	203	]=	-0.25169763	;
    RnonCO2[	204	]=	-0.241647721	;
    RnonCO2[	205	]=	-0.221452127	;
    RnonCO2[	206	]=	-0.196790013	;
    RnonCO2[	207	]=	-0.182093765	;
    RnonCO2[	208	]=	-0.174745229	;
    RnonCO2[	209	]=	-0.16714548	;
    RnonCO2[	210	]=	-0.159384584	;
    RnonCO2[	211	]=	-0.156373877	;
    RnonCO2[	212	]=	-0.153042015	;
    RnonCO2[	213	]=	-0.139817455	;
    RnonCO2[	214	]=	-0.125210902	;
    RnonCO2[	215	]=	-0.119848303	;
    RnonCO2[	216	]=	-0.119430668	;
    RnonCO2[	217	]=	-0.123211365	;
    RnonCO2[	218	]=	-0.125809708	;
    RnonCO2[	219	]=	-0.120193155	;
    RnonCO2[	220	]=	-0.110911249	;
    RnonCO2[	221	]=	-0.102402229	;
    RnonCO2[	222	]=	-0.096562536	;
    RnonCO2[	223	]=	-0.086930587	;
    RnonCO2[	224	]=	-0.072710932	;
    RnonCO2[	225	]=	-0.05997191	;
    RnonCO2[	226	]=	-0.058006544	;
    RnonCO2[	227	]=	-0.065604043	;
    RnonCO2[	228	]=	-0.067949961	;
    RnonCO2[	229	]=	-0.065994527	;
    RnonCO2[	230	]=	-0.058283284	;
    RnonCO2[	231	]=	-0.04756956	;
    RnonCO2[	232	]=	-0.049208339	;
    RnonCO2[	233	]=	-0.056699684	;
    RnonCO2[	234	]=	-0.059531967	;
    RnonCO2[	235	]=	-0.065638041	;
    RnonCO2[	236	]=	-0.069976074	;
    RnonCO2[	237	]=	-0.065660736	;
    RnonCO2[	238	]=	-0.060876733	;
    RnonCO2[	239	]=	-0.057486962	;
    RnonCO2[	240	]=	-0.052009693	;
    RnonCO2[	241	]=	-0.040632843	;
    RnonCO2[	242	]=	-0.026916588	;
    RnonCO2[	243	]=	-0.013452099	;
    RnonCO2[	244	]=	0.000389465	;
    RnonCO2[	245	]=	0.014221018	;
    RnonCO2[	246	]=	0.027735641	;
    RnonCO2[	247	]=	0.041750056	;
    RnonCO2[	248	]=	0.056057191	;
    RnonCO2[	249	]=	0.07006948	;
    RnonCO2[	250	]=	0.084104898	;
    RnonCO2[	251	]=	0.098192736	;
    RnonCO2[	252	]=	0.112337742	;
    RnonCO2[	253	]=	0.12653946	;
    RnonCO2[	254	]=	0.141365316	;
    RnonCO2[	255	]=	0.155687536	;
    RnonCO2[	256	]=	0.168102785	;
    RnonCO2[	257	]=	0.179884397	;
    RnonCO2[	258	]=	0.191686884	;
    RnonCO2[	259	]=	0.203223672	;
    RnonCO2[	260	]=	0.214540005	;
    RnonCO2[	261	]=	0.22566407	;
    RnonCO2[	262	]=	0.236614088	;
    RnonCO2[	263	]=	0.247389908	;
    RnonCO2[	264	]=	0.257994987	;
    RnonCO2[	265	]=	0.268753245	;
    RnonCO2[	266	]=	0.279985254	;
    RnonCO2[	267	]=	0.290918066	;
    RnonCO2[	268	]=	0.301097825	;
    RnonCO2[	269	]=	0.310839024	;
    RnonCO2[	270	]=	0.32015312	;
    RnonCO2[	271	]=	0.329049844	;
    RnonCO2[	272	]=	0.337537645	;
    RnonCO2[	273	]=	0.345614846	;
    RnonCO2[	274	]=	0.353268441	;
    RnonCO2[	275	]=	0.360818709	;
    RnonCO2[	276	]=	0.368598018	;
    RnonCO2[	277	]=	0.375950812	;
    RnonCO2[	278	]=	0.382536458	;
    RnonCO2[	279	]=	0.388726864	;
    RnonCO2[	280	]=	0.394624748	;
    RnonCO2[	281	]=	0.400312866	;
    RnonCO2[	282	]=	0.405855738	;
    RnonCO2[	283	]=	0.41130301	;
    RnonCO2[	284	]=	0.4166845	;
    RnonCO2[	285	]=	0.421077518	;
    RnonCO2[	286	]=	0.423561654	;
    RnonCO2[	287	]=	0.425023251	;
    RnonCO2[	288	]=	0.426380104	;
    RnonCO2[	289	]=	0.42764123	;
    RnonCO2[	290	]=	0.428800693	;
    RnonCO2[	291	]=	0.42991107	;
    RnonCO2[	292	]=	0.43101409	;
    RnonCO2[	293	]=	0.43214539	;
    RnonCO2[	294	]=	0.433340809	;
    RnonCO2[	295	]=	0.434382931	;
    RnonCO2[	296	]=	0.435036038	;
    RnonCO2[	297	]=	0.43550197	;
    RnonCO2[	298	]=	0.435985817	;
    RnonCO2[	299	]=	0.43648989	;
    RnonCO2[	300	]=	0.436977344	;
    RnonCO2[	301	]=	0.437429856	;
    RnonCO2[	302	]=	0.437887378	;
    RnonCO2[	303	]=	0.43838134	;
    RnonCO2[	304	]=	0.438938956	;
    RnonCO2[	305	]=	0.439353059	;
    RnonCO2[	306	]=	0.439393229	;
    RnonCO2[	307	]=	0.439255715	;
    RnonCO2[	308	]=	0.439141872	;
    RnonCO2[	309	]=	0.439052028	;
    RnonCO2[	310	]=	0.438990524	;
    RnonCO2[	311	]=	0.43892044	;
    RnonCO2[	312	]=	0.438822803	;
    RnonCO2[	313	]=	0.438746251	;
    RnonCO2[	314	]=	0.438789983	;
    RnonCO2[	315	]=	0.437769672	;
    RnonCO2[	316	]=	0.434413586	;
    RnonCO2[	317	]=	0.430671228	;
    RnonCO2[	318	]=	0.427880723	;
    RnonCO2[	319	]=	0.425391182	;
    RnonCO2[	320	]=	0.423169243	;
    RnonCO2[	321	]=	0.421185991	;
    RnonCO2[	322	]=	0.419376105	;
    RnonCO2[	323	]=	0.417695746	;
    RnonCO2[	324	]=	0.416158862	;
    RnonCO2[	325	]=	0.414767954	;
    RnonCO2[	326	]=	0.41352279	;
    RnonCO2[	327	]=	0.412434383	;
    RnonCO2[	328	]=	0.411494314	;
    RnonCO2[	329	]=	0.410676404	;
    RnonCO2[	330	]=	0.409961491	;
    RnonCO2[	331	]=	0.409337126	;
    RnonCO2[	332	]=	0.408792275	;
    RnonCO2[	333	]=	0.40827871	;
    RnonCO2[	334	]=	0.407767906	;
    RnonCO2[	335	]=	0.406977545	;
    RnonCO2[	336	]=	0.405618095	;
    RnonCO2[	337	]=	0.40423418	;
    RnonCO2[	338	]=	0.403194974	;
    RnonCO2[	339	]=	0.402313242	;
    RnonCO2[	340	]=	0.401556185	;
    RnonCO2[	341	]=	0.400899141	;
    RnonCO2[	342	]=	0.400325016	;
    RnonCO2[	343	]=	0.399818956	;
    RnonCO2[	344	]=	0.399330522	;
    RnonCO2[	345	]=	0.398828962	;
    RnonCO2[	346	]=	0.39833881	;
    RnonCO2[	347	]=	0.397877845	;
    RnonCO2[	348	]=	0.397459365	;
    RnonCO2[	349	]=	0.397099141	;
    RnonCO2[	350	]=	0.39679216	;
    RnonCO2[	351	]=	0.39651924	;
    RnonCO2[	352	]=	0.396267272	;
    RnonCO2[	353	]=	0.396029339	;
    RnonCO2[	354	]=	0.395799758	;
    RnonCO2[	355	]=	0.39553551	;
    RnonCO2[	356	]=	0.395212477	;
    RnonCO2[	357	]=	0.394860407	;
    RnonCO2[	358	]=	0.394501907	;
    RnonCO2[	359	]=	0.394154959	;
    RnonCO2[	360	]=	0.393841161	;
    RnonCO2[	361	]=	0.393558458	;
    RnonCO2[	362	]=	0.393287414	;
    RnonCO2[	363	]=	0.393017745	;
    RnonCO2[	364	]=	0.392744506	;
    RnonCO2[	365	]=	0.392464174	;
    RnonCO2[	366	]=	0.392136086	;
    RnonCO2[	367	]=	0.391737949	;
    RnonCO2[	368	]=	0.391301246	;
    RnonCO2[	369	]=	0.390849523	;
    RnonCO2[	370	]=	0.390401642	;
    RnonCO2[	371	]=	0.389977762	;
    RnonCO2[	372	]=	0.389576885	;
    RnonCO2[	373	]=	0.389183696	;
    RnonCO2[	374	]=	0.388788342	;
    RnonCO2[	375	]=	0.388386838	;
    RnonCO2[	376	]=	0.387975714	;
    RnonCO2[	377	]=	0.387515138	;
    RnonCO2[	378	]=	0.386983291	;
    RnonCO2[	379	]=	0.386411815	;
    RnonCO2[	380	]=	0.385824643	;
    RnonCO2[	381	]=	0.385240624	;
    RnonCO2[	382	]=	0.384680004	;
    RnonCO2[	383	]=	0.384142172	;
    RnonCO2[	384	]=	0.38361196	;
    RnonCO2[	385	]=	0.383347124	;
    RnonCO2[	386	]=	0.383347124	;
    RnonCO2[	387	]=	0.383347124	;
    RnonCO2[	388	]=	0.383347124	;
    RnonCO2[	389	]=	0.383347124	;
    RnonCO2[	390	]=	0.383347124	;
    RnonCO2[	391	]=	0.383347124	;
    RnonCO2[	392	]=	0.383347124	;
    RnonCO2[	393	]=	0.383347124	;
    RnonCO2[	394	]=	0.383347124	;
    RnonCO2[	395	]=	0.383347124	;
    RnonCO2[	396	]=	0.383347124	;
    RnonCO2[	397	]=	0.383347124	;
    RnonCO2[	398	]=	0.383347124	;
    RnonCO2[	399	]=	0.383347124	;
    RnonCO2[	400	]=	0.383347124	;
    RnonCO2[	401	]=	0.383347124	;
    RnonCO2[	402	]=	0.383347124	;
    RnonCO2[	403	]=	0.383347124	;
    RnonCO2[	404	]=	0.383347124	;
    RnonCO2[	405	]=	0.383347124	;
    RnonCO2[	406	]=	0.383347124	;
    RnonCO2[	407	]=	0.383347124	;
    RnonCO2[	408	]=	0.383347124	;
    RnonCO2[	409	]=	0.383347124	;
    RnonCO2[	410	]=	0.383347124	;
    RnonCO2[	411	]=	0.383347124	;
    RnonCO2[	412	]=	0.383347124	;
    RnonCO2[	413	]=	0.383347124	;
    RnonCO2[	414	]=	0.383347124	;
    RnonCO2[	415	]=	0.383347124	;
    RnonCO2[	416	]=	0.383347124	;
    RnonCO2[	417	]=	0.383347124	;
    RnonCO2[	418	]=	0.383347124	;
    RnonCO2[	419	]=	0.383347124	;
    RnonCO2[	420	]=	0.383347124	;
    RnonCO2[	421	]=	0.383347124	;
    RnonCO2[	422	]=	0.383347124	;
    RnonCO2[	423	]=	0.383347124	;
    RnonCO2[	424	]=	0.383347124	;
    RnonCO2[	425	]=	0.383347124	;
    RnonCO2[	426	]=	0.383347124	;
    RnonCO2[	427	]=	0.383347124	;
    RnonCO2[	428	]=	0.383347124	;
    RnonCO2[	429	]=	0.383347124	;
    RnonCO2[	430	]=	0.383347124	;
    RnonCO2[	431	]=	0.383347124	;
    RnonCO2[	432	]=	0.383347124	;
    RnonCO2[	433	]=	0.383347124	;
    RnonCO2[	434	]=	0.383347124	;
    RnonCO2[	435	]=	0.383347124	;
    RnonCO2[	436	]=	0.383347124	;
    RnonCO2[	437	]=	0.383347124	;
    RnonCO2[	438	]=	0.383347124	;
    RnonCO2[	439	]=	0.383347124	;
    RnonCO2[	440	]=	0.383347124	;
    RnonCO2[	441	]=	0.383347124	;
    RnonCO2[	442	]=	0.383347124	;
    RnonCO2[	443	]=	0.383347124	;
    RnonCO2[	444	]=	0.383347124	;
    RnonCO2[	445	]=	0.383347124	;
    RnonCO2[	446	]=	0.383347124	;
    RnonCO2[	447	]=	0.383347124	;
    RnonCO2[	448	]=	0.383347124	;
    RnonCO2[	449	]=	0.383347124	;
    RnonCO2[	450	]=	0.383347124	;
    RnonCO2[	451	]=	0.383347124	;
    RnonCO2[	452	]=	0.383347124	;
    RnonCO2[	453	]=	0.383347124	;
    RnonCO2[	454	]=	0.383347124	;
    RnonCO2[	455	]=	0.383347124	;
    RnonCO2[	456	]=	0.383347124	;
    RnonCO2[	457	]=	0.383347124	;
    RnonCO2[	458	]=	0.383347124	;
    RnonCO2[	459	]=	0.383347124	;
    RnonCO2[	460	]=	0.383347124	;
    RnonCO2[	461	]=	0.383347124	;
    RnonCO2[	462	]=	0.383347124	;
    RnonCO2[	463	]=	0.383347124	;
    RnonCO2[	464	]=	0.383347124	;
    RnonCO2[	465	]=	0.383347124	;
    RnonCO2[	466	]=	0.383347124	;
    RnonCO2[	467	]=	0.383347124	;
    RnonCO2[	468	]=	0.383347124	;
    RnonCO2[	469	]=	0.383347124	;
    RnonCO2[	470	]=	0.383347124	;
    RnonCO2[	471	]=	0.383347124	;
    RnonCO2[	472	]=	0.383347124	;
    RnonCO2[	473	]=	0.383347124	;
    RnonCO2[	474	]=	0.383347124	;
    RnonCO2[	475	]=	0.383347124	;
    RnonCO2[	476	]=	0.383347124	;
    RnonCO2[	477	]=	0.383347124	;
    RnonCO2[	478	]=	0.383347124	;
    RnonCO2[	479	]=	0.383347124	;
    RnonCO2[	480	]=	0.383347124	;
    RnonCO2[	481	]=	0.383347124	;
    RnonCO2[	482	]=	0.383347124	;
    RnonCO2[	483	]=	0.383347124	;
    RnonCO2[	484	]=	0.383347124	;
    RnonCO2[	485	]=	0.383347124	;
    RnonCO2[	486	]=	0.383347124	;
    RnonCO2[	487	]=	0.383347124	;
    RnonCO2[	488	]=	0.383347124	;
    RnonCO2[	489	]=	0.383347124	;
    RnonCO2[	490	]=	0.383347124	;
    RnonCO2[	491	]=	0.383347124	;
    RnonCO2[	492	]=	0.383347124	;
    RnonCO2[	493	]=	0.383347124	;
    RnonCO2[	494	]=	0.383347124	;
    RnonCO2[	495	]=	0.383347124	;
    RnonCO2[	496	]=	0.383347124	;
    RnonCO2[	497	]=	0.383347124	;
    RnonCO2[	498	]=	0.383347124	;
    RnonCO2[	499	]=	0.383347124	;
    RnonCO2[	500	]=	0.383347124	;
    RnonCO2[	501	]=	0.383347124	;
    RnonCO2[	502	]=	0.383347124	;
    RnonCO2[	503	]=	0.383347124	;
    RnonCO2[	504	]=	0.383347124	;
    RnonCO2[	505	]=	0.383347124	;
    RnonCO2[	506	]=	0.383347124	;
    RnonCO2[	507	]=	0.383347124	;
    RnonCO2[	508	]=	0.383347124	;
    RnonCO2[	509	]=	0.383347124	;
    RnonCO2[	510	]=	0.383347124	;
    RnonCO2[	511	]=	0.383347124	;
    RnonCO2[	512	]=	0.383347124	;
    RnonCO2[	513	]=	0.383347124	;
    RnonCO2[	514	]=	0.383347124	;
    RnonCO2[	515	]=	0.383347124	;
    RnonCO2[	516	]=	0.383347124	;
    RnonCO2[	517	]=	0.383347124	;
    RnonCO2[	518	]=	0.383347124	;
    RnonCO2[	519	]=	0.383347124	;
    RnonCO2[	520	]=	0.383347124	;
    RnonCO2[	521	]=	0.383347124	;
    RnonCO2[	522	]=	0.383347124	;
    RnonCO2[	523	]=	0.383347124	;
    RnonCO2[	524	]=	0.383347124	;
    RnonCO2[	525	]=	0.383347124	;
    RnonCO2[	526	]=	0.383347124	;
    RnonCO2[	527	]=	0.383347124	;
    RnonCO2[	528	]=	0.383347124	;
    RnonCO2[	529	]=	0.383347124	;
    RnonCO2[	530	]=	0.383347124	;
    RnonCO2[	531	]=	0.383347124	;
    RnonCO2[	532	]=	0.383347124	;
    RnonCO2[	533	]=	0.383347124	;
    RnonCO2[	534	]=	0.383347124	;
    RnonCO2[	535	]=	0.383347124	;
    RnonCO2[	536	]=	0.383347124	;
    RnonCO2[	537	]=	0.383347124	;
    RnonCO2[	538	]=	0.383347124	;
    RnonCO2[	539	]=	0.383347124	;
    RnonCO2[	540	]=	0.383347124	;
    RnonCO2[	541	]=	0.383347124	;
    RnonCO2[	542	]=	0.383347124	;
    RnonCO2[	543	]=	0.383347124	;
    RnonCO2[	544	]=	0.383347124	;
    RnonCO2[	545	]=	0.383347124	;
    RnonCO2[	546	]=	0.383347124	;
    RnonCO2[	547	]=	0.383347124	;
    RnonCO2[	548	]=	0.383347124	;
    RnonCO2[	549	]=	0.383347124	;
    RnonCO2[	550	]=	0.383347124	;
    RnonCO2[	551	]=	0.383347124	;
    RnonCO2[	552	]=	0.383347124	;
    RnonCO2[	553	]=	0.383347124	;
    RnonCO2[	554	]=	0.383347124	;
    RnonCO2[	555	]=	0.383347124	;
    RnonCO2[	556	]=	0.383347124	;
    RnonCO2[	557	]=	0.383347124	;
    RnonCO2[	558	]=	0.383347124	;
    RnonCO2[	559	]=	0.383347124	;
    RnonCO2[	560	]=	0.383347124	;
    RnonCO2[	561	]=	0.383347124	;
    RnonCO2[	562	]=	0.383347124	;
    RnonCO2[	563	]=	0.383347124	;
    RnonCO2[	564	]=	0.383347124	;
    RnonCO2[	565	]=	0.383347124	;
    RnonCO2[	566	]=	0.383347124	;
    RnonCO2[	567	]=	0.383347124	;
    RnonCO2[	568	]=	0.383347124	;
    RnonCO2[	569	]=	0.383347124	;
    RnonCO2[	570	]=	0.383347124	;
    RnonCO2[	571	]=	0.383347124	;
    RnonCO2[	572	]=	0.383347124	;
    RnonCO2[	573	]=	0.383347124	;
    RnonCO2[	574	]=	0.383347124	;
    RnonCO2[	575	]=	0.383347124	;
    RnonCO2[	576	]=	0.383347124	;
    RnonCO2[	577	]=	0.383347124	;
    RnonCO2[	578	]=	0.383347124	;
    RnonCO2[	579	]=	0.383347124	;
    RnonCO2[	580	]=	0.383347124	;
    RnonCO2[	581	]=	0.383347124	;
    RnonCO2[	582	]=	0.383347124	;
    RnonCO2[	583	]=	0.383347124	;
    RnonCO2[	584	]=	0.383347124	;
    RnonCO2[	585	]=	0.383347124	;
    RnonCO2[	586	]=	0.383347124	;
    RnonCO2[	587	]=	0.383347124	;
    RnonCO2[	588	]=	0.383347124	;
    RnonCO2[	589	]=	0.383347124	;
    RnonCO2[	590	]=	0.383347124	;
    RnonCO2[	591	]=	0.383347124	;
    RnonCO2[	592	]=	0.383347124	;
    RnonCO2[	593	]=	0.383347124	;
    RnonCO2[	594	]=	0.383347124	;
    RnonCO2[	595	]=	0.383347124	;
    RnonCO2[	596	]=	0.383347124	;
    RnonCO2[	597	]=	0.383347124	;
    RnonCO2[	598	]=	0.383347124	;
    RnonCO2[	599	]=	0.383347124	;
    RnonCO2[	600	]=	0.383347124	;
    RnonCO2[	601	]=	0.383347124	;
    RnonCO2[	602	]=	0.383347124	;
    RnonCO2[	603	]=	0.383347124	;
    RnonCO2[	604	]=	0.383347124	;
    RnonCO2[	605	]=	0.383347124	;
    RnonCO2[	606	]=	0.383347124	;
    RnonCO2[	607	]=	0.383347124	;
    RnonCO2[	608	]=	0.383347124	;
    RnonCO2[	609	]=	0.383347124	;
    RnonCO2[	610	]=	0.383347124	;
    RnonCO2[	611	]=	0.383347124	;
    RnonCO2[	612	]=	0.383347124	;
    RnonCO2[	613	]=	0.383347124	;
    RnonCO2[	614	]=	0.383347124	;
    RnonCO2[	615	]=	0.383347124	;
    RnonCO2[	616	]=	0.383347124	;
    RnonCO2[	617	]=	0.383347124	;
    RnonCO2[	618	]=	0.383347124	;
    RnonCO2[	619	]=	0.383347124	;
    RnonCO2[	620	]=	0.383347124	;
    RnonCO2[	621	]=	0.383347124	;
    RnonCO2[	622	]=	0.383347124	;
    RnonCO2[	623	]=	0.383347124	;
    RnonCO2[	624	]=	0.383347124	;
    RnonCO2[	625	]=	0.383347124	;
    RnonCO2[	626	]=	0.383347124	;
    RnonCO2[	627	]=	0.383347124	;
    RnonCO2[	628	]=	0.383347124	;
    RnonCO2[	629	]=	0.383347124	;
    RnonCO2[	630	]=	0.383347124	;
    RnonCO2[	631	]=	0.383347124	;
    RnonCO2[	632	]=	0.383347124	;
    RnonCO2[	633	]=	0.383347124	;
    RnonCO2[	634	]=	0.383347124	;
    RnonCO2[	635	]=	0.383347124	;
    RnonCO2[	636	]=	0.383347124	;
    RnonCO2[	637	]=	0.383347124	;
    RnonCO2[	638	]=	0.383347124	;
    RnonCO2[	639	]=	0.383347124	;
    RnonCO2[	640	]=	0.383347124	;
    RnonCO2[	641	]=	0.383347124	;
    RnonCO2[	642	]=	0.383347124	;
    RnonCO2[	643	]=	0.383347124	;
    RnonCO2[	644	]=	0.383347124	;
    RnonCO2[	645	]=	0.383347124	;
    RnonCO2[	646	]=	0.383347124	;
    RnonCO2[	647	]=	0.383347124	;
    RnonCO2[	648	]=	0.383347124	;
    RnonCO2[	649	]=	0.383347124	;
    RnonCO2[	650	]=	0.383347124	;
    RnonCO2[	651	]=	0.383347124	;
    RnonCO2[	652	]=	0.383347124	;
    RnonCO2[	653	]=	0.383347124	;
    RnonCO2[	654	]=	0.383347124	;
    RnonCO2[	655	]=	0.383347124	;
    RnonCO2[	656	]=	0.383347124	;
    RnonCO2[	657	]=	0.383347124	;
    RnonCO2[	658	]=	0.383347124	;
    RnonCO2[	659	]=	0.383347124	;
    RnonCO2[	660	]=	0.383347124	;
    RnonCO2[	661	]=	0.383347124	;
    RnonCO2[	662	]=	0.383347124	;
    RnonCO2[	663	]=	0.383347124	;
    RnonCO2[	664	]=	0.383347124	;
    RnonCO2[	665	]=	0.383347124	;
    RnonCO2[	666	]=	0.383347124	;
    RnonCO2[	667	]=	0.383347124	;
    RnonCO2[	668	]=	0.383347124	;
    RnonCO2[	669	]=	0.383347124	;
    RnonCO2[	670	]=	0.383347124	;
    RnonCO2[	671	]=	0.383347124	;
    RnonCO2[	672	]=	0.383347124	;
    RnonCO2[	673	]=	0.383347124	;
    RnonCO2[	674	]=	0.383347124	;
    RnonCO2[	675	]=	0.383347124	;
    RnonCO2[	676	]=	0.383347124	;
    RnonCO2[	677	]=	0.383347124	;
    RnonCO2[	678	]=	0.383347124	;
    RnonCO2[	679	]=	0.383347124	;
    RnonCO2[	680	]=	0.383347124	;
    RnonCO2[	681	]=	0.383347124	;
    RnonCO2[	682	]=	0.383347124	;
    RnonCO2[	683	]=	0.383347124	;
    RnonCO2[	684	]=	0.383347124	;
    RnonCO2[	685	]=	0.383347124	;
    RnonCO2[	686	]=	0.383347124	;
    RnonCO2[	687	]=	0.383347124	;
    RnonCO2[	688	]=	0.383347124	;
    RnonCO2[	689	]=	0.383347124	;
    RnonCO2[	690	]=	0.383347124	;
    RnonCO2[	691	]=	0.383347124	;
    RnonCO2[	692	]=	0.383347124	;
    RnonCO2[	693	]=	0.383347124	;
    RnonCO2[	694	]=	0.383347124	;
    RnonCO2[	695	]=	0.383347124	;
    RnonCO2[	696	]=	0.383347124	;
    RnonCO2[	697	]=	0.383347124	;
    RnonCO2[	698	]=	0.383347124	;
    RnonCO2[	699	]=	0.383347124	;
    RnonCO2[	700	]=	0.383347124	;
    RnonCO2[	701	]=	0.383347124	;
    RnonCO2[	702	]=	0.383347124	;
    RnonCO2[	703	]=	0.383347124	;
    RnonCO2[	704	]=	0.383347124	;
    RnonCO2[	705	]=	0.383347124	;
    RnonCO2[	706	]=	0.383347124	;
    RnonCO2[	707	]=	0.383347124	;
    RnonCO2[	708	]=	0.383347124	;
    RnonCO2[	709	]=	0.383347124	;
    RnonCO2[	710	]=	0.383347124	;
    RnonCO2[	711	]=	0.383347124	;
    RnonCO2[	712	]=	0.383347124	;
    RnonCO2[	713	]=	0.383347124	;
    RnonCO2[	714	]=	0.383347124	;
    RnonCO2[	715	]=	0.383347124	;
    RnonCO2[	716	]=	0.383347124	;
    RnonCO2[	717	]=	0.383347124	;
    RnonCO2[	718	]=	0.383347124	;
    RnonCO2[	719	]=	0.383347124	;
    RnonCO2[	720	]=	0.383347124	;
    RnonCO2[	721	]=	0.383347124	;
    RnonCO2[	722	]=	0.383347124	;
    RnonCO2[	723	]=	0.383347124	;
    RnonCO2[	724	]=	0.383347124	;
    RnonCO2[	725	]=	0.383347124	;
    RnonCO2[	726	]=	0.383347124	;
    RnonCO2[	727	]=	0.383347124	;
    RnonCO2[	728	]=	0.383347124	;
    RnonCO2[	729	]=	0.383347124	;
    RnonCO2[	730	]=	0.383347124	;
    RnonCO2[	731	]=	0.383347124	;
    RnonCO2[	732	]=	0.383347124	;
    RnonCO2[	733	]=	0.383347124	;
    RnonCO2[	734	]=	0.383347124	;
    RnonCO2[	735	]=	0.383347124	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
}

void setRnonCO2_RCP6(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005145555	;
    RnonCO2[	2	]=	0.009090068	;
    RnonCO2[	3	]=	0.007768629	;
    RnonCO2[	4	]=	0.006256789	;
    RnonCO2[	5	]=	0.004769658	;
    RnonCO2[	6	]=	0.002906336	;
    RnonCO2[	7	]=	0.001080178	;
    RnonCO2[	8	]=	-0.000291468	;
    RnonCO2[	9	]=	-0.001612412	;
    RnonCO2[	10	]=	-0.00288359	;
    RnonCO2[	11	]=	-0.00410611	;
    RnonCO2[	12	]=	-0.005282233	;
    RnonCO2[	13	]=	-0.006413549	;
    RnonCO2[	14	]=	-0.007501746	;
    RnonCO2[	15	]=	-0.008551056	;
    RnonCO2[	16	]=	-0.010019335	;
    RnonCO2[	17	]=	-0.011459991	;
    RnonCO2[	18	]=	-0.012417579	;
    RnonCO2[	19	]=	-0.013333977	;
    RnonCO2[	20	]=	-0.014201345	;
    RnonCO2[	21	]=	-0.015012487	;
    RnonCO2[	22	]=	-0.015760238	;
    RnonCO2[	23	]=	-0.016437067	;
    RnonCO2[	24	]=	-0.017035543	;
    RnonCO2[	25	]=	-0.017549544	;
    RnonCO2[	26	]=	-0.018434793	;
    RnonCO2[	27	]=	-0.019238993	;
    RnonCO2[	28	]=	-0.019510794	;
    RnonCO2[	29	]=	-0.019709367	;
    RnonCO2[	30	]=	-0.019838439	;
    RnonCO2[	31	]=	-0.019901316	;
    RnonCO2[	32	]=	-0.020355353	;
    RnonCO2[	33	]=	-0.020749651	;
    RnonCO2[	34	]=	-0.020634193	;
    RnonCO2[	35	]=	-0.02091346	;
    RnonCO2[	36	]=	-0.021125633	;
    RnonCO2[	37	]=	-0.02171132	;
    RnonCO2[	38	]=	-0.021774359	;
    RnonCO2[	39	]=	-0.020873209	;
    RnonCO2[	40	]=	-0.02036553	;
    RnonCO2[	41	]=	-0.020256367	;
    RnonCO2[	42	]=	-0.020105185	;
    RnonCO2[	43	]=	-0.01947287	;
    RnonCO2[	44	]=	-0.018814746	;
    RnonCO2[	45	]=	-0.018134946	;
    RnonCO2[	46	]=	-0.017872094	;
    RnonCO2[	47	]=	-0.017576381	;
    RnonCO2[	48	]=	-0.016804485	;
    RnonCO2[	49	]=	-0.016001407	;
    RnonCO2[	50	]=	-0.015606441	;
    RnonCO2[	51	]=	-0.015619264	;
    RnonCO2[	52	]=	-0.015600061	;
    RnonCO2[	53	]=	-0.015116575	;
    RnonCO2[	54	]=	-0.014172313	;
    RnonCO2[	55	]=	-0.013205379	;
    RnonCO2[	56	]=	-0.012216093	;
    RnonCO2[	57	]=	-0.011635129	;
    RnonCO2[	58	]=	-0.011459514	;
    RnonCO2[	59	]=	-0.010829842	;
    RnonCO2[	60	]=	-0.010175791	;
    RnonCO2[	61	]=	-0.009499636	;
    RnonCO2[	62	]=	-0.00879934	;
    RnonCO2[	63	]=	-0.008077943	;
    RnonCO2[	64	]=	-0.006912545	;
    RnonCO2[	65	]=	-0.008242223	;
    RnonCO2[	66	]=	-0.009135821	;
    RnonCO2[	67	]=	-0.007501052	;
    RnonCO2[	68	]=	-0.006687418	;
    RnonCO2[	69	]=	-0.005858015	;
    RnonCO2[	70	]=	-0.005005979	;
    RnonCO2[	71	]=	-0.005767925	;
    RnonCO2[	72	]=	-0.006086639	;
    RnonCO2[	73	]=	-0.005137938	;
    RnonCO2[	74	]=	-0.004558881	;
    RnonCO2[	75	]=	-0.004336125	;
    RnonCO2[	76	]=	-0.004045198	;
    RnonCO2[	77	]=	-0.003665109	;
    RnonCO2[	78	]=	-0.003220213	;
    RnonCO2[	79	]=	-0.002760518	;
    RnonCO2[	80	]=	-0.003527376	;
    RnonCO2[	81	]=	-0.003576651	;
    RnonCO2[	82	]=	-0.003275283	;
    RnonCO2[	83	]=	-0.003386771	;
    RnonCO2[	84	]=	-0.003510917	;
    RnonCO2[	85	]=	-0.004646356	;
    RnonCO2[	86	]=	-0.003691576	;
    RnonCO2[	87	]=	-0.009505158	;
    RnonCO2[	88	]=	-0.016364432	;
    RnonCO2[	89	]=	-0.017996784	;
    RnonCO2[	90	]=	-0.019670058	;
    RnonCO2[	91	]=	-0.020430126	;
    RnonCO2[	92	]=	-0.021643321	;
    RnonCO2[	93	]=	-0.02142206	;
    RnonCO2[	94	]=	-0.022552345	;
    RnonCO2[	95	]=	-0.031588211	;
    RnonCO2[	96	]=	-0.046252985	;
    RnonCO2[	97	]=	-0.042365448	;
    RnonCO2[	98	]=	-0.033665717	;
    RnonCO2[	99	]=	-0.034555638	;
    RnonCO2[	100	]=	-0.037298509	;
    RnonCO2[	101	]=	-0.046083195	;
    RnonCO2[	102	]=	-0.05558168	;
    RnonCO2[	103	]=	-0.057464266	;
    RnonCO2[	104	]=	-0.053606449	;
    RnonCO2[	105	]=	-0.05168834	;
    RnonCO2[	106	]=	-0.061304945	;
    RnonCO2[	107	]=	-0.086608149	;
    RnonCO2[	108	]=	-0.108195137	;
    RnonCO2[	109	]=	-0.112259625	;
    RnonCO2[	110	]=	-0.111643119	;
    RnonCO2[	111	]=	-0.108991576	;
    RnonCO2[	112	]=	-0.10203489	;
    RnonCO2[	113	]=	-0.098533227	;
    RnonCO2[	114	]=	-0.101949678	;
    RnonCO2[	115	]=	-0.114562053	;
    RnonCO2[	116	]=	-0.123024156	;
    RnonCO2[	117	]=	-0.119809652	;
    RnonCO2[	118	]=	-0.118941351	;
    RnonCO2[	119	]=	-0.120181779	;
    RnonCO2[	120	]=	-0.117316831	;
    RnonCO2[	121	]=	-0.115023243	;
    RnonCO2[	122	]=	-0.116983521	;
    RnonCO2[	123	]=	-0.125997633	;
    RnonCO2[	124	]=	-0.129568227	;
    RnonCO2[	125	]=	-0.131248987	;
    RnonCO2[	126	]=	-0.137316696	;
    RnonCO2[	127	]=	-0.141273792	;
    RnonCO2[	128	]=	-0.144231375	;
    RnonCO2[	129	]=	-0.147973341	;
    RnonCO2[	130	]=	-0.153688224	;
    RnonCO2[	131	]=	-0.15652816	;
    RnonCO2[	132	]=	-0.157109013	;
    RnonCO2[	133	]=	-0.158858513	;
    RnonCO2[	134	]=	-0.162186704	;
    RnonCO2[	135	]=	-0.165318228	;
    RnonCO2[	136	]=	-0.171733193	;
    RnonCO2[	137	]=	-0.178096644	;
    RnonCO2[	138	]=	-0.183870407	;
    RnonCO2[	139	]=	-0.189730028	;
    RnonCO2[	140	]=	-0.194221589	;
    RnonCO2[	141	]=	-0.201576481	;
    RnonCO2[	142	]=	-0.208859035	;
    RnonCO2[	143	]=	-0.207375441	;
    RnonCO2[	144	]=	-0.202571711	;
    RnonCO2[	145	]=	-0.204126848	;
    RnonCO2[	146	]=	-0.201876709	;
    RnonCO2[	147	]=	-0.195147841	;
    RnonCO2[	148	]=	-0.191449584	;
    RnonCO2[	149	]=	-0.183770215	;
    RnonCO2[	150	]=	-0.173476305	;
    RnonCO2[	151	]=	-0.170909799	;
    RnonCO2[	152	]=	-0.171515561	;
    RnonCO2[	153	]=	-0.169079801	;
    RnonCO2[	154	]=	-0.159414516	;
    RnonCO2[	155	]=	-0.155013584	;
    RnonCO2[	156	]=	-0.151089869	;
    RnonCO2[	157	]=	-0.144432651	;
    RnonCO2[	158	]=	-0.152359798	;
    RnonCO2[	159	]=	-0.158148636	;
    RnonCO2[	160	]=	-0.155277608	;
    RnonCO2[	161	]=	-0.152617947	;
    RnonCO2[	162	]=	-0.154120923	;
    RnonCO2[	163	]=	-0.156019482	;
    RnonCO2[	164	]=	-0.155886394	;
    RnonCO2[	165	]=	-0.152021034	;
    RnonCO2[	166	]=	-0.141834688	;
    RnonCO2[	167	]=	-0.13108946	;
    RnonCO2[	168	]=	-0.125408882	;
    RnonCO2[	169	]=	-0.125515632	;
    RnonCO2[	170	]=	-0.125194614	;
    RnonCO2[	171	]=	-0.126120729	;
    RnonCO2[	172	]=	-0.12532345	;
    RnonCO2[	173	]=	-0.115303554	;
    RnonCO2[	174	]=	-0.10787249	;
    RnonCO2[	175	]=	-0.109257271	;
    RnonCO2[	176	]=	-0.113724728	;
    RnonCO2[	177	]=	-0.117421621	;
    RnonCO2[	178	]=	-0.11813163	;
    RnonCO2[	179	]=	-0.119629474	;
    RnonCO2[	180	]=	-0.119789192	;
    RnonCO2[	181	]=	-0.124270593	;
    RnonCO2[	182	]=	-0.135220142	;
    RnonCO2[	183	]=	-0.145282294	;
    RnonCO2[	184	]=	-0.1490379	;
    RnonCO2[	185	]=	-0.154219559	;
    RnonCO2[	186	]=	-0.178760049	;
    RnonCO2[	187	]=	-0.203310188	;
    RnonCO2[	188	]=	-0.212758852	;
    RnonCO2[	189	]=	-0.221219612	;
    RnonCO2[	190	]=	-0.230341307	;
    RnonCO2[	191	]=	-0.239337924	;
    RnonCO2[	192	]=	-0.247524974	;
    RnonCO2[	193	]=	-0.250847198	;
    RnonCO2[	194	]=	-0.245200212	;
    RnonCO2[	195	]=	-0.237476895	;
    RnonCO2[	196	]=	-0.24791739	;
    RnonCO2[	197	]=	-0.261719365	;
    RnonCO2[	198	]=	-0.263179809	;
    RnonCO2[	199	]=	-0.263298027	;
    RnonCO2[	200	]=	-0.261139159	;
    RnonCO2[	201	]=	-0.257781723	;
    RnonCO2[	202	]=	-0.255724839	;
    RnonCO2[	203	]=	-0.25169763	;
    RnonCO2[	204	]=	-0.241647721	;
    RnonCO2[	205	]=	-0.221452127	;
    RnonCO2[	206	]=	-0.196790013	;
    RnonCO2[	207	]=	-0.182093765	;
    RnonCO2[	208	]=	-0.174745229	;
    RnonCO2[	209	]=	-0.16714548	;
    RnonCO2[	210	]=	-0.159384584	;
    RnonCO2[	211	]=	-0.156373877	;
    RnonCO2[	212	]=	-0.153042015	;
    RnonCO2[	213	]=	-0.139817455	;
    RnonCO2[	214	]=	-0.125210902	;
    RnonCO2[	215	]=	-0.119848303	;
    RnonCO2[	216	]=	-0.119430668	;
    RnonCO2[	217	]=	-0.123211365	;
    RnonCO2[	218	]=	-0.125809708	;
    RnonCO2[	219	]=	-0.120193155	;
    RnonCO2[	220	]=	-0.110911249	;
    RnonCO2[	221	]=	-0.102402229	;
    RnonCO2[	222	]=	-0.096562536	;
    RnonCO2[	223	]=	-0.086930587	;
    RnonCO2[	224	]=	-0.072710932	;
    RnonCO2[	225	]=	-0.05997191	;
    RnonCO2[	226	]=	-0.058006544	;
    RnonCO2[	227	]=	-0.065604043	;
    RnonCO2[	228	]=	-0.067949961	;
    RnonCO2[	229	]=	-0.065994527	;
    RnonCO2[	230	]=	-0.058283284	;
    RnonCO2[	231	]=	-0.04756956	;
    RnonCO2[	232	]=	-0.049208339	;
    RnonCO2[	233	]=	-0.056699684	;
    RnonCO2[	234	]=	-0.059531967	;
    RnonCO2[	235	]=	-0.065638041	;
    RnonCO2[	236	]=	-0.069976074	;
    RnonCO2[	237	]=	-0.065660736	;
    RnonCO2[	238	]=	-0.060876733	;
    RnonCO2[	239	]=	-0.057486962	;
    RnonCO2[	240	]=	-0.053923583	;
    RnonCO2[	241	]=	-0.048265245	;
    RnonCO2[	242	]=	-0.041908889	;
    RnonCO2[	243	]=	-0.035470985	;
    RnonCO2[	244	]=	-0.028488885	;
    RnonCO2[	245	]=	-0.020170078	;
    RnonCO2[	246	]=	-0.009654576	;
    RnonCO2[	247	]=	0.002229379	;
    RnonCO2[	248	]=	0.013767156	;
    RnonCO2[	249	]=	0.024503705	;
    RnonCO2[	250	]=	0.034790944	;
    RnonCO2[	251	]=	0.044692559	;
    RnonCO2[	252	]=	0.054247902	;
    RnonCO2[	253	]=	0.063487271	;
    RnonCO2[	254	]=	0.07300731	;
    RnonCO2[	255	]=	0.083115143	;
    RnonCO2[	256	]=	0.093858679	;
    RnonCO2[	257	]=	0.105274945	;
    RnonCO2[	258	]=	0.117015494	;
    RnonCO2[	259	]=	0.129042558	;
    RnonCO2[	260	]=	0.141370327	;
    RnonCO2[	261	]=	0.153994973	;
    RnonCO2[	262	]=	0.166903607	;
    RnonCO2[	263	]=	0.18006939	;
    RnonCO2[	264	]=	0.193471412	;
    RnonCO2[	265	]=	0.204195251	;
    RnonCO2[	266	]=	0.209318794	;
    RnonCO2[	267	]=	0.211921957	;
    RnonCO2[	268	]=	0.214765729	;
    RnonCO2[	269	]=	0.217500548	;
    RnonCO2[	270	]=	0.220111388	;
    RnonCO2[	271	]=	0.222584471	;
    RnonCO2[	272	]=	0.224905928	;
    RnonCO2[	273	]=	0.227053889	;
    RnonCO2[	274	]=	0.228995888	;
    RnonCO2[	275	]=	0.232519566	;
    RnonCO2[	276	]=	0.239403838	;
    RnonCO2[	277	]=	0.247369643	;
    RnonCO2[	278	]=	0.254573	;
    RnonCO2[	279	]=	0.26146722	;
    RnonCO2[	280	]=	0.268143306	;
    RnonCO2[	281	]=	0.274673454	;
    RnonCO2[	282	]=	0.281112631	;
    RnonCO2[	283	]=	0.28750532	;
    RnonCO2[	284	]=	0.293860225	;
    RnonCO2[	285	]=	0.299059232	;
    RnonCO2[	286	]=	0.302026911	;
    RnonCO2[	287	]=	0.303902576	;
    RnonCO2[	288	]=	0.305810546	;
    RnonCO2[	289	]=	0.307728275	;
    RnonCO2[	290	]=	0.309636186	;
    RnonCO2[	291	]=	0.311574085	;
    RnonCO2[	292	]=	0.313572228	;
    RnonCO2[	293	]=	0.315655383	;
    RnonCO2[	294	]=	0.317849754	;
    RnonCO2[	295	]=	0.323336003	;
    RnonCO2[	296	]=	0.335279015	;
    RnonCO2[	297	]=	0.349977553	;
    RnonCO2[	298	]=	0.364212377	;
    RnonCO2[	299	]=	0.378446117	;
    RnonCO2[	300	]=	0.392644356	;
    RnonCO2[	301	]=	0.406791296	;
    RnonCO2[	302	]=	0.420931456	;
    RnonCO2[	303	]=	0.435100184	;
    RnonCO2[	304	]=	0.449329044	;
    RnonCO2[	305	]=	0.462134841	;
    RnonCO2[	306	]=	0.472000098	;
    RnonCO2[	307	]=	0.480345009	;
    RnonCO2[	308	]=	0.488498229	;
    RnonCO2[	309	]=	0.496365261	;
    RnonCO2[	310	]=	0.503969592	;
    RnonCO2[	311	]=	0.511290562	;
    RnonCO2[	312	]=	0.518324478	;
    RnonCO2[	313	]=	0.525126448	;
    RnonCO2[	314	]=	0.531742174	;
    RnonCO2[	315	]=	0.536514421	;
    RnonCO2[	316	]=	0.537793824	;
    RnonCO2[	317	]=	0.537189424	;
    RnonCO2[	318	]=	0.535963926	;
    RnonCO2[	319	]=	0.533830098	;
    RnonCO2[	320	]=	0.530854212	;
    RnonCO2[	321	]=	0.527096934	;
    RnonCO2[	322	]=	0.522571459	;
    RnonCO2[	323	]=	0.517304785	;
    RnonCO2[	324	]=	0.511378144	;
    RnonCO2[	325	]=	0.504950814	;
    RnonCO2[	326	]=	0.498173588	;
    RnonCO2[	327	]=	0.491427323	;
    RnonCO2[	328	]=	0.485029515	;
    RnonCO2[	329	]=	0.478935116	;
    RnonCO2[	330	]=	0.473115467	;
    RnonCO2[	331	]=	0.467548525	;
    RnonCO2[	332	]=	0.462213949	;
    RnonCO2[	333	]=	0.457139058	;
    RnonCO2[	334	]=	0.452401937	;
    RnonCO2[	335	]=	0.447294793	;
    RnonCO2[	336	]=	0.441058515	;
    RnonCO2[	337	]=	0.435046091	;
    RnonCO2[	338	]=	0.430165827	;
    RnonCO2[	339	]=	0.425920409	;
    RnonCO2[	340	]=	0.422225695	;
    RnonCO2[	341	]=	0.41901013	;
    RnonCO2[	342	]=	0.416215121	;
    RnonCO2[	343	]=	0.413788317	;
    RnonCO2[	344	]=	0.411645604	;
    RnonCO2[	345	]=	0.409724998	;
    RnonCO2[	346	]=	0.408023702	;
    RnonCO2[	347	]=	0.406535893	;
    RnonCO2[	348	]=	0.405253984	;
    RnonCO2[	349	]=	0.404174485	;
    RnonCO2[	350	]=	0.403275605	;
    RnonCO2[	351	]=	0.402522488	;
    RnonCO2[	352	]=	0.401887996	;
    RnonCO2[	353	]=	0.401352761	;
    RnonCO2[	354	]=	0.400899942	;
    RnonCO2[	355	]=	0.400477424	;
    RnonCO2[	356	]=	0.40005214	;
    RnonCO2[	357	]=	0.399645998	;
    RnonCO2[	358	]=	0.399275485	;
    RnonCO2[	359	]=	0.398953056	;
    RnonCO2[	360	]=	0.398690295	;
    RnonCO2[	361	]=	0.3984758	;
    RnonCO2[	362	]=	0.398286722	;
    RnonCO2[	363	]=	0.398108358	;
    RnonCO2[	364	]=	0.397932702	;
    RnonCO2[	365	]=	0.397752792	;
    RnonCO2[	366	]=	0.397526109	;
    RnonCO2[	367	]=	0.397227301	;
    RnonCO2[	368	]=	0.396885187	;
    RnonCO2[	369	]=	0.396522534	;
    RnonCO2[	370	]=	0.396156959	;
    RnonCO2[	371	]=	0.39580735	;
    RnonCO2[	372	]=	0.395472249	;
    RnonCO2[	373	]=	0.395134885	;
    RnonCO2[	374	]=	0.394784137	;
    RnonCO2[	375	]=	0.394414873	;
    RnonCO2[	376	]=	0.394023161	;
    RnonCO2[	377	]=	0.393568791	;
    RnonCO2[	378	]=	0.393028761	;
    RnonCO2[	379	]=	0.392433693	;
    RnonCO2[	380	]=	0.391807878	;
    RnonCO2[	381	]=	0.391170327	;
    RnonCO2[	382	]=	0.390541212	;
    RnonCO2[	383	]=	0.389919841	;
    RnonCO2[	384	]=	0.38929067	;
    RnonCO2[	385	]=	0.388972503	;
    RnonCO2[	386	]=	0.388972503	;
    RnonCO2[	387	]=	0.388972503	;
    RnonCO2[	388	]=	0.388972503	;
    RnonCO2[	389	]=	0.388972503	;
    RnonCO2[	390	]=	0.388972503	;
    RnonCO2[	391	]=	0.388972503	;
    RnonCO2[	392	]=	0.388972503	;
    RnonCO2[	393	]=	0.388972503	;
    RnonCO2[	394	]=	0.388972503	;
    RnonCO2[	395	]=	0.388972503	;
    RnonCO2[	396	]=	0.388972503	;
    RnonCO2[	397	]=	0.388972503	;
    RnonCO2[	398	]=	0.388972503	;
    RnonCO2[	399	]=	0.388972503	;
    RnonCO2[	400	]=	0.388972503	;
    RnonCO2[	401	]=	0.388972503	;
    RnonCO2[	402	]=	0.388972503	;
    RnonCO2[	403	]=	0.388972503	;
    RnonCO2[	404	]=	0.388972503	;
    RnonCO2[	405	]=	0.388972503	;
    RnonCO2[	406	]=	0.388972503	;
    RnonCO2[	407	]=	0.388972503	;
    RnonCO2[	408	]=	0.388972503	;
    RnonCO2[	409	]=	0.388972503	;
    RnonCO2[	410	]=	0.388972503	;
    RnonCO2[	411	]=	0.388972503	;
    RnonCO2[	412	]=	0.388972503	;
    RnonCO2[	413	]=	0.388972503	;
    RnonCO2[	414	]=	0.388972503	;
    RnonCO2[	415	]=	0.388972503	;
    RnonCO2[	416	]=	0.388972503	;
    RnonCO2[	417	]=	0.388972503	;
    RnonCO2[	418	]=	0.388972503	;
    RnonCO2[	419	]=	0.388972503	;
    RnonCO2[	420	]=	0.388972503	;
    RnonCO2[	421	]=	0.388972503	;
    RnonCO2[	422	]=	0.388972503	;
    RnonCO2[	423	]=	0.388972503	;
    RnonCO2[	424	]=	0.388972503	;
    RnonCO2[	425	]=	0.388972503	;
    RnonCO2[	426	]=	0.388972503	;
    RnonCO2[	427	]=	0.388972503	;
    RnonCO2[	428	]=	0.388972503	;
    RnonCO2[	429	]=	0.388972503	;
    RnonCO2[	430	]=	0.388972503	;
    RnonCO2[	431	]=	0.388972503	;
    RnonCO2[	432	]=	0.388972503	;
    RnonCO2[	433	]=	0.388972503	;
    RnonCO2[	434	]=	0.388972503	;
    RnonCO2[	435	]=	0.388972503	;
    RnonCO2[	436	]=	0.388972503	;
    RnonCO2[	437	]=	0.388972503	;
    RnonCO2[	438	]=	0.388972503	;
    RnonCO2[	439	]=	0.388972503	;
    RnonCO2[	440	]=	0.388972503	;
    RnonCO2[	441	]=	0.388972503	;
    RnonCO2[	442	]=	0.388972503	;
    RnonCO2[	443	]=	0.388972503	;
    RnonCO2[	444	]=	0.388972503	;
    RnonCO2[	445	]=	0.388972503	;
    RnonCO2[	446	]=	0.388972503	;
    RnonCO2[	447	]=	0.388972503	;
    RnonCO2[	448	]=	0.388972503	;
    RnonCO2[	449	]=	0.388972503	;
    RnonCO2[	450	]=	0.388972503	;
    RnonCO2[	451	]=	0.388972503	;
    RnonCO2[	452	]=	0.388972503	;
    RnonCO2[	453	]=	0.388972503	;
    RnonCO2[	454	]=	0.388972503	;
    RnonCO2[	455	]=	0.388972503	;
    RnonCO2[	456	]=	0.388972503	;
    RnonCO2[	457	]=	0.388972503	;
    RnonCO2[	458	]=	0.388972503	;
    RnonCO2[	459	]=	0.388972503	;
    RnonCO2[	460	]=	0.388972503	;
    RnonCO2[	461	]=	0.388972503	;
    RnonCO2[	462	]=	0.388972503	;
    RnonCO2[	463	]=	0.388972503	;
    RnonCO2[	464	]=	0.388972503	;
    RnonCO2[	465	]=	0.388972503	;
    RnonCO2[	466	]=	0.388972503	;
    RnonCO2[	467	]=	0.388972503	;
    RnonCO2[	468	]=	0.388972503	;
    RnonCO2[	469	]=	0.388972503	;
    RnonCO2[	470	]=	0.388972503	;
    RnonCO2[	471	]=	0.388972503	;
    RnonCO2[	472	]=	0.388972503	;
    RnonCO2[	473	]=	0.388972503	;
    RnonCO2[	474	]=	0.388972503	;
    RnonCO2[	475	]=	0.388972503	;
    RnonCO2[	476	]=	0.388972503	;
    RnonCO2[	477	]=	0.388972503	;
    RnonCO2[	478	]=	0.388972503	;
    RnonCO2[	479	]=	0.388972503	;
    RnonCO2[	480	]=	0.388972503	;
    RnonCO2[	481	]=	0.388972503	;
    RnonCO2[	482	]=	0.388972503	;
    RnonCO2[	483	]=	0.388972503	;
    RnonCO2[	484	]=	0.388972503	;
    RnonCO2[	485	]=	0.388972503	;
    RnonCO2[	486	]=	0.388972503	;
    RnonCO2[	487	]=	0.388972503	;
    RnonCO2[	488	]=	0.388972503	;
    RnonCO2[	489	]=	0.388972503	;
    RnonCO2[	490	]=	0.388972503	;
    RnonCO2[	491	]=	0.388972503	;
    RnonCO2[	492	]=	0.388972503	;
    RnonCO2[	493	]=	0.388972503	;
    RnonCO2[	494	]=	0.388972503	;
    RnonCO2[	495	]=	0.388972503	;
    RnonCO2[	496	]=	0.388972503	;
    RnonCO2[	497	]=	0.388972503	;
    RnonCO2[	498	]=	0.388972503	;
    RnonCO2[	499	]=	0.388972503	;
    RnonCO2[	500	]=	0.388972503	;
    RnonCO2[	501	]=	0.388972503	;
    RnonCO2[	502	]=	0.388972503	;
    RnonCO2[	503	]=	0.388972503	;
    RnonCO2[	504	]=	0.388972503	;
    RnonCO2[	505	]=	0.388972503	;
    RnonCO2[	506	]=	0.388972503	;
    RnonCO2[	507	]=	0.388972503	;
    RnonCO2[	508	]=	0.388972503	;
    RnonCO2[	509	]=	0.388972503	;
    RnonCO2[	510	]=	0.388972503	;
    RnonCO2[	511	]=	0.388972503	;
    RnonCO2[	512	]=	0.388972503	;
    RnonCO2[	513	]=	0.388972503	;
    RnonCO2[	514	]=	0.388972503	;
    RnonCO2[	515	]=	0.388972503	;
    RnonCO2[	516	]=	0.388972503	;
    RnonCO2[	517	]=	0.388972503	;
    RnonCO2[	518	]=	0.388972503	;
    RnonCO2[	519	]=	0.388972503	;
    RnonCO2[	520	]=	0.388972503	;
    RnonCO2[	521	]=	0.388972503	;
    RnonCO2[	522	]=	0.388972503	;
    RnonCO2[	523	]=	0.388972503	;
    RnonCO2[	524	]=	0.388972503	;
    RnonCO2[	525	]=	0.388972503	;
    RnonCO2[	526	]=	0.388972503	;
    RnonCO2[	527	]=	0.388972503	;
    RnonCO2[	528	]=	0.388972503	;
    RnonCO2[	529	]=	0.388972503	;
    RnonCO2[	530	]=	0.388972503	;
    RnonCO2[	531	]=	0.388972503	;
    RnonCO2[	532	]=	0.388972503	;
    RnonCO2[	533	]=	0.388972503	;
    RnonCO2[	534	]=	0.388972503	;
    RnonCO2[	535	]=	0.388972503	;
    RnonCO2[	536	]=	0.388972503	;
    RnonCO2[	537	]=	0.388972503	;
    RnonCO2[	538	]=	0.388972503	;
    RnonCO2[	539	]=	0.388972503	;
    RnonCO2[	540	]=	0.388972503	;
    RnonCO2[	541	]=	0.388972503	;
    RnonCO2[	542	]=	0.388972503	;
    RnonCO2[	543	]=	0.388972503	;
    RnonCO2[	544	]=	0.388972503	;
    RnonCO2[	545	]=	0.388972503	;
    RnonCO2[	546	]=	0.388972503	;
    RnonCO2[	547	]=	0.388972503	;
    RnonCO2[	548	]=	0.388972503	;
    RnonCO2[	549	]=	0.388972503	;
    RnonCO2[	550	]=	0.388972503	;
    RnonCO2[	551	]=	0.388972503	;
    RnonCO2[	552	]=	0.388972503	;
    RnonCO2[	553	]=	0.388972503	;
    RnonCO2[	554	]=	0.388972503	;
    RnonCO2[	555	]=	0.388972503	;
    RnonCO2[	556	]=	0.388972503	;
    RnonCO2[	557	]=	0.388972503	;
    RnonCO2[	558	]=	0.388972503	;
    RnonCO2[	559	]=	0.388972503	;
    RnonCO2[	560	]=	0.388972503	;
    RnonCO2[	561	]=	0.388972503	;
    RnonCO2[	562	]=	0.388972503	;
    RnonCO2[	563	]=	0.388972503	;
    RnonCO2[	564	]=	0.388972503	;
    RnonCO2[	565	]=	0.388972503	;
    RnonCO2[	566	]=	0.388972503	;
    RnonCO2[	567	]=	0.388972503	;
    RnonCO2[	568	]=	0.388972503	;
    RnonCO2[	569	]=	0.388972503	;
    RnonCO2[	570	]=	0.388972503	;
    RnonCO2[	571	]=	0.388972503	;
    RnonCO2[	572	]=	0.388972503	;
    RnonCO2[	573	]=	0.388972503	;
    RnonCO2[	574	]=	0.388972503	;
    RnonCO2[	575	]=	0.388972503	;
    RnonCO2[	576	]=	0.388972503	;
    RnonCO2[	577	]=	0.388972503	;
    RnonCO2[	578	]=	0.388972503	;
    RnonCO2[	579	]=	0.388972503	;
    RnonCO2[	580	]=	0.388972503	;
    RnonCO2[	581	]=	0.388972503	;
    RnonCO2[	582	]=	0.388972503	;
    RnonCO2[	583	]=	0.388972503	;
    RnonCO2[	584	]=	0.388972503	;
    RnonCO2[	585	]=	0.388972503	;
    RnonCO2[	586	]=	0.388972503	;
    RnonCO2[	587	]=	0.388972503	;
    RnonCO2[	588	]=	0.388972503	;
    RnonCO2[	589	]=	0.388972503	;
    RnonCO2[	590	]=	0.388972503	;
    RnonCO2[	591	]=	0.388972503	;
    RnonCO2[	592	]=	0.388972503	;
    RnonCO2[	593	]=	0.388972503	;
    RnonCO2[	594	]=	0.388972503	;
    RnonCO2[	595	]=	0.388972503	;
    RnonCO2[	596	]=	0.388972503	;
    RnonCO2[	597	]=	0.388972503	;
    RnonCO2[	598	]=	0.388972503	;
    RnonCO2[	599	]=	0.388972503	;
    RnonCO2[	600	]=	0.388972503	;
    RnonCO2[	601	]=	0.388972503	;
    RnonCO2[	602	]=	0.388972503	;
    RnonCO2[	603	]=	0.388972503	;
    RnonCO2[	604	]=	0.388972503	;
    RnonCO2[	605	]=	0.388972503	;
    RnonCO2[	606	]=	0.388972503	;
    RnonCO2[	607	]=	0.388972503	;
    RnonCO2[	608	]=	0.388972503	;
    RnonCO2[	609	]=	0.388972503	;
    RnonCO2[	610	]=	0.388972503	;
    RnonCO2[	611	]=	0.388972503	;
    RnonCO2[	612	]=	0.388972503	;
    RnonCO2[	613	]=	0.388972503	;
    RnonCO2[	614	]=	0.388972503	;
    RnonCO2[	615	]=	0.388972503	;
    RnonCO2[	616	]=	0.388972503	;
    RnonCO2[	617	]=	0.388972503	;
    RnonCO2[	618	]=	0.388972503	;
    RnonCO2[	619	]=	0.388972503	;
    RnonCO2[	620	]=	0.388972503	;
    RnonCO2[	621	]=	0.388972503	;
    RnonCO2[	622	]=	0.388972503	;
    RnonCO2[	623	]=	0.388972503	;
    RnonCO2[	624	]=	0.388972503	;
    RnonCO2[	625	]=	0.388972503	;
    RnonCO2[	626	]=	0.388972503	;
    RnonCO2[	627	]=	0.388972503	;
    RnonCO2[	628	]=	0.388972503	;
    RnonCO2[	629	]=	0.388972503	;
    RnonCO2[	630	]=	0.388972503	;
    RnonCO2[	631	]=	0.388972503	;
    RnonCO2[	632	]=	0.388972503	;
    RnonCO2[	633	]=	0.388972503	;
    RnonCO2[	634	]=	0.388972503	;
    RnonCO2[	635	]=	0.388972503	;
    RnonCO2[	636	]=	0.388972503	;
    RnonCO2[	637	]=	0.388972503	;
    RnonCO2[	638	]=	0.388972503	;
    RnonCO2[	639	]=	0.388972503	;
    RnonCO2[	640	]=	0.388972503	;
    RnonCO2[	641	]=	0.388972503	;
    RnonCO2[	642	]=	0.388972503	;
    RnonCO2[	643	]=	0.388972503	;
    RnonCO2[	644	]=	0.388972503	;
    RnonCO2[	645	]=	0.388972503	;
    RnonCO2[	646	]=	0.388972503	;
    RnonCO2[	647	]=	0.388972503	;
    RnonCO2[	648	]=	0.388972503	;
    RnonCO2[	649	]=	0.388972503	;
    RnonCO2[	650	]=	0.388972503	;
    RnonCO2[	651	]=	0.388972503	;
    RnonCO2[	652	]=	0.388972503	;
    RnonCO2[	653	]=	0.388972503	;
    RnonCO2[	654	]=	0.388972503	;
    RnonCO2[	655	]=	0.388972503	;
    RnonCO2[	656	]=	0.388972503	;
    RnonCO2[	657	]=	0.388972503	;
    RnonCO2[	658	]=	0.388972503	;
    RnonCO2[	659	]=	0.388972503	;
    RnonCO2[	660	]=	0.388972503	;
    RnonCO2[	661	]=	0.388972503	;
    RnonCO2[	662	]=	0.388972503	;
    RnonCO2[	663	]=	0.388972503	;
    RnonCO2[	664	]=	0.388972503	;
    RnonCO2[	665	]=	0.388972503	;
    RnonCO2[	666	]=	0.388972503	;
    RnonCO2[	667	]=	0.388972503	;
    RnonCO2[	668	]=	0.388972503	;
    RnonCO2[	669	]=	0.388972503	;
    RnonCO2[	670	]=	0.388972503	;
    RnonCO2[	671	]=	0.388972503	;
    RnonCO2[	672	]=	0.388972503	;
    RnonCO2[	673	]=	0.388972503	;
    RnonCO2[	674	]=	0.388972503	;
    RnonCO2[	675	]=	0.388972503	;
    RnonCO2[	676	]=	0.388972503	;
    RnonCO2[	677	]=	0.388972503	;
    RnonCO2[	678	]=	0.388972503	;
    RnonCO2[	679	]=	0.388972503	;
    RnonCO2[	680	]=	0.388972503	;
    RnonCO2[	681	]=	0.388972503	;
    RnonCO2[	682	]=	0.388972503	;
    RnonCO2[	683	]=	0.388972503	;
    RnonCO2[	684	]=	0.388972503	;
    RnonCO2[	685	]=	0.388972503	;
    RnonCO2[	686	]=	0.388972503	;
    RnonCO2[	687	]=	0.388972503	;
    RnonCO2[	688	]=	0.388972503	;
    RnonCO2[	689	]=	0.388972503	;
    RnonCO2[	690	]=	0.388972503	;
    RnonCO2[	691	]=	0.388972503	;
    RnonCO2[	692	]=	0.388972503	;
    RnonCO2[	693	]=	0.388972503	;
    RnonCO2[	694	]=	0.388972503	;
    RnonCO2[	695	]=	0.388972503	;
    RnonCO2[	696	]=	0.388972503	;
    RnonCO2[	697	]=	0.388972503	;
    RnonCO2[	698	]=	0.388972503	;
    RnonCO2[	699	]=	0.388972503	;
    RnonCO2[	700	]=	0.388972503	;
    RnonCO2[	701	]=	0.388972503	;
    RnonCO2[	702	]=	0.388972503	;
    RnonCO2[	703	]=	0.388972503	;
    RnonCO2[	704	]=	0.388972503	;
    RnonCO2[	705	]=	0.388972503	;
    RnonCO2[	706	]=	0.388972503	;
    RnonCO2[	707	]=	0.388972503	;
    RnonCO2[	708	]=	0.388972503	;
    RnonCO2[	709	]=	0.388972503	;
    RnonCO2[	710	]=	0.388972503	;
    RnonCO2[	711	]=	0.388972503	;
    RnonCO2[	712	]=	0.388972503	;
    RnonCO2[	713	]=	0.388972503	;
    RnonCO2[	714	]=	0.388972503	;
    RnonCO2[	715	]=	0.388972503	;
    RnonCO2[	716	]=	0.388972503	;
    RnonCO2[	717	]=	0.388972503	;
    RnonCO2[	718	]=	0.388972503	;
    RnonCO2[	719	]=	0.388972503	;
    RnonCO2[	720	]=	0.388972503	;
    RnonCO2[	721	]=	0.388972503	;
    RnonCO2[	722	]=	0.388972503	;
    RnonCO2[	723	]=	0.388972503	;
    RnonCO2[	724	]=	0.388972503	;
    RnonCO2[	725	]=	0.388972503	;
    RnonCO2[	726	]=	0.388972503	;
    RnonCO2[	727	]=	0.388972503	;
    RnonCO2[	728	]=	0.388972503	;
    RnonCO2[	729	]=	0.388972503	;
    RnonCO2[	730	]=	0.388972503	;
    RnonCO2[	731	]=	0.388972503	;
    RnonCO2[	732	]=	0.388972503	;
    RnonCO2[	733	]=	0.388972503	;
    RnonCO2[	734	]=	0.388972503	;
    RnonCO2[	735	]=	0.388972503	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
    
}

void setRnonCO2_RCP85(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005145555	;
    RnonCO2[	2	]=	0.009090068	;
    RnonCO2[	3	]=	0.007768629	;
    RnonCO2[	4	]=	0.006256789	;
    RnonCO2[	5	]=	0.004769658	;
    RnonCO2[	6	]=	0.002906336	;
    RnonCO2[	7	]=	0.001080178	;
    RnonCO2[	8	]=	-0.000291468	;
    RnonCO2[	9	]=	-0.001612412	;
    RnonCO2[	10	]=	-0.00288359	;
    RnonCO2[	11	]=	-0.00410611	;
    RnonCO2[	12	]=	-0.005282233	;
    RnonCO2[	13	]=	-0.006413549	;
    RnonCO2[	14	]=	-0.007501746	;
    RnonCO2[	15	]=	-0.008551056	;
    RnonCO2[	16	]=	-0.010019335	;
    RnonCO2[	17	]=	-0.011459991	;
    RnonCO2[	18	]=	-0.012417579	;
    RnonCO2[	19	]=	-0.013333977	;
    RnonCO2[	20	]=	-0.014201345	;
    RnonCO2[	21	]=	-0.015012487	;
    RnonCO2[	22	]=	-0.015760238	;
    RnonCO2[	23	]=	-0.016437067	;
    RnonCO2[	24	]=	-0.017035543	;
    RnonCO2[	25	]=	-0.017549544	;
    RnonCO2[	26	]=	-0.018434793	;
    RnonCO2[	27	]=	-0.019238993	;
    RnonCO2[	28	]=	-0.019510794	;
    RnonCO2[	29	]=	-0.019709367	;
    RnonCO2[	30	]=	-0.019838439	;
    RnonCO2[	31	]=	-0.019901316	;
    RnonCO2[	32	]=	-0.020355353	;
    RnonCO2[	33	]=	-0.020749651	;
    RnonCO2[	34	]=	-0.020634193	;
    RnonCO2[	35	]=	-0.02091346	;
    RnonCO2[	36	]=	-0.021125633	;
    RnonCO2[	37	]=	-0.02171132	;
    RnonCO2[	38	]=	-0.021774359	;
    RnonCO2[	39	]=	-0.020873209	;
    RnonCO2[	40	]=	-0.02036553	;
    RnonCO2[	41	]=	-0.020256367	;
    RnonCO2[	42	]=	-0.020105185	;
    RnonCO2[	43	]=	-0.01947287	;
    RnonCO2[	44	]=	-0.018814746	;
    RnonCO2[	45	]=	-0.018134946	;
    RnonCO2[	46	]=	-0.017872094	;
    RnonCO2[	47	]=	-0.017576381	;
    RnonCO2[	48	]=	-0.016804485	;
    RnonCO2[	49	]=	-0.016001407	;
    RnonCO2[	50	]=	-0.015606441	;
    RnonCO2[	51	]=	-0.015619264	;
    RnonCO2[	52	]=	-0.015600061	;
    RnonCO2[	53	]=	-0.015116575	;
    RnonCO2[	54	]=	-0.014172313	;
    RnonCO2[	55	]=	-0.013205379	;
    RnonCO2[	56	]=	-0.012216093	;
    RnonCO2[	57	]=	-0.011635129	;
    RnonCO2[	58	]=	-0.011459514	;
    RnonCO2[	59	]=	-0.010829842	;
    RnonCO2[	60	]=	-0.010175791	;
    RnonCO2[	61	]=	-0.009499636	;
    RnonCO2[	62	]=	-0.00879934	;
    RnonCO2[	63	]=	-0.008077943	;
    RnonCO2[	64	]=	-0.006912545	;
    RnonCO2[	65	]=	-0.008242223	;
    RnonCO2[	66	]=	-0.009135821	;
    RnonCO2[	67	]=	-0.007501052	;
    RnonCO2[	68	]=	-0.006687418	;
    RnonCO2[	69	]=	-0.005858015	;
    RnonCO2[	70	]=	-0.005005979	;
    RnonCO2[	71	]=	-0.005767925	;
    RnonCO2[	72	]=	-0.006086639	;
    RnonCO2[	73	]=	-0.005137938	;
    RnonCO2[	74	]=	-0.004558881	;
    RnonCO2[	75	]=	-0.004336125	;
    RnonCO2[	76	]=	-0.004045198	;
    RnonCO2[	77	]=	-0.003665109	;
    RnonCO2[	78	]=	-0.003220213	;
    RnonCO2[	79	]=	-0.002760518	;
    RnonCO2[	80	]=	-0.003527376	;
    RnonCO2[	81	]=	-0.003576651	;
    RnonCO2[	82	]=	-0.003275283	;
    RnonCO2[	83	]=	-0.003386771	;
    RnonCO2[	84	]=	-0.003510917	;
    RnonCO2[	85	]=	-0.004646356	;
    RnonCO2[	86	]=	-0.003691576	;
    RnonCO2[	87	]=	-0.009505158	;
    RnonCO2[	88	]=	-0.016364432	;
    RnonCO2[	89	]=	-0.017996784	;
    RnonCO2[	90	]=	-0.019670058	;
    RnonCO2[	91	]=	-0.020430126	;
    RnonCO2[	92	]=	-0.021643321	;
    RnonCO2[	93	]=	-0.02142206	;
    RnonCO2[	94	]=	-0.022552345	;
    RnonCO2[	95	]=	-0.031588211	;
    RnonCO2[	96	]=	-0.046252985	;
    RnonCO2[	97	]=	-0.042365448	;
    RnonCO2[	98	]=	-0.033665717	;
    RnonCO2[	99	]=	-0.034555638	;
    RnonCO2[	100	]=	-0.037298509	;
    RnonCO2[	101	]=	-0.046083195	;
    RnonCO2[	102	]=	-0.05558168	;
    RnonCO2[	103	]=	-0.057464266	;
    RnonCO2[	104	]=	-0.053606449	;
    RnonCO2[	105	]=	-0.05168834	;
    RnonCO2[	106	]=	-0.061304945	;
    RnonCO2[	107	]=	-0.086608149	;
    RnonCO2[	108	]=	-0.108195137	;
    RnonCO2[	109	]=	-0.112259625	;
    RnonCO2[	110	]=	-0.111643119	;
    RnonCO2[	111	]=	-0.108991576	;
    RnonCO2[	112	]=	-0.10203489	;
    RnonCO2[	113	]=	-0.098533227	;
    RnonCO2[	114	]=	-0.101949678	;
    RnonCO2[	115	]=	-0.114562053	;
    RnonCO2[	116	]=	-0.123024156	;
    RnonCO2[	117	]=	-0.119809652	;
    RnonCO2[	118	]=	-0.118941351	;
    RnonCO2[	119	]=	-0.120181779	;
    RnonCO2[	120	]=	-0.117316831	;
    RnonCO2[	121	]=	-0.115023243	;
    RnonCO2[	122	]=	-0.116983521	;
    RnonCO2[	123	]=	-0.125997633	;
    RnonCO2[	124	]=	-0.129568227	;
    RnonCO2[	125	]=	-0.131248987	;
    RnonCO2[	126	]=	-0.137316696	;
    RnonCO2[	127	]=	-0.141273792	;
    RnonCO2[	128	]=	-0.144231375	;
    RnonCO2[	129	]=	-0.147973341	;
    RnonCO2[	130	]=	-0.153688224	;
    RnonCO2[	131	]=	-0.15652816	;
    RnonCO2[	132	]=	-0.157109013	;
    RnonCO2[	133	]=	-0.158858513	;
    RnonCO2[	134	]=	-0.162186704	;
    RnonCO2[	135	]=	-0.165318228	;
    RnonCO2[	136	]=	-0.171733193	;
    RnonCO2[	137	]=	-0.178096644	;
    RnonCO2[	138	]=	-0.183870407	;
    RnonCO2[	139	]=	-0.189730028	;
    RnonCO2[	140	]=	-0.194221589	;
    RnonCO2[	141	]=	-0.201576481	;
    RnonCO2[	142	]=	-0.208859035	;
    RnonCO2[	143	]=	-0.207375441	;
    RnonCO2[	144	]=	-0.202571711	;
    RnonCO2[	145	]=	-0.204126848	;
    RnonCO2[	146	]=	-0.201876709	;
    RnonCO2[	147	]=	-0.195147841	;
    RnonCO2[	148	]=	-0.191449584	;
    RnonCO2[	149	]=	-0.183770215	;
    RnonCO2[	150	]=	-0.173476305	;
    RnonCO2[	151	]=	-0.170909799	;
    RnonCO2[	152	]=	-0.171515561	;
    RnonCO2[	153	]=	-0.169079801	;
    RnonCO2[	154	]=	-0.159414516	;
    RnonCO2[	155	]=	-0.155013584	;
    RnonCO2[	156	]=	-0.151089869	;
    RnonCO2[	157	]=	-0.144432651	;
    RnonCO2[	158	]=	-0.152359798	;
    RnonCO2[	159	]=	-0.158148636	;
    RnonCO2[	160	]=	-0.155277608	;
    RnonCO2[	161	]=	-0.152617947	;
    RnonCO2[	162	]=	-0.154120923	;
    RnonCO2[	163	]=	-0.156019482	;
    RnonCO2[	164	]=	-0.155886394	;
    RnonCO2[	165	]=	-0.152021034	;
    RnonCO2[	166	]=	-0.141834688	;
    RnonCO2[	167	]=	-0.13108946	;
    RnonCO2[	168	]=	-0.125408882	;
    RnonCO2[	169	]=	-0.125515632	;
    RnonCO2[	170	]=	-0.125194614	;
    RnonCO2[	171	]=	-0.126120729	;
    RnonCO2[	172	]=	-0.12532345	;
    RnonCO2[	173	]=	-0.115303554	;
    RnonCO2[	174	]=	-0.10787249	;
    RnonCO2[	175	]=	-0.109257271	;
    RnonCO2[	176	]=	-0.113724728	;
    RnonCO2[	177	]=	-0.117421621	;
    RnonCO2[	178	]=	-0.11813163	;
    RnonCO2[	179	]=	-0.119629474	;
    RnonCO2[	180	]=	-0.119789192	;
    RnonCO2[	181	]=	-0.124270593	;
    RnonCO2[	182	]=	-0.135220142	;
    RnonCO2[	183	]=	-0.145282294	;
    RnonCO2[	184	]=	-0.1490379	;
    RnonCO2[	185	]=	-0.154219559	;
    RnonCO2[	186	]=	-0.178760049	;
    RnonCO2[	187	]=	-0.203310188	;
    RnonCO2[	188	]=	-0.212758852	;
    RnonCO2[	189	]=	-0.221219612	;
    RnonCO2[	190	]=	-0.230341307	;
    RnonCO2[	191	]=	-0.239337924	;
    RnonCO2[	192	]=	-0.247524974	;
    RnonCO2[	193	]=	-0.250847198	;
    RnonCO2[	194	]=	-0.245200212	;
    RnonCO2[	195	]=	-0.237476895	;
    RnonCO2[	196	]=	-0.24791739	;
    RnonCO2[	197	]=	-0.261719365	;
    RnonCO2[	198	]=	-0.263179809	;
    RnonCO2[	199	]=	-0.263298027	;
    RnonCO2[	200	]=	-0.261139159	;
    RnonCO2[	201	]=	-0.257781723	;
    RnonCO2[	202	]=	-0.255724839	;
    RnonCO2[	203	]=	-0.25169763	;
    RnonCO2[	204	]=	-0.241647721	;
    RnonCO2[	205	]=	-0.221452127	;
    RnonCO2[	206	]=	-0.196790013	;
    RnonCO2[	207	]=	-0.182093765	;
    RnonCO2[	208	]=	-0.174745229	;
    RnonCO2[	209	]=	-0.16714548	;
    RnonCO2[	210	]=	-0.159384584	;
    RnonCO2[	211	]=	-0.156373877	;
    RnonCO2[	212	]=	-0.153042015	;
    RnonCO2[	213	]=	-0.139817455	;
    RnonCO2[	214	]=	-0.125210902	;
    RnonCO2[	215	]=	-0.119848303	;
    RnonCO2[	216	]=	-0.119430668	;
    RnonCO2[	217	]=	-0.123211365	;
    RnonCO2[	218	]=	-0.125809708	;
    RnonCO2[	219	]=	-0.120193155	;
    RnonCO2[	220	]=	-0.110911249	;
    RnonCO2[	221	]=	-0.102402229	;
    RnonCO2[	222	]=	-0.096562536	;
    RnonCO2[	223	]=	-0.086930587	;
    RnonCO2[	224	]=	-0.072710932	;
    RnonCO2[	225	]=	-0.05997191	;
    RnonCO2[	226	]=	-0.058006544	;
    RnonCO2[	227	]=	-0.065604043	;
    RnonCO2[	228	]=	-0.067949961	;
    RnonCO2[	229	]=	-0.065994527	;
    RnonCO2[	230	]=	-0.058283284	;
    RnonCO2[	231	]=	-0.04756956	;
    RnonCO2[	232	]=	-0.049208339	;
    RnonCO2[	233	]=	-0.056699684	;
    RnonCO2[	234	]=	-0.059531967	;
    RnonCO2[	235	]=	-0.065638041	;
    RnonCO2[	236	]=	-0.069976074	;
    RnonCO2[	237	]=	-0.065660736	;
    RnonCO2[	238	]=	-0.060876733	;
    RnonCO2[	239	]=	-0.057486962	;
    RnonCO2[	240	]=	-0.051265033	;
    RnonCO2[	241	]=	-0.037670076	;
    RnonCO2[	242	]=	-0.019893764	;
    RnonCO2[	243	]=	-0.000823001	;
    RnonCO2[	244	]=	0.019502902	;
    RnonCO2[	245	]=	0.037441814	;
    RnonCO2[	246	]=	0.049417144	;
    RnonCO2[	247	]=	0.059768113	;
    RnonCO2[	248	]=	0.071444345	;
    RnonCO2[	249	]=	0.083442351	;
    RnonCO2[	250	]=	0.096022256	;
    RnonCO2[	251	]=	0.10916019	;
    RnonCO2[	252	]=	0.122811854	;
    RnonCO2[	253	]=	0.13693036	;
    RnonCO2[	254	]=	0.15204114	;
    RnonCO2[	255	]=	0.168591967	;
    RnonCO2[	256	]=	0.186766657	;
    RnonCO2[	257	]=	0.205173036	;
    RnonCO2[	258	]=	0.222866088	;
    RnonCO2[	259	]=	0.240576956	;
    RnonCO2[	260	]=	0.258326044	;
    RnonCO2[	261	]=	0.276116517	;
    RnonCO2[	262	]=	0.29394187	;
    RnonCO2[	263	]=	0.311780272	;
    RnonCO2[	264	]=	0.329615086	;
    RnonCO2[	265	]=	0.348986214	;
    RnonCO2[	266	]=	0.37142882	;
    RnonCO2[	267	]=	0.394872321	;
    RnonCO2[	268	]=	0.417926425	;
    RnonCO2[	269	]=	0.441218554	;
    RnonCO2[	270	]=	0.464702083	;
    RnonCO2[	271	]=	0.488333479	;
    RnonCO2[	272	]=	0.512075403	;
    RnonCO2[	273	]=	0.535880676	;
    RnonCO2[	274	]=	0.559692195	;
    RnonCO2[	275	]=	0.583094257	;
    RnonCO2[	276	]=	0.60567867	;
    RnonCO2[	277	]=	0.627987231	;
    RnonCO2[	278	]=	0.650367412	;
    RnonCO2[	279	]=	0.672650114	;
    RnonCO2[	280	]=	0.69490502	;
    RnonCO2[	281	]=	0.717184654	;
    RnonCO2[	282	]=	0.739526114	;
    RnonCO2[	283	]=	0.761955068	;
    RnonCO2[	284	]=	0.784475878	;
    RnonCO2[	285	]=	0.805983293	;
    RnonCO2[	286	]=	0.825382732	;
    RnonCO2[	287	]=	0.843811364	;
    RnonCO2[	288	]=	0.862164274	;
    RnonCO2[	289	]=	0.88017297	;
    RnonCO2[	290	]=	0.897837466	;
    RnonCO2[	291	]=	0.915228374	;
    RnonCO2[	292	]=	0.932404856	;
    RnonCO2[	293	]=	0.949417839	;
    RnonCO2[	294	]=	0.966318914	;
    RnonCO2[	295	]=	0.982819486	;
    RnonCO2[	296	]=	0.998609085	;
    RnonCO2[	297	]=	1.013870109	;
    RnonCO2[	298	]=	1.028718413	;
    RnonCO2[	299	]=	1.043105084	;
    RnonCO2[	300	]=	1.057012563	;
    RnonCO2[	301	]=	1.070443452	;
    RnonCO2[	302	]=	1.083474934	;
    RnonCO2[	303	]=	1.096173716	;
    RnonCO2[	304	]=	1.108598174	;
    RnonCO2[	305	]=	1.12060237	;
    RnonCO2[	306	]=	1.132009413	;
    RnonCO2[	307	]=	1.143129004	;
    RnonCO2[	308	]=	1.154205373	;
    RnonCO2[	309	]=	1.165181375	;
    RnonCO2[	310	]=	1.176063128	;
    RnonCO2[	311	]=	1.186799276	;
    RnonCO2[	312	]=	1.197361335	;
    RnonCO2[	313	]=	1.20780055	;
    RnonCO2[	314	]=	1.218161605	;
    RnonCO2[	315	]=	1.229404767	;
    RnonCO2[	316	]=	1.242484643	;
    RnonCO2[	317	]=	1.256439183	;
    RnonCO2[	318	]=	1.270393379	;
    RnonCO2[	319	]=	1.284434844	;
    RnonCO2[	320	]=	1.298554619	;
    RnonCO2[	321	]=	1.312745936	;
    RnonCO2[	322	]=	1.326943443	;
    RnonCO2[	323	]=	1.341105165	;
    RnonCO2[	324	]=	1.35527369	;
    RnonCO2[	325	]=	1.368587592	;
    RnonCO2[	326	]=	1.3801878	;
    RnonCO2[	327	]=	1.390971947	;
    RnonCO2[	328	]=	1.401644792	;
    RnonCO2[	329	]=	1.41204733	;
    RnonCO2[	330	]=	1.422189875	;
    RnonCO2[	331	]=	1.432089402	;
    RnonCO2[	332	]=	1.441762212	;
    RnonCO2[	333	]=	1.451165105	;
    RnonCO2[	334	]=	1.460274813	;
    RnonCO2[	335	]=	1.468374652	;
    RnonCO2[	336	]=	1.474746424	;
    RnonCO2[	337	]=	1.480301476	;
    RnonCO2[	338	]=	1.485731533	;
    RnonCO2[	339	]=	1.490849211	;
    RnonCO2[	340	]=	1.495659068	;
    RnonCO2[	341	]=	1.500169653	;
    RnonCO2[	342	]=	1.504397544	;
    RnonCO2[	343	]=	1.508359214	;
    RnonCO2[	344	]=	1.512009834	;
    RnonCO2[	345	]=	1.51532465	;
    RnonCO2[	346	]=	1.518367002	;
    RnonCO2[	347	]=	1.521195686	;
    RnonCO2[	348	]=	1.523860963	;
    RnonCO2[	349	]=	1.52641356	;
    RnonCO2[	350	]=	1.528871707	;
    RnonCO2[	351	]=	1.531222737	;
    RnonCO2[	352	]=	1.533460345	;
    RnonCO2[	353	]=	1.535587165	;
    RnonCO2[	354	]=	1.537605959	;
    RnonCO2[	355	]=	1.539459965	;
    RnonCO2[	356	]=	1.541113783	;
    RnonCO2[	357	]=	1.542618783	;
    RnonCO2[	358	]=	1.544025951	;
    RnonCO2[	359	]=	1.545378349	;
    RnonCO2[	360	]=	1.546718751	;
    RnonCO2[	361	]=	1.548055941	;
    RnonCO2[	362	]=	1.549369713	;
    RnonCO2[	363	]=	1.550646585	;
    RnonCO2[	364	]=	1.551882676	;
    RnonCO2[	365	]=	1.553075063	;
    RnonCO2[	366	]=	1.554161867	;
    RnonCO2[	367	]=	1.555101796	;
    RnonCO2[	368	]=	1.555942834	;
    RnonCO2[	369	]=	1.556732334	;
    RnonCO2[	370	]=	1.557509895	;
    RnonCO2[	371	]=	1.558316771	;
    RnonCO2[	372	]=	1.559159287	;
    RnonCO2[	373	]=	1.560016734	;
    RnonCO2[	374	]=	1.560870324	;
    RnonCO2[	375	]=	1.561714212	;
    RnonCO2[	376	]=	1.562542262	;
    RnonCO2[	377	]=	1.563290939	;
    RnonCO2[	378	]=	1.563916226	;
    RnonCO2[	379	]=	1.564463579	;
    RnonCO2[	380	]=	1.564979531	;
    RnonCO2[	381	]=	1.565503311	;
    RnonCO2[	382	]=	1.566075173	;
    RnonCO2[	383	]=	1.566700798	;
    RnonCO2[	384	]=	1.567356549	;
    RnonCO2[	385	]=	1.568023908	;
    RnonCO2[	386	]=	1.568693378	;
    RnonCO2[	387	]=	1.569361956	;
    RnonCO2[	388	]=	1.569966223	;
    RnonCO2[	389	]=	1.570460069	;
    RnonCO2[	390	]=	1.570886164	;
    RnonCO2[	391	]=	1.57129172	;
    RnonCO2[	392	]=	1.571714342	;
    RnonCO2[	393	]=	1.572194218	;
    RnonCO2[	394	]=	1.572736425	;
    RnonCO2[	395	]=	1.573316462	;
    RnonCO2[	396	]=	1.573913961	;
    RnonCO2[	397	]=	1.574518489	;
    RnonCO2[	398	]=	1.575122951	;
    RnonCO2[	399	]=	1.575661885	;
    RnonCO2[	400	]=	1.576087712	;
    RnonCO2[	401	]=	1.576445094	;
    RnonCO2[	402	]=	1.576780719	;
    RnonCO2[	403	]=	1.577133646	;
    RnonCO2[	404	]=	1.577543971	;
    RnonCO2[	405	]=	1.57801753	;
    RnonCO2[	406	]=	1.578529885	;
    RnonCO2[	407	]=	1.57905987	;
    RnonCO2[	408	]=	1.579596243	;
    RnonCO2[	409	]=	1.5801324	;
    RnonCO2[	410	]=	1.580602658	;
    RnonCO2[	411	]=	1.580959115	;
    RnonCO2[	412	]=	1.581246127	;
    RnonCO2[	413	]=	1.581511182	;
    RnonCO2[	414	]=	1.581793935	;
    RnonCO2[	415	]=	1.582134962	;
    RnonCO2[	416	]=	1.582539659	;
    RnonCO2[	417	]=	1.582982927	;
    RnonCO2[	418	]=	1.58344402	;
    RnonCO2[	419	]=	1.583911568	;
    RnonCO2[	420	]=	1.584378025	;
    RnonCO2[	421	]=	1.584777859	;
    RnonCO2[	422	]=	1.585063744	;
    RnonCO2[	423	]=	1.585280055	;
    RnonCO2[	424	]=	1.585474046	;
    RnonCO2[	425	]=	1.585685963	;
    RnonCO2[	426	]=	1.585956484	;
    RnonCO2[	427	]=	1.586291104	;
    RnonCO2[	428	]=	1.58666443	;
    RnonCO2[	429	]=	1.587054917	;
    RnonCO2[	430	]=	1.587451207	;
    RnonCO2[	431	]=	1.587845901	;
    RnonCO2[	432	]=	1.588173799	;
    RnonCO2[	433	]=	1.588387781	;
    RnonCO2[	434	]=	1.588531449	;
    RnonCO2[	435	]=	1.588653082	;
    RnonCO2[	436	]=	1.588792336	;
    RnonCO2[	437	]=	1.58898945	;
    RnonCO2[	438	]=	1.589250031	;
    RnonCO2[	439	]=	1.589548396	;
    RnonCO2[	440	]=	1.589863	;
    RnonCO2[	441	]=	1.590182435	;
    RnonCO2[	442	]=	1.59049929	;
    RnonCO2[	443	]=	1.590748191	;
    RnonCO2[	444	]=	1.590882222	;
    RnonCO2[	445	]=	1.59094589	;
    RnonCO2[	446	]=	1.590987615	;
    RnonCO2[	447	]=	1.591046945	;
    RnonCO2[	448	]=	1.591164675	;
    RnonCO2[	449	]=	1.591345419	;
    RnonCO2[	450	]=	1.591563876	;
    RnonCO2[	451	]=	1.591798229	;
    RnonCO2[	452	]=	1.592037046	;
    RnonCO2[	453	]=	1.592273621	;
    RnonCO2[	454	]=	1.59244202	;
    RnonCO2[	455	]=	1.59249612	;
    RnonCO2[	456	]=	1.5924806	;
    RnonCO2[	457	]=	1.592443478	;
    RnonCO2[	458	]=	1.592425075	;
    RnonCO2[	459	]=	1.592465084	;
    RnonCO2[	460	]=	1.592568139	;
    RnonCO2[	461	]=	1.592708986	;
    RnonCO2[	462	]=	1.592865552	;
    RnonCO2[	463	]=	1.593026493	;
    RnonCO2[	464	]=	1.593185171	;
    RnonCO2[	465	]=	1.593275772	;
    RnonCO2[	466	]=	1.593252631	;
    RnonCO2[	467	]=	1.593160152	;
    RnonCO2[	468	]=	1.593046813	;
    RnonCO2[	469	]=	1.592952255	;
    RnonCO2[	470	]=	1.59291659	;
    RnonCO2[	471	]=	1.592944036	;
    RnonCO2[	472	]=	1.593009538	;
    RnonCO2[	473	]=	1.593090652	;
    RnonCO2[	474	]=	1.593176179	;
    RnonCO2[	475	]=	1.593259269	;
    RnonCO2[	476	]=	1.593274915	;
    RnonCO2[	477	]=	1.593177524	;
    RnonCO2[	478	]=	1.593011652	;
    RnonCO2[	479	]=	1.592825679	;
    RnonCO2[	480	]=	1.592659324	;
    RnonCO2[	481	]=	1.592551739	;
    RnonCO2[	482	]=	1.592508042	;
    RnonCO2[	483	]=	1.592502118	;
    RnonCO2[	484	]=	1.592512302	;
    RnonCO2[	485	]=	1.592519077	;
    RnonCO2[	486	]=	1.592519077	;
    RnonCO2[	487	]=	1.592519077	;
    RnonCO2[	488	]=	1.592519077	;
    RnonCO2[	489	]=	1.592519077	;
    RnonCO2[	490	]=	1.592519077	;
    RnonCO2[	491	]=	1.592519077	;
    RnonCO2[	492	]=	1.592519077	;
    RnonCO2[	493	]=	1.592519077	;
    RnonCO2[	494	]=	1.592519077	;
    RnonCO2[	495	]=	1.592519077	;
    RnonCO2[	496	]=	1.592519077	;
    RnonCO2[	497	]=	1.592519077	;
    RnonCO2[	498	]=	1.592519077	;
    RnonCO2[	499	]=	1.592519077	;
    RnonCO2[	500	]=	1.592519077	;
    RnonCO2[	501	]=	1.592519077	;
    RnonCO2[	502	]=	1.592519077	;
    RnonCO2[	503	]=	1.592519077	;
    RnonCO2[	504	]=	1.592519077	;
    RnonCO2[	505	]=	1.592519077	;
    RnonCO2[	506	]=	1.592519077	;
    RnonCO2[	507	]=	1.592519077	;
    RnonCO2[	508	]=	1.592519077	;
    RnonCO2[	509	]=	1.592519077	;
    RnonCO2[	510	]=	1.592519077	;
    RnonCO2[	511	]=	1.592519077	;
    RnonCO2[	512	]=	1.592519077	;
    RnonCO2[	513	]=	1.592519077	;
    RnonCO2[	514	]=	1.592519077	;
    RnonCO2[	515	]=	1.592519077	;
    RnonCO2[	516	]=	1.592519077	;
    RnonCO2[	517	]=	1.592519077	;
    RnonCO2[	518	]=	1.592519077	;
    RnonCO2[	519	]=	1.592519077	;
    RnonCO2[	520	]=	1.592519077	;
    RnonCO2[	521	]=	1.592519077	;
    RnonCO2[	522	]=	1.592519077	;
    RnonCO2[	523	]=	1.592519077	;
    RnonCO2[	524	]=	1.592519077	;
    RnonCO2[	525	]=	1.592519077	;
    RnonCO2[	526	]=	1.592519077	;
    RnonCO2[	527	]=	1.592519077	;
    RnonCO2[	528	]=	1.592519077	;
    RnonCO2[	529	]=	1.592519077	;
    RnonCO2[	530	]=	1.592519077	;
    RnonCO2[	531	]=	1.592519077	;
    RnonCO2[	532	]=	1.592519077	;
    RnonCO2[	533	]=	1.592519077	;
    RnonCO2[	534	]=	1.592519077	;
    RnonCO2[	535	]=	1.592519077	;
    RnonCO2[	536	]=	1.592519077	;
    RnonCO2[	537	]=	1.592519077	;
    RnonCO2[	538	]=	1.592519077	;
    RnonCO2[	539	]=	1.592519077	;
    RnonCO2[	540	]=	1.592519077	;
    RnonCO2[	541	]=	1.592519077	;
    RnonCO2[	542	]=	1.592519077	;
    RnonCO2[	543	]=	1.592519077	;
    RnonCO2[	544	]=	1.592519077	;
    RnonCO2[	545	]=	1.592519077	;
    RnonCO2[	546	]=	1.592519077	;
    RnonCO2[	547	]=	1.592519077	;
    RnonCO2[	548	]=	1.592519077	;
    RnonCO2[	549	]=	1.592519077	;
    RnonCO2[	550	]=	1.592519077	;
    RnonCO2[	551	]=	1.592519077	;
    RnonCO2[	552	]=	1.592519077	;
    RnonCO2[	553	]=	1.592519077	;
    RnonCO2[	554	]=	1.592519077	;
    RnonCO2[	555	]=	1.592519077	;
    RnonCO2[	556	]=	1.592519077	;
    RnonCO2[	557	]=	1.592519077	;
    RnonCO2[	558	]=	1.592519077	;
    RnonCO2[	559	]=	1.592519077	;
    RnonCO2[	560	]=	1.592519077	;
    RnonCO2[	561	]=	1.592519077	;
    RnonCO2[	562	]=	1.592519077	;
    RnonCO2[	563	]=	1.592519077	;
    RnonCO2[	564	]=	1.592519077	;
    RnonCO2[	565	]=	1.592519077	;
    RnonCO2[	566	]=	1.592519077	;
    RnonCO2[	567	]=	1.592519077	;
    RnonCO2[	568	]=	1.592519077	;
    RnonCO2[	569	]=	1.592519077	;
    RnonCO2[	570	]=	1.592519077	;
    RnonCO2[	571	]=	1.592519077	;
    RnonCO2[	572	]=	1.592519077	;
    RnonCO2[	573	]=	1.592519077	;
    RnonCO2[	574	]=	1.592519077	;
    RnonCO2[	575	]=	1.592519077	;
    RnonCO2[	576	]=	1.592519077	;
    RnonCO2[	577	]=	1.592519077	;
    RnonCO2[	578	]=	1.592519077	;
    RnonCO2[	579	]=	1.592519077	;
    RnonCO2[	580	]=	1.592519077	;
    RnonCO2[	581	]=	1.592519077	;
    RnonCO2[	582	]=	1.592519077	;
    RnonCO2[	583	]=	1.592519077	;
    RnonCO2[	584	]=	1.592519077	;
    RnonCO2[	585	]=	1.592519077	;
    RnonCO2[	586	]=	1.592519077	;
    RnonCO2[	587	]=	1.592519077	;
    RnonCO2[	588	]=	1.592519077	;
    RnonCO2[	589	]=	1.592519077	;
    RnonCO2[	590	]=	1.592519077	;
    RnonCO2[	591	]=	1.592519077	;
    RnonCO2[	592	]=	1.592519077	;
    RnonCO2[	593	]=	1.592519077	;
    RnonCO2[	594	]=	1.592519077	;
    RnonCO2[	595	]=	1.592519077	;
    RnonCO2[	596	]=	1.592519077	;
    RnonCO2[	597	]=	1.592519077	;
    RnonCO2[	598	]=	1.592519077	;
    RnonCO2[	599	]=	1.592519077	;
    RnonCO2[	600	]=	1.592519077	;
    RnonCO2[	601	]=	1.592519077	;
    RnonCO2[	602	]=	1.592519077	;
    RnonCO2[	603	]=	1.592519077	;
    RnonCO2[	604	]=	1.592519077	;
    RnonCO2[	605	]=	1.592519077	;
    RnonCO2[	606	]=	1.592519077	;
    RnonCO2[	607	]=	1.592519077	;
    RnonCO2[	608	]=	1.592519077	;
    RnonCO2[	609	]=	1.592519077	;
    RnonCO2[	610	]=	1.592519077	;
    RnonCO2[	611	]=	1.592519077	;
    RnonCO2[	612	]=	1.592519077	;
    RnonCO2[	613	]=	1.592519077	;
    RnonCO2[	614	]=	1.592519077	;
    RnonCO2[	615	]=	1.592519077	;
    RnonCO2[	616	]=	1.592519077	;
    RnonCO2[	617	]=	1.592519077	;
    RnonCO2[	618	]=	1.592519077	;
    RnonCO2[	619	]=	1.592519077	;
    RnonCO2[	620	]=	1.592519077	;
    RnonCO2[	621	]=	1.592519077	;
    RnonCO2[	622	]=	1.592519077	;
    RnonCO2[	623	]=	1.592519077	;
    RnonCO2[	624	]=	1.592519077	;
    RnonCO2[	625	]=	1.592519077	;
    RnonCO2[	626	]=	1.592519077	;
    RnonCO2[	627	]=	1.592519077	;
    RnonCO2[	628	]=	1.592519077	;
    RnonCO2[	629	]=	1.592519077	;
    RnonCO2[	630	]=	1.592519077	;
    RnonCO2[	631	]=	1.592519077	;
    RnonCO2[	632	]=	1.592519077	;
    RnonCO2[	633	]=	1.592519077	;
    RnonCO2[	634	]=	1.592519077	;
    RnonCO2[	635	]=	1.592519077	;
    RnonCO2[	636	]=	1.592519077	;
    RnonCO2[	637	]=	1.592519077	;
    RnonCO2[	638	]=	1.592519077	;
    RnonCO2[	639	]=	1.592519077	;
    RnonCO2[	640	]=	1.592519077	;
    RnonCO2[	641	]=	1.592519077	;
    RnonCO2[	642	]=	1.592519077	;
    RnonCO2[	643	]=	1.592519077	;
    RnonCO2[	644	]=	1.592519077	;
    RnonCO2[	645	]=	1.592519077	;
    RnonCO2[	646	]=	1.592519077	;
    RnonCO2[	647	]=	1.592519077	;
    RnonCO2[	648	]=	1.592519077	;
    RnonCO2[	649	]=	1.592519077	;
    RnonCO2[	650	]=	1.592519077	;
    RnonCO2[	651	]=	1.592519077	;
    RnonCO2[	652	]=	1.592519077	;
    RnonCO2[	653	]=	1.592519077	;
    RnonCO2[	654	]=	1.592519077	;
    RnonCO2[	655	]=	1.592519077	;
    RnonCO2[	656	]=	1.592519077	;
    RnonCO2[	657	]=	1.592519077	;
    RnonCO2[	658	]=	1.592519077	;
    RnonCO2[	659	]=	1.592519077	;
    RnonCO2[	660	]=	1.592519077	;
    RnonCO2[	661	]=	1.592519077	;
    RnonCO2[	662	]=	1.592519077	;
    RnonCO2[	663	]=	1.592519077	;
    RnonCO2[	664	]=	1.592519077	;
    RnonCO2[	665	]=	1.592519077	;
    RnonCO2[	666	]=	1.592519077	;
    RnonCO2[	667	]=	1.592519077	;
    RnonCO2[	668	]=	1.592519077	;
    RnonCO2[	669	]=	1.592519077	;
    RnonCO2[	670	]=	1.592519077	;
    RnonCO2[	671	]=	1.592519077	;
    RnonCO2[	672	]=	1.592519077	;
    RnonCO2[	673	]=	1.592519077	;
    RnonCO2[	674	]=	1.592519077	;
    RnonCO2[	675	]=	1.592519077	;
    RnonCO2[	676	]=	1.592519077	;
    RnonCO2[	677	]=	1.592519077	;
    RnonCO2[	678	]=	1.592519077	;
    RnonCO2[	679	]=	1.592519077	;
    RnonCO2[	680	]=	1.592519077	;
    RnonCO2[	681	]=	1.592519077	;
    RnonCO2[	682	]=	1.592519077	;
    RnonCO2[	683	]=	1.592519077	;
    RnonCO2[	684	]=	1.592519077	;
    RnonCO2[	685	]=	1.592519077	;
    RnonCO2[	686	]=	1.592519077	;
    RnonCO2[	687	]=	1.592519077	;
    RnonCO2[	688	]=	1.592519077	;
    RnonCO2[	689	]=	1.592519077	;
    RnonCO2[	690	]=	1.592519077	;
    RnonCO2[	691	]=	1.592519077	;
    RnonCO2[	692	]=	1.592519077	;
    RnonCO2[	693	]=	1.592519077	;
    RnonCO2[	694	]=	1.592519077	;
    RnonCO2[	695	]=	1.592519077	;
    RnonCO2[	696	]=	1.592519077	;
    RnonCO2[	697	]=	1.592519077	;
    RnonCO2[	698	]=	1.592519077	;
    RnonCO2[	699	]=	1.592519077	;
    RnonCO2[	700	]=	1.592519077	;
    RnonCO2[	701	]=	1.592519077	;
    RnonCO2[	702	]=	1.592519077	;
    RnonCO2[	703	]=	1.592519077	;
    RnonCO2[	704	]=	1.592519077	;
    RnonCO2[	705	]=	1.592519077	;
    RnonCO2[	706	]=	1.592519077	;
    RnonCO2[	707	]=	1.592519077	;
    RnonCO2[	708	]=	1.592519077	;
    RnonCO2[	709	]=	1.592519077	;
    RnonCO2[	710	]=	1.592519077	;
    RnonCO2[	711	]=	1.592519077	;
    RnonCO2[	712	]=	1.592519077	;
    RnonCO2[	713	]=	1.592519077	;
    RnonCO2[	714	]=	1.592519077	;
    RnonCO2[	715	]=	1.592519077	;
    RnonCO2[	716	]=	1.592519077	;
    RnonCO2[	717	]=	1.592519077	;
    RnonCO2[	718	]=	1.592519077	;
    RnonCO2[	719	]=	1.592519077	;
    RnonCO2[	720	]=	1.592519077	;
    RnonCO2[	721	]=	1.592519077	;
    RnonCO2[	722	]=	1.592519077	;
    RnonCO2[	723	]=	1.592519077	;
    RnonCO2[	724	]=	1.592519077	;
    RnonCO2[	725	]=	1.592519077	;
    RnonCO2[	726	]=	1.592519077	;
    RnonCO2[	727	]=	1.592519077	;
    RnonCO2[	728	]=	1.592519077	;
    RnonCO2[	729	]=	1.592519077	;
    RnonCO2[	730	]=	1.592519077	;
    RnonCO2[	731	]=	1.592519077	;
    RnonCO2[	732	]=	1.592519077	;
    RnonCO2[	733	]=	1.592519077	;
    RnonCO2[	734	]=	1.592519077	;
    RnonCO2[	735	]=	1.592519077	;
    
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
    
}

void setRnonCO2_RCP3PD_K(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005612142	;
    RnonCO2[	2	]=	0.008971239	;
    RnonCO2[	3	]=	0.009466172	;
    RnonCO2[	4	]=	0.009946833	;
    RnonCO2[	5	]=	0.010412166	;
    RnonCO2[	6	]=	0.010865438	;
    RnonCO2[	7	]=	0.011309666	;
    RnonCO2[	8	]=	0.011745593	;
    RnonCO2[	9	]=	0.012173039	;
    RnonCO2[	10	]=	0.012591208	;
    RnonCO2[	11	]=	0.012999626	;
    RnonCO2[	12	]=	0.013397144	;
    RnonCO2[	13	]=	0.013783559	;
    RnonCO2[	14	]=	0.014157995	;
    RnonCO2[	15	]=	0.014518817	;
    RnonCO2[	16	]=	0.014861789	;
    RnonCO2[	17	]=	0.015185328	;
    RnonCO2[	18	]=	0.015493438	;
    RnonCO2[	19	]=	0.015792171	;
    RnonCO2[	20	]=	0.01608699	;
    RnonCO2[	21	]=	0.016384013	;
    RnonCO2[	22	]=	0.016688621	;
    RnonCO2[	23	]=	0.017006739	;
    RnonCO2[	24	]=	0.017344141	;
    RnonCO2[	25	]=	0.017705767	;
    RnonCO2[	26	]=	0.018092359	;
    RnonCO2[	27	]=	0.018501885	;
    RnonCO2[	28	]=	0.01893258	;
    RnonCO2[	29	]=	0.019382558	;
    RnonCO2[	30	]=	0.019850303	;
    RnonCO2[	31	]=	0.020334085	;
    RnonCO2[	32	]=	0.020831989	;
    RnonCO2[	33	]=	0.021342706	;
    RnonCO2[	34	]=	0.02186457	;
    RnonCO2[	35	]=	0.022398729	;
    RnonCO2[	36	]=	0.022952686	;
    RnonCO2[	37	]=	0.023532049	;
    RnonCO2[	38	]=	0.024135881	;
    RnonCO2[	39	]=	0.024759327	;
    RnonCO2[	40	]=	0.025397837	;
    RnonCO2[	41	]=	0.02604713	;
    RnonCO2[	42	]=	0.026702498	;
    RnonCO2[	43	]=	0.02735936	;
    RnonCO2[	44	]=	0.028013477	;
    RnonCO2[	45	]=	0.028662413	;
    RnonCO2[	46	]=	0.029309198	;
    RnonCO2[	47	]=	0.029958961	;
    RnonCO2[	48	]=	0.030612845	;
    RnonCO2[	49	]=	0.031270152	;
    RnonCO2[	50	]=	0.03193112	;
    RnonCO2[	51	]=	0.032594644	;
    RnonCO2[	52	]=	0.033260857	;
    RnonCO2[	53	]=	0.033928967	;
    RnonCO2[	54	]=	0.034598246	;
    RnonCO2[	55	]=	0.035268641	;
    RnonCO2[	56	]=	0.035940357	;
    RnonCO2[	57	]=	0.036613717	;
    RnonCO2[	58	]=	0.037289228	;
    RnonCO2[	59	]=	0.037967253	;
    RnonCO2[	60	]=	0.038647628	;
    RnonCO2[	61	]=	0.039330893	;
    RnonCO2[	62	]=	0.040017299	;
    RnonCO2[	63	]=	0.040707068	;
    RnonCO2[	64	]=	0.041400385	;
    RnonCO2[	65	]=	0.042096128	;
    RnonCO2[	66	]=	0.042791515	;
    RnonCO2[	67	]=	0.04348473	;
    RnonCO2[	68	]=	0.044177707	;
    RnonCO2[	69	]=	0.044873365	;
    RnonCO2[	70	]=	0.045574528	;
    RnonCO2[	71	]=	0.04628438	;
    RnonCO2[	72	]=	0.047005924	;
    RnonCO2[	73	]=	0.047742202	;
    RnonCO2[	74	]=	0.048496247	;
    RnonCO2[	75	]=	0.049273302	;
    RnonCO2[	76	]=	0.050090919	;
    RnonCO2[	77	]=	0.050966437	;
    RnonCO2[	78	]=	0.051881638	;
    RnonCO2[	79	]=	0.052787675	;
    RnonCO2[	80	]=	0.053629807	;
    RnonCO2[	81	]=	0.054384454	;
    RnonCO2[	82	]=	0.055079735	;
    RnonCO2[	83	]=	0.055748092	;
    RnonCO2[	84	]=	0.056393965	;
    RnonCO2[	85	]=	0.057093398	;
    RnonCO2[	86	]=	0.05807606	;
    RnonCO2[	87	]=	0.059274862	;
    RnonCO2[	88	]=	0.060472717	;
    RnonCO2[	89	]=	0.061669627	;
    RnonCO2[	90	]=	0.062723294	;
    RnonCO2[	91	]=	0.063776572	;
    RnonCO2[	92	]=	0.064970976	;
    RnonCO2[	93	]=	0.066164765	;
    RnonCO2[	94	]=	0.067357381	;
    RnonCO2[	95	]=	0.06854924	;
    RnonCO2[	96	]=	0.069740139	;
    RnonCO2[	97	]=	0.070930146	;
    RnonCO2[	98	]=	0.072119404	;
    RnonCO2[	99	]=	0.073307822	;
    RnonCO2[	100	]=	0.074635976	;
    RnonCO2[	101	]=	0.075963149	;
    RnonCO2[	102	]=	0.077148556	;
    RnonCO2[	103	]=	0.078333267	;
    RnonCO2[	104	]=	0.079516971	;
    RnonCO2[	105	]=	0.080754531	;
    RnonCO2[	106	]=	0.081905797	;
    RnonCO2[	107	]=	0.083001419	;
    RnonCO2[	108	]=	0.084181461	;
    RnonCO2[	109	]=	0.085360786	;
    RnonCO2[	110	]=	0.086593261	;
    RnonCO2[	111	]=	0.087739428	;
    RnonCO2[	112	]=	0.088830817	;
    RnonCO2[	113	]=	0.090006409	;
    RnonCO2[	114	]=	0.091181226	;
    RnonCO2[	115	]=	0.092494155	;
    RnonCO2[	116	]=	0.093944335	;
    RnonCO2[	117	]=	0.095393111	;
    RnonCO2[	118	]=	0.096840323	;
    RnonCO2[	119	]=	0.098148223	;
    RnonCO2[	120	]=	0.09931678	;
    RnonCO2[	121	]=	0.100622634	;
    RnonCO2[	122	]=	0.101979664	;
    RnonCO2[	123	]=	0.10325049	;
    RnonCO2[	124	]=	0.104604961	;
    RnonCO2[	125	]=	0.106043011	;
    RnonCO2[	126	]=	0.107616808	;
    RnonCO2[	127	]=	0.109325606	;
    RnonCO2[	128	]=	0.110810739	;
    RnonCO2[	129	]=	0.112072699	;
    RnonCO2[	130	]=	0.113469426	;
    RnonCO2[	131	]=	0.115000677	;
    RnonCO2[	132	]=	0.116479164	;
    RnonCO2[	133	]=	0.117955956	;
    RnonCO2[	134	]=	0.119481632	;
    RnonCO2[	135	]=	0.121230683	;
    RnonCO2[	136	]=	0.123467298	;
    RnonCO2[	137	]=	0.125964505	;
    RnonCO2[	138	]=	0.128590857	;
    RnonCO2[	139	]=	0.131345679	;
    RnonCO2[	140	]=	0.134094266	;
    RnonCO2[	141	]=	0.136836274	;
    RnonCO2[	142	]=	0.139657159	;
    RnonCO2[	143	]=	0.142689092	;
    RnonCO2[	144	]=	0.145846541	;
    RnonCO2[	145	]=	0.148864539	;
    RnonCO2[	146	]=	0.151744205	;
    RnonCO2[	147	]=	0.154833698	;
    RnonCO2[	148	]=	0.158178102	;
    RnonCO2[	149	]=	0.161560167	;
    RnonCO2[	150	]=	0.165018225	;
    RnonCO2[	151	]=	0.168552404	;
    RnonCO2[	152	]=	0.172162279	;
    RnonCO2[	153	]=	0.175976823	;
    RnonCO2[	154	]=	0.179825831	;
    RnonCO2[	155	]=	0.18353714	;
    RnonCO2[	156	]=	0.18719586	;
    RnonCO2[	157	]=	0.190888601	;
    RnonCO2[	158	]=	0.194618313	;
    RnonCO2[	159	]=	0.198342475	;
    RnonCO2[	160	]=	0.202057589	;
    RnonCO2[	161	]=	0.20584786	;
    RnonCO2[	162	]=	0.209629466	;
    RnonCO2[	163	]=	0.213233356	;
    RnonCO2[	164	]=	0.216704098	;
    RnonCO2[	165	]=	0.220042715	;
    RnonCO2[	166	]=	0.223296521	;
    RnonCO2[	167	]=	0.226627686	;
    RnonCO2[	168	]=	0.230030664	;
    RnonCO2[	169	]=	0.233304361	;
    RnonCO2[	170	]=	0.236449311	;
    RnonCO2[	171	]=	0.239588758	;
    RnonCO2[	172	]=	0.24263915	;
    RnonCO2[	173	]=	0.245600759	;
    RnonCO2[	174	]=	0.248557521	;
    RnonCO2[	175	]=	0.251630431	;
    RnonCO2[	176	]=	0.254903022	;
    RnonCO2[	177	]=	0.258133328	;
    RnonCO2[	178	]=	0.26123828	;
    RnonCO2[	179	]=	0.264542	;
    RnonCO2[	180	]=	0.268044049	;
    RnonCO2[	181	]=	0.27165959	;
    RnonCO2[	182	]=	0.275506693	;
    RnonCO2[	183	]=	0.279465183	;
    RnonCO2[	184	]=	0.283533907	;
    RnonCO2[	185	]=	0.287746496	;
    RnonCO2[	186	]=	0.292103558	;
    RnonCO2[	187	]=	0.296886349	;
    RnonCO2[	188	]=	0.302089492	;
    RnonCO2[	189	]=	0.307309759	;
    RnonCO2[	190	]=	0.312629337	;
    RnonCO2[	191	]=	0.318245324	;
    RnonCO2[	192	]=	0.323988656	;
    RnonCO2[	193	]=	0.329826066	;
    RnonCO2[	194	]=	0.335923764	;
    RnonCO2[	195	]=	0.342309427	;
    RnonCO2[	196	]=	0.348815284	;
    RnonCO2[	197	]=	0.355439785	;
    RnonCO2[	198	]=	0.362318532	;
    RnonCO2[	199	]=	0.369551061	;
    RnonCO2[	200	]=	0.377072615	;
    RnonCO2[	201	]=	0.384665115	;
    RnonCO2[	202	]=	0.392331499	;
    RnonCO2[	203	]=	0.400273286	;
    RnonCO2[	204	]=	0.408559205	;
    RnonCO2[	205	]=	0.416991838	;
    RnonCO2[	206	]=	0.425389986	;
    RnonCO2[	207	]=	0.433949678	;
    RnonCO2[	208	]=	0.442740432	;
    RnonCO2[	209	]=	0.451573488	;
    RnonCO2[	210	]=	0.460373303	;
    RnonCO2[	211	]=	0.469303629	;
    RnonCO2[	212	]=	0.478507559	;
    RnonCO2[	213	]=	0.48782133	;
    RnonCO2[	214	]=	0.49689881	;
    RnonCO2[	215	]=	0.506302348	;
    RnonCO2[	216	]=	0.516911269	;
    RnonCO2[	217	]=	0.527818076	;
    RnonCO2[	218	]=	0.538162703	;
    RnonCO2[	219	]=	0.547403268	;
    RnonCO2[	220	]=	0.555524533	;
    RnonCO2[	221	]=	0.562888474	;
    RnonCO2[	222	]=	0.569356555	;
    RnonCO2[	223	]=	0.576908971	;
    RnonCO2[	224	]=	0.585481654	;
    RnonCO2[	225	]=	0.59287455	;
    RnonCO2[	226	]=	0.599146788	;
    RnonCO2[	227	]=	0.604130931	;
    RnonCO2[	228	]=	0.607750235	;
    RnonCO2[	229	]=	0.611664417	;
    RnonCO2[	230	]=	0.616444422	;
    RnonCO2[	231	]=	0.620912678	;
    RnonCO2[	232	]=	0.625821808	;
    RnonCO2[	233	]=	0.632177868	;
    RnonCO2[	234	]=	0.637926114	;
    RnonCO2[	235	]=	0.641532814	;
    RnonCO2[	236	]=	0.644675991	;
    RnonCO2[	237	]=	0.649064599	;
    RnonCO2[	238	]=	0.653980688	;
    RnonCO2[	239	]=	0.657858713	;
    RnonCO2[	240	]=	0.661298844	;
    RnonCO2[	241	]=	0.665634405	;
    RnonCO2[	242	]=	0.670709564	;
    RnonCO2[	243	]=	0.67628923	;
    RnonCO2[	244	]=	0.682302458	;
    RnonCO2[	245	]=	0.688639697	;
    RnonCO2[	246	]=	0.69527718	;
    RnonCO2[	247	]=	0.701403562	;
    RnonCO2[	248	]=	0.70627608	;
    RnonCO2[	249	]=	0.710008327	;
    RnonCO2[	250	]=	0.712705657	;
    RnonCO2[	251	]=	0.714449176	;
    RnonCO2[	252	]=	0.715301891	;
    RnonCO2[	253	]=	0.715323851	;
    RnonCO2[	254	]=	0.714572195	;
    RnonCO2[	255	]=	0.713098359	;
    RnonCO2[	256	]=	0.710923322	;
    RnonCO2[	257	]=	0.708448191	;
    RnonCO2[	258	]=	0.706115586	;
    RnonCO2[	259	]=	0.70402495	;
    RnonCO2[	260	]=	0.702225359	;
    RnonCO2[	261	]=	0.700699373	;
    RnonCO2[	262	]=	0.699417888	;
    RnonCO2[	263	]=	0.698344459	;
    RnonCO2[	264	]=	0.697449374	;
    RnonCO2[	265	]=	0.696708732	;
    RnonCO2[	266	]=	0.69610217	;
    RnonCO2[	267	]=	0.695628173	;
    RnonCO2[	268	]=	0.695294114	;
    RnonCO2[	269	]=	0.695099011	;
    RnonCO2[	270	]=	0.695038999	;
    RnonCO2[	271	]=	0.695109645	;
    RnonCO2[	272	]=	0.695309373	;
    RnonCO2[	273	]=	0.695623892	;
    RnonCO2[	274	]=	0.696030489	;
    RnonCO2[	275	]=	0.696511834	;
    RnonCO2[	276	]=	0.697056571	;
    RnonCO2[	277	]=	0.697402494	;
    RnonCO2[	278	]=	0.69728589	;
    RnonCO2[	279	]=	0.696728513	;
    RnonCO2[	280	]=	0.695783858	;
    RnonCO2[	281	]=	0.694495906	;
    RnonCO2[	282	]=	0.692903322	;
    RnonCO2[	283	]=	0.691042708	;
    RnonCO2[	284	]=	0.688934136	;
    RnonCO2[	285	]=	0.686585963	;
    RnonCO2[	286	]=	0.684008482	;
    RnonCO2[	287	]=	0.681383708	;
    RnonCO2[	288	]=	0.678877058	;
    RnonCO2[	289	]=	0.676445668	;
    RnonCO2[	290	]=	0.674060558	;
    RnonCO2[	291	]=	0.671730066	;
    RnonCO2[	292	]=	0.669457855	;
    RnonCO2[	293	]=	0.667246271	;
    RnonCO2[	294	]=	0.665099438	;
    RnonCO2[	295	]=	0.663009405	;
    RnonCO2[	296	]=	0.660958228	;
    RnonCO2[	297	]=	0.659086247	;
    RnonCO2[	298	]=	0.657524153	;
    RnonCO2[	299	]=	0.656237746	;
    RnonCO2[	300	]=	0.655171653	;
    RnonCO2[	301	]=	0.654286182	;
    RnonCO2[	302	]=	0.65357858	;
    RnonCO2[	303	]=	0.653043038	;
    RnonCO2[	304	]=	0.652672935	;
    RnonCO2[	305	]=	0.652465157	;
    RnonCO2[	306	]=	0.652404059	;
    RnonCO2[	307	]=	0.6524418	;
    RnonCO2[	308	]=	0.652536738	;
    RnonCO2[	309	]=	0.652678506	;
    RnonCO2[	310	]=	0.652857409	;
    RnonCO2[	311	]=	0.653041128	;
    RnonCO2[	312	]=	0.653210323	;
    RnonCO2[	313	]=	0.653380236	;
    RnonCO2[	314	]=	0.653560975	;
    RnonCO2[	315	]=	0.65376115	;
    RnonCO2[	316	]=	0.653990302	;
    RnonCO2[	317	]=	0.654213781	;
    RnonCO2[	318	]=	0.654389478	;
    RnonCO2[	319	]=	0.654513982	;
    RnonCO2[	320	]=	0.654587417	;
    RnonCO2[	321	]=	0.654609747	;
    RnonCO2[	322	]=	0.654557237	;
    RnonCO2[	323	]=	0.654417955	;
    RnonCO2[	324	]=	0.654213734	;
    RnonCO2[	325	]=	0.653961206	;
    RnonCO2[	326	]=	0.653673659	;
    RnonCO2[	327	]=	0.653359165	;
    RnonCO2[	328	]=	0.653011831	;
    RnonCO2[	329	]=	0.652623659	;
    RnonCO2[	330	]=	0.652190169	;
    RnonCO2[	331	]=	0.651709747	;
    RnonCO2[	332	]=	0.65118174	;
    RnonCO2[	333	]=	0.650581524	;
    RnonCO2[	334	]=	0.649896351	;
    RnonCO2[	335	]=	0.649147717	;
    RnonCO2[	336	]=	0.648351872	;
    RnonCO2[	337	]=	0.647587491	;
    RnonCO2[	338	]=	0.646927556	;
    RnonCO2[	339	]=	0.646361929	;
    RnonCO2[	340	]=	0.645872576	;
    RnonCO2[	341	]=	0.645446444	;
    RnonCO2[	342	]=	0.645074486	;
    RnonCO2[	343	]=	0.644749065	;
    RnonCO2[	344	]=	0.644439491	;
    RnonCO2[	345	]=	0.644127681	;
    RnonCO2[	346	]=	0.643829745	;
    RnonCO2[	347	]=	0.643556768	;
    RnonCO2[	348	]=	0.643317648	;
    RnonCO2[	349	]=	0.643122434	;
    RnonCO2[	350	]=	0.642968368	;
    RnonCO2[	351	]=	0.642843801	;
    RnonCO2[	352	]=	0.642741103	;
    RnonCO2[	353	]=	0.642656013	;
    RnonCO2[	354	]=	0.642585153	;
    RnonCO2[	355	]=	0.642501504	;
    RnonCO2[	356	]=	0.642390659	;
    RnonCO2[	357	]=	0.64227118	;
    RnonCO2[	358	]=	0.642157069	;
    RnonCO2[	359	]=	0.642059166	;
    RnonCO2[	360	]=	0.641989552	;
    RnonCO2[	361	]=	0.641947462	;
    RnonCO2[	362	]=	0.641922442	;
    RnonCO2[	363	]=	0.641908413	;
    RnonCO2[	364	]=	0.641902542	;
    RnonCO2[	365	]=	0.641902103	;
    RnonCO2[	366	]=	0.641881484	;
    RnonCO2[	367	]=	0.64182659	;
    RnonCO2[	368	]=	0.641757156	;
    RnonCO2[	369	]=	0.641687481	;
    RnonCO2[	370	]=	0.641629007	;
    RnonCO2[	371	]=	0.641594499	;
    RnonCO2[	372	]=	0.641583402	;
    RnonCO2[	373	]=	0.641585827	;
    RnonCO2[	374	]=	0.641596018	;
    RnonCO2[	375	]=	0.641611463	;
    RnonCO2[	376	]=	0.64162986	;
    RnonCO2[	377	]=	0.641625726	;
    RnonCO2[	378	]=	0.641585263	;
    RnonCO2[	379	]=	0.641528723	;
    RnonCO2[	380	]=	0.641470296	;
    RnonCO2[	381	]=	0.641421766	;
    RnonCO2[	382	]=	0.641395948	;
    RnonCO2[	383	]=	0.641392154	;
    RnonCO2[	384	]=	0.641401353	;
    RnonCO2[	385	]=	0.64141721	;
    RnonCO2[	386	]=	0.641437537	;
    RnonCO2[	387	]=	0.641460391	;
    RnonCO2[	388	]=	0.641459943	;
    RnonCO2[	389	]=	0.641423022	;
    RnonCO2[	390	]=	0.641369488	;
    RnonCO2[	391	]=	0.641313577	;
    RnonCO2[	392	]=	0.641267383	;
    RnonCO2[	393	]=	0.641243587	;
    RnonCO2[	394	]=	0.641241634	;
    RnonCO2[	395	]=	0.641252286	;
    RnonCO2[	396	]=	0.641269652	;
    RnonCO2[	397	]=	0.641291382	;
    RnonCO2[	398	]=	0.641315333	;
    RnonCO2[	399	]=	0.641316089	;
    RnonCO2[	400	]=	0.641280102	;
    RnonCO2[	401	]=	0.641227629	;
    RnonCO2[	402	]=	0.641172852	;
    RnonCO2[	403	]=	0.641127523	;
    RnonCO2[	404	]=	0.641104618	;
    RnonCO2[	405	]=	0.641103737	;
    RnonCO2[	406	]=	0.64111538	;
    RnonCO2[	407	]=	0.641133688	;
    RnonCO2[	408	]=	0.641156242	;
    RnonCO2[	409	]=	0.641181334	;
    RnonCO2[	410	]=	0.641183105	;
    RnonCO2[	411	]=	0.641148179	;
    RnonCO2[	412	]=	0.64109684	;
    RnonCO2[	413	]=	0.641043309	;
    RnonCO2[	414	]=	0.640999274	;
    RnonCO2[	415	]=	0.640977747	;
    RnonCO2[	416	]=	0.64097798	;
    RnonCO2[	417	]=	0.640990871	;
    RnonCO2[	418	]=	0.641010507	;
    RnonCO2[	419	]=	0.641034661	;
    RnonCO2[	420	]=	0.641061044	;
    RnonCO2[	421	]=	0.641064416	;
    RnonCO2[	422	]=	0.641031095	;
    RnonCO2[	423	]=	0.64098136	;
    RnonCO2[	424	]=	0.640929589	;
    RnonCO2[	425	]=	0.640887156	;
    RnonCO2[	426	]=	0.64086736	;
    RnonCO2[	427	]=	0.640869364	;
    RnonCO2[	428	]=	0.64088411	;
    RnonCO2[	429	]=	0.64090566	;
    RnonCO2[	430	]=	0.640931694	;
    RnonCO2[	431	]=	0.640960009	;
    RnonCO2[	432	]=	0.640965392	;
    RnonCO2[	433	]=	0.640934081	;
    RnonCO2[	434	]=	0.640886487	;
    RnonCO2[	435	]=	0.640836625	;
    RnonCO2[	436	]=	0.640796581	;
    RnonCO2[	437	]=	0.640778892	;
    RnonCO2[	438	]=	0.640783188	;
    RnonCO2[	439	]=	0.640800038	;
    RnonCO2[	440	]=	0.640823767	;
    RnonCO2[	441	]=	0.640851987	;
    RnonCO2[	442	]=	0.640882711	;
    RnonCO2[	443	]=	0.640890341	;
    RnonCO2[	444	]=	0.640861479	;
    RnonCO2[	445	]=	0.640816265	;
    RnonCO2[	446	]=	0.640768843	;
    RnonCO2[	447	]=	0.640731096	;
    RnonCO2[	448	]=	0.640715718	;
    RnonCO2[	449	]=	0.64072241	;
    RnonCO2[	450	]=	0.640741789	;
    RnonCO2[	451	]=	0.640767899	;
    RnonCO2[	452	]=	0.640798694	;
    RnonCO2[	453	]=	0.640831765	;
    RnonCO2[	454	]=	0.640841788	;
    RnonCO2[	455	]=	0.640815504	;
    RnonCO2[	456	]=	0.640772848	;
    RnonCO2[	457	]=	0.640727856	;
    RnonCO2[	458	]=	0.640692733	;
    RnonCO2[	459	]=	0.640680046	;
    RnonCO2[	460	]=	0.640689303	;
    RnonCO2[	461	]=	0.640711189	;
    RnonCO2[	462	]=	0.640739891	;
    RnonCO2[	463	]=	0.640773157	;
    RnonCO2[	464	]=	0.640808797	;
    RnonCO2[	465	]=	0.640821428	;
    RnonCO2[	466	]=	0.640797617	;
    RnonCO2[	467	]=	0.640757545	;
    RnonCO2[	468	]=	0.64071535	;
    RnonCO2[	469	]=	0.640682616	;
    RnonCO2[	470	]=	0.640672491	;
    RnonCO2[	471	]=	0.640684395	;
    RnonCO2[	472	]=	0.64070869	;
    RnonCO2[	473	]=	0.64074009	;
    RnonCO2[	474	]=	0.640775773	;
    RnonCO2[	475	]=	0.640814056	;
    RnonCO2[	476	]=	0.640829201	;
    RnonCO2[	477	]=	0.640808032	;
    RnonCO2[	478	]=	0.64077054	;
    RnonCO2[	479	]=	0.640730713	;
    RnonCO2[	480	]=	0.640700724	;
    RnonCO2[	481	]=	0.640693031	;
    RnonCO2[	482	]=	0.640707431	;
    RnonCO2[	483	]=	0.64073449	;
    RnonCO2[	484	]=	0.64076826	;
    RnonCO2[	485	]=	0.640806409	;
    RnonCO2[	486	]=	0.640847194	;
    RnonCO2[	487	]=	0.640864861	;
    RnonCO2[	488	]=	0.640846062	;
    RnonCO2[	489	]=	0.640811122	;
    RnonCO2[	490	]=	0.640773885	;
    RnonCO2[	491	]=	0.640746288	;
    RnonCO2[	492	]=	0.640741193	;
    RnonCO2[	493	]=	0.640757802	;
    RnonCO2[	494	]=	0.640787191	;
    RnonCO2[	495	]=	0.640823405	;
    RnonCO2[	496	]=	0.640864078	;
    RnonCO2[	497	]=	0.640907151	;
    RnonCO2[	498	]=	0.640927242	;
    RnonCO2[	499	]=	0.640910852	;
    RnonCO2[	500	]=	0.640878234	;
    RnonCO2[	501	]=	0.640843453	;
    RnonCO2[	502	]=	0.640818219	;
    RnonCO2[	503	]=	0.640815287	;
    RnonCO2[	504	]=	0.640834449	;
    RnonCO2[	505	]=	0.640866076	;
    RnonCO2[	506	]=	0.640904642	;
    RnonCO2[	507	]=	0.64094757	;
    RnonCO2[	508	]=	0.640992949	;
    RnonCO2[	509	]=	0.641015182	;
    RnonCO2[	510	]=	0.641001218	;
    RnonCO2[	511	]=	0.640970905	;
    RnonCO2[	512	]=	0.640938306	;
    RnonCO2[	513	]=	0.64091527	;
    RnonCO2[	514	]=	0.640914554	;
    RnonCO2[	515	]=	0.640935918	;
    RnonCO2[	516	]=	0.640969684	;
    RnonCO2[	517	]=	0.64101034	;
    RnonCO2[	518	]=	0.641055423	;
    RnonCO2[	519	]=	0.641102976	;
    RnonCO2[	520	]=	0.641127498	;
    RnonCO2[	521	]=	0.641115546	;
    RnonCO2[	522	]=	0.641087273	;
    RnonCO2[	523	]=	0.641056701	;
    RnonCO2[	524	]=	0.641035836	;
    RnonCO2[	525	]=	0.641037306	;
    RnonCO2[	526	]=	0.64106067	;
    RnonCO2[	527	]=	0.641096487	;
    RnonCO2[	528	]=	0.64113916	;
    RnonCO2[	529	]=	0.641186291	;
    RnonCO2[	530	]=	0.641235763	;
    RnonCO2[	531	]=	0.641262211	;
    RnonCO2[	532	]=	0.641252173	;
    RnonCO2[	533	]=	0.641225977	;
    RnonCO2[	534	]=	0.641197318	;
    RnonCO2[	535	]=	0.641178511	;
    RnonCO2[	536	]=	0.641181865	;
    RnonCO2[	537	]=	0.641207056	;
    RnonCO2[	538	]=	0.641244764	;
    RnonCO2[	539	]=	0.641289276	;
    RnonCO2[	540	]=	0.641338409	;
    RnonCO2[	541	]=	0.64138962	;
    RnonCO2[	542	]=	0.641418067	;
    RnonCO2[	543	]=	0.641409757	;
    RnonCO2[	544	]=	0.641385454	;
    RnonCO2[	545	]=	0.641358657	;
    RnonCO2[	546	]=	0.641341539	;
    RnonCO2[	547	]=	0.641346701	;
    RnonCO2[	548	]=	0.641373635	;
    RnonCO2[	549	]=	0.641413119	;
    RnonCO2[	550	]=	0.641459485	;
    RnonCO2[	551	]=	0.641510222	;
    RnonCO2[	552	]=	0.641563169	;
    RnonCO2[	553	]=	0.64159322	;
    RnonCO2[	554	]=	0.64158681	;
    RnonCO2[	555	]=	0.641563995	;
    RnonCO2[	556	]=	0.641539068	;
    RnonCO2[	557	]=	0.641523643	;
    RnonCO2[	558	]=	0.641530332	;
    RnonCO2[	559	]=	0.641558975	;
    RnonCO2[	560	]=	0.641600062	;
    RnonCO2[	561	]=	0.641647961	;
    RnonCO2[	562	]=	0.641700245	;
    RnonCO2[	563	]=	0.64175489	;
    RnonCO2[	564	]=	0.641786506	;
    RnonCO2[	565	]=	0.641781651	;
    RnonCO2[	566	]=	0.641760427	;
    RnonCO2[	567	]=	0.64173704	;
    RnonCO2[	568	]=	0.641723127	;
    RnonCO2[	569	]=	0.641731388	;
    RnonCO2[	570	]=	0.641761516	;
    RnonCO2[	571	]=	0.641803981	;
    RnonCO2[	572	]=	0.641853453	;
    RnonCO2[	573	]=	0.641907207	;
    RnonCO2[	574	]=	0.641963305	;
    RnonCO2[	575	]=	0.641996229	;
    RnonCO2[	576	]=	0.641992859	;
    RnonCO2[	577	]=	0.641973142	;
    RnonCO2[	578	]=	0.641951178	;
    RnonCO2[	579	]=	0.641938654	;
    RnonCO2[	580	]=	0.641948246	;
    RnonCO2[	581	]=	0.64197973	;
    RnonCO2[	582	]=	0.642023712	;
    RnonCO2[	583	]=	0.642074341	;
    RnonCO2[	584	]=	0.642129399	;
    RnonCO2[	585	]=	0.642186954	;
    RnonCO2[	586	]=	0.642221191	;
    RnonCO2[	587	]=	0.642219303	;
    RnonCO2[	588	]=	0.642200784	;
    RnonCO2[	589	]=	0.642179984	;
    RnonCO2[	590	]=	0.642168844	;
    RnonCO2[	591	]=	0.642179874	;
    RnonCO2[	592	]=	0.642212549	;
    RnonCO2[	593	]=	0.642257576	;
    RnonCO2[	594	]=	0.642309599	;
    RnonCO2[	595	]=	0.642365945	;
    RnonCO2[	596	]=	0.642424465	;
    RnonCO2[	597	]=	0.642460121	;
    RnonCO2[	598	]=	0.642459247	;
    RnonCO2[	599	]=	0.642442055	;
    RnonCO2[	600	]=	0.642422649	;
    RnonCO2[	601	]=	0.642412542	;
    RnonCO2[	602	]=	0.642424539	;
    RnonCO2[	603	]=	0.642458609	;
    RnonCO2[	604	]=	0.642504764	;
    RnonCO2[	605	]=	0.642557976	;
    RnonCO2[	606	]=	0.64261537	;
    RnonCO2[	607	]=	0.642675074	;
    RnonCO2[	608	]=	0.642711774	;
    RnonCO2[	609	]=	0.642711987	;
    RnonCO2[	610	]=	0.64269589	;
    RnonCO2[	611	]=	0.642677526	;
    RnonCO2[	612	]=	0.642668541	;
    RnonCO2[	613	]=	0.64268183	;
    RnonCO2[	614	]=	0.642716628	;
    RnonCO2[	615	]=	0.64276394	;
    RnonCO2[	616	]=	0.642817944	;
    RnonCO2[	617	]=	0.642876415	;
    RnonCO2[	618	]=	0.642937333	;
    RnonCO2[	619	]=	0.642974973	;
    RnonCO2[	620	]=	0.642976326	;
    RnonCO2[	621	]=	0.642961087	;
    RnonCO2[	622	]=	0.642943647	;
    RnonCO2[	623	]=	0.642935649	;
    RnonCO2[	624	]=	0.642949834	;
    RnonCO2[	625	]=	0.642985662	;
    RnonCO2[	626	]=	0.643034009	;
    RnonCO2[	627	]=	0.643089089	;
    RnonCO2[	628	]=	0.643148354	;
    RnonCO2[	629	]=	0.643210068	;
    RnonCO2[	630	]=	0.643248799	;
    RnonCO2[	631	]=	0.643250861	;
    RnonCO2[	632	]=	0.64323679	;
    RnonCO2[	633	]=	0.643220293	;
    RnonCO2[	634	]=	0.643213004	;
    RnonCO2[	635	]=	0.64322822	;
    RnonCO2[	636	]=	0.643264917	;
    RnonCO2[	637	]=	0.643313997	;
    RnonCO2[	638	]=	0.643369852	;
    RnonCO2[	639	]=	0.643430059	;
    RnonCO2[	640	]=	0.643492661	;
    RnonCO2[	641	]=	0.643532044	;
    RnonCO2[	642	]=	0.643535246	;
    RnonCO2[	643	]=	0.643521737	;
    RnonCO2[	644	]=	0.643506025	;
    RnonCO2[	645	]=	0.643499719	;
    RnonCO2[	646	]=	0.643515648	;
    RnonCO2[	647	]=	0.64355305	;
    RnonCO2[	648	]=	0.643603114	;
    RnonCO2[	649	]=	0.643659699	;
    RnonCO2[	650	]=	0.643720646	;
    RnonCO2[	651	]=	0.643783971	;
    RnonCO2[	652	]=	0.643824101	;
    RnonCO2[	653	]=	0.643827969	;
    RnonCO2[	654	]=	0.643815297	;
    RnonCO2[	655	]=	0.643800331	;
    RnonCO2[	656	]=	0.64379497	;
    RnonCO2[	657	]=	0.643811412	;
    RnonCO2[	658	]=	0.643849754	;
    RnonCO2[	659	]=	0.643900303	;
    RnonCO2[	660	]=	0.64395757	;
    RnonCO2[	661	]=	0.644019334	;
    RnonCO2[	662	]=	0.644083335	;
    RnonCO2[	663	]=	0.644124308	;
    RnonCO2[	664	]=	0.644128783	;
    RnonCO2[	665	]=	0.644116891	;
    RnonCO2[	666	]=	0.644102613	;
    RnonCO2[	667	]=	0.6440977	;
    RnonCO2[	668	]=	0.644114891	;
    RnonCO2[	669	]=	0.644153654	;
    RnonCO2[	670	]=	0.644205061	;
    RnonCO2[	671	]=	0.644262928	;
    RnonCO2[	672	]=	0.644325144	;
    RnonCO2[	673	]=	0.644390018	;
    RnonCO2[	674	]=	0.644431455	;
    RnonCO2[	675	]=	0.644436475	;
    RnonCO2[	676	]=	0.644425145	;
    RnonCO2[	677	]=	0.644411638	;
    RnonCO2[	678	]=	0.644407376	;
    RnonCO2[	679	]=	0.644425236	;
    RnonCO2[	680	]=	0.644464635	;
    RnonCO2[	681	]=	0.644516358	;
    RnonCO2[	682	]=	0.644575023	;
    RnonCO2[	683	]=	0.644637906	;
    RnonCO2[	684	]=	0.644703111	;
    RnonCO2[	685	]=	0.644745068	;
    RnonCO2[	686	]=	0.644750837	;
    RnonCO2[	687	]=	0.644740132	;
    RnonCO2[	688	]=	0.644727158	;
    RnonCO2[	689	]=	0.644723467	;
    RnonCO2[	690	]=	0.644741736	;
    RnonCO2[	691	]=	0.64478167	;
    RnonCO2[	692	]=	0.644834048	;
    RnonCO2[	693	]=	0.644893108	;
    RnonCO2[	694	]=	0.644956376	;
    RnonCO2[	695	]=	0.645022107	;
    RnonCO2[	696	]=	0.645064785	;
    RnonCO2[	697	]=	0.645071063	;
    RnonCO2[	698	]=	0.645060867	;
    RnonCO2[	699	]=	0.645048167	;
    RnonCO2[	700	]=	0.645045091	;
    RnonCO2[	701	]=	0.645063809	;
    RnonCO2[	702	]=	0.645104299	;
    RnonCO2[	703	]=	0.645157211	;
    RnonCO2[	704	]=	0.64521654	;
    RnonCO2[	705	]=	0.645280534	;
    RnonCO2[	706	]=	0.645346669	;
    RnonCO2[	707	]=	0.645389786	;
    RnonCO2[	708	]=	0.645396435	;
    RnonCO2[	709	]=	0.645386649	;
    RnonCO2[	710	]=	0.645374551	;
    RnonCO2[	711	]=	0.64537181	;
    RnonCO2[	712	]=	0.645391018	;
    RnonCO2[	713	]=	0.645431924	;
    RnonCO2[	714	]=	0.645485085	;
    RnonCO2[	715	]=	0.64554515	;
    RnonCO2[	716	]=	0.645609424	;
    RnonCO2[	717	]=	0.645676124	;
    RnonCO2[	718	]=	0.645719395	;
    RnonCO2[	719	]=	0.6457266	;
    RnonCO2[	720	]=	0.645717248	;
    RnonCO2[	721	]=	0.645705635	;
    RnonCO2[	722	]=	0.645703251	;
    RnonCO2[	723	]=	0.645722935	;
    RnonCO2[	724	]=	0.645764115	;
    RnonCO2[	725	]=	0.645817686	;
    RnonCO2[	726	]=	0.64587804	;
    RnonCO2[	727	]=	0.645942756	;
    RnonCO2[	728	]=	0.646009715	;
    RnonCO2[	729	]=	0.646053591	;
    RnonCO2[	730	]=	0.64606107	;
    RnonCO2[	731	]=	0.64605214	;
    RnonCO2[	732	]=	0.646040708	;
    RnonCO2[	733	]=	0.646038832	;
    RnonCO2[	734	]=	0.646058706	;
    RnonCO2[	735	]=	0.646075547	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }

}

void setRnonCO2_RCP85_K(void)
{
    
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005612142	;
    RnonCO2[	2	]=	0.008971239	;
    RnonCO2[	3	]=	0.009466172	;
    RnonCO2[	4	]=	0.009946833	;
    RnonCO2[	5	]=	0.010412166	;
    RnonCO2[	6	]=	0.010865438	;
    RnonCO2[	7	]=	0.011309666	;
    RnonCO2[	8	]=	0.011745593	;
    RnonCO2[	9	]=	0.012173039	;
    RnonCO2[	10	]=	0.012591208	;
    RnonCO2[	11	]=	0.012999626	;
    RnonCO2[	12	]=	0.013397144	;
    RnonCO2[	13	]=	0.013783559	;
    RnonCO2[	14	]=	0.014157995	;
    RnonCO2[	15	]=	0.014518817	;
    RnonCO2[	16	]=	0.014861789	;
    RnonCO2[	17	]=	0.015185328	;
    RnonCO2[	18	]=	0.015493438	;
    RnonCO2[	19	]=	0.015792171	;
    RnonCO2[	20	]=	0.01608699	;
    RnonCO2[	21	]=	0.016384013	;
    RnonCO2[	22	]=	0.016688621	;
    RnonCO2[	23	]=	0.017006739	;
    RnonCO2[	24	]=	0.017344141	;
    RnonCO2[	25	]=	0.017705767	;
    RnonCO2[	26	]=	0.018092359	;
    RnonCO2[	27	]=	0.018501885	;
    RnonCO2[	28	]=	0.01893258	;
    RnonCO2[	29	]=	0.019382558	;
    RnonCO2[	30	]=	0.019850303	;
    RnonCO2[	31	]=	0.020334085	;
    RnonCO2[	32	]=	0.020831989	;
    RnonCO2[	33	]=	0.021342706	;
    RnonCO2[	34	]=	0.02186457	;
    RnonCO2[	35	]=	0.022398729	;
    RnonCO2[	36	]=	0.022952686	;
    RnonCO2[	37	]=	0.023532049	;
    RnonCO2[	38	]=	0.024135881	;
    RnonCO2[	39	]=	0.024759327	;
    RnonCO2[	40	]=	0.025397837	;
    RnonCO2[	41	]=	0.02604713	;
    RnonCO2[	42	]=	0.026702498	;
    RnonCO2[	43	]=	0.02735936	;
    RnonCO2[	44	]=	0.028013477	;
    RnonCO2[	45	]=	0.028662413	;
    RnonCO2[	46	]=	0.029309198	;
    RnonCO2[	47	]=	0.029958961	;
    RnonCO2[	48	]=	0.030612845	;
    RnonCO2[	49	]=	0.031270152	;
    RnonCO2[	50	]=	0.03193112	;
    RnonCO2[	51	]=	0.032594644	;
    RnonCO2[	52	]=	0.033260857	;
    RnonCO2[	53	]=	0.033928967	;
    RnonCO2[	54	]=	0.034598246	;
    RnonCO2[	55	]=	0.035268641	;
    RnonCO2[	56	]=	0.035940357	;
    RnonCO2[	57	]=	0.036613717	;
    RnonCO2[	58	]=	0.037289228	;
    RnonCO2[	59	]=	0.037967253	;
    RnonCO2[	60	]=	0.038647628	;
    RnonCO2[	61	]=	0.039330893	;
    RnonCO2[	62	]=	0.040017299	;
    RnonCO2[	63	]=	0.040707068	;
    RnonCO2[	64	]=	0.041400385	;
    RnonCO2[	65	]=	0.042096128	;
    RnonCO2[	66	]=	0.042791515	;
    RnonCO2[	67	]=	0.04348473	;
    RnonCO2[	68	]=	0.044177707	;
    RnonCO2[	69	]=	0.044873365	;
    RnonCO2[	70	]=	0.045574528	;
    RnonCO2[	71	]=	0.04628438	;
    RnonCO2[	72	]=	0.047005924	;
    RnonCO2[	73	]=	0.047742202	;
    RnonCO2[	74	]=	0.048496247	;
    RnonCO2[	75	]=	0.049273302	;
    RnonCO2[	76	]=	0.050090919	;
    RnonCO2[	77	]=	0.050966437	;
    RnonCO2[	78	]=	0.051881638	;
    RnonCO2[	79	]=	0.052787675	;
    RnonCO2[	80	]=	0.053629807	;
    RnonCO2[	81	]=	0.054384454	;
    RnonCO2[	82	]=	0.055079735	;
    RnonCO2[	83	]=	0.055748092	;
    RnonCO2[	84	]=	0.056393965	;
    RnonCO2[	85	]=	0.057093398	;
    RnonCO2[	86	]=	0.05807606	;
    RnonCO2[	87	]=	0.059274862	;
    RnonCO2[	88	]=	0.060472717	;
    RnonCO2[	89	]=	0.061669627	;
    RnonCO2[	90	]=	0.062723294	;
    RnonCO2[	91	]=	0.063776572	;
    RnonCO2[	92	]=	0.064970976	;
    RnonCO2[	93	]=	0.066164765	;
    RnonCO2[	94	]=	0.067357381	;
    RnonCO2[	95	]=	0.06854924	;
    RnonCO2[	96	]=	0.069740139	;
    RnonCO2[	97	]=	0.070930146	;
    RnonCO2[	98	]=	0.072119404	;
    RnonCO2[	99	]=	0.073307822	;
    RnonCO2[	100	]=	0.074635976	;
    RnonCO2[	101	]=	0.075963149	;
    RnonCO2[	102	]=	0.077148556	;
    RnonCO2[	103	]=	0.078333267	;
    RnonCO2[	104	]=	0.079516971	;
    RnonCO2[	105	]=	0.080754531	;
    RnonCO2[	106	]=	0.081905797	;
    RnonCO2[	107	]=	0.083001419	;
    RnonCO2[	108	]=	0.084181461	;
    RnonCO2[	109	]=	0.085360786	;
    RnonCO2[	110	]=	0.086593261	;
    RnonCO2[	111	]=	0.087739428	;
    RnonCO2[	112	]=	0.088830817	;
    RnonCO2[	113	]=	0.090006409	;
    RnonCO2[	114	]=	0.091181226	;
    RnonCO2[	115	]=	0.092494155	;
    RnonCO2[	116	]=	0.093944335	;
    RnonCO2[	117	]=	0.095393111	;
    RnonCO2[	118	]=	0.096840323	;
    RnonCO2[	119	]=	0.098148223	;
    RnonCO2[	120	]=	0.09931678	;
    RnonCO2[	121	]=	0.100622634	;
    RnonCO2[	122	]=	0.101979664	;
    RnonCO2[	123	]=	0.10325049	;
    RnonCO2[	124	]=	0.104604961	;
    RnonCO2[	125	]=	0.106043011	;
    RnonCO2[	126	]=	0.107616808	;
    RnonCO2[	127	]=	0.109325606	;
    RnonCO2[	128	]=	0.110810739	;
    RnonCO2[	129	]=	0.112072699	;
    RnonCO2[	130	]=	0.113469426	;
    RnonCO2[	131	]=	0.115000677	;
    RnonCO2[	132	]=	0.116479164	;
    RnonCO2[	133	]=	0.117955956	;
    RnonCO2[	134	]=	0.119481632	;
    RnonCO2[	135	]=	0.121230683	;
    RnonCO2[	136	]=	0.123467298	;
    RnonCO2[	137	]=	0.125964505	;
    RnonCO2[	138	]=	0.128590857	;
    RnonCO2[	139	]=	0.131345679	;
    RnonCO2[	140	]=	0.134094266	;
    RnonCO2[	141	]=	0.136836274	;
    RnonCO2[	142	]=	0.139657159	;
    RnonCO2[	143	]=	0.142689092	;
    RnonCO2[	144	]=	0.145846541	;
    RnonCO2[	145	]=	0.148864539	;
    RnonCO2[	146	]=	0.151744205	;
    RnonCO2[	147	]=	0.154833698	;
    RnonCO2[	148	]=	0.158178102	;
    RnonCO2[	149	]=	0.161560167	;
    RnonCO2[	150	]=	0.165018225	;
    RnonCO2[	151	]=	0.168552404	;
    RnonCO2[	152	]=	0.172162279	;
    RnonCO2[	153	]=	0.175976823	;
    RnonCO2[	154	]=	0.179825831	;
    RnonCO2[	155	]=	0.18353714	;
    RnonCO2[	156	]=	0.18719586	;
    RnonCO2[	157	]=	0.190888601	;
    RnonCO2[	158	]=	0.194618313	;
    RnonCO2[	159	]=	0.198342475	;
    RnonCO2[	160	]=	0.202057589	;
    RnonCO2[	161	]=	0.20584786	;
    RnonCO2[	162	]=	0.209629466	;
    RnonCO2[	163	]=	0.213233356	;
    RnonCO2[	164	]=	0.216704098	;
    RnonCO2[	165	]=	0.220042715	;
    RnonCO2[	166	]=	0.223296521	;
    RnonCO2[	167	]=	0.226627686	;
    RnonCO2[	168	]=	0.230030664	;
    RnonCO2[	169	]=	0.233304361	;
    RnonCO2[	170	]=	0.236449311	;
    RnonCO2[	171	]=	0.239588758	;
    RnonCO2[	172	]=	0.24263915	;
    RnonCO2[	173	]=	0.245600759	;
    RnonCO2[	174	]=	0.248557521	;
    RnonCO2[	175	]=	0.251630431	;
    RnonCO2[	176	]=	0.254903022	;
    RnonCO2[	177	]=	0.258133328	;
    RnonCO2[	178	]=	0.26123828	;
    RnonCO2[	179	]=	0.264542	;
    RnonCO2[	180	]=	0.268044049	;
    RnonCO2[	181	]=	0.27165959	;
    RnonCO2[	182	]=	0.275506693	;
    RnonCO2[	183	]=	0.279465183	;
    RnonCO2[	184	]=	0.283533907	;
    RnonCO2[	185	]=	0.287746496	;
    RnonCO2[	186	]=	0.292103558	;
    RnonCO2[	187	]=	0.296886349	;
    RnonCO2[	188	]=	0.302089492	;
    RnonCO2[	189	]=	0.307309759	;
    RnonCO2[	190	]=	0.312629337	;
    RnonCO2[	191	]=	0.318245324	;
    RnonCO2[	192	]=	0.323988656	;
    RnonCO2[	193	]=	0.329826066	;
    RnonCO2[	194	]=	0.335923764	;
    RnonCO2[	195	]=	0.342309427	;
    RnonCO2[	196	]=	0.348815284	;
    RnonCO2[	197	]=	0.355439785	;
    RnonCO2[	198	]=	0.362318532	;
    RnonCO2[	199	]=	0.369551061	;
    RnonCO2[	200	]=	0.377072615	;
    RnonCO2[	201	]=	0.384665115	;
    RnonCO2[	202	]=	0.392331499	;
    RnonCO2[	203	]=	0.400273286	;
    RnonCO2[	204	]=	0.408559205	;
    RnonCO2[	205	]=	0.416991838	;
    RnonCO2[	206	]=	0.425389986	;
    RnonCO2[	207	]=	0.433949678	;
    RnonCO2[	208	]=	0.442740432	;
    RnonCO2[	209	]=	0.451573488	;
    RnonCO2[	210	]=	0.460373303	;
    RnonCO2[	211	]=	0.469303629	;
    RnonCO2[	212	]=	0.478507559	;
    RnonCO2[	213	]=	0.48782133	;
    RnonCO2[	214	]=	0.49689881	;
    RnonCO2[	215	]=	0.506302348	;
    RnonCO2[	216	]=	0.516911269	;
    RnonCO2[	217	]=	0.527818076	;
    RnonCO2[	218	]=	0.538162703	;
    RnonCO2[	219	]=	0.547403268	;
    RnonCO2[	220	]=	0.555524533	;
    RnonCO2[	221	]=	0.562888474	;
    RnonCO2[	222	]=	0.569356555	;
    RnonCO2[	223	]=	0.576908971	;
    RnonCO2[	224	]=	0.585481654	;
    RnonCO2[	225	]=	0.59287455	;
    RnonCO2[	226	]=	0.599146788	;
    RnonCO2[	227	]=	0.604130931	;
    RnonCO2[	228	]=	0.607750235	;
    RnonCO2[	229	]=	0.611664417	;
    RnonCO2[	230	]=	0.616444422	;
    RnonCO2[	231	]=	0.620912678	;
    RnonCO2[	232	]=	0.625821808	;
    RnonCO2[	233	]=	0.632177868	;
    RnonCO2[	234	]=	0.637926114	;
    RnonCO2[	235	]=	0.641532814	;
    RnonCO2[	236	]=	0.644675991	;
    RnonCO2[	237	]=	0.649064599	;
    RnonCO2[	238	]=	0.653980688	;
    RnonCO2[	239	]=	0.657858713	;
    RnonCO2[	240	]=	0.661298844	;
    RnonCO2[	241	]=	0.665633413	;
    RnonCO2[	242	]=	0.670918799	;
    RnonCO2[	243	]=	0.677115343	;
    RnonCO2[	244	]=	0.684117052	;
    RnonCO2[	245	]=	0.691779863	;
    RnonCO2[	246	]=	0.700055049	;
    RnonCO2[	247	]=	0.708955169	;
    RnonCO2[	248	]=	0.718480902	;
    RnonCO2[	249	]=	0.728589067	;
    RnonCO2[	250	]=	0.739243369	;
    RnonCO2[	251	]=	0.750397995	;
    RnonCO2[	252	]=	0.762000405	;
    RnonCO2[	253	]=	0.774005664	;
    RnonCO2[	254	]=	0.786375911	;
    RnonCO2[	255	]=	0.799075749	;
    RnonCO2[	256	]=	0.812044406	;
    RnonCO2[	257	]=	0.825155905	;
    RnonCO2[	258	]=	0.838337326	;
    RnonCO2[	259	]=	0.851599925	;
    RnonCO2[	260	]=	0.864953055	;
    RnonCO2[	261	]=	0.878407402	;
    RnonCO2[	262	]=	0.89195823	;
    RnonCO2[	263	]=	0.90558941	;
    RnonCO2[	264	]=	0.919289044	;
    RnonCO2[	265	]=	0.933049417	;
    RnonCO2[	266	]=	0.946861978	;
    RnonCO2[	267	]=	0.960865669	;
    RnonCO2[	268	]=	0.975199561	;
    RnonCO2[	269	]=	0.989856102	;
    RnonCO2[	270	]=	1.00482388	;
    RnonCO2[	271	]=	1.020090986	;
    RnonCO2[	272	]=	1.03564984	;
    RnonCO2[	273	]=	1.051477376	;
    RnonCO2[	274	]=	1.067540111	;
    RnonCO2[	275	]=	1.083810068	;
    RnonCO2[	276	]=	1.100266073	;
    RnonCO2[	277	]=	1.116869792	;
    RnonCO2[	278	]=	1.133550695	;
    RnonCO2[	279	]=	1.150273404	;
    RnonCO2[	280	]=	1.16705088	;
    RnonCO2[	281	]=	1.183891341	;
    RnonCO2[	282	]=	1.200801505	;
    RnonCO2[	283	]=	1.217791069	;
    RnonCO2[	284	]=	1.234851367	;
    RnonCO2[	285	]=	1.251960784	;
    RnonCO2[	286	]=	1.269103667	;
    RnonCO2[	287	]=	1.286084756	;
    RnonCO2[	288	]=	1.302726275	;
    RnonCO2[	289	]=	1.319010791	;
    RnonCO2[	290	]=	1.334936039	;
    RnonCO2[	291	]=	1.350549926	;
    RnonCO2[	292	]=	1.365893616	;
    RnonCO2[	293	]=	1.381003333	;
    RnonCO2[	294	]=	1.395916498	;
    RnonCO2[	295	]=	1.41064864	;
    RnonCO2[	296	]=	1.42519918	;
    RnonCO2[	297	]=	1.439408159	;
    RnonCO2[	298	]=	1.453136523	;
    RnonCO2[	299	]=	1.4664178	;
    RnonCO2[	300	]=	1.479242532	;
    RnonCO2[	301	]=	1.491615636	;
    RnonCO2[	302	]=	1.503595947	;
    RnonCO2[	303	]=	1.51523466	;
    RnonCO2[	304	]=	1.52657726	;
    RnonCO2[	305	]=	1.537669318	;
    RnonCO2[	306	]=	1.548533208	;
    RnonCO2[	307	]=	1.559202988	;
    RnonCO2[	308	]=	1.569713895	;
    RnonCO2[	309	]=	1.580073196	;
    RnonCO2[	310	]=	1.590288078	;
    RnonCO2[	311	]=	1.600323109	;
    RnonCO2[	312	]=	1.610159707	;
    RnonCO2[	313	]=	1.619837346	;
    RnonCO2[	314	]=	1.629391907	;
    RnonCO2[	315	]=	1.638852659	;
    RnonCO2[	316	]=	1.648250563	;
    RnonCO2[	317	]=	1.657630141	;
    RnonCO2[	318	]=	1.6670167	;
    RnonCO2[	319	]=	1.676400373	;
    RnonCO2[	320	]=	1.685775083	;
    RnonCO2[	321	]=	1.695137707	;
    RnonCO2[	322	]=	1.704440811	;
    RnonCO2[	323	]=	1.713654237	;
    RnonCO2[	324	]=	1.722810499	;
    RnonCO2[	325	]=	1.731938449	;
    RnonCO2[	326	]=	1.741063394	;
    RnonCO2[	327	]=	1.750064593	;
    RnonCO2[	328	]=	1.758809303	;
    RnonCO2[	329	]=	1.767302441	;
    RnonCO2[	330	]=	1.775552491	;
    RnonCO2[	331	]=	1.783572411	;
    RnonCO2[	332	]=	1.791376182	;
    RnonCO2[	333	]=	1.798930436	;
    RnonCO2[	334	]=	1.806218138	;
    RnonCO2[	335	]=	1.813287315	;
    RnonCO2[	336	]=	1.820181953	;
    RnonCO2[	337	]=	1.826831551	;
    RnonCO2[	338	]=	1.833173544	;
    RnonCO2[	339	]=	1.839234344	;
    RnonCO2[	340	]=	1.845018602	;
    RnonCO2[	341	]=	1.850534021	;
    RnonCO2[	342	]=	1.855794452	;
    RnonCO2[	343	]=	1.860812544	;
    RnonCO2[	344	]=	1.865555655	;
    RnonCO2[	345	]=	1.870006103	;
    RnonCO2[	346	]=	1.874212898	;
    RnonCO2[	347	]=	1.878221365	;
    RnonCO2[	348	]=	1.882071015	;
    RnonCO2[	349	]=	1.885801052	;
    RnonCO2[	350	]=	1.88942665	;
    RnonCO2[	351	]=	1.892938893	;
    RnonCO2[	352	]=	1.896333232	;
    RnonCO2[	353	]=	1.899612841	;
    RnonCO2[	354	]=	1.902780512	;
    RnonCO2[	355	]=	1.905793058	;
    RnonCO2[	356	]=	1.908624471	;
    RnonCO2[	357	]=	1.91131432	;
    RnonCO2[	358	]=	1.9139028	;
    RnonCO2[	359	]=	1.916423314	;
    RnonCO2[	360	]=	1.918909097	;
    RnonCO2[	361	]=	1.921369147	;
    RnonCO2[	362	]=	1.923789075	;
    RnonCO2[	363	]=	1.926158439	;
    RnonCO2[	364	]=	1.928475755	;
    RnonCO2[	365	]=	1.930738396	;
    RnonCO2[	366	]=	1.932900186	;
    RnonCO2[	367	]=	1.934928556	;
    RnonCO2[	368	]=	1.936861883	;
    RnonCO2[	369	]=	1.93873657	;
    RnonCO2[	370	]=	1.940582911	;
    RnonCO2[	371	]=	1.942433919	;
    RnonCO2[	372	]=	1.944294426	;
    RnonCO2[	373	]=	1.946148568	;
    RnonCO2[	374	]=	1.947983081	;
    RnonCO2[	375	]=	1.949792732	;
    RnonCO2[	376	]=	1.951573997	;
    RnonCO2[	377	]=	1.953278219	;
    RnonCO2[	378	]=	1.954871552	;
    RnonCO2[	379	]=	1.956389263	;
    RnonCO2[	380	]=	1.95786746	;
    RnonCO2[	381	]=	1.959336631	;
    RnonCO2[	382	]=	1.960828259	;
    RnonCO2[	383	]=	1.962346787	;
    RnonCO2[	384	]=	1.963874424	;
    RnonCO2[	385	]=	1.965397015	;
    RnonCO2[	386	]=	1.966907883	;
    RnonCO2[	387	]=	1.968402531	;
    RnonCO2[	388	]=	1.969831054	;
    RnonCO2[	389	]=	1.971157707	;
    RnonCO2[	390	]=	1.972415861	;
    RnonCO2[	391	]=	1.973641986	;
    RnonCO2[	392	]=	1.974865408	;
    RnonCO2[	393	]=	1.976117073	;
    RnonCO2[	394	]=	1.977401679	;
    RnonCO2[	395	]=	1.978700111	;
    RnonCO2[	396	]=	1.979997095	;
    RnonCO2[	397	]=	1.981284588	;
    RnonCO2[	398	]=	1.982557769	;
    RnonCO2[	399	]=	1.983766077	;
    RnonCO2[	400	]=	1.984873087	;
    RnonCO2[	401	]=	1.985913082	;
    RnonCO2[	402	]=	1.98692261	;
    RnonCO2[	403	]=	1.987932088	;
    RnonCO2[	404	]=	1.988972526	;
    RnonCO2[	405	]=	1.990048399	;
    RnonCO2[	406	]=	1.99114149	;
    RnonCO2[	407	]=	1.992235256	;
    RnonCO2[	408	]=	1.993321658	;
    RnonCO2[	409	]=	1.994395277	;
    RnonCO2[	410	]=	1.995405994	;
    RnonCO2[	411	]=	1.996316622	;
    RnonCO2[	412	]=	1.997161586	;
    RnonCO2[	413	]=	1.997978112	;
    RnonCO2[	414	]=	1.998796488	;
    RnonCO2[	415	]=	1.999648281	;
    RnonCO2[	416	]=	2.000537974	;
    RnonCO2[	417	]=	2.001446506	;
    RnonCO2[	418	]=	2.002357761	;
    RnonCO2[	419	]=	2.003263291	;
    RnonCO2[	420	]=	2.004157412	;
    RnonCO2[	421	]=	2.004989355	;
    RnonCO2[	422	]=	2.005722844	;
    RnonCO2[	423	]=	2.006392207	;
    RnonCO2[	424	]=	2.007034119	;
    RnonCO2[	425	]=	2.007680016	;
    RnonCO2[	426	]=	2.008361173	;
    RnonCO2[	427	]=	2.009082032	;
    RnonCO2[	428	]=	2.009823302	;
    RnonCO2[	429	]=	2.010568601	;
    RnonCO2[	430	]=	2.011308801	;
    RnonCO2[	431	]=	2.012038565	;
    RnonCO2[	432	]=	2.012707434	;
    RnonCO2[	433	]=	2.013279591	;
    RnonCO2[	434	]=	2.013788209	;
    RnonCO2[	435	]=	2.014270824	;
    RnonCO2[	436	]=	2.014758333	;
    RnonCO2[	437	]=	2.015281983	;
    RnonCO2[	438	]=	2.015846152	;
    RnonCO2[	439	]=	2.016431385	;
    RnonCO2[	440	]=	2.017020925	;
    RnonCO2[	441	]=	2.017606065	;
    RnonCO2[	442	]=	2.018181042	;
    RnonCO2[	443	]=	2.0186957	;
    RnonCO2[	444	]=	2.019113579	;
    RnonCO2[	445	]=	2.019469239	;
    RnonCO2[	446	]=	2.019800183	;
    RnonCO2[	447	]=	2.020137026	;
    RnonCO2[	448	]=	2.020511572	;
    RnonCO2[	449	]=	2.020927347	;
    RnonCO2[	450	]=	2.021365049	;
    RnonCO2[	451	]=	2.021807854	;
    RnonCO2[	452	]=	2.022247194	;
    RnonCO2[	453	]=	2.022677498	;
    RnonCO2[	454	]=	2.023048353	;
    RnonCO2[	455	]=	2.023323831	;
    RnonCO2[	456	]=	2.023538377	;
    RnonCO2[	457	]=	2.023729451	;
    RnonCO2[	458	]=	2.023928212	;
    RnonCO2[	459	]=	2.024165643	;
    RnonCO2[	460	]=	2.024445263	;
    RnonCO2[	461	]=	2.024747932	;
    RnonCO2[	462	]=	2.025056215	;
    RnonCO2[	463	]=	2.025361736	;
    RnonCO2[	464	]=	2.025659461	;
    RnonCO2[	465	]=	2.02589831	;
    RnonCO2[	466	]=	2.02604306	;
    RnonCO2[	467	]=	2.026128158	;
    RnonCO2[	468	]=	2.026190832	;
    RnonCO2[	469	]=	2.026262078	;
    RnonCO2[	470	]=	2.026373171	;
    RnonCO2[	471	]=	2.026527398	;
    RnonCO2[	472	]=	2.026705477	;
    RnonCO2[	473	]=	2.026889701	;
    RnonCO2[	474	]=	2.027072258	;
    RnonCO2[	475	]=	2.027247324	;
    RnonCO2[	476	]=	2.027364745	;
    RnonCO2[	477	]=	2.027389328	;
    RnonCO2[	478	]=	2.027355508	;
    RnonCO2[	479	]=	2.027300724	;
    RnonCO2[	480	]=	2.027255689	;
    RnonCO2[	481	]=	2.027251024	;
    RnonCO2[	482	]=	2.027290799	;
    RnonCO2[	483	]=	2.02735461	;
    RnonCO2[	484	]=	2.027426215	;
    RnonCO2[	485	]=	2.027461889	;
    RnonCO2[	486	]=	2.027461889	;
    RnonCO2[	487	]=	2.027461889	;
    RnonCO2[	488	]=	2.027461889	;
    RnonCO2[	489	]=	2.027461889	;
    RnonCO2[	490	]=	2.027461889	;
    RnonCO2[	491	]=	2.027461889	;
    RnonCO2[	492	]=	2.027461889	;
    RnonCO2[	493	]=	2.027461889	;
    RnonCO2[	494	]=	2.027461889	;
    RnonCO2[	495	]=	2.027461889	;
    RnonCO2[	496	]=	2.027461889	;
    RnonCO2[	497	]=	2.027461889	;
    RnonCO2[	498	]=	2.027461889	;
    RnonCO2[	499	]=	2.027461889	;
    RnonCO2[	500	]=	2.027461889	;
    RnonCO2[	501	]=	2.027461889	;
    RnonCO2[	502	]=	2.027461889	;
    RnonCO2[	503	]=	2.027461889	;
    RnonCO2[	504	]=	2.027461889	;
    RnonCO2[	505	]=	2.027461889	;
    RnonCO2[	506	]=	2.027461889	;
    RnonCO2[	507	]=	2.027461889	;
    RnonCO2[	508	]=	2.027461889	;
    RnonCO2[	509	]=	2.027461889	;
    RnonCO2[	510	]=	2.027461889	;
    RnonCO2[	511	]=	2.027461889	;
    RnonCO2[	512	]=	2.027461889	;
    RnonCO2[	513	]=	2.027461889	;
    RnonCO2[	514	]=	2.027461889	;
    RnonCO2[	515	]=	2.027461889	;
    RnonCO2[	516	]=	2.027461889	;
    RnonCO2[	517	]=	2.027461889	;
    RnonCO2[	518	]=	2.027461889	;
    RnonCO2[	519	]=	2.027461889	;
    RnonCO2[	520	]=	2.027461889	;
    RnonCO2[	521	]=	2.027461889	;
    RnonCO2[	522	]=	2.027461889	;
    RnonCO2[	523	]=	2.027461889	;
    RnonCO2[	524	]=	2.027461889	;
    RnonCO2[	525	]=	2.027461889	;
    RnonCO2[	526	]=	2.027461889	;
    RnonCO2[	527	]=	2.027461889	;
    RnonCO2[	528	]=	2.027461889	;
    RnonCO2[	529	]=	2.027461889	;
    RnonCO2[	530	]=	2.027461889	;
    RnonCO2[	531	]=	2.027461889	;
    RnonCO2[	532	]=	2.027461889	;
    RnonCO2[	533	]=	2.027461889	;
    RnonCO2[	534	]=	2.027461889	;
    RnonCO2[	535	]=	2.027461889	;
    RnonCO2[	536	]=	2.027461889	;
    RnonCO2[	537	]=	2.027461889	;
    RnonCO2[	538	]=	2.027461889	;
    RnonCO2[	539	]=	2.027461889	;
    RnonCO2[	540	]=	2.027461889	;
    RnonCO2[	541	]=	2.027461889	;
    RnonCO2[	542	]=	2.027461889	;
    RnonCO2[	543	]=	2.027461889	;
    RnonCO2[	544	]=	2.027461889	;
    RnonCO2[	545	]=	2.027461889	;
    RnonCO2[	546	]=	2.027461889	;
    RnonCO2[	547	]=	2.027461889	;
    RnonCO2[	548	]=	2.027461889	;
    RnonCO2[	549	]=	2.027461889	;
    RnonCO2[	550	]=	2.027461889	;
    RnonCO2[	551	]=	2.027461889	;
    RnonCO2[	552	]=	2.027461889	;
    RnonCO2[	553	]=	2.027461889	;
    RnonCO2[	554	]=	2.027461889	;
    RnonCO2[	555	]=	2.027461889	;
    RnonCO2[	556	]=	2.027461889	;
    RnonCO2[	557	]=	2.027461889	;
    RnonCO2[	558	]=	2.027461889	;
    RnonCO2[	559	]=	2.027461889	;
    RnonCO2[	560	]=	2.027461889	;
    RnonCO2[	561	]=	2.027461889	;
    RnonCO2[	562	]=	2.027461889	;
    RnonCO2[	563	]=	2.027461889	;
    RnonCO2[	564	]=	2.027461889	;
    RnonCO2[	565	]=	2.027461889	;
    RnonCO2[	566	]=	2.027461889	;
    RnonCO2[	567	]=	2.027461889	;
    RnonCO2[	568	]=	2.027461889	;
    RnonCO2[	569	]=	2.027461889	;
    RnonCO2[	570	]=	2.027461889	;
    RnonCO2[	571	]=	2.027461889	;
    RnonCO2[	572	]=	2.027461889	;
    RnonCO2[	573	]=	2.027461889	;
    RnonCO2[	574	]=	2.027461889	;
    RnonCO2[	575	]=	2.027461889	;
    RnonCO2[	576	]=	2.027461889	;
    RnonCO2[	577	]=	2.027461889	;
    RnonCO2[	578	]=	2.027461889	;
    RnonCO2[	579	]=	2.027461889	;
    RnonCO2[	580	]=	2.027461889	;
    RnonCO2[	581	]=	2.027461889	;
    RnonCO2[	582	]=	2.027461889	;
    RnonCO2[	583	]=	2.027461889	;
    RnonCO2[	584	]=	2.027461889	;
    RnonCO2[	585	]=	2.027461889	;
    RnonCO2[	586	]=	2.027461889	;
    RnonCO2[	587	]=	2.027461889	;
    RnonCO2[	588	]=	2.027461889	;
    RnonCO2[	589	]=	2.027461889	;
    RnonCO2[	590	]=	2.027461889	;
    RnonCO2[	591	]=	2.027461889	;
    RnonCO2[	592	]=	2.027461889	;
    RnonCO2[	593	]=	2.027461889	;
    RnonCO2[	594	]=	2.027461889	;
    RnonCO2[	595	]=	2.027461889	;
    RnonCO2[	596	]=	2.027461889	;
    RnonCO2[	597	]=	2.027461889	;
    RnonCO2[	598	]=	2.027461889	;
    RnonCO2[	599	]=	2.027461889	;
    RnonCO2[	600	]=	2.027461889	;
    RnonCO2[	601	]=	2.027461889	;
    RnonCO2[	602	]=	2.027461889	;
    RnonCO2[	603	]=	2.027461889	;
    RnonCO2[	604	]=	2.027461889	;
    RnonCO2[	605	]=	2.027461889	;
    RnonCO2[	606	]=	2.027461889	;
    RnonCO2[	607	]=	2.027461889	;
    RnonCO2[	608	]=	2.027461889	;
    RnonCO2[	609	]=	2.027461889	;
    RnonCO2[	610	]=	2.027461889	;
    RnonCO2[	611	]=	2.027461889	;
    RnonCO2[	612	]=	2.027461889	;
    RnonCO2[	613	]=	2.027461889	;
    RnonCO2[	614	]=	2.027461889	;
    RnonCO2[	615	]=	2.027461889	;
    RnonCO2[	616	]=	2.027461889	;
    RnonCO2[	617	]=	2.027461889	;
    RnonCO2[	618	]=	2.027461889	;
    RnonCO2[	619	]=	2.027461889	;
    RnonCO2[	620	]=	2.027461889	;
    RnonCO2[	621	]=	2.027461889	;
    RnonCO2[	622	]=	2.027461889	;
    RnonCO2[	623	]=	2.027461889	;
    RnonCO2[	624	]=	2.027461889	;
    RnonCO2[	625	]=	2.027461889	;
    RnonCO2[	626	]=	2.027461889	;
    RnonCO2[	627	]=	2.027461889	;
    RnonCO2[	628	]=	2.027461889	;
    RnonCO2[	629	]=	2.027461889	;
    RnonCO2[	630	]=	2.027461889	;
    RnonCO2[	631	]=	2.027461889	;
    RnonCO2[	632	]=	2.027461889	;
    RnonCO2[	633	]=	2.027461889	;
    RnonCO2[	634	]=	2.027461889	;
    RnonCO2[	635	]=	2.027461889	;
    RnonCO2[	636	]=	2.027461889	;
    RnonCO2[	637	]=	2.027461889	;
    RnonCO2[	638	]=	2.027461889	;
    RnonCO2[	639	]=	2.027461889	;
    RnonCO2[	640	]=	2.027461889	;
    RnonCO2[	641	]=	2.027461889	;
    RnonCO2[	642	]=	2.027461889	;
    RnonCO2[	643	]=	2.027461889	;
    RnonCO2[	644	]=	2.027461889	;
    RnonCO2[	645	]=	2.027461889	;
    RnonCO2[	646	]=	2.027461889	;
    RnonCO2[	647	]=	2.027461889	;
    RnonCO2[	648	]=	2.027461889	;
    RnonCO2[	649	]=	2.027461889	;
    RnonCO2[	650	]=	2.027461889	;
    RnonCO2[	651	]=	2.027461889	;
    RnonCO2[	652	]=	2.027461889	;
    RnonCO2[	653	]=	2.027461889	;
    RnonCO2[	654	]=	2.027461889	;
    RnonCO2[	655	]=	2.027461889	;
    RnonCO2[	656	]=	2.027461889	;
    RnonCO2[	657	]=	2.027461889	;
    RnonCO2[	658	]=	2.027461889	;
    RnonCO2[	659	]=	2.027461889	;
    RnonCO2[	660	]=	2.027461889	;
    RnonCO2[	661	]=	2.027461889	;
    RnonCO2[	662	]=	2.027461889	;
    RnonCO2[	663	]=	2.027461889	;
    RnonCO2[	664	]=	2.027461889	;
    RnonCO2[	665	]=	2.027461889	;
    RnonCO2[	666	]=	2.027461889	;
    RnonCO2[	667	]=	2.027461889	;
    RnonCO2[	668	]=	2.027461889	;
    RnonCO2[	669	]=	2.027461889	;
    RnonCO2[	670	]=	2.027461889	;
    RnonCO2[	671	]=	2.027461889	;
    RnonCO2[	672	]=	2.027461889	;
    RnonCO2[	673	]=	2.027461889	;
    RnonCO2[	674	]=	2.027461889	;
    RnonCO2[	675	]=	2.027461889	;
    RnonCO2[	676	]=	2.027461889	;
    RnonCO2[	677	]=	2.027461889	;
    RnonCO2[	678	]=	2.027461889	;
    RnonCO2[	679	]=	2.027461889	;
    RnonCO2[	680	]=	2.027461889	;
    RnonCO2[	681	]=	2.027461889	;
    RnonCO2[	682	]=	2.027461889	;
    RnonCO2[	683	]=	2.027461889	;
    RnonCO2[	684	]=	2.027461889	;
    RnonCO2[	685	]=	2.027461889	;
    RnonCO2[	686	]=	2.027461889	;
    RnonCO2[	687	]=	2.027461889	;
    RnonCO2[	688	]=	2.027461889	;
    RnonCO2[	689	]=	2.027461889	;
    RnonCO2[	690	]=	2.027461889	;
    RnonCO2[	691	]=	2.027461889	;
    RnonCO2[	692	]=	2.027461889	;
    RnonCO2[	693	]=	2.027461889	;
    RnonCO2[	694	]=	2.027461889	;
    RnonCO2[	695	]=	2.027461889	;
    RnonCO2[	696	]=	2.027461889	;
    RnonCO2[	697	]=	2.027461889	;
    RnonCO2[	698	]=	2.027461889	;
    RnonCO2[	699	]=	2.027461889	;
    RnonCO2[	700	]=	2.027461889	;
    RnonCO2[	701	]=	2.027461889	;
    RnonCO2[	702	]=	2.027461889	;
    RnonCO2[	703	]=	2.027461889	;
    RnonCO2[	704	]=	2.027461889	;
    RnonCO2[	705	]=	2.027461889	;
    RnonCO2[	706	]=	2.027461889	;
    RnonCO2[	707	]=	2.027461889	;
    RnonCO2[	708	]=	2.027461889	;
    RnonCO2[	709	]=	2.027461889	;
    RnonCO2[	710	]=	2.027461889	;
    RnonCO2[	711	]=	2.027461889	;
    RnonCO2[	712	]=	2.027461889	;
    RnonCO2[	713	]=	2.027461889	;
    RnonCO2[	714	]=	2.027461889	;
    RnonCO2[	715	]=	2.027461889	;
    RnonCO2[	716	]=	2.027461889	;
    RnonCO2[	717	]=	2.027461889	;
    RnonCO2[	718	]=	2.027461889	;
    RnonCO2[	719	]=	2.027461889	;
    RnonCO2[	720	]=	2.027461889	;
    RnonCO2[	721	]=	2.027461889	;
    RnonCO2[	722	]=	2.027461889	;
    RnonCO2[	723	]=	2.027461889	;
    RnonCO2[	724	]=	2.027461889	;
    RnonCO2[	725	]=	2.027461889	;
    RnonCO2[	726	]=	2.027461889	;
    RnonCO2[	727	]=	2.027461889	;
    RnonCO2[	728	]=	2.027461889	;
    RnonCO2[	729	]=	2.027461889	;
    RnonCO2[	730	]=	2.027461889	;
    RnonCO2[	731	]=	2.027461889	;
    RnonCO2[	732	]=	2.027461889	;
    RnonCO2[	733	]=	2.027461889	;
    RnonCO2[	734	]=	2.027461889	;
    RnonCO2[	735	]=	2.027461889	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }

}

void setRnonCO2_RCP45_K(void)
{
    RnonCO2[	0	]=	-0.019988515	;
    RnonCO2[	1	]=	-0.005612142	;
    RnonCO2[	2	]=	0.008971239	;
    RnonCO2[	3	]=	0.009466172	;
    RnonCO2[	4	]=	0.009946833	;
    RnonCO2[	5	]=	0.010412166	;
    RnonCO2[	6	]=	0.010865438	;
    RnonCO2[	7	]=	0.011309666	;
    RnonCO2[	8	]=	0.011745593	;
    RnonCO2[	9	]=	0.012173039	;
    RnonCO2[	10	]=	0.012591208	;
    RnonCO2[	11	]=	0.012999626	;
    RnonCO2[	12	]=	0.013397144	;
    RnonCO2[	13	]=	0.013783559	;
    RnonCO2[	14	]=	0.014157995	;
    RnonCO2[	15	]=	0.014518817	;
    RnonCO2[	16	]=	0.014861789	;
    RnonCO2[	17	]=	0.015185328	;
    RnonCO2[	18	]=	0.015493438	;
    RnonCO2[	19	]=	0.015792171	;
    RnonCO2[	20	]=	0.01608699	;
    RnonCO2[	21	]=	0.016384013	;
    RnonCO2[	22	]=	0.016688621	;
    RnonCO2[	23	]=	0.017006739	;
    RnonCO2[	24	]=	0.017344141	;
    RnonCO2[	25	]=	0.017705767	;
    RnonCO2[	26	]=	0.018092359	;
    RnonCO2[	27	]=	0.018501885	;
    RnonCO2[	28	]=	0.01893258	;
    RnonCO2[	29	]=	0.019382558	;
    RnonCO2[	30	]=	0.019850303	;
    RnonCO2[	31	]=	0.020334085	;
    RnonCO2[	32	]=	0.020831989	;
    RnonCO2[	33	]=	0.021342706	;
    RnonCO2[	34	]=	0.02186457	;
    RnonCO2[	35	]=	0.022398729	;
    RnonCO2[	36	]=	0.022952686	;
    RnonCO2[	37	]=	0.023532049	;
    RnonCO2[	38	]=	0.024135881	;
    RnonCO2[	39	]=	0.024759327	;
    RnonCO2[	40	]=	0.025397837	;
    RnonCO2[	41	]=	0.02604713	;
    RnonCO2[	42	]=	0.026702498	;
    RnonCO2[	43	]=	0.02735936	;
    RnonCO2[	44	]=	0.028013477	;
    RnonCO2[	45	]=	0.028662413	;
    RnonCO2[	46	]=	0.029309198	;
    RnonCO2[	47	]=	0.029958961	;
    RnonCO2[	48	]=	0.030612845	;
    RnonCO2[	49	]=	0.031270152	;
    RnonCO2[	50	]=	0.03193112	;
    RnonCO2[	51	]=	0.032594644	;
    RnonCO2[	52	]=	0.033260857	;
    RnonCO2[	53	]=	0.033928967	;
    RnonCO2[	54	]=	0.034598246	;
    RnonCO2[	55	]=	0.035268641	;
    RnonCO2[	56	]=	0.035940357	;
    RnonCO2[	57	]=	0.036613717	;
    RnonCO2[	58	]=	0.037289228	;
    RnonCO2[	59	]=	0.037967253	;
    RnonCO2[	60	]=	0.038647628	;
    RnonCO2[	61	]=	0.039330893	;
    RnonCO2[	62	]=	0.040017299	;
    RnonCO2[	63	]=	0.040707068	;
    RnonCO2[	64	]=	0.041400385	;
    RnonCO2[	65	]=	0.042096128	;
    RnonCO2[	66	]=	0.042791515	;
    RnonCO2[	67	]=	0.04348473	;
    RnonCO2[	68	]=	0.044177707	;
    RnonCO2[	69	]=	0.044873365	;
    RnonCO2[	70	]=	0.045574528	;
    RnonCO2[	71	]=	0.04628438	;
    RnonCO2[	72	]=	0.047005924	;
    RnonCO2[	73	]=	0.047742202	;
    RnonCO2[	74	]=	0.048496247	;
    RnonCO2[	75	]=	0.049273302	;
    RnonCO2[	76	]=	0.050090919	;
    RnonCO2[	77	]=	0.050966437	;
    RnonCO2[	78	]=	0.051881638	;
    RnonCO2[	79	]=	0.052787675	;
    RnonCO2[	80	]=	0.053629807	;
    RnonCO2[	81	]=	0.054384454	;
    RnonCO2[	82	]=	0.055079735	;
    RnonCO2[	83	]=	0.055748092	;
    RnonCO2[	84	]=	0.056393965	;
    RnonCO2[	85	]=	0.057093398	;
    RnonCO2[	86	]=	0.05807606	;
    RnonCO2[	87	]=	0.059274862	;
    RnonCO2[	88	]=	0.060472717	;
    RnonCO2[	89	]=	0.061669627	;
    RnonCO2[	90	]=	0.062723294	;
    RnonCO2[	91	]=	0.063776572	;
    RnonCO2[	92	]=	0.064970976	;
    RnonCO2[	93	]=	0.066164765	;
    RnonCO2[	94	]=	0.067357381	;
    RnonCO2[	95	]=	0.06854924	;
    RnonCO2[	96	]=	0.069740139	;
    RnonCO2[	97	]=	0.070930146	;
    RnonCO2[	98	]=	0.072119404	;
    RnonCO2[	99	]=	0.073307822	;
    RnonCO2[	100	]=	0.074635976	;
    RnonCO2[	101	]=	0.075963149	;
    RnonCO2[	102	]=	0.077148556	;
    RnonCO2[	103	]=	0.078333267	;
    RnonCO2[	104	]=	0.079516971	;
    RnonCO2[	105	]=	0.080754531	;
    RnonCO2[	106	]=	0.081905797	;
    RnonCO2[	107	]=	0.083001419	;
    RnonCO2[	108	]=	0.084181461	;
    RnonCO2[	109	]=	0.085360786	;
    RnonCO2[	110	]=	0.086593261	;
    RnonCO2[	111	]=	0.087739428	;
    RnonCO2[	112	]=	0.088830817	;
    RnonCO2[	113	]=	0.090006409	;
    RnonCO2[	114	]=	0.091181226	;
    RnonCO2[	115	]=	0.092494155	;
    RnonCO2[	116	]=	0.093944335	;
    RnonCO2[	117	]=	0.095393111	;
    RnonCO2[	118	]=	0.096840323	;
    RnonCO2[	119	]=	0.098148223	;
    RnonCO2[	120	]=	0.09931678	;
    RnonCO2[	121	]=	0.100622634	;
    RnonCO2[	122	]=	0.101979664	;
    RnonCO2[	123	]=	0.10325049	;
    RnonCO2[	124	]=	0.104604961	;
    RnonCO2[	125	]=	0.106043011	;
    RnonCO2[	126	]=	0.107616808	;
    RnonCO2[	127	]=	0.109325606	;
    RnonCO2[	128	]=	0.110810739	;
    RnonCO2[	129	]=	0.112072699	;
    RnonCO2[	130	]=	0.113469426	;
    RnonCO2[	131	]=	0.115000677	;
    RnonCO2[	132	]=	0.116479164	;
    RnonCO2[	133	]=	0.117955956	;
    RnonCO2[	134	]=	0.119481632	;
    RnonCO2[	135	]=	0.121230683	;
    RnonCO2[	136	]=	0.123467298	;
    RnonCO2[	137	]=	0.125964505	;
    RnonCO2[	138	]=	0.128590857	;
    RnonCO2[	139	]=	0.131345679	;
    RnonCO2[	140	]=	0.134094266	;
    RnonCO2[	141	]=	0.136836274	;
    RnonCO2[	142	]=	0.139657159	;
    RnonCO2[	143	]=	0.142689092	;
    RnonCO2[	144	]=	0.145846541	;
    RnonCO2[	145	]=	0.148864539	;
    RnonCO2[	146	]=	0.151744205	;
    RnonCO2[	147	]=	0.154833698	;
    RnonCO2[	148	]=	0.158178102	;
    RnonCO2[	149	]=	0.161560167	;
    RnonCO2[	150	]=	0.165018225	;
    RnonCO2[	151	]=	0.168552404	;
    RnonCO2[	152	]=	0.172162279	;
    RnonCO2[	153	]=	0.175976823	;
    RnonCO2[	154	]=	0.179825831	;
    RnonCO2[	155	]=	0.18353714	;
    RnonCO2[	156	]=	0.18719586	;
    RnonCO2[	157	]=	0.190888601	;
    RnonCO2[	158	]=	0.194618313	;
    RnonCO2[	159	]=	0.198342475	;
    RnonCO2[	160	]=	0.202057589	;
    RnonCO2[	161	]=	0.20584786	;
    RnonCO2[	162	]=	0.209629466	;
    RnonCO2[	163	]=	0.213233356	;
    RnonCO2[	164	]=	0.216704098	;
    RnonCO2[	165	]=	0.220042715	;
    RnonCO2[	166	]=	0.223296521	;
    RnonCO2[	167	]=	0.226627686	;
    RnonCO2[	168	]=	0.230030664	;
    RnonCO2[	169	]=	0.233304361	;
    RnonCO2[	170	]=	0.236449311	;
    RnonCO2[	171	]=	0.239588758	;
    RnonCO2[	172	]=	0.24263915	;
    RnonCO2[	173	]=	0.245600759	;
    RnonCO2[	174	]=	0.248557521	;
    RnonCO2[	175	]=	0.251630431	;
    RnonCO2[	176	]=	0.254903022	;
    RnonCO2[	177	]=	0.258133328	;
    RnonCO2[	178	]=	0.26123828	;
    RnonCO2[	179	]=	0.264542	;
    RnonCO2[	180	]=	0.268044049	;
    RnonCO2[	181	]=	0.27165959	;
    RnonCO2[	182	]=	0.275506693	;
    RnonCO2[	183	]=	0.279465183	;
    RnonCO2[	184	]=	0.283533907	;
    RnonCO2[	185	]=	0.287746496	;
    RnonCO2[	186	]=	0.292103558	;
    RnonCO2[	187	]=	0.296886349	;
    RnonCO2[	188	]=	0.302089492	;
    RnonCO2[	189	]=	0.307309759	;
    RnonCO2[	190	]=	0.312629337	;
    RnonCO2[	191	]=	0.318245324	;
    RnonCO2[	192	]=	0.323988656	;
    RnonCO2[	193	]=	0.329826066	;
    RnonCO2[	194	]=	0.335923764	;
    RnonCO2[	195	]=	0.342309427	;
    RnonCO2[	196	]=	0.348815284	;
    RnonCO2[	197	]=	0.355439785	;
    RnonCO2[	198	]=	0.362318532	;
    RnonCO2[	199	]=	0.369551061	;
    RnonCO2[	200	]=	0.377072615	;
    RnonCO2[	201	]=	0.384665115	;
    RnonCO2[	202	]=	0.392331499	;
    RnonCO2[	203	]=	0.400273286	;
    RnonCO2[	204	]=	0.408559205	;
    RnonCO2[	205	]=	0.416991838	;
    RnonCO2[	206	]=	0.425389986	;
    RnonCO2[	207	]=	0.433949678	;
    RnonCO2[	208	]=	0.442740432	;
    RnonCO2[	209	]=	0.451573488	;
    RnonCO2[	210	]=	0.460373303	;
    RnonCO2[	211	]=	0.469303629	;
    RnonCO2[	212	]=	0.478507559	;
    RnonCO2[	213	]=	0.48782133	;
    RnonCO2[	214	]=	0.49689881	;
    RnonCO2[	215	]=	0.506302348	;
    RnonCO2[	216	]=	0.516911269	;
    RnonCO2[	217	]=	0.527818076	;
    RnonCO2[	218	]=	0.538162703	;
    RnonCO2[	219	]=	0.547403268	;
    RnonCO2[	220	]=	0.555524533	;
    RnonCO2[	221	]=	0.562888474	;
    RnonCO2[	222	]=	0.569356555	;
    RnonCO2[	223	]=	0.576908971	;
    RnonCO2[	224	]=	0.585481654	;
    RnonCO2[	225	]=	0.59287455	;
    RnonCO2[	226	]=	0.599146788	;
    RnonCO2[	227	]=	0.604130931	;
    RnonCO2[	228	]=	0.607750235	;
    RnonCO2[	229	]=	0.611664417	;
    RnonCO2[	230	]=	0.616444422	;
    RnonCO2[	231	]=	0.620912678	;
    RnonCO2[	232	]=	0.625821808	;
    RnonCO2[	233	]=	0.632177868	;
    RnonCO2[	234	]=	0.637926114	;
    RnonCO2[	235	]=	0.641532814	;
    RnonCO2[	236	]=	0.644675991	;
    RnonCO2[	237	]=	0.649064599	;
    RnonCO2[	238	]=	0.653980688	;
    RnonCO2[	239	]=	0.657858713	;
    RnonCO2[	240	]=	0.661298844	;
    RnonCO2[	241	]=	0.665634157	;
    RnonCO2[	242	]=	0.670529914	;
    RnonCO2[	243	]=	0.675587001	;
    RnonCO2[	244	]=	0.680736329	;
    RnonCO2[	245	]=	0.685870628	;
    RnonCO2[	246	]=	0.690993553	;
    RnonCO2[	247	]=	0.696130619	;
    RnonCO2[	248	]=	0.701297116	;
    RnonCO2[	249	]=	0.70649666	;
    RnonCO2[	250	]=	0.711736812	;
    RnonCO2[	251	]=	0.717011527	;
    RnonCO2[	252	]=	0.72230557	;
    RnonCO2[	253	]=	0.727608606	;
    RnonCO2[	254	]=	0.732913799	;
    RnonCO2[	255	]=	0.738215633	;
    RnonCO2[	256	]=	0.74348198	;
    RnonCO2[	257	]=	0.748612274	;
    RnonCO2[	258	]=	0.753553841	;
    RnonCO2[	259	]=	0.758340003	;
    RnonCO2[	260	]=	0.763000012	;
    RnonCO2[	261	]=	0.767562832	;
    RnonCO2[	262	]=	0.7720411	;
    RnonCO2[	263	]=	0.776435067	;
    RnonCO2[	264	]=	0.780747575	;
    RnonCO2[	265	]=	0.784984219	;
    RnonCO2[	266	]=	0.789149845	;
    RnonCO2[	267	]=	0.793173553	;
    RnonCO2[	268	]=	0.797002046	;
    RnonCO2[	269	]=	0.800669943	;
    RnonCO2[	270	]=	0.804204959	;
    RnonCO2[	271	]=	0.80763147	;
    RnonCO2[	272	]=	0.810974871	;
    RnonCO2[	273	]=	0.814243863	;
    RnonCO2[	274	]=	0.817436156	;
    RnonCO2[	275	]=	0.82055173	;
    RnonCO2[	276	]=	0.823594261	;
    RnonCO2[	277	]=	0.826514891	;
    RnonCO2[	278	]=	0.829241596	;
    RnonCO2[	279	]=	0.831770848	;
    RnonCO2[	280	]=	0.834137688	;
    RnonCO2[	281	]=	0.836370055	;
    RnonCO2[	282	]=	0.838492829	;
    RnonCO2[	283	]=	0.840530743	;
    RnonCO2[	284	]=	0.842492923	;
    RnonCO2[	285	]=	0.84437567	;
    RnonCO2[	286	]=	0.846180003	;
    RnonCO2[	287	]=	0.847843638	;
    RnonCO2[	288	]=	0.849308463	;
    RnonCO2[	289	]=	0.850557103	;
    RnonCO2[	290	]=	0.851584756	;
    RnonCO2[	291	]=	0.852426234	;
    RnonCO2[	292	]=	0.85310994	;
    RnonCO2[	293	]=	0.853661132	;
    RnonCO2[	294	]=	0.854105702	;
    RnonCO2[	295	]=	0.854453356	;
    RnonCO2[	296	]=	0.854701783	;
    RnonCO2[	297	]=	0.854837319	;
    RnonCO2[	298	]=	0.854850175	;
    RnonCO2[	299	]=	0.854747089	;
    RnonCO2[	300	]=	0.854505888	;
    RnonCO2[	301	]=	0.854116877	;
    RnonCO2[	302	]=	0.853609875	;
    RnonCO2[	303	]=	0.853008964	;
    RnonCO2[	304	]=	0.8523353	;
    RnonCO2[	305	]=	0.851610232	;
    RnonCO2[	306	]=	0.850839959	;
    RnonCO2[	307	]=	0.850000835	;
    RnonCO2[	308	]=	0.849074176	;
    RnonCO2[	309	]=	0.848064773	;
    RnonCO2[	310	]=	0.846977418	;
    RnonCO2[	311	]=	0.845788435	;
    RnonCO2[	312	]=	0.844486059	;
    RnonCO2[	313	]=	0.84310598	;
    RnonCO2[	314	]=	0.841720747	;
    RnonCO2[	315	]=	0.840386939	;
    RnonCO2[	316	]=	0.839115223	;
    RnonCO2[	317	]=	0.837993523	;
    RnonCO2[	318	]=	0.837088599	;
    RnonCO2[	319	]=	0.836371158	;
    RnonCO2[	320	]=	0.835818624	;
    RnonCO2[	321	]=	0.835411217	;
    RnonCO2[	322	]=	0.83510403	;
    RnonCO2[	323	]=	0.834866976	;
    RnonCO2[	324	]=	0.834710465	;
    RnonCO2[	325	]=	0.834640141	;
    RnonCO2[	326	]=	0.834659943	;
    RnonCO2[	327	]=	0.83477365	;
    RnonCO2[	328	]=	0.834971919	;
    RnonCO2[	329	]=	0.835236945	;
    RnonCO2[	330	]=	0.835556043	;
    RnonCO2[	331	]=	0.83592086	;
    RnonCO2[	332	]=	0.836324233	;
    RnonCO2[	333	]=	0.836732702	;
    RnonCO2[	334	]=	0.837126854	;
    RnonCO2[	335	]=	0.837525939	;
    RnonCO2[	336	]=	0.837944032	;
    RnonCO2[	337	]=	0.838420299	;
    RnonCO2[	338	]=	0.838988687	;
    RnonCO2[	339	]=	0.839635427	;
    RnonCO2[	340	]=	0.840337905	;
    RnonCO2[	341	]=	0.841079484	;
    RnonCO2[	342	]=	0.841848698	;
    RnonCO2[	343	]=	0.842635996	;
    RnonCO2[	344	]=	0.843406258	;
    RnonCO2[	345	]=	0.84413876	;
    RnonCO2[	346	]=	0.844851542	;
    RnonCO2[	347	]=	0.845557887	;
    RnonCO2[	348	]=	0.846268106	;
    RnonCO2[	349	]=	0.846993979	;
    RnonCO2[	350	]=	0.847732563	;
    RnonCO2[	351	]=	0.848470673	;
    RnonCO2[	352	]=	0.849199804	;
    RnonCO2[	353	]=	0.849915577	;
    RnonCO2[	354	]=	0.850614289	;
    RnonCO2[	355	]=	0.85126614	;
    RnonCO2[	356	]=	0.8518549	;
    RnonCO2[	357	]=	0.852402723	;
    RnonCO2[	358	]=	0.852925949	;
    RnonCO2[	359	]=	0.853437881	;
    RnonCO2[	360	]=	0.853952685	;
    RnonCO2[	361	]=	0.854469538	;
    RnonCO2[	362	]=	0.854977194	;
    RnonCO2[	363	]=	0.855468558	;
    RnonCO2[	364	]=	0.855940564	;
    RnonCO2[	365	]=	0.856390882	;
    RnonCO2[	366	]=	0.85679076	;
    RnonCO2[	367	]=	0.857124626	;
    RnonCO2[	368	]=	0.857415471	;
    RnonCO2[	369	]=	0.857680222	;
    RnonCO2[	370	]=	0.857932868	;
    RnonCO2[	371	]=	0.858188115	;
    RnonCO2[	372	]=	0.858445523	;
    RnonCO2[	373	]=	0.858694192	;
    RnonCO2[	374	]=	0.858927436	;
    RnonCO2[	375	]=	0.859142369	;
    RnonCO2[	376	]=	0.859336984	;
    RnonCO2[	377	]=	0.859482615	;
    RnonCO2[	378	]=	0.859563926	;
    RnonCO2[	379	]=	0.859603978	;
    RnonCO2[	380	]=	0.859620132	;
    RnonCO2[	381	]=	0.859626195	;
    RnonCO2[	382	]=	0.859636858	;
    RnonCO2[	383	]=	0.859651871	;
    RnonCO2[	384	]=	0.859660475	;
    RnonCO2[	385	]=	0.859662003	;
    RnonCO2[	386	]=	0.859662003	;
    RnonCO2[	387	]=	0.859662003	;
    RnonCO2[	388	]=	0.859662003	;
    RnonCO2[	389	]=	0.859662003	;
    RnonCO2[	390	]=	0.859662003	;
    RnonCO2[	391	]=	0.859662003	;
    RnonCO2[	392	]=	0.859662003	;
    RnonCO2[	393	]=	0.859662003	;
    RnonCO2[	394	]=	0.859662003	;
    RnonCO2[	395	]=	0.859662003	;
    RnonCO2[	396	]=	0.859662003	;
    RnonCO2[	397	]=	0.859662003	;
    RnonCO2[	398	]=	0.859662003	;
    RnonCO2[	399	]=	0.859662003	;
    RnonCO2[	400	]=	0.859662003	;
    RnonCO2[	401	]=	0.859662003	;
    RnonCO2[	402	]=	0.859662003	;
    RnonCO2[	403	]=	0.859662003	;
    RnonCO2[	404	]=	0.859662003	;
    RnonCO2[	405	]=	0.859662003	;
    RnonCO2[	406	]=	0.859662003	;
    RnonCO2[	407	]=	0.859662003	;
    RnonCO2[	408	]=	0.859662003	;
    RnonCO2[	409	]=	0.859662003	;
    RnonCO2[	410	]=	0.859662003	;
    RnonCO2[	411	]=	0.859662003	;
    RnonCO2[	412	]=	0.859662003	;
    RnonCO2[	413	]=	0.859662003	;
    RnonCO2[	414	]=	0.859662003	;
    RnonCO2[	415	]=	0.859662003	;
    RnonCO2[	416	]=	0.859662003	;
    RnonCO2[	417	]=	0.859662003	;
    RnonCO2[	418	]=	0.859662003	;
    RnonCO2[	419	]=	0.859662003	;
    RnonCO2[	420	]=	0.859662003	;
    RnonCO2[	421	]=	0.859662003	;
    RnonCO2[	422	]=	0.859662003	;
    RnonCO2[	423	]=	0.859662003	;
    RnonCO2[	424	]=	0.859662003	;
    RnonCO2[	425	]=	0.859662003	;
    RnonCO2[	426	]=	0.859662003	;
    RnonCO2[	427	]=	0.859662003	;
    RnonCO2[	428	]=	0.859662003	;
    RnonCO2[	429	]=	0.859662003	;
    RnonCO2[	430	]=	0.859662003	;
    RnonCO2[	431	]=	0.859662003	;
    RnonCO2[	432	]=	0.859662003	;
    RnonCO2[	433	]=	0.859662003	;
    RnonCO2[	434	]=	0.859662003	;
    RnonCO2[	435	]=	0.859662003	;
    RnonCO2[	436	]=	0.859662003	;
    RnonCO2[	437	]=	0.859662003	;
    RnonCO2[	438	]=	0.859662003	;
    RnonCO2[	439	]=	0.859662003	;
    RnonCO2[	440	]=	0.859662003	;
    RnonCO2[	441	]=	0.859662003	;
    RnonCO2[	442	]=	0.859662003	;
    RnonCO2[	443	]=	0.859662003	;
    RnonCO2[	444	]=	0.859662003	;
    RnonCO2[	445	]=	0.859662003	;
    RnonCO2[	446	]=	0.859662003	;
    RnonCO2[	447	]=	0.859662003	;
    RnonCO2[	448	]=	0.859662003	;
    RnonCO2[	449	]=	0.859662003	;
    RnonCO2[	450	]=	0.859662003	;
    RnonCO2[	451	]=	0.859662003	;
    RnonCO2[	452	]=	0.859662003	;
    RnonCO2[	453	]=	0.859662003	;
    RnonCO2[	454	]=	0.859662003	;
    RnonCO2[	455	]=	0.859662003	;
    RnonCO2[	456	]=	0.859662003	;
    RnonCO2[	457	]=	0.859662003	;
    RnonCO2[	458	]=	0.859662003	;
    RnonCO2[	459	]=	0.859662003	;
    RnonCO2[	460	]=	0.859662003	;
    RnonCO2[	461	]=	0.859662003	;
    RnonCO2[	462	]=	0.859662003	;
    RnonCO2[	463	]=	0.859662003	;
    RnonCO2[	464	]=	0.859662003	;
    RnonCO2[	465	]=	0.859662003	;
    RnonCO2[	466	]=	0.859662003	;
    RnonCO2[	467	]=	0.859662003	;
    RnonCO2[	468	]=	0.859662003	;
    RnonCO2[	469	]=	0.859662003	;
    RnonCO2[	470	]=	0.859662003	;
    RnonCO2[	471	]=	0.859662003	;
    RnonCO2[	472	]=	0.859662003	;
    RnonCO2[	473	]=	0.859662003	;
    RnonCO2[	474	]=	0.859662003	;
    RnonCO2[	475	]=	0.859662003	;
    RnonCO2[	476	]=	0.859662003	;
    RnonCO2[	477	]=	0.859662003	;
    RnonCO2[	478	]=	0.859662003	;
    RnonCO2[	479	]=	0.859662003	;
    RnonCO2[	480	]=	0.859662003	;
    RnonCO2[	481	]=	0.859662003	;
    RnonCO2[	482	]=	0.859662003	;
    RnonCO2[	483	]=	0.859662003	;
    RnonCO2[	484	]=	0.859662003	;
    RnonCO2[	485	]=	0.859662003	;
    RnonCO2[	486	]=	0.859662003	;
    RnonCO2[	487	]=	0.859662003	;
    RnonCO2[	488	]=	0.859662003	;
    RnonCO2[	489	]=	0.859662003	;
    RnonCO2[	490	]=	0.859662003	;
    RnonCO2[	491	]=	0.859662003	;
    RnonCO2[	492	]=	0.859662003	;
    RnonCO2[	493	]=	0.859662003	;
    RnonCO2[	494	]=	0.859662003	;
    RnonCO2[	495	]=	0.859662003	;
    RnonCO2[	496	]=	0.859662003	;
    RnonCO2[	497	]=	0.859662003	;
    RnonCO2[	498	]=	0.859662003	;
    RnonCO2[	499	]=	0.859662003	;
    RnonCO2[	500	]=	0.859662003	;
    RnonCO2[	501	]=	0.859662003	;
    RnonCO2[	502	]=	0.859662003	;
    RnonCO2[	503	]=	0.859662003	;
    RnonCO2[	504	]=	0.859662003	;
    RnonCO2[	505	]=	0.859662003	;
    RnonCO2[	506	]=	0.859662003	;
    RnonCO2[	507	]=	0.859662003	;
    RnonCO2[	508	]=	0.859662003	;
    RnonCO2[	509	]=	0.859662003	;
    RnonCO2[	510	]=	0.859662003	;
    RnonCO2[	511	]=	0.859662003	;
    RnonCO2[	512	]=	0.859662003	;
    RnonCO2[	513	]=	0.859662003	;
    RnonCO2[	514	]=	0.859662003	;
    RnonCO2[	515	]=	0.859662003	;
    RnonCO2[	516	]=	0.859662003	;
    RnonCO2[	517	]=	0.859662003	;
    RnonCO2[	518	]=	0.859662003	;
    RnonCO2[	519	]=	0.859662003	;
    RnonCO2[	520	]=	0.859662003	;
    RnonCO2[	521	]=	0.859662003	;
    RnonCO2[	522	]=	0.859662003	;
    RnonCO2[	523	]=	0.859662003	;
    RnonCO2[	524	]=	0.859662003	;
    RnonCO2[	525	]=	0.859662003	;
    RnonCO2[	526	]=	0.859662003	;
    RnonCO2[	527	]=	0.859662003	;
    RnonCO2[	528	]=	0.859662003	;
    RnonCO2[	529	]=	0.859662003	;
    RnonCO2[	530	]=	0.859662003	;
    RnonCO2[	531	]=	0.859662003	;
    RnonCO2[	532	]=	0.859662003	;
    RnonCO2[	533	]=	0.859662003	;
    RnonCO2[	534	]=	0.859662003	;
    RnonCO2[	535	]=	0.859662003	;
    RnonCO2[	536	]=	0.859662003	;
    RnonCO2[	537	]=	0.859662003	;
    RnonCO2[	538	]=	0.859662003	;
    RnonCO2[	539	]=	0.859662003	;
    RnonCO2[	540	]=	0.859662003	;
    RnonCO2[	541	]=	0.859662003	;
    RnonCO2[	542	]=	0.859662003	;
    RnonCO2[	543	]=	0.859662003	;
    RnonCO2[	544	]=	0.859662003	;
    RnonCO2[	545	]=	0.859662003	;
    RnonCO2[	546	]=	0.859662003	;
    RnonCO2[	547	]=	0.859662003	;
    RnonCO2[	548	]=	0.859662003	;
    RnonCO2[	549	]=	0.859662003	;
    RnonCO2[	550	]=	0.859662003	;
    RnonCO2[	551	]=	0.859662003	;
    RnonCO2[	552	]=	0.859662003	;
    RnonCO2[	553	]=	0.859662003	;
    RnonCO2[	554	]=	0.859662003	;
    RnonCO2[	555	]=	0.859662003	;
    RnonCO2[	556	]=	0.859662003	;
    RnonCO2[	557	]=	0.859662003	;
    RnonCO2[	558	]=	0.859662003	;
    RnonCO2[	559	]=	0.859662003	;
    RnonCO2[	560	]=	0.859662003	;
    RnonCO2[	561	]=	0.859662003	;
    RnonCO2[	562	]=	0.859662003	;
    RnonCO2[	563	]=	0.859662003	;
    RnonCO2[	564	]=	0.859662003	;
    RnonCO2[	565	]=	0.859662003	;
    RnonCO2[	566	]=	0.859662003	;
    RnonCO2[	567	]=	0.859662003	;
    RnonCO2[	568	]=	0.859662003	;
    RnonCO2[	569	]=	0.859662003	;
    RnonCO2[	570	]=	0.859662003	;
    RnonCO2[	571	]=	0.859662003	;
    RnonCO2[	572	]=	0.859662003	;
    RnonCO2[	573	]=	0.859662003	;
    RnonCO2[	574	]=	0.859662003	;
    RnonCO2[	575	]=	0.859662003	;
    RnonCO2[	576	]=	0.859662003	;
    RnonCO2[	577	]=	0.859662003	;
    RnonCO2[	578	]=	0.859662003	;
    RnonCO2[	579	]=	0.859662003	;
    RnonCO2[	580	]=	0.859662003	;
    RnonCO2[	581	]=	0.859662003	;
    RnonCO2[	582	]=	0.859662003	;
    RnonCO2[	583	]=	0.859662003	;
    RnonCO2[	584	]=	0.859662003	;
    RnonCO2[	585	]=	0.859662003	;
    RnonCO2[	586	]=	0.859662003	;
    RnonCO2[	587	]=	0.859662003	;
    RnonCO2[	588	]=	0.859662003	;
    RnonCO2[	589	]=	0.859662003	;
    RnonCO2[	590	]=	0.859662003	;
    RnonCO2[	591	]=	0.859662003	;
    RnonCO2[	592	]=	0.859662003	;
    RnonCO2[	593	]=	0.859662003	;
    RnonCO2[	594	]=	0.859662003	;
    RnonCO2[	595	]=	0.859662003	;
    RnonCO2[	596	]=	0.859662003	;
    RnonCO2[	597	]=	0.859662003	;
    RnonCO2[	598	]=	0.859662003	;
    RnonCO2[	599	]=	0.859662003	;
    RnonCO2[	600	]=	0.859662003	;
    RnonCO2[	601	]=	0.859662003	;
    RnonCO2[	602	]=	0.859662003	;
    RnonCO2[	603	]=	0.859662003	;
    RnonCO2[	604	]=	0.859662003	;
    RnonCO2[	605	]=	0.859662003	;
    RnonCO2[	606	]=	0.859662003	;
    RnonCO2[	607	]=	0.859662003	;
    RnonCO2[	608	]=	0.859662003	;
    RnonCO2[	609	]=	0.859662003	;
    RnonCO2[	610	]=	0.859662003	;
    RnonCO2[	611	]=	0.859662003	;
    RnonCO2[	612	]=	0.859662003	;
    RnonCO2[	613	]=	0.859662003	;
    RnonCO2[	614	]=	0.859662003	;
    RnonCO2[	615	]=	0.859662003	;
    RnonCO2[	616	]=	0.859662003	;
    RnonCO2[	617	]=	0.859662003	;
    RnonCO2[	618	]=	0.859662003	;
    RnonCO2[	619	]=	0.859662003	;
    RnonCO2[	620	]=	0.859662003	;
    RnonCO2[	621	]=	0.859662003	;
    RnonCO2[	622	]=	0.859662003	;
    RnonCO2[	623	]=	0.859662003	;
    RnonCO2[	624	]=	0.859662003	;
    RnonCO2[	625	]=	0.859662003	;
    RnonCO2[	626	]=	0.859662003	;
    RnonCO2[	627	]=	0.859662003	;
    RnonCO2[	628	]=	0.859662003	;
    RnonCO2[	629	]=	0.859662003	;
    RnonCO2[	630	]=	0.859662003	;
    RnonCO2[	631	]=	0.859662003	;
    RnonCO2[	632	]=	0.859662003	;
    RnonCO2[	633	]=	0.859662003	;
    RnonCO2[	634	]=	0.859662003	;
    RnonCO2[	635	]=	0.859662003	;
    RnonCO2[	636	]=	0.859662003	;
    RnonCO2[	637	]=	0.859662003	;
    RnonCO2[	638	]=	0.859662003	;
    RnonCO2[	639	]=	0.859662003	;
    RnonCO2[	640	]=	0.859662003	;
    RnonCO2[	641	]=	0.859662003	;
    RnonCO2[	642	]=	0.859662003	;
    RnonCO2[	643	]=	0.859662003	;
    RnonCO2[	644	]=	0.859662003	;
    RnonCO2[	645	]=	0.859662003	;
    RnonCO2[	646	]=	0.859662003	;
    RnonCO2[	647	]=	0.859662003	;
    RnonCO2[	648	]=	0.859662003	;
    RnonCO2[	649	]=	0.859662003	;
    RnonCO2[	650	]=	0.859662003	;
    RnonCO2[	651	]=	0.859662003	;
    RnonCO2[	652	]=	0.859662003	;
    RnonCO2[	653	]=	0.859662003	;
    RnonCO2[	654	]=	0.859662003	;
    RnonCO2[	655	]=	0.859662003	;
    RnonCO2[	656	]=	0.859662003	;
    RnonCO2[	657	]=	0.859662003	;
    RnonCO2[	658	]=	0.859662003	;
    RnonCO2[	659	]=	0.859662003	;
    RnonCO2[	660	]=	0.859662003	;
    RnonCO2[	661	]=	0.859662003	;
    RnonCO2[	662	]=	0.859662003	;
    RnonCO2[	663	]=	0.859662003	;
    RnonCO2[	664	]=	0.859662003	;
    RnonCO2[	665	]=	0.859662003	;
    RnonCO2[	666	]=	0.859662003	;
    RnonCO2[	667	]=	0.859662003	;
    RnonCO2[	668	]=	0.859662003	;
    RnonCO2[	669	]=	0.859662003	;
    RnonCO2[	670	]=	0.859662003	;
    RnonCO2[	671	]=	0.859662003	;
    RnonCO2[	672	]=	0.859662003	;
    RnonCO2[	673	]=	0.859662003	;
    RnonCO2[	674	]=	0.859662003	;
    RnonCO2[	675	]=	0.859662003	;
    RnonCO2[	676	]=	0.859662003	;
    RnonCO2[	677	]=	0.859662003	;
    RnonCO2[	678	]=	0.859662003	;
    RnonCO2[	679	]=	0.859662003	;
    RnonCO2[	680	]=	0.859662003	;
    RnonCO2[	681	]=	0.859662003	;
    RnonCO2[	682	]=	0.859662003	;
    RnonCO2[	683	]=	0.859662003	;
    RnonCO2[	684	]=	0.859662003	;
    RnonCO2[	685	]=	0.859662003	;
    RnonCO2[	686	]=	0.859662003	;
    RnonCO2[	687	]=	0.859662003	;
    RnonCO2[	688	]=	0.859662003	;
    RnonCO2[	689	]=	0.859662003	;
    RnonCO2[	690	]=	0.859662003	;
    RnonCO2[	691	]=	0.859662003	;
    RnonCO2[	692	]=	0.859662003	;
    RnonCO2[	693	]=	0.859662003	;
    RnonCO2[	694	]=	0.859662003	;
    RnonCO2[	695	]=	0.859662003	;
    RnonCO2[	696	]=	0.859662003	;
    RnonCO2[	697	]=	0.859662003	;
    RnonCO2[	698	]=	0.859662003	;
    RnonCO2[	699	]=	0.859662003	;
    RnonCO2[	700	]=	0.859662003	;
    RnonCO2[	701	]=	0.859662003	;
    RnonCO2[	702	]=	0.859662003	;
    RnonCO2[	703	]=	0.859662003	;
    RnonCO2[	704	]=	0.859662003	;
    RnonCO2[	705	]=	0.859662003	;
    RnonCO2[	706	]=	0.859662003	;
    RnonCO2[	707	]=	0.859662003	;
    RnonCO2[	708	]=	0.859662003	;
    RnonCO2[	709	]=	0.859662003	;
    RnonCO2[	710	]=	0.859662003	;
    RnonCO2[	711	]=	0.859662003	;
    RnonCO2[	712	]=	0.859662003	;
    RnonCO2[	713	]=	0.859662003	;
    RnonCO2[	714	]=	0.859662003	;
    RnonCO2[	715	]=	0.859662003	;
    RnonCO2[	716	]=	0.859662003	;
    RnonCO2[	717	]=	0.859662003	;
    RnonCO2[	718	]=	0.859662003	;
    RnonCO2[	719	]=	0.859662003	;
    RnonCO2[	720	]=	0.859662003	;
    RnonCO2[	721	]=	0.859662003	;
    RnonCO2[	722	]=	0.859662003	;
    RnonCO2[	723	]=	0.859662003	;
    RnonCO2[	724	]=	0.859662003	;
    RnonCO2[	725	]=	0.859662003	;
    RnonCO2[	726	]=	0.859662003	;
    RnonCO2[	727	]=	0.859662003	;
    RnonCO2[	728	]=	0.859662003	;
    RnonCO2[	729	]=	0.859662003	;
    RnonCO2[	730	]=	0.859662003	;
    RnonCO2[	731	]=	0.859662003	;
    RnonCO2[	732	]=	0.859662003	;
    RnonCO2[	733	]=	0.859662003	;
    RnonCO2[	734	]=	0.859662003	;
    RnonCO2[	735	]=	0.859662003	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
    
    
}



void setRnonCO2_RCP60K(void)
{
    RnonCO2[	0	]=	-0.01999748	;
    RnonCO2[	1	]=	-0.00561466	;
    RnonCO2[	2	]=	0.00897526	;
    RnonCO2[	3	]=	0.00947042	;
    RnonCO2[	4	]=	0.00995129	;
    RnonCO2[	5	]=	0.01041683	;
    RnonCO2[	6	]=	0.01087031	;
    RnonCO2[	7	]=	0.01131474	;
    RnonCO2[	8	]=	0.01175086	;
    RnonCO2[	9	]=	0.01217850	;
    RnonCO2[	10	]=	0.01259685	;
    RnonCO2[	11	]=	0.01300545	;
    RnonCO2[	12	]=	0.01340315	;
    RnonCO2[	13	]=	0.01378974	;
    RnonCO2[	14	]=	0.01416434	;
    RnonCO2[	15	]=	0.01452533	;
    RnonCO2[	16	]=	0.01486845	;
    RnonCO2[	17	]=	0.01519214	;
    RnonCO2[	18	]=	0.01550038	;
    RnonCO2[	19	]=	0.01579925	;
    RnonCO2[	20	]=	0.01609420	;
    RnonCO2[	21	]=	0.01639136	;
    RnonCO2[	22	]=	0.01669610	;
    RnonCO2[	23	]=	0.01701436	;
    RnonCO2[	24	]=	0.01735192	;
    RnonCO2[	25	]=	0.01771370	;
    RnonCO2[	26	]=	0.01810047	;
    RnonCO2[	27	]=	0.01851018	;
    RnonCO2[	28	]=	0.01894107	;
    RnonCO2[	29	]=	0.01939125	;
    RnonCO2[	30	]=	0.01985920	;
    RnonCO2[	31	]=	0.02034320	;
    RnonCO2[	32	]=	0.02084133	;
    RnonCO2[	33	]=	0.02135227	;
    RnonCO2[	34	]=	0.02187437	;
    RnonCO2[	35	]=	0.02240877	;
    RnonCO2[	36	]=	0.02296298	;
    RnonCO2[	37	]=	0.02354260	;
    RnonCO2[	38	]=	0.02414670	;
    RnonCO2[	39	]=	0.02477043	;
    RnonCO2[	40	]=	0.02540922	;
    RnonCO2[	41	]=	0.02605881	;
    RnonCO2[	42	]=	0.02671447	;
    RnonCO2[	43	]=	0.02737163	;
    RnonCO2[	44	]=	0.02802604	;
    RnonCO2[	45	]=	0.02867526	;
    RnonCO2[	46	]=	0.02932234	;
    RnonCO2[	47	]=	0.02997239	;
    RnonCO2[	48	]=	0.03062657	;
    RnonCO2[	49	]=	0.03128417	;
    RnonCO2[	50	]=	0.03194544	;
    RnonCO2[	51	]=	0.03260926	;
    RnonCO2[	52	]=	0.03327577	;
    RnonCO2[	53	]=	0.03394418	;
    RnonCO2[	54	]=	0.03461376	;
    RnonCO2[	55	]=	0.03528445	;
    RnonCO2[	56	]=	0.03595647	;
    RnonCO2[	57	]=	0.03663013	;
    RnonCO2[	58	]=	0.03730595	;
    RnonCO2[	59	]=	0.03798427	;
    RnonCO2[	60	]=	0.03866496	;
    RnonCO2[	61	]=	0.03934853	;
    RnonCO2[	62	]=	0.04003524	;
    RnonCO2[	63	]=	0.04072532	;
    RnonCO2[	64	]=	0.04141895	;
    RnonCO2[	65	]=	0.04211500	;
    RnonCO2[	66	]=	0.04281070	;
    RnonCO2[	67	]=	0.04350423	;
    RnonCO2[	68	]=	0.04419751	;
    RnonCO2[	69	]=	0.04489348	;
    RnonCO2[	70	]=	0.04559496	;
    RnonCO2[	71	]=	0.04630513	;
    RnonCO2[	72	]=	0.04702700	;
    RnonCO2[	73	]=	0.04776361	;
    RnonCO2[	74	]=	0.04851799	;
    RnonCO2[	75	]=	0.04929539	;
    RnonCO2[	76	]=	0.05011338	;
    RnonCO2[	77	]=	0.05098929	;
    RnonCO2[	78	]=	0.05190490	;
    RnonCO2[	79	]=	0.05281134	;
    RnonCO2[	80	]=	0.05365385	;
    RnonCO2[	81	]=	0.05440884	;
    RnonCO2[	82	]=	0.05510443	;
    RnonCO2[	83	]=	0.05577309	;
    RnonCO2[	84	]=	0.05641925	;
    RnonCO2[	85	]=	0.05711900	;
    RnonCO2[	86	]=	0.05810210	;
    RnonCO2[	87	]=	0.05930144	;
    RnonCO2[	88	]=	0.06049983	;
    RnonCO2[	89	]=	0.06169728	;
    RnonCO2[	90	]=	0.06275142	;
    RnonCO2[	91	]=	0.06380517	;
    RnonCO2[	92	]=	0.06500011	;
    RnonCO2[	93	]=	0.06619443	;
    RnonCO2[	94	]=	0.06738758	;
    RnonCO2[	95	]=	0.06857997	;
    RnonCO2[	96	]=	0.06977141	;
    RnonCO2[	97	]=	0.07096195	;
    RnonCO2[	98	]=	0.07215174	;
    RnonCO2[	99	]=	0.07334069	;
    RnonCO2[	100	]=	0.07466944	;
    RnonCO2[	101	]=	0.07599721	;
    RnonCO2[	102	]=	0.07718314	;
    RnonCO2[	103	]=	0.07836839	;
    RnonCO2[	104	]=	0.07955262	;
    RnonCO2[	105	]=	0.08079074	;
    RnonCO2[	106	]=	0.08194252	;
    RnonCO2[	107	]=	0.08303863	;
    RnonCO2[	108	]=	0.08421920	;
    RnonCO2[	109	]=	0.08539906	;
    RnonCO2[	110	]=	0.08663208	;
    RnonCO2[	111	]=	0.08777876	;
    RnonCO2[	112	]=	0.08887064	;
    RnonCO2[	113	]=	0.09004676	;
    RnonCO2[	114	]=	0.09122211	;
    RnonCO2[	115	]=	0.09253562	;
    RnonCO2[	116	]=	0.09398645	;
    RnonCO2[	117	]=	0.09543588	;
    RnonCO2[	118	]=	0.09688374	;
    RnonCO2[	119	]=	0.09819223	;
    RnonCO2[	120	]=	0.09936131	;
    RnonCO2[	121	]=	0.10066775	;
    RnonCO2[	122	]=	0.10202539	;
    RnonCO2[	123	]=	0.10329678	;
    RnonCO2[	124	]=	0.10465186	;
    RnonCO2[	125	]=	0.10609055	;
    RnonCO2[	126	]=	0.10766506	;
    RnonCO2[	127	]=	0.10937462	;
    RnonCO2[	128	]=	0.11086042	;
    RnonCO2[	129	]=	0.11212295	;
    RnonCO2[	130	]=	0.11352030	;
    RnonCO2[	131	]=	0.11505224	;
    RnonCO2[	132	]=	0.11653139	;
    RnonCO2[	133	]=	0.11800884	;
    RnonCO2[	134	]=	0.11953520	;
    RnonCO2[	135	]=	0.12128504	;
    RnonCO2[	136	]=	0.12352265	;
    RnonCO2[	137	]=	0.12602098	;
    RnonCO2[	138	]=	0.12864851	;
    RnonCO2[	139	]=	0.13140457	;
    RnonCO2[	140	]=	0.13415439	;
    RnonCO2[	141	]=	0.13689762	;
    RnonCO2[	142	]=	0.13971977	;
    RnonCO2[	143	]=	0.14275307	;
    RnonCO2[	144	]=	0.14591193	;
    RnonCO2[	145	]=	0.14893128	;
    RnonCO2[	146	]=	0.15181224	;
    RnonCO2[	147	]=	0.15490312	;
    RnonCO2[	148	]=	0.15824902	;
    RnonCO2[	149	]=	0.16163260	;
    RnonCO2[	150	]=	0.16509221	;
    RnonCO2[	151	]=	0.16862797	;
    RnonCO2[	152	]=	0.17223947	;
    RnonCO2[	153	]=	0.17605572	;
    RnonCO2[	154	]=	0.17990645	;
    RnonCO2[	155	]=	0.18361943	;
    RnonCO2[	156	]=	0.18727979	;
    RnonCO2[	157	]=	0.19097418	;
    RnonCO2[	158	]=	0.19470557	;
    RnonCO2[	159	]=	0.19843140	;
    RnonCO2[	160	]=	0.20214818	;
    RnonCO2[	161	]=	0.20594015	;
    RnonCO2[	162	]=	0.20972345	;
    RnonCO2[	163	]=	0.21332896	;
    RnonCO2[	164	]=	0.21680125	;
    RnonCO2[	165	]=	0.22014137	;
    RnonCO2[	166	]=	0.22339663	;
    RnonCO2[	167	]=	0.22672929	;
    RnonCO2[	168	]=	0.23013380	;
    RnonCO2[	169	]=	0.23340896	;
    RnonCO2[	170	]=	0.23655532	;
    RnonCO2[	171	]=	0.23969617	;
    RnonCO2[	172	]=	0.24274793	;
    RnonCO2[	173	]=	0.24571087	;
    RnonCO2[	174	]=	0.24866896	;
    RnonCO2[	175	]=	0.25174325	;
    RnonCO2[	176	]=	0.25501730	;
    RnonCO2[	177	]=	0.25824906	;
    RnonCO2[	178	]=	0.26135540	;
    RnonCO2[	179	]=	0.26466060	;
    RnonCO2[	180	]=	0.26816422	;
    RnonCO2[	181	]=	0.27178139	;
    RnonCO2[	182	]=	0.27563021	;
    RnonCO2[	183	]=	0.27959048	;
    RnonCO2[	184	]=	0.28366103	;
    RnonCO2[	185	]=	0.28787550	;
    RnonCO2[	186	]=	0.29223452	;
    RnonCO2[	187	]=	0.29701945	;
    RnonCO2[	188	]=	0.30222493	;
    RnonCO2[	189	]=	0.30744754	;
    RnonCO2[	190	]=	0.31276950	;
    RnonCO2[	191	]=	0.31838800	;
    RnonCO2[	192	]=	0.32413391	;
    RnonCO2[	193	]=	0.32997394	;
    RnonCO2[	194	]=	0.33607437	;
    RnonCO2[	195	]=	0.34246290	;
    RnonCO2[	196	]=	0.34897167	;
    RnonCO2[	197	]=	0.35559914	;
    RnonCO2[	198	]=	0.36248097	;
    RnonCO2[	199	]=	0.36971674	;
    RnonCO2[	200	]=	0.37724167	;
    RnonCO2[	201	]=	0.38483757	;
    RnonCO2[	202	]=	0.39250740	;
    RnonCO2[	203	]=	0.40045274	;
    RnonCO2[	204	]=	0.40874238	;
    RnonCO2[	205	]=	0.41717879	;
    RnonCO2[	206	]=	0.42558070	;
    RnonCO2[	207	]=	0.43414423	;
    RnonCO2[	208	]=	0.44293893	;
    RnonCO2[	209	]=	0.45177595	;
    RnonCO2[	210	]=	0.46057971	;
    RnonCO2[	211	]=	0.46951404	;
    RnonCO2[	212	]=	0.47872209	;
    RnonCO2[	213	]=	0.48804004	;
    RnonCO2[	214	]=	0.49712159	;
    RnonCO2[	215	]=	0.50652934	;
    RnonCO2[	216	]=	0.51714302	;
    RnonCO2[	217	]=	0.52805472	;
    RnonCO2[	218	]=	0.53840398	;
    RnonCO2[	219	]=	0.54764869	;
    RnonCO2[	220	]=	0.55577359	;
    RnonCO2[	221	]=	0.56314084	;
    RnonCO2[	222	]=	0.56961182	;
    RnonCO2[	223	]=	0.57716762	;
    RnonCO2[	224	]=	0.58574415	;
    RnonCO2[	225	]=	0.59314036	;
    RnonCO2[	226	]=	0.59941541	;
    RnonCO2[	227	]=	0.60440178	;
    RnonCO2[	228	]=	0.60802271	;
    RnonCO2[	229	]=	0.61193865	;
    RnonCO2[	230	]=	0.61672080	;
    RnonCO2[	231	]=	0.62119106	;
    RnonCO2[	232	]=	0.62610239	;
    RnonCO2[	233	]=	0.63246130	;
    RnonCO2[	234	]=	0.63821212	;
    RnonCO2[	235	]=	0.64182044	;
    RnonCO2[	236	]=	0.64496502	;
    RnonCO2[	237	]=	0.64935560	;
    RnonCO2[	238	]=	0.65427389	;
    RnonCO2[	239	]=	0.65815366	;
    RnonCO2[	240	]=	0.66159533	;
    RnonCO2[	241	]=	0.66593407	;
    RnonCO2[	242	]=	0.67090356	;
    RnonCO2[	243	]=	0.67616707	;
    RnonCO2[	244	]=	0.68165968	;
    RnonCO2[	245	]=	0.68727911	;
    RnonCO2[	246	]=	0.69301982	;
    RnonCO2[	247	]=	0.69861598	;
    RnonCO2[	248	]=	0.70381722	;
    RnonCO2[	249	]=	0.70866248	;
    RnonCO2[	250	]=	0.71319036	;
    RnonCO2[	251	]=	0.71742358	;
    RnonCO2[	252	]=	0.72137337	;
    RnonCO2[	253	]=	0.72505338	;
    RnonCO2[	254	]=	0.72847874	;
    RnonCO2[	255	]=	0.73166410	;
    RnonCO2[	256	]=	0.73459461	;
    RnonCO2[	257	]=	0.73747758	;
    RnonCO2[	258	]=	0.74054455	;
    RnonCO2[	259	]=	0.74380098	;
    RnonCO2[	260	]=	0.74725039	;
    RnonCO2[	261	]=	0.75089785	;
    RnonCO2[	262	]=	0.75473411	;
    RnonCO2[	263	]=	0.75873925	;
    RnonCO2[	264	]=	0.76289762	;
    RnonCO2[	265	]=	0.76719757	;
    RnonCO2[	266	]=	0.77163097	;
    RnonCO2[	267	]=	0.77617182	;
    RnonCO2[	268	]=	0.78080405	;
    RnonCO2[	269	]=	0.78554076	;
    RnonCO2[	270	]=	0.79039073	;
    RnonCO2[	271	]=	0.79536083	;
    RnonCO2[	272	]=	0.80046009	;
    RnonCO2[	273	]=	0.80568270	;
    RnonCO2[	274	]=	0.81101266	;
    RnonCO2[	275	]=	0.81643781	;
    RnonCO2[	276	]=	0.82194888	;
    RnonCO2[	277	]=	0.82748330	;
    RnonCO2[	278	]=	0.83295786	;
    RnonCO2[	279	]=	0.83836087	;
    RnonCO2[	280	]=	0.84371920	;
    RnonCO2[	281	]=	0.84905335	;
    RnonCO2[	282	]=	0.85438102	;
    RnonCO2[	283	]=	0.85972108	;
    RnonCO2[	284	]=	0.86507627	;
    RnonCO2[	285	]=	0.87043837	;
    RnonCO2[	286	]=	0.87580353	;
    RnonCO2[	287	]=	0.88115517	;
    RnonCO2[	288	]=	0.88647625	;
    RnonCO2[	289	]=	0.89173768	;
    RnonCO2[	290	]=	0.89692423	;
    RnonCO2[	291	]=	0.90206068	;
    RnonCO2[	292	]=	0.90716668	;
    RnonCO2[	293	]=	0.91225923	;
    RnonCO2[	294	]=	0.91735664	;
    RnonCO2[	295	]=	0.92246142	;
    RnonCO2[	296	]=	0.92756192	;
    RnonCO2[	297	]=	0.93258629	;
    RnonCO2[	298	]=	0.93747484	;
    RnonCO2[	299	]=	0.94223618	;
    RnonCO2[	300	]=	0.94684852	;
    RnonCO2[	301	]=	0.95130226	;
    RnonCO2[	302	]=	0.95562914	;
    RnonCO2[	303	]=	0.95985447	;
    RnonCO2[	304	]=	0.96400064	;
    RnonCO2[	305	]=	0.96809094	;
    RnonCO2[	306	]=	0.97213366	;
    RnonCO2[	307	]=	0.97599522	;
    RnonCO2[	308	]=	0.97955529	;
    RnonCO2[	309	]=	0.98283508	;
    RnonCO2[	310	]=	0.98585378	;
    RnonCO2[	311	]=	0.98859983	;
    RnonCO2[	312	]=	0.99107310	;
    RnonCO2[	313	]=	0.99331400	;
    RnonCO2[	314	]=	0.99535641	;
    RnonCO2[	315	]=	0.99723015	;
    RnonCO2[	316	]=	0.99896669	;
    RnonCO2[	317	]=	1.00024263	;
    RnonCO2[	318	]=	1.00074829	;
    RnonCO2[	319	]=	1.00053553	;
    RnonCO2[	320	]=	0.99965511	;
    RnonCO2[	321	]=	0.99815373	;
    RnonCO2[	322	]=	0.99604448	;
    RnonCO2[	323	]=	0.99335014	;
    RnonCO2[	324	]=	0.99013105	;
    RnonCO2[	325	]=	0.98644027	;
    RnonCO2[	326	]=	0.98232404	;
    RnonCO2[	327	]=	0.97811394	;
    RnonCO2[	328	]=	0.97410309	;
    RnonCO2[	329	]=	0.97026742	;
    RnonCO2[	330	]=	0.96658722	;
    RnonCO2[	331	]=	0.96304768	;
    RnonCO2[	332	]=	0.95963482	;
    RnonCO2[	333	]=	0.95637103	;
    RnonCO2[	334	]=	0.95331522	;
    RnonCO2[	335	]=	0.95049228	;
    RnonCO2[	336	]=	0.94788966	;
    RnonCO2[	337	]=	0.94564312	;
    RnonCO2[	338	]=	0.94387234	;
    RnonCO2[	339	]=	0.94252115	;
    RnonCO2[	340	]=	0.94152868	;
    RnonCO2[	341	]=	0.94084300	;
    RnonCO2[	342	]=	0.94042191	;
    RnonCO2[	343	]=	0.94022760	;
    RnonCO2[	344	]=	0.94020038	;
    RnonCO2[	345	]=	0.94029614	;
    RnonCO2[	346	]=	0.94051273	;
    RnonCO2[	347	]=	0.94084570	;
    RnonCO2[	348	]=	0.94128956	;
    RnonCO2[	349	]=	0.94184173	;
    RnonCO2[	350	]=	0.94248677	;
    RnonCO2[	351	]=	0.94320006	;
    RnonCO2[	352	]=	0.94396247	;
    RnonCO2[	353	]=	0.94476065	;
    RnonCO2[	354	]=	0.94558255	;
    RnonCO2[	355	]=	0.94639185	;
    RnonCO2[	356	]=	0.94716535	;
    RnonCO2[	357	]=	0.94791870	;
    RnonCO2[	358	]=	0.94866392	;
    RnonCO2[	359	]=	0.94941005	;
    RnonCO2[	360	]=	0.95016732	;
    RnonCO2[	361	]=	0.95093164	;
    RnonCO2[	362	]=	0.95168880	;
    RnonCO2[	363	]=	0.95242874	;
    RnonCO2[	364	]=	0.95314601	;
    RnonCO2[	365	]=	0.95383580	;
    RnonCO2[	366	]=	0.95446835	;
    RnonCO2[	367	]=	0.95502594	;
    RnonCO2[	368	]=	0.95552935	;
    RnonCO2[	369	]=	0.95599498	;
    RnonCO2[	370	]=	0.95643564	;
    RnonCO2[	371	]=	0.95686498	;
    RnonCO2[	372	]=	0.95728213	;
    RnonCO2[	373	]=	0.95767547	;
    RnonCO2[	374	]=	0.95803719	;
    RnonCO2[	375	]=	0.95836394	;
    RnonCO2[	376	]=	0.95865317	;
    RnonCO2[	377	]=	0.95887644	;
    RnonCO2[	378	]=	0.95901760	;
    RnonCO2[	379	]=	0.95909879	;
    RnonCO2[	380	]=	0.95913754	;
    RnonCO2[	381	]=	0.95914766	;
    RnonCO2[	382	]=	0.95914375	;
    RnonCO2[	383	]=	0.95912546	;
    RnonCO2[	384	]=	0.95908187	;
    RnonCO2[	385	]=	0.95905262	;
    RnonCO2[	386	]=	0.95905262	;
    RnonCO2[	387	]=	0.95905262	;
    RnonCO2[	388	]=	0.95905262	;
    RnonCO2[	389	]=	0.95905262	;
    RnonCO2[	390	]=	0.95905262	;
    RnonCO2[	391	]=	0.95905262	;
    RnonCO2[	392	]=	0.95905262	;
    RnonCO2[	393	]=	0.95905262	;
    RnonCO2[	394	]=	0.95905262	;
    RnonCO2[	395	]=	0.95905262	;
    RnonCO2[	396	]=	0.95905262	;
    RnonCO2[	397	]=	0.95905262	;
    RnonCO2[	398	]=	0.95905262	;
    RnonCO2[	399	]=	0.95905262	;
    RnonCO2[	400	]=	0.95905262	;
    RnonCO2[	401	]=	0.95905262	;
    RnonCO2[	402	]=	0.95905262	;
    RnonCO2[	403	]=	0.95905262	;
    RnonCO2[	404	]=	0.95905262	;
    RnonCO2[	405	]=	0.95905262	;
    RnonCO2[	406	]=	0.95905262	;
    RnonCO2[	407	]=	0.95905262	;
    RnonCO2[	408	]=	0.95905262	;
    RnonCO2[	409	]=	0.95905262	;
    RnonCO2[	410	]=	0.95905262	;
    RnonCO2[	411	]=	0.95905262	;
    RnonCO2[	412	]=	0.95905262	;
    RnonCO2[	413	]=	0.95905262	;
    RnonCO2[	414	]=	0.95905262	;
    RnonCO2[	415	]=	0.95905262	;
    RnonCO2[	416	]=	0.95905262	;
    RnonCO2[	417	]=	0.95905262	;
    RnonCO2[	418	]=	0.95905262	;
    RnonCO2[	419	]=	0.95905262	;
    RnonCO2[	420	]=	0.95905262	;
    RnonCO2[	421	]=	0.95905262	;
    RnonCO2[	422	]=	0.95905262	;
    RnonCO2[	423	]=	0.95905262	;
    RnonCO2[	424	]=	0.95905262	;
    RnonCO2[	425	]=	0.95905262	;
    RnonCO2[	426	]=	0.95905262	;
    RnonCO2[	427	]=	0.95905262	;
    RnonCO2[	428	]=	0.95905262	;
    RnonCO2[	429	]=	0.95905262	;
    RnonCO2[	430	]=	0.95905262	;
    RnonCO2[	431	]=	0.95905262	;
    RnonCO2[	432	]=	0.95905262	;
    RnonCO2[	433	]=	0.95905262	;
    RnonCO2[	434	]=	0.95905262	;
    RnonCO2[	435	]=	0.95905262	;
    RnonCO2[	436	]=	0.95905262	;
    RnonCO2[	437	]=	0.95905262	;
    RnonCO2[	438	]=	0.95905262	;
    RnonCO2[	439	]=	0.95905262	;
    RnonCO2[	440	]=	0.95905262	;
    RnonCO2[	441	]=	0.95905262	;
    RnonCO2[	442	]=	0.95905262	;
    RnonCO2[	443	]=	0.95905262	;
    RnonCO2[	444	]=	0.95905262	;
    RnonCO2[	445	]=	0.95905262	;
    RnonCO2[	446	]=	0.95905262	;
    RnonCO2[	447	]=	0.95905262	;
    RnonCO2[	448	]=	0.95905262	;
    RnonCO2[	449	]=	0.95905262	;
    RnonCO2[	450	]=	0.95905262	;
    RnonCO2[	451	]=	0.95905262	;
    RnonCO2[	452	]=	0.95905262	;
    RnonCO2[	453	]=	0.95905262	;
    RnonCO2[	454	]=	0.95905262	;
    RnonCO2[	455	]=	0.95905262	;
    RnonCO2[	456	]=	0.95905262	;
    RnonCO2[	457	]=	0.95905262	;
    RnonCO2[	458	]=	0.95905262	;
    RnonCO2[	459	]=	0.95905262	;
    RnonCO2[	460	]=	0.95905262	;
    RnonCO2[	461	]=	0.95905262	;
    RnonCO2[	462	]=	0.95905262	;
    RnonCO2[	463	]=	0.95905262	;
    RnonCO2[	464	]=	0.95905262	;
    RnonCO2[	465	]=	0.95905262	;
    RnonCO2[	466	]=	0.95905262	;
    RnonCO2[	467	]=	0.95905262	;
    RnonCO2[	468	]=	0.95905262	;
    RnonCO2[	469	]=	0.95905262	;
    RnonCO2[	470	]=	0.95905262	;
    RnonCO2[	471	]=	0.95905262	;
    RnonCO2[	472	]=	0.95905262	;
    RnonCO2[	473	]=	0.95905262	;
    RnonCO2[	474	]=	0.95905262	;
    RnonCO2[	475	]=	0.95905262	;
    RnonCO2[	476	]=	0.95905262	;
    RnonCO2[	477	]=	0.95905262	;
    RnonCO2[	478	]=	0.95905262	;
    RnonCO2[	479	]=	0.95905262	;
    RnonCO2[	480	]=	0.95905262	;
    RnonCO2[	481	]=	0.95905262	;
    RnonCO2[	482	]=	0.95905262	;
    RnonCO2[	483	]=	0.95905262	;
    RnonCO2[	484	]=	0.95905262	;
    RnonCO2[	485	]=	0.95905262	;
    RnonCO2[	486	]=	0.95905262	;
    RnonCO2[	487	]=	0.95905262	;
    RnonCO2[	488	]=	0.95905262	;
    RnonCO2[	489	]=	0.95905262	;
    RnonCO2[	490	]=	0.95905262	;
    RnonCO2[	491	]=	0.95905262	;
    RnonCO2[	492	]=	0.95905262	;
    RnonCO2[	493	]=	0.95905262	;
    RnonCO2[	494	]=	0.95905262	;
    RnonCO2[	495	]=	0.95905262	;
    RnonCO2[	496	]=	0.95905262	;
    RnonCO2[	497	]=	0.95905262	;
    RnonCO2[	498	]=	0.95905262	;
    RnonCO2[	499	]=	0.95905262	;
    RnonCO2[	500	]=	0.95905262	;
    RnonCO2[	501	]=	0.95905262	;
    RnonCO2[	502	]=	0.95905262	;
    RnonCO2[	503	]=	0.95905262	;
    RnonCO2[	504	]=	0.95905262	;
    RnonCO2[	505	]=	0.95905262	;
    RnonCO2[	506	]=	0.95905262	;
    RnonCO2[	507	]=	0.95905262	;
    RnonCO2[	508	]=	0.95905262	;
    RnonCO2[	509	]=	0.95905262	;
    RnonCO2[	510	]=	0.95905262	;
    RnonCO2[	511	]=	0.95905262	;
    RnonCO2[	512	]=	0.95905262	;
    RnonCO2[	513	]=	0.95905262	;
    RnonCO2[	514	]=	0.95905262	;
    RnonCO2[	515	]=	0.95905262	;
    RnonCO2[	516	]=	0.95905262	;
    RnonCO2[	517	]=	0.95905262	;
    RnonCO2[	518	]=	0.95905262	;
    RnonCO2[	519	]=	0.95905262	;
    RnonCO2[	520	]=	0.95905262	;
    RnonCO2[	521	]=	0.95905262	;
    RnonCO2[	522	]=	0.95905262	;
    RnonCO2[	523	]=	0.95905262	;
    RnonCO2[	524	]=	0.95905262	;
    RnonCO2[	525	]=	0.95905262	;
    RnonCO2[	526	]=	0.95905262	;
    RnonCO2[	527	]=	0.95905262	;
    RnonCO2[	528	]=	0.95905262	;
    RnonCO2[	529	]=	0.95905262	;
    RnonCO2[	530	]=	0.95905262	;
    RnonCO2[	531	]=	0.95905262	;
    RnonCO2[	532	]=	0.95905262	;
    RnonCO2[	533	]=	0.95905262	;
    RnonCO2[	534	]=	0.95905262	;
    RnonCO2[	535	]=	0.95905262	;
    RnonCO2[	536	]=	0.95905262	;
    RnonCO2[	537	]=	0.95905262	;
    RnonCO2[	538	]=	0.95905262	;
    RnonCO2[	539	]=	0.95905262	;
    RnonCO2[	540	]=	0.95905262	;
    RnonCO2[	541	]=	0.95905262	;
    RnonCO2[	542	]=	0.95905262	;
    RnonCO2[	543	]=	0.95905262	;
    RnonCO2[	544	]=	0.95905262	;
    RnonCO2[	545	]=	0.95905262	;
    RnonCO2[	546	]=	0.95905262	;
    RnonCO2[	547	]=	0.95905262	;
    RnonCO2[	548	]=	0.95905262	;
    RnonCO2[	549	]=	0.95905262	;
    RnonCO2[	550	]=	0.95905262	;
    RnonCO2[	551	]=	0.95905262	;
    RnonCO2[	552	]=	0.95905262	;
    RnonCO2[	553	]=	0.95905262	;
    RnonCO2[	554	]=	0.95905262	;
    RnonCO2[	555	]=	0.95905262	;
    RnonCO2[	556	]=	0.95905262	;
    RnonCO2[	557	]=	0.95905262	;
    RnonCO2[	558	]=	0.95905262	;
    RnonCO2[	559	]=	0.95905262	;
    RnonCO2[	560	]=	0.95905262	;
    RnonCO2[	561	]=	0.95905262	;
    RnonCO2[	562	]=	0.95905262	;
    RnonCO2[	563	]=	0.95905262	;
    RnonCO2[	564	]=	0.95905262	;
    RnonCO2[	565	]=	0.95905262	;
    RnonCO2[	566	]=	0.95905262	;
    RnonCO2[	567	]=	0.95905262	;
    RnonCO2[	568	]=	0.95905262	;
    RnonCO2[	569	]=	0.95905262	;
    RnonCO2[	570	]=	0.95905262	;
    RnonCO2[	571	]=	0.95905262	;
    RnonCO2[	572	]=	0.95905262	;
    RnonCO2[	573	]=	0.95905262	;
    RnonCO2[	574	]=	0.95905262	;
    RnonCO2[	575	]=	0.95905262	;
    RnonCO2[	576	]=	0.95905262	;
    RnonCO2[	577	]=	0.95905262	;
    RnonCO2[	578	]=	0.95905262	;
    RnonCO2[	579	]=	0.95905262	;
    RnonCO2[	580	]=	0.95905262	;
    RnonCO2[	581	]=	0.95905262	;
    RnonCO2[	582	]=	0.95905262	;
    RnonCO2[	583	]=	0.95905262	;
    RnonCO2[	584	]=	0.95905262	;
    RnonCO2[	585	]=	0.95905262	;
    RnonCO2[	586	]=	0.95905262	;
    RnonCO2[	587	]=	0.95905262	;
    RnonCO2[	588	]=	0.95905262	;
    RnonCO2[	589	]=	0.95905262	;
    RnonCO2[	590	]=	0.95905262	;
    RnonCO2[	591	]=	0.95905262	;
    RnonCO2[	592	]=	0.95905262	;
    RnonCO2[	593	]=	0.95905262	;
    RnonCO2[	594	]=	0.95905262	;
    RnonCO2[	595	]=	0.95905262	;
    RnonCO2[	596	]=	0.95905262	;
    RnonCO2[	597	]=	0.95905262	;
    RnonCO2[	598	]=	0.95905262	;
    RnonCO2[	599	]=	0.95905262	;
    RnonCO2[	600	]=	0.95905262	;
    RnonCO2[	601	]=	0.95905262	;
    RnonCO2[	602	]=	0.95905262	;
    RnonCO2[	603	]=	0.95905262	;
    RnonCO2[	604	]=	0.95905262	;
    RnonCO2[	605	]=	0.95905262	;
    RnonCO2[	606	]=	0.95905262	;
    RnonCO2[	607	]=	0.95905262	;
    RnonCO2[	608	]=	0.95905262	;
    RnonCO2[	609	]=	0.95905262	;
    RnonCO2[	610	]=	0.95905262	;
    RnonCO2[	611	]=	0.95905262	;
    RnonCO2[	612	]=	0.95905262	;
    RnonCO2[	613	]=	0.95905262	;
    RnonCO2[	614	]=	0.95905262	;
    RnonCO2[	615	]=	0.95905262	;
    RnonCO2[	616	]=	0.95905262	;
    RnonCO2[	617	]=	0.95905262	;
    RnonCO2[	618	]=	0.95905262	;
    RnonCO2[	619	]=	0.95905262	;
    RnonCO2[	620	]=	0.95905262	;
    RnonCO2[	621	]=	0.95905262	;
    RnonCO2[	622	]=	0.95905262	;
    RnonCO2[	623	]=	0.95905262	;
    RnonCO2[	624	]=	0.95905262	;
    RnonCO2[	625	]=	0.95905262	;
    RnonCO2[	626	]=	0.95905262	;
    RnonCO2[	627	]=	0.95905262	;
    RnonCO2[	628	]=	0.95905262	;
    RnonCO2[	629	]=	0.95905262	;
    RnonCO2[	630	]=	0.95905262	;
    RnonCO2[	631	]=	0.95905262	;
    RnonCO2[	632	]=	0.95905262	;
    RnonCO2[	633	]=	0.95905262	;
    RnonCO2[	634	]=	0.95905262	;
    RnonCO2[	635	]=	0.95905262	;
    RnonCO2[	636	]=	0.95905262	;
    RnonCO2[	637	]=	0.95905262	;
    RnonCO2[	638	]=	0.95905262	;
    RnonCO2[	639	]=	0.95905262	;
    RnonCO2[	640	]=	0.95905262	;
    RnonCO2[	641	]=	0.95905262	;
    RnonCO2[	642	]=	0.95905262	;
    RnonCO2[	643	]=	0.95905262	;
    RnonCO2[	644	]=	0.95905262	;
    RnonCO2[	645	]=	0.95905262	;
    RnonCO2[	646	]=	0.95905262	;
    RnonCO2[	647	]=	0.95905262	;
    RnonCO2[	648	]=	0.95905262	;
    RnonCO2[	649	]=	0.95905262	;
    RnonCO2[	650	]=	0.95905262	;
    RnonCO2[	651	]=	0.95905262	;
    RnonCO2[	652	]=	0.95905262	;
    RnonCO2[	653	]=	0.95905262	;
    RnonCO2[	654	]=	0.95905262	;
    RnonCO2[	655	]=	0.95905262	;
    RnonCO2[	656	]=	0.95905262	;
    RnonCO2[	657	]=	0.95905262	;
    RnonCO2[	658	]=	0.95905262	;
    RnonCO2[	659	]=	0.95905262	;
    RnonCO2[	660	]=	0.95905262	;
    RnonCO2[	661	]=	0.95905262	;
    RnonCO2[	662	]=	0.95905262	;
    RnonCO2[	663	]=	0.95905262	;
    RnonCO2[	664	]=	0.95905262	;
    RnonCO2[	665	]=	0.95905262	;
    RnonCO2[	666	]=	0.95905262	;
    RnonCO2[	667	]=	0.95905262	;
    RnonCO2[	668	]=	0.95905262	;
    RnonCO2[	669	]=	0.95905262	;
    RnonCO2[	670	]=	0.95905262	;
    RnonCO2[	671	]=	0.95905262	;
    RnonCO2[	672	]=	0.95905262	;
    RnonCO2[	673	]=	0.95905262	;
    RnonCO2[	674	]=	0.95905262	;
    RnonCO2[	675	]=	0.95905262	;
    RnonCO2[	676	]=	0.95905262	;
    RnonCO2[	677	]=	0.95905262	;
    RnonCO2[	678	]=	0.95905262	;
    RnonCO2[	679	]=	0.95905262	;
    RnonCO2[	680	]=	0.95905262	;
    RnonCO2[	681	]=	0.95905262	;
    RnonCO2[	682	]=	0.95905262	;
    RnonCO2[	683	]=	0.95905262	;
    RnonCO2[	684	]=	0.95905262	;
    RnonCO2[	685	]=	0.95905262	;
    RnonCO2[	686	]=	0.95905262	;
    RnonCO2[	687	]=	0.95905262	;
    RnonCO2[	688	]=	0.95905262	;
    RnonCO2[	689	]=	0.95905262	;
    RnonCO2[	690	]=	0.95905262	;
    RnonCO2[	691	]=	0.95905262	;
    RnonCO2[	692	]=	0.95905262	;
    RnonCO2[	693	]=	0.95905262	;
    RnonCO2[	694	]=	0.95905262	;
    RnonCO2[	695	]=	0.95905262	;
    RnonCO2[	696	]=	0.95905262	;
    RnonCO2[	697	]=	0.95905262	;
    RnonCO2[	698	]=	0.95905262	;
    RnonCO2[	699	]=	0.95905262	;
    RnonCO2[	700	]=	0.95905262	;
    RnonCO2[	701	]=	0.95905262	;
    RnonCO2[	702	]=	0.95905262	;
    RnonCO2[	703	]=	0.95905262	;
    RnonCO2[	704	]=	0.95905262	;
    RnonCO2[	705	]=	0.95905262	;
    RnonCO2[	706	]=	0.95905262	;
    RnonCO2[	707	]=	0.95905262	;
    RnonCO2[	708	]=	0.95905262	;
    RnonCO2[	709	]=	0.95905262	;
    RnonCO2[	710	]=	0.95905262	;
    RnonCO2[	711	]=	0.95905262	;
    RnonCO2[	712	]=	0.95905262	;
    RnonCO2[	713	]=	0.95905262	;
    RnonCO2[	714	]=	0.95905262	;
    RnonCO2[	715	]=	0.95905262	;
    RnonCO2[	716	]=	0.95905262	;
    RnonCO2[	717	]=	0.95905262	;
    RnonCO2[	718	]=	0.95905262	;
    RnonCO2[	719	]=	0.95905262	;
    RnonCO2[	720	]=	0.95905262	;
    RnonCO2[	721	]=	0.95905262	;
    RnonCO2[	722	]=	0.95905262	;
    RnonCO2[	723	]=	0.95905262	;
    RnonCO2[	724	]=	0.95905262	;
    RnonCO2[	725	]=	0.95905262	;
    RnonCO2[	726	]=	0.95905262	;
    RnonCO2[	727	]=	0.95905262	;
    RnonCO2[	728	]=	0.95905262	;
    RnonCO2[	729	]=	0.95905262	;
    RnonCO2[	730	]=	0.95905262	;
    RnonCO2[	731	]=	0.95905262	;
    RnonCO2[	732	]=	0.95905262	;
    RnonCO2[	733	]=	0.95905262	;
    RnonCO2[	734	]=	0.95905262	;
    RnonCO2[	735	]=	0.95905262	;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }

}

void setR_WMGHG_nonCO2_RCP85(void)
{
    RnonCO2[    0    ]=    0    ;
    RnonCO2[    1    ]=    0.004314432    ;
    RnonCO2[    2    ]=    0.008877103    ;
    RnonCO2[    3    ]=    0.009366935    ;
    RnonCO2[    4    ]=    0.00984243    ;
    RnonCO2[    5    ]=    0.010303014    ;
    RnonCO2[    6    ]=    0.010751385    ;
    RnonCO2[    7    ]=    0.011190869    ;
    RnonCO2[    8    ]=    0.01162232    ;
    RnonCO2[    9    ]=    0.012045243    ;
    RnonCO2[    10    ]=    0.012459081    ;
    RnonCO2[    11    ]=    0.012863113    ;
    RnonCO2[    12    ]=    0.013256576    ;
    RnonCO2[    13    ]=    0.013638884    ;
    RnonCO2[    14    ]=    0.014009567    ;
    RnonCO2[    15    ]=    0.014366637    ;
    RnonCO2[    16    ]=    0.014706055    ;
    RnonCO2[    17    ]=    0.015026378    ;
    RnonCO2[    18    ]=    0.015331384    ;
    RnonCO2[    19    ]=    0.015626956    ;
    RnonCO2[    20    ]=    0.015918925    ;
    RnonCO2[    21    ]=    0.01621293    ;
    RnonCO2[    22    ]=    0.016514514    ;
    RnonCO2[    23    ]=    0.016829376    ;
    RnonCO2[    24    ]=    0.017163338    ;
    RnonCO2[    25    ]=    0.017521083    ;
    RnonCO2[    26    ]=    0.017903698    ;
    RnonCO2[    27    ]=    0.01830912    ;
    RnonCO2[    28    ]=    0.018735197    ;
    RnonCO2[    29    ]=    0.019180394    ;
    RnonCO2[    30    ]=    0.01964318    ;
    RnonCO2[    31    ]=    0.02012184    ;
    RnonCO2[    32    ]=    0.02061459    ;
    RnonCO2[    33    ]=    0.02111978    ;
    RnonCO2[    34    ]=    0.02163591    ;
    RnonCO2[    35    ]=    0.02216446    ;
    RnonCO2[    36    ]=    0.02271248    ;
    RnonCO2[    37    ]=    0.02328571    ;
    RnonCO2[    38    ]=    0.0238829    ;
    RnonCO2[    39    ]=    0.02449959    ;
    RnonCO2[    40    ]=    0.02513135    ;
    RnonCO2[    41    ]=    0.02577366    ;
    RnonCO2[    42    ]=    0.02642202    ;
    RnonCO2[    43    ]=    0.02707192    ;
    RnonCO2[    44    ]=    0.02771893    ;
    RnonCO2[    45    ]=    0.02836089    ;
    RnonCO2[    46    ]=    0.02900087    ;
    RnonCO2[    47    ]=    0.02964356    ;
    RnonCO2[    48    ]=    0.03029043    ;
    RnonCO2[    49    ]=    0.03094103    ;
    RnonCO2[    50    ]=    0.03159488    ;
    RnonCO2[    51    ]=    0.03225155    ;
    RnonCO2[    52    ]=    0.0329106    ;
    RnonCO2[    53    ]=    0.03357157    ;
    RnonCO2[    54    ]=    0.03423393    ;
    RnonCO2[    55    ]=    0.03489733    ;
    RnonCO2[    56    ]=    0.03556198    ;
    RnonCO2[    57    ]=    0.03622841    ;
    RnonCO2[    58    ]=    0.03689698    ;
    RnonCO2[    59    ]=    0.03756791    ;
    RnonCO2[    60    ]=    0.03824135    ;
    RnonCO2[    61    ]=    0.03891758    ;
    RnonCO2[    62    ]=    0.03959693    ;
    RnonCO2[    63    ]=    0.04027961    ;
    RnonCO2[    64    ]=    0.04096581    ;
    RnonCO2[    65    ]=    0.04165447    ;
    RnonCO2[    66    ]=    0.04234275    ;
    RnonCO2[    67    ]=    0.04302909    ;
    RnonCO2[    68    ]=    0.04371511    ;
    RnonCO2[    69    ]=    0.04440374    ;
    RnonCO2[    70    ]=    0.0450979    ;
    RnonCO2[    71    ]=    0.04580059    ;
    RnonCO2[    72    ]=    0.04651493    ;
    RnonCO2[    73    ]=    0.0472439    ;
    RnonCO2[    74    ]=    0.04799039    ;
    RnonCO2[    75    ]=    0.04875957    ;
    RnonCO2[    76    ]=    0.04956908    ;
    RnonCO2[    77    ]=    0.05043603    ;
    RnonCO2[    78    ]=    0.05134235    ;
    RnonCO2[    79    ]=    0.05223923    ;
    RnonCO2[    80    ]=    0.05307263    ;
    RnonCO2[    81    ]=    0.05381898    ;
    RnonCO2[    82    ]=    0.05450612    ;
    RnonCO2[    83    ]=    0.05516657    ;
    RnonCO2[    84    ]=    0.05580469    ;
    RnonCO2[    85    ]=    0.05649661    ;
    RnonCO2[    86    ]=    0.05747303    ;
    RnonCO2[    87    ]=    0.05866701    ;
    RnonCO2[    88    ]=    0.0598601    ;
    RnonCO2[    89    ]=    0.0610523    ;
    RnonCO2[    90    ]=    0.06210314    ;
    RnonCO2[    91    ]=    0.06315323    ;
    RnonCO2[    92    ]=    0.06434304    ;
    RnonCO2[    93    ]=    0.06553198    ;
    RnonCO2[    94    ]=    0.06672003    ;
    RnonCO2[    95    ]=    0.06790722    ;
    RnonCO2[    96    ]=    0.06909353    ;
    RnonCO2[    97    ]=    0.07027898    ;
    RnonCO2[    98    ]=    0.07146355    ;
    RnonCO2[    99    ]=    0.07264725    ;
    RnonCO2[    100    ]=    0.07396922    ;
    RnonCO2[    101    ]=    0.0752902    ;
    RnonCO2[    102    ]=    0.07647106    ;
    RnonCO2[    103    ]=    0.07765105    ;
    RnonCO2[    104    ]=    0.07883019    ;
    RnonCO2[    105    ]=    0.08006188    ;
    RnonCO2[    106    ]=    0.0812076    ;
    RnonCO2[    107    ]=    0.08229901    ;
    RnonCO2[    108    ]=    0.08347458    ;
    RnonCO2[    109    ]=    0.08464931    ;
    RnonCO2[    110    ]=    0.08587598    ;
    RnonCO2[    111    ]=    0.08701708    ;
    RnonCO2[    112    ]=    0.08810499    ;
    RnonCO2[    113    ]=    0.08927741    ;
    RnonCO2[    114    ]=    0.09044939    ;
    RnonCO2[    115    ]=    0.09175792    ;
    RnonCO2[    116    ]=    0.09320276    ;
    RnonCO2[    117    ]=    0.09464664    ;
    RnonCO2[    118    ]=    0.09608949    ;
    RnonCO2[    119    ]=    0.09739496    ;
    RnonCO2[    120    ]=    0.0985634    ;
    RnonCO2[    121    ]=    0.09986768    ;
    RnonCO2[    122    ]=    0.10122271    ;
    RnonCO2[    123    ]=    0.10249213    ;
    RnonCO2[    124    ]=    0.10384549    ;
    RnonCO2[    125    ]=    0.10528284    ;
    RnonCO2[    126    ]=    0.10685466    ;
    RnonCO2[    127    ]=    0.1085606    ;
    RnonCO2[    128    ]=    0.11004559    ;
    RnonCO2[    129    ]=    0.11131004    ;
    RnonCO2[    130    ]=    0.11270838    ;
    RnonCO2[    131    ]=    0.1142403    ;
    RnonCO2[    132    ]=    0.11572158    ;
    RnonCO2[    133    ]=    0.11720182    ;
    RnonCO2[    134    ]=    0.11873056    ;
    RnonCO2[    135    ]=    0.12048167    ;
    RnonCO2[    136    ]=    0.12271612    ;
    RnonCO2[    137    ]=    0.12520844    ;
    RnonCO2[    138    ]=    0.12782821    ;
    RnonCO2[    139    ]=    0.13057484    ;
    RnonCO2[    140    ]=    0.13331526    ;
    RnonCO2[    141    ]=    0.13605041    ;
    RnonCO2[    142    ]=    0.13887031    ;
    RnonCO2[    143    ]=    0.14190497    ;
    RnonCO2[    144    ]=    0.14506366    ;
    RnonCO2[    145    ]=    0.14808479    ;
    RnonCO2[    146    ]=    0.15096905    ;
    RnonCO2[    147    ]=    0.15406256    ;
    RnonCO2[    148    ]=    0.15742306    ;
    RnonCO2[    149    ]=    0.16083056    ;
    RnonCO2[    150    ]=    0.16429017    ;
    RnonCO2[    151    ]=    0.16780522    ;
    RnonCO2[    152    ]=    0.17141349    ;
    RnonCO2[    153    ]=    0.17524964    ;
    RnonCO2[    154    ]=    0.17912698    ;
    RnonCO2[    155    ]=    0.18286803    ;
    RnonCO2[    156    ]=    0.18655793    ;
    RnonCO2[    157    ]=    0.19028114    ;
    RnonCO2[    158    ]=    0.19403945    ;
    RnonCO2[    159    ]=    0.19779207    ;
    RnonCO2[    160    ]=    0.2015367    ;
    RnonCO2[    161    ]=    0.20536218    ;
    RnonCO2[    162    ]=    0.20918465    ;
    RnonCO2[    163    ]=    0.21283052    ;
    RnonCO2[    164    ]=    0.2163449    ;
    RnonCO2[    165    ]=    0.21972929    ;
    RnonCO2[    166    ]=    0.22302895    ;
    RnonCO2[    167    ]=    0.22640626    ;
    RnonCO2[    168    ]=    0.22985789    ;
    RnonCO2[    169    ]=    0.23320109    ;
    RnonCO2[    170    ]=    0.2364361    ;
    RnonCO2[    171    ]=    0.23966811    ;
    RnonCO2[    172    ]=    0.2428137    ;
    RnonCO2[    173    ]=    0.24587625    ;
    RnonCO2[    174    ]=    0.248943    ;
    RnonCO2[    175    ]=    0.25213499    ;
    RnonCO2[    176    ]=    0.25554226    ;
    RnonCO2[    177    ]=    0.25892918    ;
    RnonCO2[    178    ]=    0.26220864    ;
    RnonCO2[    179    ]=    0.26570209    ;
    RnonCO2[    180    ]=    0.26941573    ;
    RnonCO2[    181    ]=    0.273294    ;
    RnonCO2[    182    ]=    0.27751544    ;
    RnonCO2[    183    ]=    0.28201064    ;
    RnonCO2[    184    ]=    0.28674226    ;
    RnonCO2[    185    ]=    0.29175313    ;
    RnonCO2[    186    ]=    0.29696911    ;
    RnonCO2[    187    ]=    0.30255457    ;
    RnonCO2[    188    ]=    0.30858029    ;
    RnonCO2[    189    ]=    0.31473264    ;
    RnonCO2[    190    ]=    0.32113183    ;
    RnonCO2[    191    ]=    0.32799691    ;
    RnonCO2[    192    ]=    0.33518916    ;
    RnonCO2[    193    ]=    0.34268013    ;
    RnonCO2[    194    ]=    0.35054912    ;
    RnonCO2[    195    ]=    0.3588091    ;
    RnonCO2[    196    ]=    0.36744837    ;
    RnonCO2[    197    ]=    0.37654998    ;
    RnonCO2[    198    ]=    0.38629282    ;
    RnonCO2[    199    ]=    0.39687085    ;
    RnonCO2[    200    ]=    0.40827014    ;
    RnonCO2[    201    ]=    0.4202703    ;
    RnonCO2[    202    ]=    0.43287302    ;
    RnonCO2[    203    ]=    0.44635066    ;
    RnonCO2[    204    ]=    0.46086195    ;
    RnonCO2[    205    ]=    0.47625741    ;
    RnonCO2[    206    ]=    0.49233715    ;
    RnonCO2[    207    ]=    0.50922498    ;
    RnonCO2[    208    ]=    0.52712569    ;
    RnonCO2[    209    ]=    0.54610485    ;
    RnonCO2[    210    ]=    0.56604558    ;
    RnonCO2[    211    ]=    0.58635079    ;
    RnonCO2[    212    ]=    0.6067464    ;
    RnonCO2[    213    ]=    0.6271609    ;
    RnonCO2[    214    ]=    0.6475189    ;
    RnonCO2[    215    ]=    0.6673124    ;
    RnonCO2[    216    ]=    0.6879383    ;
    RnonCO2[    217    ]=    0.7090557    ;
    RnonCO2[    218    ]=    0.7289172    ;
    RnonCO2[    219    ]=    0.7480442    ;
    RnonCO2[    220    ]=    0.766979    ;
    RnonCO2[    221    ]=    0.7850643    ;
    RnonCO2[    222    ]=    0.803085    ;
    RnonCO2[    223    ]=    0.8236521    ;
    RnonCO2[    224    ]=    0.8452713    ;
    RnonCO2[    225    ]=    0.864246    ;
    RnonCO2[    226    ]=    0.8809743    ;
    RnonCO2[    227    ]=    0.8949711    ;
    RnonCO2[    228    ]=    0.9053237    ;
    RnonCO2[    229    ]=    0.914042    ;
    RnonCO2[    230    ]=    0.9219104    ;
    RnonCO2[    231    ]=    0.9290394    ;
    RnonCO2[    232    ]=    0.9359876    ;
    RnonCO2[    233    ]=    0.9434778    ;
    RnonCO2[    234    ]=    0.9502339    ;
    RnonCO2[    235    ]=    0.9548618    ;
    RnonCO2[    236    ]=    0.9587726    ;
    RnonCO2[    237    ]=    0.9638465    ;
    RnonCO2[    238    ]=    0.9690029    ;
    RnonCO2[    239    ]=    0.972858    ;
    RnonCO2[    240    ]=    0.9761909    ;
    RnonCO2[    241    ]=    0.9798628    ;
    RnonCO2[    242    ]=    0.9841731    ;
    RnonCO2[    243    ]=    0.9894354    ;
    RnonCO2[    244    ]=    0.9954191    ;
    RnonCO2[    245    ]=    1.00198    ;
    RnonCO2[    246    ]=    1.0091146    ;
    RnonCO2[    247    ]=    1.0168268    ;
    RnonCO2[    248    ]=    1.0251231    ;
    RnonCO2[    249    ]=    1.0339608    ;
    RnonCO2[    250    ]=    1.0433067    ;
    RnonCO2[    251    ]=    1.0531035    ;
    RnonCO2[    252    ]=    1.0633085    ;
    RnonCO2[    253    ]=    1.0738918    ;
    RnonCO2[    254    ]=    1.084804    ;
    RnonCO2[    255    ]=    1.0960028    ;
    RnonCO2[    256    ]=    1.1074145    ;
    RnonCO2[    257    ]=    1.1189068    ;
    RnonCO2[    258    ]=    1.1304114    ;
    RnonCO2[    259    ]=    1.1419446    ;
    RnonCO2[    260    ]=    1.1535202    ;
    RnonCO2[    261    ]=    1.1651552    ;
    RnonCO2[    262    ]=    1.1768474    ;
    RnonCO2[    263    ]=    1.1885811    ;
    RnonCO2[    264    ]=    1.2003455    ;
    RnonCO2[    265    ]=    1.2121353    ;
    RnonCO2[    266    ]=    1.2239442    ;
    RnonCO2[    267    ]=    1.2358634    ;
    RnonCO2[    268    ]=    1.2479562    ;
    RnonCO2[    269    ]=    1.2601642    ;
    RnonCO2[    270    ]=    1.2724369    ;
    RnonCO2[    271    ]=    1.284734    ;
    RnonCO2[    272    ]=    1.297029    ;
    RnonCO2[    273    ]=    1.3092838    ;
    RnonCO2[    274    ]=    1.321453    ;
    RnonCO2[    275    ]=    1.3335026    ;
    RnonCO2[    276    ]=    1.3454097    ;
    RnonCO2[    277    ]=    1.3571802    ;
    RnonCO2[    278    ]=    1.3688174    ;
    RnonCO2[    279    ]=    1.3803494    ;
    RnonCO2[    280    ]=    1.39185    ;
    RnonCO2[    281    ]=    1.403377    ;
    RnonCO2[    282    ]=    1.4149773    ;
    RnonCO2[    283    ]=    1.4266939    ;
    RnonCO2[    284    ]=    1.4385426    ;
    RnonCO2[    285    ]=    1.450519    ;
    RnonCO2[    286    ]=    1.4626211    ;
    RnonCO2[    287    ]=    1.4746666    ;
    RnonCO2[    288    ]=    1.4864856    ;
    RnonCO2[    289    ]=    1.4980611    ;
    RnonCO2[    290    ]=    1.5093913    ;
    RnonCO2[    291    ]=    1.5205293    ;
    RnonCO2[    292    ]=    1.5315196    ;
    RnonCO2[    293    ]=    1.5424005    ;
    RnonCO2[    294    ]=    1.5532103    ;
    RnonCO2[    295    ]=    1.5639631    ;
    RnonCO2[    296    ]=    1.5746545    ;
    RnonCO2[    297    ]=    1.5851241    ;
    RnonCO2[    298    ]=    1.5952297    ;
    RnonCO2[    299    ]=    1.6050005    ;
    RnonCO2[    300    ]=    1.6144203    ;
    RnonCO2[    301    ]=    1.6234876    ;
    RnonCO2[    302    ]=    1.6322598    ;
    RnonCO2[    303    ]=    1.640786    ;
    RnonCO2[    304    ]=    1.6491097    ;
    RnonCO2[    305    ]=    1.6572747    ;
    RnonCO2[    306    ]=    1.6652999    ;
    RnonCO2[    307    ]=    1.6732147    ;
    RnonCO2[    308    ]=    1.6810498    ;
    RnonCO2[    309    ]=    1.6888091    ;
    RnonCO2[    310    ]=    1.6964967    ;
    RnonCO2[    311    ]=    1.7040719    ;
    RnonCO2[    312    ]=    1.7115112    ;
    RnonCO2[    313    ]=    1.7188534    ;
    RnonCO2[    314    ]=    1.7261326    ;
    RnonCO2[    315    ]=    1.7333772    ;
    RnonCO2[    316    ]=    1.740617    ;
    RnonCO2[    317    ]=    1.7478939    ;
    RnonCO2[    318    ]=    1.7552303    ;
    RnonCO2[    319    ]=    1.7626127    ;
    RnonCO2[    320    ]=    1.7700344    ;
    RnonCO2[    321    ]=    1.7774893    ;
    RnonCO2[    322    ]=    1.784927    ;
    RnonCO2[    323    ]=    1.7923144    ;
    RnonCO2[    324    ]=    1.7996837    ;
    RnonCO2[    325    ]=    1.8070631    ;
    RnonCO2[    326    ]=    1.8144777    ;
    RnonCO2[    327    ]=    1.8218089    ;
    RnonCO2[    328    ]=    1.8289238    ;
    RnonCO2[    329    ]=    1.8358256    ;
    RnonCO2[    330    ]=    1.8425207    ;
    RnonCO2[    331    ]=    1.8490211    ;
    RnonCO2[    332    ]=    1.8553386    ;
    RnonCO2[    333    ]=    1.861438    ;
    RnonCO2[    334    ]=    1.8673005    ;
    RnonCO2[    335    ]=    1.872973    ;
    RnonCO2[    336    ]=    1.8784998    ;
    RnonCO2[    337    ]=    1.8838116    ;
    RnonCO2[    338    ]=    1.8888456    ;
    RnonCO2[    339    ]=    1.8936276    ;
    RnonCO2[    340    ]=    1.898161    ;
    RnonCO2[    341    ]=    1.9024525    ;
    RnonCO2[    342    ]=    1.9065143    ;
    RnonCO2[    343    ]=    1.9103591    ;
    RnonCO2[    344    ]=    1.9139524    ;
    RnonCO2[    345    ]=    1.9172751    ;
    RnonCO2[    346    ]=    1.9203756    ;
    RnonCO2[    347    ]=    1.9232997    ;
    RnonCO2[    348    ]=    1.9260863    ;
    RnonCO2[    349    ]=    1.9287756    ;
    RnonCO2[    350    ]=    1.931381    ;
    RnonCO2[    351    ]=    1.9338935    ;
    RnonCO2[    352    ]=    1.9363084    ;
    RnonCO2[    353    ]=    1.9386273    ;
    RnonCO2[    354    ]=    1.940853    ;
    RnonCO2[    355    ]=    1.9429416    ;
    RnonCO2[    356    ]=    1.9448652    ;
    RnonCO2[    357    ]=    1.9466644    ;
    RnonCO2[    358    ]=    1.9483786    ;
    RnonCO2[    359    ]=    1.950041    ;
    RnonCO2[    360    ]=    1.9516856    ;
    RnonCO2[    361    ]=    1.9533204    ;
    RnonCO2[    362    ]=    1.9549312    ;
    RnonCO2[    363    ]=    1.9565073    ;
    RnonCO2[    364    ]=    1.9580454    ;
    RnonCO2[    365    ]=    1.9595441    ;
    RnonCO2[    366    ]=    1.9609555    ;
    RnonCO2[    367    ]=    1.9622472    ;
    RnonCO2[    368    ]=    1.9634567    ;
    RnonCO2[    369    ]=    1.9646211    ;
    RnonCO2[    370    ]=    1.9657705    ;
    RnonCO2[    371    ]=    1.9669362    ;
    RnonCO2[    372    ]=    1.9681259    ;
    RnonCO2[    373    ]=    1.9693208    ;
    RnonCO2[    374    ]=    1.9705091    ;
    RnonCO2[    375    ]=    1.9716846    ;
    RnonCO2[    376    ]=    1.9728438    ;
    RnonCO2[    377    ]=    1.9739366    ;
    RnonCO2[    378    ]=    1.9749294    ;
    RnonCO2[    379    ]=    1.9758573    ;
    RnonCO2[    380    ]=    1.9767565    ;
    RnonCO2[    381    ]=    1.9776574    ;
    RnonCO2[    382    ]=    1.9785912    ;
    RnonCO2[    383    ]=    1.9795626    ;
    RnonCO2[    384    ]=    1.9805528    ;
    RnonCO2[    385    ]=    1.9815485    ;
    RnonCO2[    386    ]=    1.9825418    ;
    RnonCO2[    387    ]=    1.9835297    ;
    RnonCO2[    388    ]=    1.9844595    ;
    RnonCO2[    389    ]=    1.9852968    ;
    RnonCO2[    390    ]=    1.9860737    ;
    RnonCO2[    391    ]=    1.9868278    ;
    RnonCO2[    392    ]=    1.9875876    ;
    RnonCO2[    393    ]=    1.9883847    ;
    RnonCO2[    394    ]=    1.9892229    ;
    RnonCO2[    395    ]=    1.9900824    ;
    RnonCO2[    396    ]=    1.9909497    ;
    RnonCO2[    397    ]=    1.9918147    ;
    RnonCO2[    398    ]=    1.9926738    ;
    RnonCO2[    399    ]=    1.9934757    ;
    RnonCO2[    400    ]=    1.9941844    ;
    RnonCO2[    401    ]=    1.9948328    ;
    RnonCO2[    402    ]=    1.9954579    ;
    RnonCO2[    403    ]=    1.9960894    ;
    RnonCO2[    404    ]=    1.9967601    ;
    RnonCO2[    405    ]=    1.9974721    ;
    RnonCO2[    406    ]=    1.9982083    ;
    RnonCO2[    407    ]=    1.9989518    ;
    RnonCO2[    408    ]=    1.9996957    ;
    RnonCO2[    409    ]=    2.0004323    ;
    RnonCO2[    410    ]=    2.0011115    ;
    RnonCO2[    411    ]=    2.0016989    ;
    RnonCO2[    412    ]=    2.0022257    ;
    RnonCO2[    413    ]=    2.0027304    ;
    RnonCO2[    414    ]=    2.0032428    ;
    RnonCO2[    415    ]=    2.0037938    ;
    RnonCO2[    416    ]=    2.0043879    ;
    RnonCO2[    417    ]=    2.0050072    ;
    RnonCO2[    418    ]=    2.0056344    ;
    RnonCO2[    419    ]=    2.0062615    ;
    RnonCO2[    420    ]=    2.0068815    ;
    RnonCO2[    421    ]=    2.0074457    ;
    RnonCO2[    422    ]=    2.0079169    ;
    RnonCO2[    423    ]=    2.0083285    ;
    RnonCO2[    424    ]=    2.0087185    ;
    RnonCO2[    425    ]=    2.0091161    ;
    RnonCO2[    426    ]=    2.0095542    ;
    RnonCO2[    427    ]=    2.010036    ;
    RnonCO2[    428    ]=    2.0105425    ;
    RnonCO2[    429    ]=    2.011058    ;
    RnonCO2[    430    ]=    2.011572    ;
    RnonCO2[    431    ]=    2.012081    ;
    RnonCO2[    432    ]=    2.012533    ;
    RnonCO2[    433    ]=    2.012893    ;
    RnonCO2[    434    ]=    2.013193    ;
    RnonCO2[    435    ]=    2.013472    ;
    RnonCO2[    436    ]=    2.013759    ;
    RnonCO2[    437    ]=    2.014085    ;
    RnonCO2[    438    ]=    2.014457    ;
    RnonCO2[    439    ]=    2.014853    ;
    RnonCO2[    440    ]=    2.015255    ;
    RnonCO2[    441    ]=    2.015658    ;
    RnonCO2[    442    ]=    2.016054    ;
    RnonCO2[    443    ]=    2.016393    ;
    RnonCO2[    444    ]=    2.01664    ;
    RnonCO2[    445    ]=    2.016827    ;
    RnonCO2[    446    ]=    2.016993    ;
    RnonCO2[    447    ]=    2.017169    ;
    RnonCO2[    448    ]=    2.017384    ;
    RnonCO2[    449    ]=    2.017644    ;
    RnonCO2[    450    ]=    2.017928    ;
    RnonCO2[    451    ]=    2.01822    ;
    RnonCO2[    452    ]=    2.018512    ;
    RnonCO2[    453    ]=    2.018798    ;
    RnonCO2[    454    ]=    2.019027    ;
    RnonCO2[    455    ]=    2.019164    ;
    RnonCO2[    456    ]=    2.019243    ;
    RnonCO2[    457    ]=    2.019301    ;
    RnonCO2[    458    ]=    2.019369    ;
    RnonCO2[    459    ]=    2.019478    ;
    RnonCO2[    460    ]=    2.019632    ;
    RnonCO2[    461    ]=    2.01981    ;
    RnonCO2[    462    ]=    2.019997    ;
    RnonCO2[    463    ]=    2.020183    ;
    RnonCO2[    464    ]=    2.020363    ;
    RnonCO2[    465    ]=    2.020487    ;
    RnonCO2[    466    ]=    2.02052    ;
    RnonCO2[    467    ]=    2.020496    ;
    RnonCO2[    468    ]=    2.020451    ;
    RnonCO2[    469    ]=    2.020417    ;
    RnonCO2[    470    ]=    2.020424    ;
    RnonCO2[    471    ]=    2.020477    ;
    RnonCO2[    472    ]=    2.020554    ;
    RnonCO2[    473    ]=    2.02064    ;
    RnonCO2[    474    ]=    2.020725    ;
    RnonCO2[    475    ]=    2.020805    ;
    RnonCO2[    476    ]=    2.02083    ;
    RnonCO2[    477    ]=    2.020763    ;
    RnonCO2[    478    ]=    2.020641    ;
    RnonCO2[    479    ]=    2.0205    ;
    RnonCO2[    480    ]=    2.020369    ;
    RnonCO2[    481    ]=    2.020281    ;
    RnonCO2[    482    ]=    2.020237    ;
    RnonCO2[    483    ]=    2.02022    ;
    RnonCO2[    484    ]=    2.020211    ;
    RnonCO2[    485    ]=    2.020207    ;
    RnonCO2[    486    ]=    2.020207    ;
    RnonCO2[    487    ]=    2.020207    ;
    RnonCO2[    488    ]=    2.020207    ;
    RnonCO2[    489    ]=    2.020207    ;
    RnonCO2[    490    ]=    2.020207    ;
    RnonCO2[    491    ]=    2.020207    ;
    RnonCO2[    492    ]=    2.020207    ;
    RnonCO2[    493    ]=    2.020207    ;
    RnonCO2[    494    ]=    2.020207    ;
    RnonCO2[    495    ]=    2.020207    ;
    RnonCO2[    496    ]=    2.020207    ;
    RnonCO2[    497    ]=    2.020207    ;
    RnonCO2[    498    ]=    2.020207    ;
    RnonCO2[    499    ]=    2.020207    ;
    RnonCO2[    500    ]=    2.020207    ;
    RnonCO2[    501    ]=    2.020207    ;
    RnonCO2[    502    ]=    2.020207    ;
    RnonCO2[    503    ]=    2.020207    ;
    RnonCO2[    504    ]=    2.020207    ;
    RnonCO2[    505    ]=    2.020207    ;
    RnonCO2[    506    ]=    2.020207    ;
    RnonCO2[    507    ]=    2.020207    ;
    RnonCO2[    508    ]=    2.020207    ;
    RnonCO2[    509    ]=    2.020207    ;
    RnonCO2[    510    ]=    2.020207    ;
    RnonCO2[    511    ]=    2.020207    ;
    RnonCO2[    512    ]=    2.020207    ;
    RnonCO2[    513    ]=    2.020207    ;
    RnonCO2[    514    ]=    2.020207    ;
    RnonCO2[    515    ]=    2.020207    ;
    RnonCO2[    516    ]=    2.020207    ;
    RnonCO2[    517    ]=    2.020207    ;
    RnonCO2[    518    ]=    2.020207    ;
    RnonCO2[    519    ]=    2.020207    ;
    RnonCO2[    520    ]=    2.020207    ;
    RnonCO2[    521    ]=    2.020207    ;
    RnonCO2[    522    ]=    2.020207    ;
    RnonCO2[    523    ]=    2.020207    ;
    RnonCO2[    524    ]=    2.020207    ;
    RnonCO2[    525    ]=    2.020207    ;
    RnonCO2[    526    ]=    2.020207    ;
    RnonCO2[    527    ]=    2.020207    ;
    RnonCO2[    528    ]=    2.020207    ;
    RnonCO2[    529    ]=    2.020207    ;
    RnonCO2[    530    ]=    2.020207    ;
    RnonCO2[    531    ]=    2.020207    ;
    RnonCO2[    532    ]=    2.020207    ;
    RnonCO2[    533    ]=    2.020207    ;
    RnonCO2[    534    ]=    2.020207    ;
    RnonCO2[    535    ]=    2.020207    ;
    RnonCO2[    536    ]=    2.020207    ;
    RnonCO2[    537    ]=    2.020207    ;
    RnonCO2[    538    ]=    2.020207    ;
    RnonCO2[    539    ]=    2.020207    ;
    RnonCO2[    540    ]=    2.020207    ;
    RnonCO2[    541    ]=    2.020207    ;
    RnonCO2[    542    ]=    2.020207    ;
    RnonCO2[    543    ]=    2.020207    ;
    RnonCO2[    544    ]=    2.020207    ;
    RnonCO2[    545    ]=    2.020207    ;
    RnonCO2[    546    ]=    2.020207    ;
    RnonCO2[    547    ]=    2.020207    ;
    RnonCO2[    548    ]=    2.020207    ;
    RnonCO2[    549    ]=    2.020207    ;
    RnonCO2[    550    ]=    2.020207    ;
    RnonCO2[    551    ]=    2.020207    ;
    RnonCO2[    552    ]=    2.020207    ;
    RnonCO2[    553    ]=    2.020207    ;
    RnonCO2[    554    ]=    2.020207    ;
    RnonCO2[    555    ]=    2.020207    ;
    RnonCO2[    556    ]=    2.020207    ;
    RnonCO2[    557    ]=    2.020207    ;
    RnonCO2[    558    ]=    2.020207    ;
    RnonCO2[    559    ]=    2.020207    ;
    RnonCO2[    560    ]=    2.020207    ;
    RnonCO2[    561    ]=    2.020207    ;
    RnonCO2[    562    ]=    2.020207    ;
    RnonCO2[    563    ]=    2.020207    ;
    RnonCO2[    564    ]=    2.020207    ;
    RnonCO2[    565    ]=    2.020207    ;
    RnonCO2[    566    ]=    2.020207    ;
    RnonCO2[    567    ]=    2.020207    ;
    RnonCO2[    568    ]=    2.020207    ;
    RnonCO2[    569    ]=    2.020207    ;
    RnonCO2[    570    ]=    2.020207    ;
    RnonCO2[    571    ]=    2.020207    ;
    RnonCO2[    572    ]=    2.020207    ;
    RnonCO2[    573    ]=    2.020207    ;
    RnonCO2[    574    ]=    2.020207    ;
    RnonCO2[    575    ]=    2.020207    ;
    RnonCO2[    576    ]=    2.020207    ;
    RnonCO2[    577    ]=    2.020207    ;
    RnonCO2[    578    ]=    2.020207    ;
    RnonCO2[    579    ]=    2.020207    ;
    RnonCO2[    580    ]=    2.020207    ;
    RnonCO2[    581    ]=    2.020207    ;
    RnonCO2[    582    ]=    2.020207    ;
    RnonCO2[    583    ]=    2.020207    ;
    RnonCO2[    584    ]=    2.020207    ;
    RnonCO2[    585    ]=    2.020207    ;
    RnonCO2[    586    ]=    2.020207    ;
    RnonCO2[    587    ]=    2.020207    ;
    RnonCO2[    588    ]=    2.020207    ;
    RnonCO2[    589    ]=    2.020207    ;
    RnonCO2[    590    ]=    2.020207    ;
    RnonCO2[    591    ]=    2.020207    ;
    RnonCO2[    592    ]=    2.020207    ;
    RnonCO2[    593    ]=    2.020207    ;
    RnonCO2[    594    ]=    2.020207    ;
    RnonCO2[    595    ]=    2.020207    ;
    RnonCO2[    596    ]=    2.020207    ;
    RnonCO2[    597    ]=    2.020207    ;
    RnonCO2[    598    ]=    2.020207    ;
    RnonCO2[    599    ]=    2.020207    ;
    RnonCO2[    600    ]=    2.020207    ;
    RnonCO2[    601    ]=    2.020207    ;
    RnonCO2[    602    ]=    2.020207    ;
    RnonCO2[    603    ]=    2.020207    ;
    RnonCO2[    604    ]=    2.020207    ;
    RnonCO2[    605    ]=    2.020207    ;
    RnonCO2[    606    ]=    2.020207    ;
    RnonCO2[    607    ]=    2.020207    ;
    RnonCO2[    608    ]=    2.020207    ;
    RnonCO2[    609    ]=    2.020207    ;
    RnonCO2[    610    ]=    2.020207    ;
    RnonCO2[    611    ]=    2.020207    ;
    RnonCO2[    612    ]=    2.020207    ;
    RnonCO2[    613    ]=    2.020207    ;
    RnonCO2[    614    ]=    2.020207    ;
    RnonCO2[    615    ]=    2.020207    ;
    RnonCO2[    616    ]=    2.020207    ;
    RnonCO2[    617    ]=    2.020207    ;
    RnonCO2[    618    ]=    2.020207    ;
    RnonCO2[    619    ]=    2.020207    ;
    RnonCO2[    620    ]=    2.020207    ;
    RnonCO2[    621    ]=    2.020207    ;
    RnonCO2[    622    ]=    2.020207    ;
    RnonCO2[    623    ]=    2.020207    ;
    RnonCO2[    624    ]=    2.020207    ;
    RnonCO2[    625    ]=    2.020207    ;
    RnonCO2[    626    ]=    2.020207    ;
    RnonCO2[    627    ]=    2.020207    ;
    RnonCO2[    628    ]=    2.020207    ;
    RnonCO2[    629    ]=    2.020207    ;
    RnonCO2[    630    ]=    2.020207    ;
    RnonCO2[    631    ]=    2.020207    ;
    RnonCO2[    632    ]=    2.020207    ;
    RnonCO2[    633    ]=    2.020207    ;
    RnonCO2[    634    ]=    2.020207    ;
    RnonCO2[    635    ]=    2.020207    ;
    RnonCO2[    636    ]=    2.020207    ;
    RnonCO2[    637    ]=    2.020207    ;
    RnonCO2[    638    ]=    2.020207    ;
    RnonCO2[    639    ]=    2.020207    ;
    RnonCO2[    640    ]=    2.020207    ;
    RnonCO2[    641    ]=    2.020207    ;
    RnonCO2[    642    ]=    2.020207    ;
    RnonCO2[    643    ]=    2.020207    ;
    RnonCO2[    644    ]=    2.020207    ;
    RnonCO2[    645    ]=    2.020207    ;
    RnonCO2[    646    ]=    2.020207    ;
    RnonCO2[    647    ]=    2.020207    ;
    RnonCO2[    648    ]=    2.020207    ;
    RnonCO2[    649    ]=    2.020207    ;
    RnonCO2[    650    ]=    2.020207    ;
    RnonCO2[    651    ]=    2.020207    ;
    RnonCO2[    652    ]=    2.020207    ;
    RnonCO2[    653    ]=    2.020207    ;
    RnonCO2[    654    ]=    2.020207    ;
    RnonCO2[    655    ]=    2.020207    ;
    RnonCO2[    656    ]=    2.020207    ;
    RnonCO2[    657    ]=    2.020207    ;
    RnonCO2[    658    ]=    2.020207    ;
    RnonCO2[    659    ]=    2.020207    ;
    RnonCO2[    660    ]=    2.020207    ;
    RnonCO2[    661    ]=    2.020207    ;
    RnonCO2[    662    ]=    2.020207    ;
    RnonCO2[    663    ]=    2.020207    ;
    RnonCO2[    664    ]=    2.020207    ;
    RnonCO2[    665    ]=    2.020207    ;
    RnonCO2[    666    ]=    2.020207    ;
    RnonCO2[    667    ]=    2.020207    ;
    RnonCO2[    668    ]=    2.020207    ;
    RnonCO2[    669    ]=    2.020207    ;
    RnonCO2[    670    ]=    2.020207    ;
    RnonCO2[    671    ]=    2.020207    ;
    RnonCO2[    672    ]=    2.020207    ;
    RnonCO2[    673    ]=    2.020207    ;
    RnonCO2[    674    ]=    2.020207    ;
    RnonCO2[    675    ]=    2.020207    ;
    RnonCO2[    676    ]=    2.020207    ;
    RnonCO2[    677    ]=    2.020207    ;
    RnonCO2[    678    ]=    2.020207    ;
    RnonCO2[    679    ]=    2.020207    ;
    RnonCO2[    680    ]=    2.020207    ;
    RnonCO2[    681    ]=    2.020207    ;
    RnonCO2[    682    ]=    2.020207    ;
    RnonCO2[    683    ]=    2.020207    ;
    RnonCO2[    684    ]=    2.020207    ;
    RnonCO2[    685    ]=    2.020207    ;
    RnonCO2[    686    ]=    2.020207    ;
    RnonCO2[    687    ]=    2.020207    ;
    RnonCO2[    688    ]=    2.020207    ;
    RnonCO2[    689    ]=    2.020207    ;
    RnonCO2[    690    ]=    2.020207    ;
    RnonCO2[    691    ]=    2.020207    ;
    RnonCO2[    692    ]=    2.020207    ;
    RnonCO2[    693    ]=    2.020207    ;
    RnonCO2[    694    ]=    2.020207    ;
    RnonCO2[    695    ]=    2.020207    ;
    RnonCO2[    696    ]=    2.020207    ;
    RnonCO2[    697    ]=    2.020207    ;
    RnonCO2[    698    ]=    2.020207    ;
    RnonCO2[    699    ]=    2.020207    ;
    RnonCO2[    700    ]=    2.020207    ;
    RnonCO2[    701    ]=    2.020207    ;
    RnonCO2[    702    ]=    2.020207    ;
    RnonCO2[    703    ]=    2.020207    ;
    RnonCO2[    704    ]=    2.020207    ;
    RnonCO2[    705    ]=    2.020207    ;
    RnonCO2[    706    ]=    2.020207    ;
    RnonCO2[    707    ]=    2.020207    ;
    RnonCO2[    708    ]=    2.020207    ;
    RnonCO2[    709    ]=    2.020207    ;
    RnonCO2[    710    ]=    2.020207    ;
    RnonCO2[    711    ]=    2.020207    ;
    RnonCO2[    712    ]=    2.020207    ;
    RnonCO2[    713    ]=    2.020207    ;
    RnonCO2[    714    ]=    2.020207    ;
    RnonCO2[    715    ]=    2.020207    ;
    RnonCO2[    716    ]=    2.020207    ;
    RnonCO2[    717    ]=    2.020207    ;
    RnonCO2[    718    ]=    2.020207    ;
    RnonCO2[    719    ]=    2.020207    ;
    RnonCO2[    720    ]=    2.020207    ;
    RnonCO2[    721    ]=    2.020207    ;
    RnonCO2[    722    ]=    2.020207    ;
    RnonCO2[    723    ]=    2.020207    ;
    RnonCO2[    724    ]=    2.020207    ;
    RnonCO2[    725    ]=    2.020207    ;
    RnonCO2[    726    ]=    2.020207    ;
    RnonCO2[    727    ]=    2.020207    ;
    RnonCO2[    728    ]=    2.020207    ;
    RnonCO2[    729    ]=    2.020207    ;
    RnonCO2[    730    ]=    2.020207    ;
    RnonCO2[    731    ]=    2.020207    ;
    RnonCO2[    732    ]=    2.020207    ;
    RnonCO2[    733    ]=    2.020207    ;
    RnonCO2[    734    ]=    2.020207    ;
    RnonCO2[    735    ]=    2.020207    ;
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
}

void setR_aerosol_RCP85(void)
{
    RnonCO2[    0    ]=    0    ;
    RnonCO2[    1    ]=    0.000955298    ;
    RnonCO2[    2    ]=    0.001424721    ;
    RnonCO2[    3    ]=    0.0001974    ;
    RnonCO2[    4    ]=    -0.001278437    ;
    RnonCO2[    5    ]=    -0.002733841    ;
    RnonCO2[    6    ]=    -0.004541334    ;
    RnonCO2[    7    ]=    -0.00632004    ;
    RnonCO2[    8    ]=    -0.007680948    ;
    RnonCO2[    9    ]=    -0.008994568    ;
    RnonCO2[    10    ]=    -0.010260775    ;
    RnonCO2[    11    ]=    -0.011479866    ;
    RnonCO2[    12    ]=    -0.012652425    ;
    RnonCO2[    13    ]=    -0.013779231    ;
    RnonCO2[    14    ]=    -0.014861204    ;
    RnonCO2[    15    ]=    -0.015900176    ;
    RnonCO2[    16    ]=    -0.017335746    ;
    RnonCO2[    17    ]=    -0.01873479    ;
    RnonCO2[    18    ]=    -0.019659073    ;
    RnonCO2[    19    ]=    -0.020540613    ;
    RnonCO2[    20    ]=    -0.02137714    ;
    RnonCO2[    21    ]=    -0.022166399    ;
    RnonCO2[    22    ]=    -0.022906132    ;
    RnonCO2[    23    ]=    -0.023594082    ;
    RnonCO2[    24    ]=    -0.024227995    ;
    RnonCO2[    25    ]=    -0.024806236    ;
    RnonCO2[    26    ]=    -0.025775743    ;
    RnonCO2[    27    ]=    -0.026691982    ;
    RnonCO2[    28    ]=    -0.027110281    ;
    RnonCO2[    29    ]=    -0.02747885    ;
    RnonCO2[    30    ]=    -0.027799526    ;
    RnonCO2[    31    ]=    -0.028074106    ;
    RnonCO2[    32    ]=    -0.02875039    ;
    RnonCO2[    33    ]=    -0.029383792    ;
    RnonCO2[    34    ]=    -0.02953002    ;
    RnonCO2[    35    ]=    -0.03007996    ;
    RnonCO2[    36    ]=    -0.03058546    ;
    RnonCO2[    37    ]=    -0.03148571    ;
    RnonCO2[    38    ]=    -0.03189741    ;
    RnonCO2[    39    ]=    -0.03138062    ;
    RnonCO2[    40    ]=    -0.03126848    ;
    RnonCO2[    41    ]=    -0.03156144    ;
    RnonCO2[    42    ]=    -0.03182181    ;
    RnonCO2[    43    ]=    -0.03161267    ;
    RnonCO2[    44    ]=    -0.03137821    ;
    RnonCO2[    45    ]=    -0.03112038    ;
    RnonCO2[    46    ]=    -0.03127367    ;
    RnonCO2[    47    ]=    -0.0313998    ;
    RnonCO2[    48    ]=    -0.03106322    ;
    RnonCO2[    49    ]=    -0.03070135    ;
    RnonCO2[    50    ]=    -0.03074616    ;
    RnonCO2[    51    ]=    -0.03119614    ;
    RnonCO2[    52    ]=    -0.03161872    ;
    RnonCO2[    53    ]=    -0.03158785    ;
    RnonCO2[    54    ]=    -0.03110696    ;
    RnonCO2[    55    ]=    -0.03060634    ;
    RnonCO2[    56    ]=    -0.0300866    ;
    RnonCO2[    57    ]=    -0.02996996    ;
    RnonCO2[    58    ]=    -0.03025404    ;
    RnonCO2[    59    ]=    -0.03009594    ;
    RnonCO2[    60    ]=    -0.02991636    ;
    RnonCO2[    61    ]=    -0.02971869    ;
    RnonCO2[    62    ]=    -0.02950042    ;
    RnonCO2[    63    ]=    -0.02926502    ;
    RnonCO2[    64    ]=    -0.02859871    ;
    RnonCO2[    65    ]=    -0.03037359    ;
    RnonCO2[    66    ]=    -0.03172034    ;
    RnonCO2[    67    ]=    -0.03059392    ;
    RnonCO2[    68    ]=    -0.03026959    ;
    RnonCO2[    69    ]=    -0.02993194    ;
    RnonCO2[    70    ]=    -0.02957653    ;
    RnonCO2[    71    ]=    -0.03080027    ;
    RnonCO2[    72    ]=    -0.03160022    ;
    RnonCO2[    73    ]=    -0.03117789    ;
    RnonCO2[    74    ]=    -0.03112982    ;
    RnonCO2[    75    ]=    -0.03144654    ;
    RnonCO2[    76    ]=    -0.03173222    ;
    RnonCO2[    77    ]=    -0.03198224    ;
    RnonCO2[    78    ]=    -0.03220368    ;
    RnonCO2[    79    ]=    -0.03239696    ;
    RnonCO2[    80    ]=    -0.03371239    ;
    RnonCO2[    81    ]=    -0.03424533    ;
    RnonCO2[    82    ]=    -0.0343764    ;
    RnonCO2[    83    ]=    -0.03487942    ;
    RnonCO2[    84    ]=    -0.03536957    ;
    RnonCO2[    85    ]=    -0.03686306    ;
    RnonCO2[    86    ]=    -0.03665392    ;
    RnonCO2[    87    ]=    -0.04248424    ;
    RnonCO2[    88    ]=    -0.04930444    ;
    RnonCO2[    89    ]=    -0.05182621    ;
    RnonCO2[    90    ]=    -0.0542671    ;
    RnonCO2[    91    ]=    -0.05573158    ;
    RnonCO2[    92    ]=    -0.05765815    ;
    RnonCO2[    93    ]=    -0.05821397    ;
    RnonCO2[    94    ]=    -0.06005825    ;
    RnonCO2[    95    ]=    -0.0683501    ;
    RnonCO2[    96    ]=    -0.08104112    ;
    RnonCO2[    97    ]=    -0.07832852    ;
    RnonCO2[    98    ]=    -0.07177024    ;
    RnonCO2[    99    ]=    -0.07363036    ;
    RnonCO2[    100    ]=    -0.07696442    ;
    RnonCO2[    101    ]=    -0.08462429    ;
    RnonCO2[    102    ]=    -0.09275025    ;
    RnonCO2[    103    ]=    -0.09511911    ;
    RnonCO2[    104    ]=    -0.0930339    ;
    RnonCO2[    105    ]=    -0.09237765    ;
    RnonCO2[    106    ]=    -0.10165608    ;
    RnonCO2[    107    ]=    -0.12466661    ;
    RnonCO2[    108    ]=    -0.14405058    ;
    RnonCO2[    109    ]=    -0.14773339    ;
    RnonCO2[    110    ]=    -0.14777672    ;
    RnonCO2[    111    ]=    -0.1470811    ;
    RnonCO2[    112    ]=    -0.14255587    ;
    RnonCO2[    113    ]=    -0.14024698    ;
    RnonCO2[    114    ]=    -0.14393886    ;
    RnonCO2[    115    ]=    -0.15612866    ;
    RnonCO2[    116    ]=    -0.164782    ;
    RnonCO2[    117    ]=    -0.16302445    ;
    RnonCO2[    118    ]=    -0.16326054    ;
    RnonCO2[    119    ]=    -0.16496204    ;
    RnonCO2[    120    ]=    -0.16272157    ;
    RnonCO2[    121    ]=    -0.1612244    ;
    RnonCO2[    122    ]=    -0.16356025    ;
    RnonCO2[    123    ]=    -0.17242315    ;
    RnonCO2[    124    ]=    -0.17632405    ;
    RnonCO2[    125    ]=    -0.17855867    ;
    RnonCO2[    126    ]=    -0.18527891    ;
    RnonCO2[    127    ]=    -0.18997972    ;
    RnonCO2[    128    ]=    -0.1933518    ;
    RnonCO2[    129    ]=    -0.19699663    ;
    RnonCO2[    130    ]=    -0.20233059    ;
    RnonCO2[    131    ]=    -0.2051441    ;
    RnonCO2[    132    ]=    -0.20577589    ;
    RnonCO2[    133    ]=    -0.20720143    ;
    RnonCO2[    134    ]=    -0.21030464    ;
    RnonCO2[    135    ]=    -0.21375193    ;
    RnonCO2[    136    ]=    -0.22004069    ;
    RnonCO2[    137    ]=    -0.22693377    ;
    RnonCO2[    138    ]=    -0.23402972    ;
    RnonCO2[    139    ]=    -0.2411565    ;
    RnonCO2[    140    ]=    -0.2471181    ;
    RnonCO2[    141    ]=    -0.255172    ;
    RnonCO2[    142    ]=    -0.26315304    ;
    RnonCO2[    143    ]=    -0.2636557    ;
    RnonCO2[    144    ]=    -0.26151664    ;
    RnonCO2[    145    ]=    -0.26499499    ;
    RnonCO2[    146    ]=    -0.26461175    ;
    RnonCO2[    147    ]=    -0.26044407    ;
    RnonCO2[    148    ]=    -0.25940869    ;
    RnonCO2[    149    ]=    -0.25560119    ;
    RnonCO2[    150    ]=    -0.25007798    ;
    RnonCO2[    151    ]=    -0.25106379    ;
    RnonCO2[    152    ]=    -0.25437609    ;
    RnonCO2[    153    ]=    -0.25544669    ;
    RnonCO2[    154    ]=    -0.2505011    ;
    RnonCO2[    155    ]=    -0.24919556    ;
    RnonCO2[    156    ]=    -0.24766564    ;
    RnonCO2[    157    ]=    -0.24454174    ;
    RnonCO2[    158    ]=    -0.25504195    ;
    RnonCO2[    159    ]=    -0.26312341    ;
    RnonCO2[    160    ]=    -0.26314088    ;
    RnonCO2[    161    ]=    -0.26376161    ;
    RnonCO2[    162    ]=    -0.26809378    ;
    RnonCO2[    163    ]=    -0.27284291    ;
    RnonCO2[    164    ]=    -0.27584022    ;
    RnonCO2[    165    ]=    -0.27557411    ;
    RnonCO2[    166    ]=    -0.26967283    ;
    RnonCO2[    167    ]=    -0.26315755    ;
    RnonCO2[    168    ]=    -0.26083606    ;
    RnonCO2[    169    ]=    -0.26325195    ;
    RnonCO2[    170    ]=    -0.2652416    ;
    RnonCO2[    171    ]=    -0.26824619    ;
    RnonCO2[    172    ]=    -0.26930622    ;
    RnonCO2[    173    ]=    -0.26149511    ;
    RnonCO2[    174    ]=    -0.25651091    ;
    RnonCO2[    175    ]=    -0.26035065    ;
    RnonCO2[    176    ]=    -0.26656695    ;
    RnonCO2[    177    ]=    -0.27194936    ;
    RnonCO2[    178    ]=    -0.274817    ;
    RnonCO2[    179    ]=    -0.27878403    ;
    RnonCO2[    180    ]=    -0.28302569    ;
    RnonCO2[    181    ]=    -0.29104814    ;
    RnonCO2[    182    ]=    -0.30416561    ;
    RnonCO2[    183    ]=    -0.31716714    ;
    RnonCO2[    184    ]=    -0.3246442    ;
    RnonCO2[    185    ]=    -0.3327935    ;
    RnonCO2[    186    ]=    -0.35639494    ;
    RnonCO2[    187    ]=    -0.38051016    ;
    RnonCO2[    188    ]=    -0.39378465    ;
    RnonCO2[    189    ]=    -0.40659776    ;
    RnonCO2[    190    ]=    -0.4196919    ;
    RnonCO2[    191    ]=    -0.43302942    ;
    RnonCO2[    192    ]=    -0.44651364    ;
    RnonCO2[    193    ]=    -0.45569127    ;
    RnonCO2[    194    ]=    -0.45642498    ;
    RnonCO2[    195    ]=    -0.45551768    ;
    RnonCO2[    196    ]=    -0.47183293    ;
    RnonCO2[    197    ]=    -0.49188519    ;
    RnonCO2[    198    ]=    -0.50135461    ;
    RnonCO2[    199    ]=    -0.5101619    ;
    RnonCO2[    200    ]=    -0.51738459    ;
    RnonCO2[    201    ]=    -0.52416219    ;
    RnonCO2[    202    ]=    -0.53325402    ;
    RnonCO2[    203    ]=    -0.54124791    ;
    RnonCO2[    204    ]=    -0.54379714    ;
    RnonCO2[    205    ]=    -0.53664772    ;
    RnonCO2[    206    ]=    -0.52607217    ;
    RnonCO2[    207    ]=    -0.52739363    ;
    RnonCO2[    208    ]=    -0.53724776    ;
    RnonCO2[    209    ]=    -0.54779467    ;
    RnonCO2[    210    ]=    -0.55942351    ;
    RnonCO2[    211    ]=    -0.57578959    ;
    RnonCO2[    212    ]=    -0.5916702    ;
    RnonCO2[    213    ]=    -0.5979117    ;
    RnonCO2[    214    ]=    -0.6009881    ;
    RnonCO2[    215    ]=    -0.6131431    ;
    RnonCO2[    216    ]=    -0.6319195    ;
    RnonCO2[    217    ]=    -0.6542028    ;
    RnonCO2[    218    ]=    -0.6747946    ;
    RnonCO2[    219    ]=    -0.6865596    ;
    RnonCO2[    220    ]=    -0.6942006    ;
    RnonCO2[    221    ]=    -0.7018816    ;
    RnonCO2[    222    ]=    -0.7121991    ;
    RnonCO2[    223    ]=    -0.7210817    ;
    RnonCO2[    224    ]=    -0.7262596    ;
    RnonCO2[    225    ]=    -0.7299457    ;
    RnonCO2[    226    ]=    -0.7418714    ;
    RnonCO2[    227    ]=    -0.7583892    ;
    RnonCO2[    228    ]=    -0.7656833    ;
    RnonCO2[    229    ]=    -0.768847    ;
    RnonCO2[    230    ]=    -0.7655134    ;
    RnonCO2[    231    ]=    -0.7588829    ;
    RnonCO2[    232    ]=    -0.7657109    ;
    RnonCO2[    233    ]=    -0.7804313    ;
    RnonCO2[    234    ]=    -0.7902367    ;
    RnonCO2[    235    ]=    -0.8012413    ;
    RnonCO2[    236    ]=    -0.8096987    ;
    RnonCO2[    237    ]=    -0.8105819    ;
    RnonCO2[    238    ]=    -0.8112899    ;
    RnonCO2[    239    ]=    -0.8123564    ;
    RnonCO2[    240    ]=    -0.8099077    ;
    RnonCO2[    241    ]=    -0.8000798    ;
    RnonCO2[    242    ]=    -0.7865755    ;
    RnonCO2[    243    ]=    -0.7727582    ;
    RnonCO2[    244    ]=    -0.7584482    ;
    RnonCO2[    245    ]=    -0.7472198    ;
    RnonCO2[    246    ]=    -0.742728    ;
    RnonCO2[    247    ]=    -0.7406136    ;
    RnonCO2[    248    ]=    -0.7377074    ;
    RnonCO2[    249    ]=    -0.7349095    ;
    RnonCO2[    250    ]=    -0.7320007    ;
    RnonCO2[    251    ]=    -0.7289608    ;
    RnonCO2[    252    ]=    -0.7257972    ;
    RnonCO2[    253    ]=    -0.7225277    ;
    RnonCO2[    254    ]=    -0.7187237    ;
    RnonCO2[    255    ]=    -0.7138313    ;
    RnonCO2[    256    ]=    -0.7074799    ;
    RnonCO2[    257    ]=    -0.7011371    ;
    RnonCO2[    258    ]=    -0.6956635    ;
    RnonCO2[    259    ]=    -0.6901843    ;
    RnonCO2[    260    ]=    -0.6846945    ;
    RnonCO2[    261    ]=    -0.6792039    ;
    RnonCO2[    262    ]=    -0.6737169    ;
    RnonCO2[    263    ]=    -0.6682408    ;
    RnonCO2[    264    ]=    -0.6627814    ;
    RnonCO2[    265    ]=    -0.6558025    ;
    RnonCO2[    266    ]=    -0.6457586    ;
    RnonCO2[    267    ]=    -0.6349733    ;
    RnonCO2[    268    ]=    -0.6249181    ;
    RnonCO2[    269    ]=    -0.614736    ;
    RnonCO2[    270    ]=    -0.604427    ;
    RnonCO2[    271    ]=    -0.5939962    ;
    RnonCO2[    272    ]=    -0.5834541    ;
    RnonCO2[    273    ]=    -0.572811    ;
    RnonCO2[    274    ]=    -0.5620802    ;
    RnonCO2[    275    ]=    -0.5516009    ;
    RnonCO2[    276    ]=    -0.5417168    ;
    RnonCO2[    277    ]=    -0.5318895    ;
    RnonCO2[    278    ]=    -0.5218095    ;
    RnonCO2[    279    ]=    -0.5117195    ;
    RnonCO2[    280    ]=    -0.5016219    ;
    RnonCO2[    281    ]=    -0.4915198    ;
    RnonCO2[    282    ]=    -0.4814209    ;
    RnonCO2[    283    ]=    -0.4713374    ;
    RnonCO2[    284    ]=    -0.4612791    ;
    RnonCO2[    285    ]=    -0.4523781    ;
    RnonCO2[    286    ]=    -0.4457713    ;
    RnonCO2[    287    ]=    -0.440062    ;
    RnonCO2[    288    ]=    -0.4341524    ;
    RnonCO2[    289    ]=    -0.4283564    ;
    RnonCO2[    290    ]=    -0.4226727    ;
    RnonCO2[    291    ]=    -0.4170824    ;
    RnonCO2[    292    ]=    -0.4115698    ;
    RnonCO2[    293    ]=    -0.4061213    ;
    RnonCO2[    294    ]=    -0.4007228    ;
    RnonCO2[    295    ]=    -0.3956366    ;
    RnonCO2[    296    ]=    -0.3911326    ;
    RnonCO2[    297    ]=    -0.3868856    ;
    RnonCO2[    298    ]=    -0.3826761    ;
    RnonCO2[    299    ]=    -0.378604    ;
    RnonCO2[    300    ]=    -0.3746703    ;
    RnonCO2[    301    ]=    -0.3708712    ;
    RnonCO2[    302    ]=    -0.3671855    ;
    RnonCO2[    303    ]=    -0.3635951    ;
    RnonCO2[    304    ]=    -0.3600835    ;
    RnonCO2[    305    ]=    -0.3568111    ;
    RnonCO2[    306    ]=    -0.3539465    ;
    RnonCO2[    307    ]=    -0.3512216    ;
    RnonCO2[    308    ]=    -0.3484468    ;
    RnonCO2[    309    ]=    -0.3456989    ;
    RnonCO2[    310    ]=    -0.3429758    ;
    RnonCO2[    311    ]=    -0.3402884    ;
    RnonCO2[    312    ]=    -0.3376425    ;
    RnonCO2[    313    ]=    -0.3350249    ;
    RnonCO2[    314    ]=    -0.3324246    ;
    RnonCO2[    315    ]=    -0.3289265    ;
    RnonCO2[    316    ]=    -0.3236119    ;
    RnonCO2[    317    ]=    -0.3174935    ;
    RnonCO2[    318    ]=    -0.3114646    ;
    RnonCO2[    319    ]=    -0.3053983    ;
    RnonCO2[    320    ]=    -0.2992967    ;
    RnonCO2[    321    ]=    -0.2931615    ;
    RnonCO2[    322    ]=    -0.2870076    ;
    RnonCO2[    323    ]=    -0.2808448    ;
    RnonCO2[    324    ]=    -0.2746629    ;
    RnonCO2[    325    ]=    -0.2693143    ;
    RnonCO2[    326    ]=    -0.2656573    ;
    RnonCO2[    327    ]=    -0.2626709    ;
    RnonCO2[    328    ]=    -0.2595414    ;
    RnonCO2[    329    ]=    -0.2564733    ;
    RnonCO2[    330    ]=    -0.2534625    ;
    RnonCO2[    331    ]=    -0.2505038    ;
    RnonCO2[    332    ]=    -0.2475918    ;
    RnonCO2[    333    ]=    -0.2447355    ;
    RnonCO2[    334    ]=    -0.2419394    ;
    RnonCO2[    335    ]=    -0.2398735    ;
    RnonCO2[    336    ]=    -0.2392144    ;
    RnonCO2[    337    ]=    -0.2390216    ;
    RnonCO2[    338    ]=    -0.2386237    ;
    RnonCO2[    339    ]=    -0.2382894    ;
    RnonCO2[    340    ]=    -0.2380172    ;
    RnonCO2[    341    ]=    -0.2378049    ;
    RnonCO2[    342    ]=    -0.2376482    ;
    RnonCO2[    343    ]=    -0.2375433    ;
    RnonCO2[    344    ]=    -0.2375006    ;
    RnonCO2[    345    ]=    -0.2375257    ;
    RnonCO2[    346    ]=    -0.2376038    ;
    RnonCO2[    347    ]=    -0.2377213    ;
    RnonCO2[    348    ]=    -0.2378659    ;
    RnonCO2[    349    ]=    -0.2380261    ;
    RnonCO2[    350    ]=    -0.2381976    ;
    RnonCO2[    351    ]=    -0.2383834    ;
    RnonCO2[    352    ]=    -0.2385853    ;
    RnonCO2[    353    ]=    -0.2388029    ;
    RnonCO2[    354    ]=    -0.2390356    ;
    RnonCO2[    355    ]=    -0.2392969    ;
    RnonCO2[    356    ]=    -0.2395954    ;
    RnonCO2[    357    ]=    -0.239919    ;
    RnonCO2[    358    ]=    -0.2402557    ;
    RnonCO2[    359    ]=    -0.2405956    ;
    RnonCO2[    360    ]=    -0.2409292    ;
    RnonCO2[    361    ]=    -0.2412561    ;
    RnonCO2[    362    ]=    -0.2415816    ;
    RnonCO2[    363    ]=    -0.2419093    ;
    RnonCO2[    364    ]=    -0.2422403    ;
    RnonCO2[    365    ]=    -0.2425753    ;
    RnonCO2[    366    ]=    -0.2429291    ;
    RnonCO2[    367    ]=    -0.2433117    ;
    RnonCO2[    368    ]=    -0.243712    ;
    RnonCO2[    369    ]=    -0.244119    ;
    RnonCO2[    370    ]=    -0.2445227    ;
    RnonCO2[    371    ]=    -0.244913    ;
    RnonCO2[    372    ]=    -0.2452901    ;
    RnonCO2[    373    ]=    -0.245658    ;
    RnonCO2[    374    ]=    -0.246021    ;
    RnonCO2[    375    ]=    -0.246382    ;
    RnonCO2[    376    ]=    -0.246742    ;
    RnonCO2[    377    ]=    -0.247115    ;
    RnonCO2[    378    ]=    -0.247514    ;
    RnonCO2[    379    ]=    -0.247925    ;
    RnonCO2[    380    ]=    -0.24834    ;
    RnonCO2[    381    ]=    -0.248748    ;
    RnonCO2[    382    ]=    -0.249141    ;
    RnonCO2[    383    ]=    -0.249516    ;
    RnonCO2[    384    ]=    -0.249878    ;
    RnonCO2[    385    ]=    -0.250234    ;
    RnonCO2[    386    ]=    -0.250585    ;
    RnonCO2[    387    ]=    -0.250932    ;
    RnonCO2[    388    ]=    -0.251284    ;
    RnonCO2[    389    ]=    -0.251656    ;
    RnonCO2[    390    ]=    -0.252035    ;
    RnonCO2[    391    ]=    -0.252412    ;
    RnonCO2[    392    ]=    -0.252776    ;
    RnonCO2[    393    ]=    -0.25312    ;
    RnonCO2[    394    ]=    -0.253441    ;
    RnonCO2[    395    ]=    -0.253744    ;
    RnonCO2[    396    ]=    -0.254037    ;
    RnonCO2[    397    ]=    -0.25432    ;
    RnonCO2[    398    ]=    -0.254597    ;
    RnonCO2[    399    ]=    -0.254882    ;
    RnonCO2[    400    ]=    -0.255188    ;
    RnonCO2[    401    ]=    -0.255503    ;
    RnonCO2[    402    ]=    -0.255816    ;
    RnonCO2[    403    ]=    -0.256117    ;
    RnonCO2[    404    ]=    -0.256399    ;
    RnonCO2[    405    ]=    -0.256657    ;
    RnonCO2[    406    ]=    -0.256901    ;
    RnonCO2[    407    ]=    -0.257133    ;
    RnonCO2[    408    ]=    -0.257358    ;
    RnonCO2[    409    ]=    -0.257576    ;
    RnonCO2[    410    ]=    -0.257804    ;
    RnonCO2[    411    ]=    -0.258053    ;
    RnonCO2[    412    ]=    -0.258312    ;
    RnonCO2[    413    ]=    -0.258571    ;
    RnonCO2[    414    ]=    -0.25882    ;
    RnonCO2[    415    ]=    -0.259047    ;
    RnonCO2[    416    ]=    -0.259253    ;
    RnonCO2[    417    ]=    -0.259444    ;
    RnonCO2[    418    ]=    -0.259625    ;
    RnonCO2[    419    ]=    -0.259799    ;
    RnonCO2[    420    ]=    -0.259966    ;
    RnonCO2[    421    ]=    -0.260145    ;
    RnonCO2[    422    ]=    -0.260345    ;
    RnonCO2[    423    ]=    -0.260556    ;
    RnonCO2[    424    ]=    -0.260768    ;
    RnonCO2[    425    ]=    -0.260968    ;
    RnonCO2[    426    ]=    -0.26115    ;
    RnonCO2[    427    ]=    -0.26131    ;
    RnonCO2[    428    ]=    -0.261455    ;
    RnonCO2[    429    ]=    -0.261591    ;
    RnonCO2[    430    ]=    -0.26172    ;
    RnonCO2[    431    ]=    -0.261844    ;
    RnonCO2[    432    ]=    -0.261979    ;
    RnonCO2[    433    ]=    -0.262137    ;
    RnonCO2[    434    ]=    -0.262306    ;
    RnonCO2[    435    ]=    -0.262476    ;
    RnonCO2[    436    ]=    -0.262635    ;
    RnonCO2[    437    ]=    -0.262775    ;
    RnonCO2[    438    ]=    -0.262896    ;
    RnonCO2[    439    ]=    -0.263002    ;
    RnonCO2[    440    ]=    -0.263099    ;
    RnonCO2[    441    ]=    -0.263189    ;
    RnonCO2[    442    ]=    -0.263277    ;
    RnonCO2[    443    ]=    -0.263375    ;
    RnonCO2[    444    ]=    -0.263496    ;
    RnonCO2[    445    ]=    -0.263629    ;
    RnonCO2[    446    ]=    -0.263764    ;
    RnonCO2[    447    ]=    -0.263889    ;
    RnonCO2[    448    ]=    -0.263995    ;
    RnonCO2[    449    ]=    -0.264081    ;
    RnonCO2[    450    ]=    -0.264153    ;
    RnonCO2[    451    ]=    -0.264216    ;
    RnonCO2[    452    ]=    -0.264274    ;
    RnonCO2[    453    ]=    -0.264329    ;
    RnonCO2[    454    ]=    -0.264394    ;
    RnonCO2[    455    ]=    -0.264484    ;
    RnonCO2[    456    ]=    -0.264586    ;
    RnonCO2[    457    ]=    -0.264688    ;
    RnonCO2[    458    ]=    -0.264782    ;
    RnonCO2[    459    ]=    -0.264856    ;
    RnonCO2[    460    ]=    -0.264912    ;
    RnonCO2[    461    ]=    -0.264954    ;
    RnonCO2[    462    ]=    -0.264987    ;
    RnonCO2[    463    ]=    -0.265015    ;
    RnonCO2[    464    ]=    -0.265039    ;
    RnonCO2[    465    ]=    -0.265076    ;
    RnonCO2[    466    ]=    -0.265136    ;
    RnonCO2[    467    ]=    -0.265209    ;
    RnonCO2[    468    ]=    -0.265283    ;
    RnonCO2[    469    ]=    -0.265348    ;
    RnonCO2[    470    ]=    -0.265395    ;
    RnonCO2[    471    ]=    -0.265422    ;
    RnonCO2[    472    ]=    -0.265435    ;
    RnonCO2[    473    ]=    -0.265442    ;
    RnonCO2[    474    ]=    -0.265442    ;
    RnonCO2[    475    ]=    -0.26544    ;
    RnonCO2[    476    ]=    -0.26545    ;
    RnonCO2[    477    ]=    -0.265484    ;
    RnonCO2[    478    ]=    -0.265531    ;
    RnonCO2[    479    ]=    -0.265578    ;
    RnonCO2[    480    ]=    -0.265617    ;
    RnonCO2[    481    ]=    -0.265638    ;
    RnonCO2[    482    ]=    -0.265638    ;
    RnonCO2[    483    ]=    -0.265627    ;
    RnonCO2[    484    ]=    -0.265607    ;
    RnonCO2[    485    ]=    -0.265596    ;
    RnonCO2[    486    ]=    -0.265596    ;
    RnonCO2[    487    ]=    -0.265596    ;
    RnonCO2[    488    ]=    -0.265596    ;
    RnonCO2[    489    ]=    -0.265596    ;
    RnonCO2[    490    ]=    -0.265596    ;
    RnonCO2[    491    ]=    -0.265596    ;
    RnonCO2[    492    ]=    -0.265596    ;
    RnonCO2[    493    ]=    -0.265596    ;
    RnonCO2[    494    ]=    -0.265596    ;
    RnonCO2[    495    ]=    -0.265596    ;
    RnonCO2[    496    ]=    -0.265596    ;
    RnonCO2[    497    ]=    -0.265596    ;
    RnonCO2[    498    ]=    -0.265596    ;
    RnonCO2[    499    ]=    -0.265596    ;
    RnonCO2[    500    ]=    -0.265596    ;
    RnonCO2[    501    ]=    -0.265596    ;
    RnonCO2[    502    ]=    -0.265596    ;
    RnonCO2[    503    ]=    -0.265596    ;
    RnonCO2[    504    ]=    -0.265596    ;
    RnonCO2[    505    ]=    -0.265596    ;
    RnonCO2[    506    ]=    -0.265596    ;
    RnonCO2[    507    ]=    -0.265596    ;
    RnonCO2[    508    ]=    -0.265596    ;
    RnonCO2[    509    ]=    -0.265596    ;
    RnonCO2[    510    ]=    -0.265596    ;
    RnonCO2[    511    ]=    -0.265596    ;
    RnonCO2[    512    ]=    -0.265596    ;
    RnonCO2[    513    ]=    -0.265596    ;
    RnonCO2[    514    ]=    -0.265596    ;
    RnonCO2[    515    ]=    -0.265596    ;
    RnonCO2[    516    ]=    -0.265596    ;
    RnonCO2[    517    ]=    -0.265596    ;
    RnonCO2[    518    ]=    -0.265596    ;
    RnonCO2[    519    ]=    -0.265596    ;
    RnonCO2[    520    ]=    -0.265596    ;
    RnonCO2[    521    ]=    -0.265596    ;
    RnonCO2[    522    ]=    -0.265596    ;
    RnonCO2[    523    ]=    -0.265596    ;
    RnonCO2[    524    ]=    -0.265596    ;
    RnonCO2[    525    ]=    -0.265596    ;
    RnonCO2[    526    ]=    -0.265596    ;
    RnonCO2[    527    ]=    -0.265596    ;
    RnonCO2[    528    ]=    -0.265596    ;
    RnonCO2[    529    ]=    -0.265596    ;
    RnonCO2[    530    ]=    -0.265596    ;
    RnonCO2[    531    ]=    -0.265596    ;
    RnonCO2[    532    ]=    -0.265596    ;
    RnonCO2[    533    ]=    -0.265596    ;
    RnonCO2[    534    ]=    -0.265596    ;
    RnonCO2[    535    ]=    -0.265596    ;
    RnonCO2[    536    ]=    -0.265596    ;
    RnonCO2[    537    ]=    -0.265596    ;
    RnonCO2[    538    ]=    -0.265596    ;
    RnonCO2[    539    ]=    -0.265596    ;
    RnonCO2[    540    ]=    -0.265596    ;
    RnonCO2[    541    ]=    -0.265596    ;
    RnonCO2[    542    ]=    -0.265596    ;
    RnonCO2[    543    ]=    -0.265596    ;
    RnonCO2[    544    ]=    -0.265596    ;
    RnonCO2[    545    ]=    -0.265596    ;
    RnonCO2[    546    ]=    -0.265596    ;
    RnonCO2[    547    ]=    -0.265596    ;
    RnonCO2[    548    ]=    -0.265596    ;
    RnonCO2[    549    ]=    -0.265596    ;
    RnonCO2[    550    ]=    -0.265596    ;
    RnonCO2[    551    ]=    -0.265596    ;
    RnonCO2[    552    ]=    -0.265596    ;
    RnonCO2[    553    ]=    -0.265596    ;
    RnonCO2[    554    ]=    -0.265596    ;
    RnonCO2[    555    ]=    -0.265596    ;
    RnonCO2[    556    ]=    -0.265596    ;
    RnonCO2[    557    ]=    -0.265596    ;
    RnonCO2[    558    ]=    -0.265596    ;
    RnonCO2[    559    ]=    -0.265596    ;
    RnonCO2[    560    ]=    -0.265596    ;
    RnonCO2[    561    ]=    -0.265596    ;
    RnonCO2[    562    ]=    -0.265596    ;
    RnonCO2[    563    ]=    -0.265596    ;
    RnonCO2[    564    ]=    -0.265596    ;
    RnonCO2[    565    ]=    -0.265596    ;
    RnonCO2[    566    ]=    -0.265596    ;
    RnonCO2[    567    ]=    -0.265596    ;
    RnonCO2[    568    ]=    -0.265596    ;
    RnonCO2[    569    ]=    -0.265596    ;
    RnonCO2[    570    ]=    -0.265596    ;
    RnonCO2[    571    ]=    -0.265596    ;
    RnonCO2[    572    ]=    -0.265596    ;
    RnonCO2[    573    ]=    -0.265596    ;
    RnonCO2[    574    ]=    -0.265596    ;
    RnonCO2[    575    ]=    -0.265596    ;
    RnonCO2[    576    ]=    -0.265596    ;
    RnonCO2[    577    ]=    -0.265596    ;
    RnonCO2[    578    ]=    -0.265596    ;
    RnonCO2[    579    ]=    -0.265596    ;
    RnonCO2[    580    ]=    -0.265596    ;
    RnonCO2[    581    ]=    -0.265596    ;
    RnonCO2[    582    ]=    -0.265596    ;
    RnonCO2[    583    ]=    -0.265596    ;
    RnonCO2[    584    ]=    -0.265596    ;
    RnonCO2[    585    ]=    -0.265596    ;
    RnonCO2[    586    ]=    -0.265596    ;
    RnonCO2[    587    ]=    -0.265596    ;
    RnonCO2[    588    ]=    -0.265596    ;
    RnonCO2[    589    ]=    -0.265596    ;
    RnonCO2[    590    ]=    -0.265596    ;
    RnonCO2[    591    ]=    -0.265596    ;
    RnonCO2[    592    ]=    -0.265596    ;
    RnonCO2[    593    ]=    -0.265596    ;
    RnonCO2[    594    ]=    -0.265596    ;
    RnonCO2[    595    ]=    -0.265596    ;
    RnonCO2[    596    ]=    -0.265596    ;
    RnonCO2[    597    ]=    -0.265596    ;
    RnonCO2[    598    ]=    -0.265596    ;
    RnonCO2[    599    ]=    -0.265596    ;
    RnonCO2[    600    ]=    -0.265596    ;
    RnonCO2[    601    ]=    -0.265596    ;
    RnonCO2[    602    ]=    -0.265596    ;
    RnonCO2[    603    ]=    -0.265596    ;
    RnonCO2[    604    ]=    -0.265596    ;
    RnonCO2[    605    ]=    -0.265596    ;
    RnonCO2[    606    ]=    -0.265596    ;
    RnonCO2[    607    ]=    -0.265596    ;
    RnonCO2[    608    ]=    -0.265596    ;
    RnonCO2[    609    ]=    -0.265596    ;
    RnonCO2[    610    ]=    -0.265596    ;
    RnonCO2[    611    ]=    -0.265596    ;
    RnonCO2[    612    ]=    -0.265596    ;
    RnonCO2[    613    ]=    -0.265596    ;
    RnonCO2[    614    ]=    -0.265596    ;
    RnonCO2[    615    ]=    -0.265596    ;
    RnonCO2[    616    ]=    -0.265596    ;
    RnonCO2[    617    ]=    -0.265596    ;
    RnonCO2[    618    ]=    -0.265596    ;
    RnonCO2[    619    ]=    -0.265596    ;
    RnonCO2[    620    ]=    -0.265596    ;
    RnonCO2[    621    ]=    -0.265596    ;
    RnonCO2[    622    ]=    -0.265596    ;
    RnonCO2[    623    ]=    -0.265596    ;
    RnonCO2[    624    ]=    -0.265596    ;
    RnonCO2[    625    ]=    -0.265596    ;
    RnonCO2[    626    ]=    -0.265596    ;
    RnonCO2[    627    ]=    -0.265596    ;
    RnonCO2[    628    ]=    -0.265596    ;
    RnonCO2[    629    ]=    -0.265596    ;
    RnonCO2[    630    ]=    -0.265596    ;
    RnonCO2[    631    ]=    -0.265596    ;
    RnonCO2[    632    ]=    -0.265596    ;
    RnonCO2[    633    ]=    -0.265596    ;
    RnonCO2[    634    ]=    -0.265596    ;
    RnonCO2[    635    ]=    -0.265596    ;
    RnonCO2[    636    ]=    -0.265596    ;
    RnonCO2[    637    ]=    -0.265596    ;
    RnonCO2[    638    ]=    -0.265596    ;
    RnonCO2[    639    ]=    -0.265596    ;
    RnonCO2[    640    ]=    -0.265596    ;
    RnonCO2[    641    ]=    -0.265596    ;
    RnonCO2[    642    ]=    -0.265596    ;
    RnonCO2[    643    ]=    -0.265596    ;
    RnonCO2[    644    ]=    -0.265596    ;
    RnonCO2[    645    ]=    -0.265596    ;
    RnonCO2[    646    ]=    -0.265596    ;
    RnonCO2[    647    ]=    -0.265596    ;
    RnonCO2[    648    ]=    -0.265596    ;
    RnonCO2[    649    ]=    -0.265596    ;
    RnonCO2[    650    ]=    -0.265596    ;
    RnonCO2[    651    ]=    -0.265596    ;
    RnonCO2[    652    ]=    -0.265596    ;
    RnonCO2[    653    ]=    -0.265596    ;
    RnonCO2[    654    ]=    -0.265596    ;
    RnonCO2[    655    ]=    -0.265596    ;
    RnonCO2[    656    ]=    -0.265596    ;
    RnonCO2[    657    ]=    -0.265596    ;
    RnonCO2[    658    ]=    -0.265596    ;
    RnonCO2[    659    ]=    -0.265596    ;
    RnonCO2[    660    ]=    -0.265596    ;
    RnonCO2[    661    ]=    -0.265596    ;
    RnonCO2[    662    ]=    -0.265596    ;
    RnonCO2[    663    ]=    -0.265596    ;
    RnonCO2[    664    ]=    -0.265596    ;
    RnonCO2[    665    ]=    -0.265596    ;
    RnonCO2[    666    ]=    -0.265596    ;
    RnonCO2[    667    ]=    -0.265596    ;
    RnonCO2[    668    ]=    -0.265596    ;
    RnonCO2[    669    ]=    -0.265596    ;
    RnonCO2[    670    ]=    -0.265596    ;
    RnonCO2[    671    ]=    -0.265596    ;
    RnonCO2[    672    ]=    -0.265596    ;
    RnonCO2[    673    ]=    -0.265596    ;
    RnonCO2[    674    ]=    -0.265596    ;
    RnonCO2[    675    ]=    -0.265596    ;
    RnonCO2[    676    ]=    -0.265596    ;
    RnonCO2[    677    ]=    -0.265596    ;
    RnonCO2[    678    ]=    -0.265596    ;
    RnonCO2[    679    ]=    -0.265596    ;
    RnonCO2[    680    ]=    -0.265596    ;
    RnonCO2[    681    ]=    -0.265596    ;
    RnonCO2[    682    ]=    -0.265596    ;
    RnonCO2[    683    ]=    -0.265596    ;
    RnonCO2[    684    ]=    -0.265596    ;
    RnonCO2[    685    ]=    -0.265596    ;
    RnonCO2[    686    ]=    -0.265596    ;
    RnonCO2[    687    ]=    -0.265596    ;
    RnonCO2[    688    ]=    -0.265596    ;
    RnonCO2[    689    ]=    -0.265596    ;
    RnonCO2[    690    ]=    -0.265596    ;
    RnonCO2[    691    ]=    -0.265596    ;
    RnonCO2[    692    ]=    -0.265596    ;
    RnonCO2[    693    ]=    -0.265596    ;
    RnonCO2[    694    ]=    -0.265596    ;
    RnonCO2[    695    ]=    -0.265596    ;
    RnonCO2[    696    ]=    -0.265596    ;
    RnonCO2[    697    ]=    -0.265596    ;
    RnonCO2[    698    ]=    -0.265596    ;
    RnonCO2[    699    ]=    -0.265596    ;
    RnonCO2[    700    ]=    -0.265596    ;
    RnonCO2[    701    ]=    -0.265596    ;
    RnonCO2[    702    ]=    -0.265596    ;
    RnonCO2[    703    ]=    -0.265596    ;
    RnonCO2[    704    ]=    -0.265596    ;
    RnonCO2[    705    ]=    -0.265596    ;
    RnonCO2[    706    ]=    -0.265596    ;
    RnonCO2[    707    ]=    -0.265596    ;
    RnonCO2[    708    ]=    -0.265596    ;
    RnonCO2[    709    ]=    -0.265596    ;
    RnonCO2[    710    ]=    -0.265596    ;
    RnonCO2[    711    ]=    -0.265596    ;
    RnonCO2[    712    ]=    -0.265596    ;
    RnonCO2[    713    ]=    -0.265596    ;
    RnonCO2[    714    ]=    -0.265596    ;
    RnonCO2[    715    ]=    -0.265596    ;
    RnonCO2[    716    ]=    -0.265596    ;
    RnonCO2[    717    ]=    -0.265596    ;
    RnonCO2[    718    ]=    -0.265596    ;
    RnonCO2[    719    ]=    -0.265596    ;
    RnonCO2[    720    ]=    -0.265596    ;
    RnonCO2[    721    ]=    -0.265596    ;
    RnonCO2[    722    ]=    -0.265596    ;
    RnonCO2[    723    ]=    -0.265596    ;
    RnonCO2[    724    ]=    -0.265596    ;
    RnonCO2[    725    ]=    -0.265596    ;
    RnonCO2[    726    ]=    -0.265596    ;
    RnonCO2[    727    ]=    -0.265596    ;
    RnonCO2[    728    ]=    -0.265596    ;
    RnonCO2[    729    ]=    -0.265596    ;
    RnonCO2[    730    ]=    -0.265596    ;
    RnonCO2[    731    ]=    -0.265596    ;
    RnonCO2[    732    ]=    -0.265596    ;
    RnonCO2[    733    ]=    -0.265596    ;
    RnonCO2[    734    ]=    -0.265596    ;
    RnonCO2[    735    ]=    -0.265596    ;
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
}

void setR_volcanic(void)
{
    RnonCO2[    0    ]=    0    ;
    RnonCO2[    1    ]=    0.11622211    ;
    RnonCO2[    2    ]=    0.23244422    ;
    RnonCO2[    3    ]=    0.19744422    ;
    RnonCO2[    4    ]=    0.13181922    ;
    RnonCO2[    5    ]=    0.12744422    ;
    RnonCO2[    6    ]=    0.17994422    ;
    RnonCO2[    7    ]=    0.21494422    ;
    RnonCO2[    8    ]=    0.22806922    ;
    RnonCO2[    9    ]=    0.23244422    ;
    RnonCO2[    10    ]=    0.23244422    ;
    RnonCO2[    11    ]=    0.23244422    ;
    RnonCO2[    12    ]=    0.23244422    ;
    RnonCO2[    13    ]=    0.23244422    ;
    RnonCO2[    14    ]=    0.23244422    ;
    RnonCO2[    15    ]=    0.23244422    ;
    RnonCO2[    16    ]=    0.23244422    ;
    RnonCO2[    17    ]=    0.21056922    ;
    RnonCO2[    18    ]=    0.11869422    ;
    RnonCO2[    19    ]=    0.044319219    ;
    RnonCO2[    20    ]=    0.10119422    ;
    RnonCO2[    21    ]=    0.18869422    ;
    RnonCO2[    22    ]=    0.22369422    ;
    RnonCO2[    23    ]=    0.22806922    ;
    RnonCO2[    24    ]=    0.12306922    ;
    RnonCO2[    25    ]=    -0.025680781    ;
    RnonCO2[    26    ]=    0.009319219    ;
    RnonCO2[    27    ]=    0.14056922    ;
    RnonCO2[    28    ]=    0.20619422    ;
    RnonCO2[    29    ]=    0.21494422    ;
    RnonCO2[    30    ]=    0.19306922    ;
    RnonCO2[    31    ]=    0.18869422    ;
    RnonCO2[    32    ]=    0.21056922    ;
    RnonCO2[    33    ]=    0.22806922    ;
    RnonCO2[    34    ]=    0.23244422    ;
    RnonCO2[    35    ]=    0.23244422    ;
    RnonCO2[    36    ]=    0.23244422    ;
    RnonCO2[    37    ]=    0.23244422    ;
    RnonCO2[    38    ]=    0.23244422    ;
    RnonCO2[    39    ]=    0.23244422    ;
    RnonCO2[    40    ]=    0.23244422    ;
    RnonCO2[    41    ]=    0.23244422    ;
    RnonCO2[    42    ]=    0.23244422    ;
    RnonCO2[    43    ]=    -0.25755578    ;
    RnonCO2[    44    ]=    -1.3994308    ;
    RnonCO2[    45    ]=    -1.8019308    ;
    RnonCO2[    46    ]=    -1.0100558    ;
    RnonCO2[    47    ]=    -0.34068078    ;
    RnonCO2[    48    ]=    -0.14818078    ;
    RnonCO2[    49    ]=    -0.67755578    ;
    RnonCO2[    50    ]=    -2.1519308    ;
    RnonCO2[    51    ]=    -2.6638058    ;
    RnonCO2[    52    ]=    -1.4956808    ;
    RnonCO2[    53    ]=    -0.36255578    ;
    RnonCO2[    54    ]=    0.092444219    ;
    RnonCO2[    55    ]=    0.22369422    ;
    RnonCO2[    56    ]=    0.23244422    ;
    RnonCO2[    57    ]=    0.23244422    ;
    RnonCO2[    58    ]=    0.23244422    ;
    RnonCO2[    59    ]=    0.23244422    ;
    RnonCO2[    60    ]=    0.23244422    ;
    RnonCO2[    61    ]=    0.23244422    ;
    RnonCO2[    62    ]=    0.23244422    ;
    RnonCO2[    63    ]=    0.22806922    ;
    RnonCO2[    64    ]=    0.19306922    ;
    RnonCO2[    65    ]=    -0.021305781    ;
    RnonCO2[    66    ]=    -0.39755578    ;
    RnonCO2[    67    ]=    -0.48505578    ;
    RnonCO2[    68    ]=    -0.18318078    ;
    RnonCO2[    69    ]=    -0.34505578    ;
    RnonCO2[    70    ]=    -0.98818078    ;
    RnonCO2[    71    ]=    -0.94880578    ;
    RnonCO2[    72    ]=    -0.34943078    ;
    RnonCO2[    73    ]=    0.044319219    ;
    RnonCO2[    74    ]=    0.17994422    ;
    RnonCO2[    75    ]=    0.17994422    ;
    RnonCO2[    76    ]=    0.17556922    ;
    RnonCO2[    77    ]=    0.18869422    ;
    RnonCO2[    78    ]=    0.16681922    ;
    RnonCO2[    79    ]=    0.15369422    ;
    RnonCO2[    80    ]=    0.18431922    ;
    RnonCO2[    81    ]=    0.21494422    ;
    RnonCO2[    82    ]=    0.22806922    ;
    RnonCO2[    83    ]=    0.23244422    ;
    RnonCO2[    84    ]=    0.21599422    ;
    RnonCO2[    85    ]=    0.19200464    ;
    RnonCO2[    86    ]=    0.19303276    ;
    RnonCO2[    87    ]=    0.20879734    ;
    RnonCO2[    88    ]=    0.2235338    ;
    RnonCO2[    89    ]=    0.2317588    ;
    RnonCO2[    90    ]=    0.10118693    ;
    RnonCO2[    91    ]=    -0.35667141    ;
    RnonCO2[    92    ]=    -0.61027557    ;
    RnonCO2[    93    ]=    -0.29772557    ;
    RnonCO2[    94    ]=    0.028190052    ;
    RnonCO2[    95    ]=    0.15053693    ;
    RnonCO2[    96    ]=    0.13957026    ;
    RnonCO2[    97    ]=    0.05526401    ;
    RnonCO2[    98    ]=    0.06760151    ;
    RnonCO2[    99    ]=    0.15087964    ;
    RnonCO2[    100    ]=    0.19851609    ;
    RnonCO2[    101    ]=    0.21907859    ;
    RnonCO2[    102    ]=    0.22901714    ;
    RnonCO2[    103    ]=    0.23107339    ;
    RnonCO2[    104    ]=    0.22284839    ;
    RnonCO2[    105    ]=    0.21873589    ;
    RnonCO2[    106    ]=    0.2194213    ;
    RnonCO2[    107    ]=    0.2070838    ;
    RnonCO2[    108    ]=    0.19337547    ;
    RnonCO2[    109    ]=    0.20125776    ;
    RnonCO2[    110    ]=    0.19406089    ;
    RnonCO2[    111    ]=    0.15293589    ;
    RnonCO2[    112    ]=    0.14848068    ;
    RnonCO2[    113    ]=    0.18035255    ;
    RnonCO2[    114    ]=    0.20194318    ;
    RnonCO2[    115    ]=    0.21565151    ;
    RnonCO2[    116    ]=    0.22284839    ;
    RnonCO2[    117    ]=    0.11112547    ;
    RnonCO2[    118    ]=    -0.80253495    ;
    RnonCO2[    119    ]=    -1.5373016    ;
    RnonCO2[    120    ]=    -0.94407349    ;
    RnonCO2[    121    ]=    -0.44851724    ;
    RnonCO2[    122    ]=    -0.32137245    ;
    RnonCO2[    123    ]=    -0.21102036    ;
    RnonCO2[    124    ]=    -0.27750578    ;
    RnonCO2[    125    ]=    -0.3316537    ;
    RnonCO2[    126    ]=    -0.2617412    ;
    RnonCO2[    127    ]=    -0.087645365    ;
    RnonCO2[    128    ]=    0.060061927    ;
    RnonCO2[    129    ]=    0.16938589    ;
    RnonCO2[    130    ]=    0.1618463    ;
    RnonCO2[    131    ]=    0.016537969    ;
    RnonCO2[    132    ]=    -0.064683906    ;
    RnonCO2[    133    ]=    0.037785885    ;
    RnonCO2[    134    ]=    0.15053693    ;
    RnonCO2[    135    ]=    0.20194318    ;
    RnonCO2[    136    ]=    0.19166193    ;
    RnonCO2[    137    ]=    -0.25694328    ;
    RnonCO2[    138    ]=    -0.65105786    ;
    RnonCO2[    139    ]=    -0.3563287    ;
    RnonCO2[    140    ]=    0.002144219    ;
    RnonCO2[    141    ]=    0.1001588    ;
    RnonCO2[    142    ]=    0.076169219    ;
    RnonCO2[    143    ]=    0.087821302    ;
    RnonCO2[    144    ]=    0.15396401    ;
    RnonCO2[    145    ]=    0.18892026    ;
    RnonCO2[    146    ]=    0.19508901    ;
    RnonCO2[    147    ]=    -0.048576615    ;
    RnonCO2[    148    ]=    -0.15652974    ;
    RnonCO2[    149    ]=    0.055606719    ;
    RnonCO2[    150    ]=    0.15944734    ;
    RnonCO2[    151    ]=    0.18754943    ;
    RnonCO2[    152    ]=    0.19611714    ;
    RnonCO2[    153    ]=    0.20194318    ;
    RnonCO2[    154    ]=    0.1947463    ;
    RnonCO2[    155    ]=    0.11078276    ;
    RnonCO2[    156    ]=    0.095703594    ;
    RnonCO2[    157    ]=    0.18103797    ;
    RnonCO2[    158    ]=    0.20228589    ;
    RnonCO2[    159    ]=    0.18926297    ;
    RnonCO2[    160    ]=    0.18926297    ;
    RnonCO2[    161    ]=    0.19714526    ;
    RnonCO2[    162    ]=    0.19508901    ;
    RnonCO2[    163    ]=    0.14573901    ;
    RnonCO2[    164    ]=    0.096046302    ;
    RnonCO2[    165    ]=    0.12174943    ;
    RnonCO2[    166    ]=    0.14642443    ;
    RnonCO2[    167    ]=    0.11489526    ;
    RnonCO2[    168    ]=    0.12380568    ;
    RnonCO2[    169    ]=    0.16218901    ;
    RnonCO2[    170    ]=    0.16938589    ;
    RnonCO2[    171    ]=    0.18069526    ;
    RnonCO2[    172    ]=    0.17932443    ;
    RnonCO2[    173    ]=    0.16321714    ;
    RnonCO2[    174    ]=    0.16390255    ;
    RnonCO2[    175    ]=    0.18377964    ;
    RnonCO2[    176    ]=    0.19303276    ;
    RnonCO2[    177    ]=    0.17144214    ;
    RnonCO2[    178    ]=    0.16630151    ;
    RnonCO2[    179    ]=    0.18926297    ;
    RnonCO2[    180    ]=    0.19988693    ;
    RnonCO2[    181    ]=    0.2070838    ;
    RnonCO2[    182    ]=    0.1988588    ;
    RnonCO2[    183    ]=    0.19680255    ;
    RnonCO2[    184    ]=    0.18926297    ;
    RnonCO2[    185    ]=    0.18686401    ;
    RnonCO2[    186    ]=    0.1906338    ;
    RnonCO2[    187    ]=    0.18446505    ;
    RnonCO2[    188    ]=    0.17555464    ;
    RnonCO2[    189    ]=    0.18069526    ;
    RnonCO2[    190    ]=    0.2029713    ;
    RnonCO2[    191    ]=    0.2153088    ;
    RnonCO2[    192    ]=    0.22559005    ;
    RnonCO2[    193    ]=    0.23073068    ;
    RnonCO2[    194    ]=    0.22696089    ;
    RnonCO2[    195    ]=    0.15190776    ;
    RnonCO2[    196    ]=    0.060747344    ;
    RnonCO2[    197    ]=    -0.013963073    ;
    RnonCO2[    198    ]=    -0.49546828    ;
    RnonCO2[    199    ]=    -0.85325578    ;
    RnonCO2[    200    ]=    -0.53248078    ;
    RnonCO2[    201    ]=    -0.15001828    ;
    RnonCO2[    202    ]=    -0.021502656    ;
    RnonCO2[    203    ]=    -0.22027349    ;
    RnonCO2[    204    ]=    -0.29635474    ;
    RnonCO2[    205    ]=    -0.055430781    ;
    RnonCO2[    206    ]=    0.11420984    ;
    RnonCO2[    207    ]=    0.15327859    ;
    RnonCO2[    208    ]=    0.10632755    ;
    RnonCO2[    209    ]=    -0.040694323    ;
    RnonCO2[    210    ]=    -0.14110786    ;
    RnonCO2[    211    ]=    -0.017390156    ;
    RnonCO2[    212    ]=    0.13408693    ;
    RnonCO2[    213    ]=    0.10906922    ;
    RnonCO2[    214    ]=    0.093990052    ;
    RnonCO2[    215    ]=    0.14813797    ;
    RnonCO2[    216    ]=    0.079596302    ;
    RnonCO2[    217    ]=    -0.59142661    ;
    RnonCO2[    218    ]=    -0.87621724    ;
    RnonCO2[    219    ]=    -0.32000161    ;
    RnonCO2[    220    ]=    -0.023216198    ;
    RnonCO2[    221    ]=    0.035044219    ;
    RnonCO2[    222    ]=    0.065887969    ;
    RnonCO2[    223    ]=    0.10598484    ;
    RnonCO2[    224    ]=    0.12928901    ;
    RnonCO2[    225    ]=    0.12654734    ;
    RnonCO2[    226    ]=    -0.81487245    ;
    RnonCO2[    227    ]=    -1.4197527    ;
    RnonCO2[    228    ]=    -0.68190161    ;
    RnonCO2[    229    ]=    -0.13151203    ;
    RnonCO2[    230    ]=    0.058691094    ;
    RnonCO2[    231    ]=    0.12380568    ;
    RnonCO2[    232    ]=    0.15327859    ;
    RnonCO2[    233    ]=    0.18754943    ;
    RnonCO2[    234    ]=    0.21633693    ;
    RnonCO2[    235    ]=    0.22867443    ;
    RnonCO2[    236    ]=    0.23244422    ;
    RnonCO2[    237    ]=    0.23244422    ;
    RnonCO2[    238    ]=    0.23244422    ;
    RnonCO2[    239    ]=    0.23244422    ;
    RnonCO2[    240    ]=    0.18401834    ;
    RnonCO2[    241    ]=    0.06779623    ;
    RnonCO2[    242    ]=    0    ;
    RnonCO2[    243    ]=    0    ;
    RnonCO2[    244    ]=    0    ;
    RnonCO2[    245    ]=    0    ;
    RnonCO2[    246    ]=    0    ;
    RnonCO2[    247    ]=    0    ;
    RnonCO2[    248    ]=    0    ;
    RnonCO2[    249    ]=    0    ;
    RnonCO2[    250    ]=    0    ;
    RnonCO2[    251    ]=    0    ;
    RnonCO2[    252    ]=    0    ;
    RnonCO2[    253    ]=    0    ;
    RnonCO2[    254    ]=    0    ;
    RnonCO2[    255    ]=    0    ;
    RnonCO2[    256    ]=    0    ;
    RnonCO2[    257    ]=    0    ;
    RnonCO2[    258    ]=    0    ;
    RnonCO2[    259    ]=    0    ;
    RnonCO2[    260    ]=    0    ;
    RnonCO2[    261    ]=    0    ;
    RnonCO2[    262    ]=    0    ;
    RnonCO2[    263    ]=    0    ;
    RnonCO2[    264    ]=    0    ;
    RnonCO2[    265    ]=    0    ;
    RnonCO2[    266    ]=    0    ;
    RnonCO2[    267    ]=    0    ;
    RnonCO2[    268    ]=    0    ;
    RnonCO2[    269    ]=    0    ;
    RnonCO2[    270    ]=    0    ;
    RnonCO2[    271    ]=    0    ;
    RnonCO2[    272    ]=    0    ;
    RnonCO2[    273    ]=    0    ;
    RnonCO2[    274    ]=    0    ;
    RnonCO2[    275    ]=    0    ;
    RnonCO2[    276    ]=    0    ;
    RnonCO2[    277    ]=    0    ;
    RnonCO2[    278    ]=    0    ;
    RnonCO2[    279    ]=    0    ;
    RnonCO2[    280    ]=    0    ;
    RnonCO2[    281    ]=    0    ;
    RnonCO2[    282    ]=    0    ;
    RnonCO2[    283    ]=    0    ;
    RnonCO2[    284    ]=    0    ;
    RnonCO2[    285    ]=    0    ;
    RnonCO2[    286    ]=    0    ;
    RnonCO2[    287    ]=    0    ;
    RnonCO2[    288    ]=    0    ;
    RnonCO2[    289    ]=    0    ;
    RnonCO2[    290    ]=    0    ;
    RnonCO2[    291    ]=    0    ;
    RnonCO2[    292    ]=    0    ;
    RnonCO2[    293    ]=    0    ;
    RnonCO2[    294    ]=    0    ;
    RnonCO2[    295    ]=    0    ;
    RnonCO2[    296    ]=    0    ;
    RnonCO2[    297    ]=    0    ;
    RnonCO2[    298    ]=    0    ;
    RnonCO2[    299    ]=    0    ;
    RnonCO2[    300    ]=    0    ;
    RnonCO2[    301    ]=    0    ;
    RnonCO2[    302    ]=    0    ;
    RnonCO2[    303    ]=    0    ;
    RnonCO2[    304    ]=    0    ;
    RnonCO2[    305    ]=    0    ;
    RnonCO2[    306    ]=    0    ;
    RnonCO2[    307    ]=    0    ;
    RnonCO2[    308    ]=    0    ;
    RnonCO2[    309    ]=    0    ;
    RnonCO2[    310    ]=    0    ;
    RnonCO2[    311    ]=    0    ;
    RnonCO2[    312    ]=    0    ;
    RnonCO2[    313    ]=    0    ;
    RnonCO2[    314    ]=    0    ;
    RnonCO2[    315    ]=    0    ;
    RnonCO2[    316    ]=    0    ;
    RnonCO2[    317    ]=    0    ;
    RnonCO2[    318    ]=    0    ;
    RnonCO2[    319    ]=    0    ;
    RnonCO2[    320    ]=    0    ;
    RnonCO2[    321    ]=    0    ;
    RnonCO2[    322    ]=    0    ;
    RnonCO2[    323    ]=    0    ;
    RnonCO2[    324    ]=    0    ;
    RnonCO2[    325    ]=    0    ;
    RnonCO2[    326    ]=    0    ;
    RnonCO2[    327    ]=    0    ;
    RnonCO2[    328    ]=    0    ;
    RnonCO2[    329    ]=    0    ;
    RnonCO2[    330    ]=    0    ;
    RnonCO2[    331    ]=    0    ;
    RnonCO2[    332    ]=    0    ;
    RnonCO2[    333    ]=    0    ;
    RnonCO2[    334    ]=    0    ;
    RnonCO2[    335    ]=    0    ;
    RnonCO2[    336    ]=    0    ;
    RnonCO2[    337    ]=    0    ;
    RnonCO2[    338    ]=    0    ;
    RnonCO2[    339    ]=    0    ;
    RnonCO2[    340    ]=    0    ;
    RnonCO2[    341    ]=    0    ;
    RnonCO2[    342    ]=    0    ;
    RnonCO2[    343    ]=    0    ;
    RnonCO2[    344    ]=    0    ;
    RnonCO2[    345    ]=    0    ;
    RnonCO2[    346    ]=    0    ;
    RnonCO2[    347    ]=    0    ;
    RnonCO2[    348    ]=    0    ;
    RnonCO2[    349    ]=    0    ;
    RnonCO2[    350    ]=    0    ;
    RnonCO2[    351    ]=    0    ;
    RnonCO2[    352    ]=    0    ;
    RnonCO2[    353    ]=    0    ;
    RnonCO2[    354    ]=    0    ;
    RnonCO2[    355    ]=    0    ;
    RnonCO2[    356    ]=    0    ;
    RnonCO2[    357    ]=    0    ;
    RnonCO2[    358    ]=    0    ;
    RnonCO2[    359    ]=    0    ;
    RnonCO2[    360    ]=    0    ;
    RnonCO2[    361    ]=    0    ;
    RnonCO2[    362    ]=    0    ;
    RnonCO2[    363    ]=    0    ;
    RnonCO2[    364    ]=    0    ;
    RnonCO2[    365    ]=    0    ;
    RnonCO2[    366    ]=    0    ;
    RnonCO2[    367    ]=    0    ;
    RnonCO2[    368    ]=    0    ;
    RnonCO2[    369    ]=    0    ;
    RnonCO2[    370    ]=    0    ;
    RnonCO2[    371    ]=    0    ;
    RnonCO2[    372    ]=    0    ;
    RnonCO2[    373    ]=    0    ;
    RnonCO2[    374    ]=    0    ;
    RnonCO2[    375    ]=    0    ;
    RnonCO2[    376    ]=    0    ;
    RnonCO2[    377    ]=    0    ;
    RnonCO2[    378    ]=    0    ;
    RnonCO2[    379    ]=    0    ;
    RnonCO2[    380    ]=    0    ;
    RnonCO2[    381    ]=    0    ;
    RnonCO2[    382    ]=    0    ;
    RnonCO2[    383    ]=    0    ;
    RnonCO2[    384    ]=    0    ;
    RnonCO2[    385    ]=    0    ;
    RnonCO2[    386    ]=    0    ;
    RnonCO2[    387    ]=    0    ;
    RnonCO2[    388    ]=    0    ;
    RnonCO2[    389    ]=    0    ;
    RnonCO2[    390    ]=    0    ;
    RnonCO2[    391    ]=    0    ;
    RnonCO2[    392    ]=    0    ;
    RnonCO2[    393    ]=    0    ;
    RnonCO2[    394    ]=    0    ;
    RnonCO2[    395    ]=    0    ;
    RnonCO2[    396    ]=    0    ;
    RnonCO2[    397    ]=    0    ;
    RnonCO2[    398    ]=    0    ;
    RnonCO2[    399    ]=    0    ;
    RnonCO2[    400    ]=    0    ;
    RnonCO2[    401    ]=    0    ;
    RnonCO2[    402    ]=    0    ;
    RnonCO2[    403    ]=    0    ;
    RnonCO2[    404    ]=    0    ;
    RnonCO2[    405    ]=    0    ;
    RnonCO2[    406    ]=    0    ;
    RnonCO2[    407    ]=    0    ;
    RnonCO2[    408    ]=    0    ;
    RnonCO2[    409    ]=    0    ;
    RnonCO2[    410    ]=    0    ;
    RnonCO2[    411    ]=    0    ;
    RnonCO2[    412    ]=    0    ;
    RnonCO2[    413    ]=    0    ;
    RnonCO2[    414    ]=    0    ;
    RnonCO2[    415    ]=    0    ;
    RnonCO2[    416    ]=    0    ;
    RnonCO2[    417    ]=    0    ;
    RnonCO2[    418    ]=    0    ;
    RnonCO2[    419    ]=    0    ;
    RnonCO2[    420    ]=    0    ;
    RnonCO2[    421    ]=    0    ;
    RnonCO2[    422    ]=    0    ;
    RnonCO2[    423    ]=    0    ;
    RnonCO2[    424    ]=    0    ;
    RnonCO2[    425    ]=    0    ;
    RnonCO2[    426    ]=    0    ;
    RnonCO2[    427    ]=    0    ;
    RnonCO2[    428    ]=    0    ;
    RnonCO2[    429    ]=    0    ;
    RnonCO2[    430    ]=    0    ;
    RnonCO2[    431    ]=    0    ;
    RnonCO2[    432    ]=    0    ;
    RnonCO2[    433    ]=    0    ;
    RnonCO2[    434    ]=    0    ;
    RnonCO2[    435    ]=    0    ;
    RnonCO2[    436    ]=    0    ;
    RnonCO2[    437    ]=    0    ;
    RnonCO2[    438    ]=    0    ;
    RnonCO2[    439    ]=    0    ;
    RnonCO2[    440    ]=    0    ;
    RnonCO2[    441    ]=    0    ;
    RnonCO2[    442    ]=    0    ;
    RnonCO2[    443    ]=    0    ;
    RnonCO2[    444    ]=    0    ;
    RnonCO2[    445    ]=    0    ;
    RnonCO2[    446    ]=    0    ;
    RnonCO2[    447    ]=    0    ;
    RnonCO2[    448    ]=    0    ;
    RnonCO2[    449    ]=    0    ;
    RnonCO2[    450    ]=    0    ;
    RnonCO2[    451    ]=    0    ;
    RnonCO2[    452    ]=    0    ;
    RnonCO2[    453    ]=    0    ;
    RnonCO2[    454    ]=    0    ;
    RnonCO2[    455    ]=    0    ;
    RnonCO2[    456    ]=    0    ;
    RnonCO2[    457    ]=    0    ;
    RnonCO2[    458    ]=    0    ;
    RnonCO2[    459    ]=    0    ;
    RnonCO2[    460    ]=    0    ;
    RnonCO2[    461    ]=    0    ;
    RnonCO2[    462    ]=    0    ;
    RnonCO2[    463    ]=    0    ;
    RnonCO2[    464    ]=    0    ;
    RnonCO2[    465    ]=    0    ;
    RnonCO2[    466    ]=    0    ;
    RnonCO2[    467    ]=    0    ;
    RnonCO2[    468    ]=    0    ;
    RnonCO2[    469    ]=    0    ;
    RnonCO2[    470    ]=    0    ;
    RnonCO2[    471    ]=    0    ;
    RnonCO2[    472    ]=    0    ;
    RnonCO2[    473    ]=    0    ;
    RnonCO2[    474    ]=    0    ;
    RnonCO2[    475    ]=    0    ;
    RnonCO2[    476    ]=    0    ;
    RnonCO2[    477    ]=    0    ;
    RnonCO2[    478    ]=    0    ;
    RnonCO2[    479    ]=    0    ;
    RnonCO2[    480    ]=    0    ;
    RnonCO2[    481    ]=    0    ;
    RnonCO2[    482    ]=    0    ;
    RnonCO2[    483    ]=    0    ;
    RnonCO2[    484    ]=    0    ;
    RnonCO2[    485    ]=    0    ;
    RnonCO2[    486    ]=    0    ;
    RnonCO2[    487    ]=    0    ;
    RnonCO2[    488    ]=    0    ;
    RnonCO2[    489    ]=    0    ;
    RnonCO2[    490    ]=    0    ;
    RnonCO2[    491    ]=    0    ;
    RnonCO2[    492    ]=    0    ;
    RnonCO2[    493    ]=    0    ;
    RnonCO2[    494    ]=    0    ;
    RnonCO2[    495    ]=    0    ;
    RnonCO2[    496    ]=    0    ;
    RnonCO2[    497    ]=    0    ;
    RnonCO2[    498    ]=    0    ;
    RnonCO2[    499    ]=    0    ;
    RnonCO2[    500    ]=    0    ;
    RnonCO2[    501    ]=    0    ;
    RnonCO2[    502    ]=    0    ;
    RnonCO2[    503    ]=    0    ;
    RnonCO2[    504    ]=    0    ;
    RnonCO2[    505    ]=    0    ;
    RnonCO2[    506    ]=    0    ;
    RnonCO2[    507    ]=    0    ;
    RnonCO2[    508    ]=    0    ;
    RnonCO2[    509    ]=    0    ;
    RnonCO2[    510    ]=    0    ;
    RnonCO2[    511    ]=    0    ;
    RnonCO2[    512    ]=    0    ;
    RnonCO2[    513    ]=    0    ;
    RnonCO2[    514    ]=    0    ;
    RnonCO2[    515    ]=    0    ;
    RnonCO2[    516    ]=    0    ;
    RnonCO2[    517    ]=    0    ;
    RnonCO2[    518    ]=    0    ;
    RnonCO2[    519    ]=    0    ;
    RnonCO2[    520    ]=    0    ;
    RnonCO2[    521    ]=    0    ;
    RnonCO2[    522    ]=    0    ;
    RnonCO2[    523    ]=    0    ;
    RnonCO2[    524    ]=    0    ;
    RnonCO2[    525    ]=    0    ;
    RnonCO2[    526    ]=    0    ;
    RnonCO2[    527    ]=    0    ;
    RnonCO2[    528    ]=    0    ;
    RnonCO2[    529    ]=    0    ;
    RnonCO2[    530    ]=    0    ;
    RnonCO2[    531    ]=    0    ;
    RnonCO2[    532    ]=    0    ;
    RnonCO2[    533    ]=    0    ;
    RnonCO2[    534    ]=    0    ;
    RnonCO2[    535    ]=    0    ;
    RnonCO2[    536    ]=    0    ;
    RnonCO2[    537    ]=    0    ;
    RnonCO2[    538    ]=    0    ;
    RnonCO2[    539    ]=    0    ;
    RnonCO2[    540    ]=    0    ;
    RnonCO2[    541    ]=    0    ;
    RnonCO2[    542    ]=    0    ;
    RnonCO2[    543    ]=    0    ;
    RnonCO2[    544    ]=    0    ;
    RnonCO2[    545    ]=    0    ;
    RnonCO2[    546    ]=    0    ;
    RnonCO2[    547    ]=    0    ;
    RnonCO2[    548    ]=    0    ;
    RnonCO2[    549    ]=    0    ;
    RnonCO2[    550    ]=    0    ;
    RnonCO2[    551    ]=    0    ;
    RnonCO2[    552    ]=    0    ;
    RnonCO2[    553    ]=    0    ;
    RnonCO2[    554    ]=    0    ;
    RnonCO2[    555    ]=    0    ;
    RnonCO2[    556    ]=    0    ;
    RnonCO2[    557    ]=    0    ;
    RnonCO2[    558    ]=    0    ;
    RnonCO2[    559    ]=    0    ;
    RnonCO2[    560    ]=    0    ;
    RnonCO2[    561    ]=    0    ;
    RnonCO2[    562    ]=    0    ;
    RnonCO2[    563    ]=    0    ;
    RnonCO2[    564    ]=    0    ;
    RnonCO2[    565    ]=    0    ;
    RnonCO2[    566    ]=    0    ;
    RnonCO2[    567    ]=    0    ;
    RnonCO2[    568    ]=    0    ;
    RnonCO2[    569    ]=    0    ;
    RnonCO2[    570    ]=    0    ;
    RnonCO2[    571    ]=    0    ;
    RnonCO2[    572    ]=    0    ;
    RnonCO2[    573    ]=    0    ;
    RnonCO2[    574    ]=    0    ;
    RnonCO2[    575    ]=    0    ;
    RnonCO2[    576    ]=    0    ;
    RnonCO2[    577    ]=    0    ;
    RnonCO2[    578    ]=    0    ;
    RnonCO2[    579    ]=    0    ;
    RnonCO2[    580    ]=    0    ;
    RnonCO2[    581    ]=    0    ;
    RnonCO2[    582    ]=    0    ;
    RnonCO2[    583    ]=    0    ;
    RnonCO2[    584    ]=    0    ;
    RnonCO2[    585    ]=    0    ;
    RnonCO2[    586    ]=    0    ;
    RnonCO2[    587    ]=    0    ;
    RnonCO2[    588    ]=    0    ;
    RnonCO2[    589    ]=    0    ;
    RnonCO2[    590    ]=    0    ;
    RnonCO2[    591    ]=    0    ;
    RnonCO2[    592    ]=    0    ;
    RnonCO2[    593    ]=    0    ;
    RnonCO2[    594    ]=    0    ;
    RnonCO2[    595    ]=    0    ;
    RnonCO2[    596    ]=    0    ;
    RnonCO2[    597    ]=    0    ;
    RnonCO2[    598    ]=    0    ;
    RnonCO2[    599    ]=    0    ;
    RnonCO2[    600    ]=    0    ;
    RnonCO2[    601    ]=    0    ;
    RnonCO2[    602    ]=    0    ;
    RnonCO2[    603    ]=    0    ;
    RnonCO2[    604    ]=    0    ;
    RnonCO2[    605    ]=    0    ;
    RnonCO2[    606    ]=    0    ;
    RnonCO2[    607    ]=    0    ;
    RnonCO2[    608    ]=    0    ;
    RnonCO2[    609    ]=    0    ;
    RnonCO2[    610    ]=    0    ;
    RnonCO2[    611    ]=    0    ;
    RnonCO2[    612    ]=    0    ;
    RnonCO2[    613    ]=    0    ;
    RnonCO2[    614    ]=    0    ;
    RnonCO2[    615    ]=    0    ;
    RnonCO2[    616    ]=    0    ;
    RnonCO2[    617    ]=    0    ;
    RnonCO2[    618    ]=    0    ;
    RnonCO2[    619    ]=    0    ;
    RnonCO2[    620    ]=    0    ;
    RnonCO2[    621    ]=    0    ;
    RnonCO2[    622    ]=    0    ;
    RnonCO2[    623    ]=    0    ;
    RnonCO2[    624    ]=    0    ;
    RnonCO2[    625    ]=    0    ;
    RnonCO2[    626    ]=    0    ;
    RnonCO2[    627    ]=    0    ;
    RnonCO2[    628    ]=    0    ;
    RnonCO2[    629    ]=    0    ;
    RnonCO2[    630    ]=    0    ;
    RnonCO2[    631    ]=    0    ;
    RnonCO2[    632    ]=    0    ;
    RnonCO2[    633    ]=    0    ;
    RnonCO2[    634    ]=    0    ;
    RnonCO2[    635    ]=    0    ;
    RnonCO2[    636    ]=    0    ;
    RnonCO2[    637    ]=    0    ;
    RnonCO2[    638    ]=    0    ;
    RnonCO2[    639    ]=    0    ;
    RnonCO2[    640    ]=    0    ;
    RnonCO2[    641    ]=    0    ;
    RnonCO2[    642    ]=    0    ;
    RnonCO2[    643    ]=    0    ;
    RnonCO2[    644    ]=    0    ;
    RnonCO2[    645    ]=    0    ;
    RnonCO2[    646    ]=    0    ;
    RnonCO2[    647    ]=    0    ;
    RnonCO2[    648    ]=    0    ;
    RnonCO2[    649    ]=    0    ;
    RnonCO2[    650    ]=    0    ;
    RnonCO2[    651    ]=    0    ;
    RnonCO2[    652    ]=    0    ;
    RnonCO2[    653    ]=    0    ;
    RnonCO2[    654    ]=    0    ;
    RnonCO2[    655    ]=    0    ;
    RnonCO2[    656    ]=    0    ;
    RnonCO2[    657    ]=    0    ;
    RnonCO2[    658    ]=    0    ;
    RnonCO2[    659    ]=    0    ;
    RnonCO2[    660    ]=    0    ;
    RnonCO2[    661    ]=    0    ;
    RnonCO2[    662    ]=    0    ;
    RnonCO2[    663    ]=    0    ;
    RnonCO2[    664    ]=    0    ;
    RnonCO2[    665    ]=    0    ;
    RnonCO2[    666    ]=    0    ;
    RnonCO2[    667    ]=    0    ;
    RnonCO2[    668    ]=    0    ;
    RnonCO2[    669    ]=    0    ;
    RnonCO2[    670    ]=    0    ;
    RnonCO2[    671    ]=    0    ;
    RnonCO2[    672    ]=    0    ;
    RnonCO2[    673    ]=    0    ;
    RnonCO2[    674    ]=    0    ;
    RnonCO2[    675    ]=    0    ;
    RnonCO2[    676    ]=    0    ;
    RnonCO2[    677    ]=    0    ;
    RnonCO2[    678    ]=    0    ;
    RnonCO2[    679    ]=    0    ;
    RnonCO2[    680    ]=    0    ;
    RnonCO2[    681    ]=    0    ;
    RnonCO2[    682    ]=    0    ;
    RnonCO2[    683    ]=    0    ;
    RnonCO2[    684    ]=    0    ;
    RnonCO2[    685    ]=    0    ;
    RnonCO2[    686    ]=    0    ;
    RnonCO2[    687    ]=    0    ;
    RnonCO2[    688    ]=    0    ;
    RnonCO2[    689    ]=    0    ;
    RnonCO2[    690    ]=    0    ;
    RnonCO2[    691    ]=    0    ;
    RnonCO2[    692    ]=    0    ;
    RnonCO2[    693    ]=    0    ;
    RnonCO2[    694    ]=    0    ;
    RnonCO2[    695    ]=    0    ;
    RnonCO2[    696    ]=    0    ;
    RnonCO2[    697    ]=    0    ;
    RnonCO2[    698    ]=    0    ;
    RnonCO2[    699    ]=    0    ;
    RnonCO2[    700    ]=    0    ;
    RnonCO2[    701    ]=    0    ;
    RnonCO2[    702    ]=    0    ;
    RnonCO2[    703    ]=    0    ;
    RnonCO2[    704    ]=    0    ;
    RnonCO2[    705    ]=    0    ;
    RnonCO2[    706    ]=    0    ;
    RnonCO2[    707    ]=    0    ;
    RnonCO2[    708    ]=    0    ;
    RnonCO2[    709    ]=    0    ;
    RnonCO2[    710    ]=    0    ;
    RnonCO2[    711    ]=    0    ;
    RnonCO2[    712    ]=    0    ;
    RnonCO2[    713    ]=    0    ;
    RnonCO2[    714    ]=    0    ;
    RnonCO2[    715    ]=    0    ;
    RnonCO2[    716    ]=    0    ;
    RnonCO2[    717    ]=    0    ;
    RnonCO2[    718    ]=    0    ;
    RnonCO2[    719    ]=    0    ;
    RnonCO2[    720    ]=    0    ;
    RnonCO2[    721    ]=    0    ;
    RnonCO2[    722    ]=    0    ;
    RnonCO2[    723    ]=    0    ;
    RnonCO2[    724    ]=    0    ;
    RnonCO2[    725    ]=    0    ;
    RnonCO2[    726    ]=    0    ;
    RnonCO2[    727    ]=    0    ;
    RnonCO2[    728    ]=    0    ;
    RnonCO2[    729    ]=    0    ;
    RnonCO2[    730    ]=    0    ;
    RnonCO2[    731    ]=    0    ;
    RnonCO2[    732    ]=    0    ;
    RnonCO2[    733    ]=    0    ;
    RnonCO2[    734    ]=    0    ;
    RnonCO2[    734    ]=    0    ;
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
}

void setR_solar(void)
{
    RnonCO2[    0    ]=    -0.02835875    ;
    RnonCO2[    1    ]=    -0.02069375    ;
    RnonCO2[    2    ]=    0.007039375    ;
    RnonCO2[    3    ]=    0.046256875    ;
    RnonCO2[    4    ]=    0.073605    ;
    RnonCO2[    5    ]=    0.077258125    ;
    RnonCO2[    6    ]=    0.064894375    ;
    RnonCO2[    7    ]=    0.04433625    ;
    RnonCO2[    8    ]=    0.020348125    ;
    RnonCO2[    9    ]=    0.00144375    ;
    RnonCO2[    10    ]=    -0.009813125    ;
    RnonCO2[    11    ]=    -0.003950625    ;
    RnonCO2[    12    ]=    0.022645    ;
    RnonCO2[    13    ]=    0.05236875    ;
    RnonCO2[    14    ]=    0.05970125    ;
    RnonCO2[    15    ]=    0.05152875    ;
    RnonCO2[    16    ]=    0.041895    ;
    RnonCO2[    17    ]=    0.019495    ;
    RnonCO2[    18    ]=    -0.006033125    ;
    RnonCO2[    19    ]=    -0.0190575    ;
    RnonCO2[    20    ]=    -0.00597625    ;
    RnonCO2[    21    ]=    0.031189375    ;
    RnonCO2[    22    ]=    0.056993125    ;
    RnonCO2[    23    ]=    0.0586425    ;
    RnonCO2[    24    ]=    0.050159375    ;
    RnonCO2[    25    ]=    0.03401125    ;
    RnonCO2[    26    ]=    0.015911875    ;
    RnonCO2[    27    ]=    0.007214375    ;
    RnonCO2[    28    ]=    0.000695625    ;
    RnonCO2[    29    ]=    -0.013549375    ;
    RnonCO2[    30    ]=    -0.0292075    ;
    RnonCO2[    31    ]=    -0.0392525    ;
    RnonCO2[    32    ]=    -0.046291875    ;
    RnonCO2[    33    ]=    -0.05053125    ;
    RnonCO2[    34    ]=    -0.04930625    ;
    RnonCO2[    35    ]=    -0.03357375    ;
    RnonCO2[    36    ]=    -0.0133    ;
    RnonCO2[    37    ]=    -0.017819375    ;
    RnonCO2[    38    ]=    -0.034545    ;
    RnonCO2[    39    ]=    -0.039536875    ;
    RnonCO2[    40    ]=    -0.04272625    ;
    RnonCO2[    41    ]=    -0.053764375    ;
    RnonCO2[    42    ]=    -0.065043125    ;
    RnonCO2[    43    ]=    -0.0714175    ;
    RnonCO2[    44    ]=    -0.07532875    ;
    RnonCO2[    45    ]=    -0.0767375    ;
    RnonCO2[    46    ]=    -0.074204375    ;
    RnonCO2[    47    ]=    -0.067939375    ;
    RnonCO2[    48    ]=    -0.06085625    ;
    RnonCO2[    49    ]=    -0.054236875    ;
    RnonCO2[    50    ]=    -0.044174375    ;
    RnonCO2[    51    ]=    -0.0345275    ;
    RnonCO2[    52    ]=    -0.034759375    ;
    RnonCO2[    53    ]=    -0.0407925    ;
    RnonCO2[    54    ]=    -0.046659375    ;
    RnonCO2[    55    ]=    -0.0531475    ;
    RnonCO2[    56    ]=    -0.0564375    ;
    RnonCO2[    57    ]=    -0.055076875    ;
    RnonCO2[    58    ]=    -0.051795625    ;
    RnonCO2[    59    ]=    -0.04477375    ;
    RnonCO2[    60    ]=    -0.0320425    ;
    RnonCO2[    61    ]=    -0.01493625    ;
    RnonCO2[    62    ]=    0.003136875    ;
    RnonCO2[    63    ]=    0.01644125    ;
    RnonCO2[    64    ]=    0.023629375    ;
    RnonCO2[    65    ]=    0.02078125    ;
    RnonCO2[    66    ]=    0.003675    ;
    RnonCO2[    67    ]=    -0.016638125    ;
    RnonCO2[    68    ]=    -0.027890625    ;
    RnonCO2[    69    ]=    -0.017539375    ;
    RnonCO2[    70    ]=    0.023550625    ;
    RnonCO2[    71    ]=    0.071575    ;
    RnonCO2[    72    ]=    0.08537375    ;
    RnonCO2[    73    ]=    0.066346875    ;
    RnonCO2[    74    ]=    0.04472125    ;
    RnonCO2[    75    ]=    0.0242725    ;
    RnonCO2[    76    ]=    0.003486875    ;
    RnonCO2[    77    ]=    -0.011038125    ;
    RnonCO2[    78    ]=    -0.018256875    ;
    RnonCO2[    79    ]=    -0.013068125    ;
    RnonCO2[    80    ]=    0.003745    ;
    RnonCO2[    81    ]=    0.022365    ;
    RnonCO2[    82    ]=    0.04412625    ;
    RnonCO2[    83    ]=    0.065358125    ;
    RnonCO2[    84    ]=    0.064448125    ;
    RnonCO2[    85    ]=    0.046816875    ;
    RnonCO2[    86    ]=    0.035013125    ;
    RnonCO2[    87    ]=    0.0234325    ;
    RnonCO2[    88    ]=    0.004930625    ;
    RnonCO2[    89    ]=    -0.01411375    ;
    RnonCO2[    90    ]=    -0.026280625    ;
    RnonCO2[    91    ]=    -0.02471875    ;
    RnonCO2[    92    ]=    -0.00660625    ;
    RnonCO2[    93    ]=    0.0245875    ;
    RnonCO2[    94    ]=    0.054998125    ;
    RnonCO2[    95    ]=    0.065550625    ;
    RnonCO2[    96    ]=    0.05229875    ;
    RnonCO2[    97    ]=    0.030695    ;
    RnonCO2[    98    ]=    0.01407    ;
    RnonCO2[    99    ]=    0.0009975    ;
    RnonCO2[    100    ]=    -0.012429375    ;
    RnonCO2[    101    ]=    -0.0242375    ;
    RnonCO2[    102    ]=    -0.024600625    ;
    RnonCO2[    103    ]=    -0.0025725    ;
    RnonCO2[    104    ]=    0.03553375    ;
    RnonCO2[    105    ]=    0.06412875    ;
    RnonCO2[    106    ]=    0.06727    ;
    RnonCO2[    107    ]=    0.051760625    ;
    RnonCO2[    108    ]=    0.0265125    ;
    RnonCO2[    109    ]=    -2.1875E-05    ;
    RnonCO2[    110    ]=    -0.020846875    ;
    RnonCO2[    111    ]=    -0.031731875    ;
    RnonCO2[    112    ]=    -0.0351575    ;
    RnonCO2[    113    ]=    -0.036675625    ;
    RnonCO2[    114    ]=    -0.029553125    ;
    RnonCO2[    115    ]=    -0.00942375    ;
    RnonCO2[    116    ]=    0.01064    ;
    RnonCO2[    117    ]=    0.0210525    ;
    RnonCO2[    118    ]=    0.02190125    ;
    RnonCO2[    119    ]=    0.010583125    ;
    RnonCO2[    120    ]=    -0.010530625    ;
    RnonCO2[    121    ]=    -0.0316925    ;
    RnonCO2[    122    ]=    -0.044279375    ;
    RnonCO2[    123    ]=    -0.0505225    ;
    RnonCO2[    124    ]=    -0.0530425    ;
    RnonCO2[    125    ]=    -0.04025875    ;
    RnonCO2[    126    ]=    -0.01243375    ;
    RnonCO2[    127    ]=    0.01336125    ;
    RnonCO2[    128    ]=    0.034181875    ;
    RnonCO2[    129    ]=    0.04360125    ;
    RnonCO2[    130    ]=    0.02968    ;
    RnonCO2[    131    ]=    0.0023975    ;
    RnonCO2[    132    ]=    -0.01924125    ;
    RnonCO2[    133    ]=    -0.029859375    ;
    RnonCO2[    134    ]=    -0.036728125    ;
    RnonCO2[    135    ]=    -0.045101875    ;
    RnonCO2[    136    ]=    -0.05291125    ;
    RnonCO2[    137    ]=    -0.046388125    ;
    RnonCO2[    138    ]=    -0.01581125    ;
    RnonCO2[    139    ]=    0.00875    ;
    RnonCO2[    140    ]=    0.012630625    ;
    RnonCO2[    141    ]=    0.016485    ;
    RnonCO2[    142    ]=    0.017793125    ;
    RnonCO2[    143    ]=    0.013584375    ;
    RnonCO2[    144    ]=    0.000923125    ;
    RnonCO2[    145    ]=    -0.019236875    ;
    RnonCO2[    146    ]=    -0.034409375    ;
    RnonCO2[    147    ]=    -0.04139625    ;
    RnonCO2[    148    ]=    -0.03905125    ;
    RnonCO2[    149    ]=    -0.019149375    ;
    RnonCO2[    150    ]=    0.0196175    ;
    RnonCO2[    151    ]=    0.0578375    ;
    RnonCO2[    152    ]=    0.0783825    ;
    RnonCO2[    153    ]=    0.071505    ;
    RnonCO2[    154    ]=    0.0426475    ;
    RnonCO2[    155    ]=    0.013803125    ;
    RnonCO2[    156    ]=    -0.00765625    ;
    RnonCO2[    157    ]=    -0.02118375    ;
    RnonCO2[    158    ]=    -0.022185625    ;
    RnonCO2[    159    ]=    -0.009104375    ;
    RnonCO2[    160    ]=    0.01456    ;
    RnonCO2[    161    ]=    0.04036375    ;
    RnonCO2[    162    ]=    0.0554925    ;
    RnonCO2[    163    ]=    0.051016875    ;
    RnonCO2[    164    ]=    0.0412825    ;
    RnonCO2[    165    ]=    0.032589375    ;
    RnonCO2[    166    ]=    0.016454375    ;
    RnonCO2[    167    ]=    -0.00354375    ;
    RnonCO2[    168    ]=    -0.013908125    ;
    RnonCO2[    169    ]=    6.5625E-05    ;
    RnonCO2[    170    ]=    0.0409325    ;
    RnonCO2[    171    ]=    0.081598125    ;
    RnonCO2[    172    ]=    0.09006375    ;
    RnonCO2[    173    ]=    0.0808325    ;
    RnonCO2[    174    ]=    0.073845625    ;
    RnonCO2[    175    ]=    0.064194375    ;
    RnonCO2[    176    ]=    0.050019375    ;
    RnonCO2[    177    ]=    0.030625    ;
    RnonCO2[    178    ]=    0.013610625    ;
    RnonCO2[    179    ]=    0.021004375    ;
    RnonCO2[    180    ]=    0.049966875    ;
    RnonCO2[    181    ]=    0.080705625    ;
    RnonCO2[    182    ]=    0.11165437    ;
    RnonCO2[    183    ]=    0.12945625    ;
    RnonCO2[    184    ]=    0.11637937    ;
    RnonCO2[    185    ]=    0.0807275    ;
    RnonCO2[    186    ]=    0.049030625    ;
    RnonCO2[    187    ]=    0.031810625    ;
    RnonCO2[    188    ]=    0.02046625    ;
    RnonCO2[    189    ]=    0.022115625    ;
    RnonCO2[    190    ]=    0.057264375    ;
    RnonCO2[    191    ]=    0.12487125    ;
    RnonCO2[    192    ]=    0.17792687    ;
    RnonCO2[    193    ]=    0.17952812    ;
    RnonCO2[    194    ]=    0.15146687    ;
    RnonCO2[    195    ]=    0.11563562    ;
    RnonCO2[    196    ]=    0.072270625    ;
    RnonCO2[    197    ]=    0.039375    ;
    RnonCO2[    198    ]=    0.02737    ;
    RnonCO2[    199    ]=    0.02680125    ;
    RnonCO2[    200    ]=    0.03808875    ;
    RnonCO2[    201    ]=    0.06435625    ;
    RnonCO2[    202    ]=    0.09177875    ;
    RnonCO2[    203    ]=    0.10839937    ;
    RnonCO2[    204    ]=    0.1176525    ;
    RnonCO2[    205    ]=    0.10840375    ;
    RnonCO2[    206    ]=    0.087416875    ;
    RnonCO2[    207    ]=    0.072148125    ;
    RnonCO2[    208    ]=    0.05096    ;
    RnonCO2[    209    ]=    0.0251475    ;
    RnonCO2[    210    ]=    0.0099925    ;
    RnonCO2[    211    ]=    0.0194775    ;
    RnonCO2[    212    ]=    0.0600775    ;
    RnonCO2[    213    ]=    0.12268812    ;
    RnonCO2[    214    ]=    0.17410312    ;
    RnonCO2[    215    ]=    0.19308187    ;
    RnonCO2[    216    ]=    0.17986937    ;
    RnonCO2[    217    ]=    0.14232312    ;
    RnonCO2[    218    ]=    0.09982    ;
    RnonCO2[    219    ]=    0.0546175    ;
    RnonCO2[    220    ]=    0.02268    ;
    RnonCO2[    221    ]=    0.021625625    ;
    RnonCO2[    222    ]=    0.047569375    ;
    RnonCO2[    223    ]=    0.1045625    ;
    RnonCO2[    224    ]=    0.16269312    ;
    RnonCO2[    225    ]=    0.17444    ;
    RnonCO2[    226    ]=    0.15460375    ;
    RnonCO2[    227    ]=    0.12536562    ;
    RnonCO2[    228    ]=    0.08502375    ;
    RnonCO2[    229    ]=    0.04853625    ;
    RnonCO2[    230    ]=    0.02604875    ;
    RnonCO2[    231    ]=    0.019718125    ;
    RnonCO2[    232    ]=    0.04291875    ;
    RnonCO2[    233    ]=    0.09258375    ;
    RnonCO2[    234    ]=    0.14625187    ;
    RnonCO2[    235    ]=    0.18119062    ;
    RnonCO2[    236    ]=    0.19056187    ;
    RnonCO2[    237    ]=    0.17415125    ;
    RnonCO2[    238    ]=    0.13018687    ;
    RnonCO2[    239    ]=    0.086078125    ;
    RnonCO2[    240    ]=    0.059268125    ;
    RnonCO2[    241    ]=    0.043176875    ;
    RnonCO2[    242    ]=    0.032265625    ;
    RnonCO2[    243    ]=    0.025655    ;
    RnonCO2[    244    ]=    0.07252875    ;
    RnonCO2[    245    ]=    0.14625187    ;
    RnonCO2[    246    ]=    0.18119062    ;
    RnonCO2[    247    ]=    0.19056187    ;
    RnonCO2[    248    ]=    0.17415125    ;
    RnonCO2[    249    ]=    0.13018687    ;
    RnonCO2[    250    ]=    0.086078125    ;
    RnonCO2[    251    ]=    0.059268125    ;
    RnonCO2[    252    ]=    0.043176875    ;
    RnonCO2[    253    ]=    0.032265625    ;
    RnonCO2[    254    ]=    0.025655    ;
    RnonCO2[    255    ]=    0.07252875    ;
    RnonCO2[    256    ]=    0.14625187    ;
    RnonCO2[    257    ]=    0.18119062    ;
    RnonCO2[    258    ]=    0.19056187    ;
    RnonCO2[    259    ]=    0.17415125    ;
    RnonCO2[    260    ]=    0.13018687    ;
    RnonCO2[    261    ]=    0.086078125    ;
    RnonCO2[    262    ]=    0.059268125    ;
    RnonCO2[    263    ]=    0.043176875    ;
    RnonCO2[    264    ]=    0.032265625    ;
    RnonCO2[    265    ]=    0.025655    ;
    RnonCO2[    266    ]=    0.07252875    ;
    RnonCO2[    267    ]=    0.14625187    ;
    RnonCO2[    268    ]=    0.18119062    ;
    RnonCO2[    269    ]=    0.19056187    ;
    RnonCO2[    270    ]=    0.17415125    ;
    RnonCO2[    271    ]=    0.13018687    ;
    RnonCO2[    272    ]=    0.086078125    ;
    RnonCO2[    273    ]=    0.059268125    ;
    RnonCO2[    274    ]=    0.043176875    ;
    RnonCO2[    275    ]=    0.032265625    ;
    RnonCO2[    276    ]=    0.025655    ;
    RnonCO2[    277    ]=    0.07252875    ;
    RnonCO2[    278    ]=    0.14625187    ;
    RnonCO2[    279    ]=    0.18119062    ;
    RnonCO2[    280    ]=    0.19056187    ;
    RnonCO2[    281    ]=    0.17415125    ;
    RnonCO2[    282    ]=    0.13018687    ;
    RnonCO2[    283    ]=    0.086078125    ;
    RnonCO2[    284    ]=    0.059268125    ;
    RnonCO2[    285    ]=    0.043176875    ;
    RnonCO2[    286    ]=    0.032265625    ;
    RnonCO2[    287    ]=    0.025655    ;
    RnonCO2[    288    ]=    0.07252875    ;
    RnonCO2[    289    ]=    0.14625187    ;
    RnonCO2[    290    ]=    0.18119062    ;
    RnonCO2[    291    ]=    0.19056187    ;
    RnonCO2[    292    ]=    0.17415125    ;
    RnonCO2[    293    ]=    0.13018687    ;
    RnonCO2[    294    ]=    0.086078125    ;
    RnonCO2[    295    ]=    0.059268125    ;
    RnonCO2[    296    ]=    0.043176875    ;
    RnonCO2[    297    ]=    0.032265625    ;
    RnonCO2[    298    ]=    0.025655    ;
    RnonCO2[    299    ]=    0.07252875    ;
    RnonCO2[    300    ]=    0.14625187    ;
    RnonCO2[    301    ]=    0.18119062    ;
    RnonCO2[    302    ]=    0.19056187    ;
    RnonCO2[    303    ]=    0.17415125    ;
    RnonCO2[    304    ]=    0.13018687    ;
    RnonCO2[    305    ]=    0.086078125    ;
    RnonCO2[    306    ]=    0.059268125    ;
    RnonCO2[    307    ]=    0.043176875    ;
    RnonCO2[    308    ]=    0.032265625    ;
    RnonCO2[    309    ]=    0.025655    ;
    RnonCO2[    310    ]=    0.07252875    ;
    RnonCO2[    311    ]=    0.14625187    ;
    RnonCO2[    312    ]=    0.18119062    ;
    RnonCO2[    313    ]=    0.19056187    ;
    RnonCO2[    314    ]=    0.17415125    ;
    RnonCO2[    315    ]=    0.13018687    ;
    RnonCO2[    316    ]=    0.086078125    ;
    RnonCO2[    317    ]=    0.059268125    ;
    RnonCO2[    318    ]=    0.043176875    ;
    RnonCO2[    319    ]=    0.032265625    ;
    RnonCO2[    320    ]=    0.025655    ;
    RnonCO2[    321    ]=    0.07252875    ;
    RnonCO2[    322    ]=    0.14625187    ;
    RnonCO2[    323    ]=    0.18119062    ;
    RnonCO2[    324    ]=    0.19056187    ;
    RnonCO2[    325    ]=    0.17415125    ;
    RnonCO2[    326    ]=    0.13018687    ;
    RnonCO2[    327    ]=    0.086078125    ;
    RnonCO2[    328    ]=    0.059268125    ;
    RnonCO2[    329    ]=    0.043176875    ;
    RnonCO2[    330    ]=    0.032265625    ;
    RnonCO2[    331    ]=    0.025655    ;
    RnonCO2[    332    ]=    0.07252875    ;
    RnonCO2[    333    ]=    0.14625187    ;
    RnonCO2[    334    ]=    0.18119062    ;
    RnonCO2[    335    ]=    0.19056187    ;
    RnonCO2[    336    ]=    0.17415125    ;
    RnonCO2[    337    ]=    0.13018687    ;
    RnonCO2[    338    ]=    0.086078125    ;
    RnonCO2[    339    ]=    0.059268125    ;
    RnonCO2[    340    ]=    0.043176875    ;
    RnonCO2[    341    ]=    0.032265625    ;
    RnonCO2[    342    ]=    0.025655    ;
    RnonCO2[    343    ]=    0.07252875    ;
    RnonCO2[    344    ]=    0.14625187    ;
    RnonCO2[    345    ]=    0.18119062    ;
    RnonCO2[    346    ]=    0.19056187    ;
    RnonCO2[    347    ]=    0.17415125    ;
    RnonCO2[    348    ]=    0.13018687    ;
    RnonCO2[    349    ]=    0.086078125    ;
    RnonCO2[    350    ]=    0.059268125    ;
    RnonCO2[    351    ]=    0.043176875    ;
    RnonCO2[    352    ]=    0.032265625    ;
    RnonCO2[    353    ]=    0.025655    ;
    RnonCO2[    354    ]=    0.07252875    ;
    RnonCO2[    355    ]=    0.14625187    ;
    RnonCO2[    356    ]=    0.18119062    ;
    RnonCO2[    357    ]=    0.19056187    ;
    RnonCO2[    358    ]=    0.17415125    ;
    RnonCO2[    359    ]=    0.13018687    ;
    RnonCO2[    360    ]=    0.086078125    ;
    RnonCO2[    361    ]=    0.059268125    ;
    RnonCO2[    362    ]=    0.043176875    ;
    RnonCO2[    363    ]=    0.032265625    ;
    RnonCO2[    364    ]=    0.025655    ;
    RnonCO2[    365    ]=    0.07252875    ;
    RnonCO2[    366    ]=    0.14625187    ;
    RnonCO2[    367    ]=    0.18119062    ;
    RnonCO2[    368    ]=    0.19056187    ;
    RnonCO2[    369    ]=    0.17415125    ;
    RnonCO2[    370    ]=    0.13018687    ;
    RnonCO2[    371    ]=    0.086078125    ;
    RnonCO2[    372    ]=    0.059268125    ;
    RnonCO2[    373    ]=    0.043176875    ;
    RnonCO2[    374    ]=    0.032265625    ;
    RnonCO2[    375    ]=    0.025655    ;
    RnonCO2[    376    ]=    0.07252875    ;
    RnonCO2[    377    ]=    0.14625187    ;
    RnonCO2[    378    ]=    0.18119062    ;
    RnonCO2[    379    ]=    0.19056187    ;
    RnonCO2[    380    ]=    0.17415125    ;
    RnonCO2[    381    ]=    0.13018687    ;
    RnonCO2[    382    ]=    0.086078125    ;
    RnonCO2[    383    ]=    0.059268125    ;
    RnonCO2[    384    ]=    0.043176875    ;
    RnonCO2[    385    ]=    0.032265625    ;
    RnonCO2[    386    ]=    0.025655    ;
    RnonCO2[    387    ]=    0.07252875    ;
    RnonCO2[    388    ]=    0.14625187    ;
    RnonCO2[    389    ]=    0.18119062    ;
    RnonCO2[    390    ]=    0.19056187    ;
    RnonCO2[    391    ]=    0.17415125    ;
    RnonCO2[    392    ]=    0.13018687    ;
    RnonCO2[    393    ]=    0.086078125    ;
    RnonCO2[    394    ]=    0.059268125    ;
    RnonCO2[    395    ]=    0.043176875    ;
    RnonCO2[    396    ]=    0.032265625    ;
    RnonCO2[    397    ]=    0.025655    ;
    RnonCO2[    398    ]=    0.07252875    ;
    RnonCO2[    399    ]=    0.14625187    ;
    RnonCO2[    400    ]=    0.18119062    ;
    RnonCO2[    401    ]=    0.19056187    ;
    RnonCO2[    402    ]=    0.17415125    ;
    RnonCO2[    403    ]=    0.13018687    ;
    RnonCO2[    404    ]=    0.086078125    ;
    RnonCO2[    405    ]=    0.059268125    ;
    RnonCO2[    406    ]=    0.043176875    ;
    RnonCO2[    407    ]=    0.032265625    ;
    RnonCO2[    408    ]=    0.025655    ;
    RnonCO2[    409    ]=    0.07252875    ;
    RnonCO2[    410    ]=    0.14625187    ;
    RnonCO2[    411    ]=    0.18119062    ;
    RnonCO2[    412    ]=    0.19056187    ;
    RnonCO2[    413    ]=    0.17415125    ;
    RnonCO2[    414    ]=    0.13018687    ;
    RnonCO2[    415    ]=    0.086078125    ;
    RnonCO2[    416    ]=    0.059268125    ;
    RnonCO2[    417    ]=    0.043176875    ;
    RnonCO2[    418    ]=    0.032265625    ;
    RnonCO2[    419    ]=    0.025655    ;
    RnonCO2[    420    ]=    0.07252875    ;
    RnonCO2[    421    ]=    0.14625187    ;
    RnonCO2[    422    ]=    0.18119062    ;
    RnonCO2[    423    ]=    0.19056187    ;
    RnonCO2[    424    ]=    0.17415125    ;
    RnonCO2[    425    ]=    0.13018687    ;
    RnonCO2[    426    ]=    0.086078125    ;
    RnonCO2[    427    ]=    0.059268125    ;
    RnonCO2[    428    ]=    0.043176875    ;
    RnonCO2[    429    ]=    0.032265625    ;
    RnonCO2[    430    ]=    0.025655    ;
    RnonCO2[    431    ]=    0.07252875    ;
    RnonCO2[    432    ]=    0.14625187    ;
    RnonCO2[    433    ]=    0.18119062    ;
    RnonCO2[    434    ]=    0.19056187    ;
    RnonCO2[    435    ]=    0.17415125    ;
    RnonCO2[    436    ]=    0.13018687    ;
    RnonCO2[    437    ]=    0.086078125    ;
    RnonCO2[    438    ]=    0.059268125    ;
    RnonCO2[    439    ]=    0.043176875    ;
    RnonCO2[    440    ]=    0.032265625    ;
    RnonCO2[    441    ]=    0.025655    ;
    RnonCO2[    442    ]=    0.07252875    ;
    RnonCO2[    443    ]=    0.14625187    ;
    RnonCO2[    444    ]=    0.18119062    ;
    RnonCO2[    445    ]=    0.19056187    ;
    RnonCO2[    446    ]=    0.17415125    ;
    RnonCO2[    447    ]=    0.13018687    ;
    RnonCO2[    448    ]=    0.086078125    ;
    RnonCO2[    449    ]=    0.059268125    ;
    RnonCO2[    450    ]=    0.043176875    ;
    RnonCO2[    451    ]=    0.032265625    ;
    RnonCO2[    452    ]=    0.025655    ;
    RnonCO2[    453    ]=    0.07252875    ;
    RnonCO2[    454    ]=    0.14625187    ;
    RnonCO2[    455    ]=    0.18119062    ;
    RnonCO2[    456    ]=    0.19056187    ;
    RnonCO2[    457    ]=    0.17415125    ;
    RnonCO2[    458    ]=    0.13018687    ;
    RnonCO2[    459    ]=    0.086078125    ;
    RnonCO2[    460    ]=    0.059268125    ;
    RnonCO2[    461    ]=    0.043176875    ;
    RnonCO2[    462    ]=    0.032265625    ;
    RnonCO2[    463    ]=    0.025655    ;
    RnonCO2[    464    ]=    0.07252875    ;
    RnonCO2[    465    ]=    0.14625187    ;
    RnonCO2[    466    ]=    0.18119062    ;
    RnonCO2[    467    ]=    0.19056187    ;
    RnonCO2[    468    ]=    0.17415125    ;
    RnonCO2[    469    ]=    0.13018687    ;
    RnonCO2[    470    ]=    0.086078125    ;
    RnonCO2[    471    ]=    0.059268125    ;
    RnonCO2[    472    ]=    0.043176875    ;
    RnonCO2[    473    ]=    0.032265625    ;
    RnonCO2[    474    ]=    0.025655    ;
    RnonCO2[    475    ]=    0.07252875    ;
    RnonCO2[    476    ]=    0.14625187    ;
    RnonCO2[    477    ]=    0.18119062    ;
    RnonCO2[    478    ]=    0.19056187    ;
    RnonCO2[    479    ]=    0.17415125    ;
    RnonCO2[    480    ]=    0.13018687    ;
    RnonCO2[    481    ]=    0.086078125    ;
    RnonCO2[    482    ]=    0.059268125    ;
    RnonCO2[    483    ]=    0.043176875    ;
    RnonCO2[    484    ]=    0.070611704    ;
    RnonCO2[    485    ]=    0.10375591    ;
    RnonCO2[    486    ]=    0.10375591    ;
    RnonCO2[    487    ]=    0.10375591    ;
    RnonCO2[    488    ]=    0.10375591    ;
    RnonCO2[    489    ]=    0.10375591    ;
    RnonCO2[    490    ]=    0.10375591    ;
    RnonCO2[    491    ]=    0.10375591    ;
    RnonCO2[    492    ]=    0.10375591    ;
    RnonCO2[    493    ]=    0.10375591    ;
    RnonCO2[    494    ]=    0.10375591    ;
    RnonCO2[    495    ]=    0.10375591    ;
    RnonCO2[    496    ]=    0.10375591    ;
    RnonCO2[    497    ]=    0.10375591    ;
    RnonCO2[    498    ]=    0.10375591    ;
    RnonCO2[    499    ]=    0.10375591    ;
    RnonCO2[    500    ]=    0.10375591    ;
    RnonCO2[    501    ]=    0.10375591    ;
    RnonCO2[    502    ]=    0.10375591    ;
    RnonCO2[    503    ]=    0.10375591    ;
    RnonCO2[    504    ]=    0.10375591    ;
    RnonCO2[    505    ]=    0.10375591    ;
    RnonCO2[    506    ]=    0.10375591    ;
    RnonCO2[    507    ]=    0.10375591    ;
    RnonCO2[    508    ]=    0.10375591    ;
    RnonCO2[    509    ]=    0.10375591    ;
    RnonCO2[    510    ]=    0.10375591    ;
    RnonCO2[    511    ]=    0.10375591    ;
    RnonCO2[    512    ]=    0.10375591    ;
    RnonCO2[    513    ]=    0.10375591    ;
    RnonCO2[    514    ]=    0.10375591    ;
    RnonCO2[    515    ]=    0.10375591    ;
    RnonCO2[    516    ]=    0.10375591    ;
    RnonCO2[    517    ]=    0.10375591    ;
    RnonCO2[    518    ]=    0.10375591    ;
    RnonCO2[    519    ]=    0.10375591    ;
    RnonCO2[    520    ]=    0.10375591    ;
    RnonCO2[    521    ]=    0.10375591    ;
    RnonCO2[    522    ]=    0.10375591    ;
    RnonCO2[    523    ]=    0.10375591    ;
    RnonCO2[    524    ]=    0.10375591    ;
    RnonCO2[    525    ]=    0.10375591    ;
    RnonCO2[    526    ]=    0.10375591    ;
    RnonCO2[    527    ]=    0.10375591    ;
    RnonCO2[    528    ]=    0.10375591    ;
    RnonCO2[    529    ]=    0.10375591    ;
    RnonCO2[    530    ]=    0.10375591    ;
    RnonCO2[    531    ]=    0.10375591    ;
    RnonCO2[    532    ]=    0.10375591    ;
    RnonCO2[    533    ]=    0.10375591    ;
    RnonCO2[    534    ]=    0.10375591    ;
    RnonCO2[    535    ]=    0.10375591    ;
    RnonCO2[    536    ]=    0.10375591    ;
    RnonCO2[    537    ]=    0.10375591    ;
    RnonCO2[    538    ]=    0.10375591    ;
    RnonCO2[    539    ]=    0.10375591    ;
    RnonCO2[    540    ]=    0.10375591    ;
    RnonCO2[    541    ]=    0.10375591    ;
    RnonCO2[    542    ]=    0.10375591    ;
    RnonCO2[    543    ]=    0.10375591    ;
    RnonCO2[    544    ]=    0.10375591    ;
    RnonCO2[    545    ]=    0.10375591    ;
    RnonCO2[    546    ]=    0.10375591    ;
    RnonCO2[    547    ]=    0.10375591    ;
    RnonCO2[    548    ]=    0.10375591    ;
    RnonCO2[    549    ]=    0.10375591    ;
    RnonCO2[    550    ]=    0.10375591    ;
    RnonCO2[    551    ]=    0.10375591    ;
    RnonCO2[    552    ]=    0.10375591    ;
    RnonCO2[    553    ]=    0.10375591    ;
    RnonCO2[    554    ]=    0.10375591    ;
    RnonCO2[    555    ]=    0.10375591    ;
    RnonCO2[    556    ]=    0.10375591    ;
    RnonCO2[    557    ]=    0.10375591    ;
    RnonCO2[    558    ]=    0.10375591    ;
    RnonCO2[    559    ]=    0.10375591    ;
    RnonCO2[    560    ]=    0.10375591    ;
    RnonCO2[    561    ]=    0.10375591    ;
    RnonCO2[    562    ]=    0.10375591    ;
    RnonCO2[    563    ]=    0.10375591    ;
    RnonCO2[    564    ]=    0.10375591    ;
    RnonCO2[    565    ]=    0.10375591    ;
    RnonCO2[    566    ]=    0.10375591    ;
    RnonCO2[    567    ]=    0.10375591    ;
    RnonCO2[    568    ]=    0.10375591    ;
    RnonCO2[    569    ]=    0.10375591    ;
    RnonCO2[    570    ]=    0.10375591    ;
    RnonCO2[    571    ]=    0.10375591    ;
    RnonCO2[    572    ]=    0.10375591    ;
    RnonCO2[    573    ]=    0.10375591    ;
    RnonCO2[    574    ]=    0.10375591    ;
    RnonCO2[    575    ]=    0.10375591    ;
    RnonCO2[    576    ]=    0.10375591    ;
    RnonCO2[    577    ]=    0.10375591    ;
    RnonCO2[    578    ]=    0.10375591    ;
    RnonCO2[    579    ]=    0.10375591    ;
    RnonCO2[    580    ]=    0.10375591    ;
    RnonCO2[    581    ]=    0.10375591    ;
    RnonCO2[    582    ]=    0.10375591    ;
    RnonCO2[    583    ]=    0.10375591    ;
    RnonCO2[    584    ]=    0.10375591    ;
    RnonCO2[    585    ]=    0.10375591    ;
    RnonCO2[    586    ]=    0.10375591    ;
    RnonCO2[    587    ]=    0.10375591    ;
    RnonCO2[    588    ]=    0.10375591    ;
    RnonCO2[    589    ]=    0.10375591    ;
    RnonCO2[    590    ]=    0.10375591    ;
    RnonCO2[    591    ]=    0.10375591    ;
    RnonCO2[    592    ]=    0.10375591    ;
    RnonCO2[    593    ]=    0.10375591    ;
    RnonCO2[    594    ]=    0.10375591    ;
    RnonCO2[    595    ]=    0.10375591    ;
    RnonCO2[    596    ]=    0.10375591    ;
    RnonCO2[    597    ]=    0.10375591    ;
    RnonCO2[    598    ]=    0.10375591    ;
    RnonCO2[    599    ]=    0.10375591    ;
    RnonCO2[    600    ]=    0.10375591    ;
    RnonCO2[    601    ]=    0.10375591    ;
    RnonCO2[    602    ]=    0.10375591    ;
    RnonCO2[    603    ]=    0.10375591    ;
    RnonCO2[    604    ]=    0.10375591    ;
    RnonCO2[    605    ]=    0.10375591    ;
    RnonCO2[    606    ]=    0.10375591    ;
    RnonCO2[    607    ]=    0.10375591    ;
    RnonCO2[    608    ]=    0.10375591    ;
    RnonCO2[    609    ]=    0.10375591    ;
    RnonCO2[    610    ]=    0.10375591    ;
    RnonCO2[    611    ]=    0.10375591    ;
    RnonCO2[    612    ]=    0.10375591    ;
    RnonCO2[    613    ]=    0.10375591    ;
    RnonCO2[    614    ]=    0.10375591    ;
    RnonCO2[    615    ]=    0.10375591    ;
    RnonCO2[    616    ]=    0.10375591    ;
    RnonCO2[    617    ]=    0.10375591    ;
    RnonCO2[    618    ]=    0.10375591    ;
    RnonCO2[    619    ]=    0.10375591    ;
    RnonCO2[    620    ]=    0.10375591    ;
    RnonCO2[    621    ]=    0.10375591    ;
    RnonCO2[    622    ]=    0.10375591    ;
    RnonCO2[    623    ]=    0.10375591    ;
    RnonCO2[    624    ]=    0.10375591    ;
    RnonCO2[    625    ]=    0.10375591    ;
    RnonCO2[    626    ]=    0.10375591    ;
    RnonCO2[    627    ]=    0.10375591    ;
    RnonCO2[    628    ]=    0.10375591    ;
    RnonCO2[    629    ]=    0.10375591    ;
    RnonCO2[    630    ]=    0.10375591    ;
    RnonCO2[    631    ]=    0.10375591    ;
    RnonCO2[    632    ]=    0.10375591    ;
    RnonCO2[    633    ]=    0.10375591    ;
    RnonCO2[    634    ]=    0.10375591    ;
    RnonCO2[    635    ]=    0.10375591    ;
    RnonCO2[    636    ]=    0.10375591    ;
    RnonCO2[    637    ]=    0.10375591    ;
    RnonCO2[    638    ]=    0.10375591    ;
    RnonCO2[    639    ]=    0.10375591    ;
    RnonCO2[    640    ]=    0.10375591    ;
    RnonCO2[    641    ]=    0.10375591    ;
    RnonCO2[    642    ]=    0.10375591    ;
    RnonCO2[    643    ]=    0.10375591    ;
    RnonCO2[    644    ]=    0.10375591    ;
    RnonCO2[    645    ]=    0.10375591    ;
    RnonCO2[    646    ]=    0.10375591    ;
    RnonCO2[    647    ]=    0.10375591    ;
    RnonCO2[    648    ]=    0.10375591    ;
    RnonCO2[    649    ]=    0.10375591    ;
    RnonCO2[    650    ]=    0.10375591    ;
    RnonCO2[    651    ]=    0.10375591    ;
    RnonCO2[    652    ]=    0.10375591    ;
    RnonCO2[    653    ]=    0.10375591    ;
    RnonCO2[    654    ]=    0.10375591    ;
    RnonCO2[    655    ]=    0.10375591    ;
    RnonCO2[    656    ]=    0.10375591    ;
    RnonCO2[    657    ]=    0.10375591    ;
    RnonCO2[    658    ]=    0.10375591    ;
    RnonCO2[    659    ]=    0.10375591    ;
    RnonCO2[    660    ]=    0.10375591    ;
    RnonCO2[    661    ]=    0.10375591    ;
    RnonCO2[    662    ]=    0.10375591    ;
    RnonCO2[    663    ]=    0.10375591    ;
    RnonCO2[    664    ]=    0.10375591    ;
    RnonCO2[    665    ]=    0.10375591    ;
    RnonCO2[    666    ]=    0.10375591    ;
    RnonCO2[    667    ]=    0.10375591    ;
    RnonCO2[    668    ]=    0.10375591    ;
    RnonCO2[    669    ]=    0.10375591    ;
    RnonCO2[    670    ]=    0.10375591    ;
    RnonCO2[    671    ]=    0.10375591    ;
    RnonCO2[    672    ]=    0.10375591    ;
    RnonCO2[    673    ]=    0.10375591    ;
    RnonCO2[    674    ]=    0.10375591    ;
    RnonCO2[    675    ]=    0.10375591    ;
    RnonCO2[    676    ]=    0.10375591    ;
    RnonCO2[    677    ]=    0.10375591    ;
    RnonCO2[    678    ]=    0.10375591    ;
    RnonCO2[    679    ]=    0.10375591    ;
    RnonCO2[    680    ]=    0.10375591    ;
    RnonCO2[    681    ]=    0.10375591    ;
    RnonCO2[    682    ]=    0.10375591    ;
    RnonCO2[    683    ]=    0.10375591    ;
    RnonCO2[    684    ]=    0.10375591    ;
    RnonCO2[    685    ]=    0.10375591    ;
    RnonCO2[    686    ]=    0.10375591    ;
    RnonCO2[    687    ]=    0.10375591    ;
    RnonCO2[    688    ]=    0.10375591    ;
    RnonCO2[    689    ]=    0.10375591    ;
    RnonCO2[    690    ]=    0.10375591    ;
    RnonCO2[    691    ]=    0.10375591    ;
    RnonCO2[    692    ]=    0.10375591    ;
    RnonCO2[    693    ]=    0.10375591    ;
    RnonCO2[    694    ]=    0.10375591    ;
    RnonCO2[    695    ]=    0.10375591    ;
    RnonCO2[    696    ]=    0.10375591    ;
    RnonCO2[    697    ]=    0.10375591    ;
    RnonCO2[    698    ]=    0.10375591    ;
    RnonCO2[    699    ]=    0.10375591    ;
    RnonCO2[    700    ]=    0.10375591    ;
    RnonCO2[    701    ]=    0.10375591    ;
    RnonCO2[    702    ]=    0.10375591    ;
    RnonCO2[    703    ]=    0.10375591    ;
    RnonCO2[    704    ]=    0.10375591    ;
    RnonCO2[    705    ]=    0.10375591    ;
    RnonCO2[    706    ]=    0.10375591    ;
    RnonCO2[    707    ]=    0.10375591    ;
    RnonCO2[    708    ]=    0.10375591    ;
    RnonCO2[    709    ]=    0.10375591    ;
    RnonCO2[    710    ]=    0.10375591    ;
    RnonCO2[    711    ]=    0.10375591    ;
    RnonCO2[    712    ]=    0.10375591    ;
    RnonCO2[    713    ]=    0.10375591    ;
    RnonCO2[    714    ]=    0.10375591    ;
    RnonCO2[    715    ]=    0.10375591    ;
    RnonCO2[    716    ]=    0.10375591    ;
    RnonCO2[    717    ]=    0.10375591    ;
    RnonCO2[    718    ]=    0.10375591    ;
    RnonCO2[    719    ]=    0.10375591    ;
    RnonCO2[    720    ]=    0.10375591    ;
    RnonCO2[    721    ]=    0.10375591    ;
    RnonCO2[    722    ]=    0.10375591    ;
    RnonCO2[    723    ]=    0.10375591    ;
    RnonCO2[    724    ]=    0.10375591    ;
    RnonCO2[    725    ]=    0.10375591    ;
    RnonCO2[    726    ]=    0.10375591    ;
    RnonCO2[    727    ]=    0.10375591    ;
    RnonCO2[    728    ]=    0.10375591    ;
    RnonCO2[    729    ]=    0.10375591    ;
    RnonCO2[    730    ]=    0.10375591    ;
    RnonCO2[    731    ]=    0.10375591    ;
    RnonCO2[    732    ]=    0.10375591    ;
    RnonCO2[    733    ]=    0.10375591    ;
    RnonCO2[    734    ]=    0.10375591    ;
    RnonCO2[    735    ]=    0.10375591    ;
    
    for(int i = 736; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }
}

void setR_volcanicIPCC(void)
{
    RnonCO2[	0	]=	-0.003	;
    RnonCO2[	1	]=	0.000	;
    RnonCO2[	2	]=	0.000	;
    RnonCO2[	3	]=	0.000	;
    RnonCO2[	4	]=	0.000	;
    RnonCO2[	5	]=	0.000	;
    RnonCO2[	6	]=	0.000	;
    RnonCO2[	7	]=	-0.070	;
    RnonCO2[	8	]=	-0.020	;
    RnonCO2[	9	]=	-0.005	;
    RnonCO2[	10	]=	-0.001	;
    RnonCO2[	11	]=	0.000	;
    RnonCO2[	12	]=	0.000	;
    RnonCO2[	13	]=	-0.067	;
    RnonCO2[	14	]=	-0.071	;
    RnonCO2[	15	]=	-0.018	;
    RnonCO2[	16	]=	-0.004	;
    RnonCO2[	17	]=	-0.001	;
    RnonCO2[	18	]=	-7.857	;
    RnonCO2[	19	]=	-0.522	;
    RnonCO2[	20	]=	-0.121	;
    RnonCO2[	21	]=	-0.027	;
    RnonCO2[	22	]=	-0.002	;
    RnonCO2[	23	]=	-0.133	;
    RnonCO2[	24	]=	-0.041	;
    RnonCO2[	25	]=	-0.009	;
    RnonCO2[	26	]=	-0.001	;
    RnonCO2[	27	]=	0.000	;
    RnonCO2[	28	]=	0.000	;
    RnonCO2[	29	]=	-0.157	;
    RnonCO2[	30	]=	0.000	;
    RnonCO2[	31	]=	-0.781	;
    RnonCO2[	32	]=	-0.071	;
    RnonCO2[	33	]=	-0.016	;
    RnonCO2[	34	]=	-0.002	;
    RnonCO2[	35	]=	0.000	;
    RnonCO2[	36	]=	-0.154	;
    RnonCO2[	37	]=	-0.048	;
    RnonCO2[	38	]=	-0.011	;
    RnonCO2[	39	]=	-0.230	;
    RnonCO2[	40	]=	-0.070	;
    RnonCO2[	41	]=	-0.016	;
    RnonCO2[	42	]=	-0.002	;
    RnonCO2[	43	]=	0.000	;
    RnonCO2[	44	]=	-6.947	;
    RnonCO2[	45	]=	-2.254	;
    RnonCO2[	46	]=	-0.836	;
    RnonCO2[	47	]=	-0.308	;
    RnonCO2[	48	]=	-0.109	;
    RnonCO2[	49	]=	0.000	;
    RnonCO2[	50	]=	-11.629	;
    RnonCO2[	51	]=	-4.553	;
    RnonCO2[	52	]=	-2.419	;
    RnonCO2[	53	]=	-0.915	;
    RnonCO2[	54	]=	-0.337	;
    RnonCO2[	55	]=	-0.039	;
    RnonCO2[	56	]=	0.000	;
    RnonCO2[	57	]=	0.000	;
    RnonCO2[	58	]=	0.000	;
    RnonCO2[	59	]=	0.000	;
    RnonCO2[	60	]=	0.000	;
    RnonCO2[	61	]=	0.000	;
    RnonCO2[	62	]=	0.000	;
    RnonCO2[	63	]=	0.000	;
    RnonCO2[	64	]=	0.000	;
    RnonCO2[	65	]=	0.000	;
    RnonCO2[	66	]=	-1.538	;
    RnonCO2[	67	]=	-1.229	;
    RnonCO2[	68	]=	-0.605	;
    RnonCO2[	69	]=	-0.223	;
    RnonCO2[	70	]=	-4.935	;
    RnonCO2[	71	]=	-1.445	;
    RnonCO2[	72	]=	-0.523	;
    RnonCO2[	73	]=	-0.192	;
    RnonCO2[	74	]=	-0.069	;
    RnonCO2[	75	]=	-0.047	;
    RnonCO2[	76	]=	-0.013	;
    RnonCO2[	77	]=	-0.003	;
    RnonCO2[	78	]=	-0.052	;
    RnonCO2[	79	]=	-0.014	;
    RnonCO2[	80	]=	-0.003	;
    RnonCO2[	81	]=	-0.071	;
    RnonCO2[	82	]=	-0.020	;
    RnonCO2[	83	]=	-0.005	;
    RnonCO2[	84	]=	-0.001	;
    RnonCO2[	85	]=	-0.100	;
    RnonCO2[	86	]=	-0.075	;
    RnonCO2[	87	]=	-0.025	;
    RnonCO2[	88	]=	-0.025	;
    RnonCO2[	89	]=	0.000	;
    RnonCO2[	90	]=	-0.050	;
    RnonCO2[	91	]=	-0.975	;
    RnonCO2[	92	]=	-1.500	;
    RnonCO2[	93	]=	-0.725	;
    RnonCO2[	94	]=	-0.275	;
    RnonCO2[	95	]=	-0.125	;
    RnonCO2[	96	]=	-0.075	;
    RnonCO2[	97	]=	-0.350	;
    RnonCO2[	98	]=	-0.250	;
    RnonCO2[	99	]=	-0.125	;
    RnonCO2[	100	]=	-0.050	;
    RnonCO2[	101	]=	-0.025	;
    RnonCO2[	102	]=	0.000	;
    RnonCO2[	103	]=	0.000	;
    RnonCO2[	104	]=	-0.025	;
    RnonCO2[	105	]=	-0.025	;
    RnonCO2[	106	]=	-0.025	;
    RnonCO2[	107	]=	-0.025	;
    RnonCO2[	108	]=	-0.075	;
    RnonCO2[	109	]=	-0.050	;
    RnonCO2[	110	]=	-0.025	;
    RnonCO2[	111	]=	-0.150	;
    RnonCO2[	112	]=	-0.125	;
    RnonCO2[	113	]=	-0.075	;
    RnonCO2[	114	]=	-0.050	;
    RnonCO2[	115	]=	-0.025	;
    RnonCO2[	116	]=	-0.025	;
    RnonCO2[	117	]=	-0.025	;
    RnonCO2[	118	]=	-1.175	;
    RnonCO2[	119	]=	-3.575	;
    RnonCO2[	120	]=	-1.575	;
    RnonCO2[	121	]=	-0.900	;
    RnonCO2[	122	]=	-0.925	;
    RnonCO2[	123	]=	-0.550	;
    RnonCO2[	124	]=	-0.725	;
    RnonCO2[	125	]=	-0.975	;
    RnonCO2[	126	]=	-0.750	;
    RnonCO2[	127	]=	-0.550	;
    RnonCO2[	128	]=	-0.225	;
    RnonCO2[	129	]=	-0.100	;
    RnonCO2[	130	]=	-0.025	;
    RnonCO2[	131	]=	-0.450	;
    RnonCO2[	132	]=	-0.425	;
    RnonCO2[	133	]=	-0.300	;
    RnonCO2[	134	]=	-0.125	;
    RnonCO2[	135	]=	-0.050	;
    RnonCO2[	136	]=	-0.025	;
    RnonCO2[	137	]=	-0.500	;
    RnonCO2[	138	]=	-1.800	;
    RnonCO2[	139	]=	-0.800	;
    RnonCO2[	140	]=	-0.325	;
    RnonCO2[	141	]=	-0.175	;
    RnonCO2[	142	]=	-0.225	;
    RnonCO2[	143	]=	-0.250	;
    RnonCO2[	144	]=	-0.100	;
    RnonCO2[	145	]=	-0.075	;
    RnonCO2[	146	]=	-0.050	;
    RnonCO2[	147	]=	-0.475	;
    RnonCO2[	148	]=	-0.600	;
    RnonCO2[	149	]=	-0.250	;
    RnonCO2[	150	]=	-0.100	;
    RnonCO2[	151	]=	-0.075	;
    RnonCO2[	152	]=	-0.050	;
    RnonCO2[	153	]=	-0.050	;
    RnonCO2[	154	]=	-0.050	;
    RnonCO2[	155	]=	-0.225	;
    RnonCO2[	156	]=	-0.200	;
    RnonCO2[	157	]=	-0.075	;
    RnonCO2[	158	]=	-0.025	;
    RnonCO2[	159	]=	-0.075	;
    RnonCO2[	160	]=	-0.075	;
    RnonCO2[	161	]=	-0.050	;
    RnonCO2[	162	]=	-0.050	;
    RnonCO2[	163	]=	-0.125	;
    RnonCO2[	164	]=	-0.250	;
    RnonCO2[	165	]=	-0.150	;
    RnonCO2[	166	]=	-0.125	;
    RnonCO2[	167	]=	-0.200	;
    RnonCO2[	168	]=	-0.175	;
    RnonCO2[	169	]=	-0.100	;
    RnonCO2[	170	]=	-0.100	;
    RnonCO2[	171	]=	-0.075	;
    RnonCO2[	172	]=	-0.075	;
    RnonCO2[	173	]=	-0.125	;
    RnonCO2[	174	]=	-0.100	;
    RnonCO2[	175	]=	-0.075	;
    RnonCO2[	176	]=	-0.050	;
    RnonCO2[	177	]=	-0.100	;
    RnonCO2[	178	]=	-0.100	;
    RnonCO2[	179	]=	-0.050	;
    RnonCO2[	180	]=	-0.050	;
    RnonCO2[	181	]=	-0.050	;
    RnonCO2[	182	]=	-0.050	;
    RnonCO2[	183	]=	-0.050	;
    RnonCO2[	184	]=	-0.075	;
    RnonCO2[	185	]=	-0.075	;
    RnonCO2[	186	]=	-0.050	;
    RnonCO2[	187	]=	-0.100	;
    RnonCO2[	188	]=	-0.075	;
    RnonCO2[	189	]=	-0.100	;
    RnonCO2[	190	]=	-0.050	;
    RnonCO2[	191	]=	-0.025	;
    RnonCO2[	192	]=	-0.025	;
    RnonCO2[	193	]=	0.000	;
    RnonCO2[	194	]=	0.000	;
    RnonCO2[	195	]=	-0.125	;
    RnonCO2[	196	]=	-0.275	;
    RnonCO2[	197	]=	-0.325	;
    RnonCO2[	198	]=	-1.150	;
    RnonCO2[	199	]=	-1.800	;
    RnonCO2[	200	]=	-1.075	;
    RnonCO2[	201	]=	-0.575	;
    RnonCO2[	202	]=	-0.375	;
    RnonCO2[	203	]=	-0.675	;
    RnonCO2[	204	]=	-0.850	;
    RnonCO2[	205	]=	-0.425	;
    RnonCO2[	206	]=	-0.150	;
    RnonCO2[	207	]=	-0.100	;
    RnonCO2[	208	]=	-0.200	;
    RnonCO2[	209	]=	-0.325	;
    RnonCO2[	210	]=	-0.750	;
    RnonCO2[	211	]=	-0.350	;
    RnonCO2[	212	]=	-0.125	;
    RnonCO2[	213	]=	-0.200	;
    RnonCO2[	214	]=	-0.225	;
    RnonCO2[	215	]=	-0.125	;
    RnonCO2[	216	]=	-0.125	;
    RnonCO2[	217	]=	-1.325	;
    RnonCO2[	218	]=	-1.875	;
    RnonCO2[	219	]=	-0.750	;
    RnonCO2[	220	]=	-0.325	;
    RnonCO2[	221	]=	-0.350	;
    RnonCO2[	222	]=	-0.250	;
    RnonCO2[	223	]=	-0.200	;
    RnonCO2[	224	]=	-0.150	;
    RnonCO2[	225	]=	-0.150	;
    RnonCO2[	226	]=	-1.350	;
    RnonCO2[	227	]=	-3.025	;
    RnonCO2[	228	]=	-1.225	;
    RnonCO2[	229	]=	-0.500	;
    RnonCO2[	230	]=	-0.250	;
    RnonCO2[	231	]=	-0.175	;
    RnonCO2[	232	]=	-0.125	;
    RnonCO2[	233	]=	-0.075	;
    RnonCO2[	234	]=	-0.050	;
    RnonCO2[	235	]=	-0.050	;
    RnonCO2[	236	]=	-0.050	;
    RnonCO2[	237	]=	-0.050	;
    RnonCO2[	238	]=	-0.075	;
    RnonCO2[	239	]=	-0.050	;
    RnonCO2[	240	]=	-0.075	;
    RnonCO2[	241	]=	-0.100	;
    RnonCO2[	242	]=	-0.100	;
    RnonCO2[	243	]=	-0.100	;
    RnonCO2[	244	]=	-0.125	;
    RnonCO2[	245	]=	-0.100	;
    RnonCO2[	246	]=	-0.125	;
    RnonCO2[	247	]=	0.000	;
    
    for(int i = 248; i<tmax; i++)
    {
        RnonCO2[i] = RnonCO2[i-1];
    }

}

//This is the RCP scenario historic analysis with max of zero
void setR_volcanic2(void)
{
    RnonCO2[    0    ]=    0.00000000    ;
    RnonCO2[    1    ]=    -0.11622211    ;
    RnonCO2[    2    ]=    0.00000000    ;
    RnonCO2[    3    ]=    -0.03500000    ;
    RnonCO2[    4    ]=    -0.10062500    ;
    RnonCO2[    5    ]=    -0.10500000    ;
    RnonCO2[    6    ]=    -0.05250000    ;
    RnonCO2[    7    ]=    -0.01750000    ;
    RnonCO2[    8    ]=    -0.00437500    ;
    RnonCO2[    9    ]=    0.00000000    ;
    RnonCO2[    10    ]=    0.00000000    ;
    RnonCO2[    11    ]=    0.00000000    ;
    RnonCO2[    12    ]=    0.00000000    ;
    RnonCO2[    13    ]=    0.00000000    ;
    RnonCO2[    14    ]=    0.00000000    ;
    RnonCO2[    15    ]=    0.00000000    ;
    RnonCO2[    16    ]=    0.00000000    ;
    RnonCO2[    17    ]=    -0.02187500    ;
    RnonCO2[    18    ]=    -0.11375000    ;
    RnonCO2[    19    ]=    -0.18812500    ;
    RnonCO2[    20    ]=    -0.13125000    ;
    RnonCO2[    21    ]=    -0.04375000    ;
    RnonCO2[    22    ]=    -0.00875000    ;
    RnonCO2[    23    ]=    -0.00437500    ;
    RnonCO2[    24    ]=    -0.10937500    ;
    RnonCO2[    25    ]=    -0.25812500    ;
    RnonCO2[    26    ]=    -0.22312500    ;
    RnonCO2[    27    ]=    -0.09187500    ;
    RnonCO2[    28    ]=    -0.02625000    ;
    RnonCO2[    29    ]=    -0.01750000    ;
    RnonCO2[    30    ]=    -0.03937500    ;
    RnonCO2[    31    ]=    -0.04375000    ;
    RnonCO2[    32    ]=    -0.02187500    ;
    RnonCO2[    33    ]=    -0.00437500    ;
    RnonCO2[    34    ]=    0.00000000    ;
    RnonCO2[    35    ]=    0.00000000    ;
    RnonCO2[    36    ]=    0.00000000    ;
    RnonCO2[    37    ]=    0.00000000    ;
    RnonCO2[    38    ]=    0.00000000    ;
    RnonCO2[    39    ]=    0.00000000    ;
    RnonCO2[    40    ]=    0.00000000    ;
    RnonCO2[    41    ]=    0.00000000    ;
    RnonCO2[    42    ]=    0.00000000    ;
    RnonCO2[    43    ]=    -0.49000000    ;
    RnonCO2[    44    ]=    -1.63187502    ;
    RnonCO2[    45    ]=    -2.03437502    ;
    RnonCO2[    46    ]=    -1.24250002    ;
    RnonCO2[    47    ]=    -0.57312500    ;
    RnonCO2[    48    ]=    -0.38062500    ;
    RnonCO2[    49    ]=    -0.91000000    ;
    RnonCO2[    50    ]=    -2.38437502    ;
    RnonCO2[    51    ]=    -2.89625002    ;
    RnonCO2[    52    ]=    -1.72812502    ;
    RnonCO2[    53    ]=    -0.59500000    ;
    RnonCO2[    54    ]=    -0.14000000    ;
    RnonCO2[    55    ]=    -0.00875000    ;
    RnonCO2[    56    ]=    0.00000000    ;
    RnonCO2[    57    ]=    0.00000000    ;
    RnonCO2[    58    ]=    0.00000000    ;
    RnonCO2[    59    ]=    0.00000000    ;
    RnonCO2[    60    ]=    0.00000000    ;
    RnonCO2[    61    ]=    0.00000000    ;
    RnonCO2[    62    ]=    0.00000000    ;
    RnonCO2[    63    ]=    -0.00437500    ;
    RnonCO2[    64    ]=    -0.03937500    ;
    RnonCO2[    65    ]=    -0.25375000    ;
    RnonCO2[    66    ]=    -0.63000000    ;
    RnonCO2[    67    ]=    -0.71750000    ;
    RnonCO2[    68    ]=    -0.41562500    ;
    RnonCO2[    69    ]=    -0.57750000    ;
    RnonCO2[    70    ]=    -1.22062500    ;
    RnonCO2[    71    ]=    -1.18125000    ;
    RnonCO2[    72    ]=    -0.58187500    ;
    RnonCO2[    73    ]=    -0.18812500    ;
    RnonCO2[    74    ]=    -0.05250000    ;
    RnonCO2[    75    ]=    -0.05250000    ;
    RnonCO2[    76    ]=    -0.05687500    ;
    RnonCO2[    77    ]=    -0.04375000    ;
    RnonCO2[    78    ]=    -0.06562500    ;
    RnonCO2[    79    ]=    -0.07875000    ;
    RnonCO2[    80    ]=    -0.04812500    ;
    RnonCO2[    81    ]=    -0.01750000    ;
    RnonCO2[    82    ]=    -0.00437500    ;
    RnonCO2[    83    ]=    0.00000000    ;
    RnonCO2[    84    ]=    -0.01645000    ;
    RnonCO2[    85    ]=    -0.04043958    ;
    RnonCO2[    86    ]=    -0.03941146    ;
    RnonCO2[    87    ]=    -0.02364688    ;
    RnonCO2[    88    ]=    -0.00891042    ;
    RnonCO2[    89    ]=    -0.00068542    ;
    RnonCO2[    90    ]=    -0.13125729    ;
    RnonCO2[    91    ]=    -0.58911563    ;
    RnonCO2[    92    ]=    -0.84271979    ;
    RnonCO2[    93    ]=    -0.53016979    ;
    RnonCO2[    94    ]=    -0.20425417    ;
    RnonCO2[    95    ]=    -0.08190729    ;
    RnonCO2[    96    ]=    -0.09287396    ;
    RnonCO2[    97    ]=    -0.17718021    ;
    RnonCO2[    98    ]=    -0.16484271    ;
    RnonCO2[    99    ]=    -0.08156458    ;
    RnonCO2[    100    ]=    -0.03392813    ;
    RnonCO2[    101    ]=    -0.01336563    ;
    RnonCO2[    102    ]=    -0.00342708    ;
    RnonCO2[    103    ]=    -0.00137083    ;
    RnonCO2[    104    ]=    -0.00959583    ;
    RnonCO2[    105    ]=    -0.01370833    ;
    RnonCO2[    106    ]=    -0.01302292    ;
    RnonCO2[    107    ]=    -0.02536042    ;
    RnonCO2[    108    ]=    -0.03906875    ;
    RnonCO2[    109    ]=    -0.03118646    ;
    RnonCO2[    110    ]=    -0.03838333    ;
    RnonCO2[    111    ]=    -0.07950833    ;
    RnonCO2[    112    ]=    -0.08396354    ;
    RnonCO2[    113    ]=    -0.05209167    ;
    RnonCO2[    114    ]=    -0.03050104    ;
    RnonCO2[    115    ]=    -0.01679271    ;
    RnonCO2[    116    ]=    -0.00959583    ;
    RnonCO2[    117    ]=    -0.12131875    ;
    RnonCO2[    118    ]=    -1.03497917    ;
    RnonCO2[    119    ]=    -1.76974582    ;
    RnonCO2[    120    ]=    -1.17651771    ;
    RnonCO2[    121    ]=    -0.68096146    ;
    RnonCO2[    122    ]=    -0.55381667    ;
    RnonCO2[    123    ]=    -0.44346458    ;
    RnonCO2[    124    ]=    -0.50995000    ;
    RnonCO2[    125    ]=    -0.56409792    ;
    RnonCO2[    126    ]=    -0.49418542    ;
    RnonCO2[    127    ]=    -0.32008959    ;
    RnonCO2[    128    ]=    -0.17238229    ;
    RnonCO2[    129    ]=    -0.06305833    ;
    RnonCO2[    130    ]=    -0.07059792    ;
    RnonCO2[    131    ]=    -0.21590625    ;
    RnonCO2[    132    ]=    -0.29712813    ;
    RnonCO2[    133    ]=    -0.19465834    ;
    RnonCO2[    134    ]=    -0.08190729    ;
    RnonCO2[    135    ]=    -0.03050104    ;
    RnonCO2[    136    ]=    -0.04078229    ;
    RnonCO2[    137    ]=    -0.48938750    ;
    RnonCO2[    138    ]=    -0.88350208    ;
    RnonCO2[    139    ]=    -0.58877292    ;
    RnonCO2[    140    ]=    -0.23030000    ;
    RnonCO2[    141    ]=    -0.13228542    ;
    RnonCO2[    142    ]=    -0.15627500    ;
    RnonCO2[    143    ]=    -0.14462292    ;
    RnonCO2[    144    ]=    -0.07848021    ;
    RnonCO2[    145    ]=    -0.04352396    ;
    RnonCO2[    146    ]=    -0.03735521    ;
    RnonCO2[    147    ]=    -0.28102084    ;
    RnonCO2[    148    ]=    -0.38897396    ;
    RnonCO2[    149    ]=    -0.17683750    ;
    RnonCO2[    150    ]=    -0.07299688    ;
    RnonCO2[    151    ]=    -0.04489479    ;
    RnonCO2[    152    ]=    -0.03632708    ;
    RnonCO2[    153    ]=    -0.03050104    ;
    RnonCO2[    154    ]=    -0.03769792    ;
    RnonCO2[    155    ]=    -0.12166146    ;
    RnonCO2[    156    ]=    -0.13674063    ;
    RnonCO2[    157    ]=    -0.05140625    ;
    RnonCO2[    158    ]=    -0.03015833    ;
    RnonCO2[    159    ]=    -0.04318125    ;
    RnonCO2[    160    ]=    -0.04318125    ;
    RnonCO2[    161    ]=    -0.03529896    ;
    RnonCO2[    162    ]=    -0.03735521    ;
    RnonCO2[    163    ]=    -0.08670521    ;
    RnonCO2[    164    ]=    -0.13639792    ;
    RnonCO2[    165    ]=    -0.11069479    ;
    RnonCO2[    166    ]=    -0.08601979    ;
    RnonCO2[    167    ]=    -0.11754896    ;
    RnonCO2[    168    ]=    -0.10863854    ;
    RnonCO2[    169    ]=    -0.07025521    ;
    RnonCO2[    170    ]=    -0.06305833    ;
    RnonCO2[    171    ]=    -0.05174896    ;
    RnonCO2[    172    ]=    -0.05311979    ;
    RnonCO2[    173    ]=    -0.06922708    ;
    RnonCO2[    174    ]=    -0.06854167    ;
    RnonCO2[    175    ]=    -0.04866458    ;
    RnonCO2[    176    ]=    -0.03941146    ;
    RnonCO2[    177    ]=    -0.06100208    ;
    RnonCO2[    178    ]=    -0.06614271    ;
    RnonCO2[    179    ]=    -0.04318125    ;
    RnonCO2[    180    ]=    -0.03255729    ;
    RnonCO2[    181    ]=    -0.02536042    ;
    RnonCO2[    182    ]=    -0.03358542    ;
    RnonCO2[    183    ]=    -0.03564167    ;
    RnonCO2[    184    ]=    -0.04318125    ;
    RnonCO2[    185    ]=    -0.04558021    ;
    RnonCO2[    186    ]=    -0.04181042    ;
    RnonCO2[    187    ]=    -0.04797917    ;
    RnonCO2[    188    ]=    -0.05688958    ;
    RnonCO2[    189    ]=    -0.05174896    ;
    RnonCO2[    190    ]=    -0.02947292    ;
    RnonCO2[    191    ]=    -0.01713542    ;
    RnonCO2[    192    ]=    -0.00685417    ;
    RnonCO2[    193    ]=    -0.00171354    ;
    RnonCO2[    194    ]=    -0.00548333    ;
    RnonCO2[    195    ]=    -0.08053646    ;
    RnonCO2[    196    ]=    -0.17169688    ;
    RnonCO2[    197    ]=    -0.24640729    ;
    RnonCO2[    198    ]=    -0.72791250    ;
    RnonCO2[    199    ]=    -1.08570000    ;
    RnonCO2[    200    ]=    -0.76492500    ;
    RnonCO2[    201    ]=    -0.38246250    ;
    RnonCO2[    202    ]=    -0.25394688    ;
    RnonCO2[    203    ]=    -0.45271771    ;
    RnonCO2[    204    ]=    -0.52879896    ;
    RnonCO2[    205    ]=    -0.28787500    ;
    RnonCO2[    206    ]=    -0.11823438    ;
    RnonCO2[    207    ]=    -0.07916563    ;
    RnonCO2[    208    ]=    -0.12611667    ;
    RnonCO2[    209    ]=    -0.27313854    ;
    RnonCO2[    210    ]=    -0.37355208    ;
    RnonCO2[    211    ]=    -0.24983438    ;
    RnonCO2[    212    ]=    -0.09835729    ;
    RnonCO2[    213    ]=    -0.12337500    ;
    RnonCO2[    214    ]=    -0.13845417    ;
    RnonCO2[    215    ]=    -0.08430625    ;
    RnonCO2[    216    ]=    -0.15284792    ;
    RnonCO2[    217    ]=    -0.82387083    ;
    RnonCO2[    218    ]=    -1.10866146    ;
    RnonCO2[    219    ]=    -0.55244583    ;
    RnonCO2[    220    ]=    -0.25566042    ;
    RnonCO2[    221    ]=    -0.19740000    ;
    RnonCO2[    222    ]=    -0.16655625    ;
    RnonCO2[    223    ]=    -0.12645938    ;
    RnonCO2[    224    ]=    -0.10315521    ;
    RnonCO2[    225    ]=    -0.10589688    ;
    RnonCO2[    226    ]=    -1.04731667    ;
    RnonCO2[    227    ]=    -1.65219692    ;
    RnonCO2[    228    ]=    -0.91434583    ;
    RnonCO2[    229    ]=    -0.36395625    ;
    RnonCO2[    230    ]=    -0.17375313    ;
    RnonCO2[    231    ]=    -0.10863854    ;
    RnonCO2[    232    ]=    -0.07916563    ;
    RnonCO2[    233    ]=    -0.04489479    ;
    RnonCO2[    234    ]=    -0.01610729    ;
    RnonCO2[    235    ]=    -0.00376979    ;
    RnonCO2[    236    ]=    0.00000000    ;
    RnonCO2[    237    ]=    0.00000000    ;
    RnonCO2[    238    ]=    0.00000000    ;
    RnonCO2[    239    ]=    0.00000000    ;
    RnonCO2[    240    ]=    -0.04842588    ;
    RnonCO2[    241    ]=    -0.16464799    ;
    RnonCO2[    242    ]=    -0.23244422    ;
    RnonCO2[    243    ]=    -0.23244422    ;
    RnonCO2[    244    ]=    -0.23244422    ;
    RnonCO2[    245    ]=    -0.23244422    ;
    RnonCO2[    246    ]=    -0.23244422    ;
    RnonCO2[    247    ]=    -0.23244422    ;
    RnonCO2[    248    ]=    -0.23244422    ;
    RnonCO2[    249    ]=    -0.23244422    ;
    RnonCO2[    250    ]=    -0.23244422    ;
    RnonCO2[    251    ]=    -0.23244422    ;
    RnonCO2[    252    ]=    -0.23244422    ;
    RnonCO2[    253    ]=    -0.23244422    ;
    RnonCO2[    254    ]=    -0.23244422    ;
    RnonCO2[    255    ]=    -0.23244422    ;
    RnonCO2[    256    ]=    -0.23244422    ;
    RnonCO2[    257    ]=    -0.23244422    ;
    RnonCO2[    258    ]=    -0.23244422    ;
    RnonCO2[    259    ]=    -0.23244422    ;
    RnonCO2[    260    ]=    -0.23244422    ;
    RnonCO2[    261    ]=    -0.23244422    ;
    RnonCO2[    262    ]=    -0.23244422    ;
    RnonCO2[    263    ]=    -0.23244422    ;
    RnonCO2[    264    ]=    -0.23244422    ;
    RnonCO2[    265    ]=    -0.23244422    ;
    RnonCO2[    266    ]=    -0.23244422    ;
    RnonCO2[    267    ]=    -0.23244422    ;
    RnonCO2[    268    ]=    -0.23244422    ;
    RnonCO2[    269    ]=    -0.23244422    ;
    RnonCO2[    270    ]=    -0.23244422    ;
    RnonCO2[    271    ]=    -0.23244422    ;
    RnonCO2[    272    ]=    -0.23244422    ;
    RnonCO2[    273    ]=    -0.23244422    ;
    RnonCO2[    274    ]=    -0.23244422    ;
    RnonCO2[    275    ]=    -0.23244422    ;
    RnonCO2[    276    ]=    -0.23244422    ;
    RnonCO2[    277    ]=    -0.23244422    ;
    RnonCO2[    278    ]=    -0.23244422    ;
    RnonCO2[    279    ]=    -0.23244422    ;
    RnonCO2[    280    ]=    -0.23244422    ;
    RnonCO2[    281    ]=    -0.23244422    ;
    RnonCO2[    282    ]=    -0.23244422    ;
    RnonCO2[    283    ]=    -0.23244422    ;
    RnonCO2[    284    ]=    -0.23244422    ;
    RnonCO2[    285    ]=    -0.23244422    ;
    RnonCO2[    286    ]=    -0.23244422    ;
    RnonCO2[    287    ]=    -0.23244422    ;
    RnonCO2[    288    ]=    -0.23244422    ;
    RnonCO2[    289    ]=    -0.23244422    ;
    RnonCO2[    290    ]=    -0.23244422    ;
    RnonCO2[    291    ]=    -0.23244422    ;
    RnonCO2[    292    ]=    -0.23244422    ;
    RnonCO2[    293    ]=    -0.23244422    ;
    RnonCO2[    294    ]=    -0.23244422    ;
    RnonCO2[    295    ]=    -0.23244422    ;
    RnonCO2[    296    ]=    -0.23244422    ;
    RnonCO2[    297    ]=    -0.23244422    ;
    RnonCO2[    298    ]=    -0.23244422    ;
    RnonCO2[    299    ]=    -0.23244422    ;
    RnonCO2[    300    ]=    -0.23244422    ;
    RnonCO2[    301    ]=    -0.23244422    ;
    RnonCO2[    302    ]=    -0.23244422    ;
    RnonCO2[    303    ]=    -0.23244422    ;
    RnonCO2[    304    ]=    -0.23244422    ;
    RnonCO2[    305    ]=    -0.23244422    ;
    RnonCO2[    306    ]=    -0.23244422    ;
    RnonCO2[    307    ]=    -0.23244422    ;
    RnonCO2[    308    ]=    -0.23244422    ;
    RnonCO2[    309    ]=    -0.23244422    ;
    RnonCO2[    310    ]=    -0.23244422    ;
    RnonCO2[    311    ]=    -0.23244422    ;
    RnonCO2[    312    ]=    -0.23244422    ;
    RnonCO2[    313    ]=    -0.23244422    ;
    RnonCO2[    314    ]=    -0.23244422    ;
    RnonCO2[    315    ]=    -0.23244422    ;
    RnonCO2[    316    ]=    -0.23244422    ;
    RnonCO2[    317    ]=    -0.23244422    ;
    RnonCO2[    318    ]=    -0.23244422    ;
    RnonCO2[    319    ]=    -0.23244422    ;
    RnonCO2[    320    ]=    -0.23244422    ;
    RnonCO2[    321    ]=    -0.23244422    ;
    RnonCO2[    322    ]=    -0.23244422    ;
    RnonCO2[    323    ]=    -0.23244422    ;
    RnonCO2[    324    ]=    -0.23244422    ;
    RnonCO2[    325    ]=    -0.23244422    ;
    RnonCO2[    326    ]=    -0.23244422    ;
    RnonCO2[    327    ]=    -0.23244422    ;
    RnonCO2[    328    ]=    -0.23244422    ;
    RnonCO2[    329    ]=    -0.23244422    ;
    RnonCO2[    330    ]=    -0.23244422    ;
    RnonCO2[    331    ]=    -0.23244422    ;
    RnonCO2[    332    ]=    -0.23244422    ;
    RnonCO2[    333    ]=    -0.23244422    ;
    RnonCO2[    334    ]=    -0.23244422    ;
    RnonCO2[    335    ]=    -0.23244422    ;
    RnonCO2[    336    ]=    -0.23244422    ;
    RnonCO2[    337    ]=    -0.23244422    ;
    RnonCO2[    338    ]=    -0.23244422    ;
    RnonCO2[    339    ]=    -0.23244422    ;
    RnonCO2[    340    ]=    -0.23244422    ;
    RnonCO2[    341    ]=    -0.23244422    ;
    RnonCO2[    342    ]=    -0.23244422    ;
    RnonCO2[    343    ]=    -0.23244422    ;
    RnonCO2[    344    ]=    -0.23244422    ;
    RnonCO2[    345    ]=    -0.23244422    ;
    RnonCO2[    346    ]=    -0.23244422    ;
    RnonCO2[    347    ]=    -0.23244422    ;
    RnonCO2[    348    ]=    -0.23244422    ;
    RnonCO2[    349    ]=    -0.23244422    ;
    RnonCO2[    350    ]=    -0.23244422    ;
    RnonCO2[    351    ]=    -0.23244422    ;
    RnonCO2[    352    ]=    -0.23244422    ;
    RnonCO2[    353    ]=    -0.23244422    ;
    RnonCO2[    354    ]=    -0.23244422    ;
    RnonCO2[    355    ]=    -0.23244422    ;
    RnonCO2[    356    ]=    -0.23244422    ;
    RnonCO2[    357    ]=    -0.23244422    ;
    RnonCO2[    358    ]=    -0.23244422    ;
    RnonCO2[    359    ]=    -0.23244422    ;
    RnonCO2[    360    ]=    -0.23244422    ;
    RnonCO2[    361    ]=    -0.23244422    ;
    RnonCO2[    362    ]=    -0.23244422    ;
    RnonCO2[    363    ]=    -0.23244422    ;
    RnonCO2[    364    ]=    -0.23244422    ;
    RnonCO2[    365    ]=    -0.23244422    ;
    RnonCO2[    366    ]=    -0.23244422    ;
    RnonCO2[    367    ]=    -0.23244422    ;
    RnonCO2[    368    ]=    -0.23244422    ;
    RnonCO2[    369    ]=    -0.23244422    ;
    RnonCO2[    370    ]=    -0.23244422    ;
    RnonCO2[    371    ]=    -0.23244422    ;
    RnonCO2[    372    ]=    -0.23244422    ;
    RnonCO2[    373    ]=    -0.23244422    ;
    RnonCO2[    374    ]=    -0.23244422    ;
    RnonCO2[    375    ]=    -0.23244422    ;
    RnonCO2[    376    ]=    -0.23244422    ;
    RnonCO2[    377    ]=    -0.23244422    ;
    RnonCO2[    378    ]=    -0.23244422    ;
    RnonCO2[    379    ]=    -0.23244422    ;
    RnonCO2[    380    ]=    -0.23244422    ;
    RnonCO2[    381    ]=    -0.23244422    ;
    RnonCO2[    382    ]=    -0.23244422    ;
    RnonCO2[    383    ]=    -0.23244422    ;
    RnonCO2[    384    ]=    -0.23244422    ;
    RnonCO2[    385    ]=    -0.23244422    ;
    RnonCO2[    386    ]=    -0.23244422    ;
    RnonCO2[    387    ]=    -0.23244422    ;
    RnonCO2[    388    ]=    -0.23244422    ;
    RnonCO2[    389    ]=    -0.23244422    ;
    RnonCO2[    390    ]=    -0.23244422    ;
    RnonCO2[    391    ]=    -0.23244422    ;
    RnonCO2[    392    ]=    -0.23244422    ;
    RnonCO2[    393    ]=    -0.23244422    ;
    RnonCO2[    394    ]=    -0.23244422    ;
    RnonCO2[    395    ]=    -0.23244422    ;
    RnonCO2[    396    ]=    -0.23244422    ;
    RnonCO2[    397    ]=    -0.23244422    ;
    RnonCO2[    398    ]=    -0.23244422    ;
    RnonCO2[    399    ]=    -0.23244422    ;
    RnonCO2[    400    ]=    -0.23244422    ;
    RnonCO2[    401    ]=    -0.23244422    ;
    RnonCO2[    402    ]=    -0.23244422    ;
    RnonCO2[    403    ]=    -0.23244422    ;
    RnonCO2[    404    ]=    -0.23244422    ;
    RnonCO2[    405    ]=    -0.23244422    ;
    RnonCO2[    406    ]=    -0.23244422    ;
    RnonCO2[    407    ]=    -0.23244422    ;
    RnonCO2[    408    ]=    -0.23244422    ;
    RnonCO2[    409    ]=    -0.23244422    ;
    RnonCO2[    410    ]=    -0.23244422    ;
    RnonCO2[    411    ]=    -0.23244422    ;
    RnonCO2[    412    ]=    -0.23244422    ;
    RnonCO2[    413    ]=    -0.23244422    ;
    RnonCO2[    414    ]=    -0.23244422    ;
    RnonCO2[    415    ]=    -0.23244422    ;
    RnonCO2[    416    ]=    -0.23244422    ;
    RnonCO2[    417    ]=    -0.23244422    ;
    RnonCO2[    418    ]=    -0.23244422    ;
    RnonCO2[    419    ]=    -0.23244422    ;
    RnonCO2[    420    ]=    -0.23244422    ;
    RnonCO2[    421    ]=    -0.23244422    ;
    RnonCO2[    422    ]=    -0.23244422    ;
    RnonCO2[    423    ]=    -0.23244422    ;
    RnonCO2[    424    ]=    -0.23244422    ;
    RnonCO2[    425    ]=    -0.23244422    ;
    RnonCO2[    426    ]=    -0.23244422    ;
    RnonCO2[    427    ]=    -0.23244422    ;
    RnonCO2[    428    ]=    -0.23244422    ;
    RnonCO2[    429    ]=    -0.23244422    ;
    RnonCO2[    430    ]=    -0.23244422    ;
    RnonCO2[    431    ]=    -0.23244422    ;
    RnonCO2[    432    ]=    -0.23244422    ;
    RnonCO2[    433    ]=    -0.23244422    ;
    RnonCO2[    434    ]=    -0.23244422    ;
    RnonCO2[    435    ]=    -0.23244422    ;
    RnonCO2[    436    ]=    -0.23244422    ;
    RnonCO2[    437    ]=    -0.23244422    ;
    RnonCO2[    438    ]=    -0.23244422    ;
    RnonCO2[    439    ]=    -0.23244422    ;
    RnonCO2[    440    ]=    -0.23244422    ;
    RnonCO2[    441    ]=    -0.23244422    ;
    RnonCO2[    442    ]=    -0.23244422    ;
    RnonCO2[    443    ]=    -0.23244422    ;
    RnonCO2[    444    ]=    -0.23244422    ;
    RnonCO2[    445    ]=    -0.23244422    ;
    RnonCO2[    446    ]=    -0.23244422    ;
    RnonCO2[    447    ]=    -0.23244422    ;
    RnonCO2[    448    ]=    -0.23244422    ;
    RnonCO2[    449    ]=    -0.23244422    ;
    RnonCO2[    450    ]=    -0.23244422    ;
    RnonCO2[    451    ]=    -0.23244422    ;
    RnonCO2[    452    ]=    -0.23244422    ;
    RnonCO2[    453    ]=    -0.23244422    ;
    RnonCO2[    454    ]=    -0.23244422    ;
    RnonCO2[    455    ]=    -0.23244422    ;
    RnonCO2[    456    ]=    -0.23244422    ;
    RnonCO2[    457    ]=    -0.23244422    ;
    RnonCO2[    458    ]=    -0.23244422    ;
    RnonCO2[    459    ]=    -0.23244422    ;
    RnonCO2[    460    ]=    -0.23244422    ;
    RnonCO2[    461    ]=    -0.23244422    ;
    RnonCO2[    462    ]=    -0.23244422    ;
    RnonCO2[    463    ]=    -0.23244422    ;
    RnonCO2[    464    ]=    -0.23244422    ;
    RnonCO2[    465    ]=    -0.23244422    ;
    RnonCO2[    466    ]=    -0.23244422    ;
    RnonCO2[    467    ]=    -0.23244422    ;
    RnonCO2[    468    ]=    -0.23244422    ;
    RnonCO2[    469    ]=    -0.23244422    ;
    RnonCO2[    470    ]=    -0.23244422    ;
    RnonCO2[    471    ]=    -0.23244422    ;
    RnonCO2[    472    ]=    -0.23244422    ;
    RnonCO2[    473    ]=    -0.23244422    ;
    RnonCO2[    474    ]=    -0.23244422    ;
    RnonCO2[    475    ]=    -0.23244422    ;
    RnonCO2[    476    ]=    -0.23244422    ;
    RnonCO2[    477    ]=    -0.23244422    ;
    RnonCO2[    478    ]=    -0.23244422    ;
    RnonCO2[    479    ]=    -0.23244422    ;
    RnonCO2[    480    ]=    -0.23244422    ;
    RnonCO2[    481    ]=    -0.23244422    ;
    RnonCO2[    482    ]=    -0.23244422    ;
    RnonCO2[    483    ]=    -0.23244422    ;
    RnonCO2[    484    ]=    -0.23244422    ;
    RnonCO2[    485    ]=    -0.23244422    ;
    RnonCO2[    486    ]=    -0.23244422    ;
    RnonCO2[    487    ]=    -0.23244422    ;
    RnonCO2[    488    ]=    -0.23244422    ;
    RnonCO2[    489    ]=    -0.23244422    ;
    RnonCO2[    490    ]=    -0.23244422    ;
    RnonCO2[    491    ]=    -0.23244422    ;
    RnonCO2[    492    ]=    -0.23244422    ;
    RnonCO2[    493    ]=    -0.23244422    ;
    RnonCO2[    494    ]=    -0.23244422    ;
    RnonCO2[    495    ]=    -0.23244422    ;
    RnonCO2[    496    ]=    -0.23244422    ;
    RnonCO2[    497    ]=    -0.23244422    ;
    RnonCO2[    498    ]=    -0.23244422    ;
    RnonCO2[    499    ]=    -0.23244422    ;
    RnonCO2[    500    ]=    -0.23244422    ;
    RnonCO2[    501    ]=    -0.23244422    ;
    RnonCO2[    502    ]=    -0.23244422    ;
    RnonCO2[    503    ]=    -0.23244422    ;
    RnonCO2[    504    ]=    -0.23244422    ;
    RnonCO2[    505    ]=    -0.23244422    ;
    RnonCO2[    506    ]=    -0.23244422    ;
    RnonCO2[    507    ]=    -0.23244422    ;
    RnonCO2[    508    ]=    -0.23244422    ;
    RnonCO2[    509    ]=    -0.23244422    ;
    RnonCO2[    510    ]=    -0.23244422    ;
    RnonCO2[    511    ]=    -0.23244422    ;
    RnonCO2[    512    ]=    -0.23244422    ;
    RnonCO2[    513    ]=    -0.23244422    ;
    RnonCO2[    514    ]=    -0.23244422    ;
    RnonCO2[    515    ]=    -0.23244422    ;
    RnonCO2[    516    ]=    -0.23244422    ;
    RnonCO2[    517    ]=    -0.23244422    ;
    RnonCO2[    518    ]=    -0.23244422    ;
    RnonCO2[    519    ]=    -0.23244422    ;
    RnonCO2[    520    ]=    -0.23244422    ;
    RnonCO2[    521    ]=    -0.23244422    ;
    RnonCO2[    522    ]=    -0.23244422    ;
    RnonCO2[    523    ]=    -0.23244422    ;
    RnonCO2[    524    ]=    -0.23244422    ;
    RnonCO2[    525    ]=    -0.23244422    ;
    RnonCO2[    526    ]=    -0.23244422    ;
    RnonCO2[    527    ]=    -0.23244422    ;
    RnonCO2[    528    ]=    -0.23244422    ;
    RnonCO2[    529    ]=    -0.23244422    ;
    RnonCO2[    530    ]=    -0.23244422    ;
    RnonCO2[    531    ]=    -0.23244422    ;
    RnonCO2[    532    ]=    -0.23244422    ;
    RnonCO2[    533    ]=    -0.23244422    ;
    RnonCO2[    534    ]=    -0.23244422    ;
    RnonCO2[    535    ]=    -0.23244422    ;
    RnonCO2[    536    ]=    -0.23244422    ;
    RnonCO2[    537    ]=    -0.23244422    ;
    RnonCO2[    538    ]=    -0.23244422    ;
    RnonCO2[    539    ]=    -0.23244422    ;
    RnonCO2[    540    ]=    -0.23244422    ;
    RnonCO2[    541    ]=    -0.23244422    ;
    RnonCO2[    542    ]=    -0.23244422    ;
    RnonCO2[    543    ]=    -0.23244422    ;
    RnonCO2[    544    ]=    -0.23244422    ;
    RnonCO2[    545    ]=    -0.23244422    ;
    RnonCO2[    546    ]=    -0.23244422    ;
    RnonCO2[    547    ]=    -0.23244422    ;
    RnonCO2[    548    ]=    -0.23244422    ;
    RnonCO2[    549    ]=    -0.23244422    ;
    RnonCO2[    550    ]=    -0.23244422    ;
    RnonCO2[    551    ]=    -0.23244422    ;
    RnonCO2[    552    ]=    -0.23244422    ;
    RnonCO2[    553    ]=    -0.23244422    ;
    RnonCO2[    554    ]=    -0.23244422    ;
    RnonCO2[    555    ]=    -0.23244422    ;
    RnonCO2[    556    ]=    -0.23244422    ;
    RnonCO2[    557    ]=    -0.23244422    ;
    RnonCO2[    558    ]=    -0.23244422    ;
    RnonCO2[    559    ]=    -0.23244422    ;
    RnonCO2[    560    ]=    -0.23244422    ;
    RnonCO2[    561    ]=    -0.23244422    ;
    RnonCO2[    562    ]=    -0.23244422    ;
    RnonCO2[    563    ]=    -0.23244422    ;
    RnonCO2[    564    ]=    -0.23244422    ;
    RnonCO2[    565    ]=    -0.23244422    ;
    RnonCO2[    566    ]=    -0.23244422    ;
    RnonCO2[    567    ]=    -0.23244422    ;
    RnonCO2[    568    ]=    -0.23244422    ;
    RnonCO2[    569    ]=    -0.23244422    ;
    RnonCO2[    570    ]=    -0.23244422    ;
    RnonCO2[    571    ]=    -0.23244422    ;
    RnonCO2[    572    ]=    -0.23244422    ;
    RnonCO2[    573    ]=    -0.23244422    ;
    RnonCO2[    574    ]=    -0.23244422    ;
    RnonCO2[    575    ]=    -0.23244422    ;
    RnonCO2[    576    ]=    -0.23244422    ;
    RnonCO2[    577    ]=    -0.23244422    ;
    RnonCO2[    578    ]=    -0.23244422    ;
    RnonCO2[    579    ]=    -0.23244422    ;
    RnonCO2[    580    ]=    -0.23244422    ;
    RnonCO2[    581    ]=    -0.23244422    ;
    RnonCO2[    582    ]=    -0.23244422    ;
    RnonCO2[    583    ]=    -0.23244422    ;
    RnonCO2[    584    ]=    -0.23244422    ;
    RnonCO2[    585    ]=    -0.23244422    ;
    RnonCO2[    586    ]=    -0.23244422    ;
    RnonCO2[    587    ]=    -0.23244422    ;
    RnonCO2[    588    ]=    -0.23244422    ;
    RnonCO2[    589    ]=    -0.23244422    ;
    RnonCO2[    590    ]=    -0.23244422    ;
    RnonCO2[    591    ]=    -0.23244422    ;
    RnonCO2[    592    ]=    -0.23244422    ;
    RnonCO2[    593    ]=    -0.23244422    ;
    RnonCO2[    594    ]=    -0.23244422    ;
    RnonCO2[    595    ]=    -0.23244422    ;
    RnonCO2[    596    ]=    -0.23244422    ;
    RnonCO2[    597    ]=    -0.23244422    ;
    RnonCO2[    598    ]=    -0.23244422    ;
    RnonCO2[    599    ]=    -0.23244422    ;
    RnonCO2[    600    ]=    -0.23244422    ;
    RnonCO2[    601    ]=    -0.23244422    ;
    RnonCO2[    602    ]=    -0.23244422    ;
    RnonCO2[    603    ]=    -0.23244422    ;
    RnonCO2[    604    ]=    -0.23244422    ;
    RnonCO2[    605    ]=    -0.23244422    ;
    RnonCO2[    606    ]=    -0.23244422    ;
    RnonCO2[    607    ]=    -0.23244422    ;
    RnonCO2[    608    ]=    -0.23244422    ;
    RnonCO2[    609    ]=    -0.23244422    ;
    RnonCO2[    610    ]=    -0.23244422    ;
    RnonCO2[    611    ]=    -0.23244422    ;
    RnonCO2[    612    ]=    -0.23244422    ;
    RnonCO2[    613    ]=    -0.23244422    ;
    RnonCO2[    614    ]=    -0.23244422    ;
    RnonCO2[    615    ]=    -0.23244422    ;
    RnonCO2[    616    ]=    -0.23244422    ;
    RnonCO2[    617    ]=    -0.23244422    ;
    RnonCO2[    618    ]=    -0.23244422    ;
    RnonCO2[    619    ]=    -0.23244422    ;
    RnonCO2[    620    ]=    -0.23244422    ;
    RnonCO2[    621    ]=    -0.23244422    ;
    RnonCO2[    622    ]=    -0.23244422    ;
    RnonCO2[    623    ]=    -0.23244422    ;
    RnonCO2[    624    ]=    -0.23244422    ;
    RnonCO2[    625    ]=    -0.23244422    ;
    RnonCO2[    626    ]=    -0.23244422    ;
    RnonCO2[    627    ]=    -0.23244422    ;
    RnonCO2[    628    ]=    -0.23244422    ;
    RnonCO2[    629    ]=    -0.23244422    ;
    RnonCO2[    630    ]=    -0.23244422    ;
    RnonCO2[    631    ]=    -0.23244422    ;
    RnonCO2[    632    ]=    -0.23244422    ;
    RnonCO2[    633    ]=    -0.23244422    ;
    RnonCO2[    634    ]=    -0.23244422    ;
    RnonCO2[    635    ]=    -0.23244422    ;
    RnonCO2[    636    ]=    -0.23244422    ;
    RnonCO2[    637    ]=    -0.23244422    ;
    RnonCO2[    638    ]=    -0.23244422    ;
    RnonCO2[    639    ]=    -0.23244422    ;
    RnonCO2[    640    ]=    -0.23244422    ;
    RnonCO2[    641    ]=    -0.23244422    ;
    RnonCO2[    642    ]=    -0.23244422    ;
    RnonCO2[    643    ]=    -0.23244422    ;
    RnonCO2[    644    ]=    -0.23244422    ;
    RnonCO2[    645    ]=    -0.23244422    ;
    RnonCO2[    646    ]=    -0.23244422    ;
    RnonCO2[    647    ]=    -0.23244422    ;
    RnonCO2[    648    ]=    -0.23244422    ;
    RnonCO2[    649    ]=    -0.23244422    ;
    RnonCO2[    650    ]=    -0.23244422    ;
    RnonCO2[    651    ]=    -0.23244422    ;
    RnonCO2[    652    ]=    -0.23244422    ;
    RnonCO2[    653    ]=    -0.23244422    ;
    RnonCO2[    654    ]=    -0.23244422    ;
    RnonCO2[    655    ]=    -0.23244422    ;
    RnonCO2[    656    ]=    -0.23244422    ;
    RnonCO2[    657    ]=    -0.23244422    ;
    RnonCO2[    658    ]=    -0.23244422    ;
    RnonCO2[    659    ]=    -0.23244422    ;
    RnonCO2[    660    ]=    -0.23244422    ;
    RnonCO2[    661    ]=    -0.23244422    ;
    RnonCO2[    662    ]=    -0.23244422    ;
    RnonCO2[    663    ]=    -0.23244422    ;
    RnonCO2[    664    ]=    -0.23244422    ;
    RnonCO2[    665    ]=    -0.23244422    ;
    RnonCO2[    666    ]=    -0.23244422    ;
    RnonCO2[    667    ]=    -0.23244422    ;
    RnonCO2[    668    ]=    -0.23244422    ;
    RnonCO2[    669    ]=    -0.23244422    ;
    RnonCO2[    670    ]=    -0.23244422    ;
    RnonCO2[    671    ]=    -0.23244422    ;
    RnonCO2[    672    ]=    -0.23244422    ;
    RnonCO2[    673    ]=    -0.23244422    ;
    RnonCO2[    674    ]=    -0.23244422    ;
    RnonCO2[    675    ]=    -0.23244422    ;
    RnonCO2[    676    ]=    -0.23244422    ;
    RnonCO2[    677    ]=    -0.23244422    ;
    RnonCO2[    678    ]=    -0.23244422    ;
    RnonCO2[    679    ]=    -0.23244422    ;
    RnonCO2[    680    ]=    -0.23244422    ;
    RnonCO2[    681    ]=    -0.23244422    ;
    RnonCO2[    682    ]=    -0.23244422    ;
    RnonCO2[    683    ]=    -0.23244422    ;
    RnonCO2[    684    ]=    -0.23244422    ;
    RnonCO2[    685    ]=    -0.23244422    ;
    RnonCO2[    686    ]=    -0.23244422    ;
    RnonCO2[    687    ]=    -0.23244422    ;
    RnonCO2[    688    ]=    -0.23244422    ;
    RnonCO2[    689    ]=    -0.23244422    ;
    RnonCO2[    690    ]=    -0.23244422    ;
    RnonCO2[    691    ]=    -0.23244422    ;
    RnonCO2[    692    ]=    -0.23244422    ;
    RnonCO2[    693    ]=    -0.23244422    ;
    RnonCO2[    694    ]=    -0.23244422    ;
    RnonCO2[    695    ]=    -0.23244422    ;
    RnonCO2[    696    ]=    -0.23244422    ;
    RnonCO2[    697    ]=    -0.23244422    ;
    RnonCO2[    698    ]=    -0.23244422    ;
    RnonCO2[    699    ]=    -0.23244422    ;
    RnonCO2[    700    ]=    -0.23244422    ;
    RnonCO2[    701    ]=    -0.23244422    ;
    RnonCO2[    702    ]=    -0.23244422    ;
    RnonCO2[    703    ]=    -0.23244422    ;
    RnonCO2[    704    ]=    -0.23244422    ;
    RnonCO2[    705    ]=    -0.23244422    ;
    RnonCO2[    706    ]=    -0.23244422    ;
    RnonCO2[    707    ]=    -0.23244422    ;
    RnonCO2[    708    ]=    -0.23244422    ;
    RnonCO2[    709    ]=    -0.23244422    ;
    RnonCO2[    710    ]=    -0.23244422    ;
    RnonCO2[    711    ]=    -0.23244422    ;
    RnonCO2[    712    ]=    -0.23244422    ;
    RnonCO2[    713    ]=    -0.23244422    ;
    RnonCO2[    714    ]=    -0.23244422    ;
    RnonCO2[    715    ]=    -0.23244422    ;
    RnonCO2[    716    ]=    -0.23244422    ;
    RnonCO2[    717    ]=    -0.23244422    ;
    RnonCO2[    718    ]=    -0.23244422    ;
    RnonCO2[    719    ]=    -0.23244422    ;
    RnonCO2[    720    ]=    -0.23244422    ;
    RnonCO2[    721    ]=    -0.23244422    ;
    RnonCO2[    722    ]=    -0.23244422    ;
    RnonCO2[    723    ]=    -0.23244422    ;
    RnonCO2[    724    ]=    -0.23244422    ;
    RnonCO2[    725    ]=    -0.23244422    ;
    RnonCO2[    726    ]=    -0.23244422    ;
    RnonCO2[    727    ]=    -0.23244422    ;
    RnonCO2[    728    ]=    -0.23244422    ;
    RnonCO2[    729    ]=    -0.23244422    ;
    RnonCO2[    730    ]=    -0.23244422    ;
    RnonCO2[    731    ]=    -0.23244422    ;
    RnonCO2[    732    ]=    -0.23244422    ;
    RnonCO2[    733    ]=    -0.23244422    ;
    RnonCO2[    734    ]=    -0.23244422    ;
    RnonCO2[    735    ]=    -0.23244422    ;
    
    for(int i = 736; i<tmax; i++)
    {

        RnonCO2[i] = RnonCO2[i-1];

    }
}

//Sets Aerosol Optical Depth (Must have 12 time steps per year to use
//From data.giss.nasa.gov/modelforce/strataer/reff_line.txt, downloaded 14th November 2017
void setAOD(int start_year, int t_step_month)
{
    int n=0;
    for(int i=0; i< (1850-start_year)*12; i++)
    {
        AOD[i] = 0.0;
        n++;
    }
    AOD[    n+    1    ]=    0.0044    ;
    AOD[    n+    2    ]=    0.0042    ;
    AOD[    n+    3    ]=    0.004    ;
    AOD[    n+    4    ]=    0.0039    ;
    AOD[    n+    5    ]=    0.0037    ;
    AOD[    n+    6    ]=    0.0036    ;
    AOD[    n+    7    ]=    0.0034    ;
    AOD[    n+    8    ]=    0.0034    ;
    AOD[    n+    9    ]=    0.0033    ;
    AOD[    n+    10    ]=    0.0032    ;
    AOD[    n+    11    ]=    0.0031    ;
    AOD[    n+    12    ]=    0.003    ;
    AOD[    n+    13    ]=    0.003    ;
    AOD[    n+    14    ]=    0.0029    ;
    AOD[    n+    15    ]=    0.0028    ;
    AOD[    n+    16    ]=    0.0027    ;
    AOD[    n+    17    ]=    0.0026    ;
    AOD[    n+    18    ]=    0.0026    ;
    AOD[    n+    19    ]=    0.0025    ;
    AOD[    n+    20    ]=    0.0024    ;
    AOD[    n+    21    ]=    0.0023    ;
    AOD[    n+    22    ]=    0.0022    ;
    AOD[    n+    23    ]=    0.0021    ;
    AOD[    n+    24    ]=    0.002    ;
    AOD[    n+    25    ]=    0.0019    ;
    AOD[    n+    26    ]=    0.0018    ;
    AOD[    n+    27    ]=    0.0018    ;
    AOD[    n+    28    ]=    0.0017    ;
    AOD[    n+    29    ]=    0.0016    ;
    AOD[    n+    30    ]=    0.0015    ;
    AOD[    n+    31    ]=    0.0014    ;
    AOD[    n+    32    ]=    0.0013    ;
    AOD[    n+    33    ]=    0.0012    ;
    AOD[    n+    34    ]=    0.0011    ;
    AOD[    n+    35    ]=    0.001    ;
    AOD[    n+    36    ]=    0.001    ;
    AOD[    n+    37    ]=    0.0009    ;
    AOD[    n+    38    ]=    0.0008    ;
    AOD[    n+    39    ]=    0.0008    ;
    AOD[    n+    40    ]=    0.0007    ;
    AOD[    n+    41    ]=    0.0007    ;
    AOD[    n+    42    ]=    0.0006    ;
    AOD[    n+    43    ]=    0.0006    ;
    AOD[    n+    44    ]=    0.0005    ;
    AOD[    n+    45    ]=    0.0005    ;
    AOD[    n+    46    ]=    0.0005    ;
    AOD[    n+    47    ]=    0.0004    ;
    AOD[    n+    48    ]=    0.0004    ;
    AOD[    n+    49    ]=    0.0004    ;
    AOD[    n+    50    ]=    0.0004    ;
    AOD[    n+    51    ]=    0.0003    ;
    AOD[    n+    52    ]=    0.0003    ;
    AOD[    n+    53    ]=    0.0003    ;
    AOD[    n+    54    ]=    0.0003    ;
    AOD[    n+    55    ]=    0.0003    ;
    AOD[    n+    56    ]=    0.0003    ;
    AOD[    n+    57    ]=    0.0002    ;
    AOD[    n+    58    ]=    0.0002    ;
    AOD[    n+    59    ]=    0.0002    ;
    AOD[    n+    60    ]=    0.0002    ;
    AOD[    n+    61    ]=    0.0002    ;
    AOD[    n+    62    ]=    0.0002    ;
    AOD[    n+    63    ]=    0.0002    ;
    AOD[    n+    64    ]=    0.0002    ;
    AOD[    n+    65    ]=    0.0002    ;
    AOD[    n+    66    ]=    0.0002    ;
    AOD[    n+    67    ]=    0.0002    ;
    AOD[    n+    68    ]=    0.0002    ;
    AOD[    n+    69    ]=    0.0002    ;
    AOD[    n+    70    ]=    0.0029    ;
    AOD[    n+    71    ]=    0.0075    ;
    AOD[    n+    72    ]=    0.0122    ;
    AOD[    n+    73    ]=    0.0168    ;
    AOD[    n+    74    ]=    0.0214    ;
    AOD[    n+    75    ]=    0.026    ;
    AOD[    n+    76    ]=    0.0306    ;
    AOD[    n+    77    ]=    0.0352    ;
    AOD[    n+    78    ]=    0.0399    ;
    AOD[    n+    79    ]=    0.0433    ;
    AOD[    n+    80    ]=    0.0456    ;
    AOD[    n+    81    ]=    0.0479    ;
    AOD[    n+    82    ]=    0.0501    ;
    AOD[    n+    83    ]=    0.0524    ;
    AOD[    n+    84    ]=    0.0547    ;
    AOD[    n+    85    ]=    0.057    ;
    AOD[    n+    86    ]=    0.0593    ;
    AOD[    n+    87    ]=    0.0615    ;
    AOD[    n+    88    ]=    0.0638    ;
    AOD[    n+    89    ]=    0.0661    ;
    AOD[    n+    90    ]=    0.0684    ;
    AOD[    n+    91    ]=    0.0675    ;
    AOD[    n+    92    ]=    0.0636    ;
    AOD[    n+    93    ]=    0.0596    ;
    AOD[    n+    94    ]=    0.0557    ;
    AOD[    n+    95    ]=    0.0517    ;
    AOD[    n+    96    ]=    0.0478    ;
    AOD[    n+    97    ]=    0.044    ;
    AOD[    n+    98    ]=    0.0405    ;
    AOD[    n+    99    ]=    0.0372    ;
    AOD[    n+    100    ]=    0.0343    ;
    AOD[    n+    101    ]=    0.0315    ;
    AOD[    n+    102    ]=    0.029    ;
    AOD[    n+    103    ]=    0.0267    ;
    AOD[    n+    104    ]=    0.0246    ;
    AOD[    n+    105    ]=    0.0226    ;
    AOD[    n+    106    ]=    0.0208    ;
    AOD[    n+    107    ]=    0.0192    ;
    AOD[    n+    108    ]=    0.0176    ;
    AOD[    n+    109    ]=    0.0162    ;
    AOD[    n+    110    ]=    0.015    ;
    AOD[    n+    111    ]=    0.0139    ;
    AOD[    n+    112    ]=    0.013    ;
    AOD[    n+    113    ]=    0.012    ;
    AOD[    n+    114    ]=    0.011    ;
    AOD[    n+    115    ]=    0.0103    ;
    AOD[    n+    116    ]=    0.0097    ;
    AOD[    n+    117    ]=    0.0091    ;
    AOD[    n+    118    ]=    0.0086    ;
    AOD[    n+    119    ]=    0.008    ;
    AOD[    n+    120    ]=    0.0074    ;
    AOD[    n+    121    ]=    0.0069    ;
    AOD[    n+    122    ]=    0.0064    ;
    AOD[    n+    123    ]=    0.0059    ;
    AOD[    n+    124    ]=    0.0054    ;
    AOD[    n+    125    ]=    0.005    ;
    AOD[    n+    126    ]=    0.0046    ;
    AOD[    n+    127    ]=    0.0042    ;
    AOD[    n+    128    ]=    0.0039    ;
    AOD[    n+    129    ]=    0.0036    ;
    AOD[    n+    130    ]=    0.0033    ;
    AOD[    n+    131    ]=    0.0031    ;
    AOD[    n+    132    ]=    0.0028    ;
    AOD[    n+    133    ]=    0.0026    ;
    AOD[    n+    134    ]=    0.0024    ;
    AOD[    n+    135    ]=    0.0022    ;
    AOD[    n+    136    ]=    0.002    ;
    AOD[    n+    137    ]=    0.0019    ;
    AOD[    n+    138    ]=    0.0017    ;
    AOD[    n+    139    ]=    0.0016    ;
    AOD[    n+    140    ]=    0.0027    ;
    AOD[    n+    141    ]=    0.004    ;
    AOD[    n+    142    ]=    0.0053    ;
    AOD[    n+    143    ]=    0.0066    ;
    AOD[    n+    144    ]=    0.0079    ;
    AOD[    n+    145    ]=    0.0092    ;
    AOD[    n+    146    ]=    0.0105    ;
    AOD[    n+    147    ]=    0.0118    ;
    AOD[    n+    148    ]=    0.0132    ;
    AOD[    n+    149    ]=    0.0145    ;
    AOD[    n+    150    ]=    0.0158    ;
    AOD[    n+    151    ]=    0.0162    ;
    AOD[    n+    152    ]=    0.0156    ;
    AOD[    n+    153    ]=    0.0151    ;
    AOD[    n+    154    ]=    0.0145    ;
    AOD[    n+    155    ]=    0.014    ;
    AOD[    n+    156    ]=    0.0135    ;
    AOD[    n+    157    ]=    0.0129    ;
    AOD[    n+    158    ]=    0.0124    ;
    AOD[    n+    159    ]=    0.0118    ;
    AOD[    n+    160    ]=    0.0113    ;
    AOD[    n+    161    ]=    0.0107    ;
    AOD[    n+    162    ]=    0.0102    ;
    AOD[    n+    163    ]=    0.0097    ;
    AOD[    n+    164    ]=    0.0092    ;
    AOD[    n+    165    ]=    0.0087    ;
    AOD[    n+    166    ]=    0.0082    ;
    AOD[    n+    167    ]=    0.0078    ;
    AOD[    n+    168    ]=    0.0073    ;
    AOD[    n+    169    ]=    0.0068    ;
    AOD[    n+    170    ]=    0.0063    ;
    AOD[    n+    171    ]=    0.0058    ;
    AOD[    n+    172    ]=    0.0054    ;
    AOD[    n+    173    ]=    0.005    ;
    AOD[    n+    174    ]=    0.0046    ;
    AOD[    n+    175    ]=    0.0042    ;
    AOD[    n+    176    ]=    0.0039    ;
    AOD[    n+    177    ]=    0.0037    ;
    AOD[    n+    178    ]=    0.0035    ;
    AOD[    n+    179    ]=    0.0033    ;
    AOD[    n+    180    ]=    0.0031    ;
    AOD[    n+    181    ]=    0.0029    ;
    AOD[    n+    182    ]=    0.0027    ;
    AOD[    n+    183    ]=    0.0025    ;
    AOD[    n+    184    ]=    0.0023    ;
    AOD[    n+    185    ]=    0.0022    ;
    AOD[    n+    186    ]=    0.002    ;
    AOD[    n+    187    ]=    0.0019    ;
    AOD[    n+    188    ]=    0.0017    ;
    AOD[    n+    189    ]=    0.0016    ;
    AOD[    n+    190    ]=    0.0015    ;
    AOD[    n+    191    ]=    0.0014    ;
    AOD[    n+    192    ]=    0.0013    ;
    AOD[    n+    193    ]=    0.0012    ;
    AOD[    n+    194    ]=    0.0011    ;
    AOD[    n+    195    ]=    0.001    ;
    AOD[    n+    196    ]=    0.001    ;
    AOD[    n+    197    ]=    0.0009    ;
    AOD[    n+    198    ]=    0.0008    ;
    AOD[    n+    199    ]=    0.0008    ;
    AOD[    n+    200    ]=    0.0007    ;
    AOD[    n+    201    ]=    0.0007    ;
    AOD[    n+    202    ]=    0.0006    ;
    AOD[    n+    203    ]=    0.0006    ;
    AOD[    n+    204    ]=    0.0005    ;
    AOD[    n+    205    ]=    0.0005    ;
    AOD[    n+    206    ]=    0.0005    ;
    AOD[    n+    207    ]=    0.0004    ;
    AOD[    n+    208    ]=    0.0004    ;
    AOD[    n+    209    ]=    0.0004    ;
    AOD[    n+    210    ]=    0.0004    ;
    AOD[    n+    211    ]=    0.0003    ;
    AOD[    n+    212    ]=    0.0003    ;
    AOD[    n+    213    ]=    0.0003    ;
    AOD[    n+    214    ]=    0.0003    ;
    AOD[    n+    215    ]=    0.0003    ;
    AOD[    n+    216    ]=    0.0003    ;
    AOD[    n+    217    ]=    0.0002    ;
    AOD[    n+    218    ]=    0.0002    ;
    AOD[    n+    219    ]=    0.0002    ;
    AOD[    n+    220    ]=    0.0002    ;
    AOD[    n+    221    ]=    0.0002    ;
    AOD[    n+    222    ]=    0.0002    ;
    AOD[    n+    223    ]=    0.0002    ;
    AOD[    n+    224    ]=    0.0002    ;
    AOD[    n+    225    ]=    0.0002    ;
    AOD[    n+    226    ]=    0.0002    ;
    AOD[    n+    227    ]=    0.0002    ;
    AOD[    n+    228    ]=    0.0003    ;
    AOD[    n+    229    ]=    0.0003    ;
    AOD[    n+    230    ]=    0.0004    ;
    AOD[    n+    231    ]=    0.0005    ;
    AOD[    n+    232    ]=    0.0005    ;
    AOD[    n+    233    ]=    0.0006    ;
    AOD[    n+    234    ]=    0.0007    ;
    AOD[    n+    235    ]=    0.0007    ;
    AOD[    n+    236    ]=    0.0007    ;
    AOD[    n+    237    ]=    0.0007    ;
    AOD[    n+    238    ]=    0.0007    ;
    AOD[    n+    239    ]=    0.0007    ;
    AOD[    n+    240    ]=    0.0007    ;
    AOD[    n+    241    ]=    0.0007    ;
    AOD[    n+    242    ]=    0.0006    ;
    AOD[    n+    243    ]=    0.0006    ;
    AOD[    n+    244    ]=    0.0006    ;
    AOD[    n+    245    ]=    0.0006    ;
    AOD[    n+    246    ]=    0.0006    ;
    AOD[    n+    247    ]=    0.0006    ;
    AOD[    n+    248    ]=    0.0006    ;
    AOD[    n+    249    ]=    0.0006    ;
    AOD[    n+    250    ]=    0.0006    ;
    AOD[    n+    251    ]=    0.0006    ;
    AOD[    n+    252    ]=    0.0006    ;
    AOD[    n+    253    ]=    0.0006    ;
    AOD[    n+    254    ]=    0.0006    ;
    AOD[    n+    255    ]=    0.0005    ;
    AOD[    n+    256    ]=    0.0005    ;
    AOD[    n+    257    ]=    0.0005    ;
    AOD[    n+    258    ]=    0.0005    ;
    AOD[    n+    259    ]=    0.0005    ;
    AOD[    n+    260    ]=    0.0006    ;
    AOD[    n+    261    ]=    0.0006    ;
    AOD[    n+    262    ]=    0.0007    ;
    AOD[    n+    263    ]=    0.0007    ;
    AOD[    n+    264    ]=    0.0008    ;
    AOD[    n+    265    ]=    0.0008    ;
    AOD[    n+    266    ]=    0.0009    ;
    AOD[    n+    267    ]=    0.0009    ;
    AOD[    n+    268    ]=    0.001    ;
    AOD[    n+    269    ]=    0.001    ;
    AOD[    n+    270    ]=    0.001    ;
    AOD[    n+    271    ]=    0.0012    ;
    AOD[    n+    272    ]=    0.0014    ;
    AOD[    n+    273    ]=    0.0016    ;
    AOD[    n+    274    ]=    0.0018    ;
    AOD[    n+    275    ]=    0.002    ;
    AOD[    n+    276    ]=    0.0022    ;
    AOD[    n+    277    ]=    0.0024    ;
    AOD[    n+    278    ]=    0.0026    ;
    AOD[    n+    279    ]=    0.0028    ;
    AOD[    n+    280    ]=    0.003    ;
    AOD[    n+    281    ]=    0.0032    ;
    AOD[    n+    282    ]=    0.0034    ;
    AOD[    n+    283    ]=    0.0034    ;
    AOD[    n+    284    ]=    0.0033    ;
    AOD[    n+    285    ]=    0.0032    ;
    AOD[    n+    286    ]=    0.0031    ;
    AOD[    n+    287    ]=    0.0029    ;
    AOD[    n+    288    ]=    0.0028    ;
    AOD[    n+    289    ]=    0.0027    ;
    AOD[    n+    290    ]=    0.0025    ;
    AOD[    n+    291    ]=    0.0024    ;
    AOD[    n+    292    ]=    0.0023    ;
    AOD[    n+    293    ]=    0.0022    ;
    AOD[    n+    294    ]=    0.002    ;
    AOD[    n+    295    ]=    0.0019    ;
    AOD[    n+    296    ]=    0.0017    ;
    AOD[    n+    297    ]=    0.0016    ;
    AOD[    n+    298    ]=    0.0015    ;
    AOD[    n+    299    ]=    0.0014    ;
    AOD[    n+    300    ]=    0.0013    ;
    AOD[    n+    301    ]=    0.0012    ;
    AOD[    n+    302    ]=    0.0011    ;
    AOD[    n+    303    ]=    0.001    ;
    AOD[    n+    304    ]=    0.0009    ;
    AOD[    n+    305    ]=    0.0009    ;
    AOD[    n+    306    ]=    0.0008    ;
    AOD[    n+    307    ]=    0.0008    ;
    AOD[    n+    308    ]=    0.0007    ;
    AOD[    n+    309    ]=    0.001    ;
    AOD[    n+    310    ]=    0.0017    ;
    AOD[    n+    311    ]=    0.0024    ;
    AOD[    n+    312    ]=    0.003    ;
    AOD[    n+    313    ]=    0.0037    ;
    AOD[    n+    314    ]=    0.0044    ;
    AOD[    n+    315    ]=    0.0051    ;
    AOD[    n+    316    ]=    0.0058    ;
    AOD[    n+    317    ]=    0.0065    ;
    AOD[    n+    318    ]=    0.0072    ;
    AOD[    n+    319    ]=    0.0074    ;
    AOD[    n+    320    ]=    0.0072    ;
    AOD[    n+    321    ]=    0.007    ;
    AOD[    n+    322    ]=    0.0069    ;
    AOD[    n+    323    ]=    0.0067    ;
    AOD[    n+    324    ]=    0.0065    ;
    AOD[    n+    325    ]=    0.0063    ;
    AOD[    n+    326    ]=    0.0061    ;
    AOD[    n+    327    ]=    0.0059    ;
    AOD[    n+    328    ]=    0.0057    ;
    AOD[    n+    329    ]=    0.0056    ;
    AOD[    n+    330    ]=    0.0054    ;
    AOD[    n+    331    ]=    0.0052    ;
    AOD[    n+    332    ]=    0.005    ;
    AOD[    n+    333    ]=    0.0048    ;
    AOD[    n+    334    ]=    0.0046    ;
    AOD[    n+    335    ]=    0.0044    ;
    AOD[    n+    336    ]=    0.0042    ;
    AOD[    n+    337    ]=    0.004    ;
    AOD[    n+    338    ]=    0.0039    ;
    AOD[    n+    339    ]=    0.0037    ;
    AOD[    n+    340    ]=    0.0035    ;
    AOD[    n+    341    ]=    0.0033    ;
    AOD[    n+    342    ]=    0.0031    ;
    AOD[    n+    343    ]=    0.0029    ;
    AOD[    n+    344    ]=    0.0029    ;
    AOD[    n+    345    ]=    0.0028    ;
    AOD[    n+    346    ]=    0.0027    ;
    AOD[    n+    347    ]=    0.0026    ;
    AOD[    n+    348    ]=    0.0025    ;
    AOD[    n+    349    ]=    0.0024    ;
    AOD[    n+    350    ]=    0.0024    ;
    AOD[    n+    351    ]=    0.0023    ;
    AOD[    n+    352    ]=    0.0022    ;
    AOD[    n+    353    ]=    0.0021    ;
    AOD[    n+    354    ]=    0.002    ;
    AOD[    n+    355    ]=    0.002    ;
    AOD[    n+    356    ]=    0.0019    ;
    AOD[    n+    357    ]=    0.0018    ;
    AOD[    n+    358    ]=    0.0017    ;
    AOD[    n+    359    ]=    0.0016    ;
    AOD[    n+    360    ]=    0.0016    ;
    AOD[    n+    361    ]=    0.0015    ;
    AOD[    n+    362    ]=    0.0014    ;
    AOD[    n+    363    ]=    0.0014    ;
    AOD[    n+    364    ]=    0.0013    ;
    AOD[    n+    365    ]=    0.0012    ;
    AOD[    n+    366    ]=    0.0011    ;
    AOD[    n+    367    ]=    0.0011    ;
    AOD[    n+    368    ]=    0.001    ;
    AOD[    n+    369    ]=    0.001    ;
    AOD[    n+    370    ]=    0.0009    ;
    AOD[    n+    371    ]=    0.0009    ;
    AOD[    n+    372    ]=    0.0009    ;
    AOD[    n+    373    ]=    0.0008    ;
    AOD[    n+    374    ]=    0.0008    ;
    AOD[    n+    375    ]=    0.0008    ;
    AOD[    n+    376    ]=    0.0007    ;
    AOD[    n+    377    ]=    0.0007    ;
    AOD[    n+    378    ]=    0.0006    ;
    AOD[    n+    379    ]=    0.0006    ;
    AOD[    n+    380    ]=    0.0006    ;
    AOD[    n+    381    ]=    0.0006    ;
    AOD[    n+    382    ]=    0.0006    ;
    AOD[    n+    383    ]=    0.0006    ;
    AOD[    n+    384    ]=    0.0006    ;
    AOD[    n+    385    ]=    0.0006    ;
    AOD[    n+    386    ]=    0.0006    ;
    AOD[    n+    387    ]=    0.0006    ;
    AOD[    n+    388    ]=    0.0006    ;
    AOD[    n+    389    ]=    0.0006    ;
    AOD[    n+    390    ]=    0.0006    ;
    AOD[    n+    391    ]=    0.0006    ;
    AOD[    n+    392    ]=    0.0006    ;
    AOD[    n+    393    ]=    0.0006    ;
    AOD[    n+    394    ]=    0.0005    ;
    AOD[    n+    395    ]=    0.0005    ;
    AOD[    n+    396    ]=    0.0005    ;
    AOD[    n+    397    ]=    0.0291    ;
    AOD[    n+    398    ]=    0.0328    ;
    AOD[    n+    399    ]=    0.0302    ;
    AOD[    n+    400    ]=    0.0278    ;
    AOD[    n+    401    ]=    0.0255    ;
    AOD[    n+    402    ]=    0.0235    ;
    AOD[    n+    403    ]=    0.0216    ;
    AOD[    n+    404    ]=    0.0197    ;
    AOD[    n+    405    ]=    0.0415    ;
    AOD[    n+    406    ]=    0.0781    ;
    AOD[    n+    407    ]=    0.106    ;
    AOD[    n+    408    ]=    0.1317    ;
    AOD[    n+    409    ]=    0.1518    ;
    AOD[    n+    410    ]=    0.1523    ;
    AOD[    n+    411    ]=    0.1631    ;
    AOD[    n+    412    ]=    0.1644    ;
    AOD[    n+    413    ]=    0.157    ;
    AOD[    n+    414    ]=    0.1525    ;
    AOD[    n+    415    ]=    0.1516    ;
    AOD[    n+    416    ]=    0.1392    ;
    AOD[    n+    417    ]=    0.135    ;
    AOD[    n+    418    ]=    0.1255    ;
    AOD[    n+    419    ]=    0.1149    ;
    AOD[    n+    420    ]=    0.1076    ;
    AOD[    n+    421    ]=    0.1009    ;
    AOD[    n+    422    ]=    0.0872    ;
    AOD[    n+    423    ]=    0.0817    ;
    AOD[    n+    424    ]=    0.0727    ;
    AOD[    n+    425    ]=    0.0668    ;
    AOD[    n+    426    ]=    0.0615    ;
    AOD[    n+    427    ]=    0.0577    ;
    AOD[    n+    428    ]=    0.053    ;
    AOD[    n+    429    ]=    0.049    ;
    AOD[    n+    430    ]=    0.0468    ;
    AOD[    n+    431    ]=    0.0433    ;
    AOD[    n+    432    ]=    0.0413    ;
    AOD[    n+    433    ]=    0.0385    ;
    AOD[    n+    434    ]=    0.0343    ;
    AOD[    n+    435    ]=    0.0313    ;
    AOD[    n+    436    ]=    0.0291    ;
    AOD[    n+    437    ]=    0.0261    ;
    AOD[    n+    438    ]=    0.0239    ;
    AOD[    n+    439    ]=    0.0225    ;
    AOD[    n+    440    ]=    0.0203    ;
    AOD[    n+    441    ]=    0.0197    ;
    AOD[    n+    442    ]=    0.0692    ;
    AOD[    n+    443    ]=    0.0637    ;
    AOD[    n+    444    ]=    0.0586    ;
    AOD[    n+    445    ]=    0.0539    ;
    AOD[    n+    446    ]=    0.0496    ;
    AOD[    n+    447    ]=    0.0457    ;
    AOD[    n+    448    ]=    0.042    ;
    AOD[    n+    449    ]=    0.0387    ;
    AOD[    n+    450    ]=    0.0356    ;
    AOD[    n+    451    ]=    0.0328    ;
    AOD[    n+    452    ]=    0.0345    ;
    AOD[    n+    453    ]=    0.0317    ;
    AOD[    n+    454    ]=    0.0292    ;
    AOD[    n+    455    ]=    0.0269    ;
    AOD[    n+    456    ]=    0.0247    ;
    AOD[    n+    457    ]=    0.0228    ;
    AOD[    n+    458    ]=    0.021    ;
    AOD[    n+    459    ]=    0.0193    ;
    AOD[    n+    460    ]=    0.0178    ;
    AOD[    n+    461    ]=    0.0163    ;
    AOD[    n+    462    ]=    0.011    ;
    AOD[    n+    463    ]=    0.013    ;
    AOD[    n+    464    ]=    0.0149    ;
    AOD[    n+    465    ]=    0.0222    ;
    AOD[    n+    466    ]=    0.0296    ;
    AOD[    n+    467    ]=    0.0368    ;
    AOD[    n+    468    ]=    0.0376    ;
    AOD[    n+    469    ]=    0.0385    ;
    AOD[    n+    470    ]=    0.0393    ;
    AOD[    n+    471    ]=    0.0361    ;
    AOD[    n+    472    ]=    0.0332    ;
    AOD[    n+    473    ]=    0.0306    ;
    AOD[    n+    474    ]=    0.0282    ;
    AOD[    n+    475    ]=    0.0259    ;
    AOD[    n+    476    ]=    0.0238    ;
    AOD[    n+    477    ]=    0.0219    ;
    AOD[    n+    478    ]=    0.0202    ;
    AOD[    n+    479    ]=    0.0191    ;
    AOD[    n+    480    ]=    0.0256    ;
    AOD[    n+    481    ]=    0.0321    ;
    AOD[    n+    482    ]=    0.0387    ;
    AOD[    n+    483    ]=    0.0418    ;
    AOD[    n+    484    ]=    0.045    ;
    AOD[    n+    485    ]=    0.0482    ;
    AOD[    n+    486    ]=    0.0443    ;
    AOD[    n+    487    ]=    0.0408    ;
    AOD[    n+    488    ]=    0.0375    ;
    AOD[    n+    489    ]=    0.0345    ;
    AOD[    n+    490    ]=    0.0331    ;
    AOD[    n+    491    ]=    0.0359    ;
    AOD[    n+    492    ]=    0.0376    ;
    AOD[    n+    493    ]=    0.0398    ;
    AOD[    n+    494    ]=    0.0422    ;
    AOD[    n+    495    ]=    0.0388    ;
    AOD[    n+    496    ]=    0.0357    ;
    AOD[    n+    497    ]=    0.0328    ;
    AOD[    n+    498    ]=    0.0303    ;
    AOD[    n+    499    ]=    0.0278    ;
    AOD[    n+    500    ]=    0.0256    ;
    AOD[    n+    501    ]=    0.0236    ;
    AOD[    n+    502    ]=    0.0217    ;
    AOD[    n+    503    ]=    0.0206    ;
    AOD[    n+    504    ]=    0.0208    ;
    AOD[    n+    505    ]=    0.021    ;
    AOD[    n+    506    ]=    0.0212    ;
    AOD[    n+    507    ]=    0.0234    ;
    AOD[    n+    508    ]=    0.0255    ;
    AOD[    n+    509    ]=    0.0277    ;
    AOD[    n+    510    ]=    0.0255    ;
    AOD[    n+    511    ]=    0.0235    ;
    AOD[    n+    512    ]=    0.0216    ;
    AOD[    n+    513    ]=    0.0199    ;
    AOD[    n+    514    ]=    0.0183    ;
    AOD[    n+    515    ]=    0.0168    ;
    AOD[    n+    516    ]=    0.0155    ;
    AOD[    n+    517    ]=    0.0143    ;
    AOD[    n+    518    ]=    0.0131    ;
    AOD[    n+    519    ]=    0.0121    ;
    AOD[    n+    520    ]=    0.0111    ;
    AOD[    n+    521    ]=    0.0102    ;
    AOD[    n+    522    ]=    0.0095    ;
    AOD[    n+    523    ]=    0.0087    ;
    AOD[    n+    524    ]=    0.008    ;
    AOD[    n+    525    ]=    0.0074    ;
    AOD[    n+    526    ]=    0.0068    ;
    AOD[    n+    527    ]=    0.0063    ;
    AOD[    n+    528    ]=    0.0058    ;
    AOD[    n+    529    ]=    0.0053    ;
    AOD[    n+    530    ]=    0.0049    ;
    AOD[    n+    531    ]=    0.0045    ;
    AOD[    n+    532    ]=    0.0042    ;
    AOD[    n+    533    ]=    0.0038    ;
    AOD[    n+    534    ]=    0.0035    ;
    AOD[    n+    535    ]=    0.0033    ;
    AOD[    n+    536    ]=    0.003    ;
    AOD[    n+    537    ]=    0.0028    ;
    AOD[    n+    538    ]=    0.0025    ;
    AOD[    n+    539    ]=    0.0024    ;
    AOD[    n+    540    ]=    0.0022    ;
    AOD[    n+    541    ]=    0.002    ;
    AOD[    n+    542    ]=    0.0019    ;
    AOD[    n+    543    ]=    0.0017    ;
    AOD[    n+    544    ]=    0.0016    ;
    AOD[    n+    545    ]=    0.0015    ;
    AOD[    n+    546    ]=    0.0014    ;
    AOD[    n+    547    ]=    0.0012    ;
    AOD[    n+    548    ]=    0.0012    ;
    AOD[    n+    549    ]=    0.0011    ;
    AOD[    n+    550    ]=    0.001    ;
    AOD[    n+    551    ]=    0.0009    ;
    AOD[    n+    552    ]=    0.0009    ;
    AOD[    n+    553    ]=    0.0063    ;
    AOD[    n+    554    ]=    0.0058    ;
    AOD[    n+    555    ]=    0.0071    ;
    AOD[    n+    556    ]=    0.0134    ;
    AOD[    n+    557    ]=    0.0197    ;
    AOD[    n+    558    ]=    0.0225    ;
    AOD[    n+    559    ]=    0.0252    ;
    AOD[    n+    560    ]=    0.028    ;
    AOD[    n+    561    ]=    0.0258    ;
    AOD[    n+    562    ]=    0.0237    ;
    AOD[    n+    563    ]=    0.0218    ;
    AOD[    n+    564    ]=    0.0201    ;
    AOD[    n+    565    ]=    0.0185    ;
    AOD[    n+    566    ]=    0.0171    ;
    AOD[    n+    567    ]=    0.0157    ;
    AOD[    n+    568    ]=    0.0144    ;
    AOD[    n+    569    ]=    0.0138    ;
    AOD[    n+    570    ]=    0.0143    ;
    AOD[    n+    571    ]=    0.0148    ;
    AOD[    n+    572    ]=    0.0153    ;
    AOD[    n+    573    ]=    0.0174    ;
    AOD[    n+    574    ]=    0.0195    ;
    AOD[    n+    575    ]=    0.0216    ;
    AOD[    n+    576    ]=    0.0199    ;
    AOD[    n+    577    ]=    0.0183    ;
    AOD[    n+    578    ]=    0.0169    ;
    AOD[    n+    579    ]=    0.0155    ;
    AOD[    n+    580    ]=    0.0143    ;
    AOD[    n+    581    ]=    0.0132    ;
    AOD[    n+    582    ]=    0.0121    ;
    AOD[    n+    583    ]=    0.0112    ;
    AOD[    n+    584    ]=    0.0103    ;
    AOD[    n+    585    ]=    0.0095    ;
    AOD[    n+    586    ]=    0.0087    ;
    AOD[    n+    587    ]=    0.008    ;
    AOD[    n+    588    ]=    0.0074    ;
    AOD[    n+    589    ]=    0.0069    ;
    AOD[    n+    590    ]=    0.0063    ;
    AOD[    n+    591    ]=    0.0058    ;
    AOD[    n+    592    ]=    0.0054    ;
    AOD[    n+    593    ]=    0.0049    ;
    AOD[    n+    594    ]=    0.0046    ;
    AOD[    n+    595    ]=    0.0042    ;
    AOD[    n+    596    ]=    0.0039    ;
    AOD[    n+    597    ]=    0.0036    ;
    AOD[    n+    598    ]=    0.0033    ;
    AOD[    n+    599    ]=    0.003    ;
    AOD[    n+    600    ]=    0.0028    ;
    AOD[    n+    601    ]=    0.0026    ;
    AOD[    n+    602    ]=    0.0024    ;
    AOD[    n+    603    ]=    0.0022    ;
    AOD[    n+    604    ]=    0.0021    ;
    AOD[    n+    605    ]=    0.0019    ;
    AOD[    n+    606    ]=    0.0018    ;
    AOD[    n+    607    ]=    0.0016    ;
    AOD[    n+    608    ]=    0.0015    ;
    AOD[    n+    609    ]=    0.0014    ;
    AOD[    n+    610    ]=    0.0013    ;
    AOD[    n+    611    ]=    0.0012    ;
    AOD[    n+    612    ]=    0.0011    ;
    AOD[    n+    613    ]=    0.001    ;
    AOD[    n+    614    ]=    0.001    ;
    AOD[    n+    615    ]=    0.0009    ;
    AOD[    n+    616    ]=    0.0009    ;
    AOD[    n+    617    ]=    0.0008    ;
    AOD[    n+    618    ]=    0.0007    ;
    AOD[    n+    619    ]=    0.0007    ;
    AOD[    n+    620    ]=    0.0007    ;
    AOD[    n+    621    ]=    0.0006    ;
    AOD[    n+    622    ]=    0.0006    ;
    AOD[    n+    623    ]=    0.0005    ;
    AOD[    n+    624    ]=    0.0005    ;
    AOD[    n+    625    ]=    0.0029    ;
    AOD[    n+    626    ]=    0.0043    ;
    AOD[    n+    627    ]=    0.0066    ;
    AOD[    n+    628    ]=    0.0089    ;
    AOD[    n+    629    ]=    0.0112    ;
    AOD[    n+    630    ]=    0.0103    ;
    AOD[    n+    631    ]=    0.0095    ;
    AOD[    n+    632    ]=    0.0099    ;
    AOD[    n+    633    ]=    0.0208    ;
    AOD[    n+    634    ]=    0.0391    ;
    AOD[    n+    635    ]=    0.053    ;
    AOD[    n+    636    ]=    0.0659    ;
    AOD[    n+    637    ]=    0.076    ;
    AOD[    n+    638    ]=    0.0762    ;
    AOD[    n+    639    ]=    0.0816    ;
    AOD[    n+    640    ]=    0.0822    ;
    AOD[    n+    641    ]=    0.0786    ;
    AOD[    n+    642    ]=    0.0763    ;
    AOD[    n+    643    ]=    0.0759    ;
    AOD[    n+    644    ]=    0.0696    ;
    AOD[    n+    645    ]=    0.0676    ;
    AOD[    n+    646    ]=    0.0628    ;
    AOD[    n+    647    ]=    0.0575    ;
    AOD[    n+    648    ]=    0.0539    ;
    AOD[    n+    649    ]=    0.0505    ;
    AOD[    n+    650    ]=    0.0437    ;
    AOD[    n+    651    ]=    0.0409    ;
    AOD[    n+    652    ]=    0.0364    ;
    AOD[    n+    653    ]=    0.0335    ;
    AOD[    n+    654    ]=    0.0308    ;
    AOD[    n+    655    ]=    0.0289    ;
    AOD[    n+    656    ]=    0.0265    ;
    AOD[    n+    657    ]=    0.0245    ;
    AOD[    n+    658    ]=    0.0234    ;
    AOD[    n+    659    ]=    0.0217    ;
    AOD[    n+    660    ]=    0.0207    ;
    AOD[    n+    661    ]=    0.0193    ;
    AOD[    n+    662    ]=    0.0172    ;
    AOD[    n+    663    ]=    0.0157    ;
    AOD[    n+    664    ]=    0.0146    ;
    AOD[    n+    665    ]=    0.0131    ;
    AOD[    n+    666    ]=    0.012    ;
    AOD[    n+    667    ]=    0.0113    ;
    AOD[    n+    668    ]=    0.0102    ;
    AOD[    n+    669    ]=    0.0099    ;
    AOD[    n+    670    ]=    0.0095    ;
    AOD[    n+    671    ]=    0.0089    ;
    AOD[    n+    672    ]=    0.0092    ;
    AOD[    n+    673    ]=    0.0088    ;
    AOD[    n+    674    ]=    0.0088    ;
    AOD[    n+    675    ]=    0.0067    ;
    AOD[    n+    676    ]=    0.0065    ;
    AOD[    n+    677    ]=    0.0061    ;
    AOD[    n+    678    ]=    0.0056    ;
    AOD[    n+    679    ]=    0.0055    ;
    AOD[    n+    680    ]=    0.0091    ;
    AOD[    n+    681    ]=    0.0084    ;
    AOD[    n+    682    ]=    0.0078    ;
    AOD[    n+    683    ]=    0.0071    ;
    AOD[    n+    684    ]=    0.0066    ;
    AOD[    n+    685    ]=    0.0061    ;
    AOD[    n+    686    ]=    0.0058    ;
    AOD[    n+    687    ]=    0.0075    ;
    AOD[    n+    688    ]=    0.0091    ;
    AOD[    n+    689    ]=    0.0108    ;
    AOD[    n+    690    ]=    0.0108    ;
    AOD[    n+    691    ]=    0.0109    ;
    AOD[    n+    692    ]=    0.0109    ;
    AOD[    n+    693    ]=    0.0101    ;
    AOD[    n+    694    ]=    0.0093    ;
    AOD[    n+    695    ]=    0.0086    ;
    AOD[    n+    696    ]=    0.0105    ;
    AOD[    n+    697    ]=    0.0126    ;
    AOD[    n+    698    ]=    0.0147    ;
    AOD[    n+    699    ]=    0.0135    ;
    AOD[    n+    700    ]=    0.0125    ;
    AOD[    n+    701    ]=    0.0115    ;
    AOD[    n+    702    ]=    0.0106    ;
    AOD[    n+    703    ]=    0.0097    ;
    AOD[    n+    704    ]=    0.0089    ;
    AOD[    n+    705    ]=    0.0082    ;
    AOD[    n+    706    ]=    0.0076    ;
    AOD[    n+    707    ]=    0.007    ;
    AOD[    n+    708    ]=    0.0065    ;
    AOD[    n+    709    ]=    0.0059    ;
    AOD[    n+    710    ]=    0.0056    ;
    AOD[    n+    711    ]=    0.0051    ;
    AOD[    n+    712    ]=    0.0047    ;
    AOD[    n+    713    ]=    0.0044    ;
    AOD[    n+    714    ]=    0.004    ;
    AOD[    n+    715    ]=    0.0037    ;
    AOD[    n+    716    ]=    0.0034    ;
    AOD[    n+    717    ]=    0.0032    ;
    AOD[    n+    718    ]=    0.0029    ;
    AOD[    n+    719    ]=    0.0027    ;
    AOD[    n+    720    ]=    0.0025    ;
    AOD[    n+    721    ]=    0.0028    ;
    AOD[    n+    722    ]=    0.0041    ;
    AOD[    n+    723    ]=    0.004    ;
    AOD[    n+    724    ]=    0.0039    ;
    AOD[    n+    725    ]=    0.0037    ;
    AOD[    n+    726    ]=    0.0034    ;
    AOD[    n+    727    ]=    0.0031    ;
    AOD[    n+    728    ]=    0.0029    ;
    AOD[    n+    729    ]=    0.0027    ;
    AOD[    n+    730    ]=    0.0025    ;
    AOD[    n+    731    ]=    0.0023    ;
    AOD[    n+    732    ]=    0.0021    ;
    AOD[    n+    733    ]=    0.002    ;
    AOD[    n+    734    ]=    0.0023    ;
    AOD[    n+    735    ]=    0.0021    ;
    AOD[    n+    736    ]=    0.002    ;
    AOD[    n+    737    ]=    0.0019    ;
    AOD[    n+    738    ]=    0.0017    ;
    AOD[    n+    739    ]=    0.0016    ;
    AOD[    n+    740    ]=    0.0015    ;
    AOD[    n+    741    ]=    0.0014    ;
    AOD[    n+    742    ]=    0.0013    ;
    AOD[    n+    743    ]=    0.0012    ;
    AOD[    n+    744    ]=    0.0011    ;
    AOD[    n+    745    ]=    0.0008    ;
    AOD[    n+    746    ]=    0.0017    ;
    AOD[    n+    747    ]=    0.0019    ;
    AOD[    n+    748    ]=    0.0021    ;
    AOD[    n+    749    ]=    0.0023    ;
    AOD[    n+    750    ]=    0.0149    ;
    AOD[    n+    751    ]=    0.0275    ;
    AOD[    n+    752    ]=    0.0401    ;
    AOD[    n+    753    ]=    0.0378    ;
    AOD[    n+    754    ]=    0.0357    ;
    AOD[    n+    755    ]=    0.0338    ;
    AOD[    n+    756    ]=    0.033    ;
    AOD[    n+    757    ]=    0.0324    ;
    AOD[    n+    758    ]=    0.0319    ;
    AOD[    n+    759    ]=    0.0294    ;
    AOD[    n+    760    ]=    0.0271    ;
    AOD[    n+    761    ]=    0.0276    ;
    AOD[    n+    762    ]=    0.0254    ;
    AOD[    n+    763    ]=    0.0234    ;
    AOD[    n+    764    ]=    0.0215    ;
    AOD[    n+    765    ]=    0.0198    ;
    AOD[    n+    766    ]=    0.0182    ;
    AOD[    n+    767    ]=    0.0168    ;
    AOD[    n+    768    ]=    0.0155    ;
    AOD[    n+    769    ]=    0.0142    ;
    AOD[    n+    770    ]=    0.0134    ;
    AOD[    n+    771    ]=    0.0126    ;
    AOD[    n+    772    ]=    0.0117    ;
    AOD[    n+    773    ]=    0.011    ;
    AOD[    n+    774    ]=    0.0101    ;
    AOD[    n+    775    ]=    0.0093    ;
    AOD[    n+    776    ]=    0.0086    ;
    AOD[    n+    777    ]=    0.0079    ;
    AOD[    n+    778    ]=    0.0073    ;
    AOD[    n+    779    ]=    0.0067    ;
    AOD[    n+    780    ]=    0.0062    ;
    AOD[    n+    781    ]=    0.0057    ;
    AOD[    n+    782    ]=    0.0052    ;
    AOD[    n+    783    ]=    0.0049    ;
    AOD[    n+    784    ]=    0.0045    ;
    AOD[    n+    785    ]=    0.0041    ;
    AOD[    n+    786    ]=    0.0038    ;
    AOD[    n+    787    ]=    0.0035    ;
    AOD[    n+    788    ]=    0.0033    ;
    AOD[    n+    789    ]=    0.003    ;
    AOD[    n+    790    ]=    0.0028    ;
    AOD[    n+    791    ]=    0.0033    ;
    AOD[    n+    792    ]=    0.0032    ;
    AOD[    n+    793    ]=    0.0036    ;
    AOD[    n+    794    ]=    0.0033    ;
    AOD[    n+    795    ]=    0.003    ;
    AOD[    n+    796    ]=    0.0028    ;
    AOD[    n+    797    ]=    0.0026    ;
    AOD[    n+    798    ]=    0.0024    ;
    AOD[    n+    799    ]=    0.0025    ;
    AOD[    n+    800    ]=    0.0023    ;
    AOD[    n+    801    ]=    0.0026    ;
    AOD[    n+    802    ]=    0.0024    ;
    AOD[    n+    803    ]=    0.0027    ;
    AOD[    n+    804    ]=    0.0027    ;
    AOD[    n+    805    ]=    0.0034    ;
    AOD[    n+    806    ]=    0.0031    ;
    AOD[    n+    807    ]=    0.0028    ;
    AOD[    n+    808    ]=    0.0026    ;
    AOD[    n+    809    ]=    0.0024    ;
    AOD[    n+    810    ]=    0.0022    ;
    AOD[    n+    811    ]=    0.002    ;
    AOD[    n+    812    ]=    0.0019    ;
    AOD[    n+    813    ]=    0.0018    ;
    AOD[    n+    814    ]=    0.0016    ;
    AOD[    n+    815    ]=    0.0015    ;
    AOD[    n+    816    ]=    0.0014    ;
    AOD[    n+    817    ]=    0.002    ;
    AOD[    n+    818    ]=    0.002    ;
    AOD[    n+    819    ]=    0.0027    ;
    AOD[    n+    820    ]=    0.0025    ;
    AOD[    n+    821    ]=    0.0023    ;
    AOD[    n+    822    ]=    0.0021    ;
    AOD[    n+    823    ]=    0.0019    ;
    AOD[    n+    824    ]=    0.0018    ;
    AOD[    n+    825    ]=    0.0017    ;
    AOD[    n+    826    ]=    0.0016    ;
    AOD[    n+    827    ]=    0.0014    ;
    AOD[    n+    828    ]=    0.0014    ;
    AOD[    n+    829    ]=    0.0014    ;
    AOD[    n+    830    ]=    0.002    ;
    AOD[    n+    831    ]=    0.0027    ;
    AOD[    n+    832    ]=    0.0027    ;
    AOD[    n+    833    ]=    0.0025    ;
    AOD[    n+    834    ]=    0.0023    ;
    AOD[    n+    835    ]=    0.0021    ;
    AOD[    n+    836    ]=    0.0019    ;
    AOD[    n+    837    ]=    0.0018    ;
    AOD[    n+    838    ]=    0.0017    ;
    AOD[    n+    839    ]=    0.0016    ;
    AOD[    n+    840    ]=    0.0014    ;
    AOD[    n+    841    ]=    0.0013    ;
    AOD[    n+    842    ]=    0.0012    ;
    AOD[    n+    843    ]=    0.0012    ;
    AOD[    n+    844    ]=    0.0031    ;
    AOD[    n+    845    ]=    0.0071    ;
    AOD[    n+    846    ]=    0.0101    ;
    AOD[    n+    847    ]=    0.0141    ;
    AOD[    n+    848    ]=    0.0171    ;
    AOD[    n+    849    ]=    0.0161    ;
    AOD[    n+    850    ]=    0.0148    ;
    AOD[    n+    851    ]=    0.0136    ;
    AOD[    n+    852    ]=    0.0126    ;
    AOD[    n+    853    ]=    0.0116    ;
    AOD[    n+    854    ]=    0.0106    ;
    AOD[    n+    855    ]=    0.0098    ;
    AOD[    n+    856    ]=    0.009    ;
    AOD[    n+    857    ]=    0.0083    ;
    AOD[    n+    858    ]=    0.0077    ;
    AOD[    n+    859    ]=    0.0071    ;
    AOD[    n+    860    ]=    0.0065    ;
    AOD[    n+    861    ]=    0.006    ;
    AOD[    n+    862    ]=    0.0055    ;
    AOD[    n+    863    ]=    0.0051    ;
    AOD[    n+    864    ]=    0.0047    ;
    AOD[    n+    865    ]=    0.0043    ;
    AOD[    n+    866    ]=    0.004    ;
    AOD[    n+    867    ]=    0.0037    ;
    AOD[    n+    868    ]=    0.0034    ;
    AOD[    n+    869    ]=    0.0031    ;
    AOD[    n+    870    ]=    0.0029    ;
    AOD[    n+    871    ]=    0.0027    ;
    AOD[    n+    872    ]=    0.0025    ;
    AOD[    n+    873    ]=    0.0023    ;
    AOD[    n+    874    ]=    0.0021    ;
    AOD[    n+    875    ]=    0.0019    ;
    AOD[    n+    876    ]=    0.0018    ;
    AOD[    n+    877    ]=    0.0017    ;
    AOD[    n+    878    ]=    0.0015    ;
    AOD[    n+    879    ]=    0.0014    ;
    AOD[    n+    880    ]=    0.0013    ;
    AOD[    n+    881    ]=    0.0012    ;
    AOD[    n+    882    ]=    0.0011    ;
    AOD[    n+    883    ]=    0.001    ;
    AOD[    n+    884    ]=    0.001    ;
    AOD[    n+    885    ]=    0.0009    ;
    AOD[    n+    886    ]=    0.0008    ;
    AOD[    n+    887    ]=    0.0008    ;
    AOD[    n+    888    ]=    0.0007    ;
    AOD[    n+    889    ]=    0.003    ;
    AOD[    n+    890    ]=    0.0027    ;
    AOD[    n+    891    ]=    0.0031    ;
    AOD[    n+    892    ]=    0.0031    ;
    AOD[    n+    893    ]=    0.0031    ;
    AOD[    n+    894    ]=    0.0035    ;
    AOD[    n+    895    ]=    0.0042    ;
    AOD[    n+    896    ]=    0.004    ;
    AOD[    n+    897    ]=    0.0037    ;
    AOD[    n+    898    ]=    0.0037    ;
    AOD[    n+    899    ]=    0.0035    ;
    AOD[    n+    900    ]=    0.0033    ;
    AOD[    n+    901    ]=    0.0031    ;
    AOD[    n+    902    ]=    0.0028    ;
    AOD[    n+    903    ]=    0.0032    ;
    AOD[    n+    904    ]=    0.0032    ;
    AOD[    n+    905    ]=    0.0036    ;
    AOD[    n+    906    ]=    0.0033    ;
    AOD[    n+    907    ]=    0.003    ;
    AOD[    n+    908    ]=    0.0028    ;
    AOD[    n+    909    ]=    0.0026    ;
    AOD[    n+    910    ]=    0.0024    ;
    AOD[    n+    911    ]=    0.0022    ;
    AOD[    n+    912    ]=    0.0021    ;
    AOD[    n+    913    ]=    0.0019    ;
    AOD[    n+    914    ]=    0.0018    ;
    AOD[    n+    915    ]=    0.0016    ;
    AOD[    n+    916    ]=    0.0015    ;
    AOD[    n+    917    ]=    0.0014    ;
    AOD[    n+    918    ]=    0.0027    ;
    AOD[    n+    919    ]=    0.003    ;
    AOD[    n+    920    ]=    0.0033    ;
    AOD[    n+    921    ]=    0.0031    ;
    AOD[    n+    922    ]=    0.0028    ;
    AOD[    n+    923    ]=    0.0026    ;
    AOD[    n+    924    ]=    0.0024    ;
    AOD[    n+    925    ]=    0.0022    ;
    AOD[    n+    926    ]=    0.0021    ;
    AOD[    n+    927    ]=    0.0019    ;
    AOD[    n+    928    ]=    0.0018    ;
    AOD[    n+    929    ]=    0.0016    ;
    AOD[    n+    930    ]=    0.0015    ;
    AOD[    n+    931    ]=    0.0014    ;
    AOD[    n+    932    ]=    0.0013    ;
    AOD[    n+    933    ]=    0.0012    ;
    AOD[    n+    934    ]=    0.0011    ;
    AOD[    n+    935    ]=    0.001    ;
    AOD[    n+    936    ]=    0.001    ;
    AOD[    n+    937    ]=    0.0017    ;
    AOD[    n+    938    ]=    0.0024    ;
    AOD[    n+    939    ]=    0.0028    ;
    AOD[    n+    940    ]=    0.0033    ;
    AOD[    n+    941    ]=    0.0039    ;
    AOD[    n+    942    ]=    0.0058    ;
    AOD[    n+    943    ]=    0.0065    ;
    AOD[    n+    944    ]=    0.0072    ;
    AOD[    n+    945    ]=    0.0073    ;
    AOD[    n+    946    ]=    0.0069    ;
    AOD[    n+    947    ]=    0.0068    ;
    AOD[    n+    948    ]=    0.0084    ;
    AOD[    n+    949    ]=    0.0086    ;
    AOD[    n+    950    ]=    0.01    ;
    AOD[    n+    951    ]=    0.0104    ;
    AOD[    n+    952    ]=    0.0099    ;
    AOD[    n+    953    ]=    0.0098    ;
    AOD[    n+    954    ]=    0.0098    ;
    AOD[    n+    955    ]=    0.0104    ;
    AOD[    n+    956    ]=    0.0108    ;
    AOD[    n+    957    ]=    0.0104    ;
    AOD[    n+    958    ]=    0.0099    ;
    AOD[    n+    959    ]=    0.0093    ;
    AOD[    n+    960    ]=    0.0086    ;
    AOD[    n+    961    ]=    0.008    ;
    AOD[    n+    962    ]=    0.0075    ;
    AOD[    n+    963    ]=    0.0069    ;
    AOD[    n+    964    ]=    0.0064    ;
    AOD[    n+    965    ]=    0.0066    ;
    AOD[    n+    966    ]=    0.0064    ;
    AOD[    n+    967    ]=    0.0061    ;
    AOD[    n+    968    ]=    0.0058    ;
    AOD[    n+    969    ]=    0.0057    ;
    AOD[    n+    970    ]=    0.0053    ;
    AOD[    n+    971    ]=    0.0049    ;
    AOD[    n+    972    ]=    0.0049    ;
    AOD[    n+    973    ]=    0.0052    ;
    AOD[    n+    974    ]=    0.0051    ;
    AOD[    n+    975    ]=    0.0052    ;
    AOD[    n+    976    ]=    0.0052    ;
    AOD[    n+    977    ]=    0.005    ;
    AOD[    n+    978    ]=    0.0049    ;
    AOD[    n+    979    ]=    0.0049    ;
    AOD[    n+    980    ]=    0.0045    ;
    AOD[    n+    981    ]=    0.0044    ;
    AOD[    n+    982    ]=    0.0041    ;
    AOD[    n+    983    ]=    0.0038    ;
    AOD[    n+    984    ]=    0.0041    ;
    AOD[    n+    985    ]=    0.0046    ;
    AOD[    n+    986    ]=    0.0057    ;
    AOD[    n+    987    ]=    0.006    ;
    AOD[    n+    988    ]=    0.0066    ;
    AOD[    n+    989    ]=    0.0073    ;
    AOD[    n+    990    ]=    0.0088    ;
    AOD[    n+    991    ]=    0.0096    ;
    AOD[    n+    992    ]=    0.0102    ;
    AOD[    n+    993    ]=    0.0105    ;
    AOD[    n+    994    ]=    0.0101    ;
    AOD[    n+    995    ]=    0.0098    ;
    AOD[    n+    996    ]=    0.0097    ;
    AOD[    n+    997    ]=    0.0095    ;
    AOD[    n+    998    ]=    0.0088    ;
    AOD[    n+    999    ]=    0.0083    ;
    AOD[    n+    1000    ]=    0.0079    ;
    AOD[    n+    1001    ]=    0.0075    ;
    AOD[    n+    1002    ]=    0.0069    ;
    AOD[    n+    1003    ]=    0.0063    ;
    AOD[    n+    1004    ]=    0.0059    ;
    AOD[    n+    1005    ]=    0.0054    ;
    AOD[    n+    1006    ]=    0.0049    ;
    AOD[    n+    1007    ]=    0.0045    ;
    AOD[    n+    1008    ]=    0.0042    ;
    AOD[    n+    1009    ]=    0.0039    ;
    AOD[    n+    1010    ]=    0.0036    ;
    AOD[    n+    1011    ]=    0.0033    ;
    AOD[    n+    1012    ]=    0.003    ;
    AOD[    n+    1013    ]=    0.0029    ;
    AOD[    n+    1014    ]=    0.0032    ;
    AOD[    n+    1015    ]=    0.0037    ;
    AOD[    n+    1016    ]=    0.0039    ;
    AOD[    n+    1017    ]=    0.0039    ;
    AOD[    n+    1018    ]=    0.0044    ;
    AOD[    n+    1019    ]=    0.0051    ;
    AOD[    n+    1020    ]=    0.0047    ;
    AOD[    n+    1021    ]=    0.0045    ;
    AOD[    n+    1022    ]=    0.0045    ;
    AOD[    n+    1023    ]=    0.0046    ;
    AOD[    n+    1024    ]=    0.0048    ;
    AOD[    n+    1025    ]=    0.0048    ;
    AOD[    n+    1026    ]=    0.0046    ;
    AOD[    n+    1027    ]=    0.0043    ;
    AOD[    n+    1028    ]=    0.0041    ;
    AOD[    n+    1029    ]=    0.0038    ;
    AOD[    n+    1030    ]=    0.0037    ;
    AOD[    n+    1031    ]=    0.0036    ;
    AOD[    n+    1032    ]=    0.0035    ;
    AOD[    n+    1033    ]=    0.0034    ;
    AOD[    n+    1034    ]=    0.0032    ;
    AOD[    n+    1035    ]=    0.0031    ;
    AOD[    n+    1036    ]=    0.003    ;
    AOD[    n+    1037    ]=    0.0028    ;
    AOD[    n+    1038    ]=    0.0026    ;
    AOD[    n+    1039    ]=    0.0029    ;
    AOD[    n+    1040    ]=    0.0035    ;
    AOD[    n+    1041    ]=    0.0034    ;
    AOD[    n+    1042    ]=    0.0037    ;
    AOD[    n+    1043    ]=    0.0039    ;
    AOD[    n+    1044    ]=    0.0036    ;
    AOD[    n+    1045    ]=    0.0033    ;
    AOD[    n+    1046    ]=    0.003    ;
    AOD[    n+    1047    ]=    0.0029    ;
    AOD[    n+    1048    ]=    0.0026    ;
    AOD[    n+    1049    ]=    0.0025    ;
    AOD[    n+    1050    ]=    0.0022    ;
    AOD[    n+    1051    ]=    0.0021    ;
    AOD[    n+    1052    ]=    0.0026    ;
    AOD[    n+    1053    ]=    0.0032    ;
    AOD[    n+    1054    ]=    0.0032    ;
    AOD[    n+    1055    ]=    0.0032    ;
    AOD[    n+    1056    ]=    0.003    ;
    AOD[    n+    1057    ]=    0.0033    ;
    AOD[    n+    1058    ]=    0.0035    ;
    AOD[    n+    1059    ]=    0.0046    ;
    AOD[    n+    1060    ]=    0.0046    ;
    AOD[    n+    1061    ]=    0.0047    ;
    AOD[    n+    1062    ]=    0.0049    ;
    AOD[    n+    1063    ]=    0.0055    ;
    AOD[    n+    1064    ]=    0.0055    ;
    AOD[    n+    1065    ]=    0.0057    ;
    AOD[    n+    1066    ]=    0.0059    ;
    AOD[    n+    1067    ]=    0.0055    ;
    AOD[    n+    1068    ]=    0.0052    ;
    AOD[    n+    1069    ]=    0.0047    ;
    AOD[    n+    1070    ]=    0.0044    ;
    AOD[    n+    1071    ]=    0.0049    ;
    AOD[    n+    1072    ]=    0.0047    ;
    AOD[    n+    1073    ]=    0.0046    ;
    AOD[    n+    1074    ]=    0.0046    ;
    AOD[    n+    1075    ]=    0.0042    ;
    AOD[    n+    1076    ]=    0.0039    ;
    AOD[    n+    1077    ]=    0.0036    ;
    AOD[    n+    1078    ]=    0.0033    ;
    AOD[    n+    1079    ]=    0.0031    ;
    AOD[    n+    1080    ]=    0.0032    ;
    AOD[    n+    1081    ]=    0.0034    ;
    AOD[    n+    1082    ]=    0.0036    ;
    AOD[    n+    1083    ]=    0.0037    ;
    AOD[    n+    1084    ]=    0.0034    ;
    AOD[    n+    1085    ]=    0.0033    ;
    AOD[    n+    1086    ]=    0.0031    ;
    AOD[    n+    1087    ]=    0.003    ;
    AOD[    n+    1088    ]=    0.0027    ;
    AOD[    n+    1089    ]=    0.0033    ;
    AOD[    n+    1090    ]=    0.003    ;
    AOD[    n+    1091    ]=    0.003    ;
    AOD[    n+    1092    ]=    0.0028    ;
    AOD[    n+    1093    ]=    0.0026    ;
    AOD[    n+    1094    ]=    0.0023    ;
    AOD[    n+    1095    ]=    0.0022    ;
    AOD[    n+    1096    ]=    0.002    ;
    AOD[    n+    1097    ]=    0.0019    ;
    AOD[    n+    1098    ]=    0.0017    ;
    AOD[    n+    1099    ]=    0.0016    ;
    AOD[    n+    1100    ]=    0.0015    ;
    AOD[    n+    1101    ]=    0.0021    ;
    AOD[    n+    1102    ]=    0.0019    ;
    AOD[    n+    1103    ]=    0.0018    ;
    AOD[    n+    1104    ]=    0.0017    ;
    AOD[    n+    1105    ]=    0.0026    ;
    AOD[    n+    1106    ]=    0.0029    ;
    AOD[    n+    1107    ]=    0.003    ;
    AOD[    n+    1108    ]=    0.0031    ;
    AOD[    n+    1109    ]=    0.0034    ;
    AOD[    n+    1110    ]=    0.0035    ;
    AOD[    n+    1111    ]=    0.0037    ;
    AOD[    n+    1112    ]=    0.0038    ;
    AOD[    n+    1113    ]=    0.0063    ;
    AOD[    n+    1114    ]=    0.0061    ;
    AOD[    n+    1115    ]=    0.006    ;
    AOD[    n+    1116    ]=    0.006    ;
    AOD[    n+    1117    ]=    0.0061    ;
    AOD[    n+    1118    ]=    0.0056    ;
    AOD[    n+    1119    ]=    0.0052    ;
    AOD[    n+    1120    ]=    0.0048    ;
    AOD[    n+    1121    ]=    0.0044    ;
    AOD[    n+    1122    ]=    0.004    ;
    AOD[    n+    1123    ]=    0.0039    ;
    AOD[    n+    1124    ]=    0.0039    ;
    AOD[    n+    1125    ]=    0.0041    ;
    AOD[    n+    1126    ]=    0.0038    ;
    AOD[    n+    1127    ]=    0.0035    ;
    AOD[    n+    1128    ]=    0.0032    ;
    AOD[    n+    1129    ]=    0.003    ;
    AOD[    n+    1130    ]=    0.0027    ;
    AOD[    n+    1131    ]=    0.0025    ;
    AOD[    n+    1132    ]=    0.0023    ;
    AOD[    n+    1133    ]=    0.0022    ;
    AOD[    n+    1134    ]=    0.002    ;
    AOD[    n+    1135    ]=    0.0019    ;
    AOD[    n+    1136    ]=    0.0022    ;
    AOD[    n+    1137    ]=    0.0025    ;
    AOD[    n+    1138    ]=    0.0025    ;
    AOD[    n+    1139    ]=    0.0023    ;
    AOD[    n+    1140    ]=    0.0021    ;
    AOD[    n+    1141    ]=    0.0025    ;
    AOD[    n+    1142    ]=    0.0027    ;
    AOD[    n+    1143    ]=    0.003    ;
    AOD[    n+    1144    ]=    0.0028    ;
    AOD[    n+    1145    ]=    0.0025    ;
    AOD[    n+    1146    ]=    0.0023    ;
    AOD[    n+    1147    ]=    0.0022    ;
    AOD[    n+    1148    ]=    0.002    ;
    AOD[    n+    1149    ]=    0.0019    ;
    AOD[    n+    1150    ]=    0.0017    ;
    AOD[    n+    1151    ]=    0.0016    ;
    AOD[    n+    1152    ]=    0.0014    ;
    AOD[    n+    1153    ]=    0.0016    ;
    AOD[    n+    1154    ]=    0.0015    ;
    AOD[    n+    1155    ]=    0.0014    ;
    AOD[    n+    1156    ]=    0.0014    ;
    AOD[    n+    1157    ]=    0.0015    ;
    AOD[    n+    1158    ]=    0.0026    ;
    AOD[    n+    1159    ]=    0.0024    ;
    AOD[    n+    1160    ]=    0.0022    ;
    AOD[    n+    1161    ]=    0.002    ;
    AOD[    n+    1162    ]=    0.0019    ;
    AOD[    n+    1163    ]=    0.0017    ;
    AOD[    n+    1164    ]=    0.0016    ;
    AOD[    n+    1165    ]=    0.0015    ;
    AOD[    n+    1166    ]=    0.0014    ;
    AOD[    n+    1167    ]=    0.0013    ;
    AOD[    n+    1168    ]=    0.0012    ;
    AOD[    n+    1169    ]=    0.0011    ;
    AOD[    n+    1170    ]=    0.001    ;
    AOD[    n+    1171    ]=    0.0037    ;
    AOD[    n+    1172    ]=    0.0036    ;
    AOD[    n+    1173    ]=    0.0035    ;
    AOD[    n+    1174    ]=    0.0033    ;
    AOD[    n+    1175    ]=    0.003    ;
    AOD[    n+    1176    ]=    0.0028    ;
    AOD[    n+    1177    ]=    0.0025    ;
    AOD[    n+    1178    ]=    0.0023    ;
    AOD[    n+    1179    ]=    0.0022    ;
    AOD[    n+    1180    ]=    0.002    ;
    AOD[    n+    1181    ]=    0.0019    ;
    AOD[    n+    1182    ]=    0.0017    ;
    AOD[    n+    1183    ]=    0.0016    ;
    AOD[    n+    1184    ]=    0.0015    ;
    AOD[    n+    1185    ]=    0.0014    ;
    AOD[    n+    1186    ]=    0.0012    ;
    AOD[    n+    1187    ]=    0.0012    ;
    AOD[    n+    1188    ]=    0.001    ;
    AOD[    n+    1189    ]=    0.001    ;
    AOD[    n+    1190    ]=    0.0013    ;
    AOD[    n+    1191    ]=    0.0026    ;
    AOD[    n+    1192    ]=    0.0027    ;
    AOD[    n+    1193    ]=    0.0032    ;
    AOD[    n+    1194    ]=    0.0038    ;
    AOD[    n+    1195    ]=    0.0043    ;
    AOD[    n+    1196    ]=    0.0045    ;
    AOD[    n+    1197    ]=    0.0044    ;
    AOD[    n+    1198    ]=    0.0041    ;
    AOD[    n+    1199    ]=    0.0038    ;
    AOD[    n+    1200    ]=    0.0035    ;
    AOD[    n+    1201    ]=    0.0034    ;
    AOD[    n+    1202    ]=    0.0031    ;
    AOD[    n+    1203    ]=    0.0029    ;
    AOD[    n+    1204    ]=    0.0029    ;
    AOD[    n+    1205    ]=    0.0036    ;
    AOD[    n+    1206    ]=    0.0033    ;
    AOD[    n+    1207    ]=    0.003    ;
    AOD[    n+    1208    ]=    0.0029    ;
    AOD[    n+    1209    ]=    0.0026    ;
    AOD[    n+    1210    ]=    0.0024    ;
    AOD[    n+    1211    ]=    0.0022    ;
    AOD[    n+    1212    ]=    0.0021    ;
    AOD[    n+    1213    ]=    0.0019    ;
    AOD[    n+    1214    ]=    0.0017    ;
    AOD[    n+    1215    ]=    0.0016    ;
    AOD[    n+    1216    ]=    0.0016    ;
    AOD[    n+    1217    ]=    0.0014    ;
    AOD[    n+    1218    ]=    0.0013    ;
    AOD[    n+    1219    ]=    0.0012    ;
    AOD[    n+    1220    ]=    0.0011    ;
    AOD[    n+    1221    ]=    0.0025    ;
    AOD[    n+    1222    ]=    0.0034    ;
    AOD[    n+    1223    ]=    0.0031    ;
    AOD[    n+    1224    ]=    0.0029    ;
    AOD[    n+    1225    ]=    0.004    ;
    AOD[    n+    1226    ]=    0.0042    ;
    AOD[    n+    1227    ]=    0.0039    ;
    AOD[    n+    1228    ]=    0.0039    ;
    AOD[    n+    1229    ]=    0.0039    ;
    AOD[    n+    1230    ]=    0.0037    ;
    AOD[    n+    1231    ]=    0.0037    ;
    AOD[    n+    1232    ]=    0.0036    ;
    AOD[    n+    1233    ]=    0.0037    ;
    AOD[    n+    1234    ]=    0.0034    ;
    AOD[    n+    1235    ]=    0.0032    ;
    AOD[    n+    1236    ]=    0.0029    ;
    AOD[    n+    1237    ]=    0.0027    ;
    AOD[    n+    1238    ]=    0.0025    ;
    AOD[    n+    1239    ]=    0.0023    ;
    AOD[    n+    1240    ]=    0.0021    ;
    AOD[    n+    1241    ]=    0.0021    ;
    AOD[    n+    1242    ]=    0.0034    ;
    AOD[    n+    1243    ]=    0.0034    ;
    AOD[    n+    1244    ]=    0.004    ;
    AOD[    n+    1245    ]=    0.0046    ;
    AOD[    n+    1246    ]=    0.0045    ;
    AOD[    n+    1247    ]=    0.0044    ;
    AOD[    n+    1248    ]=    0.0047    ;
    AOD[    n+    1249    ]=    0.0049    ;
    AOD[    n+    1250    ]=    0.0047    ;
    AOD[    n+    1251    ]=    0.0047    ;
    AOD[    n+    1252    ]=    0.0043    ;
    AOD[    n+    1253    ]=    0.004    ;
    AOD[    n+    1254    ]=    0.0037    ;
    AOD[    n+    1255    ]=    0.0034    ;
    AOD[    n+    1256    ]=    0.0032    ;
    AOD[    n+    1257    ]=    0.0029    ;
    AOD[    n+    1258    ]=    0.0027    ;
    AOD[    n+    1259    ]=    0.0025    ;
    AOD[    n+    1260    ]=    0.0023    ;
    AOD[    n+    1261    ]=    0.0022    ;
    AOD[    n+    1262    ]=    0.0019    ;
    AOD[    n+    1263    ]=    0.0018    ;
    AOD[    n+    1264    ]=    0.0017    ;
    AOD[    n+    1265    ]=    0.0015    ;
    AOD[    n+    1266    ]=    0.0014    ;
    AOD[    n+    1267    ]=    0.0014    ;
    AOD[    n+    1268    ]=    0.0016    ;
    AOD[    n+    1269    ]=    0.0023    ;
    AOD[    n+    1270    ]=    0.0021    ;
    AOD[    n+    1271    ]=    0.0019    ;
    AOD[    n+    1272    ]=    0.0018    ;
    AOD[    n+    1273    ]=    0.0016    ;
    AOD[    n+    1274    ]=    0.0015    ;
    AOD[    n+    1275    ]=    0.0014    ;
    AOD[    n+    1276    ]=    0.0013    ;
    AOD[    n+    1277    ]=    0.0012    ;
    AOD[    n+    1278    ]=    0.0012    ;
    AOD[    n+    1279    ]=    0.001    ;
    AOD[    n+    1280    ]=    0.001    ;
    AOD[    n+    1281    ]=    0.0009    ;
    AOD[    n+    1282    ]=    0.0009    ;
    AOD[    n+    1283    ]=    0.0008    ;
    AOD[    n+    1284    ]=    0.0008    ;
    AOD[    n+    1285    ]=    0.0007    ;
    AOD[    n+    1286    ]=    0.0007    ;
    AOD[    n+    1287    ]=    0.0006    ;
    AOD[    n+    1288    ]=    0.0006    ;
    AOD[    n+    1289    ]=    0.0005    ;
    AOD[    n+    1290    ]=    0.0005    ;
    AOD[    n+    1291    ]=    0.0005    ;
    AOD[    n+    1292    ]=    0.0005    ;
    AOD[    n+    1293    ]=    0.0005    ;
    AOD[    n+    1294    ]=    0.0004    ;
    AOD[    n+    1295    ]=    0.0004    ;
    AOD[    n+    1296    ]=    0.0003    ;
    AOD[    n+    1297    ]=    0.0003    ;
    AOD[    n+    1298    ]=    0.0003    ;
    AOD[    n+    1299    ]=    0.0003    ;
    AOD[    n+    1300    ]=    0.0003    ;
    AOD[    n+    1301    ]=    0.0003    ;
    AOD[    n+    1302    ]=    0.0003    ;
    AOD[    n+    1303    ]=    0.0002    ;
    AOD[    n+    1304    ]=    0.0002    ;
    AOD[    n+    1305    ]=    0.0002    ;
    AOD[    n+    1306    ]=    0.0002    ;
    AOD[    n+    1307    ]=    0.0002    ;
    AOD[    n+    1308    ]=    0.0002    ;
    AOD[    n+    1309    ]=    0.0002    ;
    AOD[    n+    1310    ]=    0.0002    ;
    AOD[    n+    1311    ]=    0.0002    ;
    AOD[    n+    1312    ]=    0.0002    ;
    AOD[    n+    1313    ]=    0.0002    ;
    AOD[    n+    1314    ]=    0.0002    ;
    AOD[    n+    1315    ]=    0.0002    ;
    AOD[    n+    1316    ]=    0.0002    ;
    AOD[    n+    1317    ]=    0.0002    ;
    AOD[    n+    1318    ]=    0.0002    ;
    AOD[    n+    1319    ]=    0.0002    ;
    AOD[    n+    1320    ]=    0.0002    ;
    AOD[    n+    1321    ]=    0.0002    ;
    AOD[    n+    1322    ]=    0.0002    ;
    AOD[    n+    1323    ]=    0.0002    ;
    AOD[    n+    1324    ]=    0.0015    ;
    AOD[    n+    1325    ]=    0.0028    ;
    AOD[    n+    1326    ]=    0.0042    ;
    AOD[    n+    1327    ]=    0.0057    ;
    AOD[    n+    1328    ]=    0.007    ;
    AOD[    n+    1329    ]=    0.0084    ;
    AOD[    n+    1330    ]=    0.0084    ;
    AOD[    n+    1331    ]=    0.0084    ;
    AOD[    n+    1332    ]=    0.0084    ;
    AOD[    n+    1333    ]=    0.0078    ;
    AOD[    n+    1334    ]=    0.0086    ;
    AOD[    n+    1335    ]=    0.0115    ;
    AOD[    n+    1336    ]=    0.0126    ;
    AOD[    n+    1337    ]=    0.0116    ;
    AOD[    n+    1338    ]=    0.0112    ;
    AOD[    n+    1339    ]=    0.0104    ;
    AOD[    n+    1340    ]=    0.0107    ;
    AOD[    n+    1341    ]=    0.0118    ;
    AOD[    n+    1342    ]=    0.0116    ;
    AOD[    n+    1343    ]=    0.0112    ;
    AOD[    n+    1344    ]=    0.0103    ;
    AOD[    n+    1345    ]=    0.0095    ;
    AOD[    n+    1346    ]=    0.009    ;
    AOD[    n+    1347    ]=    0.0138    ;
    AOD[    n+    1348    ]=    0.0151    ;
    AOD[    n+    1349    ]=    0.0141    ;
    AOD[    n+    1350    ]=    0.0132    ;
    AOD[    n+    1351    ]=    0.0134    ;
    AOD[    n+    1352    ]=    0.016    ;
    AOD[    n+    1353    ]=    0.0147    ;
    AOD[    n+    1354    ]=    0.0143    ;
    AOD[    n+    1355    ]=    0.0134    ;
    AOD[    n+    1356    ]=    0.0125    ;
    AOD[    n+    1357    ]=    0.0122    ;
    AOD[    n+    1358    ]=    0.0119    ;
    AOD[    n+    1359    ]=    0.0123    ;
    AOD[    n+    1360    ]=    0.0173    ;
    AOD[    n+    1361    ]=    0.0338    ;
    AOD[    n+    1362    ]=    0.047    ;
    AOD[    n+    1363    ]=    0.0516    ;
    AOD[    n+    1364    ]=    0.0562    ;
    AOD[    n+    1365    ]=    0.0605    ;
    AOD[    n+    1366    ]=    0.0754    ;
    AOD[    n+    1367    ]=    0.0885    ;
    AOD[    n+    1368    ]=    0.0849    ;
    AOD[    n+    1369    ]=    0.0798    ;
    AOD[    n+    1370    ]=    0.0746    ;
    AOD[    n+    1371    ]=    0.0696    ;
    AOD[    n+    1372    ]=    0.0668    ;
    AOD[    n+    1373    ]=    0.0667    ;
    AOD[    n+    1374    ]=    0.07    ;
    AOD[    n+    1375    ]=    0.0798    ;
    AOD[    n+    1376    ]=    0.0797    ;
    AOD[    n+    1377    ]=    0.0743    ;
    AOD[    n+    1378    ]=    0.0695    ;
    AOD[    n+    1379    ]=    0.0662    ;
    AOD[    n+    1380    ]=    0.0633    ;
    AOD[    n+    1381    ]=    0.06    ;
    AOD[    n+    1382    ]=    0.0567    ;
    AOD[    n+    1383    ]=    0.0531    ;
    AOD[    n+    1384    ]=    0.0493    ;
    AOD[    n+    1385    ]=    0.0466    ;
    AOD[    n+    1386    ]=    0.0435    ;
    AOD[    n+    1387    ]=    0.0406    ;
    AOD[    n+    1388    ]=    0.0374    ;
    AOD[    n+    1389    ]=    0.0347    ;
    AOD[    n+    1390    ]=    0.0325    ;
    AOD[    n+    1391    ]=    0.0312    ;
    AOD[    n+    1392    ]=    0.0326    ;
    AOD[    n+    1393    ]=    0.0327    ;
    AOD[    n+    1394    ]=    0.0307    ;
    AOD[    n+    1395    ]=    0.0288    ;
    AOD[    n+    1396    ]=    0.0269    ;
    AOD[    n+    1397    ]=    0.0252    ;
    AOD[    n+    1398    ]=    0.0236    ;
    AOD[    n+    1399    ]=    0.022    ;
    AOD[    n+    1400    ]=    0.0206    ;
    AOD[    n+    1401    ]=    0.0191    ;
    AOD[    n+    1402    ]=    0.0177    ;
    AOD[    n+    1403    ]=    0.0164    ;
    AOD[    n+    1404    ]=    0.0151    ;
    AOD[    n+    1405    ]=    0.0139    ;
    AOD[    n+    1406    ]=    0.0128    ;
    AOD[    n+    1407    ]=    0.0118    ;
    AOD[    n+    1408    ]=    0.0108    ;
    AOD[    n+    1409    ]=    0.0112    ;
    AOD[    n+    1410    ]=    0.0126    ;
    AOD[    n+    1411    ]=    0.0142    ;
    AOD[    n+    1412    ]=    0.0159    ;
    AOD[    n+    1413    ]=    0.0176    ;
    AOD[    n+    1414    ]=    0.0192    ;
    AOD[    n+    1415    ]=    0.0177    ;
    AOD[    n+    1416    ]=    0.0163    ;
    AOD[    n+    1417    ]=    0.015    ;
    AOD[    n+    1418    ]=    0.0138    ;
    AOD[    n+    1419    ]=    0.0127    ;
    AOD[    n+    1420    ]=    0.0117    ;
    AOD[    n+    1421    ]=    0.0142    ;
    AOD[    n+    1422    ]=    0.0209    ;
    AOD[    n+    1423    ]=    0.0276    ;
    AOD[    n+    1424    ]=    0.0342    ;
    AOD[    n+    1425    ]=    0.0409    ;
    AOD[    n+    1426    ]=    0.0475    ;
    AOD[    n+    1427    ]=    0.0459    ;
    AOD[    n+    1428    ]=    0.0445    ;
    AOD[    n+    1429    ]=    0.0429    ;
    AOD[    n+    1430    ]=    0.0414    ;
    AOD[    n+    1431    ]=    0.0398    ;
    AOD[    n+    1432    ]=    0.0383    ;
    AOD[    n+    1433    ]=    0.0367    ;
    AOD[    n+    1434    ]=    0.0351    ;
    AOD[    n+    1435    ]=    0.0336    ;
    AOD[    n+    1436    ]=    0.032    ;
    AOD[    n+    1437    ]=    0.0306    ;
    AOD[    n+    1438    ]=    0.029    ;
    AOD[    n+    1439    ]=    0.0275    ;
    AOD[    n+    1440    ]=    0.0259    ;
    AOD[    n+    1441    ]=    0.0243    ;
    AOD[    n+    1442    ]=    0.0228    ;
    AOD[    n+    1443    ]=    0.0212    ;
    AOD[    n+    1444    ]=    0.0197    ;
    AOD[    n+    1445    ]=    0.0182    ;
    AOD[    n+    1446    ]=    0.0167    ;
    AOD[    n+    1447    ]=    0.0154    ;
    AOD[    n+    1448    ]=    0.0142    ;
    AOD[    n+    1449    ]=    0.013    ;
    AOD[    n+    1450    ]=    0.012    ;
    AOD[    n+    1451    ]=    0.0111    ;
    AOD[    n+    1452    ]=    0.0102    ;
    AOD[    n+    1453    ]=    0.0094    ;
    AOD[    n+    1454    ]=    0.0086    ;
    AOD[    n+    1455    ]=    0.0079    ;
    AOD[    n+    1456    ]=    0.0073    ;
    AOD[    n+    1457    ]=    0.0067    ;
    AOD[    n+    1458    ]=    0.0062    ;
    AOD[    n+    1459    ]=    0.0057    ;
    AOD[    n+    1460    ]=    0.0053    ;
    AOD[    n+    1461    ]=    0.0058    ;
    AOD[    n+    1462    ]=    0.0054    ;
    AOD[    n+    1463    ]=    0.0049    ;
    AOD[    n+    1464    ]=    0.0046    ;
    AOD[    n+    1465    ]=    0.0042    ;
    AOD[    n+    1466    ]=    0.0039    ;
    AOD[    n+    1467    ]=    0.0036    ;
    AOD[    n+    1468    ]=    0.0033    ;
    AOD[    n+    1469    ]=    0.003    ;
    AOD[    n+    1470    ]=    0.003    ;
    AOD[    n+    1471    ]=    0.0034    ;
    AOD[    n+    1472    ]=    0.0038    ;
    AOD[    n+    1473    ]=    0.0042    ;
    AOD[    n+    1474    ]=    0.0045    ;
    AOD[    n+    1475    ]=    0.0049    ;
    AOD[    n+    1476    ]=    0.0053    ;
    AOD[    n+    1477    ]=    0.0057    ;
    AOD[    n+    1478    ]=    0.0061    ;
    AOD[    n+    1479    ]=    0.0065    ;
    AOD[    n+    1480    ]=    0.0068    ;
    AOD[    n+    1481    ]=    0.0072    ;
    AOD[    n+    1482    ]=    0.0076    ;
    AOD[    n+    1483    ]=    0.008    ;
    AOD[    n+    1484    ]=    0.0084    ;
    AOD[    n+    1485    ]=    0.0087    ;
    AOD[    n+    1486    ]=    0.0091    ;
    AOD[    n+    1487    ]=    0.0095    ;
    AOD[    n+    1488    ]=    0.0099    ;
    AOD[    n+    1489    ]=    0.0103    ;
    AOD[    n+    1490    ]=    0.0107    ;
    AOD[    n+    1491    ]=    0.011    ;
    AOD[    n+    1492    ]=    0.0114    ;
    AOD[    n+    1493    ]=    0.0118    ;
    AOD[    n+    1494    ]=    0.0122    ;
    AOD[    n+    1495    ]=    0.0126    ;
    AOD[    n+    1496    ]=    0.013    ;
    AOD[    n+    1497    ]=    0.0133    ;
    AOD[    n+    1498    ]=    0.0137    ;
    AOD[    n+    1499    ]=    0.0141    ;
    AOD[    n+    1500    ]=    0.0184    ;
    AOD[    n+    1501    ]=    0.0228    ;
    AOD[    n+    1502    ]=    0.0271    ;
    AOD[    n+    1503    ]=    0.0314    ;
    AOD[    n+    1504    ]=    0.0358    ;
    AOD[    n+    1505    ]=    0.0401    ;
    AOD[    n+    1506    ]=    0.0369    ;
    AOD[    n+    1507    ]=    0.034    ;
    AOD[    n+    1508    ]=    0.0313    ;
    AOD[    n+    1509    ]=    0.0288    ;
    AOD[    n+    1510    ]=    0.0265    ;
    AOD[    n+    1511    ]=    0.0244    ;
    AOD[    n+    1512    ]=    0.0224    ;
    AOD[    n+    1513    ]=    0.0206    ;
    AOD[    n+    1514    ]=    0.019    ;
    AOD[    n+    1515    ]=    0.0175    ;
    AOD[    n+    1516    ]=    0.0161    ;
    AOD[    n+    1517    ]=    0.0148    ;
    AOD[    n+    1518    ]=    0.0136    ;
    AOD[    n+    1519    ]=    0.0126    ;
    AOD[    n+    1520    ]=    0.0116    ;
    AOD[    n+    1521    ]=    0.0106    ;
    AOD[    n+    1522    ]=    0.0098    ;
    AOD[    n+    1523    ]=    0.009    ;
    AOD[    n+    1524    ]=    0.0083    ;
    AOD[    n+    1525    ]=    0.0077    ;
    AOD[    n+    1526    ]=    0.0071    ;
    AOD[    n+    1527    ]=    0.0065    ;
    AOD[    n+    1528    ]=    0.006    ;
    AOD[    n+    1529    ]=    0.0055    ;
    AOD[    n+    1530    ]=    0.0051    ;
    AOD[    n+    1531    ]=    0.0047    ;
    AOD[    n+    1532    ]=    0.0043    ;
    AOD[    n+    1533    ]=    0.004    ;
    AOD[    n+    1534    ]=    0.0037    ;
    AOD[    n+    1535    ]=    0.0034    ;
    AOD[    n+    1536    ]=    0.0031    ;
    AOD[    n+    1537    ]=    0.0029    ;
    AOD[    n+    1538    ]=    0.0027    ;
    AOD[    n+    1539    ]=    0.0025    ;
    AOD[    n+    1540    ]=    0.0029    ;
    AOD[    n+    1541    ]=    0.0048    ;
    AOD[    n+    1542    ]=    0.0066    ;
    AOD[    n+    1543    ]=    0.0084    ;
    AOD[    n+    1544    ]=    0.0103    ;
    AOD[    n+    1545    ]=    0.0121    ;
    AOD[    n+    1546    ]=    0.0123    ;
    AOD[    n+    1547    ]=    0.0124    ;
    AOD[    n+    1548    ]=    0.0126    ;
    AOD[    n+    1549    ]=    0.0128    ;
    AOD[    n+    1550    ]=    0.0129    ;
    AOD[    n+    1551    ]=    0.0119    ;
    AOD[    n+    1552    ]=    0.0109    ;
    AOD[    n+    1553    ]=    0.0101    ;
    AOD[    n+    1554    ]=    0.0093    ;
    AOD[    n+    1555    ]=    0.0085    ;
    AOD[    n+    1556    ]=    0.0079    ;
    AOD[    n+    1557    ]=    0.0072    ;
    AOD[    n+    1558    ]=    0.0067    ;
    AOD[    n+    1559    ]=    0.0061    ;
    AOD[    n+    1560    ]=    0.0057    ;
    AOD[    n+    1561    ]=    0.0052    ;
    AOD[    n+    1562    ]=    0.0048    ;
    AOD[    n+    1563    ]=    0.0044    ;
    AOD[    n+    1564    ]=    0.0041    ;
    AOD[    n+    1565    ]=    0.0038    ;
    AOD[    n+    1566    ]=    0.0039    ;
    AOD[    n+    1567    ]=    0.0044    ;
    AOD[    n+    1568    ]=    0.0049    ;
    AOD[    n+    1569    ]=    0.0051    ;
    AOD[    n+    1570    ]=    0.0052    ;
    AOD[    n+    1571    ]=    0.0054    ;
    AOD[    n+    1572    ]=    0.0052    ;
    AOD[    n+    1573    ]=    0.0051    ;
    AOD[    n+    1574    ]=    0.0049    ;
    AOD[    n+    1575    ]=    0.0047    ;
    AOD[    n+    1576    ]=    0.0045    ;
    AOD[    n+    1577    ]=    0.0044    ;
    AOD[    n+    1578    ]=    0.0049    ;
    AOD[    n+    1579    ]=    0.0055    ;
    AOD[    n+    1580    ]=    0.0055    ;
    AOD[    n+    1581    ]=    0.0051    ;
    AOD[    n+    1582    ]=    0.0051    ;
    AOD[    n+    1583    ]=    0.0051    ;
    AOD[    n+    1584    ]=    0.0051    ;
    AOD[    n+    1585    ]=    0.0057    ;
    AOD[    n+    1586    ]=    0.0057    ;
    AOD[    n+    1587    ]=    0.0057    ;
    AOD[    n+    1588    ]=    0.0245    ;
    AOD[    n+    1589    ]=    0.0427    ;
    AOD[    n+    1590    ]=    0.0534    ;
    AOD[    n+    1591    ]=    0.0681    ;
    AOD[    n+    1592    ]=    0.0741    ;
    AOD[    n+    1593    ]=    0.0782    ;
    AOD[    n+    1594    ]=    0.0843    ;
    AOD[    n+    1595    ]=    0.0901    ;
    AOD[    n+    1596    ]=    0.0978    ;
    AOD[    n+    1597    ]=    0.096    ;
    AOD[    n+    1598    ]=    0.0939    ;
    AOD[    n+    1599    ]=    0.0959    ;
    AOD[    n+    1600    ]=    0.0912    ;
    AOD[    n+    1601    ]=    0.0863    ;
    AOD[    n+    1602    ]=    0.0794    ;
    AOD[    n+    1603    ]=    0.0731    ;
    AOD[    n+    1604    ]=    0.0673    ;
    AOD[    n+    1605    ]=    0.0619    ;
    AOD[    n+    1606    ]=    0.0569    ;
    AOD[    n+    1607    ]=    0.0524    ;
    AOD[    n+    1608    ]=    0.0486    ;
    AOD[    n+    1609    ]=    0.0451    ;
    AOD[    n+    1610    ]=    0.0416    ;
    AOD[    n+    1611    ]=    0.0383    ;
    AOD[    n+    1612    ]=    0.0352    ;
    AOD[    n+    1613    ]=    0.0324    ;
    AOD[    n+    1614    ]=    0.0302    ;
    AOD[    n+    1615    ]=    0.0282    ;
    AOD[    n+    1616    ]=    0.026    ;
    AOD[    n+    1617    ]=    0.0239    ;
    AOD[    n+    1618    ]=    0.022    ;
    AOD[    n+    1619    ]=    0.0202    ;
    AOD[    n+    1620    ]=    0.0188    ;
    AOD[    n+    1621    ]=    0.0164    ;
    AOD[    n+    1622    ]=    0.016    ;
    AOD[    n+    1623    ]=    0.0141    ;
    AOD[    n+    1624    ]=    0.0138    ;
    AOD[    n+    1625    ]=    0.0128    ;
    AOD[    n+    1626    ]=    0.0126    ;
    AOD[    n+    1627    ]=    0.0121    ;
    AOD[    n+    1628    ]=    0.0116    ;
    AOD[    n+    1629    ]=    0.0102    ;
    AOD[    n+    1630    ]=    0.0101    ;
    AOD[    n+    1631    ]=    0.0097    ;
    AOD[    n+    1632    ]=    0.0122    ;
    AOD[    n+    1633    ]=    0.0146    ;
    AOD[    n+    1634    ]=    0.0158    ;
    AOD[    n+    1635    ]=    0.0144    ;
    AOD[    n+    1636    ]=    0.0147    ;
    AOD[    n+    1637    ]=    0.014    ;
    AOD[    n+    1638    ]=    0.013    ;
    AOD[    n+    1639    ]=    0.0128    ;
    AOD[    n+    1640    ]=    0.014    ;
    AOD[    n+    1641    ]=    0.0126    ;
    AOD[    n+    1642    ]=    0.0126    ;
    AOD[    n+    1643    ]=    0.0123    ;
    AOD[    n+    1644    ]=    0.012    ;
    AOD[    n+    1645    ]=    0.0118    ;
    AOD[    n+    1646    ]=    0.0111    ;
    AOD[    n+    1647    ]=    0.0109    ;
    AOD[    n+    1648    ]=    0.0104    ;
    AOD[    n+    1649    ]=    0.0101    ;
    AOD[    n+    1650    ]=    0.0105    ;
    AOD[    n+    1651    ]=    0.0108    ;
    AOD[    n+    1652    ]=    0.0108    ;
    AOD[    n+    1653    ]=    0.0104    ;
    AOD[    n+    1654    ]=    0.0094    ;
    AOD[    n+    1655    ]=    0.0089    ;
    AOD[    n+    1656    ]=    0.0089    ;
    AOD[    n+    1657    ]=    0.0085    ;
    AOD[    n+    1658    ]=    0.0088    ;
    AOD[    n+    1659    ]=    0.0078    ;
    AOD[    n+    1660    ]=    0.0074    ;
    AOD[    n+    1661    ]=    0.0071    ;
    AOD[    n+    1662    ]=    0.0071    ;
    AOD[    n+    1663    ]=    0.008    ;
    AOD[    n+    1664    ]=    0.0096    ;
    AOD[    n+    1665    ]=    0.0069    ;
    AOD[    n+    1666    ]=    0.0065    ;
    AOD[    n+    1667    ]=    0.0068    ;
    AOD[    n+    1668    ]=    0.0068    ;
    AOD[    n+    1669    ]=    0.0072    ;
    AOD[    n+    1670    ]=    0.0064    ;
    AOD[    n+    1671    ]=    0.0062    ;
    AOD[    n+    1672    ]=    0.006    ;
    AOD[    n+    1673    ]=    0.0047    ;
    AOD[    n+    1674    ]=    0.0057    ;
    AOD[    n+    1675    ]=    0.0067    ;
    AOD[    n+    1676    ]=    0.0083    ;
    AOD[    n+    1677    ]=    0.0062    ;
    AOD[    n+    1678    ]=    0.0054    ;
    AOD[    n+    1679    ]=    0.0055    ;
    AOD[    n+    1680    ]=    0.0054    ;
    AOD[    n+    1681    ]=    0.0059    ;
    AOD[    n+    1682    ]=    0.0074    ;
    AOD[    n+    1683    ]=    0.0062    ;
    AOD[    n+    1684    ]=    0.0044    ;
    AOD[    n+    1685    ]=    0.0044    ;
    AOD[    n+    1686    ]=    0.006    ;
    AOD[    n+    1687    ]=    0.0073    ;
    AOD[    n+    1688    ]=    0.0074    ;
    AOD[    n+    1689    ]=    0.0068    ;
    AOD[    n+    1690    ]=    0.0058    ;
    AOD[    n+    1691    ]=    0.006    ;
    AOD[    n+    1692    ]=    0.006    ;
    AOD[    n+    1693    ]=    0.006    ;
    AOD[    n+    1694    ]=    0.0057    ;
    AOD[    n+    1695    ]=    0.0055    ;
    AOD[    n+    1696    ]=    0.0053    ;
    AOD[    n+    1697    ]=    0.0053    ;
    AOD[    n+    1698    ]=    0.0179    ;
    AOD[    n+    1699    ]=    0.0377    ;
    AOD[    n+    1700    ]=    0.071    ;
    AOD[    n+    1701    ]=    0.0964    ;
    AOD[    n+    1702    ]=    0.1197    ;
    AOD[    n+    1703    ]=    0.138    ;
    AOD[    n+    1704    ]=    0.1385    ;
    AOD[    n+    1705    ]=    0.1483    ;
    AOD[    n+    1706    ]=    0.1494    ;
    AOD[    n+    1707    ]=    0.1428    ;
    AOD[    n+    1708    ]=    0.1386    ;
    AOD[    n+    1709    ]=    0.1379    ;
    AOD[    n+    1710    ]=    0.1265    ;
    AOD[    n+    1711    ]=    0.1228    ;
    AOD[    n+    1712    ]=    0.1141    ;
    AOD[    n+    1713    ]=    0.1044    ;
    AOD[    n+    1714    ]=    0.0978    ;
    AOD[    n+    1715    ]=    0.0918    ;
    AOD[    n+    1716    ]=    0.0793    ;
    AOD[    n+    1717    ]=    0.0743    ;
    AOD[    n+    1718    ]=    0.0661    ;
    AOD[    n+    1719    ]=    0.0608    ;
    AOD[    n+    1720    ]=    0.0559    ;
    AOD[    n+    1721    ]=    0.0525    ;
    AOD[    n+    1722    ]=    0.0482    ;
    AOD[    n+    1723    ]=    0.0445    ;
    AOD[    n+    1724    ]=    0.0425    ;
    AOD[    n+    1725    ]=    0.0394    ;
    AOD[    n+    1726    ]=    0.0376    ;
    AOD[    n+    1727    ]=    0.035    ;
    AOD[    n+    1728    ]=    0.0312    ;
    AOD[    n+    1729    ]=    0.0285    ;
    AOD[    n+    1730    ]=    0.0265    ;
    AOD[    n+    1731    ]=    0.0238    ;
    AOD[    n+    1732    ]=    0.0218    ;
    AOD[    n+    1733    ]=    0.0205    ;
    AOD[    n+    1734    ]=    0.0185    ;
    AOD[    n+    1735    ]=    0.0179    ;
    AOD[    n+    1736    ]=    0.0173    ;
    AOD[    n+    1737    ]=    0.0161    ;
    AOD[    n+    1738    ]=    0.0166    ;
    AOD[    n+    1739    ]=    0.0159    ;
    AOD[    n+    1740    ]=    0.016    ;
    AOD[    n+    1741    ]=    0.012    ;
    AOD[    n+    1742    ]=    0.0117    ;
    AOD[    n+    1743    ]=    0.0109    ;
    AOD[    n+    1744    ]=    0.01    ;
    AOD[    n+    1745    ]=    0.01    ;
    AOD[    n+    1746    ]=    0.0093    ;
    AOD[    n+    1747    ]=    0.0094    ;
    AOD[    n+    1748    ]=    0.0087    ;
    AOD[    n+    1749    ]=    0.0085    ;
    AOD[    n+    1750    ]=    0.0088    ;
    AOD[    n+    1751    ]=    0.0086    ;
    AOD[    n+    1752    ]=    0.0077    ;
    AOD[    n+    1753    ]=    0.0074    ;
    AOD[    n+    1754    ]=    0.0072    ;
    AOD[    n+    1755    ]=    0.0068    ;
    AOD[    n+    1756    ]=    0.0063    ;
    AOD[    n+    1757    ]=    0.0067    ;
    AOD[    n+    1758    ]=    0.006    ;
    AOD[    n+    1759    ]=    0.0066    ;
    AOD[    n+    1760    ]=    0.0062    ;
    AOD[    n+    1761    ]=    0.0059    ;
    AOD[    n+    1762    ]=    0.0064    ;
    AOD[    n+    1763    ]=    0.0064    ;
    AOD[    n+    1764    ]=    0.0061    ;
    AOD[    n+    1765    ]=    0.006    ;
    AOD[    n+    1766    ]=    0.0057    ;
    AOD[    n+    1767    ]=    0.0053    ;
    AOD[    n+    1768    ]=    0.0052    ;
    AOD[    n+    1769    ]=    0.0055    ;
    AOD[    n+    1770    ]=    0.005    ;
    AOD[    n+    1771    ]=    0.0054    ;
    AOD[    n+    1772    ]=    0.0051    ;
    AOD[    n+    1773    ]=    0.0053    ;
    AOD[    n+    1774    ]=    0.0051    ;
    AOD[    n+    1775    ]=    0.0047    ;
    AOD[    n+    1776    ]=    0.0043    ;
    AOD[    n+    1777    ]=    0.004    ;
    AOD[    n+    1778    ]=    0.0037    ;
    AOD[    n+    1779    ]=    0.0034    ;
    AOD[    n+    1780    ]=    0.0031    ;
    AOD[    n+    1781    ]=    0.0029    ;
    AOD[    n+    1782    ]=    0.0027    ;
    AOD[    n+    1783    ]=    0.0025    ;
    AOD[    n+    1784    ]=    0.0024    ;
    AOD[    n+    1785    ]=    0.0023    ;
    AOD[    n+    1786    ]=    0.0022    ;
    AOD[    n+    1787    ]=    0.0022    ;
    AOD[    n+    1788    ]=    0.0022    ;
    AOD[    n+    1789    ]=    0.0022    ;
    AOD[    n+    1790    ]=    0.0022    ;
    AOD[    n+    1791    ]=    0.0021    ;
    AOD[    n+    1792    ]=    0.0021    ;
    AOD[    n+    1793    ]=    0.0021    ;
    AOD[    n+    1794    ]=    0.0021    ;
    AOD[    n+    1795    ]=    0.0021    ;
    AOD[    n+    1796    ]=    0.0021    ;
    AOD[    n+    1797    ]=    0.0021    ;
    AOD[    n+    1798    ]=    0.0021    ;
    AOD[    n+    1799    ]=    0.0021    ;
    AOD[    n+    1800    ]=    0.0021    ;
    AOD[    n+    1801    ]=    0.0021    ;
    AOD[    n+    1802    ]=    0.0021    ;
    AOD[    n+    1803    ]=    0.0021    ;
    AOD[    n+    1804    ]=    0.0021    ;
    AOD[    n+    1805    ]=    0.0021    ;
    AOD[    n+    1806    ]=    0.0021    ;
    AOD[    n+    1807    ]=    0.0021    ;
    AOD[    n+    1808    ]=    0.0021    ;
    AOD[    n+    1809    ]=    0.0021    ;
    AOD[    n+    1810    ]=    0.0021    ;
    AOD[    n+    1811    ]=    0.0021    ;
    AOD[    n+    1812    ]=    0.0021    ;
    AOD[    n+    1813    ]=    0.0021    ;
    AOD[    n+    1814    ]=    0.0021    ;
    AOD[    n+    1815    ]=    0.0021    ;
    AOD[    n+    1816    ]=    0.0021    ;
    AOD[    n+    1817    ]=    0.0021    ;
    AOD[    n+    1818    ]=    0.0021    ;
    AOD[    n+    1819    ]=    0.0021    ;
    AOD[    n+    1820    ]=    0.0021    ;
    AOD[    n+    1821    ]=    0.0021    ;
    AOD[    n+    1822    ]=    0.0021    ;
    AOD[    n+    1823    ]=    0.0021    ;
    AOD[    n+    1824    ]=    0.0022    ;
    AOD[    n+    1825    ]=    0.0021    ;
    AOD[    n+    1826    ]=    0.0021    ;
    AOD[    n+    1827    ]=    0.002    ;
    AOD[    n+    1828    ]=    0.002    ;
    AOD[    n+    1829    ]=    0.0019    ;
    AOD[    n+    1830    ]=    0.0019    ;
    AOD[    n+    1831    ]=    0.0016    ;
    AOD[    n+    1832    ]=    0.0021    ;
    AOD[    n+    1833    ]=    0.0022    ;
    AOD[    n+    1834    ]=    0.0022    ;
    AOD[    n+    1835    ]=    0.0024    ;
    AOD[    n+    1836    ]=    0.0026    ;
    AOD[    n+    1837    ]=    0.0028    ;
    AOD[    n+    1838    ]=    0.0028    ;
    AOD[    n+    1839    ]=    0.0026    ;
    AOD[    n+    1840    ]=    0.0026    ;
    AOD[    n+    1841    ]=    0.0025    ;
    AOD[    n+    1842    ]=    0.0025    ;
    AOD[    n+    1843    ]=    0.0026    ;
    AOD[    n+    1844    ]=    0.0028    ;
    AOD[    n+    1845    ]=    0.0029    ;
    AOD[    n+    1846    ]=    0.0028    ;
    AOD[    n+    1847    ]=    0.0028    ;
    AOD[    n+    1848    ]=    0.0027    ;
    AOD[    n+    1849    ]=    0.0025    ;
    AOD[    n+    1850    ]=    0.0024    ;
    AOD[    n+    1851    ]=    0.0024    ;
    AOD[    n+    1852    ]=    0.0024    ;
    AOD[    n+    1853    ]=    0.0022    ;
    AOD[    n+    1854    ]=    0.0022    ;
    AOD[    n+    1855    ]=    0.0023    ;
    AOD[    n+    1856    ]=    0.0025    ;
    AOD[    n+    1857    ]=    0.0025    ;
    AOD[    n+    1858    ]=    0.0025    ;
    AOD[    n+    1859    ]=    0.0025    ;
    AOD[    n+    1860    ]=    0.0027    ;
    AOD[    n+    1861    ]=    0.0029    ;
    AOD[    n+    1862    ]=    0.0031    ;
    AOD[    n+    1863    ]=    0.0034    ;
    AOD[    n+    1864    ]=    0.0035    ;
    AOD[    n+    1865    ]=    0.0034    ;
    AOD[    n+    1866    ]=    0.0033    ;
    AOD[    n+    1867    ]=    0.0033    ;
    AOD[    n+    1868    ]=    0.0036    ;
    AOD[    n+    1869    ]=    0.0037    ;
    AOD[    n+    1870    ]=    0.0037    ;
    AOD[    n+    1871    ]=    0.0037    ;
    AOD[    n+    1872    ]=    0.0036    ;
    AOD[    n+    1873    ]=    0.0034    ;
    AOD[    n+    1874    ]=    0.0033    ;
    AOD[    n+    1875    ]=    0.0032    ;
    AOD[    n+    1876    ]=    0.0032    ;
    AOD[    n+    1877    ]=    0.003    ;
    AOD[    n+    1878    ]=    0.0033    ;
    AOD[    n+    1879    ]=    0.0038    ;
    AOD[    n+    1880    ]=    0.0041    ;
    AOD[    n+    1881    ]=    0.0043    ;
    AOD[    n+    1882    ]=    0.0044    ;
    AOD[    n+    1883    ]=    0.0049    ;
    AOD[    n+    1884    ]=    0.0054    ;
    AOD[    n+    1885    ]=    0.0054    ;
    AOD[    n+    1886    ]=    0.0051    ;
    AOD[    n+    1887    ]=    0.0045    ;
    AOD[    n+    1888    ]=    0.0045    ;
    AOD[    n+    1889    ]=    0.0041    ;
    AOD[    n+    1890    ]=    0.004    ;
    AOD[    n+    1891    ]=    0.004    ;
    AOD[    n+    1892    ]=    0.0041    ;
    AOD[    n+    1893    ]=    0.0042    ;
    AOD[    n+    1894    ]=    0.0041    ;
    AOD[    n+    1895    ]=    0.0042    ;
    AOD[    n+    1896    ]=    0.004    ;
    AOD[    n+    1897    ]=    0.0038    ;
    AOD[    n+    1898    ]=    0.0036    ;
    AOD[    n+    1899    ]=    0.0034    ;
    AOD[    n+    1900    ]=    0.0033    ;
    AOD[    n+    1901    ]=    0.0031    ;
    AOD[    n+    1902    ]=    0.0031    ;
    AOD[    n+    1903    ]=    0.0033    ;
    AOD[    n+    1904    ]=    0.0036    ;
    AOD[    n+    1905    ]=    0.0043    ;
    AOD[    n+    1906    ]=    0.0046    ;
    AOD[    n+    1907    ]=    0.0048    ;
    AOD[    n+    1908    ]=    0.0046    ;
    AOD[    n+    1909    ]=    0.0042    ;
    AOD[    n+    1910    ]=    0.0039    ;
    AOD[    n+    1911    ]=    0.004    ;
    AOD[    n+    1912    ]=    0.0038    ;
    AOD[    n+    1913    ]=    0.0036    ;
    AOD[    n+    1914    ]=    0.0036    ;
    AOD[    n+    1915    ]=    0.0051    ;
    AOD[    n+    1916    ]=    0.0062    ;
    AOD[    n+    1917    ]=    0.0062    ;
    AOD[    n+    1918    ]=    0.0056    ;
    AOD[    n+    1919    ]=    0.0053    ;
    AOD[    n+    1920    ]=    0.0046    ;
    AOD[    n+    1921    ]=    0.0041    ;
    AOD[    n+    1922    ]=    0.0037    ;
    AOD[    n+    1923    ]=    0.0033    ;
    AOD[    n+    1924    ]=    0.0034    ;
    AOD[    n+    1925    ]=    0.0032    ;
    AOD[    n+    1926    ]=    0.0032    ;
    AOD[    n+    1927    ]=    0.0033    ;
    AOD[    n+    1928    ]=    0.0035    ;
    AOD[    n+    1929    ]=    0.0035    ;
    AOD[    n+    1930    ]=    0.0034    ;
    AOD[    n+    1931    ]=    0.0037    ;
    AOD[    n+    1932    ]=    0.0045    ;
    AOD[    n+    1933    ]=    0.0044    ;
    AOD[    n+    1934    ]=    0.0041    ;
    AOD[    n+    1935    ]=    0.0037    ;
    AOD[    n+    1936    ]=    0.0035    ;
    AOD[    n+    1937    ]=    0.0034    ;
    AOD[    n+    1938    ]=    0.0034    ;
    AOD[    n+    1939    ]=    0.0052    ;
    AOD[    n+    1940    ]=    0.0068    ;
    AOD[    n+    1941    ]=    0.0067    ;
    AOD[    n+    1942    ]=    0.0064    ;
    AOD[    n+    1943    ]=    0.006    ;
    AOD[    n+    1944    ]=    0.0055    ;
    AOD[    n+    1945    ]=    0.0048    ;
    AOD[    n+    1946    ]=    0.004    ;
    AOD[    n+    1947    ]=    0.0038    ;
    AOD[    n+    1948    ]=    0.0038    ;
    AOD[    n+    1949    ]=    0.0035    ;
    AOD[    n+    1950    ]=    0.0034    ;
    AOD[    n+    1951    ]=    0.0034    ;
    AOD[    n+    1952    ]=    0.0034    ;
    AOD[    n+    1953    ]=    0.0035    ;
    
    
    for(int i = n+1954; i<tmax; i++)
    {
        AOD[i] = 0.012740502;
    }
    
    
}

void setR_aerosol_RCP6(void)
{
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.000955298	;
    RnonCO2[	2	]=	0.001424721	;
    RnonCO2[	3	]=	0.0001974	;
    RnonCO2[	4	]=	-0.001278437	;
    RnonCO2[	5	]=	-0.002733841	;
    RnonCO2[	6	]=	-0.004541334	;
    RnonCO2[	7	]=	-0.00632004	;
    RnonCO2[	8	]=	-0.007680948	;
    RnonCO2[	9	]=	-0.008994568	;
    RnonCO2[	10	]=	-0.010260775	;
    RnonCO2[	11	]=	-0.011479866	;
    RnonCO2[	12	]=	-0.012652425	;
    RnonCO2[	13	]=	-0.013779231	;
    RnonCO2[	14	]=	-0.014861204	;
    RnonCO2[	15	]=	-0.015900176	;
    RnonCO2[	16	]=	-0.017335746	;
    RnonCO2[	17	]=	-0.01873479	;
    RnonCO2[	18	]=	-0.019659073	;
    RnonCO2[	19	]=	-0.020540613	;
    RnonCO2[	20	]=	-0.02137714	;
    RnonCO2[	21	]=	-0.022166399	;
    RnonCO2[	22	]=	-0.022906132	;
    RnonCO2[	23	]=	-0.023594082	;
    RnonCO2[	24	]=	-0.024227995	;
    RnonCO2[	25	]=	-0.024806236	;
    RnonCO2[	26	]=	-0.025775743	;
    RnonCO2[	27	]=	-0.026691982	;
    RnonCO2[	28	]=	-0.027110281	;
    RnonCO2[	29	]=	-0.02747885	;
    RnonCO2[	30	]=	-0.027799526	;
    RnonCO2[	31	]=	-0.028074106	;
    RnonCO2[	32	]=	-0.02875039	;
    RnonCO2[	33	]=	-0.029383792	;
    RnonCO2[	34	]=	-0.02953002	;
    RnonCO2[	35	]=	-0.03007996	;
    RnonCO2[	36	]=	-0.03058546	;
    RnonCO2[	37	]=	-0.03148571	;
    RnonCO2[	38	]=	-0.03189741	;
    RnonCO2[	39	]=	-0.03138062	;
    RnonCO2[	40	]=	-0.03126848	;
    RnonCO2[	41	]=	-0.03156144	;
    RnonCO2[	42	]=	-0.03182181	;
    RnonCO2[	43	]=	-0.03161267	;
    RnonCO2[	44	]=	-0.03137821	;
    RnonCO2[	45	]=	-0.03112038	;
    RnonCO2[	46	]=	-0.03127367	;
    RnonCO2[	47	]=	-0.0313998	;
    RnonCO2[	48	]=	-0.03106322	;
    RnonCO2[	49	]=	-0.03070135	;
    RnonCO2[	50	]=	-0.03074616	;
    RnonCO2[	51	]=	-0.03119614	;
    RnonCO2[	52	]=	-0.03161872	;
    RnonCO2[	53	]=	-0.03158785	;
    RnonCO2[	54	]=	-0.03110696	;
    RnonCO2[	55	]=	-0.03060634	;
    RnonCO2[	56	]=	-0.0300866	;
    RnonCO2[	57	]=	-0.02996996	;
    RnonCO2[	58	]=	-0.03025404	;
    RnonCO2[	59	]=	-0.03009594	;
    RnonCO2[	60	]=	-0.02991636	;
    RnonCO2[	61	]=	-0.02971869	;
    RnonCO2[	62	]=	-0.02950042	;
    RnonCO2[	63	]=	-0.02926502	;
    RnonCO2[	64	]=	-0.02859871	;
    RnonCO2[	65	]=	-0.03037359	;
    RnonCO2[	66	]=	-0.03172034	;
    RnonCO2[	67	]=	-0.03059392	;
    RnonCO2[	68	]=	-0.03026959	;
    RnonCO2[	69	]=	-0.02993194	;
    RnonCO2[	70	]=	-0.02957653	;
    RnonCO2[	71	]=	-0.03080027	;
    RnonCO2[	72	]=	-0.03160022	;
    RnonCO2[	73	]=	-0.03117789	;
    RnonCO2[	74	]=	-0.03112982	;
    RnonCO2[	75	]=	-0.03144654	;
    RnonCO2[	76	]=	-0.03173222	;
    RnonCO2[	77	]=	-0.03198224	;
    RnonCO2[	78	]=	-0.03220368	;
    RnonCO2[	79	]=	-0.03239696	;
    RnonCO2[	80	]=	-0.03371239	;
    RnonCO2[	81	]=	-0.03424533	;
    RnonCO2[	82	]=	-0.0343764	;
    RnonCO2[	83	]=	-0.03487942	;
    RnonCO2[	84	]=	-0.03536957	;
    RnonCO2[	85	]=	-0.03686306	;
    RnonCO2[	86	]=	-0.03665392	;
    RnonCO2[	87	]=	-0.04248424	;
    RnonCO2[	88	]=	-0.04930444	;
    RnonCO2[	89	]=	-0.05182621	;
    RnonCO2[	90	]=	-0.0542671	;
    RnonCO2[	91	]=	-0.05573158	;
    RnonCO2[	92	]=	-0.05765815	;
    RnonCO2[	93	]=	-0.05821397	;
    RnonCO2[	94	]=	-0.06005825	;
    RnonCO2[	95	]=	-0.0683501	;
    RnonCO2[	96	]=	-0.08104112	;
    RnonCO2[	97	]=	-0.07832852	;
    RnonCO2[	98	]=	-0.07177024	;
    RnonCO2[	99	]=	-0.07363036	;
    RnonCO2[	100	]=	-0.07696442	;
    RnonCO2[	101	]=	-0.08462429	;
    RnonCO2[	102	]=	-0.09275025	;
    RnonCO2[	103	]=	-0.09511911	;
    RnonCO2[	104	]=	-0.0930339	;
    RnonCO2[	105	]=	-0.09237765	;
    RnonCO2[	106	]=	-0.10165608	;
    RnonCO2[	107	]=	-0.12466661	;
    RnonCO2[	108	]=	-0.14405058	;
    RnonCO2[	109	]=	-0.14773339	;
    RnonCO2[	110	]=	-0.14777672	;
    RnonCO2[	111	]=	-0.1470811	;
    RnonCO2[	112	]=	-0.14255587	;
    RnonCO2[	113	]=	-0.14024698	;
    RnonCO2[	114	]=	-0.14393886	;
    RnonCO2[	115	]=	-0.15612866	;
    RnonCO2[	116	]=	-0.164782	;
    RnonCO2[	117	]=	-0.16302445	;
    RnonCO2[	118	]=	-0.16326054	;
    RnonCO2[	119	]=	-0.16496204	;
    RnonCO2[	120	]=	-0.16272157	;
    RnonCO2[	121	]=	-0.1612244	;
    RnonCO2[	122	]=	-0.16356025	;
    RnonCO2[	123	]=	-0.17242315	;
    RnonCO2[	124	]=	-0.17632405	;
    RnonCO2[	125	]=	-0.17855867	;
    RnonCO2[	126	]=	-0.18527891	;
    RnonCO2[	127	]=	-0.18997972	;
    RnonCO2[	128	]=	-0.1933518	;
    RnonCO2[	129	]=	-0.19699663	;
    RnonCO2[	130	]=	-0.20233059	;
    RnonCO2[	131	]=	-0.2051441	;
    RnonCO2[	132	]=	-0.20577589	;
    RnonCO2[	133	]=	-0.20720143	;
    RnonCO2[	134	]=	-0.21030464	;
    RnonCO2[	135	]=	-0.21375193	;
    RnonCO2[	136	]=	-0.22004069	;
    RnonCO2[	137	]=	-0.22693377	;
    RnonCO2[	138	]=	-0.23402972	;
    RnonCO2[	139	]=	-0.2411565	;
    RnonCO2[	140	]=	-0.2471181	;
    RnonCO2[	141	]=	-0.255172	;
    RnonCO2[	142	]=	-0.26315304	;
    RnonCO2[	143	]=	-0.2636557	;
    RnonCO2[	144	]=	-0.26151664	;
    RnonCO2[	145	]=	-0.26499499	;
    RnonCO2[	146	]=	-0.26461175	;
    RnonCO2[	147	]=	-0.26044407	;
    RnonCO2[	148	]=	-0.25940869	;
    RnonCO2[	149	]=	-0.25560119	;
    RnonCO2[	150	]=	-0.25007798	;
    RnonCO2[	151	]=	-0.25106379	;
    RnonCO2[	152	]=	-0.25437609	;
    RnonCO2[	153	]=	-0.25544669	;
    RnonCO2[	154	]=	-0.2505011	;
    RnonCO2[	155	]=	-0.24919556	;
    RnonCO2[	156	]=	-0.24766564	;
    RnonCO2[	157	]=	-0.24454174	;
    RnonCO2[	158	]=	-0.25504195	;
    RnonCO2[	159	]=	-0.26312341	;
    RnonCO2[	160	]=	-0.26314088	;
    RnonCO2[	161	]=	-0.26376161	;
    RnonCO2[	162	]=	-0.26809378	;
    RnonCO2[	163	]=	-0.27284291	;
    RnonCO2[	164	]=	-0.27584022	;
    RnonCO2[	165	]=	-0.27557411	;
    RnonCO2[	166	]=	-0.26967283	;
    RnonCO2[	167	]=	-0.26315755	;
    RnonCO2[	168	]=	-0.26083606	;
    RnonCO2[	169	]=	-0.26325195	;
    RnonCO2[	170	]=	-0.2652416	;
    RnonCO2[	171	]=	-0.26824619	;
    RnonCO2[	172	]=	-0.26930622	;
    RnonCO2[	173	]=	-0.26149511	;
    RnonCO2[	174	]=	-0.25651091	;
    RnonCO2[	175	]=	-0.26035065	;
    RnonCO2[	176	]=	-0.26656695	;
    RnonCO2[	177	]=	-0.27194936	;
    RnonCO2[	178	]=	-0.274817	;
    RnonCO2[	179	]=	-0.27878403	;
    RnonCO2[	180	]=	-0.28302569	;
    RnonCO2[	181	]=	-0.29104814	;
    RnonCO2[	182	]=	-0.30416561	;
    RnonCO2[	183	]=	-0.31716714	;
    RnonCO2[	184	]=	-0.3246442	;
    RnonCO2[	185	]=	-0.3327935	;
    RnonCO2[	186	]=	-0.35639494	;
    RnonCO2[	187	]=	-0.38051016	;
    RnonCO2[	188	]=	-0.39378465	;
    RnonCO2[	189	]=	-0.40659776	;
    RnonCO2[	190	]=	-0.4196919	;
    RnonCO2[	191	]=	-0.43302942	;
    RnonCO2[	192	]=	-0.44651364	;
    RnonCO2[	193	]=	-0.45569127	;
    RnonCO2[	194	]=	-0.45642498	;
    RnonCO2[	195	]=	-0.45551768	;
    RnonCO2[	196	]=	-0.47183293	;
    RnonCO2[	197	]=	-0.49188519	;
    RnonCO2[	198	]=	-0.50135461	;
    RnonCO2[	199	]=	-0.5101619	;
    RnonCO2[	200	]=	-0.51738459	;
    RnonCO2[	201	]=	-0.52416219	;
    RnonCO2[	202	]=	-0.53325402	;
    RnonCO2[	203	]=	-0.54124791	;
    RnonCO2[	204	]=	-0.54379714	;
    RnonCO2[	205	]=	-0.53664772	;
    RnonCO2[	206	]=	-0.52607217	;
    RnonCO2[	207	]=	-0.52739363	;
    RnonCO2[	208	]=	-0.53724776	;
    RnonCO2[	209	]=	-0.54779467	;
    RnonCO2[	210	]=	-0.55942351	;
    RnonCO2[	211	]=	-0.57578959	;
    RnonCO2[	212	]=	-0.5916702	;
    RnonCO2[	213	]=	-0.5979117	;
    RnonCO2[	214	]=	-0.6009881	;
    RnonCO2[	215	]=	-0.6131431	;
    RnonCO2[	216	]=	-0.6319195	;
    RnonCO2[	217	]=	-0.6542028	;
    RnonCO2[	218	]=	-0.6747946	;
    RnonCO2[	219	]=	-0.6865596	;
    RnonCO2[	220	]=	-0.6942006	;
    RnonCO2[	221	]=	-0.7018816	;
    RnonCO2[	222	]=	-0.7121991	;
    RnonCO2[	223	]=	-0.7210817	;
    RnonCO2[	224	]=	-0.7262596	;
    RnonCO2[	225	]=	-0.7299457	;
    RnonCO2[	226	]=	-0.7418714	;
    RnonCO2[	227	]=	-0.7583892	;
    RnonCO2[	228	]=	-0.7656833	;
    RnonCO2[	229	]=	-0.768847	;
    RnonCO2[	230	]=	-0.7655134	;
    RnonCO2[	231	]=	-0.7588829	;
    RnonCO2[	232	]=	-0.7657109	;
    RnonCO2[	233	]=	-0.7804313	;
    RnonCO2[	234	]=	-0.7902367	;
    RnonCO2[	235	]=	-0.8012413	;
    RnonCO2[	236	]=	-0.8096987	;
    RnonCO2[	237	]=	-0.8105819	;
    RnonCO2[	238	]=	-0.8112899	;
    RnonCO2[	239	]=	-0.8123564	;
    RnonCO2[	240	]=	-0.8127693	;
    RnonCO2[	241	]=	-0.8114998	;
    RnonCO2[	242	]=	-0.8100512	;
    RnonCO2[	243	]=	-0.8090083	;
    RnonCO2[	244	]=	-0.8076194	;
    RnonCO2[	245	]=	-0.8048381	;
    RnonCO2[	246	]=	-0.7996442	;
    RnonCO2[	247	]=	-0.792911	;
    RnonCO2[	248	]=	-0.7861671	;
    RnonCO2[	249	]=	-0.7797473	;
    RnonCO2[	250	]=	-0.7734094	;
    RnonCO2[	251	]=	-0.76711	;
    RnonCO2[	252	]=	-0.7608332	;
    RnonCO2[	253	]=	-0.7545757	;
    RnonCO2[	254	]=	-0.7478873	;
    RnonCO2[	255	]=	-0.7402884	;
    RnonCO2[	256	]=	-0.7314711	;
    RnonCO2[	257	]=	-0.7217277	;
    RnonCO2[	258	]=	-0.7117183	;
    RnonCO2[	259	]=	-0.7015213	;
    RnonCO2[	260	]=	-0.6911336	;
    RnonCO2[	261	]=	-0.6805672	;
    RnonCO2[	262	]=	-0.669829	;
    RnonCO2[	263	]=	-0.658928	;
    RnonCO2[	264	]=	-0.6478722	;
    RnonCO2[	265	]=	-0.6396725	;
    RnonCO2[	266	]=	-0.6373726	;
    RnonCO2[	267	]=	-0.6376422	;
    RnonCO2[	268	]=	-0.6375075	;
    RnonCO2[	269	]=	-0.637358	;
    RnonCO2[	270	]=	-0.6371818	;
    RnonCO2[	271	]=	-0.6369729	;
    RnonCO2[	272	]=	-0.636734	;
    RnonCO2[	273	]=	-0.6364677	;
    RnonCO2[	274	]=	-0.6361804	;
    RnonCO2[	275	]=	-0.634026	;
    RnonCO2[	276	]=	-0.6281673	;
    RnonCO2[	277	]=	-0.6210131	;
    RnonCO2[	278	]=	-0.6144609	;
    RnonCO2[	279	]=	-0.6080083	;
    RnonCO2[	280	]=	-0.6016499	;
    RnonCO2[	281	]=	-0.5953814	;
    RnonCO2[	282	]=	-0.5892031	;
    RnonCO2[	283	]=	-0.5831185	;
    RnonCO2[	284	]=	-0.5771411	;
    RnonCO2[	285	]=	-0.5725313	;
    RnonCO2[	286	]=	-0.5705237	;
    RnonCO2[	287	]=	-0.5698536	;
    RnonCO2[	288	]=	-0.5692522	;
    RnonCO2[	289	]=	-0.5687109	;
    RnonCO2[	290	]=	-0.5682345	;
    RnonCO2[	291	]=	-0.5678125	;
    RnonCO2[	292	]=	-0.5674364	;
    RnonCO2[	293	]=	-0.5670986	;
    RnonCO2[	294	]=	-0.5667917	;
    RnonCO2[	295	]=	-0.5632628	;
    RnonCO2[	296	]=	-0.5532447	;
    RnonCO2[	297	]=	-0.540553	;
    RnonCO2[	298	]=	-0.5284535	;
    RnonCO2[	299	]=	-0.5163756	;
    RnonCO2[	300	]=	-0.5043256	;
    RnonCO2[	301	]=	-0.4923045	;
    RnonCO2[	302	]=	-0.4802974	;
    RnonCO2[	303	]=	-0.4682919	;
    RnonCO2[	304	]=	-0.4562769	;
    RnonCO2[	305	]=	-0.4457461	;
    RnonCO2[	306	]=	-0.4382204	;
    RnonCO2[	307	]=	-0.4321175	;
    RnonCO2[	308	]=	-0.4259812	;
    RnonCO2[	309	]=	-0.4199528	;
    RnonCO2[	310	]=	-0.4140242	;
    RnonCO2[	311	]=	-0.4081992	;
    RnonCO2[	312	]=	-0.4024771	;
    RnonCO2[	313	]=	-0.3968416	;
    RnonCO2[	314	]=	-0.3912786	;
    RnonCO2[	315	]=	-0.3874316	;
    RnonCO2[	316	]=	-0.3869466	;
    RnonCO2[	317	]=	-0.387848	;
    RnonCO2[	318	]=	-0.3885955	;
    RnonCO2[	319	]=	-0.3896114	;
    RnonCO2[	320	]=	-0.3908763	;
    RnonCO2[	321	]=	-0.3923728	;
    RnonCO2[	322	]=	-0.3940965	;
    RnonCO2[	323	]=	-0.3960398	;
    RnonCO2[	324	]=	-0.3981799	;
    RnonCO2[	325	]=	-0.4003766	;
    RnonCO2[	326	]=	-0.4024909	;
    RnonCO2[	327	]=	-0.4044876	;
    RnonCO2[	328	]=	-0.4063598	;
    RnonCO2[	329	]=	-0.4081302	;
    RnonCO2[	330	]=	-0.4098073	;
    RnonCO2[	331	]=	-0.4113974	;
    RnonCO2[	332	]=	-0.4129068	;
    RnonCO2[	333	]=	-0.4143267	;
    RnonCO2[	334	]=	-0.4156335	;
    RnonCO2[	335	]=	-0.4174491	;
    RnonCO2[	336	]=	-0.4204126	;
    RnonCO2[	337	]=	-0.4233067	;
    RnonCO2[	338	]=	-0.4254415	;
    RnonCO2[	339	]=	-0.427363	;
    RnonCO2[	340	]=	-0.4290953	;
    RnonCO2[	341	]=	-0.4306596	;
    RnonCO2[	342	]=	-0.4320731	;
    RnonCO2[	343	]=	-0.4333513	;
    RnonCO2[	344	]=	-0.4345191	;
    RnonCO2[	345	]=	-0.4355948	;
    RnonCO2[	346	]=	-0.4365798	;
    RnonCO2[	347	]=	-0.4374762	;
    RnonCO2[	348	]=	-0.4382865	;
    RnonCO2[	349	]=	-0.4390119	;
    RnonCO2[	350	]=	-0.4396595	;
    RnonCO2[	351	]=	-0.4402397	;
    RnonCO2[	352	]=	-0.4407606	;
    RnonCO2[	353	]=	-0.4412283	;
    RnonCO2[	354	]=	-0.4416481	;
    RnonCO2[	355	]=	-0.4420352	;
    RnonCO2[	356	]=	-0.4424	;
    RnonCO2[	357	]=	-0.4427358	;
    RnonCO2[	358	]=	-0.4430382	;
    RnonCO2[	359	]=	-0.4433038	;
    RnonCO2[	360	]=	-0.4435315	;
    RnonCO2[	361	]=	-0.443729	;
    RnonCO2[	362	]=	-0.4439055	;
    RnonCO2[	363	]=	-0.4440656	;
    RnonCO2[	364	]=	-0.4442117	;
    RnonCO2[	365	]=	-0.4443461	;
    RnonCO2[	366	]=	-0.4444814	;
    RnonCO2[	367	]=	-0.4446253	;
    RnonCO2[	368	]=	-0.4447691	;
    RnonCO2[	369	]=	-0.4449066	;
    RnonCO2[	370	]=	-0.4450323	;
    RnonCO2[	371	]=	-0.4451409	;
    RnonCO2[	372	]=	-0.4452328	;
    RnonCO2[	373	]=	-0.4453132	;
    RnonCO2[	374	]=	-0.4453855	;
    RnonCO2[	375	]=	-0.4454513	;
    RnonCO2[	376	]=	-0.4455118	;
    RnonCO2[	377	]=	-0.4455791	;
    RnonCO2[	378	]=	-0.44566	;
    RnonCO2[	379	]=	-0.4457457	;
    RnonCO2[	380	]=	-0.4458289	;
    RnonCO2[	381	]=	-0.4459038	;
    RnonCO2[	382	]=	-0.4459649	;
    RnonCO2[	383	]=	-0.4460121	;
    RnonCO2[	384	]=	-0.4460503	;
    RnonCO2[	385	]=	-0.4460677	;
    RnonCO2[	386	]=	-0.4460677	;
    RnonCO2[	387	]=	-0.4460677	;
    RnonCO2[	388	]=	-0.4460677	;
    RnonCO2[	389	]=	-0.4460677	;
    RnonCO2[	390	]=	-0.4460677	;
    RnonCO2[	391	]=	-0.4460677	;
    RnonCO2[	392	]=	-0.4460677	;
    RnonCO2[	393	]=	-0.4460677	;
    RnonCO2[	394	]=	-0.4460677	;
    RnonCO2[	395	]=	-0.4460677	;
    RnonCO2[	396	]=	-0.4460677	;
    RnonCO2[	397	]=	-0.4460677	;
    RnonCO2[	398	]=	-0.4460677	;
    RnonCO2[	399	]=	-0.4460677	;
    RnonCO2[	400	]=	-0.4460677	;
    RnonCO2[	401	]=	-0.4460677	;
    RnonCO2[	402	]=	-0.4460677	;
    RnonCO2[	403	]=	-0.4460677	;
    RnonCO2[	404	]=	-0.4460677	;
    RnonCO2[	405	]=	-0.4460677	;
    RnonCO2[	406	]=	-0.4460677	;
    RnonCO2[	407	]=	-0.4460677	;
    RnonCO2[	408	]=	-0.4460677	;
    RnonCO2[	409	]=	-0.4460677	;
    RnonCO2[	410	]=	-0.4460677	;
    RnonCO2[	411	]=	-0.4460677	;
    RnonCO2[	412	]=	-0.4460677	;
    RnonCO2[	413	]=	-0.4460677	;
    RnonCO2[	414	]=	-0.4460677	;
    RnonCO2[	415	]=	-0.4460677	;
    RnonCO2[	416	]=	-0.4460677	;
    RnonCO2[	417	]=	-0.4460677	;
    RnonCO2[	418	]=	-0.4460677	;
    RnonCO2[	419	]=	-0.4460677	;
    RnonCO2[	420	]=	-0.4460677	;
    RnonCO2[	421	]=	-0.4460677	;
    RnonCO2[	422	]=	-0.4460677	;
    RnonCO2[	423	]=	-0.4460677	;
    RnonCO2[	424	]=	-0.4460677	;
    RnonCO2[	425	]=	-0.4460677	;
    RnonCO2[	426	]=	-0.4460677	;
    RnonCO2[	427	]=	-0.4460677	;
    RnonCO2[	428	]=	-0.4460677	;
    RnonCO2[	429	]=	-0.4460677	;
    RnonCO2[	430	]=	-0.4460677	;
    RnonCO2[	431	]=	-0.4460677	;
    RnonCO2[	432	]=	-0.4460677	;
    RnonCO2[	433	]=	-0.4460677	;
    RnonCO2[	434	]=	-0.4460677	;
    RnonCO2[	435	]=	-0.4460677	;
    RnonCO2[	436	]=	-0.4460677	;
    RnonCO2[	437	]=	-0.4460677	;
    RnonCO2[	438	]=	-0.4460677	;
    RnonCO2[	439	]=	-0.4460677	;
    RnonCO2[	440	]=	-0.4460677	;
    RnonCO2[	441	]=	-0.4460677	;
    RnonCO2[	442	]=	-0.4460677	;
    RnonCO2[	443	]=	-0.4460677	;
    RnonCO2[	444	]=	-0.4460677	;
    RnonCO2[	445	]=	-0.4460677	;
    RnonCO2[	446	]=	-0.4460677	;
    RnonCO2[	447	]=	-0.4460677	;
    RnonCO2[	448	]=	-0.4460677	;
    RnonCO2[	449	]=	-0.4460677	;
    RnonCO2[	450	]=	-0.4460677	;
    RnonCO2[	451	]=	-0.4460677	;
    RnonCO2[	452	]=	-0.4460677	;
    RnonCO2[	453	]=	-0.4460677	;
    RnonCO2[	454	]=	-0.4460677	;
    RnonCO2[	455	]=	-0.4460677	;
    RnonCO2[	456	]=	-0.4460677	;
    RnonCO2[	457	]=	-0.4460677	;
    RnonCO2[	458	]=	-0.4460677	;
    RnonCO2[	459	]=	-0.4460677	;
    RnonCO2[	460	]=	-0.4460677	;
    RnonCO2[	461	]=	-0.4460677	;
    RnonCO2[	462	]=	-0.4460677	;
    RnonCO2[	463	]=	-0.4460677	;
    RnonCO2[	464	]=	-0.4460677	;
    RnonCO2[	465	]=	-0.4460677	;
    RnonCO2[	466	]=	-0.4460677	;
    RnonCO2[	467	]=	-0.4460677	;
    RnonCO2[	468	]=	-0.4460677	;
    RnonCO2[	469	]=	-0.4460677	;
    RnonCO2[	470	]=	-0.4460677	;
    RnonCO2[	471	]=	-0.4460677	;
    RnonCO2[	472	]=	-0.4460677	;
    RnonCO2[	473	]=	-0.4460677	;
    RnonCO2[	474	]=	-0.4460677	;
    RnonCO2[	475	]=	-0.4460677	;
    RnonCO2[	476	]=	-0.4460677	;
    RnonCO2[	477	]=	-0.4460677	;
    RnonCO2[	478	]=	-0.4460677	;
    RnonCO2[	479	]=	-0.4460677	;
    RnonCO2[	480	]=	-0.4460677	;
    RnonCO2[	481	]=	-0.4460677	;
    RnonCO2[	482	]=	-0.4460677	;
    RnonCO2[	483	]=	-0.4460677	;
    RnonCO2[	484	]=	-0.4460677	;
    RnonCO2[	485	]=	-0.4460677	;
    RnonCO2[	486	]=	-0.4460677	;
    RnonCO2[	487	]=	-0.4460677	;
    RnonCO2[	488	]=	-0.4460677	;
    RnonCO2[	489	]=	-0.4460677	;
    RnonCO2[	490	]=	-0.4460677	;
    RnonCO2[	491	]=	-0.4460677	;
    RnonCO2[	492	]=	-0.4460677	;
    RnonCO2[	493	]=	-0.4460677	;
    RnonCO2[	494	]=	-0.4460677	;
    RnonCO2[	495	]=	-0.4460677	;
    RnonCO2[	496	]=	-0.4460677	;
    RnonCO2[	497	]=	-0.4460677	;
    RnonCO2[	498	]=	-0.4460677	;
    RnonCO2[	499	]=	-0.4460677	;
    RnonCO2[	500	]=	-0.4460677	;
    RnonCO2[	501	]=	-0.4460677	;
    RnonCO2[	502	]=	-0.4460677	;
    RnonCO2[	503	]=	-0.4460677	;
    RnonCO2[	504	]=	-0.4460677	;
    RnonCO2[	505	]=	-0.4460677	;
    RnonCO2[	506	]=	-0.4460677	;
    RnonCO2[	507	]=	-0.4460677	;
    RnonCO2[	508	]=	-0.4460677	;
    RnonCO2[	509	]=	-0.4460677	;
    RnonCO2[	510	]=	-0.4460677	;
    RnonCO2[	511	]=	-0.4460677	;
    RnonCO2[	512	]=	-0.4460677	;
    RnonCO2[	513	]=	-0.4460677	;
    RnonCO2[	514	]=	-0.4460677	;
    RnonCO2[	515	]=	-0.4460677	;
    RnonCO2[	516	]=	-0.4460677	;
    RnonCO2[	517	]=	-0.4460677	;
    RnonCO2[	518	]=	-0.4460677	;
    RnonCO2[	519	]=	-0.4460677	;
    RnonCO2[	520	]=	-0.4460677	;
    RnonCO2[	521	]=	-0.4460677	;
    RnonCO2[	522	]=	-0.4460677	;
    RnonCO2[	523	]=	-0.4460677	;
    RnonCO2[	524	]=	-0.4460677	;
    RnonCO2[	525	]=	-0.4460677	;
    RnonCO2[	526	]=	-0.4460677	;
    RnonCO2[	527	]=	-0.4460677	;
    RnonCO2[	528	]=	-0.4460677	;
    RnonCO2[	529	]=	-0.4460677	;
    RnonCO2[	530	]=	-0.4460677	;
    RnonCO2[	531	]=	-0.4460677	;
    RnonCO2[	532	]=	-0.4460677	;
    RnonCO2[	533	]=	-0.4460677	;
    RnonCO2[	534	]=	-0.4460677	;
    RnonCO2[	535	]=	-0.4460677	;
    RnonCO2[	536	]=	-0.4460677	;
    RnonCO2[	537	]=	-0.4460677	;
    RnonCO2[	538	]=	-0.4460677	;
    RnonCO2[	539	]=	-0.4460677	;
    RnonCO2[	540	]=	-0.4460677	;
    RnonCO2[	541	]=	-0.4460677	;
    RnonCO2[	542	]=	-0.4460677	;
    RnonCO2[	543	]=	-0.4460677	;
    RnonCO2[	544	]=	-0.4460677	;
    RnonCO2[	545	]=	-0.4460677	;
    RnonCO2[	546	]=	-0.4460677	;
    RnonCO2[	547	]=	-0.4460677	;
    RnonCO2[	548	]=	-0.4460677	;
    RnonCO2[	549	]=	-0.4460677	;
    RnonCO2[	550	]=	-0.4460677	;
    RnonCO2[	551	]=	-0.4460677	;
    RnonCO2[	552	]=	-0.4460677	;
    RnonCO2[	553	]=	-0.4460677	;
    RnonCO2[	554	]=	-0.4460677	;
    RnonCO2[	555	]=	-0.4460677	;
    RnonCO2[	556	]=	-0.4460677	;
    RnonCO2[	557	]=	-0.4460677	;
    RnonCO2[	558	]=	-0.4460677	;
    RnonCO2[	559	]=	-0.4460677	;
    RnonCO2[	560	]=	-0.4460677	;
    RnonCO2[	561	]=	-0.4460677	;
    RnonCO2[	562	]=	-0.4460677	;
    RnonCO2[	563	]=	-0.4460677	;
    RnonCO2[	564	]=	-0.4460677	;
    RnonCO2[	565	]=	-0.4460677	;
    RnonCO2[	566	]=	-0.4460677	;
    RnonCO2[	567	]=	-0.4460677	;
    RnonCO2[	568	]=	-0.4460677	;
    RnonCO2[	569	]=	-0.4460677	;
    RnonCO2[	570	]=	-0.4460677	;
    RnonCO2[	571	]=	-0.4460677	;
    RnonCO2[	572	]=	-0.4460677	;
    RnonCO2[	573	]=	-0.4460677	;
    RnonCO2[	574	]=	-0.4460677	;
    RnonCO2[	575	]=	-0.4460677	;
    RnonCO2[	576	]=	-0.4460677	;
    RnonCO2[	577	]=	-0.4460677	;
    RnonCO2[	578	]=	-0.4460677	;
    RnonCO2[	579	]=	-0.4460677	;
    RnonCO2[	580	]=	-0.4460677	;
    RnonCO2[	581	]=	-0.4460677	;
    RnonCO2[	582	]=	-0.4460677	;
    RnonCO2[	583	]=	-0.4460677	;
    RnonCO2[	584	]=	-0.4460677	;
    RnonCO2[	585	]=	-0.4460677	;
    RnonCO2[	586	]=	-0.4460677	;
    RnonCO2[	587	]=	-0.4460677	;
    RnonCO2[	588	]=	-0.4460677	;
    RnonCO2[	589	]=	-0.4460677	;
    RnonCO2[	590	]=	-0.4460677	;
    RnonCO2[	591	]=	-0.4460677	;
    RnonCO2[	592	]=	-0.4460677	;
    RnonCO2[	593	]=	-0.4460677	;
    RnonCO2[	594	]=	-0.4460677	;
    RnonCO2[	595	]=	-0.4460677	;
    RnonCO2[	596	]=	-0.4460677	;
    RnonCO2[	597	]=	-0.4460677	;
    RnonCO2[	598	]=	-0.4460677	;
    RnonCO2[	599	]=	-0.4460677	;
    RnonCO2[	600	]=	-0.4460677	;
    RnonCO2[	601	]=	-0.4460677	;
    RnonCO2[	602	]=	-0.4460677	;
    RnonCO2[	603	]=	-0.4460677	;
    RnonCO2[	604	]=	-0.4460677	;
    RnonCO2[	605	]=	-0.4460677	;
    RnonCO2[	606	]=	-0.4460677	;
    RnonCO2[	607	]=	-0.4460677	;
    RnonCO2[	608	]=	-0.4460677	;
    RnonCO2[	609	]=	-0.4460677	;
    RnonCO2[	610	]=	-0.4460677	;
    RnonCO2[	611	]=	-0.4460677	;
    RnonCO2[	612	]=	-0.4460677	;
    RnonCO2[	613	]=	-0.4460677	;
    RnonCO2[	614	]=	-0.4460677	;
    RnonCO2[	615	]=	-0.4460677	;
    RnonCO2[	616	]=	-0.4460677	;
    RnonCO2[	617	]=	-0.4460677	;
    RnonCO2[	618	]=	-0.4460677	;
    RnonCO2[	619	]=	-0.4460677	;
    RnonCO2[	620	]=	-0.4460677	;
    RnonCO2[	621	]=	-0.4460677	;
    RnonCO2[	622	]=	-0.4460677	;
    RnonCO2[	623	]=	-0.4460677	;
    RnonCO2[	624	]=	-0.4460677	;
    RnonCO2[	625	]=	-0.4460677	;
    RnonCO2[	626	]=	-0.4460677	;
    RnonCO2[	627	]=	-0.4460677	;
    RnonCO2[	628	]=	-0.4460677	;
    RnonCO2[	629	]=	-0.4460677	;
    RnonCO2[	630	]=	-0.4460677	;
    RnonCO2[	631	]=	-0.4460677	;
    RnonCO2[	632	]=	-0.4460677	;
    RnonCO2[	633	]=	-0.4460677	;
    RnonCO2[	634	]=	-0.4460677	;
    RnonCO2[	635	]=	-0.4460677	;
    RnonCO2[	636	]=	-0.4460677	;
    RnonCO2[	637	]=	-0.4460677	;
    RnonCO2[	638	]=	-0.4460677	;
    RnonCO2[	639	]=	-0.4460677	;
    RnonCO2[	640	]=	-0.4460677	;
    RnonCO2[	641	]=	-0.4460677	;
    RnonCO2[	642	]=	-0.4460677	;
    RnonCO2[	643	]=	-0.4460677	;
    RnonCO2[	644	]=	-0.4460677	;
    RnonCO2[	645	]=	-0.4460677	;
    RnonCO2[	646	]=	-0.4460677	;
    RnonCO2[	647	]=	-0.4460677	;
    RnonCO2[	648	]=	-0.4460677	;
    RnonCO2[	649	]=	-0.4460677	;
    RnonCO2[	650	]=	-0.4460677	;
    RnonCO2[	651	]=	-0.4460677	;
    RnonCO2[	652	]=	-0.4460677	;
    RnonCO2[	653	]=	-0.4460677	;
    RnonCO2[	654	]=	-0.4460677	;
    RnonCO2[	655	]=	-0.4460677	;
    RnonCO2[	656	]=	-0.4460677	;
    RnonCO2[	657	]=	-0.4460677	;
    RnonCO2[	658	]=	-0.4460677	;
    RnonCO2[	659	]=	-0.4460677	;
    RnonCO2[	660	]=	-0.4460677	;
    RnonCO2[	661	]=	-0.4460677	;
    RnonCO2[	662	]=	-0.4460677	;
    RnonCO2[	663	]=	-0.4460677	;
    RnonCO2[	664	]=	-0.4460677	;
    RnonCO2[	665	]=	-0.4460677	;
    RnonCO2[	666	]=	-0.4460677	;
    RnonCO2[	667	]=	-0.4460677	;
    RnonCO2[	668	]=	-0.4460677	;
    RnonCO2[	669	]=	-0.4460677	;
    RnonCO2[	670	]=	-0.4460677	;
    RnonCO2[	671	]=	-0.4460677	;
    RnonCO2[	672	]=	-0.4460677	;
    RnonCO2[	673	]=	-0.4460677	;
    RnonCO2[	674	]=	-0.4460677	;
    RnonCO2[	675	]=	-0.4460677	;
    RnonCO2[	676	]=	-0.4460677	;
    RnonCO2[	677	]=	-0.4460677	;
    RnonCO2[	678	]=	-0.4460677	;
    RnonCO2[	679	]=	-0.4460677	;
    RnonCO2[	680	]=	-0.4460677	;
    RnonCO2[	681	]=	-0.4460677	;
    RnonCO2[	682	]=	-0.4460677	;
    RnonCO2[	683	]=	-0.4460677	;
    RnonCO2[	684	]=	-0.4460677	;
    RnonCO2[	685	]=	-0.4460677	;
    RnonCO2[	686	]=	-0.4460677	;
    RnonCO2[	687	]=	-0.4460677	;
    RnonCO2[	688	]=	-0.4460677	;
    RnonCO2[	689	]=	-0.4460677	;
    RnonCO2[	690	]=	-0.4460677	;
    RnonCO2[	691	]=	-0.4460677	;
    RnonCO2[	692	]=	-0.4460677	;
    RnonCO2[	693	]=	-0.4460677	;
    RnonCO2[	694	]=	-0.4460677	;
    RnonCO2[	695	]=	-0.4460677	;
    RnonCO2[	696	]=	-0.4460677	;
    RnonCO2[	697	]=	-0.4460677	;
    RnonCO2[	698	]=	-0.4460677	;
    RnonCO2[	699	]=	-0.4460677	;
    RnonCO2[	700	]=	-0.4460677	;
    RnonCO2[	701	]=	-0.4460677	;
    RnonCO2[	702	]=	-0.4460677	;
    RnonCO2[	703	]=	-0.4460677	;
    RnonCO2[	704	]=	-0.4460677	;
    RnonCO2[	705	]=	-0.4460677	;
    RnonCO2[	706	]=	-0.4460677	;
    RnonCO2[	707	]=	-0.4460677	;
    RnonCO2[	708	]=	-0.4460677	;
    RnonCO2[	709	]=	-0.4460677	;
    RnonCO2[	710	]=	-0.4460677	;
    RnonCO2[	711	]=	-0.4460677	;
    RnonCO2[	712	]=	-0.4460677	;
    RnonCO2[	713	]=	-0.4460677	;
    RnonCO2[	714	]=	-0.4460677	;
    RnonCO2[	715	]=	-0.4460677	;
    RnonCO2[	716	]=	-0.4460677	;
    RnonCO2[	717	]=	-0.4460677	;
    RnonCO2[	718	]=	-0.4460677	;
    RnonCO2[	719	]=	-0.4460677	;
    RnonCO2[	720	]=	-0.4460677	;
    RnonCO2[	721	]=	-0.4460677	;
    RnonCO2[	722	]=	-0.4460677	;
    RnonCO2[	723	]=	-0.4460677	;
    RnonCO2[	724	]=	-0.4460677	;
    RnonCO2[	725	]=	-0.4460677	;
    RnonCO2[	726	]=	-0.4460677	;
    RnonCO2[	727	]=	-0.4460677	;
    RnonCO2[	728	]=	-0.4460677	;
    RnonCO2[	729	]=	-0.4460677	;
    RnonCO2[	730	]=	-0.4460677	;
    RnonCO2[	731	]=	-0.4460677	;
    RnonCO2[	732	]=	-0.4460677	;
    RnonCO2[	733	]=	-0.4460677	;
    RnonCO2[	734	]=	-0.4460677	;
    RnonCO2[	735	]=	-0.4460677	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_aerosol_RCP45(void)
{
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.000955298	;
    RnonCO2[	2	]=	0.001424721	;
    RnonCO2[	3	]=	0.0001974	;
    RnonCO2[	4	]=	-0.001278437	;
    RnonCO2[	5	]=	-0.002733841	;
    RnonCO2[	6	]=	-0.004541334	;
    RnonCO2[	7	]=	-0.00632004	;
    RnonCO2[	8	]=	-0.007680948	;
    RnonCO2[	9	]=	-0.008994568	;
    RnonCO2[	10	]=	-0.010260775	;
    RnonCO2[	11	]=	-0.011479866	;
    RnonCO2[	12	]=	-0.012652425	;
    RnonCO2[	13	]=	-0.013779231	;
    RnonCO2[	14	]=	-0.014861204	;
    RnonCO2[	15	]=	-0.015900176	;
    RnonCO2[	16	]=	-0.017335746	;
    RnonCO2[	17	]=	-0.01873479	;
    RnonCO2[	18	]=	-0.019659073	;
    RnonCO2[	19	]=	-0.020540613	;
    RnonCO2[	20	]=	-0.02137714	;
    RnonCO2[	21	]=	-0.022166399	;
    RnonCO2[	22	]=	-0.022906132	;
    RnonCO2[	23	]=	-0.023594082	;
    RnonCO2[	24	]=	-0.024227995	;
    RnonCO2[	25	]=	-0.024806236	;
    RnonCO2[	26	]=	-0.025775743	;
    RnonCO2[	27	]=	-0.026691982	;
    RnonCO2[	28	]=	-0.027110281	;
    RnonCO2[	29	]=	-0.02747885	;
    RnonCO2[	30	]=	-0.027799526	;
    RnonCO2[	31	]=	-0.028074106	;
    RnonCO2[	32	]=	-0.02875039	;
    RnonCO2[	33	]=	-0.029383792	;
    RnonCO2[	34	]=	-0.02953002	;
    RnonCO2[	35	]=	-0.03007996	;
    RnonCO2[	36	]=	-0.03058546	;
    RnonCO2[	37	]=	-0.03148571	;
    RnonCO2[	38	]=	-0.03189741	;
    RnonCO2[	39	]=	-0.03138062	;
    RnonCO2[	40	]=	-0.03126848	;
    RnonCO2[	41	]=	-0.03156144	;
    RnonCO2[	42	]=	-0.03182181	;
    RnonCO2[	43	]=	-0.03161267	;
    RnonCO2[	44	]=	-0.03137821	;
    RnonCO2[	45	]=	-0.03112038	;
    RnonCO2[	46	]=	-0.03127367	;
    RnonCO2[	47	]=	-0.0313998	;
    RnonCO2[	48	]=	-0.03106322	;
    RnonCO2[	49	]=	-0.03070135	;
    RnonCO2[	50	]=	-0.03074616	;
    RnonCO2[	51	]=	-0.03119614	;
    RnonCO2[	52	]=	-0.03161872	;
    RnonCO2[	53	]=	-0.03158785	;
    RnonCO2[	54	]=	-0.03110696	;
    RnonCO2[	55	]=	-0.03060634	;
    RnonCO2[	56	]=	-0.0300866	;
    RnonCO2[	57	]=	-0.02996996	;
    RnonCO2[	58	]=	-0.03025404	;
    RnonCO2[	59	]=	-0.03009594	;
    RnonCO2[	60	]=	-0.02991636	;
    RnonCO2[	61	]=	-0.02971869	;
    RnonCO2[	62	]=	-0.02950042	;
    RnonCO2[	63	]=	-0.02926502	;
    RnonCO2[	64	]=	-0.02859871	;
    RnonCO2[	65	]=	-0.03037359	;
    RnonCO2[	66	]=	-0.03172034	;
    RnonCO2[	67	]=	-0.03059392	;
    RnonCO2[	68	]=	-0.03026959	;
    RnonCO2[	69	]=	-0.02993194	;
    RnonCO2[	70	]=	-0.02957653	;
    RnonCO2[	71	]=	-0.03080027	;
    RnonCO2[	72	]=	-0.03160022	;
    RnonCO2[	73	]=	-0.03117789	;
    RnonCO2[	74	]=	-0.03112982	;
    RnonCO2[	75	]=	-0.03144654	;
    RnonCO2[	76	]=	-0.03173222	;
    RnonCO2[	77	]=	-0.03198224	;
    RnonCO2[	78	]=	-0.03220368	;
    RnonCO2[	79	]=	-0.03239696	;
    RnonCO2[	80	]=	-0.03371239	;
    RnonCO2[	81	]=	-0.03424533	;
    RnonCO2[	82	]=	-0.0343764	;
    RnonCO2[	83	]=	-0.03487942	;
    RnonCO2[	84	]=	-0.03536957	;
    RnonCO2[	85	]=	-0.03686306	;
    RnonCO2[	86	]=	-0.03665392	;
    RnonCO2[	87	]=	-0.04248424	;
    RnonCO2[	88	]=	-0.04930444	;
    RnonCO2[	89	]=	-0.05182621	;
    RnonCO2[	90	]=	-0.0542671	;
    RnonCO2[	91	]=	-0.05573158	;
    RnonCO2[	92	]=	-0.05765815	;
    RnonCO2[	93	]=	-0.05821397	;
    RnonCO2[	94	]=	-0.06005825	;
    RnonCO2[	95	]=	-0.0683501	;
    RnonCO2[	96	]=	-0.08104112	;
    RnonCO2[	97	]=	-0.07832852	;
    RnonCO2[	98	]=	-0.07177024	;
    RnonCO2[	99	]=	-0.07363036	;
    RnonCO2[	100	]=	-0.07696442	;
    RnonCO2[	101	]=	-0.08462429	;
    RnonCO2[	102	]=	-0.09275025	;
    RnonCO2[	103	]=	-0.09511911	;
    RnonCO2[	104	]=	-0.0930339	;
    RnonCO2[	105	]=	-0.09237765	;
    RnonCO2[	106	]=	-0.10165608	;
    RnonCO2[	107	]=	-0.12466661	;
    RnonCO2[	108	]=	-0.14405058	;
    RnonCO2[	109	]=	-0.14773339	;
    RnonCO2[	110	]=	-0.14777672	;
    RnonCO2[	111	]=	-0.1470811	;
    RnonCO2[	112	]=	-0.14255587	;
    RnonCO2[	113	]=	-0.14024698	;
    RnonCO2[	114	]=	-0.14393886	;
    RnonCO2[	115	]=	-0.15612866	;
    RnonCO2[	116	]=	-0.164782	;
    RnonCO2[	117	]=	-0.16302445	;
    RnonCO2[	118	]=	-0.16326054	;
    RnonCO2[	119	]=	-0.16496204	;
    RnonCO2[	120	]=	-0.16272157	;
    RnonCO2[	121	]=	-0.1612244	;
    RnonCO2[	122	]=	-0.16356025	;
    RnonCO2[	123	]=	-0.17242315	;
    RnonCO2[	124	]=	-0.17632405	;
    RnonCO2[	125	]=	-0.17855867	;
    RnonCO2[	126	]=	-0.18527891	;
    RnonCO2[	127	]=	-0.18997972	;
    RnonCO2[	128	]=	-0.1933518	;
    RnonCO2[	129	]=	-0.19699663	;
    RnonCO2[	130	]=	-0.20233059	;
    RnonCO2[	131	]=	-0.2051441	;
    RnonCO2[	132	]=	-0.20577589	;
    RnonCO2[	133	]=	-0.20720143	;
    RnonCO2[	134	]=	-0.21030464	;
    RnonCO2[	135	]=	-0.21375193	;
    RnonCO2[	136	]=	-0.22004069	;
    RnonCO2[	137	]=	-0.22693377	;
    RnonCO2[	138	]=	-0.23402972	;
    RnonCO2[	139	]=	-0.2411565	;
    RnonCO2[	140	]=	-0.2471181	;
    RnonCO2[	141	]=	-0.255172	;
    RnonCO2[	142	]=	-0.26315304	;
    RnonCO2[	143	]=	-0.2636557	;
    RnonCO2[	144	]=	-0.26151664	;
    RnonCO2[	145	]=	-0.26499499	;
    RnonCO2[	146	]=	-0.26461175	;
    RnonCO2[	147	]=	-0.26044407	;
    RnonCO2[	148	]=	-0.25940869	;
    RnonCO2[	149	]=	-0.25560119	;
    RnonCO2[	150	]=	-0.25007798	;
    RnonCO2[	151	]=	-0.25106379	;
    RnonCO2[	152	]=	-0.25437609	;
    RnonCO2[	153	]=	-0.25544669	;
    RnonCO2[	154	]=	-0.2505011	;
    RnonCO2[	155	]=	-0.24919556	;
    RnonCO2[	156	]=	-0.24766564	;
    RnonCO2[	157	]=	-0.24454174	;
    RnonCO2[	158	]=	-0.25504195	;
    RnonCO2[	159	]=	-0.26312341	;
    RnonCO2[	160	]=	-0.26314088	;
    RnonCO2[	161	]=	-0.26376161	;
    RnonCO2[	162	]=	-0.26809378	;
    RnonCO2[	163	]=	-0.27284291	;
    RnonCO2[	164	]=	-0.27584022	;
    RnonCO2[	165	]=	-0.27557411	;
    RnonCO2[	166	]=	-0.26967283	;
    RnonCO2[	167	]=	-0.26315755	;
    RnonCO2[	168	]=	-0.26083606	;
    RnonCO2[	169	]=	-0.26325195	;
    RnonCO2[	170	]=	-0.2652416	;
    RnonCO2[	171	]=	-0.26824619	;
    RnonCO2[	172	]=	-0.26930622	;
    RnonCO2[	173	]=	-0.26149511	;
    RnonCO2[	174	]=	-0.25651091	;
    RnonCO2[	175	]=	-0.26035065	;
    RnonCO2[	176	]=	-0.26656695	;
    RnonCO2[	177	]=	-0.27194936	;
    RnonCO2[	178	]=	-0.274817	;
    RnonCO2[	179	]=	-0.27878403	;
    RnonCO2[	180	]=	-0.28302569	;
    RnonCO2[	181	]=	-0.29104814	;
    RnonCO2[	182	]=	-0.30416561	;
    RnonCO2[	183	]=	-0.31716714	;
    RnonCO2[	184	]=	-0.3246442	;
    RnonCO2[	185	]=	-0.3327935	;
    RnonCO2[	186	]=	-0.35639494	;
    RnonCO2[	187	]=	-0.38051016	;
    RnonCO2[	188	]=	-0.39378465	;
    RnonCO2[	189	]=	-0.40659776	;
    RnonCO2[	190	]=	-0.4196919	;
    RnonCO2[	191	]=	-0.43302942	;
    RnonCO2[	192	]=	-0.44651364	;
    RnonCO2[	193	]=	-0.45569127	;
    RnonCO2[	194	]=	-0.45642498	;
    RnonCO2[	195	]=	-0.45551768	;
    RnonCO2[	196	]=	-0.47183293	;
    RnonCO2[	197	]=	-0.49188519	;
    RnonCO2[	198	]=	-0.50135461	;
    RnonCO2[	199	]=	-0.5101619	;
    RnonCO2[	200	]=	-0.51738459	;
    RnonCO2[	201	]=	-0.52416219	;
    RnonCO2[	202	]=	-0.53325402	;
    RnonCO2[	203	]=	-0.54124791	;
    RnonCO2[	204	]=	-0.54379714	;
    RnonCO2[	205	]=	-0.53664772	;
    RnonCO2[	206	]=	-0.52607217	;
    RnonCO2[	207	]=	-0.52739363	;
    RnonCO2[	208	]=	-0.53724776	;
    RnonCO2[	209	]=	-0.54779467	;
    RnonCO2[	210	]=	-0.55942351	;
    RnonCO2[	211	]=	-0.57578959	;
    RnonCO2[	212	]=	-0.5916702	;
    RnonCO2[	213	]=	-0.5979117	;
    RnonCO2[	214	]=	-0.6009881	;
    RnonCO2[	215	]=	-0.6131431	;
    RnonCO2[	216	]=	-0.6319195	;
    RnonCO2[	217	]=	-0.6542028	;
    RnonCO2[	218	]=	-0.6747946	;
    RnonCO2[	219	]=	-0.6865596	;
    RnonCO2[	220	]=	-0.6942006	;
    RnonCO2[	221	]=	-0.7018816	;
    RnonCO2[	222	]=	-0.7121991	;
    RnonCO2[	223	]=	-0.7210817	;
    RnonCO2[	224	]=	-0.7262596	;
    RnonCO2[	225	]=	-0.7299457	;
    RnonCO2[	226	]=	-0.7418714	;
    RnonCO2[	227	]=	-0.7583892	;
    RnonCO2[	228	]=	-0.7656833	;
    RnonCO2[	229	]=	-0.768847	;
    RnonCO2[	230	]=	-0.7655134	;
    RnonCO2[	231	]=	-0.7588829	;
    RnonCO2[	232	]=	-0.7657109	;
    RnonCO2[	233	]=	-0.7804313	;
    RnonCO2[	234	]=	-0.7902367	;
    RnonCO2[	235	]=	-0.8012413	;
    RnonCO2[	236	]=	-0.8096987	;
    RnonCO2[	237	]=	-0.8105819	;
    RnonCO2[	238	]=	-0.8112899	;
    RnonCO2[	239	]=	-0.8123564	;
    RnonCO2[	240	]=	-0.8108507	;
    RnonCO2[	241	]=	-0.8038388	;
    RnonCO2[	242	]=	-0.7949639	;
    RnonCO2[	243	]=	-0.7867463	;
    RnonCO2[	244	]=	-0.7782199	;
    RnonCO2[	245	]=	-0.7696101	;
    RnonCO2[	246	]=	-0.7611859	;
    RnonCO2[	247	]=	-0.7523398	;
    RnonCO2[	248	]=	-0.7432371	;
    RnonCO2[	249	]=	-0.7343269	;
    RnonCO2[	250	]=	-0.7253724	;
    RnonCO2[	251	]=	-0.7163378	;
    RnonCO2[	252	]=	-0.7072163	;
    RnonCO2[	253	]=	-0.698012	;
    RnonCO2[	254	]=	-0.6882828	;
    RnonCO2[	255	]=	-0.6789353	;
    RnonCO2[	256	]=	-0.6710819	;
    RnonCO2[	257	]=	-0.6634482	;
    RnonCO2[	258	]=	-0.6554378	;
    RnonCO2[	259	]=	-0.6474739	;
    RnonCO2[	260	]=	-0.6395458	;
    RnonCO2[	261	]=	-0.6316558	;
    RnonCO2[	262	]=	-0.6238013	;
    RnonCO2[	263	]=	-0.6159833	;
    RnonCO2[	264	]=	-0.6082026	;
    RnonCO2[	265	]=	-0.6001577	;
    RnonCO2[	266	]=	-0.5915484	;
    RnonCO2[	267	]=	-0.5830978	;
    RnonCO2[	268	]=	-0.575125	;
    RnonCO2[	269	]=	-0.5672197	;
    RnonCO2[	270	]=	-0.5593621	;
    RnonCO2[	271	]=	-0.5515396	;
    RnonCO2[	272	]=	-0.5437488	;
    RnonCO2[	273	]=	-0.5359863	;
    RnonCO2[	274	]=	-0.5282529	;
    RnonCO2[	275	]=	-0.5202403	;
    RnonCO2[	276	]=	-0.5116363	;
    RnonCO2[	277	]=	-0.5031575	;
    RnonCO2[	278	]=	-0.4951399	;
    RnonCO2[	279	]=	-0.4871949	;
    RnonCO2[	280	]=	-0.4793139	;
    RnonCO2[	281	]=	-0.4714904	;
    RnonCO2[	282	]=	-0.4637225	;
    RnonCO2[	283	]=	-0.4560139	;
    RnonCO2[	284	]=	-0.4483667	;
    RnonCO2[	285	]=	-0.4418114	;
    RnonCO2[	286	]=	-0.4373793	;
    RnonCO2[	287	]=	-0.4340576	;
    RnonCO2[	288	]=	-0.4307923	;
    RnonCO2[	289	]=	-0.4275505	;
    RnonCO2[	290	]=	-0.4243342	;
    RnonCO2[	291	]=	-0.4211294	;
    RnonCO2[	292	]=	-0.4179249	;
    RnonCO2[	293	]=	-0.4147107	;
    RnonCO2[	294	]=	-0.4114766	;
    RnonCO2[	295	]=	-0.4084679	;
    RnonCO2[	296	]=	-0.4059352	;
    RnonCO2[	297	]=	-0.403637	;
    RnonCO2[	298	]=	-0.4013333	;
    RnonCO2[	299	]=	-0.399025	;
    RnonCO2[	300	]=	-0.39672	;
    RnonCO2[	301	]=	-0.3944212	;
    RnonCO2[	302	]=	-0.3921159	;
    RnonCO2[	303	]=	-0.3897938	;
    RnonCO2[	304	]=	-0.3874458	;
    RnonCO2[	305	]=	-0.3853167	;
    RnonCO2[	306	]=	-0.3836585	;
    RnonCO2[	307	]=	-0.382227	;
    RnonCO2[	308	]=	-0.3807793	;
    RnonCO2[	309	]=	-0.3793168	;
    RnonCO2[	310	]=	-0.3778368	;
    RnonCO2[	311	]=	-0.3763473	;
    RnonCO2[	312	]=	-0.3748516	;
    RnonCO2[	313	]=	-0.3733347	;
    RnonCO2[	314	]=	-0.3717663	;
    RnonCO2[	315	]=	-0.3711127	;
    RnonCO2[	316	]=	-0.3723784	;
    RnonCO2[	317	]=	-0.3738112	;
    RnonCO2[	318	]=	-0.3744043	;
    RnonCO2[	319	]=	-0.3749248	;
    RnonCO2[	320	]=	-0.375382	;
    RnonCO2[	321	]=	-0.3757837	;
    RnonCO2[	322	]=	-0.3761478	;
    RnonCO2[	323	]=	-0.3764863	;
    RnonCO2[	324	]=	-0.3767948	;
    RnonCO2[	325	]=	-0.3770756	;
    RnonCO2[	326	]=	-0.3773313	;
    RnonCO2[	327	]=	-0.377555	;
    RnonCO2[	328	]=	-0.3777453	;
    RnonCO2[	329	]=	-0.3779096	;
    RnonCO2[	330	]=	-0.3780531	;
    RnonCO2[	331	]=	-0.3781791	;
    RnonCO2[	332	]=	-0.3782905	;
    RnonCO2[	333	]=	-0.3784007	;
    RnonCO2[	334	]=	-0.3785174	;
    RnonCO2[	335	]=	-0.3788718	;
    RnonCO2[	336	]=	-0.3796964	;
    RnonCO2[	337	]=	-0.3805122	;
    RnonCO2[	338	]=	-0.3810503	;
    RnonCO2[	339	]=	-0.3815251	;
    RnonCO2[	340	]=	-0.3819464	;
    RnonCO2[	341	]=	-0.3823224	;
    RnonCO2[	342	]=	-0.3826584	;
    RnonCO2[	343	]=	-0.3829595	;
    RnonCO2[	344	]=	-0.3832407	;
    RnonCO2[	345	]=	-0.3835115	;
    RnonCO2[	346	]=	-0.3837653	;
    RnonCO2[	347	]=	-0.3839978	;
    RnonCO2[	348	]=	-0.3842056	;
    RnonCO2[	349	]=	-0.3843847	;
    RnonCO2[	350	]=	-0.3845373	;
    RnonCO2[	351	]=	-0.384669	;
    RnonCO2[	352	]=	-0.3847842	;
    RnonCO2[	353	]=	-0.3848851	;
    RnonCO2[	354	]=	-0.3849739	;
    RnonCO2[	355	]=	-0.3850633	;
    RnonCO2[	356	]=	-0.3851609	;
    RnonCO2[	357	]=	-0.3852587	;
    RnonCO2[	358	]=	-0.3853504	;
    RnonCO2[	359	]=	-0.3854312	;
    RnonCO2[	360	]=	-0.3854929	;
    RnonCO2[	361	]=	-0.3855371	;
    RnonCO2[	362	]=	-0.3855717	;
    RnonCO2[	363	]=	-0.3856003	;
    RnonCO2[	364	]=	-0.3856241	;
    RnonCO2[	365	]=	-0.3856445	;
    RnonCO2[	366	]=	-0.3856732	;
    RnonCO2[	367	]=	-0.3857168	;
    RnonCO2[	368	]=	-0.3857662	;
    RnonCO2[	369	]=	-0.3858148	;
    RnonCO2[	370	]=	-0.3858573	;
    RnonCO2[	371	]=	-0.3858879	;
    RnonCO2[	372	]=	-0.3859072	;
    RnonCO2[	373	]=	-0.3859195	;
    RnonCO2[	374	]=	-0.3859278	;
    RnonCO2[	375	]=	-0.3859334	;
    RnonCO2[	376	]=	-0.3859374	;
    RnonCO2[	377	]=	-0.3859512	;
    RnonCO2[	378	]=	-0.3859812	;
    RnonCO2[	379	]=	-0.3860183	;
    RnonCO2[	380	]=	-0.3860556	;
    RnonCO2[	381	]=	-0.3860878	;
    RnonCO2[	382	]=	-0.3861089	;
    RnonCO2[	383	]=	-0.3861194	;
    RnonCO2[	384	]=	-0.3861236	;
    RnonCO2[	385	]=	-0.3861246	;
    RnonCO2[	386	]=	-0.3861246	;
    RnonCO2[	387	]=	-0.3861246	;
    RnonCO2[	388	]=	-0.3861246	;
    RnonCO2[	389	]=	-0.3861246	;
    RnonCO2[	390	]=	-0.3861246	;
    RnonCO2[	391	]=	-0.3861246	;
    RnonCO2[	392	]=	-0.3861246	;
    RnonCO2[	393	]=	-0.3861246	;
    RnonCO2[	394	]=	-0.3861246	;
    RnonCO2[	395	]=	-0.3861246	;
    RnonCO2[	396	]=	-0.3861246	;
    RnonCO2[	397	]=	-0.3861246	;
    RnonCO2[	398	]=	-0.3861246	;
    RnonCO2[	399	]=	-0.3861246	;
    RnonCO2[	400	]=	-0.3861246	;
    RnonCO2[	401	]=	-0.3861246	;
    RnonCO2[	402	]=	-0.3861246	;
    RnonCO2[	403	]=	-0.3861246	;
    RnonCO2[	404	]=	-0.3861246	;
    RnonCO2[	405	]=	-0.3861246	;
    RnonCO2[	406	]=	-0.3861246	;
    RnonCO2[	407	]=	-0.3861246	;
    RnonCO2[	408	]=	-0.3861246	;
    RnonCO2[	409	]=	-0.3861246	;
    RnonCO2[	410	]=	-0.3861246	;
    RnonCO2[	411	]=	-0.3861246	;
    RnonCO2[	412	]=	-0.3861246	;
    RnonCO2[	413	]=	-0.3861246	;
    RnonCO2[	414	]=	-0.3861246	;
    RnonCO2[	415	]=	-0.3861246	;
    RnonCO2[	416	]=	-0.3861246	;
    RnonCO2[	417	]=	-0.3861246	;
    RnonCO2[	418	]=	-0.3861246	;
    RnonCO2[	419	]=	-0.3861246	;
    RnonCO2[	420	]=	-0.3861246	;
    RnonCO2[	421	]=	-0.3861246	;
    RnonCO2[	422	]=	-0.3861246	;
    RnonCO2[	423	]=	-0.3861246	;
    RnonCO2[	424	]=	-0.3861246	;
    RnonCO2[	425	]=	-0.3861246	;
    RnonCO2[	426	]=	-0.3861246	;
    RnonCO2[	427	]=	-0.3861246	;
    RnonCO2[	428	]=	-0.3861246	;
    RnonCO2[	429	]=	-0.3861246	;
    RnonCO2[	430	]=	-0.3861246	;
    RnonCO2[	431	]=	-0.3861246	;
    RnonCO2[	432	]=	-0.3861246	;
    RnonCO2[	433	]=	-0.3861246	;
    RnonCO2[	434	]=	-0.3861246	;
    RnonCO2[	435	]=	-0.3861246	;
    RnonCO2[	436	]=	-0.3861246	;
    RnonCO2[	437	]=	-0.3861246	;
    RnonCO2[	438	]=	-0.3861246	;
    RnonCO2[	439	]=	-0.3861246	;
    RnonCO2[	440	]=	-0.3861246	;
    RnonCO2[	441	]=	-0.3861246	;
    RnonCO2[	442	]=	-0.3861246	;
    RnonCO2[	443	]=	-0.3861246	;
    RnonCO2[	444	]=	-0.3861246	;
    RnonCO2[	445	]=	-0.3861246	;
    RnonCO2[	446	]=	-0.3861246	;
    RnonCO2[	447	]=	-0.3861246	;
    RnonCO2[	448	]=	-0.3861246	;
    RnonCO2[	449	]=	-0.3861246	;
    RnonCO2[	450	]=	-0.3861246	;
    RnonCO2[	451	]=	-0.3861246	;
    RnonCO2[	452	]=	-0.3861246	;
    RnonCO2[	453	]=	-0.3861246	;
    RnonCO2[	454	]=	-0.3861246	;
    RnonCO2[	455	]=	-0.3861246	;
    RnonCO2[	456	]=	-0.3861246	;
    RnonCO2[	457	]=	-0.3861246	;
    RnonCO2[	458	]=	-0.3861246	;
    RnonCO2[	459	]=	-0.3861246	;
    RnonCO2[	460	]=	-0.3861246	;
    RnonCO2[	461	]=	-0.3861246	;
    RnonCO2[	462	]=	-0.3861246	;
    RnonCO2[	463	]=	-0.3861246	;
    RnonCO2[	464	]=	-0.3861246	;
    RnonCO2[	465	]=	-0.3861246	;
    RnonCO2[	466	]=	-0.3861246	;
    RnonCO2[	467	]=	-0.3861246	;
    RnonCO2[	468	]=	-0.3861246	;
    RnonCO2[	469	]=	-0.3861246	;
    RnonCO2[	470	]=	-0.3861246	;
    RnonCO2[	471	]=	-0.3861246	;
    RnonCO2[	472	]=	-0.3861246	;
    RnonCO2[	473	]=	-0.3861246	;
    RnonCO2[	474	]=	-0.3861246	;
    RnonCO2[	475	]=	-0.3861246	;
    RnonCO2[	476	]=	-0.3861246	;
    RnonCO2[	477	]=	-0.3861246	;
    RnonCO2[	478	]=	-0.3861246	;
    RnonCO2[	479	]=	-0.3861246	;
    RnonCO2[	480	]=	-0.3861246	;
    RnonCO2[	481	]=	-0.3861246	;
    RnonCO2[	482	]=	-0.3861246	;
    RnonCO2[	483	]=	-0.3861246	;
    RnonCO2[	484	]=	-0.3861246	;
    RnonCO2[	485	]=	-0.3861246	;
    RnonCO2[	486	]=	-0.3861246	;
    RnonCO2[	487	]=	-0.3861246	;
    RnonCO2[	488	]=	-0.3861246	;
    RnonCO2[	489	]=	-0.3861246	;
    RnonCO2[	490	]=	-0.3861246	;
    RnonCO2[	491	]=	-0.3861246	;
    RnonCO2[	492	]=	-0.3861246	;
    RnonCO2[	493	]=	-0.3861246	;
    RnonCO2[	494	]=	-0.3861246	;
    RnonCO2[	495	]=	-0.3861246	;
    RnonCO2[	496	]=	-0.3861246	;
    RnonCO2[	497	]=	-0.3861246	;
    RnonCO2[	498	]=	-0.3861246	;
    RnonCO2[	499	]=	-0.3861246	;
    RnonCO2[	500	]=	-0.3861246	;
    RnonCO2[	501	]=	-0.3861246	;
    RnonCO2[	502	]=	-0.3861246	;
    RnonCO2[	503	]=	-0.3861246	;
    RnonCO2[	504	]=	-0.3861246	;
    RnonCO2[	505	]=	-0.3861246	;
    RnonCO2[	506	]=	-0.3861246	;
    RnonCO2[	507	]=	-0.3861246	;
    RnonCO2[	508	]=	-0.3861246	;
    RnonCO2[	509	]=	-0.3861246	;
    RnonCO2[	510	]=	-0.3861246	;
    RnonCO2[	511	]=	-0.3861246	;
    RnonCO2[	512	]=	-0.3861246	;
    RnonCO2[	513	]=	-0.3861246	;
    RnonCO2[	514	]=	-0.3861246	;
    RnonCO2[	515	]=	-0.3861246	;
    RnonCO2[	516	]=	-0.3861246	;
    RnonCO2[	517	]=	-0.3861246	;
    RnonCO2[	518	]=	-0.3861246	;
    RnonCO2[	519	]=	-0.3861246	;
    RnonCO2[	520	]=	-0.3861246	;
    RnonCO2[	521	]=	-0.3861246	;
    RnonCO2[	522	]=	-0.3861246	;
    RnonCO2[	523	]=	-0.3861246	;
    RnonCO2[	524	]=	-0.3861246	;
    RnonCO2[	525	]=	-0.3861246	;
    RnonCO2[	526	]=	-0.3861246	;
    RnonCO2[	527	]=	-0.3861246	;
    RnonCO2[	528	]=	-0.3861246	;
    RnonCO2[	529	]=	-0.3861246	;
    RnonCO2[	530	]=	-0.3861246	;
    RnonCO2[	531	]=	-0.3861246	;
    RnonCO2[	532	]=	-0.3861246	;
    RnonCO2[	533	]=	-0.3861246	;
    RnonCO2[	534	]=	-0.3861246	;
    RnonCO2[	535	]=	-0.3861246	;
    RnonCO2[	536	]=	-0.3861246	;
    RnonCO2[	537	]=	-0.3861246	;
    RnonCO2[	538	]=	-0.3861246	;
    RnonCO2[	539	]=	-0.3861246	;
    RnonCO2[	540	]=	-0.3861246	;
    RnonCO2[	541	]=	-0.3861246	;
    RnonCO2[	542	]=	-0.3861246	;
    RnonCO2[	543	]=	-0.3861246	;
    RnonCO2[	544	]=	-0.3861246	;
    RnonCO2[	545	]=	-0.3861246	;
    RnonCO2[	546	]=	-0.3861246	;
    RnonCO2[	547	]=	-0.3861246	;
    RnonCO2[	548	]=	-0.3861246	;
    RnonCO2[	549	]=	-0.3861246	;
    RnonCO2[	550	]=	-0.3861246	;
    RnonCO2[	551	]=	-0.3861246	;
    RnonCO2[	552	]=	-0.3861246	;
    RnonCO2[	553	]=	-0.3861246	;
    RnonCO2[	554	]=	-0.3861246	;
    RnonCO2[	555	]=	-0.3861246	;
    RnonCO2[	556	]=	-0.3861246	;
    RnonCO2[	557	]=	-0.3861246	;
    RnonCO2[	558	]=	-0.3861246	;
    RnonCO2[	559	]=	-0.3861246	;
    RnonCO2[	560	]=	-0.3861246	;
    RnonCO2[	561	]=	-0.3861246	;
    RnonCO2[	562	]=	-0.3861246	;
    RnonCO2[	563	]=	-0.3861246	;
    RnonCO2[	564	]=	-0.3861246	;
    RnonCO2[	565	]=	-0.3861246	;
    RnonCO2[	566	]=	-0.3861246	;
    RnonCO2[	567	]=	-0.3861246	;
    RnonCO2[	568	]=	-0.3861246	;
    RnonCO2[	569	]=	-0.3861246	;
    RnonCO2[	570	]=	-0.3861246	;
    RnonCO2[	571	]=	-0.3861246	;
    RnonCO2[	572	]=	-0.3861246	;
    RnonCO2[	573	]=	-0.3861246	;
    RnonCO2[	574	]=	-0.3861246	;
    RnonCO2[	575	]=	-0.3861246	;
    RnonCO2[	576	]=	-0.3861246	;
    RnonCO2[	577	]=	-0.3861246	;
    RnonCO2[	578	]=	-0.3861246	;
    RnonCO2[	579	]=	-0.3861246	;
    RnonCO2[	580	]=	-0.3861246	;
    RnonCO2[	581	]=	-0.3861246	;
    RnonCO2[	582	]=	-0.3861246	;
    RnonCO2[	583	]=	-0.3861246	;
    RnonCO2[	584	]=	-0.3861246	;
    RnonCO2[	585	]=	-0.3861246	;
    RnonCO2[	586	]=	-0.3861246	;
    RnonCO2[	587	]=	-0.3861246	;
    RnonCO2[	588	]=	-0.3861246	;
    RnonCO2[	589	]=	-0.3861246	;
    RnonCO2[	590	]=	-0.3861246	;
    RnonCO2[	591	]=	-0.3861246	;
    RnonCO2[	592	]=	-0.3861246	;
    RnonCO2[	593	]=	-0.3861246	;
    RnonCO2[	594	]=	-0.3861246	;
    RnonCO2[	595	]=	-0.3861246	;
    RnonCO2[	596	]=	-0.3861246	;
    RnonCO2[	597	]=	-0.3861246	;
    RnonCO2[	598	]=	-0.3861246	;
    RnonCO2[	599	]=	-0.3861246	;
    RnonCO2[	600	]=	-0.3861246	;
    RnonCO2[	601	]=	-0.3861246	;
    RnonCO2[	602	]=	-0.3861246	;
    RnonCO2[	603	]=	-0.3861246	;
    RnonCO2[	604	]=	-0.3861246	;
    RnonCO2[	605	]=	-0.3861246	;
    RnonCO2[	606	]=	-0.3861246	;
    RnonCO2[	607	]=	-0.3861246	;
    RnonCO2[	608	]=	-0.3861246	;
    RnonCO2[	609	]=	-0.3861246	;
    RnonCO2[	610	]=	-0.3861246	;
    RnonCO2[	611	]=	-0.3861246	;
    RnonCO2[	612	]=	-0.3861246	;
    RnonCO2[	613	]=	-0.3861246	;
    RnonCO2[	614	]=	-0.3861246	;
    RnonCO2[	615	]=	-0.3861246	;
    RnonCO2[	616	]=	-0.3861246	;
    RnonCO2[	617	]=	-0.3861246	;
    RnonCO2[	618	]=	-0.3861246	;
    RnonCO2[	619	]=	-0.3861246	;
    RnonCO2[	620	]=	-0.3861246	;
    RnonCO2[	621	]=	-0.3861246	;
    RnonCO2[	622	]=	-0.3861246	;
    RnonCO2[	623	]=	-0.3861246	;
    RnonCO2[	624	]=	-0.3861246	;
    RnonCO2[	625	]=	-0.3861246	;
    RnonCO2[	626	]=	-0.3861246	;
    RnonCO2[	627	]=	-0.3861246	;
    RnonCO2[	628	]=	-0.3861246	;
    RnonCO2[	629	]=	-0.3861246	;
    RnonCO2[	630	]=	-0.3861246	;
    RnonCO2[	631	]=	-0.3861246	;
    RnonCO2[	632	]=	-0.3861246	;
    RnonCO2[	633	]=	-0.3861246	;
    RnonCO2[	634	]=	-0.3861246	;
    RnonCO2[	635	]=	-0.3861246	;
    RnonCO2[	636	]=	-0.3861246	;
    RnonCO2[	637	]=	-0.3861246	;
    RnonCO2[	638	]=	-0.3861246	;
    RnonCO2[	639	]=	-0.3861246	;
    RnonCO2[	640	]=	-0.3861246	;
    RnonCO2[	641	]=	-0.3861246	;
    RnonCO2[	642	]=	-0.3861246	;
    RnonCO2[	643	]=	-0.3861246	;
    RnonCO2[	644	]=	-0.3861246	;
    RnonCO2[	645	]=	-0.3861246	;
    RnonCO2[	646	]=	-0.3861246	;
    RnonCO2[	647	]=	-0.3861246	;
    RnonCO2[	648	]=	-0.3861246	;
    RnonCO2[	649	]=	-0.3861246	;
    RnonCO2[	650	]=	-0.3861246	;
    RnonCO2[	651	]=	-0.3861246	;
    RnonCO2[	652	]=	-0.3861246	;
    RnonCO2[	653	]=	-0.3861246	;
    RnonCO2[	654	]=	-0.3861246	;
    RnonCO2[	655	]=	-0.3861246	;
    RnonCO2[	656	]=	-0.3861246	;
    RnonCO2[	657	]=	-0.3861246	;
    RnonCO2[	658	]=	-0.3861246	;
    RnonCO2[	659	]=	-0.3861246	;
    RnonCO2[	660	]=	-0.3861246	;
    RnonCO2[	661	]=	-0.3861246	;
    RnonCO2[	662	]=	-0.3861246	;
    RnonCO2[	663	]=	-0.3861246	;
    RnonCO2[	664	]=	-0.3861246	;
    RnonCO2[	665	]=	-0.3861246	;
    RnonCO2[	666	]=	-0.3861246	;
    RnonCO2[	667	]=	-0.3861246	;
    RnonCO2[	668	]=	-0.3861246	;
    RnonCO2[	669	]=	-0.3861246	;
    RnonCO2[	670	]=	-0.3861246	;
    RnonCO2[	671	]=	-0.3861246	;
    RnonCO2[	672	]=	-0.3861246	;
    RnonCO2[	673	]=	-0.3861246	;
    RnonCO2[	674	]=	-0.3861246	;
    RnonCO2[	675	]=	-0.3861246	;
    RnonCO2[	676	]=	-0.3861246	;
    RnonCO2[	677	]=	-0.3861246	;
    RnonCO2[	678	]=	-0.3861246	;
    RnonCO2[	679	]=	-0.3861246	;
    RnonCO2[	680	]=	-0.3861246	;
    RnonCO2[	681	]=	-0.3861246	;
    RnonCO2[	682	]=	-0.3861246	;
    RnonCO2[	683	]=	-0.3861246	;
    RnonCO2[	684	]=	-0.3861246	;
    RnonCO2[	685	]=	-0.3861246	;
    RnonCO2[	686	]=	-0.3861246	;
    RnonCO2[	687	]=	-0.3861246	;
    RnonCO2[	688	]=	-0.3861246	;
    RnonCO2[	689	]=	-0.3861246	;
    RnonCO2[	690	]=	-0.3861246	;
    RnonCO2[	691	]=	-0.3861246	;
    RnonCO2[	692	]=	-0.3861246	;
    RnonCO2[	693	]=	-0.3861246	;
    RnonCO2[	694	]=	-0.3861246	;
    RnonCO2[	695	]=	-0.3861246	;
    RnonCO2[	696	]=	-0.3861246	;
    RnonCO2[	697	]=	-0.3861246	;
    RnonCO2[	698	]=	-0.3861246	;
    RnonCO2[	699	]=	-0.3861246	;
    RnonCO2[	700	]=	-0.3861246	;
    RnonCO2[	701	]=	-0.3861246	;
    RnonCO2[	702	]=	-0.3861246	;
    RnonCO2[	703	]=	-0.3861246	;
    RnonCO2[	704	]=	-0.3861246	;
    RnonCO2[	705	]=	-0.3861246	;
    RnonCO2[	706	]=	-0.3861246	;
    RnonCO2[	707	]=	-0.3861246	;
    RnonCO2[	708	]=	-0.3861246	;
    RnonCO2[	709	]=	-0.3861246	;
    RnonCO2[	710	]=	-0.3861246	;
    RnonCO2[	711	]=	-0.3861246	;
    RnonCO2[	712	]=	-0.3861246	;
    RnonCO2[	713	]=	-0.3861246	;
    RnonCO2[	714	]=	-0.3861246	;
    RnonCO2[	715	]=	-0.3861246	;
    RnonCO2[	716	]=	-0.3861246	;
    RnonCO2[	717	]=	-0.3861246	;
    RnonCO2[	718	]=	-0.3861246	;
    RnonCO2[	719	]=	-0.3861246	;
    RnonCO2[	720	]=	-0.3861246	;
    RnonCO2[	721	]=	-0.3861246	;
    RnonCO2[	722	]=	-0.3861246	;
    RnonCO2[	723	]=	-0.3861246	;
    RnonCO2[	724	]=	-0.3861246	;
    RnonCO2[	725	]=	-0.3861246	;
    RnonCO2[	726	]=	-0.3861246	;
    RnonCO2[	727	]=	-0.3861246	;
    RnonCO2[	728	]=	-0.3861246	;
    RnonCO2[	729	]=	-0.3861246	;
    RnonCO2[	730	]=	-0.3861246	;
    RnonCO2[	731	]=	-0.3861246	;
    RnonCO2[	732	]=	-0.3861246	;
    RnonCO2[	733	]=	-0.3861246	;
    RnonCO2[	734	]=	-0.3861246	;
    RnonCO2[	735	]=	-0.3861246	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_aerosol_RCP3PD(void)
{
    
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.000955298	;
    RnonCO2[	2	]=	0.001424721	;
    RnonCO2[	3	]=	0.0001974	;
    RnonCO2[	4	]=	-0.001278437	;
    RnonCO2[	5	]=	-0.002733841	;
    RnonCO2[	6	]=	-0.004541334	;
    RnonCO2[	7	]=	-0.00632004	;
    RnonCO2[	8	]=	-0.007680948	;
    RnonCO2[	9	]=	-0.008994568	;
    RnonCO2[	10	]=	-0.010260775	;
    RnonCO2[	11	]=	-0.011479866	;
    RnonCO2[	12	]=	-0.012652425	;
    RnonCO2[	13	]=	-0.013779231	;
    RnonCO2[	14	]=	-0.014861204	;
    RnonCO2[	15	]=	-0.015900176	;
    RnonCO2[	16	]=	-0.017335746	;
    RnonCO2[	17	]=	-0.01873479	;
    RnonCO2[	18	]=	-0.019659073	;
    RnonCO2[	19	]=	-0.020540613	;
    RnonCO2[	20	]=	-0.02137714	;
    RnonCO2[	21	]=	-0.022166399	;
    RnonCO2[	22	]=	-0.022906132	;
    RnonCO2[	23	]=	-0.023594082	;
    RnonCO2[	24	]=	-0.024227995	;
    RnonCO2[	25	]=	-0.024806236	;
    RnonCO2[	26	]=	-0.025775743	;
    RnonCO2[	27	]=	-0.026691982	;
    RnonCO2[	28	]=	-0.027110281	;
    RnonCO2[	29	]=	-0.02747885	;
    RnonCO2[	30	]=	-0.027799526	;
    RnonCO2[	31	]=	-0.028074106	;
    RnonCO2[	32	]=	-0.02875039	;
    RnonCO2[	33	]=	-0.029383792	;
    RnonCO2[	34	]=	-0.02953002	;
    RnonCO2[	35	]=	-0.03007996	;
    RnonCO2[	36	]=	-0.03058546	;
    RnonCO2[	37	]=	-0.03148571	;
    RnonCO2[	38	]=	-0.03189741	;
    RnonCO2[	39	]=	-0.03138062	;
    RnonCO2[	40	]=	-0.03126848	;
    RnonCO2[	41	]=	-0.03156144	;
    RnonCO2[	42	]=	-0.03182181	;
    RnonCO2[	43	]=	-0.03161267	;
    RnonCO2[	44	]=	-0.03137821	;
    RnonCO2[	45	]=	-0.03112038	;
    RnonCO2[	46	]=	-0.03127367	;
    RnonCO2[	47	]=	-0.0313998	;
    RnonCO2[	48	]=	-0.03106322	;
    RnonCO2[	49	]=	-0.03070135	;
    RnonCO2[	50	]=	-0.03074616	;
    RnonCO2[	51	]=	-0.03119614	;
    RnonCO2[	52	]=	-0.03161872	;
    RnonCO2[	53	]=	-0.03158785	;
    RnonCO2[	54	]=	-0.03110696	;
    RnonCO2[	55	]=	-0.03060634	;
    RnonCO2[	56	]=	-0.0300866	;
    RnonCO2[	57	]=	-0.02996996	;
    RnonCO2[	58	]=	-0.03025404	;
    RnonCO2[	59	]=	-0.03009594	;
    RnonCO2[	60	]=	-0.02991636	;
    RnonCO2[	61	]=	-0.02971869	;
    RnonCO2[	62	]=	-0.02950042	;
    RnonCO2[	63	]=	-0.02926502	;
    RnonCO2[	64	]=	-0.02859871	;
    RnonCO2[	65	]=	-0.03037359	;
    RnonCO2[	66	]=	-0.03172034	;
    RnonCO2[	67	]=	-0.03059392	;
    RnonCO2[	68	]=	-0.03026959	;
    RnonCO2[	69	]=	-0.02993194	;
    RnonCO2[	70	]=	-0.02957653	;
    RnonCO2[	71	]=	-0.03080027	;
    RnonCO2[	72	]=	-0.03160022	;
    RnonCO2[	73	]=	-0.03117789	;
    RnonCO2[	74	]=	-0.03112982	;
    RnonCO2[	75	]=	-0.03144654	;
    RnonCO2[	76	]=	-0.03173222	;
    RnonCO2[	77	]=	-0.03198224	;
    RnonCO2[	78	]=	-0.03220368	;
    RnonCO2[	79	]=	-0.03239696	;
    RnonCO2[	80	]=	-0.03371239	;
    RnonCO2[	81	]=	-0.03424533	;
    RnonCO2[	82	]=	-0.0343764	;
    RnonCO2[	83	]=	-0.03487942	;
    RnonCO2[	84	]=	-0.03536957	;
    RnonCO2[	85	]=	-0.03686306	;
    RnonCO2[	86	]=	-0.03665392	;
    RnonCO2[	87	]=	-0.04248424	;
    RnonCO2[	88	]=	-0.04930444	;
    RnonCO2[	89	]=	-0.05182621	;
    RnonCO2[	90	]=	-0.0542671	;
    RnonCO2[	91	]=	-0.05573158	;
    RnonCO2[	92	]=	-0.05765815	;
    RnonCO2[	93	]=	-0.05821397	;
    RnonCO2[	94	]=	-0.06005825	;
    RnonCO2[	95	]=	-0.0683501	;
    RnonCO2[	96	]=	-0.08104112	;
    RnonCO2[	97	]=	-0.07832852	;
    RnonCO2[	98	]=	-0.07177024	;
    RnonCO2[	99	]=	-0.07363036	;
    RnonCO2[	100	]=	-0.07696442	;
    RnonCO2[	101	]=	-0.08462429	;
    RnonCO2[	102	]=	-0.09275025	;
    RnonCO2[	103	]=	-0.09511911	;
    RnonCO2[	104	]=	-0.0930339	;
    RnonCO2[	105	]=	-0.09237765	;
    RnonCO2[	106	]=	-0.10165608	;
    RnonCO2[	107	]=	-0.12466661	;
    RnonCO2[	108	]=	-0.14405058	;
    RnonCO2[	109	]=	-0.14773339	;
    RnonCO2[	110	]=	-0.14777672	;
    RnonCO2[	111	]=	-0.1470811	;
    RnonCO2[	112	]=	-0.14255587	;
    RnonCO2[	113	]=	-0.14024698	;
    RnonCO2[	114	]=	-0.14393886	;
    RnonCO2[	115	]=	-0.15612866	;
    RnonCO2[	116	]=	-0.164782	;
    RnonCO2[	117	]=	-0.16302445	;
    RnonCO2[	118	]=	-0.16326054	;
    RnonCO2[	119	]=	-0.16496204	;
    RnonCO2[	120	]=	-0.16272157	;
    RnonCO2[	121	]=	-0.1612244	;
    RnonCO2[	122	]=	-0.16356025	;
    RnonCO2[	123	]=	-0.17242315	;
    RnonCO2[	124	]=	-0.17632405	;
    RnonCO2[	125	]=	-0.17855867	;
    RnonCO2[	126	]=	-0.18527891	;
    RnonCO2[	127	]=	-0.18997972	;
    RnonCO2[	128	]=	-0.1933518	;
    RnonCO2[	129	]=	-0.19699663	;
    RnonCO2[	130	]=	-0.20233059	;
    RnonCO2[	131	]=	-0.2051441	;
    RnonCO2[	132	]=	-0.20577589	;
    RnonCO2[	133	]=	-0.20720143	;
    RnonCO2[	134	]=	-0.21030464	;
    RnonCO2[	135	]=	-0.21375193	;
    RnonCO2[	136	]=	-0.22004069	;
    RnonCO2[	137	]=	-0.22693377	;
    RnonCO2[	138	]=	-0.23402972	;
    RnonCO2[	139	]=	-0.2411565	;
    RnonCO2[	140	]=	-0.2471181	;
    RnonCO2[	141	]=	-0.255172	;
    RnonCO2[	142	]=	-0.26315304	;
    RnonCO2[	143	]=	-0.2636557	;
    RnonCO2[	144	]=	-0.26151664	;
    RnonCO2[	145	]=	-0.26499499	;
    RnonCO2[	146	]=	-0.26461175	;
    RnonCO2[	147	]=	-0.26044407	;
    RnonCO2[	148	]=	-0.25940869	;
    RnonCO2[	149	]=	-0.25560119	;
    RnonCO2[	150	]=	-0.25007798	;
    RnonCO2[	151	]=	-0.25106379	;
    RnonCO2[	152	]=	-0.25437609	;
    RnonCO2[	153	]=	-0.25544669	;
    RnonCO2[	154	]=	-0.2505011	;
    RnonCO2[	155	]=	-0.24919556	;
    RnonCO2[	156	]=	-0.24766564	;
    RnonCO2[	157	]=	-0.24454174	;
    RnonCO2[	158	]=	-0.25504195	;
    RnonCO2[	159	]=	-0.26312341	;
    RnonCO2[	160	]=	-0.26314088	;
    RnonCO2[	161	]=	-0.26376161	;
    RnonCO2[	162	]=	-0.26809378	;
    RnonCO2[	163	]=	-0.27284291	;
    RnonCO2[	164	]=	-0.27584022	;
    RnonCO2[	165	]=	-0.27557411	;
    RnonCO2[	166	]=	-0.26967283	;
    RnonCO2[	167	]=	-0.26315755	;
    RnonCO2[	168	]=	-0.26083606	;
    RnonCO2[	169	]=	-0.26325195	;
    RnonCO2[	170	]=	-0.2652416	;
    RnonCO2[	171	]=	-0.26824619	;
    RnonCO2[	172	]=	-0.26930622	;
    RnonCO2[	173	]=	-0.26149511	;
    RnonCO2[	174	]=	-0.25651091	;
    RnonCO2[	175	]=	-0.26035065	;
    RnonCO2[	176	]=	-0.26656695	;
    RnonCO2[	177	]=	-0.27194936	;
    RnonCO2[	178	]=	-0.274817	;
    RnonCO2[	179	]=	-0.27878403	;
    RnonCO2[	180	]=	-0.28302569	;
    RnonCO2[	181	]=	-0.29104814	;
    RnonCO2[	182	]=	-0.30416561	;
    RnonCO2[	183	]=	-0.31716714	;
    RnonCO2[	184	]=	-0.3246442	;
    RnonCO2[	185	]=	-0.3327935	;
    RnonCO2[	186	]=	-0.35639494	;
    RnonCO2[	187	]=	-0.38051016	;
    RnonCO2[	188	]=	-0.39378465	;
    RnonCO2[	189	]=	-0.40659776	;
    RnonCO2[	190	]=	-0.4196919	;
    RnonCO2[	191	]=	-0.43302942	;
    RnonCO2[	192	]=	-0.44651364	;
    RnonCO2[	193	]=	-0.45569127	;
    RnonCO2[	194	]=	-0.45642498	;
    RnonCO2[	195	]=	-0.45551768	;
    RnonCO2[	196	]=	-0.47183293	;
    RnonCO2[	197	]=	-0.49188519	;
    RnonCO2[	198	]=	-0.50135461	;
    RnonCO2[	199	]=	-0.5101619	;
    RnonCO2[	200	]=	-0.51738459	;
    RnonCO2[	201	]=	-0.52416219	;
    RnonCO2[	202	]=	-0.53325402	;
    RnonCO2[	203	]=	-0.54124791	;
    RnonCO2[	204	]=	-0.54379714	;
    RnonCO2[	205	]=	-0.53664772	;
    RnonCO2[	206	]=	-0.52607217	;
    RnonCO2[	207	]=	-0.52739363	;
    RnonCO2[	208	]=	-0.53724776	;
    RnonCO2[	209	]=	-0.54779467	;
    RnonCO2[	210	]=	-0.55942351	;
    RnonCO2[	211	]=	-0.57578959	;
    RnonCO2[	212	]=	-0.5916702	;
    RnonCO2[	213	]=	-0.5979117	;
    RnonCO2[	214	]=	-0.6009881	;
    RnonCO2[	215	]=	-0.6131431	;
    RnonCO2[	216	]=	-0.6319195	;
    RnonCO2[	217	]=	-0.6542028	;
    RnonCO2[	218	]=	-0.6747946	;
    RnonCO2[	219	]=	-0.6865596	;
    RnonCO2[	220	]=	-0.6942006	;
    RnonCO2[	221	]=	-0.7018816	;
    RnonCO2[	222	]=	-0.7121991	;
    RnonCO2[	223	]=	-0.7210817	;
    RnonCO2[	224	]=	-0.7262596	;
    RnonCO2[	225	]=	-0.7299457	;
    RnonCO2[	226	]=	-0.7418714	;
    RnonCO2[	227	]=	-0.7583892	;
    RnonCO2[	228	]=	-0.7656833	;
    RnonCO2[	229	]=	-0.768847	;
    RnonCO2[	230	]=	-0.7655134	;
    RnonCO2[	231	]=	-0.7588829	;
    RnonCO2[	232	]=	-0.7657109	;
    RnonCO2[	233	]=	-0.7804313	;
    RnonCO2[	234	]=	-0.7902367	;
    RnonCO2[	235	]=	-0.8012413	;
    RnonCO2[	236	]=	-0.8096987	;
    RnonCO2[	237	]=	-0.8105819	;
    RnonCO2[	238	]=	-0.8112899	;
    RnonCO2[	239	]=	-0.8123564	;
    RnonCO2[	240	]=	-0.8111513	;
    RnonCO2[	241	]=	-0.8050465	;
    RnonCO2[	242	]=	-0.7966306	;
    RnonCO2[	243	]=	-0.7880713	;
    RnonCO2[	244	]=	-0.7791377	;
    RnonCO2[	245	]=	-0.7684838	;
    RnonCO2[	246	]=	-0.7547825	;
    RnonCO2[	247	]=	-0.7400687	;
    RnonCO2[	248	]=	-0.7264014	;
    RnonCO2[	249	]=	-0.7134622	;
    RnonCO2[	250	]=	-0.7009668	;
    RnonCO2[	251	]=	-0.6888369	;
    RnonCO2[	252	]=	-0.6770345	;
    RnonCO2[	253	]=	-0.6655394	;
    RnonCO2[	254	]=	-0.653891	;
    RnonCO2[	255	]=	-0.6434029	;
    RnonCO2[	256	]=	-0.6355575	;
    RnonCO2[	257	]=	-0.6294243	;
    RnonCO2[	258	]=	-0.6237506	;
    RnonCO2[	259	]=	-0.6178977	;
    RnonCO2[	260	]=	-0.611837	;
    RnonCO2[	261	]=	-0.6055847	;
    RnonCO2[	262	]=	-0.59916	;
    RnonCO2[	263	]=	-0.5925781	;
    RnonCO2[	264	]=	-0.5858487	;
    RnonCO2[	265	]=	-0.580215	;
    RnonCO2[	266	]=	-0.5769285	;
    RnonCO2[	267	]=	-0.5739943	;
    RnonCO2[	268	]=	-0.5701748	;
    RnonCO2[	269	]=	-0.5662388	;
    RnonCO2[	270	]=	-0.5621802	;
    RnonCO2[	271	]=	-0.5579998	;
    RnonCO2[	272	]=	-0.5537056	;
    RnonCO2[	273	]=	-0.5493032	;
    RnonCO2[	274	]=	-0.5448003	;
    RnonCO2[	275	]=	-0.5412975	;
    RnonCO2[	276	]=	-0.539911	;
    RnonCO2[	277	]=	-0.5396073	;
    RnonCO2[	278	]=	-0.5393865	;
    RnonCO2[	279	]=	-0.5392914	;
    RnonCO2[	280	]=	-0.5393053	;
    RnonCO2[	281	]=	-0.5394198	;
    RnonCO2[	282	]=	-0.5396188	;
    RnonCO2[	283	]=	-0.5398498	;
    RnonCO2[	284	]=	-0.5400737	;
    RnonCO2[	285	]=	-0.5410681	;
    RnonCO2[	286	]=	-0.5436393	;
    RnonCO2[	287	]=	-0.5470987	;
    RnonCO2[	288	]=	-0.5506475	;
    RnonCO2[	289	]=	-0.5542153	;
    RnonCO2[	290	]=	-0.557813	;
    RnonCO2[	291	]=	-0.5614358	;
    RnonCO2[	292	]=	-0.5650812	;
    RnonCO2[	293	]=	-0.568747	;
    RnonCO2[	294	]=	-0.5724309	;
    RnonCO2[	295	]=	-0.5753782	;
    RnonCO2[	296	]=	-0.5768182	;
    RnonCO2[	297	]=	-0.577794	;
    RnonCO2[	298	]=	-0.5789932	;
    RnonCO2[	299	]=	-0.5800496	;
    RnonCO2[	300	]=	-0.5809866	;
    RnonCO2[	301	]=	-0.5818207	;
    RnonCO2[	302	]=	-0.582553	;
    RnonCO2[	303	]=	-0.5831855	;
    RnonCO2[	304	]=	-0.5837211	;
    RnonCO2[	305	]=	-0.5836775	;
    RnonCO2[	306	]=	-0.5825824	;
    RnonCO2[	307	]=	-0.580916	;
    RnonCO2[	308	]=	-0.5791711	;
    RnonCO2[	309	]=	-0.5773716	;
    RnonCO2[	310	]=	-0.5755228	;
    RnonCO2[	311	]=	-0.5736392	;
    RnonCO2[	312	]=	-0.5717301	;
    RnonCO2[	313	]=	-0.5697893	;
    RnonCO2[	314	]=	-0.5678132	;
    RnonCO2[	315	]=	-0.5660861	;
    RnonCO2[	316	]=	-0.5648969	;
    RnonCO2[	317	]=	-0.5636325	;
    RnonCO2[	318	]=	-0.5620179	;
    RnonCO2[	319	]=	-0.5603957	;
    RnonCO2[	320	]=	-0.5587675	;
    RnonCO2[	321	]=	-0.5571346	;
    RnonCO2[	322	]=	-0.5555085	;
    RnonCO2[	323	]=	-0.5538953	;
    RnonCO2[	324	]=	-0.5522866	;
    RnonCO2[	325	]=	-0.550654	;
    RnonCO2[	326	]=	-0.5489639	;
    RnonCO2[	327	]=	-0.5473193	;
    RnonCO2[	328	]=	-0.5457334	;
    RnonCO2[	329	]=	-0.54411	;
    RnonCO2[	330	]=	-0.5424524	;
    RnonCO2[	331	]=	-0.5407624	;
    RnonCO2[	332	]=	-0.5390414	;
    RnonCO2[	333	]=	-0.5373012	;
    RnonCO2[	334	]=	-0.5355478	;
    RnonCO2[	335	]=	-0.5347717	;
    RnonCO2[	336	]=	-0.5359662	;
    RnonCO2[	337	]=	-0.5374878	;
    RnonCO2[	338	]=	-0.5383173	;
    RnonCO2[	339	]=	-0.5390826	;
    RnonCO2[	340	]=	-0.5397906	;
    RnonCO2[	341	]=	-0.5404467	;
    RnonCO2[	342	]=	-0.5410543	;
    RnonCO2[	343	]=	-0.5416166	;
    RnonCO2[	344	]=	-0.5421464	;
    RnonCO2[	345	]=	-0.542651	;
    RnonCO2[	346	]=	-0.5431236	;
    RnonCO2[	347	]=	-0.5435591	;
    RnonCO2[	348	]=	-0.5439538	;
    RnonCO2[	349	]=	-0.5443033	;
    RnonCO2[	350	]=	-0.5446088	;
    RnonCO2[	351	]=	-0.5448751	;
    RnonCO2[	352	]=	-0.5451056	;
    RnonCO2[	353	]=	-0.545302	;
    RnonCO2[	354	]=	-0.5454656	;
    RnonCO2[	355	]=	-0.5456081	;
    RnonCO2[	356	]=	-0.5457354	;
    RnonCO2[	357	]=	-0.5458396	;
    RnonCO2[	358	]=	-0.5459148	;
    RnonCO2[	359	]=	-0.5459561	;
    RnonCO2[	360	]=	-0.5459653	;
    RnonCO2[	361	]=	-0.5459561	;
    RnonCO2[	362	]=	-0.5459399	;
    RnonCO2[	363	]=	-0.5459192	;
    RnonCO2[	364	]=	-0.5458953	;
    RnonCO2[	365	]=	-0.5458692	;
    RnonCO2[	366	]=	-0.545852	;
    RnonCO2[	367	]=	-0.5458494	;
    RnonCO2[	368	]=	-0.5458532	;
    RnonCO2[	369	]=	-0.5458572	;
    RnonCO2[	370	]=	-0.5458563	;
    RnonCO2[	371	]=	-0.5458454	;
    RnonCO2[	372	]=	-0.5458246	;
    RnonCO2[	373	]=	-0.5457981	;
    RnonCO2[	374	]=	-0.5457684	;
    RnonCO2[	375	]=	-0.5457367	;
    RnonCO2[	376	]=	-0.5457039	;
    RnonCO2[	377	]=	-0.5456809	;
    RnonCO2[	378	]=	-0.5456733	;
    RnonCO2[	379	]=	-0.5456728	;
    RnonCO2[	380	]=	-0.5456731	;
    RnonCO2[	381	]=	-0.545669	;
    RnonCO2[	382	]=	-0.5456555	;
    RnonCO2[	383	]=	-0.5456325	;
    RnonCO2[	384	]=	-0.5456043	;
    RnonCO2[	385	]=	-0.5455733	;
    RnonCO2[	386	]=	-0.5455404	;
    RnonCO2[	387	]=	-0.5455068	;
    RnonCO2[	388	]=	-0.5454831	;
    RnonCO2[	389	]=	-0.5454751	;
    RnonCO2[	390	]=	-0.5454742	;
    RnonCO2[	391	]=	-0.5454743	;
    RnonCO2[	392	]=	-0.5454704	;
    RnonCO2[	393	]=	-0.5454569	;
    RnonCO2[	394	]=	-0.5454342	;
    RnonCO2[	395	]=	-0.5454062	;
    RnonCO2[	396	]=	-0.5453757	;
    RnonCO2[	397	]=	-0.5453433	;
    RnonCO2[	398	]=	-0.5453102	;
    RnonCO2[	399	]=	-0.545287	;
    RnonCO2[	400	]=	-0.5452796	;
    RnonCO2[	401	]=	-0.5452793	;
    RnonCO2[	402	]=	-0.5452801	;
    RnonCO2[	403	]=	-0.5452767	;
    RnonCO2[	404	]=	-0.5452639	;
    RnonCO2[	405	]=	-0.545242	;
    RnonCO2[	406	]=	-0.5452148	;
    RnonCO2[	407	]=	-0.5451848	;
    RnonCO2[	408	]=	-0.5451532	;
    RnonCO2[	409	]=	-0.5451208	;
    RnonCO2[	410	]=	-0.5450983	;
    RnonCO2[	411	]=	-0.5450917	;
    RnonCO2[	412	]=	-0.5450921	;
    RnonCO2[	413	]=	-0.5450935	;
    RnonCO2[	414	]=	-0.5450909	;
    RnonCO2[	415	]=	-0.5450788	;
    RnonCO2[	416	]=	-0.5450575	;
    RnonCO2[	417	]=	-0.545031	;
    RnonCO2[	418	]=	-0.5450018	;
    RnonCO2[	419	]=	-0.5449708	;
    RnonCO2[	420	]=	-0.5449391	;
    RnonCO2[	421	]=	-0.5449173	;
    RnonCO2[	422	]=	-0.5449113	;
    RnonCO2[	423	]=	-0.5449123	;
    RnonCO2[	424	]=	-0.5449143	;
    RnonCO2[	425	]=	-0.5449123	;
    RnonCO2[	426	]=	-0.5449008	;
    RnonCO2[	427	]=	-0.5448801	;
    RnonCO2[	428	]=	-0.5448542	;
    RnonCO2[	429	]=	-0.5448255	;
    RnonCO2[	430	]=	-0.5447951	;
    RnonCO2[	431	]=	-0.544764	;
    RnonCO2[	432	]=	-0.5447428	;
    RnonCO2[	433	]=	-0.5447373	;
    RnonCO2[	434	]=	-0.5447388	;
    RnonCO2[	435	]=	-0.5447413	;
    RnonCO2[	436	]=	-0.5447398	;
    RnonCO2[	437	]=	-0.5447288	;
    RnonCO2[	438	]=	-0.5447085	;
    RnonCO2[	439	]=	-0.5446832	;
    RnonCO2[	440	]=	-0.544655	;
    RnonCO2[	441	]=	-0.5446251	;
    RnonCO2[	442	]=	-0.5445943	;
    RnonCO2[	443	]=	-0.5445736	;
    RnonCO2[	444	]=	-0.5445685	;
    RnonCO2[	445	]=	-0.5445705	;
    RnonCO2[	446	]=	-0.5445734	;
    RnonCO2[	447	]=	-0.5445723	;
    RnonCO2[	448	]=	-0.5445617	;
    RnonCO2[	449	]=	-0.5445419	;
    RnonCO2[	450	]=	-0.544517	;
    RnonCO2[	451	]=	-0.5444891	;
    RnonCO2[	452	]=	-0.5444597	;
    RnonCO2[	453	]=	-0.5444293	;
    RnonCO2[	454	]=	-0.544409	;
    RnonCO2[	455	]=	-0.5444042	;
    RnonCO2[	456	]=	-0.5444066	;
    RnonCO2[	457	]=	-0.5444099	;
    RnonCO2[	458	]=	-0.5444091	;
    RnonCO2[	459	]=	-0.5443989	;
    RnonCO2[	460	]=	-0.5443795	;
    RnonCO2[	461	]=	-0.5443548	;
    RnonCO2[	462	]=	-0.5443274	;
    RnonCO2[	463	]=	-0.5442982	;
    RnonCO2[	464	]=	-0.5442682	;
    RnonCO2[	465	]=	-0.5442482	;
    RnonCO2[	466	]=	-0.5442438	;
    RnonCO2[	467	]=	-0.5442464	;
    RnonCO2[	468	]=	-0.54425	;
    RnonCO2[	469	]=	-0.5442495	;
    RnonCO2[	470	]=	-0.5442396	;
    RnonCO2[	471	]=	-0.5442204	;
    RnonCO2[	472	]=	-0.5441961	;
    RnonCO2[	473	]=	-0.544169	;
    RnonCO2[	474	]=	-0.5441401	;
    RnonCO2[	475	]=	-0.5441105	;
    RnonCO2[	476	]=	-0.5440907	;
    RnonCO2[	477	]=	-0.5440866	;
    RnonCO2[	478	]=	-0.5440894	;
    RnonCO2[	479	]=	-0.5440933	;
    RnonCO2[	480	]=	-0.5440931	;
    RnonCO2[	481	]=	-0.5440835	;
    RnonCO2[	482	]=	-0.5440646	;
    RnonCO2[	483	]=	-0.5440405	;
    RnonCO2[	484	]=	-0.5440137	;
    RnonCO2[	485	]=	-0.5439851	;
    RnonCO2[	486	]=	-0.5439556	;
    RnonCO2[	487	]=	-0.5439362	;
    RnonCO2[	488	]=	-0.5439322	;
    RnonCO2[	489	]=	-0.5439354	;
    RnonCO2[	490	]=	-0.5439394	;
    RnonCO2[	491	]=	-0.5439395	;
    RnonCO2[	492	]=	-0.54393	;
    RnonCO2[	493	]=	-0.5439114	;
    RnonCO2[	494	]=	-0.5438876	;
    RnonCO2[	495	]=	-0.543861	;
    RnonCO2[	496	]=	-0.5438326	;
    RnonCO2[	497	]=	-0.5438034	;
    RnonCO2[	498	]=	-0.5437841	;
    RnonCO2[	499	]=	-0.5437805	;
    RnonCO2[	500	]=	-0.5437838	;
    RnonCO2[	501	]=	-0.5437881	;
    RnonCO2[	502	]=	-0.5437883	;
    RnonCO2[	503	]=	-0.5437791	;
    RnonCO2[	504	]=	-0.5437606	;
    RnonCO2[	505	]=	-0.5437371	;
    RnonCO2[	506	]=	-0.5437107	;
    RnonCO2[	507	]=	-0.5436826	;
    RnonCO2[	508	]=	-0.5436536	;
    RnonCO2[	509	]=	-0.5436345	;
    RnonCO2[	510	]=	-0.543631	;
    RnonCO2[	511	]=	-0.5436345	;
    RnonCO2[	512	]=	-0.543639	;
    RnonCO2[	513	]=	-0.5436394	;
    RnonCO2[	514	]=	-0.5436304	;
    RnonCO2[	515	]=	-0.5436122	;
    RnonCO2[	516	]=	-0.5435888	;
    RnonCO2[	517	]=	-0.5435626	;
    RnonCO2[	518	]=	-0.5435346	;
    RnonCO2[	519	]=	-0.5435059	;
    RnonCO2[	520	]=	-0.5434869	;
    RnonCO2[	521	]=	-0.5434837	;
    RnonCO2[	522	]=	-0.5434874	;
    RnonCO2[	523	]=	-0.543492	;
    RnonCO2[	524	]=	-0.5434926	;
    RnonCO2[	525	]=	-0.5434838	;
    RnonCO2[	526	]=	-0.5434658	;
    RnonCO2[	527	]=	-0.5434425	;
    RnonCO2[	528	]=	-0.5434165	;
    RnonCO2[	529	]=	-0.5433887	;
    RnonCO2[	530	]=	-0.5433601	;
    RnonCO2[	531	]=	-0.5433414	;
    RnonCO2[	532	]=	-0.5433383	;
    RnonCO2[	533	]=	-0.5433421	;
    RnonCO2[	534	]=	-0.5433469	;
    RnonCO2[	535	]=	-0.5433476	;
    RnonCO2[	536	]=	-0.543339	;
    RnonCO2[	537	]=	-0.5433211	;
    RnonCO2[	538	]=	-0.543298	;
    RnonCO2[	539	]=	-0.5432722	;
    RnonCO2[	540	]=	-0.5432446	;
    RnonCO2[	541	]=	-0.5432162	;
    RnonCO2[	542	]=	-0.5431976	;
    RnonCO2[	543	]=	-0.5431946	;
    RnonCO2[	544	]=	-0.5431986	;
    RnonCO2[	545	]=	-0.5432035	;
    RnonCO2[	546	]=	-0.5432044	;
    RnonCO2[	547	]=	-0.5431959	;
    RnonCO2[	548	]=	-0.5431783	;
    RnonCO2[	549	]=	-0.5431553	;
    RnonCO2[	550	]=	-0.5431296	;
    RnonCO2[	551	]=	-0.5431022	;
    RnonCO2[	552	]=	-0.5430738	;
    RnonCO2[	553	]=	-0.5430555	;
    RnonCO2[	554	]=	-0.5430527	;
    RnonCO2[	555	]=	-0.5430567	;
    RnonCO2[	556	]=	-0.5430619	;
    RnonCO2[	557	]=	-0.5430629	;
    RnonCO2[	558	]=	-0.5430545	;
    RnonCO2[	559	]=	-0.543037	;
    RnonCO2[	560	]=	-0.5430142	;
    RnonCO2[	561	]=	-0.5429887	;
    RnonCO2[	562	]=	-0.5429614	;
    RnonCO2[	563	]=	-0.5429332	;
    RnonCO2[	564	]=	-0.5429149	;
    RnonCO2[	565	]=	-0.5429123	;
    RnonCO2[	566	]=	-0.5429164	;
    RnonCO2[	567	]=	-0.5429217	;
    RnonCO2[	568	]=	-0.5429229	;
    RnonCO2[	569	]=	-0.5429147	;
    RnonCO2[	570	]=	-0.5428972	;
    RnonCO2[	571	]=	-0.5428746	;
    RnonCO2[	572	]=	-0.5428492	;
    RnonCO2[	573	]=	-0.542822	;
    RnonCO2[	574	]=	-0.542794	;
    RnonCO2[	575	]=	-0.5427759	;
    RnonCO2[	576	]=	-0.5427733	;
    RnonCO2[	577	]=	-0.5427776	;
    RnonCO2[	578	]=	-0.5427829	;
    RnonCO2[	579	]=	-0.5427842	;
    RnonCO2[	580	]=	-0.5427761	;
    RnonCO2[	581	]=	-0.5427588	;
    RnonCO2[	582	]=	-0.5427364	;
    RnonCO2[	583	]=	-0.5427111	;
    RnonCO2[	584	]=	-0.5426841	;
    RnonCO2[	585	]=	-0.5426562	;
    RnonCO2[	586	]=	-0.5426382	;
    RnonCO2[	587	]=	-0.5426357	;
    RnonCO2[	588	]=	-0.5426401	;
    RnonCO2[	589	]=	-0.5426456	;
    RnonCO2[	590	]=	-0.542647	;
    RnonCO2[	591	]=	-0.542639	;
    RnonCO2[	592	]=	-0.5426218	;
    RnonCO2[	593	]=	-0.5425995	;
    RnonCO2[	594	]=	-0.5425743	;
    RnonCO2[	595	]=	-0.5425474	;
    RnonCO2[	596	]=	-0.5425196	;
    RnonCO2[	597	]=	-0.5425018	;
    RnonCO2[	598	]=	-0.5424994	;
    RnonCO2[	599	]=	-0.5425039	;
    RnonCO2[	600	]=	-0.5425095	;
    RnonCO2[	601	]=	-0.542511	;
    RnonCO2[	602	]=	-0.5425031	;
    RnonCO2[	603	]=	-0.542486	;
    RnonCO2[	604	]=	-0.5424638	;
    RnonCO2[	605	]=	-0.5424388	;
    RnonCO2[	606	]=	-0.5424119	;
    RnonCO2[	607	]=	-0.5423844	;
    RnonCO2[	608	]=	-0.5423665	;
    RnonCO2[	609	]=	-0.5423643	;
    RnonCO2[	610	]=	-0.5423689	;
    RnonCO2[	611	]=	-0.5423746	;
    RnonCO2[	612	]=	-0.5423762	;
    RnonCO2[	613	]=	-0.5423684	;
    RnonCO2[	614	]=	-0.5423514	;
    RnonCO2[	615	]=	-0.5423294	;
    RnonCO2[	616	]=	-0.5423044	;
    RnonCO2[	617	]=	-0.5422777	;
    RnonCO2[	618	]=	-0.5422502	;
    RnonCO2[	619	]=	-0.5422325	;
    RnonCO2[	620	]=	-0.5422303	;
    RnonCO2[	621	]=	-0.5422351	;
    RnonCO2[	622	]=	-0.5422408	;
    RnonCO2[	623	]=	-0.5422426	;
    RnonCO2[	624	]=	-0.5422348	;
    RnonCO2[	625	]=	-0.542218	;
    RnonCO2[	626	]=	-0.542196	;
    RnonCO2[	627	]=	-0.5421712	;
    RnonCO2[	628	]=	-0.5421446	;
    RnonCO2[	629	]=	-0.5421171	;
    RnonCO2[	630	]=	-0.5420996	;
    RnonCO2[	631	]=	-0.5420975	;
    RnonCO2[	632	]=	-0.5421023	;
    RnonCO2[	633	]=	-0.5421081	;
    RnonCO2[	634	]=	-0.54211	;
    RnonCO2[	635	]=	-0.5421024	;
    RnonCO2[	636	]=	-0.5420857	;
    RnonCO2[	637	]=	-0.5420637	;
    RnonCO2[	638	]=	-0.542039	;
    RnonCO2[	639	]=	-0.5420126	;
    RnonCO2[	640	]=	-0.5419852	;
    RnonCO2[	641	]=	-0.5419677	;
    RnonCO2[	642	]=	-0.5419656	;
    RnonCO2[	643	]=	-0.5419706	;
    RnonCO2[	644	]=	-0.5419765	;
    RnonCO2[	645	]=	-0.5419784	;
    RnonCO2[	646	]=	-0.541971	;
    RnonCO2[	647	]=	-0.5419542	;
    RnonCO2[	648	]=	-0.5419325	;
    RnonCO2[	649	]=	-0.5419079	;
    RnonCO2[	650	]=	-0.5418814	;
    RnonCO2[	651	]=	-0.5418542	;
    RnonCO2[	652	]=	-0.5418368	;
    RnonCO2[	653	]=	-0.5418349	;
    RnonCO2[	654	]=	-0.5418399	;
    RnonCO2[	655	]=	-0.5418459	;
    RnonCO2[	656	]=	-0.5418478	;
    RnonCO2[	657	]=	-0.5418405	;
    RnonCO2[	658	]=	-0.5418239	;
    RnonCO2[	659	]=	-0.5418021	;
    RnonCO2[	660	]=	-0.5417777	;
    RnonCO2[	661	]=	-0.5417513	;
    RnonCO2[	662	]=	-0.5417242	;
    RnonCO2[	663	]=	-0.5417069	;
    RnonCO2[	664	]=	-0.541705	;
    RnonCO2[	665	]=	-0.5417102	;
    RnonCO2[	666	]=	-0.5417162	;
    RnonCO2[	667	]=	-0.5417182	;
    RnonCO2[	668	]=	-0.5417109	;
    RnonCO2[	669	]=	-0.5416945	;
    RnonCO2[	670	]=	-0.5416728	;
    RnonCO2[	671	]=	-0.5416484	;
    RnonCO2[	672	]=	-0.5416222	;
    RnonCO2[	673	]=	-0.5415951	;
    RnonCO2[	674	]=	-0.5415779	;
    RnonCO2[	675	]=	-0.5415761	;
    RnonCO2[	676	]=	-0.5415812	;
    RnonCO2[	677	]=	-0.5415873	;
    RnonCO2[	678	]=	-0.5415895	;
    RnonCO2[	679	]=	-0.5415823	;
    RnonCO2[	680	]=	-0.5415659	;
    RnonCO2[	681	]=	-0.5415443	;
    RnonCO2[	682	]=	-0.5415199	;
    RnonCO2[	683	]=	-0.5414939	;
    RnonCO2[	684	]=	-0.5414669	;
    RnonCO2[	685	]=	-0.5414497	;
    RnonCO2[	686	]=	-0.541448	;
    RnonCO2[	687	]=	-0.5414532	;
    RnonCO2[	688	]=	-0.5414594	;
    RnonCO2[	689	]=	-0.5414616	;
    RnonCO2[	690	]=	-0.5414545	;
    RnonCO2[	691	]=	-0.5414382	;
    RnonCO2[	692	]=	-0.5414166	;
    RnonCO2[	693	]=	-0.5413924	;
    RnonCO2[	694	]=	-0.5413663	;
    RnonCO2[	695	]=	-0.5413394	;
    RnonCO2[	696	]=	-0.5413224	;
    RnonCO2[	697	]=	-0.5413208	;
    RnonCO2[	698	]=	-0.541326	;
    RnonCO2[	699	]=	-0.5413324	;
    RnonCO2[	700	]=	-0.5413346	;
    RnonCO2[	701	]=	-0.5413275	;
    RnonCO2[	702	]=	-0.5413112	;
    RnonCO2[	703	]=	-0.5412899	;
    RnonCO2[	704	]=	-0.5412657	;
    RnonCO2[	705	]=	-0.5412398	;
    RnonCO2[	706	]=	-0.5412128	;
    RnonCO2[	707	]=	-0.5411959	;
    RnonCO2[	708	]=	-0.5411943	;
    RnonCO2[	709	]=	-0.5411997	;
    RnonCO2[	710	]=	-0.541206	;
    RnonCO2[	711	]=	-0.5412084	;
    RnonCO2[	712	]=	-0.5412014	;
    RnonCO2[	713	]=	-0.5411852	;
    RnonCO2[	714	]=	-0.5411638	;
    RnonCO2[	715	]=	-0.5411398	;
    RnonCO2[	716	]=	-0.5411139	;
    RnonCO2[	717	]=	-0.5410871	;
    RnonCO2[	718	]=	-0.5410701	;
    RnonCO2[	719	]=	-0.5410686	;
    RnonCO2[	720	]=	-0.5410741	;
    RnonCO2[	721	]=	-0.5410805	;
    RnonCO2[	722	]=	-0.5410829	;
    RnonCO2[	723	]=	-0.5410759	;
    RnonCO2[	724	]=	-0.5410599	;
    RnonCO2[	725	]=	-0.5410386	;
    RnonCO2[	726	]=	-0.5410145	;
    RnonCO2[	727	]=	-0.5409887	;
    RnonCO2[	728	]=	-0.540962	;
    RnonCO2[	729	]=	-0.5409451	;
    RnonCO2[	730	]=	-0.5409437	;
    RnonCO2[	731	]=	-0.5409492	;
    RnonCO2[	732	]=	-0.5409557	;
    RnonCO2[	733	]=	-0.54095816	;
    RnonCO2[	734	]=	-0.54095127	;
    RnonCO2[	735	]=	-0.5409449	;
    
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_RCP6(void)
{
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.004314432	;
    RnonCO2[	2	]=	0.008877103	;
    RnonCO2[	3	]=	0.009366935	;
    RnonCO2[	4	]=	0.00984243	;
    RnonCO2[	5	]=	0.010303014	;
    RnonCO2[	6	]=	0.010751385	;
    RnonCO2[	7	]=	0.011190869	;
    RnonCO2[	8	]=	0.01162232	;
    RnonCO2[	9	]=	0.012045243	;
    RnonCO2[	10	]=	0.012459081	;
    RnonCO2[	11	]=	0.012863113	;
    RnonCO2[	12	]=	0.013256576	;
    RnonCO2[	13	]=	0.013638884	;
    RnonCO2[	14	]=	0.014009567	;
    RnonCO2[	15	]=	0.014366637	;
    RnonCO2[	16	]=	0.014706055	;
    RnonCO2[	17	]=	0.015026378	;
    RnonCO2[	18	]=	0.015331384	;
    RnonCO2[	19	]=	0.015626956	;
    RnonCO2[	20	]=	0.015918925	;
    RnonCO2[	21	]=	0.01621293	;
    RnonCO2[	22	]=	0.016514514	;
    RnonCO2[	23	]=	0.016829376	;
    RnonCO2[	24	]=	0.017163338	;
    RnonCO2[	25	]=	0.017521083	;
    RnonCO2[	26	]=	0.017903698	;
    RnonCO2[	27	]=	0.01830912	;
    RnonCO2[	28	]=	0.018735197	;
    RnonCO2[	29	]=	0.019180394	;
    RnonCO2[	30	]=	0.01964318	;
    RnonCO2[	31	]=	0.02012184	;
    RnonCO2[	32	]=	0.02061459	;
    RnonCO2[	33	]=	0.02111978	;
    RnonCO2[	34	]=	0.02163591	;
    RnonCO2[	35	]=	0.02216446	;
    RnonCO2[	36	]=	0.02271248	;
    RnonCO2[	37	]=	0.02328571	;
    RnonCO2[	38	]=	0.0238829	;
    RnonCO2[	39	]=	0.02449959	;
    RnonCO2[	40	]=	0.02513135	;
    RnonCO2[	41	]=	0.02577366	;
    RnonCO2[	42	]=	0.02642202	;
    RnonCO2[	43	]=	0.02707192	;
    RnonCO2[	44	]=	0.02771893	;
    RnonCO2[	45	]=	0.02836089	;
    RnonCO2[	46	]=	0.02900087	;
    RnonCO2[	47	]=	0.02964356	;
    RnonCO2[	48	]=	0.03029043	;
    RnonCO2[	49	]=	0.03094103	;
    RnonCO2[	50	]=	0.03159488	;
    RnonCO2[	51	]=	0.03225155	;
    RnonCO2[	52	]=	0.0329106	;
    RnonCO2[	53	]=	0.03357157	;
    RnonCO2[	54	]=	0.03423393	;
    RnonCO2[	55	]=	0.03489733	;
    RnonCO2[	56	]=	0.03556198	;
    RnonCO2[	57	]=	0.03622841	;
    RnonCO2[	58	]=	0.03689698	;
    RnonCO2[	59	]=	0.03756791	;
    RnonCO2[	60	]=	0.03824135	;
    RnonCO2[	61	]=	0.03891758	;
    RnonCO2[	62	]=	0.03959693	;
    RnonCO2[	63	]=	0.04027961	;
    RnonCO2[	64	]=	0.04096581	;
    RnonCO2[	65	]=	0.04165447	;
    RnonCO2[	66	]=	0.04234275	;
    RnonCO2[	67	]=	0.04302909	;
    RnonCO2[	68	]=	0.04371511	;
    RnonCO2[	69	]=	0.04440374	;
    RnonCO2[	70	]=	0.0450979	;
    RnonCO2[	71	]=	0.04580059	;
    RnonCO2[	72	]=	0.04651493	;
    RnonCO2[	73	]=	0.0472439	;
    RnonCO2[	74	]=	0.04799039	;
    RnonCO2[	75	]=	0.04875957	;
    RnonCO2[	76	]=	0.04956908	;
    RnonCO2[	77	]=	0.05043603	;
    RnonCO2[	78	]=	0.05134235	;
    RnonCO2[	79	]=	0.05223923	;
    RnonCO2[	80	]=	0.05307263	;
    RnonCO2[	81	]=	0.05381898	;
    RnonCO2[	82	]=	0.05450612	;
    RnonCO2[	83	]=	0.05516657	;
    RnonCO2[	84	]=	0.05580469	;
    RnonCO2[	85	]=	0.05649661	;
    RnonCO2[	86	]=	0.05747303	;
    RnonCO2[	87	]=	0.05866701	;
    RnonCO2[	88	]=	0.0598601	;
    RnonCO2[	89	]=	0.0610523	;
    RnonCO2[	90	]=	0.06210314	;
    RnonCO2[	91	]=	0.06315323	;
    RnonCO2[	92	]=	0.06434304	;
    RnonCO2[	93	]=	0.06553198	;
    RnonCO2[	94	]=	0.06672003	;
    RnonCO2[	95	]=	0.06790722	;
    RnonCO2[	96	]=	0.06909353	;
    RnonCO2[	97	]=	0.07027898	;
    RnonCO2[	98	]=	0.07146355	;
    RnonCO2[	99	]=	0.07264725	;
    RnonCO2[	100	]=	0.07396922	;
    RnonCO2[	101	]=	0.0752902	;
    RnonCO2[	102	]=	0.07647106	;
    RnonCO2[	103	]=	0.07765105	;
    RnonCO2[	104	]=	0.07883019	;
    RnonCO2[	105	]=	0.08006188	;
    RnonCO2[	106	]=	0.0812076	;
    RnonCO2[	107	]=	0.08229901	;
    RnonCO2[	108	]=	0.08347458	;
    RnonCO2[	109	]=	0.08464931	;
    RnonCO2[	110	]=	0.08587598	;
    RnonCO2[	111	]=	0.08701708	;
    RnonCO2[	112	]=	0.08810499	;
    RnonCO2[	113	]=	0.08927741	;
    RnonCO2[	114	]=	0.09044939	;
    RnonCO2[	115	]=	0.09175792	;
    RnonCO2[	116	]=	0.09320276	;
    RnonCO2[	117	]=	0.09464664	;
    RnonCO2[	118	]=	0.09608949	;
    RnonCO2[	119	]=	0.09739496	;
    RnonCO2[	120	]=	0.0985634	;
    RnonCO2[	121	]=	0.09986768	;
    RnonCO2[	122	]=	0.10122271	;
    RnonCO2[	123	]=	0.10249213	;
    RnonCO2[	124	]=	0.10384549	;
    RnonCO2[	125	]=	0.10528284	;
    RnonCO2[	126	]=	0.10685466	;
    RnonCO2[	127	]=	0.1085606	;
    RnonCO2[	128	]=	0.11004559	;
    RnonCO2[	129	]=	0.11131004	;
    RnonCO2[	130	]=	0.11270838	;
    RnonCO2[	131	]=	0.1142403	;
    RnonCO2[	132	]=	0.11572158	;
    RnonCO2[	133	]=	0.11720182	;
    RnonCO2[	134	]=	0.11873056	;
    RnonCO2[	135	]=	0.12048167	;
    RnonCO2[	136	]=	0.12271612	;
    RnonCO2[	137	]=	0.12520844	;
    RnonCO2[	138	]=	0.12782821	;
    RnonCO2[	139	]=	0.13057484	;
    RnonCO2[	140	]=	0.13331526	;
    RnonCO2[	141	]=	0.13605041	;
    RnonCO2[	142	]=	0.13887031	;
    RnonCO2[	143	]=	0.14190497	;
    RnonCO2[	144	]=	0.14506366	;
    RnonCO2[	145	]=	0.14808479	;
    RnonCO2[	146	]=	0.15096905	;
    RnonCO2[	147	]=	0.15406256	;
    RnonCO2[	148	]=	0.15742306	;
    RnonCO2[	149	]=	0.16083056	;
    RnonCO2[	150	]=	0.16429017	;
    RnonCO2[	151	]=	0.16780522	;
    RnonCO2[	152	]=	0.17141349	;
    RnonCO2[	153	]=	0.17524964	;
    RnonCO2[	154	]=	0.17912698	;
    RnonCO2[	155	]=	0.18286803	;
    RnonCO2[	156	]=	0.18655793	;
    RnonCO2[	157	]=	0.19028114	;
    RnonCO2[	158	]=	0.19403945	;
    RnonCO2[	159	]=	0.19779207	;
    RnonCO2[	160	]=	0.2015367	;
    RnonCO2[	161	]=	0.20536218	;
    RnonCO2[	162	]=	0.20918465	;
    RnonCO2[	163	]=	0.21283052	;
    RnonCO2[	164	]=	0.2163449	;
    RnonCO2[	165	]=	0.21972929	;
    RnonCO2[	166	]=	0.22302895	;
    RnonCO2[	167	]=	0.22640626	;
    RnonCO2[	168	]=	0.22985789	;
    RnonCO2[	169	]=	0.23320109	;
    RnonCO2[	170	]=	0.2364361	;
    RnonCO2[	171	]=	0.23966811	;
    RnonCO2[	172	]=	0.2428137	;
    RnonCO2[	173	]=	0.24587625	;
    RnonCO2[	174	]=	0.248943	;
    RnonCO2[	175	]=	0.25213499	;
    RnonCO2[	176	]=	0.25554226	;
    RnonCO2[	177	]=	0.25892918	;
    RnonCO2[	178	]=	0.26220864	;
    RnonCO2[	179	]=	0.26570209	;
    RnonCO2[	180	]=	0.26941573	;
    RnonCO2[	181	]=	0.273294	;
    RnonCO2[	182	]=	0.27751544	;
    RnonCO2[	183	]=	0.28201064	;
    RnonCO2[	184	]=	0.28674226	;
    RnonCO2[	185	]=	0.29175313	;
    RnonCO2[	186	]=	0.29696911	;
    RnonCO2[	187	]=	0.30255457	;
    RnonCO2[	188	]=	0.30858029	;
    RnonCO2[	189	]=	0.31473264	;
    RnonCO2[	190	]=	0.32113183	;
    RnonCO2[	191	]=	0.32799691	;
    RnonCO2[	192	]=	0.33518916	;
    RnonCO2[	193	]=	0.34268013	;
    RnonCO2[	194	]=	0.35054912	;
    RnonCO2[	195	]=	0.3588091	;
    RnonCO2[	196	]=	0.36744837	;
    RnonCO2[	197	]=	0.37654998	;
    RnonCO2[	198	]=	0.38629282	;
    RnonCO2[	199	]=	0.39687085	;
    RnonCO2[	200	]=	0.40827014	;
    RnonCO2[	201	]=	0.4202703	;
    RnonCO2[	202	]=	0.43287302	;
    RnonCO2[	203	]=	0.44635066	;
    RnonCO2[	204	]=	0.46086195	;
    RnonCO2[	205	]=	0.47625741	;
    RnonCO2[	206	]=	0.49233715	;
    RnonCO2[	207	]=	0.50922498	;
    RnonCO2[	208	]=	0.52712569	;
    RnonCO2[	209	]=	0.54610485	;
    RnonCO2[	210	]=	0.56604558	;
    RnonCO2[	211	]=	0.58635079	;
    RnonCO2[	212	]=	0.6067464	;
    RnonCO2[	213	]=	0.6271609	;
    RnonCO2[	214	]=	0.6475189	;
    RnonCO2[	215	]=	0.6673124	;
    RnonCO2[	216	]=	0.6879383	;
    RnonCO2[	217	]=	0.7090557	;
    RnonCO2[	218	]=	0.7289172	;
    RnonCO2[	219	]=	0.7480442	;
    RnonCO2[	220	]=	0.766979	;
    RnonCO2[	221	]=	0.7850643	;
    RnonCO2[	222	]=	0.803085	;
    RnonCO2[	223	]=	0.8236521	;
    RnonCO2[	224	]=	0.8452713	;
    RnonCO2[	225	]=	0.864246	;
    RnonCO2[	226	]=	0.8809743	;
    RnonCO2[	227	]=	0.8949711	;
    RnonCO2[	228	]=	0.9053237	;
    RnonCO2[	229	]=	0.914042	;
    RnonCO2[	230	]=	0.9219104	;
    RnonCO2[	231	]=	0.9290394	;
    RnonCO2[	232	]=	0.9359876	;
    RnonCO2[	233	]=	0.9434778	;
    RnonCO2[	234	]=	0.9502339	;
    RnonCO2[	235	]=	0.9548618	;
    RnonCO2[	236	]=	0.9587726	;
    RnonCO2[	237	]=	0.9638465	;
    RnonCO2[	238	]=	0.9690029	;
    RnonCO2[	239	]=	0.972858	;
    RnonCO2[	240	]=	0.9761909	;
    RnonCO2[	241	]=	0.979865	;
    RnonCO2[	242	]=	0.9838607	;
    RnonCO2[	243	]=	0.9881962	;
    RnonCO2[	244	]=	0.9926917	;
    RnonCO2[	245	]=	0.9972453	;
    RnonCO2[	246	]=	1.0018881	;
    RnonCO2[	247	]=	1.0063484	;
    RnonCO2[	248	]=	1.0103817	;
    RnonCO2[	249	]=	1.0140262	;
    RnonCO2[	250	]=	1.0173217	;
    RnonCO2[	251	]=	1.0202781	;
    RnonCO2[	252	]=	1.0229149	;
    RnonCO2[	253	]=	1.0252597	;
    RnonCO2[	254	]=	1.0273159	;
    RnonCO2[	255	]=	1.0290893	;
    RnonCO2[	256	]=	1.0305521	;
    RnonCO2[	257	]=	1.0319004	;
    RnonCO2[	258	]=	1.0333688	;
    RnonCO2[	259	]=	1.0349681	;
    RnonCO2[	260	]=	1.0367072	;
    RnonCO2[	261	]=	1.0385984	;
    RnonCO2[	262	]=	1.0406353	;
    RnonCO2[	263	]=	1.042799	;
    RnonCO2[	264	]=	1.045076	;
    RnonCO2[	265	]=	1.0474575	;
    RnonCO2[	266	]=	1.0499391	;
    RnonCO2[	267	]=	1.0524481	;
    RnonCO2[	268	]=	1.054891	;
    RnonCO2[	269	]=	1.0572297	;
    RnonCO2[	270	]=	1.0594342	;
    RnonCO2[	271	]=	1.0614837	;
    RnonCO2[	272	]=	1.0633689	;
    RnonCO2[	273	]=	1.0650698	;
    RnonCO2[	274	]=	1.0665599	;
    RnonCO2[	275	]=	1.0678224	;
    RnonCO2[	276	]=	1.0688481	;
    RnonCO2[	277	]=	1.0696204	;
    RnonCO2[	278	]=	1.070133	;
    RnonCO2[	279	]=	1.0704387	;
    RnonCO2[	280	]=	1.0706254	;
    RnonCO2[	281	]=	1.0707631	;
    RnonCO2[	282	]=	1.0709097	;
    RnonCO2[	283	]=	1.0711173	;
    RnonCO2[	284	]=	1.0714131	;
    RnonCO2[	285	]=	1.0718053	;
    RnonCO2[	286	]=	1.0723038	;
    RnonCO2[	287	]=	1.0729023	;
    RnonCO2[	288	]=	1.0735907	;
    RnonCO2[	289	]=	1.0743409	;
    RnonCO2[	290	]=	1.0751375	;
    RnonCO2[	291	]=	1.0760106	;
    RnonCO2[	292	]=	1.0769825	;
    RnonCO2[	293	]=	1.0780711	;
    RnonCO2[	294	]=	1.0792954	;
    RnonCO2[	295	]=	1.0806557	;
    RnonCO2[	296	]=	1.0821355	;
    RnonCO2[	297	]=	1.0836592	;
    RnonCO2[	298	]=	1.0851638	;
    RnonCO2[	299	]=	1.0866533	;
    RnonCO2[	300	]=	1.0880982	;
    RnonCO2[	301	]=	1.0894825	;
    RnonCO2[	302	]=	1.0908356	;
    RnonCO2[	303	]=	1.0921806	;
    RnonCO2[	304	]=	1.0935374	;
    RnonCO2[	305	]=	1.0949267	;
    RnonCO2[	306	]=	1.0963533	;
    RnonCO2[	307	]=	1.0976809	;
    RnonCO2[	308	]=	1.0987856	;
    RnonCO2[	309	]=	1.0996843	;
    RnonCO2[	310	]=	1.1003929	;
    RnonCO2[	311	]=	1.100894	;
    RnonCO2[	312	]=	1.1011824	;
    RnonCO2[	313	]=	1.1012974	;
    RnonCO2[	314	]=	1.1012716	;
    RnonCO2[	315	]=	1.1011335	;
    RnonCO2[	316	]=	1.1009134	;
    RnonCO2[	317	]=	1.1002909	;
    RnonCO2[	318	]=	1.0989556	;
    RnonCO2[	319	]=	1.0969561	;
    RnonCO2[	320	]=	1.0943407	;
    RnonCO2[	321	]=	1.0911536	;
    RnonCO2[	322	]=	1.0874039	;
    RnonCO2[	323	]=	1.0831111	;
    RnonCO2[	324	]=	1.0783352	;
    RnonCO2[	325	]=	1.0731283	;
    RnonCO2[	326	]=	1.0675364	;
    RnonCO2[	327	]=	1.0618862	;
    RnonCO2[	328	]=	1.0564668	;
    RnonCO2[	329	]=	1.0512526	;
    RnonCO2[	330	]=	1.0462228	;
    RnonCO2[	331	]=	1.0413613	;
    RnonCO2[	332	]=	1.0366536	;
    RnonCO2[	333	]=	1.0321188	;
    RnonCO2[	334	]=	1.0278132	;
    RnonCO2[	335	]=	1.0237623	;
    RnonCO2[	336	]=	1.0199536	;
    RnonCO2[	337	]=	1.0165209	;
    RnonCO2[	338	]=	1.0135833	;
    RnonCO2[	339	]=	1.0110843	;
    RnonCO2[	340	]=	1.0089625	;
    RnonCO2[	341	]=	1.0071658	;
    RnonCO2[	342	]=	1.0056514	;
    RnonCO2[	343	]=	1.0043812	;
    RnonCO2[	344	]=	1.0032942	;
    RnonCO2[	345	]=	1.0023453	;
    RnonCO2[	346	]=	1.0015329	;
    RnonCO2[	347	]=	1.000853	;
    RnonCO2[	348	]=	1.0003004	;
    RnonCO2[	349	]=	0.9998729	;
    RnonCO2[	350	]=	0.999555	;
    RnonCO2[	351	]=	0.9993217	;
    RnonCO2[	352	]=	0.999153	;
    RnonCO2[	353	]=	0.9990352	;
    RnonCO2[	354	]=	0.9989564	;
    RnonCO2[	355	]=	0.9988787	;
    RnonCO2[	356	]=	0.9987782	;
    RnonCO2[	357	]=	0.9986708	;
    RnonCO2[	358	]=	0.9985689	;
    RnonCO2[	359	]=	0.9984817	;
    RnonCO2[	360	]=	0.9984199	;
    RnonCO2[	361	]=	0.9983791	;
    RnonCO2[	362	]=	0.9983445	;
    RnonCO2[	363	]=	0.9983059	;
    RnonCO2[	364	]=	0.9982573	;
    RnonCO2[	365	]=	0.998194	;
    RnonCO2[	366	]=	0.9980849	;
    RnonCO2[	367	]=	0.9979118	;
    RnonCO2[	368	]=	0.9976956	;
    RnonCO2[	369	]=	0.9974531	;
    RnonCO2[	370	]=	0.9971971	;
    RnonCO2[	371	]=	0.9969416	;
    RnonCO2[	372	]=	0.9966855	;
    RnonCO2[	373	]=	0.9964167	;
    RnonCO2[	374	]=	0.9961273	;
    RnonCO2[	375	]=	0.9958138	;
    RnonCO2[	376	]=	0.995473	;
    RnonCO2[	377	]=	0.9950759	;
    RnonCO2[	378	]=	0.994606	;
    RnonCO2[	379	]=	0.9940855	;
    RnonCO2[	380	]=	0.9935321	;
    RnonCO2[	381	]=	0.9929597	;
    RnonCO2[	382	]=	0.992383	;
    RnonCO2[	383	]=	0.9918017	;
    RnonCO2[	384	]=	0.9912045	;
    RnonCO2[	385	]=	0.9909006	;
    RnonCO2[	386	]=	0.9909006	;
    RnonCO2[	387	]=	0.9909006	;
    RnonCO2[	388	]=	0.9909006	;
    RnonCO2[	389	]=	0.9909006	;
    RnonCO2[	390	]=	0.9909006	;
    RnonCO2[	391	]=	0.9909006	;
    RnonCO2[	392	]=	0.9909006	;
    RnonCO2[	393	]=	0.9909006	;
    RnonCO2[	394	]=	0.9909006	;
    RnonCO2[	395	]=	0.9909006	;
    RnonCO2[	396	]=	0.9909006	;
    RnonCO2[	397	]=	0.9909006	;
    RnonCO2[	398	]=	0.9909006	;
    RnonCO2[	399	]=	0.9909006	;
    RnonCO2[	400	]=	0.9909006	;
    RnonCO2[	401	]=	0.9909006	;
    RnonCO2[	402	]=	0.9909006	;
    RnonCO2[	403	]=	0.9909006	;
    RnonCO2[	404	]=	0.9909006	;
    RnonCO2[	405	]=	0.9909006	;
    RnonCO2[	406	]=	0.9909006	;
    RnonCO2[	407	]=	0.9909006	;
    RnonCO2[	408	]=	0.9909006	;
    RnonCO2[	409	]=	0.9909006	;
    RnonCO2[	410	]=	0.9909006	;
    RnonCO2[	411	]=	0.9909006	;
    RnonCO2[	412	]=	0.9909006	;
    RnonCO2[	413	]=	0.9909006	;
    RnonCO2[	414	]=	0.9909006	;
    RnonCO2[	415	]=	0.9909006	;
    RnonCO2[	416	]=	0.9909006	;
    RnonCO2[	417	]=	0.9909006	;
    RnonCO2[	418	]=	0.9909006	;
    RnonCO2[	419	]=	0.9909006	;
    RnonCO2[	420	]=	0.9909006	;
    RnonCO2[	421	]=	0.9909006	;
    RnonCO2[	422	]=	0.9909006	;
    RnonCO2[	423	]=	0.9909006	;
    RnonCO2[	424	]=	0.9909006	;
    RnonCO2[	425	]=	0.9909006	;
    RnonCO2[	426	]=	0.9909006	;
    RnonCO2[	427	]=	0.9909006	;
    RnonCO2[	428	]=	0.9909006	;
    RnonCO2[	429	]=	0.9909006	;
    RnonCO2[	430	]=	0.9909006	;
    RnonCO2[	431	]=	0.9909006	;
    RnonCO2[	432	]=	0.9909006	;
    RnonCO2[	433	]=	0.9909006	;
    RnonCO2[	434	]=	0.9909006	;
    RnonCO2[	435	]=	0.9909006	;
    RnonCO2[	436	]=	0.9909006	;
    RnonCO2[	437	]=	0.9909006	;
    RnonCO2[	438	]=	0.9909006	;
    RnonCO2[	439	]=	0.9909006	;
    RnonCO2[	440	]=	0.9909006	;
    RnonCO2[	441	]=	0.9909006	;
    RnonCO2[	442	]=	0.9909006	;
    RnonCO2[	443	]=	0.9909006	;
    RnonCO2[	444	]=	0.9909006	;
    RnonCO2[	445	]=	0.9909006	;
    RnonCO2[	446	]=	0.9909006	;
    RnonCO2[	447	]=	0.9909006	;
    RnonCO2[	448	]=	0.9909006	;
    RnonCO2[	449	]=	0.9909006	;
    RnonCO2[	450	]=	0.9909006	;
    RnonCO2[	451	]=	0.9909006	;
    RnonCO2[	452	]=	0.9909006	;
    RnonCO2[	453	]=	0.9909006	;
    RnonCO2[	454	]=	0.9909006	;
    RnonCO2[	455	]=	0.9909006	;
    RnonCO2[	456	]=	0.9909006	;
    RnonCO2[	457	]=	0.9909006	;
    RnonCO2[	458	]=	0.9909006	;
    RnonCO2[	459	]=	0.9909006	;
    RnonCO2[	460	]=	0.9909006	;
    RnonCO2[	461	]=	0.9909006	;
    RnonCO2[	462	]=	0.9909006	;
    RnonCO2[	463	]=	0.9909006	;
    RnonCO2[	464	]=	0.9909006	;
    RnonCO2[	465	]=	0.9909006	;
    RnonCO2[	466	]=	0.9909006	;
    RnonCO2[	467	]=	0.9909006	;
    RnonCO2[	468	]=	0.9909006	;
    RnonCO2[	469	]=	0.9909006	;
    RnonCO2[	470	]=	0.9909006	;
    RnonCO2[	471	]=	0.9909006	;
    RnonCO2[	472	]=	0.9909006	;
    RnonCO2[	473	]=	0.9909006	;
    RnonCO2[	474	]=	0.9909006	;
    RnonCO2[	475	]=	0.9909006	;
    RnonCO2[	476	]=	0.9909006	;
    RnonCO2[	477	]=	0.9909006	;
    RnonCO2[	478	]=	0.9909006	;
    RnonCO2[	479	]=	0.9909006	;
    RnonCO2[	480	]=	0.9909006	;
    RnonCO2[	481	]=	0.9909006	;
    RnonCO2[	482	]=	0.9909006	;
    RnonCO2[	483	]=	0.9909006	;
    RnonCO2[	484	]=	0.9909006	;
    RnonCO2[	485	]=	0.9909006	;
    RnonCO2[	486	]=	0.9909006	;
    RnonCO2[	487	]=	0.9909006	;
    RnonCO2[	488	]=	0.9909006	;
    RnonCO2[	489	]=	0.9909006	;
    RnonCO2[	490	]=	0.9909006	;
    RnonCO2[	491	]=	0.9909006	;
    RnonCO2[	492	]=	0.9909006	;
    RnonCO2[	493	]=	0.9909006	;
    RnonCO2[	494	]=	0.9909006	;
    RnonCO2[	495	]=	0.9909006	;
    RnonCO2[	496	]=	0.9909006	;
    RnonCO2[	497	]=	0.9909006	;
    RnonCO2[	498	]=	0.9909006	;
    RnonCO2[	499	]=	0.9909006	;
    RnonCO2[	500	]=	0.9909006	;
    RnonCO2[	501	]=	0.9909006	;
    RnonCO2[	502	]=	0.9909006	;
    RnonCO2[	503	]=	0.9909006	;
    RnonCO2[	504	]=	0.9909006	;
    RnonCO2[	505	]=	0.9909006	;
    RnonCO2[	506	]=	0.9909006	;
    RnonCO2[	507	]=	0.9909006	;
    RnonCO2[	508	]=	0.9909006	;
    RnonCO2[	509	]=	0.9909006	;
    RnonCO2[	510	]=	0.9909006	;
    RnonCO2[	511	]=	0.9909006	;
    RnonCO2[	512	]=	0.9909006	;
    RnonCO2[	513	]=	0.9909006	;
    RnonCO2[	514	]=	0.9909006	;
    RnonCO2[	515	]=	0.9909006	;
    RnonCO2[	516	]=	0.9909006	;
    RnonCO2[	517	]=	0.9909006	;
    RnonCO2[	518	]=	0.9909006	;
    RnonCO2[	519	]=	0.9909006	;
    RnonCO2[	520	]=	0.9909006	;
    RnonCO2[	521	]=	0.9909006	;
    RnonCO2[	522	]=	0.9909006	;
    RnonCO2[	523	]=	0.9909006	;
    RnonCO2[	524	]=	0.9909006	;
    RnonCO2[	525	]=	0.9909006	;
    RnonCO2[	526	]=	0.9909006	;
    RnonCO2[	527	]=	0.9909006	;
    RnonCO2[	528	]=	0.9909006	;
    RnonCO2[	529	]=	0.9909006	;
    RnonCO2[	530	]=	0.9909006	;
    RnonCO2[	531	]=	0.9909006	;
    RnonCO2[	532	]=	0.9909006	;
    RnonCO2[	533	]=	0.9909006	;
    RnonCO2[	534	]=	0.9909006	;
    RnonCO2[	535	]=	0.9909006	;
    RnonCO2[	536	]=	0.9909006	;
    RnonCO2[	537	]=	0.9909006	;
    RnonCO2[	538	]=	0.9909006	;
    RnonCO2[	539	]=	0.9909006	;
    RnonCO2[	540	]=	0.9909006	;
    RnonCO2[	541	]=	0.9909006	;
    RnonCO2[	542	]=	0.9909006	;
    RnonCO2[	543	]=	0.9909006	;
    RnonCO2[	544	]=	0.9909006	;
    RnonCO2[	545	]=	0.9909006	;
    RnonCO2[	546	]=	0.9909006	;
    RnonCO2[	547	]=	0.9909006	;
    RnonCO2[	548	]=	0.9909006	;
    RnonCO2[	549	]=	0.9909006	;
    RnonCO2[	550	]=	0.9909006	;
    RnonCO2[	551	]=	0.9909006	;
    RnonCO2[	552	]=	0.9909006	;
    RnonCO2[	553	]=	0.9909006	;
    RnonCO2[	554	]=	0.9909006	;
    RnonCO2[	555	]=	0.9909006	;
    RnonCO2[	556	]=	0.9909006	;
    RnonCO2[	557	]=	0.9909006	;
    RnonCO2[	558	]=	0.9909006	;
    RnonCO2[	559	]=	0.9909006	;
    RnonCO2[	560	]=	0.9909006	;
    RnonCO2[	561	]=	0.9909006	;
    RnonCO2[	562	]=	0.9909006	;
    RnonCO2[	563	]=	0.9909006	;
    RnonCO2[	564	]=	0.9909006	;
    RnonCO2[	565	]=	0.9909006	;
    RnonCO2[	566	]=	0.9909006	;
    RnonCO2[	567	]=	0.9909006	;
    RnonCO2[	568	]=	0.9909006	;
    RnonCO2[	569	]=	0.9909006	;
    RnonCO2[	570	]=	0.9909006	;
    RnonCO2[	571	]=	0.9909006	;
    RnonCO2[	572	]=	0.9909006	;
    RnonCO2[	573	]=	0.9909006	;
    RnonCO2[	574	]=	0.9909006	;
    RnonCO2[	575	]=	0.9909006	;
    RnonCO2[	576	]=	0.9909006	;
    RnonCO2[	577	]=	0.9909006	;
    RnonCO2[	578	]=	0.9909006	;
    RnonCO2[	579	]=	0.9909006	;
    RnonCO2[	580	]=	0.9909006	;
    RnonCO2[	581	]=	0.9909006	;
    RnonCO2[	582	]=	0.9909006	;
    RnonCO2[	583	]=	0.9909006	;
    RnonCO2[	584	]=	0.9909006	;
    RnonCO2[	585	]=	0.9909006	;
    RnonCO2[	586	]=	0.9909006	;
    RnonCO2[	587	]=	0.9909006	;
    RnonCO2[	588	]=	0.9909006	;
    RnonCO2[	589	]=	0.9909006	;
    RnonCO2[	590	]=	0.9909006	;
    RnonCO2[	591	]=	0.9909006	;
    RnonCO2[	592	]=	0.9909006	;
    RnonCO2[	593	]=	0.9909006	;
    RnonCO2[	594	]=	0.9909006	;
    RnonCO2[	595	]=	0.9909006	;
    RnonCO2[	596	]=	0.9909006	;
    RnonCO2[	597	]=	0.9909006	;
    RnonCO2[	598	]=	0.9909006	;
    RnonCO2[	599	]=	0.9909006	;
    RnonCO2[	600	]=	0.9909006	;
    RnonCO2[	601	]=	0.9909006	;
    RnonCO2[	602	]=	0.9909006	;
    RnonCO2[	603	]=	0.9909006	;
    RnonCO2[	604	]=	0.9909006	;
    RnonCO2[	605	]=	0.9909006	;
    RnonCO2[	606	]=	0.9909006	;
    RnonCO2[	607	]=	0.9909006	;
    RnonCO2[	608	]=	0.9909006	;
    RnonCO2[	609	]=	0.9909006	;
    RnonCO2[	610	]=	0.9909006	;
    RnonCO2[	611	]=	0.9909006	;
    RnonCO2[	612	]=	0.9909006	;
    RnonCO2[	613	]=	0.9909006	;
    RnonCO2[	614	]=	0.9909006	;
    RnonCO2[	615	]=	0.9909006	;
    RnonCO2[	616	]=	0.9909006	;
    RnonCO2[	617	]=	0.9909006	;
    RnonCO2[	618	]=	0.9909006	;
    RnonCO2[	619	]=	0.9909006	;
    RnonCO2[	620	]=	0.9909006	;
    RnonCO2[	621	]=	0.9909006	;
    RnonCO2[	622	]=	0.9909006	;
    RnonCO2[	623	]=	0.9909006	;
    RnonCO2[	624	]=	0.9909006	;
    RnonCO2[	625	]=	0.9909006	;
    RnonCO2[	626	]=	0.9909006	;
    RnonCO2[	627	]=	0.9909006	;
    RnonCO2[	628	]=	0.9909006	;
    RnonCO2[	629	]=	0.9909006	;
    RnonCO2[	630	]=	0.9909006	;
    RnonCO2[	631	]=	0.9909006	;
    RnonCO2[	632	]=	0.9909006	;
    RnonCO2[	633	]=	0.9909006	;
    RnonCO2[	634	]=	0.9909006	;
    RnonCO2[	635	]=	0.9909006	;
    RnonCO2[	636	]=	0.9909006	;
    RnonCO2[	637	]=	0.9909006	;
    RnonCO2[	638	]=	0.9909006	;
    RnonCO2[	639	]=	0.9909006	;
    RnonCO2[	640	]=	0.9909006	;
    RnonCO2[	641	]=	0.9909006	;
    RnonCO2[	642	]=	0.9909006	;
    RnonCO2[	643	]=	0.9909006	;
    RnonCO2[	644	]=	0.9909006	;
    RnonCO2[	645	]=	0.9909006	;
    RnonCO2[	646	]=	0.9909006	;
    RnonCO2[	647	]=	0.9909006	;
    RnonCO2[	648	]=	0.9909006	;
    RnonCO2[	649	]=	0.9909006	;
    RnonCO2[	650	]=	0.9909006	;
    RnonCO2[	651	]=	0.9909006	;
    RnonCO2[	652	]=	0.9909006	;
    RnonCO2[	653	]=	0.9909006	;
    RnonCO2[	654	]=	0.9909006	;
    RnonCO2[	655	]=	0.9909006	;
    RnonCO2[	656	]=	0.9909006	;
    RnonCO2[	657	]=	0.9909006	;
    RnonCO2[	658	]=	0.9909006	;
    RnonCO2[	659	]=	0.9909006	;
    RnonCO2[	660	]=	0.9909006	;
    RnonCO2[	661	]=	0.9909006	;
    RnonCO2[	662	]=	0.9909006	;
    RnonCO2[	663	]=	0.9909006	;
    RnonCO2[	664	]=	0.9909006	;
    RnonCO2[	665	]=	0.9909006	;
    RnonCO2[	666	]=	0.9909006	;
    RnonCO2[	667	]=	0.9909006	;
    RnonCO2[	668	]=	0.9909006	;
    RnonCO2[	669	]=	0.9909006	;
    RnonCO2[	670	]=	0.9909006	;
    RnonCO2[	671	]=	0.9909006	;
    RnonCO2[	672	]=	0.9909006	;
    RnonCO2[	673	]=	0.9909006	;
    RnonCO2[	674	]=	0.9909006	;
    RnonCO2[	675	]=	0.9909006	;
    RnonCO2[	676	]=	0.9909006	;
    RnonCO2[	677	]=	0.9909006	;
    RnonCO2[	678	]=	0.9909006	;
    RnonCO2[	679	]=	0.9909006	;
    RnonCO2[	680	]=	0.9909006	;
    RnonCO2[	681	]=	0.9909006	;
    RnonCO2[	682	]=	0.9909006	;
    RnonCO2[	683	]=	0.9909006	;
    RnonCO2[	684	]=	0.9909006	;
    RnonCO2[	685	]=	0.9909006	;
    RnonCO2[	686	]=	0.9909006	;
    RnonCO2[	687	]=	0.9909006	;
    RnonCO2[	688	]=	0.9909006	;
    RnonCO2[	689	]=	0.9909006	;
    RnonCO2[	690	]=	0.9909006	;
    RnonCO2[	691	]=	0.9909006	;
    RnonCO2[	692	]=	0.9909006	;
    RnonCO2[	693	]=	0.9909006	;
    RnonCO2[	694	]=	0.9909006	;
    RnonCO2[	695	]=	0.9909006	;
    RnonCO2[	696	]=	0.9909006	;
    RnonCO2[	697	]=	0.9909006	;
    RnonCO2[	698	]=	0.9909006	;
    RnonCO2[	699	]=	0.9909006	;
    RnonCO2[	700	]=	0.9909006	;
    RnonCO2[	701	]=	0.9909006	;
    RnonCO2[	702	]=	0.9909006	;
    RnonCO2[	703	]=	0.9909006	;
    RnonCO2[	704	]=	0.9909006	;
    RnonCO2[	705	]=	0.9909006	;
    RnonCO2[	706	]=	0.9909006	;
    RnonCO2[	707	]=	0.9909006	;
    RnonCO2[	708	]=	0.9909006	;
    RnonCO2[	709	]=	0.9909006	;
    RnonCO2[	710	]=	0.9909006	;
    RnonCO2[	711	]=	0.9909006	;
    RnonCO2[	712	]=	0.9909006	;
    RnonCO2[	713	]=	0.9909006	;
    RnonCO2[	714	]=	0.9909006	;
    RnonCO2[	715	]=	0.9909006	;
    RnonCO2[	716	]=	0.9909006	;
    RnonCO2[	717	]=	0.9909006	;
    RnonCO2[	718	]=	0.9909006	;
    RnonCO2[	719	]=	0.9909006	;
    RnonCO2[	720	]=	0.9909006	;
    RnonCO2[	721	]=	0.9909006	;
    RnonCO2[	722	]=	0.9909006	;
    RnonCO2[	723	]=	0.9909006	;
    RnonCO2[	724	]=	0.9909006	;
    RnonCO2[	725	]=	0.9909006	;
    RnonCO2[	726	]=	0.9909006	;
    RnonCO2[	727	]=	0.9909006	;
    RnonCO2[	728	]=	0.9909006	;
    RnonCO2[	729	]=	0.9909006	;
    RnonCO2[	730	]=	0.9909006	;
    RnonCO2[	731	]=	0.9909006	;
    RnonCO2[	732	]=	0.9909006	;
    RnonCO2[	733	]=	0.9909006	;
    RnonCO2[	734	]=	0.9909006	;
    RnonCO2[	735	]=	0.9909006	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_RCP45(void)
{
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.004314432	;
    RnonCO2[	2	]=	0.008877103	;
    RnonCO2[	3	]=	0.009366935	;
    RnonCO2[	4	]=	0.00984243	;
    RnonCO2[	5	]=	0.010303014	;
    RnonCO2[	6	]=	0.010751385	;
    RnonCO2[	7	]=	0.011190869	;
    RnonCO2[	8	]=	0.01162232	;
    RnonCO2[	9	]=	0.012045243	;
    RnonCO2[	10	]=	0.012459081	;
    RnonCO2[	11	]=	0.012863113	;
    RnonCO2[	12	]=	0.013256576	;
    RnonCO2[	13	]=	0.013638884	;
    RnonCO2[	14	]=	0.014009567	;
    RnonCO2[	15	]=	0.014366637	;
    RnonCO2[	16	]=	0.014706055	;
    RnonCO2[	17	]=	0.015026378	;
    RnonCO2[	18	]=	0.015331384	;
    RnonCO2[	19	]=	0.015626956	;
    RnonCO2[	20	]=	0.015918925	;
    RnonCO2[	21	]=	0.01621293	;
    RnonCO2[	22	]=	0.016514514	;
    RnonCO2[	23	]=	0.016829376	;
    RnonCO2[	24	]=	0.017163338	;
    RnonCO2[	25	]=	0.017521083	;
    RnonCO2[	26	]=	0.017903698	;
    RnonCO2[	27	]=	0.01830912	;
    RnonCO2[	28	]=	0.018735197	;
    RnonCO2[	29	]=	0.019180394	;
    RnonCO2[	30	]=	0.01964318	;
    RnonCO2[	31	]=	0.02012184	;
    RnonCO2[	32	]=	0.02061459	;
    RnonCO2[	33	]=	0.02111978	;
    RnonCO2[	34	]=	0.02163591	;
    RnonCO2[	35	]=	0.02216446	;
    RnonCO2[	36	]=	0.02271248	;
    RnonCO2[	37	]=	0.02328571	;
    RnonCO2[	38	]=	0.0238829	;
    RnonCO2[	39	]=	0.02449959	;
    RnonCO2[	40	]=	0.02513135	;
    RnonCO2[	41	]=	0.02577366	;
    RnonCO2[	42	]=	0.02642202	;
    RnonCO2[	43	]=	0.02707192	;
    RnonCO2[	44	]=	0.02771893	;
    RnonCO2[	45	]=	0.02836089	;
    RnonCO2[	46	]=	0.02900087	;
    RnonCO2[	47	]=	0.02964356	;
    RnonCO2[	48	]=	0.03029043	;
    RnonCO2[	49	]=	0.03094103	;
    RnonCO2[	50	]=	0.03159488	;
    RnonCO2[	51	]=	0.03225155	;
    RnonCO2[	52	]=	0.0329106	;
    RnonCO2[	53	]=	0.03357157	;
    RnonCO2[	54	]=	0.03423393	;
    RnonCO2[	55	]=	0.03489733	;
    RnonCO2[	56	]=	0.03556198	;
    RnonCO2[	57	]=	0.03622841	;
    RnonCO2[	58	]=	0.03689698	;
    RnonCO2[	59	]=	0.03756791	;
    RnonCO2[	60	]=	0.03824135	;
    RnonCO2[	61	]=	0.03891758	;
    RnonCO2[	62	]=	0.03959693	;
    RnonCO2[	63	]=	0.04027961	;
    RnonCO2[	64	]=	0.04096581	;
    RnonCO2[	65	]=	0.04165447	;
    RnonCO2[	66	]=	0.04234275	;
    RnonCO2[	67	]=	0.04302909	;
    RnonCO2[	68	]=	0.04371511	;
    RnonCO2[	69	]=	0.04440374	;
    RnonCO2[	70	]=	0.0450979	;
    RnonCO2[	71	]=	0.04580059	;
    RnonCO2[	72	]=	0.04651493	;
    RnonCO2[	73	]=	0.0472439	;
    RnonCO2[	74	]=	0.04799039	;
    RnonCO2[	75	]=	0.04875957	;
    RnonCO2[	76	]=	0.04956908	;
    RnonCO2[	77	]=	0.05043603	;
    RnonCO2[	78	]=	0.05134235	;
    RnonCO2[	79	]=	0.05223923	;
    RnonCO2[	80	]=	0.05307263	;
    RnonCO2[	81	]=	0.05381898	;
    RnonCO2[	82	]=	0.05450612	;
    RnonCO2[	83	]=	0.05516657	;
    RnonCO2[	84	]=	0.05580469	;
    RnonCO2[	85	]=	0.05649661	;
    RnonCO2[	86	]=	0.05747303	;
    RnonCO2[	87	]=	0.05866701	;
    RnonCO2[	88	]=	0.0598601	;
    RnonCO2[	89	]=	0.0610523	;
    RnonCO2[	90	]=	0.06210314	;
    RnonCO2[	91	]=	0.06315323	;
    RnonCO2[	92	]=	0.06434304	;
    RnonCO2[	93	]=	0.06553198	;
    RnonCO2[	94	]=	0.06672003	;
    RnonCO2[	95	]=	0.06790722	;
    RnonCO2[	96	]=	0.06909353	;
    RnonCO2[	97	]=	0.07027898	;
    RnonCO2[	98	]=	0.07146355	;
    RnonCO2[	99	]=	0.07264725	;
    RnonCO2[	100	]=	0.07396922	;
    RnonCO2[	101	]=	0.0752902	;
    RnonCO2[	102	]=	0.07647106	;
    RnonCO2[	103	]=	0.07765105	;
    RnonCO2[	104	]=	0.07883019	;
    RnonCO2[	105	]=	0.08006188	;
    RnonCO2[	106	]=	0.0812076	;
    RnonCO2[	107	]=	0.08229901	;
    RnonCO2[	108	]=	0.08347458	;
    RnonCO2[	109	]=	0.08464931	;
    RnonCO2[	110	]=	0.08587598	;
    RnonCO2[	111	]=	0.08701708	;
    RnonCO2[	112	]=	0.08810499	;
    RnonCO2[	113	]=	0.08927741	;
    RnonCO2[	114	]=	0.09044939	;
    RnonCO2[	115	]=	0.09175792	;
    RnonCO2[	116	]=	0.09320276	;
    RnonCO2[	117	]=	0.09464664	;
    RnonCO2[	118	]=	0.09608949	;
    RnonCO2[	119	]=	0.09739496	;
    RnonCO2[	120	]=	0.0985634	;
    RnonCO2[	121	]=	0.09986768	;
    RnonCO2[	122	]=	0.10122271	;
    RnonCO2[	123	]=	0.10249213	;
    RnonCO2[	124	]=	0.10384549	;
    RnonCO2[	125	]=	0.10528284	;
    RnonCO2[	126	]=	0.10685466	;
    RnonCO2[	127	]=	0.1085606	;
    RnonCO2[	128	]=	0.11004559	;
    RnonCO2[	129	]=	0.11131004	;
    RnonCO2[	130	]=	0.11270838	;
    RnonCO2[	131	]=	0.1142403	;
    RnonCO2[	132	]=	0.11572158	;
    RnonCO2[	133	]=	0.11720182	;
    RnonCO2[	134	]=	0.11873056	;
    RnonCO2[	135	]=	0.12048167	;
    RnonCO2[	136	]=	0.12271612	;
    RnonCO2[	137	]=	0.12520844	;
    RnonCO2[	138	]=	0.12782821	;
    RnonCO2[	139	]=	0.13057484	;
    RnonCO2[	140	]=	0.13331526	;
    RnonCO2[	141	]=	0.13605041	;
    RnonCO2[	142	]=	0.13887031	;
    RnonCO2[	143	]=	0.14190497	;
    RnonCO2[	144	]=	0.14506366	;
    RnonCO2[	145	]=	0.14808479	;
    RnonCO2[	146	]=	0.15096905	;
    RnonCO2[	147	]=	0.15406256	;
    RnonCO2[	148	]=	0.15742306	;
    RnonCO2[	149	]=	0.16083056	;
    RnonCO2[	150	]=	0.16429017	;
    RnonCO2[	151	]=	0.16780522	;
    RnonCO2[	152	]=	0.17141349	;
    RnonCO2[	153	]=	0.17524964	;
    RnonCO2[	154	]=	0.17912698	;
    RnonCO2[	155	]=	0.18286803	;
    RnonCO2[	156	]=	0.18655793	;
    RnonCO2[	157	]=	0.19028114	;
    RnonCO2[	158	]=	0.19403945	;
    RnonCO2[	159	]=	0.19779207	;
    RnonCO2[	160	]=	0.2015367	;
    RnonCO2[	161	]=	0.20536218	;
    RnonCO2[	162	]=	0.20918465	;
    RnonCO2[	163	]=	0.21283052	;
    RnonCO2[	164	]=	0.2163449	;
    RnonCO2[	165	]=	0.21972929	;
    RnonCO2[	166	]=	0.22302895	;
    RnonCO2[	167	]=	0.22640626	;
    RnonCO2[	168	]=	0.22985789	;
    RnonCO2[	169	]=	0.23320109	;
    RnonCO2[	170	]=	0.2364361	;
    RnonCO2[	171	]=	0.23966811	;
    RnonCO2[	172	]=	0.2428137	;
    RnonCO2[	173	]=	0.24587625	;
    RnonCO2[	174	]=	0.248943	;
    RnonCO2[	175	]=	0.25213499	;
    RnonCO2[	176	]=	0.25554226	;
    RnonCO2[	177	]=	0.25892918	;
    RnonCO2[	178	]=	0.26220864	;
    RnonCO2[	179	]=	0.26570209	;
    RnonCO2[	180	]=	0.26941573	;
    RnonCO2[	181	]=	0.273294	;
    RnonCO2[	182	]=	0.27751544	;
    RnonCO2[	183	]=	0.28201064	;
    RnonCO2[	184	]=	0.28674226	;
    RnonCO2[	185	]=	0.29175313	;
    RnonCO2[	186	]=	0.29696911	;
    RnonCO2[	187	]=	0.30255457	;
    RnonCO2[	188	]=	0.30858029	;
    RnonCO2[	189	]=	0.31473264	;
    RnonCO2[	190	]=	0.32113183	;
    RnonCO2[	191	]=	0.32799691	;
    RnonCO2[	192	]=	0.33518916	;
    RnonCO2[	193	]=	0.34268013	;
    RnonCO2[	194	]=	0.35054912	;
    RnonCO2[	195	]=	0.3588091	;
    RnonCO2[	196	]=	0.36744837	;
    RnonCO2[	197	]=	0.37654998	;
    RnonCO2[	198	]=	0.38629282	;
    RnonCO2[	199	]=	0.39687085	;
    RnonCO2[	200	]=	0.40827014	;
    RnonCO2[	201	]=	0.4202703	;
    RnonCO2[	202	]=	0.43287302	;
    RnonCO2[	203	]=	0.44635066	;
    RnonCO2[	204	]=	0.46086195	;
    RnonCO2[	205	]=	0.47625741	;
    RnonCO2[	206	]=	0.49233715	;
    RnonCO2[	207	]=	0.50922498	;
    RnonCO2[	208	]=	0.52712569	;
    RnonCO2[	209	]=	0.54610485	;
    RnonCO2[	210	]=	0.56604558	;
    RnonCO2[	211	]=	0.58635079	;
    RnonCO2[	212	]=	0.6067464	;
    RnonCO2[	213	]=	0.6271609	;
    RnonCO2[	214	]=	0.6475189	;
    RnonCO2[	215	]=	0.6673124	;
    RnonCO2[	216	]=	0.6879383	;
    RnonCO2[	217	]=	0.7090557	;
    RnonCO2[	218	]=	0.7289172	;
    RnonCO2[	219	]=	0.7480442	;
    RnonCO2[	220	]=	0.766979	;
    RnonCO2[	221	]=	0.7850643	;
    RnonCO2[	222	]=	0.803085	;
    RnonCO2[	223	]=	0.8236521	;
    RnonCO2[	224	]=	0.8452713	;
    RnonCO2[	225	]=	0.864246	;
    RnonCO2[	226	]=	0.8809743	;
    RnonCO2[	227	]=	0.8949711	;
    RnonCO2[	228	]=	0.9053237	;
    RnonCO2[	229	]=	0.914042	;
    RnonCO2[	230	]=	0.9219104	;
    RnonCO2[	231	]=	0.9290394	;
    RnonCO2[	232	]=	0.9359876	;
    RnonCO2[	233	]=	0.9434778	;
    RnonCO2[	234	]=	0.9502339	;
    RnonCO2[	235	]=	0.9548618	;
    RnonCO2[	236	]=	0.9587726	;
    RnonCO2[	237	]=	0.9638465	;
    RnonCO2[	238	]=	0.9690029	;
    RnonCO2[	239	]=	0.972858	;
    RnonCO2[	240	]=	0.9761909	;
    RnonCO2[	241	]=	0.9798636	;
    RnonCO2[	242	]=	0.9837885	;
    RnonCO2[	243	]=	0.9879216	;
    RnonCO2[	244	]=	0.9920736	;
    RnonCO2[	245	]=	0.9961362	;
    RnonCO2[	246	]=	1.0001534	;
    RnonCO2[	247	]=	1.0041406	;
    RnonCO2[	248	]=	1.0081179	;
    RnonCO2[	249	]=	1.0120888	;
    RnonCO2[	250	]=	1.0160626	;
    RnonCO2[	251	]=	1.0200208	;
    RnonCO2[	252	]=	1.0239574	;
    RnonCO2[	253	]=	1.0278762	;
    RnonCO2[	254	]=	1.0317588	;
    RnonCO2[	255	]=	1.0355918	;
    RnonCO2[	256	]=	1.0393303	;
    RnonCO2[	257	]=	1.0428685	;
    RnonCO2[	258	]=	1.04616	;
    RnonCO2[	259	]=	1.0492419	;
    RnonCO2[	260	]=	1.0521483	;
    RnonCO2[	261	]=	1.054914	;
    RnonCO2[	262	]=	1.0575542	;
    RnonCO2[	263	]=	1.0600695	;
    RnonCO2[	264	]=	1.0624641	;
    RnonCO2[	265	]=	1.0647461	;
    RnonCO2[	266	]=	1.0669226	;
    RnonCO2[	267	]=	1.0688765	;
    RnonCO2[	268	]=	1.0704761	;
    RnonCO2[	269	]=	1.0717049	;
    RnonCO2[	270	]=	1.0725519	;
    RnonCO2[	271	]=	1.0730135	;
    RnonCO2[	272	]=	1.0730966	;
    RnonCO2[	273	]=	1.0727968	;
    RnonCO2[	274	]=	1.072101	;
    RnonCO2[	275	]=	1.0710055	;
    RnonCO2[	276	]=	1.0695146	;
    RnonCO2[	277	]=	1.0676264	;
    RnonCO2[	278	]=	1.0653457	;
    RnonCO2[	279	]=	1.0627346	;
    RnonCO2[	280	]=	1.0598897	;
    RnonCO2[	281	]=	1.0568894	;
    RnonCO2[	282	]=	1.0537991	;
    RnonCO2[	283	]=	1.0506775	;
    RnonCO2[	284	]=	1.0475581	;
    RnonCO2[	285	]=	1.0444547	;
    RnonCO2[	286	]=	1.0413816	;
    RnonCO2[	287	]=	1.0382878	;
    RnonCO2[	288	]=	1.0351228	;
    RnonCO2[	289	]=	1.0318695	;
    RnonCO2[	290	]=	1.0285234	;
    RnonCO2[	291	]=	1.025124	;
    RnonCO2[	292	]=	1.0217023	;
    RnonCO2[	293	]=	1.0182846	;
    RnonCO2[	294	]=	1.0148969	;
    RnonCO2[	295	]=	1.0115463	;
    RnonCO2[	296	]=	1.0082259	;
    RnonCO2[	297	]=	1.0049176	;
    RnonCO2[	298	]=	1.0016079	;
    RnonCO2[	299	]=	0.9982987	;
    RnonCO2[	300	]=	0.9949603	;
    RnonCO2[	301	]=	0.9915764	;
    RnonCO2[	302	]=	0.988175	;
    RnonCO2[	303	]=	0.9847778	;
    RnonCO2[	304	]=	0.981403	;
    RnonCO2[	305	]=	0.9780696	;
    RnonCO2[	306	]=	0.97478	;
    RnonCO2[	307	]=	0.9715057	;
    RnonCO2[	308	]=	0.968224	;
    RnonCO2[	309	]=	0.9649359	;
    RnonCO2[	310	]=	0.9616425	;
    RnonCO2[	311	]=	0.958314	;
    RnonCO2[	312	]=	0.9549343	;
    RnonCO2[	313	]=	0.9515372	;
    RnonCO2[	314	]=	0.948194	;
    RnonCO2[	315	]=	0.9449594	;
    RnonCO2[	316	]=	0.9418428	;
    RnonCO2[	317	]=	0.9389288	;
    RnonCO2[	318	]=	0.9362802	;
    RnonCO2[	319	]=	0.933865	;
    RnonCO2[	320	]=	0.9316588	;
    RnonCO2[	321	]=	0.9296395	;
    RnonCO2[	322	]=	0.9277583	;
    RnonCO2[	323	]=	0.9259826	;
    RnonCO2[	324	]=	0.9243221	;
    RnonCO2[	325	]=	0.9227825	;
    RnonCO2[	326	]=	0.9213668	;
    RnonCO2[	327	]=	0.9200788	;
    RnonCO2[	328	]=	0.9189076	;
    RnonCO2[	329	]=	0.9178341	;
    RnonCO2[	330	]=	0.9168437	;
    RnonCO2[	331	]=	0.9159271	;
    RnonCO2[	332	]=	0.9150758	;
    RnonCO2[	333	]=	0.9142542	;
    RnonCO2[	334	]=	0.9134406	;
    RnonCO2[	335	]=	0.9126545	;
    RnonCO2[	336	]=	0.9119101	;
    RnonCO2[	337	]=	0.911246	;
    RnonCO2[	338	]=	0.9106951	;
    RnonCO2[	339	]=	0.9102435	;
    RnonCO2[	340	]=	0.9098674	;
    RnonCO2[	341	]=	0.9095496	;
    RnonCO2[	342	]=	0.909278	;
    RnonCO2[	343	]=	0.9090426	;
    RnonCO2[	344	]=	0.9088065	;
    RnonCO2[	345	]=	0.9085477	;
    RnonCO2[	346	]=	0.9082848	;
    RnonCO2[	347	]=	0.9080314	;
    RnonCO2[	348	]=	0.9077981	;
    RnonCO2[	349	]=	0.9075967	;
    RnonCO2[	350	]=	0.9074242	;
    RnonCO2[	351	]=	0.9072668	;
    RnonCO2[	352	]=	0.9071152	;
    RnonCO2[	353	]=	0.9069647	;
    RnonCO2[	354	]=	0.9068114	;
    RnonCO2[	355	]=	0.9066242	;
    RnonCO2[	356	]=	0.9063857	;
    RnonCO2[	357	]=	0.9061185	;
    RnonCO2[	358	]=	0.9058394	;
    RnonCO2[	359	]=	0.9055618	;
    RnonCO2[	360	]=	0.9053001	;
    RnonCO2[	361	]=	0.9050535	;
    RnonCO2[	362	]=	0.9048099	;
    RnonCO2[	363	]=	0.9045621	;
    RnonCO2[	364	]=	0.9043065	;
    RnonCO2[	365	]=	0.9040407	;
    RnonCO2[	366	]=	0.9037348	;
    RnonCO2[	367	]=	0.9033725	;
    RnonCO2[	368	]=	0.9029771	;
    RnonCO2[	369	]=	0.902566	;
    RnonCO2[	370	]=	0.9021532	;
    RnonCO2[	371	]=	0.9017535	;
    RnonCO2[	372	]=	0.9013665	;
    RnonCO2[	373	]=	0.9009809	;
    RnonCO2[	374	]=	0.9005896	;
    RnonCO2[	375	]=	0.9001895	;
    RnonCO2[	376	]=	0.8997785	;
    RnonCO2[	377	]=	0.899327	;
    RnonCO2[	378	]=	0.8988193	;
    RnonCO2[	379	]=	0.8982785	;
    RnonCO2[	380	]=	0.8977223	;
    RnonCO2[	381	]=	0.8971646	;
    RnonCO2[	382	]=	0.8966201	;
    RnonCO2[	383	]=	0.8960888	;
    RnonCO2[	384	]=	0.8955593	;
    RnonCO2[	385	]=	0.8952938	;
    RnonCO2[	386	]=	0.8952938	;
    RnonCO2[	387	]=	0.8952938	;
    RnonCO2[	388	]=	0.8952938	;
    RnonCO2[	389	]=	0.8952938	;
    RnonCO2[	390	]=	0.8952938	;
    RnonCO2[	391	]=	0.8952938	;
    RnonCO2[	392	]=	0.8952938	;
    RnonCO2[	393	]=	0.8952938	;
    RnonCO2[	394	]=	0.8952938	;
    RnonCO2[	395	]=	0.8952938	;
    RnonCO2[	396	]=	0.8952938	;
    RnonCO2[	397	]=	0.8952938	;
    RnonCO2[	398	]=	0.8952938	;
    RnonCO2[	399	]=	0.8952938	;
    RnonCO2[	400	]=	0.8952938	;
    RnonCO2[	401	]=	0.8952938	;
    RnonCO2[	402	]=	0.8952938	;
    RnonCO2[	403	]=	0.8952938	;
    RnonCO2[	404	]=	0.8952938	;
    RnonCO2[	405	]=	0.8952938	;
    RnonCO2[	406	]=	0.8952938	;
    RnonCO2[	407	]=	0.8952938	;
    RnonCO2[	408	]=	0.8952938	;
    RnonCO2[	409	]=	0.8952938	;
    RnonCO2[	410	]=	0.8952938	;
    RnonCO2[	411	]=	0.8952938	;
    RnonCO2[	412	]=	0.8952938	;
    RnonCO2[	413	]=	0.8952938	;
    RnonCO2[	414	]=	0.8952938	;
    RnonCO2[	415	]=	0.8952938	;
    RnonCO2[	416	]=	0.8952938	;
    RnonCO2[	417	]=	0.8952938	;
    RnonCO2[	418	]=	0.8952938	;
    RnonCO2[	419	]=	0.8952938	;
    RnonCO2[	420	]=	0.8952938	;
    RnonCO2[	421	]=	0.8952938	;
    RnonCO2[	422	]=	0.8952938	;
    RnonCO2[	423	]=	0.8952938	;
    RnonCO2[	424	]=	0.8952938	;
    RnonCO2[	425	]=	0.8952938	;
    RnonCO2[	426	]=	0.8952938	;
    RnonCO2[	427	]=	0.8952938	;
    RnonCO2[	428	]=	0.8952938	;
    RnonCO2[	429	]=	0.8952938	;
    RnonCO2[	430	]=	0.8952938	;
    RnonCO2[	431	]=	0.8952938	;
    RnonCO2[	432	]=	0.8952938	;
    RnonCO2[	433	]=	0.8952938	;
    RnonCO2[	434	]=	0.8952938	;
    RnonCO2[	435	]=	0.8952938	;
    RnonCO2[	436	]=	0.8952938	;
    RnonCO2[	437	]=	0.8952938	;
    RnonCO2[	438	]=	0.8952938	;
    RnonCO2[	439	]=	0.8952938	;
    RnonCO2[	440	]=	0.8952938	;
    RnonCO2[	441	]=	0.8952938	;
    RnonCO2[	442	]=	0.8952938	;
    RnonCO2[	443	]=	0.8952938	;
    RnonCO2[	444	]=	0.8952938	;
    RnonCO2[	445	]=	0.8952938	;
    RnonCO2[	446	]=	0.8952938	;
    RnonCO2[	447	]=	0.8952938	;
    RnonCO2[	448	]=	0.8952938	;
    RnonCO2[	449	]=	0.8952938	;
    RnonCO2[	450	]=	0.8952938	;
    RnonCO2[	451	]=	0.8952938	;
    RnonCO2[	452	]=	0.8952938	;
    RnonCO2[	453	]=	0.8952938	;
    RnonCO2[	454	]=	0.8952938	;
    RnonCO2[	455	]=	0.8952938	;
    RnonCO2[	456	]=	0.8952938	;
    RnonCO2[	457	]=	0.8952938	;
    RnonCO2[	458	]=	0.8952938	;
    RnonCO2[	459	]=	0.8952938	;
    RnonCO2[	460	]=	0.8952938	;
    RnonCO2[	461	]=	0.8952938	;
    RnonCO2[	462	]=	0.8952938	;
    RnonCO2[	463	]=	0.8952938	;
    RnonCO2[	464	]=	0.8952938	;
    RnonCO2[	465	]=	0.8952938	;
    RnonCO2[	466	]=	0.8952938	;
    RnonCO2[	467	]=	0.8952938	;
    RnonCO2[	468	]=	0.8952938	;
    RnonCO2[	469	]=	0.8952938	;
    RnonCO2[	470	]=	0.8952938	;
    RnonCO2[	471	]=	0.8952938	;
    RnonCO2[	472	]=	0.8952938	;
    RnonCO2[	473	]=	0.8952938	;
    RnonCO2[	474	]=	0.8952938	;
    RnonCO2[	475	]=	0.8952938	;
    RnonCO2[	476	]=	0.8952938	;
    RnonCO2[	477	]=	0.8952938	;
    RnonCO2[	478	]=	0.8952938	;
    RnonCO2[	479	]=	0.8952938	;
    RnonCO2[	480	]=	0.8952938	;
    RnonCO2[	481	]=	0.8952938	;
    RnonCO2[	482	]=	0.8952938	;
    RnonCO2[	483	]=	0.8952938	;
    RnonCO2[	484	]=	0.8952938	;
    RnonCO2[	485	]=	0.8952938	;
    RnonCO2[	486	]=	0.8952938	;
    RnonCO2[	487	]=	0.8952938	;
    RnonCO2[	488	]=	0.8952938	;
    RnonCO2[	489	]=	0.8952938	;
    RnonCO2[	490	]=	0.8952938	;
    RnonCO2[	491	]=	0.8952938	;
    RnonCO2[	492	]=	0.8952938	;
    RnonCO2[	493	]=	0.8952938	;
    RnonCO2[	494	]=	0.8952938	;
    RnonCO2[	495	]=	0.8952938	;
    RnonCO2[	496	]=	0.8952938	;
    RnonCO2[	497	]=	0.8952938	;
    RnonCO2[	498	]=	0.8952938	;
    RnonCO2[	499	]=	0.8952938	;
    RnonCO2[	500	]=	0.8952938	;
    RnonCO2[	501	]=	0.8952938	;
    RnonCO2[	502	]=	0.8952938	;
    RnonCO2[	503	]=	0.8952938	;
    RnonCO2[	504	]=	0.8952938	;
    RnonCO2[	505	]=	0.8952938	;
    RnonCO2[	506	]=	0.8952938	;
    RnonCO2[	507	]=	0.8952938	;
    RnonCO2[	508	]=	0.8952938	;
    RnonCO2[	509	]=	0.8952938	;
    RnonCO2[	510	]=	0.8952938	;
    RnonCO2[	511	]=	0.8952938	;
    RnonCO2[	512	]=	0.8952938	;
    RnonCO2[	513	]=	0.8952938	;
    RnonCO2[	514	]=	0.8952938	;
    RnonCO2[	515	]=	0.8952938	;
    RnonCO2[	516	]=	0.8952938	;
    RnonCO2[	517	]=	0.8952938	;
    RnonCO2[	518	]=	0.8952938	;
    RnonCO2[	519	]=	0.8952938	;
    RnonCO2[	520	]=	0.8952938	;
    RnonCO2[	521	]=	0.8952938	;
    RnonCO2[	522	]=	0.8952938	;
    RnonCO2[	523	]=	0.8952938	;
    RnonCO2[	524	]=	0.8952938	;
    RnonCO2[	525	]=	0.8952938	;
    RnonCO2[	526	]=	0.8952938	;
    RnonCO2[	527	]=	0.8952938	;
    RnonCO2[	528	]=	0.8952938	;
    RnonCO2[	529	]=	0.8952938	;
    RnonCO2[	530	]=	0.8952938	;
    RnonCO2[	531	]=	0.8952938	;
    RnonCO2[	532	]=	0.8952938	;
    RnonCO2[	533	]=	0.8952938	;
    RnonCO2[	534	]=	0.8952938	;
    RnonCO2[	535	]=	0.8952938	;
    RnonCO2[	536	]=	0.8952938	;
    RnonCO2[	537	]=	0.8952938	;
    RnonCO2[	538	]=	0.8952938	;
    RnonCO2[	539	]=	0.8952938	;
    RnonCO2[	540	]=	0.8952938	;
    RnonCO2[	541	]=	0.8952938	;
    RnonCO2[	542	]=	0.8952938	;
    RnonCO2[	543	]=	0.8952938	;
    RnonCO2[	544	]=	0.8952938	;
    RnonCO2[	545	]=	0.8952938	;
    RnonCO2[	546	]=	0.8952938	;
    RnonCO2[	547	]=	0.8952938	;
    RnonCO2[	548	]=	0.8952938	;
    RnonCO2[	549	]=	0.8952938	;
    RnonCO2[	550	]=	0.8952938	;
    RnonCO2[	551	]=	0.8952938	;
    RnonCO2[	552	]=	0.8952938	;
    RnonCO2[	553	]=	0.8952938	;
    RnonCO2[	554	]=	0.8952938	;
    RnonCO2[	555	]=	0.8952938	;
    RnonCO2[	556	]=	0.8952938	;
    RnonCO2[	557	]=	0.8952938	;
    RnonCO2[	558	]=	0.8952938	;
    RnonCO2[	559	]=	0.8952938	;
    RnonCO2[	560	]=	0.8952938	;
    RnonCO2[	561	]=	0.8952938	;
    RnonCO2[	562	]=	0.8952938	;
    RnonCO2[	563	]=	0.8952938	;
    RnonCO2[	564	]=	0.8952938	;
    RnonCO2[	565	]=	0.8952938	;
    RnonCO2[	566	]=	0.8952938	;
    RnonCO2[	567	]=	0.8952938	;
    RnonCO2[	568	]=	0.8952938	;
    RnonCO2[	569	]=	0.8952938	;
    RnonCO2[	570	]=	0.8952938	;
    RnonCO2[	571	]=	0.8952938	;
    RnonCO2[	572	]=	0.8952938	;
    RnonCO2[	573	]=	0.8952938	;
    RnonCO2[	574	]=	0.8952938	;
    RnonCO2[	575	]=	0.8952938	;
    RnonCO2[	576	]=	0.8952938	;
    RnonCO2[	577	]=	0.8952938	;
    RnonCO2[	578	]=	0.8952938	;
    RnonCO2[	579	]=	0.8952938	;
    RnonCO2[	580	]=	0.8952938	;
    RnonCO2[	581	]=	0.8952938	;
    RnonCO2[	582	]=	0.8952938	;
    RnonCO2[	583	]=	0.8952938	;
    RnonCO2[	584	]=	0.8952938	;
    RnonCO2[	585	]=	0.8952938	;
    RnonCO2[	586	]=	0.8952938	;
    RnonCO2[	587	]=	0.8952938	;
    RnonCO2[	588	]=	0.8952938	;
    RnonCO2[	589	]=	0.8952938	;
    RnonCO2[	590	]=	0.8952938	;
    RnonCO2[	591	]=	0.8952938	;
    RnonCO2[	592	]=	0.8952938	;
    RnonCO2[	593	]=	0.8952938	;
    RnonCO2[	594	]=	0.8952938	;
    RnonCO2[	595	]=	0.8952938	;
    RnonCO2[	596	]=	0.8952938	;
    RnonCO2[	597	]=	0.8952938	;
    RnonCO2[	598	]=	0.8952938	;
    RnonCO2[	599	]=	0.8952938	;
    RnonCO2[	600	]=	0.8952938	;
    RnonCO2[	601	]=	0.8952938	;
    RnonCO2[	602	]=	0.8952938	;
    RnonCO2[	603	]=	0.8952938	;
    RnonCO2[	604	]=	0.8952938	;
    RnonCO2[	605	]=	0.8952938	;
    RnonCO2[	606	]=	0.8952938	;
    RnonCO2[	607	]=	0.8952938	;
    RnonCO2[	608	]=	0.8952938	;
    RnonCO2[	609	]=	0.8952938	;
    RnonCO2[	610	]=	0.8952938	;
    RnonCO2[	611	]=	0.8952938	;
    RnonCO2[	612	]=	0.8952938	;
    RnonCO2[	613	]=	0.8952938	;
    RnonCO2[	614	]=	0.8952938	;
    RnonCO2[	615	]=	0.8952938	;
    RnonCO2[	616	]=	0.8952938	;
    RnonCO2[	617	]=	0.8952938	;
    RnonCO2[	618	]=	0.8952938	;
    RnonCO2[	619	]=	0.8952938	;
    RnonCO2[	620	]=	0.8952938	;
    RnonCO2[	621	]=	0.8952938	;
    RnonCO2[	622	]=	0.8952938	;
    RnonCO2[	623	]=	0.8952938	;
    RnonCO2[	624	]=	0.8952938	;
    RnonCO2[	625	]=	0.8952938	;
    RnonCO2[	626	]=	0.8952938	;
    RnonCO2[	627	]=	0.8952938	;
    RnonCO2[	628	]=	0.8952938	;
    RnonCO2[	629	]=	0.8952938	;
    RnonCO2[	630	]=	0.8952938	;
    RnonCO2[	631	]=	0.8952938	;
    RnonCO2[	632	]=	0.8952938	;
    RnonCO2[	633	]=	0.8952938	;
    RnonCO2[	634	]=	0.8952938	;
    RnonCO2[	635	]=	0.8952938	;
    RnonCO2[	636	]=	0.8952938	;
    RnonCO2[	637	]=	0.8952938	;
    RnonCO2[	638	]=	0.8952938	;
    RnonCO2[	639	]=	0.8952938	;
    RnonCO2[	640	]=	0.8952938	;
    RnonCO2[	641	]=	0.8952938	;
    RnonCO2[	642	]=	0.8952938	;
    RnonCO2[	643	]=	0.8952938	;
    RnonCO2[	644	]=	0.8952938	;
    RnonCO2[	645	]=	0.8952938	;
    RnonCO2[	646	]=	0.8952938	;
    RnonCO2[	647	]=	0.8952938	;
    RnonCO2[	648	]=	0.8952938	;
    RnonCO2[	649	]=	0.8952938	;
    RnonCO2[	650	]=	0.8952938	;
    RnonCO2[	651	]=	0.8952938	;
    RnonCO2[	652	]=	0.8952938	;
    RnonCO2[	653	]=	0.8952938	;
    RnonCO2[	654	]=	0.8952938	;
    RnonCO2[	655	]=	0.8952938	;
    RnonCO2[	656	]=	0.8952938	;
    RnonCO2[	657	]=	0.8952938	;
    RnonCO2[	658	]=	0.8952938	;
    RnonCO2[	659	]=	0.8952938	;
    RnonCO2[	660	]=	0.8952938	;
    RnonCO2[	661	]=	0.8952938	;
    RnonCO2[	662	]=	0.8952938	;
    RnonCO2[	663	]=	0.8952938	;
    RnonCO2[	664	]=	0.8952938	;
    RnonCO2[	665	]=	0.8952938	;
    RnonCO2[	666	]=	0.8952938	;
    RnonCO2[	667	]=	0.8952938	;
    RnonCO2[	668	]=	0.8952938	;
    RnonCO2[	669	]=	0.8952938	;
    RnonCO2[	670	]=	0.8952938	;
    RnonCO2[	671	]=	0.8952938	;
    RnonCO2[	672	]=	0.8952938	;
    RnonCO2[	673	]=	0.8952938	;
    RnonCO2[	674	]=	0.8952938	;
    RnonCO2[	675	]=	0.8952938	;
    RnonCO2[	676	]=	0.8952938	;
    RnonCO2[	677	]=	0.8952938	;
    RnonCO2[	678	]=	0.8952938	;
    RnonCO2[	679	]=	0.8952938	;
    RnonCO2[	680	]=	0.8952938	;
    RnonCO2[	681	]=	0.8952938	;
    RnonCO2[	682	]=	0.8952938	;
    RnonCO2[	683	]=	0.8952938	;
    RnonCO2[	684	]=	0.8952938	;
    RnonCO2[	685	]=	0.8952938	;
    RnonCO2[	686	]=	0.8952938	;
    RnonCO2[	687	]=	0.8952938	;
    RnonCO2[	688	]=	0.8952938	;
    RnonCO2[	689	]=	0.8952938	;
    RnonCO2[	690	]=	0.8952938	;
    RnonCO2[	691	]=	0.8952938	;
    RnonCO2[	692	]=	0.8952938	;
    RnonCO2[	693	]=	0.8952938	;
    RnonCO2[	694	]=	0.8952938	;
    RnonCO2[	695	]=	0.8952938	;
    RnonCO2[	696	]=	0.8952938	;
    RnonCO2[	697	]=	0.8952938	;
    RnonCO2[	698	]=	0.8952938	;
    RnonCO2[	699	]=	0.8952938	;
    RnonCO2[	700	]=	0.8952938	;
    RnonCO2[	701	]=	0.8952938	;
    RnonCO2[	702	]=	0.8952938	;
    RnonCO2[	703	]=	0.8952938	;
    RnonCO2[	704	]=	0.8952938	;
    RnonCO2[	705	]=	0.8952938	;
    RnonCO2[	706	]=	0.8952938	;
    RnonCO2[	707	]=	0.8952938	;
    RnonCO2[	708	]=	0.8952938	;
    RnonCO2[	709	]=	0.8952938	;
    RnonCO2[	710	]=	0.8952938	;
    RnonCO2[	711	]=	0.8952938	;
    RnonCO2[	712	]=	0.8952938	;
    RnonCO2[	713	]=	0.8952938	;
    RnonCO2[	714	]=	0.8952938	;
    RnonCO2[	715	]=	0.8952938	;
    RnonCO2[	716	]=	0.8952938	;
    RnonCO2[	717	]=	0.8952938	;
    RnonCO2[	718	]=	0.8952938	;
    RnonCO2[	719	]=	0.8952938	;
    RnonCO2[	720	]=	0.8952938	;
    RnonCO2[	721	]=	0.8952938	;
    RnonCO2[	722	]=	0.8952938	;
    RnonCO2[	723	]=	0.8952938	;
    RnonCO2[	724	]=	0.8952938	;
    RnonCO2[	725	]=	0.8952938	;
    RnonCO2[	726	]=	0.8952938	;
    RnonCO2[	727	]=	0.8952938	;
    RnonCO2[	728	]=	0.8952938	;
    RnonCO2[	729	]=	0.8952938	;
    RnonCO2[	730	]=	0.8952938	;
    RnonCO2[	731	]=	0.8952938	;
    RnonCO2[	732	]=	0.8952938	;
    RnonCO2[	733	]=	0.8952938	;
    RnonCO2[	734	]=	0.8952938	;
    RnonCO2[	735	]=	0.8952938	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}



void setR_WMGHG_nonCO2_RCP3PD(void)
{
    RnonCO2[	0	]=	0	;
    RnonCO2[	1	]=	0.004314432	;
    RnonCO2[	2	]=	0.008877103	;
    RnonCO2[	3	]=	0.009366935	;
    RnonCO2[	4	]=	0.00984243	;
    RnonCO2[	5	]=	0.010303014	;
    RnonCO2[	6	]=	0.010751385	;
    RnonCO2[	7	]=	0.011190869	;
    RnonCO2[	8	]=	0.01162232	;
    RnonCO2[	9	]=	0.012045243	;
    RnonCO2[	10	]=	0.012459081	;
    RnonCO2[	11	]=	0.012863113	;
    RnonCO2[	12	]=	0.013256576	;
    RnonCO2[	13	]=	0.013638884	;
    RnonCO2[	14	]=	0.014009567	;
    RnonCO2[	15	]=	0.014366637	;
    RnonCO2[	16	]=	0.014706055	;
    RnonCO2[	17	]=	0.015026378	;
    RnonCO2[	18	]=	0.015331384	;
    RnonCO2[	19	]=	0.015626956	;
    RnonCO2[	20	]=	0.015918925	;
    RnonCO2[	21	]=	0.01621293	;
    RnonCO2[	22	]=	0.016514514	;
    RnonCO2[	23	]=	0.016829376	;
    RnonCO2[	24	]=	0.017163338	;
    RnonCO2[	25	]=	0.017521083	;
    RnonCO2[	26	]=	0.017903698	;
    RnonCO2[	27	]=	0.01830912	;
    RnonCO2[	28	]=	0.018735197	;
    RnonCO2[	29	]=	0.019180394	;
    RnonCO2[	30	]=	0.01964318	;
    RnonCO2[	31	]=	0.02012184	;
    RnonCO2[	32	]=	0.02061459	;
    RnonCO2[	33	]=	0.02111978	;
    RnonCO2[	34	]=	0.02163591	;
    RnonCO2[	35	]=	0.02216446	;
    RnonCO2[	36	]=	0.02271248	;
    RnonCO2[	37	]=	0.02328571	;
    RnonCO2[	38	]=	0.0238829	;
    RnonCO2[	39	]=	0.02449959	;
    RnonCO2[	40	]=	0.02513135	;
    RnonCO2[	41	]=	0.02577366	;
    RnonCO2[	42	]=	0.02642202	;
    RnonCO2[	43	]=	0.02707192	;
    RnonCO2[	44	]=	0.02771893	;
    RnonCO2[	45	]=	0.02836089	;
    RnonCO2[	46	]=	0.02900087	;
    RnonCO2[	47	]=	0.02964356	;
    RnonCO2[	48	]=	0.03029043	;
    RnonCO2[	49	]=	0.03094103	;
    RnonCO2[	50	]=	0.03159488	;
    RnonCO2[	51	]=	0.03225155	;
    RnonCO2[	52	]=	0.0329106	;
    RnonCO2[	53	]=	0.03357157	;
    RnonCO2[	54	]=	0.03423393	;
    RnonCO2[	55	]=	0.03489733	;
    RnonCO2[	56	]=	0.03556198	;
    RnonCO2[	57	]=	0.03622841	;
    RnonCO2[	58	]=	0.03689698	;
    RnonCO2[	59	]=	0.03756791	;
    RnonCO2[	60	]=	0.03824135	;
    RnonCO2[	61	]=	0.03891758	;
    RnonCO2[	62	]=	0.03959693	;
    RnonCO2[	63	]=	0.04027961	;
    RnonCO2[	64	]=	0.04096581	;
    RnonCO2[	65	]=	0.04165447	;
    RnonCO2[	66	]=	0.04234275	;
    RnonCO2[	67	]=	0.04302909	;
    RnonCO2[	68	]=	0.04371511	;
    RnonCO2[	69	]=	0.04440374	;
    RnonCO2[	70	]=	0.0450979	;
    RnonCO2[	71	]=	0.04580059	;
    RnonCO2[	72	]=	0.04651493	;
    RnonCO2[	73	]=	0.0472439	;
    RnonCO2[	74	]=	0.04799039	;
    RnonCO2[	75	]=	0.04875957	;
    RnonCO2[	76	]=	0.04956908	;
    RnonCO2[	77	]=	0.05043603	;
    RnonCO2[	78	]=	0.05134235	;
    RnonCO2[	79	]=	0.05223923	;
    RnonCO2[	80	]=	0.05307263	;
    RnonCO2[	81	]=	0.05381898	;
    RnonCO2[	82	]=	0.05450612	;
    RnonCO2[	83	]=	0.05516657	;
    RnonCO2[	84	]=	0.05580469	;
    RnonCO2[	85	]=	0.05649661	;
    RnonCO2[	86	]=	0.05747303	;
    RnonCO2[	87	]=	0.05866701	;
    RnonCO2[	88	]=	0.0598601	;
    RnonCO2[	89	]=	0.0610523	;
    RnonCO2[	90	]=	0.06210314	;
    RnonCO2[	91	]=	0.06315323	;
    RnonCO2[	92	]=	0.06434304	;
    RnonCO2[	93	]=	0.06553198	;
    RnonCO2[	94	]=	0.06672003	;
    RnonCO2[	95	]=	0.06790722	;
    RnonCO2[	96	]=	0.06909353	;
    RnonCO2[	97	]=	0.07027898	;
    RnonCO2[	98	]=	0.07146355	;
    RnonCO2[	99	]=	0.07264725	;
    RnonCO2[	100	]=	0.07396922	;
    RnonCO2[	101	]=	0.0752902	;
    RnonCO2[	102	]=	0.07647106	;
    RnonCO2[	103	]=	0.07765105	;
    RnonCO2[	104	]=	0.07883019	;
    RnonCO2[	105	]=	0.08006188	;
    RnonCO2[	106	]=	0.0812076	;
    RnonCO2[	107	]=	0.08229901	;
    RnonCO2[	108	]=	0.08347458	;
    RnonCO2[	109	]=	0.08464931	;
    RnonCO2[	110	]=	0.08587598	;
    RnonCO2[	111	]=	0.08701708	;
    RnonCO2[	112	]=	0.08810499	;
    RnonCO2[	113	]=	0.08927741	;
    RnonCO2[	114	]=	0.09044939	;
    RnonCO2[	115	]=	0.09175792	;
    RnonCO2[	116	]=	0.09320276	;
    RnonCO2[	117	]=	0.09464664	;
    RnonCO2[	118	]=	0.09608949	;
    RnonCO2[	119	]=	0.09739496	;
    RnonCO2[	120	]=	0.0985634	;
    RnonCO2[	121	]=	0.09986768	;
    RnonCO2[	122	]=	0.10122271	;
    RnonCO2[	123	]=	0.10249213	;
    RnonCO2[	124	]=	0.10384549	;
    RnonCO2[	125	]=	0.10528284	;
    RnonCO2[	126	]=	0.10685466	;
    RnonCO2[	127	]=	0.1085606	;
    RnonCO2[	128	]=	0.11004559	;
    RnonCO2[	129	]=	0.11131004	;
    RnonCO2[	130	]=	0.11270838	;
    RnonCO2[	131	]=	0.1142403	;
    RnonCO2[	132	]=	0.11572158	;
    RnonCO2[	133	]=	0.11720182	;
    RnonCO2[	134	]=	0.11873056	;
    RnonCO2[	135	]=	0.12048167	;
    RnonCO2[	136	]=	0.12271612	;
    RnonCO2[	137	]=	0.12520844	;
    RnonCO2[	138	]=	0.12782821	;
    RnonCO2[	139	]=	0.13057484	;
    RnonCO2[	140	]=	0.13331526	;
    RnonCO2[	141	]=	0.13605041	;
    RnonCO2[	142	]=	0.13887031	;
    RnonCO2[	143	]=	0.14190497	;
    RnonCO2[	144	]=	0.14506366	;
    RnonCO2[	145	]=	0.14808479	;
    RnonCO2[	146	]=	0.15096905	;
    RnonCO2[	147	]=	0.15406256	;
    RnonCO2[	148	]=	0.15742306	;
    RnonCO2[	149	]=	0.16083056	;
    RnonCO2[	150	]=	0.16429017	;
    RnonCO2[	151	]=	0.16780522	;
    RnonCO2[	152	]=	0.17141349	;
    RnonCO2[	153	]=	0.17524964	;
    RnonCO2[	154	]=	0.17912698	;
    RnonCO2[	155	]=	0.18286803	;
    RnonCO2[	156	]=	0.18655793	;
    RnonCO2[	157	]=	0.19028114	;
    RnonCO2[	158	]=	0.19403945	;
    RnonCO2[	159	]=	0.19779207	;
    RnonCO2[	160	]=	0.2015367	;
    RnonCO2[	161	]=	0.20536218	;
    RnonCO2[	162	]=	0.20918465	;
    RnonCO2[	163	]=	0.21283052	;
    RnonCO2[	164	]=	0.2163449	;
    RnonCO2[	165	]=	0.21972929	;
    RnonCO2[	166	]=	0.22302895	;
    RnonCO2[	167	]=	0.22640626	;
    RnonCO2[	168	]=	0.22985789	;
    RnonCO2[	169	]=	0.23320109	;
    RnonCO2[	170	]=	0.2364361	;
    RnonCO2[	171	]=	0.23966811	;
    RnonCO2[	172	]=	0.2428137	;
    RnonCO2[	173	]=	0.24587625	;
    RnonCO2[	174	]=	0.248943	;
    RnonCO2[	175	]=	0.25213499	;
    RnonCO2[	176	]=	0.25554226	;
    RnonCO2[	177	]=	0.25892918	;
    RnonCO2[	178	]=	0.26220864	;
    RnonCO2[	179	]=	0.26570209	;
    RnonCO2[	180	]=	0.26941573	;
    RnonCO2[	181	]=	0.273294	;
    RnonCO2[	182	]=	0.27751544	;
    RnonCO2[	183	]=	0.28201064	;
    RnonCO2[	184	]=	0.28674226	;
    RnonCO2[	185	]=	0.29175313	;
    RnonCO2[	186	]=	0.29696911	;
    RnonCO2[	187	]=	0.30255457	;
    RnonCO2[	188	]=	0.30858029	;
    RnonCO2[	189	]=	0.31473264	;
    RnonCO2[	190	]=	0.32113183	;
    RnonCO2[	191	]=	0.32799691	;
    RnonCO2[	192	]=	0.33518916	;
    RnonCO2[	193	]=	0.34268013	;
    RnonCO2[	194	]=	0.35054912	;
    RnonCO2[	195	]=	0.3588091	;
    RnonCO2[	196	]=	0.36744837	;
    RnonCO2[	197	]=	0.37654998	;
    RnonCO2[	198	]=	0.38629282	;
    RnonCO2[	199	]=	0.39687085	;
    RnonCO2[	200	]=	0.40827014	;
    RnonCO2[	201	]=	0.4202703	;
    RnonCO2[	202	]=	0.43287302	;
    RnonCO2[	203	]=	0.44635066	;
    RnonCO2[	204	]=	0.46086195	;
    RnonCO2[	205	]=	0.47625741	;
    RnonCO2[	206	]=	0.49233715	;
    RnonCO2[	207	]=	0.50922498	;
    RnonCO2[	208	]=	0.52712569	;
    RnonCO2[	209	]=	0.54610485	;
    RnonCO2[	210	]=	0.56604558	;
    RnonCO2[	211	]=	0.58635079	;
    RnonCO2[	212	]=	0.6067464	;
    RnonCO2[	213	]=	0.6271609	;
    RnonCO2[	214	]=	0.6475189	;
    RnonCO2[	215	]=	0.6673124	;
    RnonCO2[	216	]=	0.6879383	;
    RnonCO2[	217	]=	0.7090557	;
    RnonCO2[	218	]=	0.7289172	;
    RnonCO2[	219	]=	0.7480442	;
    RnonCO2[	220	]=	0.766979	;
    RnonCO2[	221	]=	0.7850643	;
    RnonCO2[	222	]=	0.803085	;
    RnonCO2[	223	]=	0.8236521	;
    RnonCO2[	224	]=	0.8452713	;
    RnonCO2[	225	]=	0.864246	;
    RnonCO2[	226	]=	0.8809743	;
    RnonCO2[	227	]=	0.8949711	;
    RnonCO2[	228	]=	0.9053237	;
    RnonCO2[	229	]=	0.914042	;
    RnonCO2[	230	]=	0.9219104	;
    RnonCO2[	231	]=	0.9290394	;
    RnonCO2[	232	]=	0.9359876	;
    RnonCO2[	233	]=	0.9434778	;
    RnonCO2[	234	]=	0.9502339	;
    RnonCO2[	235	]=	0.9548618	;
    RnonCO2[	236	]=	0.9587726	;
    RnonCO2[	237	]=	0.9638465	;
    RnonCO2[	238	]=	0.9690029	;
    RnonCO2[	239	]=	0.972858	;
    RnonCO2[	240	]=	0.9761909	;
    RnonCO2[	241	]=	0.9798637	;
    RnonCO2[	242	]=	0.9839659	;
    RnonCO2[	243	]=	0.9886163	;
    RnonCO2[	244	]=	0.9935961	;
    RnonCO2[	245	]=	0.9987971	;
    RnonCO2[	246	]=	1.0042671	;
    RnonCO2[	247	]=	1.0091057	;
    RnonCO2[	248	]=	1.0124942	;
    RnonCO2[	249	]=	1.0145622	;
    RnonCO2[	250	]=	1.0154303	;
    RnonCO2[	251	]=	1.0151798	;
    RnonCO2[	252	]=	1.0139019	;
    RnonCO2[	253	]=	1.0116952	;
    RnonCO2[	254	]=	1.0086249	;
    RnonCO2[	255	]=	1.004751	;
    RnonCO2[	256	]=	1.0000955	;
    RnonCO2[	257	]=	0.9949606	;
    RnonCO2[	258	]=	0.9897129	;
    RnonCO2[	259	]=	0.9844862	;
    RnonCO2[	260	]=	0.9793593	;
    RnonCO2[	261	]=	0.9743385	;
    RnonCO2[	262	]=	0.9694131	;
    RnonCO2[	263	]=	0.9645612	;
    RnonCO2[	264	]=	0.9597663	;
    RnonCO2[	265	]=	0.9550179	;
    RnonCO2[	266	]=	0.9503079	;
    RnonCO2[	267	]=	0.9456576	;
    RnonCO2[	268	]=	0.9410975	;
    RnonCO2[	269	]=	0.9366385	;
    RnonCO2[	270	]=	0.9322865	;
    RnonCO2[	271	]=	0.928046	;
    RnonCO2[	272	]=	0.9239233	;
    RnonCO2[	273	]=	0.9199093	;
    RnonCO2[	274	]=	0.9159837	;
    RnonCO2[	275	]=	0.9121317	;
    RnonCO2[	276	]=	0.9083448	;
    RnonCO2[	277	]=	0.9044256	;
    RnonCO2[	278	]=	0.9001644	;
    RnonCO2[	279	]=	0.8955727	;
    RnonCO2[	280	]=	0.8907008	;
    RnonCO2[	281	]=	0.88559	;
    RnonCO2[	282	]=	0.8802749	;
    RnonCO2[	283	]=	0.8747896	;
    RnonCO2[	284	]=	0.8691492	;
    RnonCO2[	285	]=	0.8633559	;
    RnonCO2[	286	]=	0.8574152	;
    RnonCO2[	287	]=	0.8515233	;
    RnonCO2[	288	]=	0.8458588	;
    RnonCO2[	289	]=	0.8403682	;
    RnonCO2[	290	]=	0.8350142	;
    RnonCO2[	291	]=	0.8298023	;
    RnonCO2[	292	]=	0.8247332	;
    RnonCO2[	293	]=	0.819806	;
    RnonCO2[	294	]=	0.8150227	;
    RnonCO2[	295	]=	0.810371	;
    RnonCO2[	296	]=	0.8058283	;
    RnonCO2[	297	]=	0.801534	;
    RnonCO2[	298	]=	0.7976189	;
    RnonCO2[	299	]=	0.7940447	;
    RnonCO2[	300	]=	0.7907496	;
    RnonCO2[	301	]=	0.7876889	;
    RnonCO2[	302	]=	0.784859	;
    RnonCO2[	303	]=	0.7822529	;
    RnonCO2[	304	]=	0.7798632	;
    RnonCO2[	305	]=	0.7776856	;
    RnonCO2[	306	]=	0.7757026	;
    RnonCO2[	307	]=	0.7738647	;
    RnonCO2[	308	]=	0.7721296	;
    RnonCO2[	309	]=	0.7704841	;
    RnonCO2[	310	]=	0.7689169	;
    RnonCO2[	311	]=	0.767391	;
    RnonCO2[	312	]=	0.7658839	;
    RnonCO2[	313	]=	0.7644109	;
    RnonCO2[	314	]=	0.7629824	;
    RnonCO2[	315	]=	0.7616064	;
    RnonCO2[	316	]=	0.7602926	;
    RnonCO2[	317	]=	0.7590056	;
    RnonCO2[	318	]=	0.7577023	;
    RnonCO2[	319	]=	0.7563777	;
    RnonCO2[	320	]=	0.7550304	;
    RnonCO2[	321	]=	0.7536595	;
    RnonCO2[	322	]=	0.752238	;
    RnonCO2[	323	]=	0.7507519	;
    RnonCO2[	324	]=	0.7492239	;
    RnonCO2[	325	]=	0.7476704	;
    RnonCO2[	326	]=	0.7461052	;
    RnonCO2[	327	]=	0.7445368	;
    RnonCO2[	328	]=	0.7429588	;
    RnonCO2[	329	]=	0.7413619	;
    RnonCO2[	330	]=	0.7397406	;
    RnonCO2[	331	]=	0.7380929	;
    RnonCO2[	332	]=	0.736417	;
    RnonCO2[	333	]=	0.7346863	;
    RnonCO2[	334	]=	0.7328865	;
    RnonCO2[	335	]=	0.7310399	;
    RnonCO2[	336	]=	0.729163	;
    RnonCO2[	337	]=	0.727335	;
    RnonCO2[	338	]=	0.7256289	;
    RnonCO2[	339	]=	0.7240345	;
    RnonCO2[	340	]=	0.7225328	;
    RnonCO2[	341	]=	0.7211102	;
    RnonCO2[	342	]=	0.7197575	;
    RnonCO2[	343	]=	0.7184664	;
    RnonCO2[	344	]=	0.7172045	;
    RnonCO2[	345	]=	0.7159525	;
    RnonCO2[	346	]=	0.7147276	;
    RnonCO2[	347	]=	0.713541	;
    RnonCO2[	348	]=	0.712402	;
    RnonCO2[	349	]=	0.7113211	;
    RnonCO2[	350	]=	0.7102955	;
    RnonCO2[	351	]=	0.7093128	;
    RnonCO2[	352	]=	0.7083648	;
    RnonCO2[	353	]=	0.7074472	;
    RnonCO2[	354	]=	0.7065561	;
    RnonCO2[	355	]=	0.7056632	;
    RnonCO2[	356	]=	0.7047529	;
    RnonCO2[	357	]=	0.7038449	;
    RnonCO2[	358	]=	0.702953	;
    RnonCO2[	359	]=	0.7020886	;
    RnonCO2[	360	]=	0.7012643	;
    RnonCO2[	361	]=	0.7004787	;
    RnonCO2[	362	]=	0.6997216	;
    RnonCO2[	363	]=	0.6989861	;
    RnonCO2[	364	]=	0.6982691	;
    RnonCO2[	365	]=	0.6975678	;
    RnonCO2[	366	]=	0.6968552	;
    RnonCO2[	367	]=	0.6961166	;
    RnonCO2[	368	]=	0.6953724	;
    RnonCO2[	369	]=	0.694637	;
    RnonCO2[	370	]=	0.6939221	;
    RnonCO2[	371	]=	0.693241	;
    RnonCO2[	372	]=	0.6925926	;
    RnonCO2[	373	]=	0.6919671	;
    RnonCO2[	374	]=	0.6913582	;
    RnonCO2[	375	]=	0.6907631	;
    RnonCO2[	376	]=	0.6901796	;
    RnonCO2[	377	]=	0.689581	;
    RnonCO2[	378	]=	0.6889531	;
    RnonCO2[	379	]=	0.6883164	;
    RnonCO2[	380	]=	0.6876854	;
    RnonCO2[	381	]=	0.6870721	;
    RnonCO2[	382	]=	0.6864896	;
    RnonCO2[	383	]=	0.6859372	;
    RnonCO2[	384	]=	0.6854053	;
    RnonCO2[	385	]=	0.6848879	;
    RnonCO2[	386	]=	0.684382	;
    RnonCO2[	387	]=	0.6838858	;
    RnonCO2[	388	]=	0.6833726	;
    RnonCO2[	389	]=	0.6828287	;
    RnonCO2[	390	]=	0.6822745	;
    RnonCO2[	391	]=	0.6817244	;
    RnonCO2[	392	]=	0.6811905	;
    RnonCO2[	393	]=	0.6806857	;
    RnonCO2[	394	]=	0.6802097	;
    RnonCO2[	395	]=	0.6797527	;
    RnonCO2[	396	]=	0.6793088	;
    RnonCO2[	397	]=	0.6788753	;
    RnonCO2[	398	]=	0.6784502	;
    RnonCO2[	399	]=	0.6780071	;
    RnonCO2[	400	]=	0.6775325	;
    RnonCO2[	401	]=	0.6770464	;
    RnonCO2[	402	]=	0.6765636	;
    RnonCO2[	403	]=	0.6760958	;
    RnonCO2[	404	]=	0.6756562	;
    RnonCO2[	405	]=	0.6752443	;
    RnonCO2[	406	]=	0.6748504	;
    RnonCO2[	407	]=	0.6744685	;
    RnonCO2[	408	]=	0.6740963	;
    RnonCO2[	409	]=	0.6737315	;
    RnonCO2[	410	]=	0.6733481	;
    RnonCO2[	411	]=	0.6729325	;
    RnonCO2[	412	]=	0.6725047	;
    RnonCO2[	413	]=	0.6720793	;
    RnonCO2[	414	]=	0.6716683	;
    RnonCO2[	415	]=	0.6712846	;
    RnonCO2[	416	]=	0.6709277	;
    RnonCO2[	417	]=	0.6705881	;
    RnonCO2[	418	]=	0.6702598	;
    RnonCO2[	419	]=	0.6699403	;
    RnonCO2[	420	]=	0.6696277	;
    RnonCO2[	421	]=	0.6692957	;
    RnonCO2[	422	]=	0.6689311	;
    RnonCO2[	423	]=	0.6685537	;
    RnonCO2[	424	]=	0.6681781	;
    RnonCO2[	425	]=	0.6678163	;
    RnonCO2[	426	]=	0.667481	;
    RnonCO2[	427	]=	0.6671719	;
    RnonCO2[	428	]=	0.6668794	;
    RnonCO2[	429	]=	0.6665976	;
    RnonCO2[	430	]=	0.666324	;
    RnonCO2[	431	]=	0.6660566	;
    RnonCO2[	432	]=	0.6657696	;
    RnonCO2[	433	]=	0.6654492	;
    RnonCO2[	434	]=	0.6651158	;
    RnonCO2[	435	]=	0.6647835	;
    RnonCO2[	436	]=	0.6644645	;
    RnonCO2[	437	]=	0.6641714	;
    RnonCO2[	438	]=	0.6639039	;
    RnonCO2[	439	]=	0.6636525	;
    RnonCO2[	440	]=	0.6634112	;
    RnonCO2[	441	]=	0.6631777	;
    RnonCO2[	442	]=	0.6629498	;
    RnonCO2[	443	]=	0.6627018	;
    RnonCO2[	444	]=	0.6624202	;
    RnonCO2[	445	]=	0.6621251	;
    RnonCO2[	446	]=	0.6618307	;
    RnonCO2[	447	]=	0.6615491	;
    RnonCO2[	448	]=	0.661293	;
    RnonCO2[	449	]=	0.6610618	;
    RnonCO2[	450	]=	0.6608463	;
    RnonCO2[	451	]=	0.6606404	;
    RnonCO2[	452	]=	0.6604419	;
    RnonCO2[	453	]=	0.6602486	;
    RnonCO2[	454	]=	0.6600348	;
    RnonCO2[	455	]=	0.6597871	;
    RnonCO2[	456	]=	0.6595255	;
    RnonCO2[	457	]=	0.6592643	;
    RnonCO2[	458	]=	0.6590154	;
    RnonCO2[	459	]=	0.6587916	;
    RnonCO2[	460	]=	0.6585923	;
    RnonCO2[	461	]=	0.6584081	;
    RnonCO2[	462	]=	0.6582334	;
    RnonCO2[	463	]=	0.6580655	;
    RnonCO2[	464	]=	0.6579025	;
    RnonCO2[	465	]=	0.6577187	;
    RnonCO2[	466	]=	0.6575007	;
    RnonCO2[	467	]=	0.6572685	;
    RnonCO2[	468	]=	0.6570364	;
    RnonCO2[	469	]=	0.6568161	;
    RnonCO2[	470	]=	0.6566206	;
    RnonCO2[	471	]=	0.6564492	;
    RnonCO2[	472	]=	0.6562926	;
    RnonCO2[	473	]=	0.6561451	;
    RnonCO2[	474	]=	0.6560041	;
    RnonCO2[	475	]=	0.6558677	;
    RnonCO2[	476	]=	0.6557102	;
    RnonCO2[	477	]=	0.6555183	;
    RnonCO2[	478	]=	0.6553118	;
    RnonCO2[	479	]=	0.6551053	;
    RnonCO2[	480	]=	0.6549103	;
    RnonCO2[	481	]=	0.6547395	;
    RnonCO2[	482	]=	0.6545928	;
    RnonCO2[	483	]=	0.6544603	;
    RnonCO2[	484	]=	0.6543368	;
    RnonCO2[	485	]=	0.6542194	;
    RnonCO2[	486	]=	0.6541063	;
    RnonCO2[	487	]=	0.653972	;
    RnonCO2[	488	]=	0.6538028	;
    RnonCO2[	489	]=	0.6536192	;
    RnonCO2[	490	]=	0.6534349	;
    RnonCO2[	491	]=	0.6532621	;
    RnonCO2[	492	]=	0.6531132	;
    RnonCO2[	493	]=	0.652988	;
    RnonCO2[	494	]=	0.6528769	;
    RnonCO2[	495	]=	0.6527743	;
    RnonCO2[	496	]=	0.6526777	;
    RnonCO2[	497	]=	0.6525852	;
    RnonCO2[	498	]=	0.6524711	;
    RnonCO2[	499	]=	0.6523222	;
    RnonCO2[	500	]=	0.6521584	;
    RnonCO2[	501	]=	0.651994	;
    RnonCO2[	502	]=	0.6518406	;
    RnonCO2[	503	]=	0.651711	;
    RnonCO2[	504	]=	0.6516046	;
    RnonCO2[	505	]=	0.6515124	;
    RnonCO2[	506	]=	0.6514283	;
    RnonCO2[	507	]=	0.65135	;
    RnonCO2[	508	]=	0.6512756	;
    RnonCO2[	509	]=	0.6511794	;
    RnonCO2[	510	]=	0.6510483	;
    RnonCO2[	511	]=	0.6509021	;
    RnonCO2[	512	]=	0.650755	;
    RnonCO2[	513	]=	0.6506187	;
    RnonCO2[	514	]=	0.6505061	;
    RnonCO2[	515	]=	0.6504165	;
    RnonCO2[	516	]=	0.6503408	;
    RnonCO2[	517	]=	0.650273	;
    RnonCO2[	518	]=	0.6502108	;
    RnonCO2[	519	]=	0.6501524	;
    RnonCO2[	520	]=	0.6500719	;
    RnonCO2[	521	]=	0.6499565	;
    RnonCO2[	522	]=	0.6498258	;
    RnonCO2[	523	]=	0.6496941	;
    RnonCO2[	524	]=	0.649573	;
    RnonCO2[	525	]=	0.6494753	;
    RnonCO2[	526	]=	0.6494005	;
    RnonCO2[	527	]=	0.6493393	;
    RnonCO2[	528	]=	0.6492859	;
    RnonCO2[	529	]=	0.649238	;
    RnonCO2[	530	]=	0.6491935	;
    RnonCO2[	531	]=	0.6491272	;
    RnonCO2[	532	]=	0.6490255	;
    RnonCO2[	533	]=	0.6489084	;
    RnonCO2[	534	]=	0.6487903	;
    RnonCO2[	535	]=	0.6486826	;
    RnonCO2[	536	]=	0.6485981	;
    RnonCO2[	537	]=	0.6485363	;
    RnonCO2[	538	]=	0.6484879	;
    RnonCO2[	539	]=	0.6484472	;
    RnonCO2[	540	]=	0.648412	;
    RnonCO2[	541	]=	0.64838	;
    RnonCO2[	542	]=	0.6483259	;
    RnonCO2[	543	]=	0.6482364	;
    RnonCO2[	544	]=	0.6481315	;
    RnonCO2[	545	]=	0.6480252	;
    RnonCO2[	546	]=	0.6479294	;
    RnonCO2[	547	]=	0.6478566	;
    RnonCO2[	548	]=	0.6478064	;
    RnonCO2[	549	]=	0.6477694	;
    RnonCO2[	550	]=	0.6477399	;
    RnonCO2[	551	]=	0.6477158	;
    RnonCO2[	552	]=	0.6476947	;
    RnonCO2[	553	]=	0.6476515	;
    RnonCO2[	554	]=	0.6475729	;
    RnonCO2[	555	]=	0.6474786	;
    RnonCO2[	556	]=	0.6473831	;
    RnonCO2[	557	]=	0.6472977	;
    RnonCO2[	558	]=	0.6472351	;
    RnonCO2[	559	]=	0.6471951	;
    RnonCO2[	560	]=	0.6471682	;
    RnonCO2[	561	]=	0.6471487	;
    RnonCO2[	562	]=	0.6471344	;
    RnonCO2[	563	]=	0.6471231	;
    RnonCO2[	564	]=	0.6470895	;
    RnonCO2[	565	]=	0.6470204	;
    RnonCO2[	566	]=	0.6469357	;
    RnonCO2[	567	]=	0.6468494	;
    RnonCO2[	568	]=	0.6467734	;
    RnonCO2[	569	]=	0.64672	;
    RnonCO2[	570	]=	0.6466889	;
    RnonCO2[	571	]=	0.646671	;
    RnonCO2[	572	]=	0.6466604	;
    RnonCO2[	573	]=	0.6466547	;
    RnonCO2[	574	]=	0.6466521	;
    RnonCO2[	575	]=	0.6466271	;
    RnonCO2[	576	]=	0.6465664	;
    RnonCO2[	577	]=	0.6464901	;
    RnonCO2[	578	]=	0.6464122	;
    RnonCO2[	579	]=	0.6463442	;
    RnonCO2[	580	]=	0.646299	;
    RnonCO2[	581	]=	0.646276	;
    RnonCO2[	582	]=	0.646266	;
    RnonCO2[	583	]=	0.6462631	;
    RnonCO2[	584	]=	0.6462652	;
    RnonCO2[	585	]=	0.6462702	;
    RnonCO2[	586	]=	0.6462528	;
    RnonCO2[	587	]=	0.6461997	;
    RnonCO2[	588	]=	0.6461308	;
    RnonCO2[	589	]=	0.6460603	;
    RnonCO2[	590	]=	0.6459996	;
    RnonCO2[	591	]=	0.6459616	;
    RnonCO2[	592	]=	0.6459456	;
    RnonCO2[	593	]=	0.6459425	;
    RnonCO2[	594	]=	0.6459467	;
    RnonCO2[	595	]=	0.6459556	;
    RnonCO2[	596	]=	0.6459674	;
    RnonCO2[	597	]=	0.6459567	;
    RnonCO2[	598	]=	0.6459103	;
    RnonCO2[	599	]=	0.645848	;
    RnonCO2[	600	]=	0.645784	;
    RnonCO2[	601	]=	0.6457299	;
    RnonCO2[	602	]=	0.6456982	;
    RnonCO2[	603	]=	0.6456885	;
    RnonCO2[	604	]=	0.6456917	;
    RnonCO2[	605	]=	0.645702	;
    RnonCO2[	606	]=	0.645717	;
    RnonCO2[	607	]=	0.6457349	;
    RnonCO2[	608	]=	0.6457301	;
    RnonCO2[	609	]=	0.6456896	;
    RnonCO2[	610	]=	0.6456333	;
    RnonCO2[	611	]=	0.6455751	;
    RnonCO2[	612	]=	0.6455267	;
    RnonCO2[	613	]=	0.6455006	;
    RnonCO2[	614	]=	0.6454966	;
    RnonCO2[	615	]=	0.6455053	;
    RnonCO2[	616	]=	0.645521	;
    RnonCO2[	617	]=	0.6455415	;
    RnonCO2[	618	]=	0.6455647	;
    RnonCO2[	619	]=	0.6455653	;
    RnonCO2[	620	]=	0.64553	;
    RnonCO2[	621	]=	0.645479	;
    RnonCO2[	622	]=	0.6454259	;
    RnonCO2[	623	]=	0.6453826	;
    RnonCO2[	624	]=	0.6453617	;
    RnonCO2[	625	]=	0.6453627	;
    RnonCO2[	626	]=	0.6453763	;
    RnonCO2[	627	]=	0.6453968	;
    RnonCO2[	628	]=	0.6454222	;
    RnonCO2[	629	]=	0.6454501	;
    RnonCO2[	630	]=	0.6454554	;
    RnonCO2[	631	]=	0.6454249	;
    RnonCO2[	632	]=	0.6453784	;
    RnonCO2[	633	]=	0.64533	;
    RnonCO2[	634	]=	0.6452912	;
    RnonCO2[	635	]=	0.6452748	;
    RnonCO2[	636	]=	0.6452802	;
    RnonCO2[	637	]=	0.6452981	;
    RnonCO2[	638	]=	0.645323	;
    RnonCO2[	639	]=	0.6453527	;
    RnonCO2[	640	]=	0.6453848	;
    RnonCO2[	641	]=	0.6453944	;
    RnonCO2[	642	]=	0.645368	;
    RnonCO2[	643	]=	0.6453257	;
    RnonCO2[	644	]=	0.6452813	;
    RnonCO2[	645	]=	0.6452467	;
    RnonCO2[	646	]=	0.6452342	;
    RnonCO2[	647	]=	0.6452435	;
    RnonCO2[	648	]=	0.6452654	;
    RnonCO2[	649	]=	0.6452942	;
    RnonCO2[	650	]=	0.6453276	;
    RnonCO2[	651	]=	0.6453636	;
    RnonCO2[	652	]=	0.6453768	;
    RnonCO2[	653	]=	0.6453542	;
    RnonCO2[	654	]=	0.6453156	;
    RnonCO2[	655	]=	0.645275	;
    RnonCO2[	656	]=	0.6452438	;
    RnonCO2[	657	]=	0.6452349	;
    RnonCO2[	658	]=	0.6452478	;
    RnonCO2[	659	]=	0.6452731	;
    RnonCO2[	660	]=	0.6453054	;
    RnonCO2[	661	]=	0.6453421	;
    RnonCO2[	662	]=	0.6453815	;
    RnonCO2[	663	]=	0.6453981	;
    RnonCO2[	664	]=	0.6453788	;
    RnonCO2[	665	]=	0.6453435	;
    RnonCO2[	666	]=	0.645306	;
    RnonCO2[	667	]=	0.6452781	;
    RnonCO2[	668	]=	0.6452724	;
    RnonCO2[	669	]=	0.6452884	;
    RnonCO2[	670	]=	0.6453168	;
    RnonCO2[	671	]=	0.6453521	;
    RnonCO2[	672	]=	0.645392	;
    RnonCO2[	673	]=	0.6454343	;
    RnonCO2[	674	]=	0.6454539	;
    RnonCO2[	675	]=	0.6454375	;
    RnonCO2[	676	]=	0.6454051	;
    RnonCO2[	677	]=	0.6453706	;
    RnonCO2[	678	]=	0.6453456	;
    RnonCO2[	679	]=	0.6453427	;
    RnonCO2[	680	]=	0.6453615	;
    RnonCO2[	681	]=	0.6453926	;
    RnonCO2[	682	]=	0.6454306	;
    RnonCO2[	683	]=	0.6454732	;
    RnonCO2[	684	]=	0.6455183	;
    RnonCO2[	685	]=	0.6455405	;
    RnonCO2[	686	]=	0.6455268	;
    RnonCO2[	687	]=	0.645497	;
    RnonCO2[	688	]=	0.6454651	;
    RnonCO2[	689	]=	0.64544266	;
    RnonCO2[	690	]=	0.64544228	;
    RnonCO2[	691	]=	0.64546356	;
    RnonCO2[	692	]=	0.64549714	;
    RnonCO2[	693	]=	0.64553763	;
    RnonCO2[	694	]=	0.64558254	;
    RnonCO2[	695	]=	0.64562997	;
    RnonCO2[	696	]=	0.64565467	;
    RnonCO2[	697	]=	0.6456433	;
    RnonCO2[	698	]=	0.64561584	;
    RnonCO2[	699	]=	0.64558629	;
    RnonCO2[	700	]=	0.64556609	;
    RnonCO2[	701	]=	0.645568	;
    RnonCO2[	702	]=	0.6455914	;
    RnonCO2[	703	]=	0.64562733	;
    RnonCO2[	704	]=	0.64566993	;
    RnonCO2[	705	]=	0.64571707	;
    RnonCO2[	706	]=	0.64576657	;
    RnonCO2[	707	]=	0.64579335	;
    RnonCO2[	708	]=	0.64578408	;
    RnonCO2[	709	]=	0.64575878	;
    RnonCO2[	710	]=	0.64573126	;
    RnonCO2[	711	]=	0.64571315	;
    RnonCO2[	712	]=	0.64571703	;
    RnonCO2[	713	]=	0.64574252	;
    RnonCO2[	714	]=	0.64578025	;
    RnonCO2[	715	]=	0.6458249	;
    RnonCO2[	716	]=	0.64587391	;
    RnonCO2[	717	]=	0.64592541	;
    RnonCO2[	718	]=	0.64595398	;
    RnonCO2[	719	]=	0.64594665	;
    RnonCO2[	720	]=	0.64592321	;
    RnonCO2[	721	]=	0.64589755	;
    RnonCO2[	722	]=	0.64588124	;
    RnonCO2[	723	]=	0.6458869	;
    RnonCO2[	724	]=	0.64591419	;
    RnonCO2[	725	]=	0.64595372	;
    RnonCO2[	726	]=	0.646	;
    RnonCO2[	727	]=	0.64605074	;
    RnonCO2[	728	]=	0.64610391	;
    RnonCO2[	729	]=	0.64613424	;
    RnonCO2[	730	]=	0.64612859	;
    RnonCO2[	731	]=	0.64610687	;
    RnonCO2[	732	]=	0.64608283	;
    RnonCO2[	733	]=	0.64606819	;
    RnonCO2[	734	]=	0.64607547	;
    RnonCO2[	735	]=	0.6460859	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}


void setRnonCO2_zero(void)
{
    
    for(int i = 0; i<tmax; i++)
    {
        RnonCO2[i] = 0.0;
    }
}


void setR_WMGHG_nonCO2_ssp119(void)
{
    
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07202E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09004E+00	;
    RnonCO2[	253	]=	1.09658E+00	;
    RnonCO2[	254	]=	1.10213E+00	;
    RnonCO2[	255	]=	1.10665E+00	;
    RnonCO2[	256	]=	1.11022E+00	;
    RnonCO2[	257	]=	1.11213E+00	;
    RnonCO2[	258	]=	1.11180E+00	;
    RnonCO2[	259	]=	1.10955E+00	;
    RnonCO2[	260	]=	1.10558E+00	;
    RnonCO2[	261	]=	1.10003E+00	;
    RnonCO2[	262	]=	1.09285E+00	;
    RnonCO2[	263	]=	1.08405E+00	;
    RnonCO2[	264	]=	1.07378E+00	;
    RnonCO2[	265	]=	1.06217E+00	;
    RnonCO2[	266	]=	1.04934E+00	;
    RnonCO2[	267	]=	1.03597E+00	;
    RnonCO2[	268	]=	1.02267E+00	;
    RnonCO2[	269	]=	1.00944E+00	;
    RnonCO2[	270	]=	9.96329E-01	;
    RnonCO2[	271	]=	9.83372E-01	;
    RnonCO2[	272	]=	9.70601E-01	;
    RnonCO2[	273	]=	9.58029E-01	;
    RnonCO2[	274	]=	9.45667E-01	;
    RnonCO2[	275	]=	9.33515E-01	;
    RnonCO2[	276	]=	9.21579E-01	;
    RnonCO2[	277	]=	9.09892E-01	;
    RnonCO2[	278	]=	8.98490E-01	;
    RnonCO2[	279	]=	8.87367E-01	;
    RnonCO2[	280	]=	8.76516E-01	;
    RnonCO2[	281	]=	8.65919E-01	;
    RnonCO2[	282	]=	8.55569E-01	;
    RnonCO2[	283	]=	8.45450E-01	;
    RnonCO2[	284	]=	8.35560E-01	;
    RnonCO2[	285	]=	8.25872E-01	;
    RnonCO2[	286	]=	8.16386E-01	;
    RnonCO2[	287	]=	8.07178E-01	;
    RnonCO2[	288	]=	7.98334E-01	;
    RnonCO2[	289	]=	7.89838E-01	;
    RnonCO2[	290	]=	7.81670E-01	;
    RnonCO2[	291	]=	7.73801E-01	;
    RnonCO2[	292	]=	7.66225E-01	;
    RnonCO2[	293	]=	7.58918E-01	;
    RnonCO2[	294	]=	7.51862E-01	;
    RnonCO2[	295	]=	7.45043E-01	;
    RnonCO2[	296	]=	7.38449E-01	;
    RnonCO2[	297	]=	7.32074E-01	;
    RnonCO2[	298	]=	7.25902E-01	;
    RnonCO2[	299	]=	7.19920E-01	;
    RnonCO2[	300	]=	7.14128E-01	;
    RnonCO2[	301	]=	7.08503E-01	;
    RnonCO2[	302	]=	7.03039E-01	;
    RnonCO2[	303	]=	6.97724E-01	;
    RnonCO2[	304	]=	6.92554E-01	;
    RnonCO2[	305	]=	6.87516E-01	;
    RnonCO2[	306	]=	6.82600E-01	;
    RnonCO2[	307	]=	6.77781E-01	;
    RnonCO2[	308	]=	6.73018E-01	;
    RnonCO2[	309	]=	6.68320E-01	;
    RnonCO2[	310	]=	6.63669E-01	;
    RnonCO2[	311	]=	6.59077E-01	;
    RnonCO2[	312	]=	6.54523E-01	;
    RnonCO2[	313	]=	6.50023E-01	;
    RnonCO2[	314	]=	6.45562E-01	;
    RnonCO2[	315	]=	6.41140E-01	;
    RnonCO2[	316	]=	6.36755E-01	;
    RnonCO2[	317	]=	6.32439E-01	;
    RnonCO2[	318	]=	6.28206E-01	;
    RnonCO2[	319	]=	6.24063E-01	;
    RnonCO2[	320	]=	6.20000E-01	;
    RnonCO2[	321	]=	6.16014E-01	;
    RnonCO2[	322	]=	6.12101E-01	;
    RnonCO2[	323	]=	6.08253E-01	;
    RnonCO2[	324	]=	6.04468E-01	;
    RnonCO2[	325	]=	6.00751E-01	;
    RnonCO2[	326	]=	5.97087E-01	;
    RnonCO2[	327	]=	5.93492E-01	;
    RnonCO2[	328	]=	5.89966E-01	;
    RnonCO2[	329	]=	5.86518E-01	;
    RnonCO2[	330	]=	5.83136E-01	;
    RnonCO2[	331	]=	5.79818E-01	;
    RnonCO2[	332	]=	5.76595E-01	;
    RnonCO2[	333	]=	5.73508E-01	;
    RnonCO2[	334	]=	5.70536E-01	;
    RnonCO2[	335	]=	5.67681E-01	;
    RnonCO2[	336	]=	5.64926E-01	;
    RnonCO2[	337	]=	5.62323E-01	;
    RnonCO2[	338	]=	5.59900E-01	;
    RnonCO2[	339	]=	5.57642E-01	;
    RnonCO2[	340	]=	5.55530E-01	;
    RnonCO2[	341	]=	5.53553E-01	;
    RnonCO2[	342	]=	5.51694E-01	;
    RnonCO2[	343	]=	5.49949E-01	;
    RnonCO2[	344	]=	5.48301E-01	;
    RnonCO2[	345	]=	5.46739E-01	;
    RnonCO2[	346	]=	5.45264E-01	;
    RnonCO2[	347	]=	5.43856E-01	;
    RnonCO2[	348	]=	5.42514E-01	;
    RnonCO2[	349	]=	5.41234E-01	;
    RnonCO2[	350	]=	5.40004E-01	;
    RnonCO2[	351	]=	5.38820E-01	;
    RnonCO2[	352	]=	5.37680E-01	;
    RnonCO2[	353	]=	5.36579E-01	;
    RnonCO2[	354	]=	5.35511E-01	;
    RnonCO2[	355	]=	5.34473E-01	;
    RnonCO2[	356	]=	5.33463E-01	;
    RnonCO2[	357	]=	5.32478E-01	;
    RnonCO2[	358	]=	5.31515E-01	;
    RnonCO2[	359	]=	5.30573E-01	;
    RnonCO2[	360	]=	5.29646E-01	;
    RnonCO2[	361	]=	5.28737E-01	;
    RnonCO2[	362	]=	5.27843E-01	;
    RnonCO2[	363	]=	5.26959E-01	;
    RnonCO2[	364	]=	5.26089E-01	;
    RnonCO2[	365	]=	5.25229E-01	;
    RnonCO2[	366	]=	5.24376E-01	;
    RnonCO2[	367	]=	5.23532E-01	;
    RnonCO2[	368	]=	5.22695E-01	;
    RnonCO2[	369	]=	5.21866E-01	;
    RnonCO2[	370	]=	5.21040E-01	;
    RnonCO2[	371	]=	5.20220E-01	;
    RnonCO2[	372	]=	5.19403E-01	;
    RnonCO2[	373	]=	5.18592E-01	;
    RnonCO2[	374	]=	5.17784E-01	;
    RnonCO2[	375	]=	5.16976E-01	;
    RnonCO2[	376	]=	5.16173E-01	;
    RnonCO2[	377	]=	5.15370E-01	;
    RnonCO2[	378	]=	5.14568E-01	;
    RnonCO2[	379	]=	5.13767E-01	;
    RnonCO2[	380	]=	5.12968E-01	;
    RnonCO2[	381	]=	5.12167E-01	;
    RnonCO2[	382	]=	5.11363E-01	;
    RnonCO2[	383	]=	5.10559E-01	;
    RnonCO2[	384	]=	5.09750E-01	;
    RnonCO2[	385	]=	5.08940E-01	;
    RnonCO2[	386	]=	5.08128E-01	;
    RnonCO2[	387	]=	5.07312E-01	;
    RnonCO2[	388	]=	5.06493E-01	;
    RnonCO2[	389	]=	5.05675E-01	;
    RnonCO2[	390	]=	5.04855E-01	;
    RnonCO2[	391	]=	5.04035E-01	;
    RnonCO2[	392	]=	5.03216E-01	;
    RnonCO2[	393	]=	5.02399E-01	;
    RnonCO2[	394	]=	5.01580E-01	;
    RnonCO2[	395	]=	5.00762E-01	;
    RnonCO2[	396	]=	4.99942E-01	;
    RnonCO2[	397	]=	4.99121E-01	;
    RnonCO2[	398	]=	4.98299E-01	;
    RnonCO2[	399	]=	4.97474E-01	;
    RnonCO2[	400	]=	4.96649E-01	;
    RnonCO2[	401	]=	4.95821E-01	;
    RnonCO2[	402	]=	4.94987E-01	;
    RnonCO2[	403	]=	4.94157E-01	;
    RnonCO2[	404	]=	4.93319E-01	;
    RnonCO2[	405	]=	4.92481E-01	;
    RnonCO2[	406	]=	4.91641E-01	;
    RnonCO2[	407	]=	4.90795E-01	;
    RnonCO2[	408	]=	4.89946E-01	;
    RnonCO2[	409	]=	4.89095E-01	;
    RnonCO2[	410	]=	4.88240E-01	;
    RnonCO2[	411	]=	4.87384E-01	;
    RnonCO2[	412	]=	4.86520E-01	;
    RnonCO2[	413	]=	4.85654E-01	;
    RnonCO2[	414	]=	4.84787E-01	;
    RnonCO2[	415	]=	4.83915E-01	;
    RnonCO2[	416	]=	4.83037E-01	;
    RnonCO2[	417	]=	4.82155E-01	;
    RnonCO2[	418	]=	4.81271E-01	;
    RnonCO2[	419	]=	4.80381E-01	;
    RnonCO2[	420	]=	4.79490E-01	;
    RnonCO2[	421	]=	4.78592E-01	;
    RnonCO2[	422	]=	4.77693E-01	;
    RnonCO2[	423	]=	4.76787E-01	;
    RnonCO2[	424	]=	4.75877E-01	;
    RnonCO2[	425	]=	4.74963E-01	;
    RnonCO2[	426	]=	4.74047E-01	;
    RnonCO2[	427	]=	4.73125E-01	;
    RnonCO2[	428	]=	4.72198E-01	;
    RnonCO2[	429	]=	4.71268E-01	;
    RnonCO2[	430	]=	4.70335E-01	;
    RnonCO2[	431	]=	4.69398E-01	;
    RnonCO2[	432	]=	4.68456E-01	;
    RnonCO2[	433	]=	4.67511E-01	;
    RnonCO2[	434	]=	4.66566E-01	;
    RnonCO2[	435	]=	4.65616E-01	;
    RnonCO2[	436	]=	4.64663E-01	;
    RnonCO2[	437	]=	4.63707E-01	;
    RnonCO2[	438	]=	4.62750E-01	;
    RnonCO2[	439	]=	4.61791E-01	;
    RnonCO2[	440	]=	4.60827E-01	;
    RnonCO2[	441	]=	4.59862E-01	;
    RnonCO2[	442	]=	4.58894E-01	;
    RnonCO2[	443	]=	4.57926E-01	;
    RnonCO2[	444	]=	4.56954E-01	;
    RnonCO2[	445	]=	4.55978E-01	;
    RnonCO2[	446	]=	4.55000E-01	;
    RnonCO2[	447	]=	4.54022E-01	;
    RnonCO2[	448	]=	4.53040E-01	;
    RnonCO2[	449	]=	4.52055E-01	;
    RnonCO2[	450	]=	4.51069E-01	;
    RnonCO2[	451	]=	4.50083E-01	;
    RnonCO2[	452	]=	4.49099E-01	;
    RnonCO2[	453	]=	4.48114E-01	;
    RnonCO2[	454	]=	4.47131E-01	;
    RnonCO2[	455	]=	4.46151E-01	;
    RnonCO2[	456	]=	4.45172E-01	;
    RnonCO2[	457	]=	4.44195E-01	;
    RnonCO2[	458	]=	4.43216E-01	;
    RnonCO2[	459	]=	4.42238E-01	;
    RnonCO2[	460	]=	4.41261E-01	;
    RnonCO2[	461	]=	4.40284E-01	;
    RnonCO2[	462	]=	4.39305E-01	;
    RnonCO2[	463	]=	4.38330E-01	;
    RnonCO2[	464	]=	4.37352E-01	;
    RnonCO2[	465	]=	4.36374E-01	;
    RnonCO2[	466	]=	4.35399E-01	;
    RnonCO2[	467	]=	4.34421E-01	;
    RnonCO2[	468	]=	4.33439E-01	;
    RnonCO2[	469	]=	4.32460E-01	;
    RnonCO2[	470	]=	4.31480E-01	;
    RnonCO2[	471	]=	4.30501E-01	;
    RnonCO2[	472	]=	4.29517E-01	;
    RnonCO2[	473	]=	4.28536E-01	;
    RnonCO2[	474	]=	4.27551E-01	;
    RnonCO2[	475	]=	4.26568E-01	;
    RnonCO2[	476	]=	4.25581E-01	;
    RnonCO2[	477	]=	4.24593E-01	;
    RnonCO2[	478	]=	4.23607E-01	;
    RnonCO2[	479	]=	4.22617E-01	;
    RnonCO2[	480	]=	4.21626E-01	;
    RnonCO2[	481	]=	4.20637E-01	;
    RnonCO2[	482	]=	4.19643E-01	;
    RnonCO2[	483	]=	4.18649E-01	;
    RnonCO2[	484	]=	4.17656E-01	;
    RnonCO2[	485	]=	4.16658E-01	;
    RnonCO2[	486	]=	4.15660E-01	;
    RnonCO2[	487	]=	4.14691E-01	;
    RnonCO2[	488	]=	4.13781E-01	;
    RnonCO2[	489	]=	4.12922E-01	;
    RnonCO2[	490	]=	4.12108E-01	;
    RnonCO2[	491	]=	4.11338E-01	;
    RnonCO2[	492	]=	4.10608E-01	;
    RnonCO2[	493	]=	4.09914E-01	;
    RnonCO2[	494	]=	4.09249E-01	;
    RnonCO2[	495	]=	4.08619E-01	;
    RnonCO2[	496	]=	4.08011E-01	;
    RnonCO2[	497	]=	4.07432E-01	;
    RnonCO2[	498	]=	4.06876E-01	;
    RnonCO2[	499	]=	4.06338E-01	;
    RnonCO2[	500	]=	4.05821E-01	;
    RnonCO2[	501	]=	4.05324E-01	;
    RnonCO2[	502	]=	4.04840E-01	;
    RnonCO2[	503	]=	4.04376E-01	;
    RnonCO2[	504	]=	4.03921E-01	;
    RnonCO2[	505	]=	4.03482E-01	;
    RnonCO2[	506	]=	4.03054E-01	;
    RnonCO2[	507	]=	4.02639E-01	;
    RnonCO2[	508	]=	4.02230E-01	;
    RnonCO2[	509	]=	4.01836E-01	;
    RnonCO2[	510	]=	4.01448E-01	;
    RnonCO2[	511	]=	4.01070E-01	;
    RnonCO2[	512	]=	4.00699E-01	;
    RnonCO2[	513	]=	4.00337E-01	;
    RnonCO2[	514	]=	3.99982E-01	;
    RnonCO2[	515	]=	3.99632E-01	;
    RnonCO2[	516	]=	3.99288E-01	;
    RnonCO2[	517	]=	3.98952E-01	;
    RnonCO2[	518	]=	3.98620E-01	;
    RnonCO2[	519	]=	3.98296E-01	;
    RnonCO2[	520	]=	3.97973E-01	;
    RnonCO2[	521	]=	3.97657E-01	;
    RnonCO2[	522	]=	3.97348E-01	;
    RnonCO2[	523	]=	3.97039E-01	;
    RnonCO2[	524	]=	3.96737E-01	;
    RnonCO2[	525	]=	3.96440E-01	;
    RnonCO2[	526	]=	3.96145E-01	;
    RnonCO2[	527	]=	3.95854E-01	;
    RnonCO2[	528	]=	3.95567E-01	;
    RnonCO2[	529	]=	3.95282E-01	;
    RnonCO2[	530	]=	3.95003E-01	;
    RnonCO2[	531	]=	3.94726E-01	;
    RnonCO2[	532	]=	3.94452E-01	;
    RnonCO2[	533	]=	3.94183E-01	;
    RnonCO2[	534	]=	3.93916E-01	;
    RnonCO2[	535	]=	3.93651E-01	;
    RnonCO2[	536	]=	3.93389E-01	;
    RnonCO2[	537	]=	3.93131E-01	;
    RnonCO2[	538	]=	3.92875E-01	;
    RnonCO2[	539	]=	3.92621E-01	;
    RnonCO2[	540	]=	3.92369E-01	;
    RnonCO2[	541	]=	3.92121E-01	;
    RnonCO2[	542	]=	3.91876E-01	;
    RnonCO2[	543	]=	3.91631E-01	;
    RnonCO2[	544	]=	3.91392E-01	;
    RnonCO2[	545	]=	3.91151E-01	;
    RnonCO2[	546	]=	3.90914E-01	;
    RnonCO2[	547	]=	3.90682E-01	;
    RnonCO2[	548	]=	3.90448E-01	;
    RnonCO2[	549	]=	3.90218E-01	;
    RnonCO2[	550	]=	3.89990E-01	;
    RnonCO2[	551	]=	3.89763E-01	;
    RnonCO2[	552	]=	3.89537E-01	;
    RnonCO2[	553	]=	3.89316E-01	;
    RnonCO2[	554	]=	3.89096E-01	;
    RnonCO2[	555	]=	3.88877E-01	;
    RnonCO2[	556	]=	3.88662E-01	;
    RnonCO2[	557	]=	3.88445E-01	;
    RnonCO2[	558	]=	3.88232E-01	;
    RnonCO2[	559	]=	3.88020E-01	;
    RnonCO2[	560	]=	3.87810E-01	;
    RnonCO2[	561	]=	3.87603E-01	;
    RnonCO2[	562	]=	3.87397E-01	;
    RnonCO2[	563	]=	3.87192E-01	;
    RnonCO2[	564	]=	3.86988E-01	;
    RnonCO2[	565	]=	3.86785E-01	;
    RnonCO2[	566	]=	3.86585E-01	;
    RnonCO2[	567	]=	3.86386E-01	;
    RnonCO2[	568	]=	3.86188E-01	;
    RnonCO2[	569	]=	3.85991E-01	;
    RnonCO2[	570	]=	3.85797E-01	;
    RnonCO2[	571	]=	3.85601E-01	;
    RnonCO2[	572	]=	3.85409E-01	;
    RnonCO2[	573	]=	3.85218E-01	;
    RnonCO2[	574	]=	3.85030E-01	;
    RnonCO2[	575	]=	3.84839E-01	;
    RnonCO2[	576	]=	3.84652E-01	;
    RnonCO2[	577	]=	3.84466E-01	;
    RnonCO2[	578	]=	3.84279E-01	;
    RnonCO2[	579	]=	3.84094E-01	;
    RnonCO2[	580	]=	3.83912E-01	;
    RnonCO2[	581	]=	3.83727E-01	;
    RnonCO2[	582	]=	3.83545E-01	;
    RnonCO2[	583	]=	3.83364E-01	;
    RnonCO2[	584	]=	3.83183E-01	;
    RnonCO2[	585	]=	3.83006E-01	;
    RnonCO2[	586	]=	3.82826E-01	;
    RnonCO2[	587	]=	3.82651E-01	;
    RnonCO2[	588	]=	3.82477E-01	;
    RnonCO2[	589	]=	3.82304E-01	;
    RnonCO2[	590	]=	3.82136E-01	;
    RnonCO2[	591	]=	3.81968E-01	;
    RnonCO2[	592	]=	3.81806E-01	;
    RnonCO2[	593	]=	3.81645E-01	;
    RnonCO2[	594	]=	3.81487E-01	;
    RnonCO2[	595	]=	3.81332E-01	;
    RnonCO2[	596	]=	3.81182E-01	;
    RnonCO2[	597	]=	3.81030E-01	;
    RnonCO2[	598	]=	3.80883E-01	;
    RnonCO2[	599	]=	3.80738E-01	;
    RnonCO2[	600	]=	3.80594E-01	;
    RnonCO2[	601	]=	3.80452E-01	;
    RnonCO2[	602	]=	3.80311E-01	;
    RnonCO2[	603	]=	3.80175E-01	;
    RnonCO2[	604	]=	3.80040E-01	;
    RnonCO2[	605	]=	3.79906E-01	;
    RnonCO2[	606	]=	3.79773E-01	;
    RnonCO2[	607	]=	3.79641E-01	;
    RnonCO2[	608	]=	3.79510E-01	;
    RnonCO2[	609	]=	3.79383E-01	;
    RnonCO2[	610	]=	3.79254E-01	;
    RnonCO2[	611	]=	3.79129E-01	;
    RnonCO2[	612	]=	3.79005E-01	;
    RnonCO2[	613	]=	3.78882E-01	;
    RnonCO2[	614	]=	3.78762E-01	;
    RnonCO2[	615	]=	3.78641E-01	;
    RnonCO2[	616	]=	3.78519E-01	;
    RnonCO2[	617	]=	3.78402E-01	;
    RnonCO2[	618	]=	3.78285E-01	;
    RnonCO2[	619	]=	3.78170E-01	;
    RnonCO2[	620	]=	3.78054E-01	;
    RnonCO2[	621	]=	3.77940E-01	;
    RnonCO2[	622	]=	3.77829E-01	;
    RnonCO2[	623	]=	3.77716E-01	;
    RnonCO2[	624	]=	3.77605E-01	;
    RnonCO2[	625	]=	3.77496E-01	;
    RnonCO2[	626	]=	3.77388E-01	;
    RnonCO2[	627	]=	3.77280E-01	;
    RnonCO2[	628	]=	3.77172E-01	;
    RnonCO2[	629	]=	3.77069E-01	;
    RnonCO2[	630	]=	3.76962E-01	;
    RnonCO2[	631	]=	3.76859E-01	;
    RnonCO2[	632	]=	3.76754E-01	;
    RnonCO2[	633	]=	3.76652E-01	;
    RnonCO2[	634	]=	3.76550E-01	;
    RnonCO2[	635	]=	3.76450E-01	;
    RnonCO2[	636	]=	3.76352E-01	;
    RnonCO2[	637	]=	3.76253E-01	;
    RnonCO2[	638	]=	3.76156E-01	;
    RnonCO2[	639	]=	3.76057E-01	;
    RnonCO2[	640	]=	3.75962E-01	;
    RnonCO2[	641	]=	3.75867E-01	;
    RnonCO2[	642	]=	3.75772E-01	;
    RnonCO2[	643	]=	3.75678E-01	;
    RnonCO2[	644	]=	3.75584E-01	;
    RnonCO2[	645	]=	3.75491E-01	;
    RnonCO2[	646	]=	3.75401E-01	;
    RnonCO2[	647	]=	3.75312E-01	;
    RnonCO2[	648	]=	3.75220E-01	;
    RnonCO2[	649	]=	3.75132E-01	;
    RnonCO2[	650	]=	3.75043E-01	;
    RnonCO2[	651	]=	3.74955E-01	;
    RnonCO2[	652	]=	3.74868E-01	;
    RnonCO2[	653	]=	3.74781E-01	;
    RnonCO2[	654	]=	3.74697E-01	;
    RnonCO2[	655	]=	3.74611E-01	;
    RnonCO2[	656	]=	3.74528E-01	;
    RnonCO2[	657	]=	3.74443E-01	;
    RnonCO2[	658	]=	3.74361E-01	;
    RnonCO2[	659	]=	3.74279E-01	;
    RnonCO2[	660	]=	3.74198E-01	;
    RnonCO2[	661	]=	3.74117E-01	;
    RnonCO2[	662	]=	3.74036E-01	;
    RnonCO2[	663	]=	3.73959E-01	;
    RnonCO2[	664	]=	3.73879E-01	;
    RnonCO2[	665	]=	3.73802E-01	;
    RnonCO2[	666	]=	3.73723E-01	;
    RnonCO2[	667	]=	3.73647E-01	;
    RnonCO2[	668	]=	3.73572E-01	;
    RnonCO2[	669	]=	3.73496E-01	;
    RnonCO2[	670	]=	3.73421E-01	;
    RnonCO2[	671	]=	3.73347E-01	;
    RnonCO2[	672	]=	3.73272E-01	;
    RnonCO2[	673	]=	3.73198E-01	;
    RnonCO2[	674	]=	3.73125E-01	;
    RnonCO2[	675	]=	3.73054E-01	;
    RnonCO2[	676	]=	3.72981E-01	;
    RnonCO2[	677	]=	3.72911E-01	;
    RnonCO2[	678	]=	3.72842E-01	;
    RnonCO2[	679	]=	3.72773E-01	;
    RnonCO2[	680	]=	3.72704E-01	;
    RnonCO2[	681	]=	3.72635E-01	;
    RnonCO2[	682	]=	3.72567E-01	;
    RnonCO2[	683	]=	3.72499E-01	;
    RnonCO2[	684	]=	3.72431E-01	;
    RnonCO2[	685	]=	3.72363E-01	;
    RnonCO2[	686	]=	3.72300E-01	;
    RnonCO2[	687	]=	3.72232E-01	;
    RnonCO2[	688	]=	3.72169E-01	;
    RnonCO2[	689	]=	3.72105E-01	;
    RnonCO2[	690	]=	3.72039E-01	;
    RnonCO2[	691	]=	3.71976E-01	;
    RnonCO2[	692	]=	3.71914E-01	;
    RnonCO2[	693	]=	3.71851E-01	;
    RnonCO2[	694	]=	3.71789E-01	;
    RnonCO2[	695	]=	3.71727E-01	;
    RnonCO2[	696	]=	3.71668E-01	;
    RnonCO2[	697	]=	3.71607E-01	;
    RnonCO2[	698	]=	3.71546E-01	;
    RnonCO2[	699	]=	3.71488E-01	;
    RnonCO2[	700	]=	3.71427E-01	;
    RnonCO2[	701	]=	3.71370E-01	;
    RnonCO2[	702	]=	3.71313E-01	;
    RnonCO2[	703	]=	3.71256E-01	;
    RnonCO2[	704	]=	3.71196E-01	;
    RnonCO2[	705	]=	3.71140E-01	;
    RnonCO2[	706	]=	3.71083E-01	;
    RnonCO2[	707	]=	3.71027E-01	;
    RnonCO2[	708	]=	3.70974E-01	;
    RnonCO2[	709	]=	3.70918E-01	;
    RnonCO2[	710	]=	3.70863E-01	;
    RnonCO2[	711	]=	3.70808E-01	;
    RnonCO2[	712	]=	3.70756E-01	;
    RnonCO2[	713	]=	3.70701E-01	;
    RnonCO2[	714	]=	3.70649E-01	;
    RnonCO2[	715	]=	3.70598E-01	;
    RnonCO2[	716	]=	3.70544E-01	;
    RnonCO2[	717	]=	3.70493E-01	;
    RnonCO2[	718	]=	3.70442E-01	;
    RnonCO2[	719	]=	3.70391E-01	;
    RnonCO2[	720	]=	3.70341E-01	;
    RnonCO2[	721	]=	3.70291E-01	;
    RnonCO2[	722	]=	3.70241E-01	;
    RnonCO2[	723	]=	3.70191E-01	;
    RnonCO2[	724	]=	3.70141E-01	;
    RnonCO2[	725	]=	3.70092E-01	;
    RnonCO2[	726	]=	3.70045E-01	;
    RnonCO2[	727	]=	3.69996E-01	;
    RnonCO2[	728	]=	3.69950E-01	;
    RnonCO2[	729	]=	3.69901E-01	;
    RnonCO2[	730	]=	3.69856E-01	;
    RnonCO2[	731	]=	3.69808E-01	;
    RnonCO2[	732	]=	3.69762E-01	;
    RnonCO2[	733	]=	3.69717E-01	;
    RnonCO2[	734	]=	3.69672E-01	;
    RnonCO2[	735	]=	3.69648E-01	;
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
}

void setR_aerosol_ssp119(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.16717E+00	;
    RnonCO2[	252	]=	-1.13187E+00	;
    RnonCO2[	253	]=	-1.09576E+00	;
    RnonCO2[	254	]=	-1.05880E+00	;
    RnonCO2[	255	]=	-1.02093E+00	;
    RnonCO2[	256	]=	-9.80600E-01	;
    RnonCO2[	257	]=	-9.39215E-01	;
    RnonCO2[	258	]=	-8.96703E-01	;
    RnonCO2[	259	]=	-8.52987E-01	;
    RnonCO2[	260	]=	-8.07982E-01	;
    RnonCO2[	261	]=	-7.61591E-01	;
    RnonCO2[	262	]=	-7.13707E-01	;
    RnonCO2[	263	]=	-6.64211E-01	;
    RnonCO2[	264	]=	-6.12967E-01	;
    RnonCO2[	265	]=	-5.59824E-01	;
    RnonCO2[	266	]=	-5.43941E-01	;
    RnonCO2[	267	]=	-5.27870E-01	;
    RnonCO2[	268	]=	-5.11604E-01	;
    RnonCO2[	269	]=	-4.95139E-01	;
    RnonCO2[	270	]=	-4.78470E-01	;
    RnonCO2[	271	]=	-4.61590E-01	;
    RnonCO2[	272	]=	-4.44493E-01	;
    RnonCO2[	273	]=	-4.27172E-01	;
    RnonCO2[	274	]=	-4.09622E-01	;
    RnonCO2[	275	]=	-3.91835E-01	;
    RnonCO2[	276	]=	-3.88725E-01	;
    RnonCO2[	277	]=	-3.85609E-01	;
    RnonCO2[	278	]=	-3.82487E-01	;
    RnonCO2[	279	]=	-3.79359E-01	;
    RnonCO2[	280	]=	-3.76225E-01	;
    RnonCO2[	281	]=	-3.73085E-01	;
    RnonCO2[	282	]=	-3.69939E-01	;
    RnonCO2[	283	]=	-3.66786E-01	;
    RnonCO2[	284	]=	-3.63628E-01	;
    RnonCO2[	285	]=	-3.60464E-01	;
    RnonCO2[	286	]=	-3.58905E-01	;
    RnonCO2[	287	]=	-3.57346E-01	;
    RnonCO2[	288	]=	-3.55785E-01	;
    RnonCO2[	289	]=	-3.54222E-01	;
    RnonCO2[	290	]=	-3.52659E-01	;
    RnonCO2[	291	]=	-3.51093E-01	;
    RnonCO2[	292	]=	-3.49526E-01	;
    RnonCO2[	293	]=	-3.47958E-01	;
    RnonCO2[	294	]=	-3.46388E-01	;
    RnonCO2[	295	]=	-3.44817E-01	;
    RnonCO2[	296	]=	-3.41360E-01	;
    RnonCO2[	297	]=	-3.37895E-01	;
    RnonCO2[	298	]=	-3.34421E-01	;
    RnonCO2[	299	]=	-3.30939E-01	;
    RnonCO2[	300	]=	-3.27448E-01	;
    RnonCO2[	301	]=	-3.23950E-01	;
    RnonCO2[	302	]=	-3.20443E-01	;
    RnonCO2[	303	]=	-3.16927E-01	;
    RnonCO2[	304	]=	-3.13403E-01	;
    RnonCO2[	305	]=	-3.09870E-01	;
    RnonCO2[	306	]=	-3.05307E-01	;
    RnonCO2[	307	]=	-3.00731E-01	;
    RnonCO2[	308	]=	-2.96140E-01	;
    RnonCO2[	309	]=	-2.91534E-01	;
    RnonCO2[	310	]=	-2.86914E-01	;
    RnonCO2[	311	]=	-2.82279E-01	;
    RnonCO2[	312	]=	-2.77629E-01	;
    RnonCO2[	313	]=	-2.72964E-01	;
    RnonCO2[	314	]=	-2.68284E-01	;
    RnonCO2[	315	]=	-2.63589E-01	;
    RnonCO2[	316	]=	-2.59021E-01	;
    RnonCO2[	317	]=	-2.54439E-01	;
    RnonCO2[	318	]=	-2.49841E-01	;
    RnonCO2[	319	]=	-2.45227E-01	;
    RnonCO2[	320	]=	-2.40598E-01	;
    RnonCO2[	321	]=	-2.35953E-01	;
    RnonCO2[	322	]=	-2.31293E-01	;
    RnonCO2[	323	]=	-2.26616E-01	;
    RnonCO2[	324	]=	-2.21923E-01	;
    RnonCO2[	325	]=	-2.17215E-01	;
    RnonCO2[	326	]=	-2.12023E-01	;
    RnonCO2[	327	]=	-2.06811E-01	;
    RnonCO2[	328	]=	-2.01579E-01	;
    RnonCO2[	329	]=	-1.96328E-01	;
    RnonCO2[	330	]=	-1.91055E-01	;
    RnonCO2[	331	]=	-1.85763E-01	;
    RnonCO2[	332	]=	-1.80449E-01	;
    RnonCO2[	333	]=	-1.75115E-01	;
    RnonCO2[	334	]=	-1.69760E-01	;
    RnonCO2[	335	]=	-1.64383E-01	;
    RnonCO2[	336	]=	-1.63389E-01	;
    RnonCO2[	337	]=	-1.62394E-01	;
    RnonCO2[	338	]=	-1.61399E-01	;
    RnonCO2[	339	]=	-1.60403E-01	;
    RnonCO2[	340	]=	-1.59406E-01	;
    RnonCO2[	341	]=	-1.58409E-01	;
    RnonCO2[	342	]=	-1.57411E-01	;
    RnonCO2[	343	]=	-1.56412E-01	;
    RnonCO2[	344	]=	-1.55413E-01	;
    RnonCO2[	345	]=	-1.54413E-01	;
    RnonCO2[	346	]=	-1.53412E-01	;
    RnonCO2[	347	]=	-1.52410E-01	;
    RnonCO2[	348	]=	-1.51408E-01	;
    RnonCO2[	349	]=	-1.50405E-01	;
    RnonCO2[	350	]=	-1.49402E-01	;
    RnonCO2[	351	]=	-1.48398E-01	;
    RnonCO2[	352	]=	-1.47393E-01	;
    RnonCO2[	353	]=	-1.46387E-01	;
    RnonCO2[	354	]=	-1.45381E-01	;
    RnonCO2[	355	]=	-1.44375E-01	;
    RnonCO2[	356	]=	-1.43368E-01	;
    RnonCO2[	357	]=	-1.42360E-01	;
    RnonCO2[	358	]=	-1.41351E-01	;
    RnonCO2[	359	]=	-1.40342E-01	;
    RnonCO2[	360	]=	-1.39333E-01	;
    RnonCO2[	361	]=	-1.38322E-01	;
    RnonCO2[	362	]=	-1.37311E-01	;
    RnonCO2[	363	]=	-1.36299E-01	;
    RnonCO2[	364	]=	-1.35287E-01	;
    RnonCO2[	365	]=	-1.34274E-01	;
    RnonCO2[	366	]=	-1.33261E-01	;
    RnonCO2[	367	]=	-1.32246E-01	;
    RnonCO2[	368	]=	-1.31231E-01	;
    RnonCO2[	369	]=	-1.30216E-01	;
    RnonCO2[	370	]=	-1.29200E-01	;
    RnonCO2[	371	]=	-1.28183E-01	;
    RnonCO2[	372	]=	-1.27165E-01	;
    RnonCO2[	373	]=	-1.26147E-01	;
    RnonCO2[	374	]=	-1.25128E-01	;
    RnonCO2[	375	]=	-1.24108E-01	;
    RnonCO2[	376	]=	-1.23088E-01	;
    RnonCO2[	377	]=	-1.22067E-01	;
    RnonCO2[	378	]=	-1.21045E-01	;
    RnonCO2[	379	]=	-1.20022E-01	;
    RnonCO2[	380	]=	-1.18999E-01	;
    RnonCO2[	381	]=	-1.17975E-01	;
    RnonCO2[	382	]=	-1.16950E-01	;
    RnonCO2[	383	]=	-1.15925E-01	;
    RnonCO2[	384	]=	-1.14899E-01	;
    RnonCO2[	385	]=	-1.13872E-01	;
    RnonCO2[	386	]=	-1.12845E-01	;
    RnonCO2[	387	]=	-1.11817E-01	;
    RnonCO2[	388	]=	-1.10789E-01	;
    RnonCO2[	389	]=	-1.09759E-01	;
    RnonCO2[	390	]=	-1.08730E-01	;
    RnonCO2[	391	]=	-1.07699E-01	;
    RnonCO2[	392	]=	-1.06668E-01	;
    RnonCO2[	393	]=	-1.05636E-01	;
    RnonCO2[	394	]=	-1.04603E-01	;
    RnonCO2[	395	]=	-1.03570E-01	;
    RnonCO2[	396	]=	-1.02536E-01	;
    RnonCO2[	397	]=	-1.01501E-01	;
    RnonCO2[	398	]=	-1.00465E-01	;
    RnonCO2[	399	]=	-9.94289E-02	;
    RnonCO2[	400	]=	-9.83918E-02	;
    RnonCO2[	401	]=	-9.73541E-02	;
    RnonCO2[	402	]=	-9.63156E-02	;
    RnonCO2[	403	]=	-9.52765E-02	;
    RnonCO2[	404	]=	-9.42367E-02	;
    RnonCO2[	405	]=	-9.31961E-02	;
    RnonCO2[	406	]=	-9.21552E-02	;
    RnonCO2[	407	]=	-9.11136E-02	;
    RnonCO2[	408	]=	-9.00713E-02	;
    RnonCO2[	409	]=	-8.90283E-02	;
    RnonCO2[	410	]=	-8.79845E-02	;
    RnonCO2[	411	]=	-8.69401E-02	;
    RnonCO2[	412	]=	-8.58950E-02	;
    RnonCO2[	413	]=	-8.48491E-02	;
    RnonCO2[	414	]=	-8.38025E-02	;
    RnonCO2[	415	]=	-8.27552E-02	;
    RnonCO2[	416	]=	-8.17072E-02	;
    RnonCO2[	417	]=	-8.06585E-02	;
    RnonCO2[	418	]=	-7.96090E-02	;
    RnonCO2[	419	]=	-7.85588E-02	;
    RnonCO2[	420	]=	-7.75079E-02	;
    RnonCO2[	421	]=	-7.64563E-02	;
    RnonCO2[	422	]=	-7.54040E-02	;
    RnonCO2[	423	]=	-7.43509E-02	;
    RnonCO2[	424	]=	-7.32971E-02	;
    RnonCO2[	425	]=	-7.22426E-02	;
    RnonCO2[	426	]=	-7.11869E-02	;
    RnonCO2[	427	]=	-7.01305E-02	;
    RnonCO2[	428	]=	-6.90733E-02	;
    RnonCO2[	429	]=	-6.80155E-02	;
    RnonCO2[	430	]=	-6.69569E-02	;
    RnonCO2[	431	]=	-6.58975E-02	;
    RnonCO2[	432	]=	-6.48374E-02	;
    RnonCO2[	433	]=	-6.37766E-02	;
    RnonCO2[	434	]=	-6.27151E-02	;
    RnonCO2[	435	]=	-6.16528E-02	;
    RnonCO2[	436	]=	-6.05902E-02	;
    RnonCO2[	437	]=	-5.95268E-02	;
    RnonCO2[	438	]=	-5.84628E-02	;
    RnonCO2[	439	]=	-5.73980E-02	;
    RnonCO2[	440	]=	-5.63324E-02	;
    RnonCO2[	441	]=	-5.52661E-02	;
    RnonCO2[	442	]=	-5.41991E-02	;
    RnonCO2[	443	]=	-5.31312E-02	;
    RnonCO2[	444	]=	-5.20627E-02	;
    RnonCO2[	445	]=	-5.09934E-02	;
    RnonCO2[	446	]=	-4.99230E-02	;
    RnonCO2[	447	]=	-4.88518E-02	;
    RnonCO2[	448	]=	-4.77798E-02	;
    RnonCO2[	449	]=	-4.67071E-02	;
    RnonCO2[	450	]=	-4.56337E-02	;
    RnonCO2[	451	]=	-4.45594E-02	;
    RnonCO2[	452	]=	-4.34845E-02	;
    RnonCO2[	453	]=	-4.24087E-02	;
    RnonCO2[	454	]=	-4.13322E-02	;
    RnonCO2[	455	]=	-4.02549E-02	;
    RnonCO2[	456	]=	-3.91772E-02	;
    RnonCO2[	457	]=	-3.80986E-02	;
    RnonCO2[	458	]=	-3.70193E-02	;
    RnonCO2[	459	]=	-3.59393E-02	;
    RnonCO2[	460	]=	-3.48584E-02	;
    RnonCO2[	461	]=	-3.37768E-02	;
    RnonCO2[	462	]=	-3.26944E-02	;
    RnonCO2[	463	]=	-3.16112E-02	;
    RnonCO2[	464	]=	-3.05273E-02	;
    RnonCO2[	465	]=	-2.94426E-02	;
    RnonCO2[	466	]=	-2.83572E-02	;
    RnonCO2[	467	]=	-2.72710E-02	;
    RnonCO2[	468	]=	-2.61840E-02	;
    RnonCO2[	469	]=	-2.50962E-02	;
    RnonCO2[	470	]=	-2.40077E-02	;
    RnonCO2[	471	]=	-2.29183E-02	;
    RnonCO2[	472	]=	-2.18282E-02	;
    RnonCO2[	473	]=	-2.07373E-02	;
    RnonCO2[	474	]=	-1.96456E-02	;
    RnonCO2[	475	]=	-1.85531E-02	;
    RnonCO2[	476	]=	-1.74595E-02	;
    RnonCO2[	477	]=	-1.63650E-02	;
    RnonCO2[	478	]=	-1.52698E-02	;
    RnonCO2[	479	]=	-1.41737E-02	;
    RnonCO2[	480	]=	-1.30769E-02	;
    RnonCO2[	481	]=	-1.19792E-02	;
    RnonCO2[	482	]=	-1.08808E-02	;
    RnonCO2[	483	]=	-9.78154E-03	;
    RnonCO2[	484	]=	-8.68148E-03	;
    RnonCO2[	485	]=	-7.58062E-03	;
    RnonCO2[	486	]=	-7.58062E-03	;
    RnonCO2[	487	]=	-7.58062E-03	;
    RnonCO2[	488	]=	-7.58062E-03	;
    RnonCO2[	489	]=	-7.58062E-03	;
    RnonCO2[	490	]=	-7.58062E-03	;
    RnonCO2[	491	]=	-7.58062E-03	;
    RnonCO2[	492	]=	-7.58062E-03	;
    RnonCO2[	493	]=	-7.58062E-03	;
    RnonCO2[	494	]=	-7.58062E-03	;
    RnonCO2[	495	]=	-7.58062E-03	;
    RnonCO2[	496	]=	-7.58062E-03	;
    RnonCO2[	497	]=	-7.58062E-03	;
    RnonCO2[	498	]=	-7.58062E-03	;
    RnonCO2[	499	]=	-7.58062E-03	;
    RnonCO2[	500	]=	-7.58062E-03	;
    RnonCO2[	501	]=	-7.58062E-03	;
    RnonCO2[	502	]=	-7.58062E-03	;
    RnonCO2[	503	]=	-7.58062E-03	;
    RnonCO2[	504	]=	-7.58062E-03	;
    RnonCO2[	505	]=	-7.58062E-03	;
    RnonCO2[	506	]=	-7.58062E-03	;
    RnonCO2[	507	]=	-7.58062E-03	;
    RnonCO2[	508	]=	-7.58062E-03	;
    RnonCO2[	509	]=	-7.58062E-03	;
    RnonCO2[	510	]=	-7.58062E-03	;
    RnonCO2[	511	]=	-7.58062E-03	;
    RnonCO2[	512	]=	-7.58062E-03	;
    RnonCO2[	513	]=	-7.58062E-03	;
    RnonCO2[	514	]=	-7.58062E-03	;
    RnonCO2[	515	]=	-7.58062E-03	;
    RnonCO2[	516	]=	-7.58062E-03	;
    RnonCO2[	517	]=	-7.58062E-03	;
    RnonCO2[	518	]=	-7.58062E-03	;
    RnonCO2[	519	]=	-7.58062E-03	;
    RnonCO2[	520	]=	-7.58062E-03	;
    RnonCO2[	521	]=	-7.58062E-03	;
    RnonCO2[	522	]=	-7.58062E-03	;
    RnonCO2[	523	]=	-7.58062E-03	;
    RnonCO2[	524	]=	-7.58062E-03	;
    RnonCO2[	525	]=	-7.58062E-03	;
    RnonCO2[	526	]=	-7.58062E-03	;
    RnonCO2[	527	]=	-7.58062E-03	;
    RnonCO2[	528	]=	-7.58062E-03	;
    RnonCO2[	529	]=	-7.58062E-03	;
    RnonCO2[	530	]=	-7.58062E-03	;
    RnonCO2[	531	]=	-7.58062E-03	;
    RnonCO2[	532	]=	-7.58062E-03	;
    RnonCO2[	533	]=	-7.58062E-03	;
    RnonCO2[	534	]=	-7.58062E-03	;
    RnonCO2[	535	]=	-7.58062E-03	;
    RnonCO2[	536	]=	-7.58062E-03	;
    RnonCO2[	537	]=	-7.58062E-03	;
    RnonCO2[	538	]=	-7.58062E-03	;
    RnonCO2[	539	]=	-7.58062E-03	;
    RnonCO2[	540	]=	-7.58062E-03	;
    RnonCO2[	541	]=	-7.58062E-03	;
    RnonCO2[	542	]=	-7.58062E-03	;
    RnonCO2[	543	]=	-7.58062E-03	;
    RnonCO2[	544	]=	-7.58062E-03	;
    RnonCO2[	545	]=	-7.58062E-03	;
    RnonCO2[	546	]=	-7.58062E-03	;
    RnonCO2[	547	]=	-7.58062E-03	;
    RnonCO2[	548	]=	-7.58062E-03	;
    RnonCO2[	549	]=	-7.58062E-03	;
    RnonCO2[	550	]=	-7.58062E-03	;
    RnonCO2[	551	]=	-7.58062E-03	;
    RnonCO2[	552	]=	-7.58062E-03	;
    RnonCO2[	553	]=	-7.58062E-03	;
    RnonCO2[	554	]=	-7.58062E-03	;
    RnonCO2[	555	]=	-7.58062E-03	;
    RnonCO2[	556	]=	-7.58062E-03	;
    RnonCO2[	557	]=	-7.58062E-03	;
    RnonCO2[	558	]=	-7.58062E-03	;
    RnonCO2[	559	]=	-7.58062E-03	;
    RnonCO2[	560	]=	-7.58062E-03	;
    RnonCO2[	561	]=	-7.58062E-03	;
    RnonCO2[	562	]=	-7.58062E-03	;
    RnonCO2[	563	]=	-7.58062E-03	;
    RnonCO2[	564	]=	-7.58062E-03	;
    RnonCO2[	565	]=	-7.58062E-03	;
    RnonCO2[	566	]=	-7.58062E-03	;
    RnonCO2[	567	]=	-7.58062E-03	;
    RnonCO2[	568	]=	-7.58062E-03	;
    RnonCO2[	569	]=	-7.58062E-03	;
    RnonCO2[	570	]=	-7.58062E-03	;
    RnonCO2[	571	]=	-7.58062E-03	;
    RnonCO2[	572	]=	-7.58062E-03	;
    RnonCO2[	573	]=	-7.58062E-03	;
    RnonCO2[	574	]=	-7.58062E-03	;
    RnonCO2[	575	]=	-7.58062E-03	;
    RnonCO2[	576	]=	-7.58062E-03	;
    RnonCO2[	577	]=	-7.58062E-03	;
    RnonCO2[	578	]=	-7.58062E-03	;
    RnonCO2[	579	]=	-7.58062E-03	;
    RnonCO2[	580	]=	-7.58062E-03	;
    RnonCO2[	581	]=	-7.58062E-03	;
    RnonCO2[	582	]=	-7.58062E-03	;
    RnonCO2[	583	]=	-7.58062E-03	;
    RnonCO2[	584	]=	-7.58062E-03	;
    RnonCO2[	585	]=	-7.58062E-03	;
    RnonCO2[	586	]=	-7.58062E-03	;
    RnonCO2[	587	]=	-7.58062E-03	;
    RnonCO2[	588	]=	-7.58062E-03	;
    RnonCO2[	589	]=	-7.58062E-03	;
    RnonCO2[	590	]=	-7.58062E-03	;
    RnonCO2[	591	]=	-7.58062E-03	;
    RnonCO2[	592	]=	-7.58062E-03	;
    RnonCO2[	593	]=	-7.58062E-03	;
    RnonCO2[	594	]=	-7.58062E-03	;
    RnonCO2[	595	]=	-7.58062E-03	;
    RnonCO2[	596	]=	-7.58062E-03	;
    RnonCO2[	597	]=	-7.58062E-03	;
    RnonCO2[	598	]=	-7.58062E-03	;
    RnonCO2[	599	]=	-7.58062E-03	;
    RnonCO2[	600	]=	-7.58062E-03	;
    RnonCO2[	601	]=	-7.58062E-03	;
    RnonCO2[	602	]=	-7.58062E-03	;
    RnonCO2[	603	]=	-7.58062E-03	;
    RnonCO2[	604	]=	-7.58062E-03	;
    RnonCO2[	605	]=	-7.58062E-03	;
    RnonCO2[	606	]=	-7.58062E-03	;
    RnonCO2[	607	]=	-7.58062E-03	;
    RnonCO2[	608	]=	-7.58062E-03	;
    RnonCO2[	609	]=	-7.58062E-03	;
    RnonCO2[	610	]=	-7.58062E-03	;
    RnonCO2[	611	]=	-7.58062E-03	;
    RnonCO2[	612	]=	-7.58062E-03	;
    RnonCO2[	613	]=	-7.58062E-03	;
    RnonCO2[	614	]=	-7.58062E-03	;
    RnonCO2[	615	]=	-7.58062E-03	;
    RnonCO2[	616	]=	-7.58062E-03	;
    RnonCO2[	617	]=	-7.58062E-03	;
    RnonCO2[	618	]=	-7.58062E-03	;
    RnonCO2[	619	]=	-7.58062E-03	;
    RnonCO2[	620	]=	-7.58062E-03	;
    RnonCO2[	621	]=	-7.58062E-03	;
    RnonCO2[	622	]=	-7.58062E-03	;
    RnonCO2[	623	]=	-7.58062E-03	;
    RnonCO2[	624	]=	-7.58062E-03	;
    RnonCO2[	625	]=	-7.58062E-03	;
    RnonCO2[	626	]=	-7.58062E-03	;
    RnonCO2[	627	]=	-7.58062E-03	;
    RnonCO2[	628	]=	-7.58062E-03	;
    RnonCO2[	629	]=	-7.58062E-03	;
    RnonCO2[	630	]=	-7.58062E-03	;
    RnonCO2[	631	]=	-7.58062E-03	;
    RnonCO2[	632	]=	-7.58062E-03	;
    RnonCO2[	633	]=	-7.58062E-03	;
    RnonCO2[	634	]=	-7.58062E-03	;
    RnonCO2[	635	]=	-7.58062E-03	;
    RnonCO2[	636	]=	-7.58062E-03	;
    RnonCO2[	637	]=	-7.58062E-03	;
    RnonCO2[	638	]=	-7.58062E-03	;
    RnonCO2[	639	]=	-7.58062E-03	;
    RnonCO2[	640	]=	-7.58062E-03	;
    RnonCO2[	641	]=	-7.58062E-03	;
    RnonCO2[	642	]=	-7.58062E-03	;
    RnonCO2[	643	]=	-7.58062E-03	;
    RnonCO2[	644	]=	-7.58062E-03	;
    RnonCO2[	645	]=	-7.58062E-03	;
    RnonCO2[	646	]=	-7.58062E-03	;
    RnonCO2[	647	]=	-7.58062E-03	;
    RnonCO2[	648	]=	-7.58062E-03	;
    RnonCO2[	649	]=	-7.58062E-03	;
    RnonCO2[	650	]=	-7.58062E-03	;
    RnonCO2[	651	]=	-7.58062E-03	;
    RnonCO2[	652	]=	-7.58062E-03	;
    RnonCO2[	653	]=	-7.58062E-03	;
    RnonCO2[	654	]=	-7.58062E-03	;
    RnonCO2[	655	]=	-7.58062E-03	;
    RnonCO2[	656	]=	-7.58062E-03	;
    RnonCO2[	657	]=	-7.58062E-03	;
    RnonCO2[	658	]=	-7.58062E-03	;
    RnonCO2[	659	]=	-7.58062E-03	;
    RnonCO2[	660	]=	-7.58062E-03	;
    RnonCO2[	661	]=	-7.58062E-03	;
    RnonCO2[	662	]=	-7.58062E-03	;
    RnonCO2[	663	]=	-7.58062E-03	;
    RnonCO2[	664	]=	-7.58062E-03	;
    RnonCO2[	665	]=	-7.58062E-03	;
    RnonCO2[	666	]=	-7.58062E-03	;
    RnonCO2[	667	]=	-7.58062E-03	;
    RnonCO2[	668	]=	-7.58062E-03	;
    RnonCO2[	669	]=	-7.58062E-03	;
    RnonCO2[	670	]=	-7.58062E-03	;
    RnonCO2[	671	]=	-7.58062E-03	;
    RnonCO2[	672	]=	-7.58062E-03	;
    RnonCO2[	673	]=	-7.58062E-03	;
    RnonCO2[	674	]=	-7.58062E-03	;
    RnonCO2[	675	]=	-7.58062E-03	;
    RnonCO2[	676	]=	-7.58062E-03	;
    RnonCO2[	677	]=	-7.58062E-03	;
    RnonCO2[	678	]=	-7.58062E-03	;
    RnonCO2[	679	]=	-7.58062E-03	;
    RnonCO2[	680	]=	-7.58062E-03	;
    RnonCO2[	681	]=	-7.58062E-03	;
    RnonCO2[	682	]=	-7.58062E-03	;
    RnonCO2[	683	]=	-7.58062E-03	;
    RnonCO2[	684	]=	-7.58062E-03	;
    RnonCO2[	685	]=	-7.58062E-03	;
    RnonCO2[	686	]=	-7.58062E-03	;
    RnonCO2[	687	]=	-7.58062E-03	;
    RnonCO2[	688	]=	-7.58062E-03	;
    RnonCO2[	689	]=	-7.58062E-03	;
    RnonCO2[	690	]=	-7.58062E-03	;
    RnonCO2[	691	]=	-7.58062E-03	;
    RnonCO2[	692	]=	-7.58062E-03	;
    RnonCO2[	693	]=	-7.58062E-03	;
    RnonCO2[	694	]=	-7.58062E-03	;
    RnonCO2[	695	]=	-7.58062E-03	;
    RnonCO2[	696	]=	-7.58062E-03	;
    RnonCO2[	697	]=	-7.58062E-03	;
    RnonCO2[	698	]=	-7.58062E-03	;
    RnonCO2[	699	]=	-7.58062E-03	;
    RnonCO2[	700	]=	-7.58062E-03	;
    RnonCO2[	701	]=	-7.58062E-03	;
    RnonCO2[	702	]=	-7.58062E-03	;
    RnonCO2[	703	]=	-7.58062E-03	;
    RnonCO2[	704	]=	-7.58062E-03	;
    RnonCO2[	705	]=	-7.58062E-03	;
    RnonCO2[	706	]=	-7.58062E-03	;
    RnonCO2[	707	]=	-7.58062E-03	;
    RnonCO2[	708	]=	-7.58062E-03	;
    RnonCO2[	709	]=	-7.58062E-03	;
    RnonCO2[	710	]=	-7.58062E-03	;
    RnonCO2[	711	]=	-7.58062E-03	;
    RnonCO2[	712	]=	-7.58062E-03	;
    RnonCO2[	713	]=	-7.58062E-03	;
    RnonCO2[	714	]=	-7.58062E-03	;
    RnonCO2[	715	]=	-7.58062E-03	;
    RnonCO2[	716	]=	-7.58062E-03	;
    RnonCO2[	717	]=	-7.58062E-03	;
    RnonCO2[	718	]=	-7.58062E-03	;
    RnonCO2[	719	]=	-7.58062E-03	;
    RnonCO2[	720	]=	-7.58062E-03	;
    RnonCO2[	721	]=	-7.58062E-03	;
    RnonCO2[	722	]=	-7.58062E-03	;
    RnonCO2[	723	]=	-7.58062E-03	;
    RnonCO2[	724	]=	-7.58062E-03	;
    RnonCO2[	725	]=	-7.58062E-03	;
    RnonCO2[	726	]=	-7.58062E-03	;
    RnonCO2[	727	]=	-7.58062E-03	;
    RnonCO2[	728	]=	-7.58062E-03	;
    RnonCO2[	729	]=	-7.58062E-03	;
    RnonCO2[	730	]=	-7.58062E-03	;
    RnonCO2[	731	]=	-7.58062E-03	;
    RnonCO2[	732	]=	-7.58062E-03	;
    RnonCO2[	733	]=	-7.58062E-03	;
    RnonCO2[	734	]=	-7.58062E-03	;
    RnonCO2[	735	]=	-7.58062E-03	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp126(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07202E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.08988E+00	;
    RnonCO2[	253	]=	1.09593E+00	;
    RnonCO2[	254	]=	1.10071E+00	;
    RnonCO2[	255	]=	1.10417E+00	;
    RnonCO2[	256	]=	1.10642E+00	;
    RnonCO2[	257	]=	1.10739E+00	;
    RnonCO2[	258	]=	1.10708E+00	;
    RnonCO2[	259	]=	1.10572E+00	;
    RnonCO2[	260	]=	1.10345E+00	;
    RnonCO2[	261	]=	1.10037E+00	;
    RnonCO2[	262	]=	1.09641E+00	;
    RnonCO2[	263	]=	1.09154E+00	;
    RnonCO2[	264	]=	1.08588E+00	;
    RnonCO2[	265	]=	1.07954E+00	;
    RnonCO2[	266	]=	1.07263E+00	;
    RnonCO2[	267	]=	1.06503E+00	;
    RnonCO2[	268	]=	1.05669E+00	;
    RnonCO2[	269	]=	1.04773E+00	;
    RnonCO2[	270	]=	1.03824E+00	;
    RnonCO2[	271	]=	1.02832E+00	;
    RnonCO2[	272	]=	1.01799E+00	;
    RnonCO2[	273	]=	1.00733E+00	;
    RnonCO2[	274	]=	9.96366E-01	;
    RnonCO2[	275	]=	9.85129E-01	;
    RnonCO2[	276	]=	9.73645E-01	;
    RnonCO2[	277	]=	9.62227E-01	;
    RnonCO2[	278	]=	9.51145E-01	;
    RnonCO2[	279	]=	9.40340E-01	;
    RnonCO2[	280	]=	9.29797E-01	;
    RnonCO2[	281	]=	9.19496E-01	;
    RnonCO2[	282	]=	9.09434E-01	;
    RnonCO2[	283	]=	8.99594E-01	;
    RnonCO2[	284	]=	8.89960E-01	;
    RnonCO2[	285	]=	8.80519E-01	;
    RnonCO2[	286	]=	8.71260E-01	;
    RnonCO2[	287	]=	8.62226E-01	;
    RnonCO2[	288	]=	8.53446E-01	;
    RnonCO2[	289	]=	8.44911E-01	;
    RnonCO2[	290	]=	8.36605E-01	;
    RnonCO2[	291	]=	8.28509E-01	;
    RnonCO2[	292	]=	8.20616E-01	;
    RnonCO2[	293	]=	8.12909E-01	;
    RnonCO2[	294	]=	8.05379E-01	;
    RnonCO2[	295	]=	7.98014E-01	;
    RnonCO2[	296	]=	7.90811E-01	;
    RnonCO2[	297	]=	7.83729E-01	;
    RnonCO2[	298	]=	7.76739E-01	;
    RnonCO2[	299	]=	7.69833E-01	;
    RnonCO2[	300	]=	7.63013E-01	;
    RnonCO2[	301	]=	7.56263E-01	;
    RnonCO2[	302	]=	7.49584E-01	;
    RnonCO2[	303	]=	7.42973E-01	;
    RnonCO2[	304	]=	7.36426E-01	;
    RnonCO2[	305	]=	7.29934E-01	;
    RnonCO2[	306	]=	7.23497E-01	;
    RnonCO2[	307	]=	7.17104E-01	;
    RnonCO2[	308	]=	7.10732E-01	;
    RnonCO2[	309	]=	7.04378E-01	;
    RnonCO2[	310	]=	6.98045E-01	;
    RnonCO2[	311	]=	6.91739E-01	;
    RnonCO2[	312	]=	6.85443E-01	;
    RnonCO2[	313	]=	6.79168E-01	;
    RnonCO2[	314	]=	6.72911E-01	;
    RnonCO2[	315	]=	6.66671E-01	;
    RnonCO2[	316	]=	6.60449E-01	;
    RnonCO2[	317	]=	6.54377E-01	;
    RnonCO2[	318	]=	6.48587E-01	;
    RnonCO2[	319	]=	6.43065E-01	;
    RnonCO2[	320	]=	6.37796E-01	;
    RnonCO2[	321	]=	6.32765E-01	;
    RnonCO2[	322	]=	6.27957E-01	;
    RnonCO2[	323	]=	6.23362E-01	;
    RnonCO2[	324	]=	6.18963E-01	;
    RnonCO2[	325	]=	6.14751E-01	;
    RnonCO2[	326	]=	6.10714E-01	;
    RnonCO2[	327	]=	6.06826E-01	;
    RnonCO2[	328	]=	6.03054E-01	;
    RnonCO2[	329	]=	5.99394E-01	;
    RnonCO2[	330	]=	5.95837E-01	;
    RnonCO2[	331	]=	5.92372E-01	;
    RnonCO2[	332	]=	5.89000E-01	;
    RnonCO2[	333	]=	5.85705E-01	;
    RnonCO2[	334	]=	5.82493E-01	;
    RnonCO2[	335	]=	5.79340E-01	;
    RnonCO2[	336	]=	5.76289E-01	;
    RnonCO2[	337	]=	5.73400E-01	;
    RnonCO2[	338	]=	5.70703E-01	;
    RnonCO2[	339	]=	5.68193E-01	;
    RnonCO2[	340	]=	5.65836E-01	;
    RnonCO2[	341	]=	5.63617E-01	;
    RnonCO2[	342	]=	5.61532E-01	;
    RnonCO2[	343	]=	5.59557E-01	;
    RnonCO2[	344	]=	5.57689E-01	;
    RnonCO2[	345	]=	5.55908E-01	;
    RnonCO2[	346	]=	5.54215E-01	;
    RnonCO2[	347	]=	5.52597E-01	;
    RnonCO2[	348	]=	5.51045E-01	;
    RnonCO2[	349	]=	5.49558E-01	;
    RnonCO2[	350	]=	5.48127E-01	;
    RnonCO2[	351	]=	5.46746E-01	;
    RnonCO2[	352	]=	5.45409E-01	;
    RnonCO2[	353	]=	5.44111E-01	;
    RnonCO2[	354	]=	5.42851E-01	;
    RnonCO2[	355	]=	5.41626E-01	;
    RnonCO2[	356	]=	5.40427E-01	;
    RnonCO2[	357	]=	5.39259E-01	;
    RnonCO2[	358	]=	5.38107E-01	;
    RnonCO2[	359	]=	5.36985E-01	;
    RnonCO2[	360	]=	5.35880E-01	;
    RnonCO2[	361	]=	5.34790E-01	;
    RnonCO2[	362	]=	5.33717E-01	;
    RnonCO2[	363	]=	5.32659E-01	;
    RnonCO2[	364	]=	5.31611E-01	;
    RnonCO2[	365	]=	5.30576E-01	;
    RnonCO2[	366	]=	5.29552E-01	;
    RnonCO2[	367	]=	5.28539E-01	;
    RnonCO2[	368	]=	5.27531E-01	;
    RnonCO2[	369	]=	5.26535E-01	;
    RnonCO2[	370	]=	5.25541E-01	;
    RnonCO2[	371	]=	5.24556E-01	;
    RnonCO2[	372	]=	5.23578E-01	;
    RnonCO2[	373	]=	5.22603E-01	;
    RnonCO2[	374	]=	5.21632E-01	;
    RnonCO2[	375	]=	5.20665E-01	;
    RnonCO2[	376	]=	5.19704E-01	;
    RnonCO2[	377	]=	5.18742E-01	;
    RnonCO2[	378	]=	5.17786E-01	;
    RnonCO2[	379	]=	5.16833E-01	;
    RnonCO2[	380	]=	5.15880E-01	;
    RnonCO2[	381	]=	5.14928E-01	;
    RnonCO2[	382	]=	5.13981E-01	;
    RnonCO2[	383	]=	5.13031E-01	;
    RnonCO2[	384	]=	5.12083E-01	;
    RnonCO2[	385	]=	5.11135E-01	;
    RnonCO2[	386	]=	5.10189E-01	;
    RnonCO2[	387	]=	5.09241E-01	;
    RnonCO2[	388	]=	5.08293E-01	;
    RnonCO2[	389	]=	5.07347E-01	;
    RnonCO2[	390	]=	5.06398E-01	;
    RnonCO2[	391	]=	5.05447E-01	;
    RnonCO2[	392	]=	5.04499E-01	;
    RnonCO2[	393	]=	5.03549E-01	;
    RnonCO2[	394	]=	5.02597E-01	;
    RnonCO2[	395	]=	5.01642E-01	;
    RnonCO2[	396	]=	5.00691E-01	;
    RnonCO2[	397	]=	4.99735E-01	;
    RnonCO2[	398	]=	4.98777E-01	;
    RnonCO2[	399	]=	4.97821E-01	;
    RnonCO2[	400	]=	4.96862E-01	;
    RnonCO2[	401	]=	4.95901E-01	;
    RnonCO2[	402	]=	4.94938E-01	;
    RnonCO2[	403	]=	4.93972E-01	;
    RnonCO2[	404	]=	4.93007E-01	;
    RnonCO2[	405	]=	4.92039E-01	;
    RnonCO2[	406	]=	4.91069E-01	;
    RnonCO2[	407	]=	4.90099E-01	;
    RnonCO2[	408	]=	4.89126E-01	;
    RnonCO2[	409	]=	4.88150E-01	;
    RnonCO2[	410	]=	4.87171E-01	;
    RnonCO2[	411	]=	4.86192E-01	;
    RnonCO2[	412	]=	4.85209E-01	;
    RnonCO2[	413	]=	4.84226E-01	;
    RnonCO2[	414	]=	4.83240E-01	;
    RnonCO2[	415	]=	4.82250E-01	;
    RnonCO2[	416	]=	4.81260E-01	;
    RnonCO2[	417	]=	4.80266E-01	;
    RnonCO2[	418	]=	4.79268E-01	;
    RnonCO2[	419	]=	4.78269E-01	;
    RnonCO2[	420	]=	4.77266E-01	;
    RnonCO2[	421	]=	4.76263E-01	;
    RnonCO2[	422	]=	4.75256E-01	;
    RnonCO2[	423	]=	4.74252E-01	;
    RnonCO2[	424	]=	4.73247E-01	;
    RnonCO2[	425	]=	4.72243E-01	;
    RnonCO2[	426	]=	4.71237E-01	;
    RnonCO2[	427	]=	4.70233E-01	;
    RnonCO2[	428	]=	4.69226E-01	;
    RnonCO2[	429	]=	4.68221E-01	;
    RnonCO2[	430	]=	4.67217E-01	;
    RnonCO2[	431	]=	4.66207E-01	;
    RnonCO2[	432	]=	4.65201E-01	;
    RnonCO2[	433	]=	4.64192E-01	;
    RnonCO2[	434	]=	4.63184E-01	;
    RnonCO2[	435	]=	4.62173E-01	;
    RnonCO2[	436	]=	4.61163E-01	;
    RnonCO2[	437	]=	4.60151E-01	;
    RnonCO2[	438	]=	4.59138E-01	;
    RnonCO2[	439	]=	4.58126E-01	;
    RnonCO2[	440	]=	4.57111E-01	;
    RnonCO2[	441	]=	4.56099E-01	;
    RnonCO2[	442	]=	4.55081E-01	;
    RnonCO2[	443	]=	4.54067E-01	;
    RnonCO2[	444	]=	4.53049E-01	;
    RnonCO2[	445	]=	4.52031E-01	;
    RnonCO2[	446	]=	4.51010E-01	;
    RnonCO2[	447	]=	4.49992E-01	;
    RnonCO2[	448	]=	4.48970E-01	;
    RnonCO2[	449	]=	4.47946E-01	;
    RnonCO2[	450	]=	4.46924E-01	;
    RnonCO2[	451	]=	4.45899E-01	;
    RnonCO2[	452	]=	4.44873E-01	;
    RnonCO2[	453	]=	4.43847E-01	;
    RnonCO2[	454	]=	4.42820E-01	;
    RnonCO2[	455	]=	4.41791E-01	;
    RnonCO2[	456	]=	4.40763E-01	;
    RnonCO2[	457	]=	4.39732E-01	;
    RnonCO2[	458	]=	4.38699E-01	;
    RnonCO2[	459	]=	4.37664E-01	;
    RnonCO2[	460	]=	4.36631E-01	;
    RnonCO2[	461	]=	4.35597E-01	;
    RnonCO2[	462	]=	4.34559E-01	;
    RnonCO2[	463	]=	4.33520E-01	;
    RnonCO2[	464	]=	4.32480E-01	;
    RnonCO2[	465	]=	4.31440E-01	;
    RnonCO2[	466	]=	4.30398E-01	;
    RnonCO2[	467	]=	4.29355E-01	;
    RnonCO2[	468	]=	4.28312E-01	;
    RnonCO2[	469	]=	4.27264E-01	;
    RnonCO2[	470	]=	4.26218E-01	;
    RnonCO2[	471	]=	4.25168E-01	;
    RnonCO2[	472	]=	4.24120E-01	;
    RnonCO2[	473	]=	4.23067E-01	;
    RnonCO2[	474	]=	4.22013E-01	;
    RnonCO2[	475	]=	4.20961E-01	;
    RnonCO2[	476	]=	4.19905E-01	;
    RnonCO2[	477	]=	4.18847E-01	;
    RnonCO2[	478	]=	4.17791E-01	;
    RnonCO2[	479	]=	4.16731E-01	;
    RnonCO2[	480	]=	4.15669E-01	;
    RnonCO2[	481	]=	4.14608E-01	;
    RnonCO2[	482	]=	4.13543E-01	;
    RnonCO2[	483	]=	4.12477E-01	;
    RnonCO2[	484	]=	4.11411E-01	;
    RnonCO2[	485	]=	4.10342E-01	;
    RnonCO2[	486	]=	4.09273E-01	;
    RnonCO2[	487	]=	4.08237E-01	;
    RnonCO2[	488	]=	4.07267E-01	;
    RnonCO2[	489	]=	4.06354E-01	;
    RnonCO2[	490	]=	4.05497E-01	;
    RnonCO2[	491	]=	4.04687E-01	;
    RnonCO2[	492	]=	4.03920E-01	;
    RnonCO2[	493	]=	4.03195E-01	;
    RnonCO2[	494	]=	4.02506E-01	;
    RnonCO2[	495	]=	4.01848E-01	;
    RnonCO2[	496	]=	4.01223E-01	;
    RnonCO2[	497	]=	4.00628E-01	;
    RnonCO2[	498	]=	4.00053E-01	;
    RnonCO2[	499	]=	3.99504E-01	;
    RnonCO2[	500	]=	3.98978E-01	;
    RnonCO2[	501	]=	3.98470E-01	;
    RnonCO2[	502	]=	3.97979E-01	;
    RnonCO2[	503	]=	3.97504E-01	;
    RnonCO2[	504	]=	3.97046E-01	;
    RnonCO2[	505	]=	3.96603E-01	;
    RnonCO2[	506	]=	3.96169E-01	;
    RnonCO2[	507	]=	3.95750E-01	;
    RnonCO2[	508	]=	3.95343E-01	;
    RnonCO2[	509	]=	3.94943E-01	;
    RnonCO2[	510	]=	3.94557E-01	;
    RnonCO2[	511	]=	3.94176E-01	;
    RnonCO2[	512	]=	3.93806E-01	;
    RnonCO2[	513	]=	3.93442E-01	;
    RnonCO2[	514	]=	3.93085E-01	;
    RnonCO2[	515	]=	3.92736E-01	;
    RnonCO2[	516	]=	3.92394E-01	;
    RnonCO2[	517	]=	3.92059E-01	;
    RnonCO2[	518	]=	3.91726E-01	;
    RnonCO2[	519	]=	3.91404E-01	;
    RnonCO2[	520	]=	3.91083E-01	;
    RnonCO2[	521	]=	3.90768E-01	;
    RnonCO2[	522	]=	3.90458E-01	;
    RnonCO2[	523	]=	3.90152E-01	;
    RnonCO2[	524	]=	3.89852E-01	;
    RnonCO2[	525	]=	3.89555E-01	;
    RnonCO2[	526	]=	3.89261E-01	;
    RnonCO2[	527	]=	3.88973E-01	;
    RnonCO2[	528	]=	3.88688E-01	;
    RnonCO2[	529	]=	3.88406E-01	;
    RnonCO2[	530	]=	3.88129E-01	;
    RnonCO2[	531	]=	3.87851E-01	;
    RnonCO2[	532	]=	3.87583E-01	;
    RnonCO2[	533	]=	3.87313E-01	;
    RnonCO2[	534	]=	3.87049E-01	;
    RnonCO2[	535	]=	3.86786E-01	;
    RnonCO2[	536	]=	3.86526E-01	;
    RnonCO2[	537	]=	3.86267E-01	;
    RnonCO2[	538	]=	3.86014E-01	;
    RnonCO2[	539	]=	3.85763E-01	;
    RnonCO2[	540	]=	3.85516E-01	;
    RnonCO2[	541	]=	3.85268E-01	;
    RnonCO2[	542	]=	3.85025E-01	;
    RnonCO2[	543	]=	3.84786E-01	;
    RnonCO2[	544	]=	3.84546E-01	;
    RnonCO2[	545	]=	3.84310E-01	;
    RnonCO2[	546	]=	3.84076E-01	;
    RnonCO2[	547	]=	3.83844E-01	;
    RnonCO2[	548	]=	3.83615E-01	;
    RnonCO2[	549	]=	3.83386E-01	;
    RnonCO2[	550	]=	3.83161E-01	;
    RnonCO2[	551	]=	3.82940E-01	;
    RnonCO2[	552	]=	3.82717E-01	;
    RnonCO2[	553	]=	3.82499E-01	;
    RnonCO2[	554	]=	3.82282E-01	;
    RnonCO2[	555	]=	3.82066E-01	;
    RnonCO2[	556	]=	3.81854E-01	;
    RnonCO2[	557	]=	3.81643E-01	;
    RnonCO2[	558	]=	3.81434E-01	;
    RnonCO2[	559	]=	3.81225E-01	;
    RnonCO2[	560	]=	3.81018E-01	;
    RnonCO2[	561	]=	3.80815E-01	;
    RnonCO2[	562	]=	3.80613E-01	;
    RnonCO2[	563	]=	3.80412E-01	;
    RnonCO2[	564	]=	3.80211E-01	;
    RnonCO2[	565	]=	3.80015E-01	;
    RnonCO2[	566	]=	3.79820E-01	;
    RnonCO2[	567	]=	3.79626E-01	;
    RnonCO2[	568	]=	3.79432E-01	;
    RnonCO2[	569	]=	3.79242E-01	;
    RnonCO2[	570	]=	3.79053E-01	;
    RnonCO2[	571	]=	3.78865E-01	;
    RnonCO2[	572	]=	3.78679E-01	;
    RnonCO2[	573	]=	3.78492E-01	;
    RnonCO2[	574	]=	3.78309E-01	;
    RnonCO2[	575	]=	3.78128E-01	;
    RnonCO2[	576	]=	3.77947E-01	;
    RnonCO2[	577	]=	3.77766E-01	;
    RnonCO2[	578	]=	3.77586E-01	;
    RnonCO2[	579	]=	3.77410E-01	;
    RnonCO2[	580	]=	3.77235E-01	;
    RnonCO2[	581	]=	3.77061E-01	;
    RnonCO2[	582	]=	3.76886E-01	;
    RnonCO2[	583	]=	3.76713E-01	;
    RnonCO2[	584	]=	3.76543E-01	;
    RnonCO2[	585	]=	3.76373E-01	;
    RnonCO2[	586	]=	3.76204E-01	;
    RnonCO2[	587	]=	3.76036E-01	;
    RnonCO2[	588	]=	3.75868E-01	;
    RnonCO2[	589	]=	3.75704E-01	;
    RnonCO2[	590	]=	3.75539E-01	;
    RnonCO2[	591	]=	3.75376E-01	;
    RnonCO2[	592	]=	3.75213E-01	;
    RnonCO2[	593	]=	3.75050E-01	;
    RnonCO2[	594	]=	3.74891E-01	;
    RnonCO2[	595	]=	3.74729E-01	;
    RnonCO2[	596	]=	3.74570E-01	;
    RnonCO2[	597	]=	3.74412E-01	;
    RnonCO2[	598	]=	3.74255E-01	;
    RnonCO2[	599	]=	3.74102E-01	;
    RnonCO2[	600	]=	3.73948E-01	;
    RnonCO2[	601	]=	3.73800E-01	;
    RnonCO2[	602	]=	3.73653E-01	;
    RnonCO2[	603	]=	3.73509E-01	;
    RnonCO2[	604	]=	3.73367E-01	;
    RnonCO2[	605	]=	3.73229E-01	;
    RnonCO2[	606	]=	3.73091E-01	;
    RnonCO2[	607	]=	3.72957E-01	;
    RnonCO2[	608	]=	3.72824E-01	;
    RnonCO2[	609	]=	3.72693E-01	;
    RnonCO2[	610	]=	3.72563E-01	;
    RnonCO2[	611	]=	3.72438E-01	;
    RnonCO2[	612	]=	3.72311E-01	;
    RnonCO2[	613	]=	3.72187E-01	;
    RnonCO2[	614	]=	3.72065E-01	;
    RnonCO2[	615	]=	3.71943E-01	;
    RnonCO2[	616	]=	3.71823E-01	;
    RnonCO2[	617	]=	3.71703E-01	;
    RnonCO2[	618	]=	3.71587E-01	;
    RnonCO2[	619	]=	3.71470E-01	;
    RnonCO2[	620	]=	3.71356E-01	;
    RnonCO2[	621	]=	3.71243E-01	;
    RnonCO2[	622	]=	3.71130E-01	;
    RnonCO2[	623	]=	3.71018E-01	;
    RnonCO2[	624	]=	3.70907E-01	;
    RnonCO2[	625	]=	3.70799E-01	;
    RnonCO2[	626	]=	3.70692E-01	;
    RnonCO2[	627	]=	3.70583E-01	;
    RnonCO2[	628	]=	3.70477E-01	;
    RnonCO2[	629	]=	3.70372E-01	;
    RnonCO2[	630	]=	3.70267E-01	;
    RnonCO2[	631	]=	3.70166E-01	;
    RnonCO2[	632	]=	3.70063E-01	;
    RnonCO2[	633	]=	3.69963E-01	;
    RnonCO2[	634	]=	3.69860E-01	;
    RnonCO2[	635	]=	3.69761E-01	;
    RnonCO2[	636	]=	3.69663E-01	;
    RnonCO2[	637	]=	3.69565E-01	;
    RnonCO2[	638	]=	3.69470E-01	;
    RnonCO2[	639	]=	3.69373E-01	;
    RnonCO2[	640	]=	3.69277E-01	;
    RnonCO2[	641	]=	3.69184E-01	;
    RnonCO2[	642	]=	3.69091E-01	;
    RnonCO2[	643	]=	3.68999E-01	;
    RnonCO2[	644	]=	3.68907E-01	;
    RnonCO2[	645	]=	3.68816E-01	;
    RnonCO2[	646	]=	3.68725E-01	;
    RnonCO2[	647	]=	3.68634E-01	;
    RnonCO2[	648	]=	3.68547E-01	;
    RnonCO2[	649	]=	3.68457E-01	;
    RnonCO2[	650	]=	3.68371E-01	;
    RnonCO2[	651	]=	3.68285E-01	;
    RnonCO2[	652	]=	3.68200E-01	;
    RnonCO2[	653	]=	3.68114E-01	;
    RnonCO2[	654	]=	3.68030E-01	;
    RnonCO2[	655	]=	3.67945E-01	;
    RnonCO2[	656	]=	3.67861E-01	;
    RnonCO2[	657	]=	3.67781E-01	;
    RnonCO2[	658	]=	3.67700E-01	;
    RnonCO2[	659	]=	3.67617E-01	;
    RnonCO2[	660	]=	3.67538E-01	;
    RnonCO2[	661	]=	3.67458E-01	;
    RnonCO2[	662	]=	3.67379E-01	;
    RnonCO2[	663	]=	3.67301E-01	;
    RnonCO2[	664	]=	3.67223E-01	;
    RnonCO2[	665	]=	3.67147E-01	;
    RnonCO2[	666	]=	3.67070E-01	;
    RnonCO2[	667	]=	3.66996E-01	;
    RnonCO2[	668	]=	3.66919E-01	;
    RnonCO2[	669	]=	3.66845E-01	;
    RnonCO2[	670	]=	3.66772E-01	;
    RnonCO2[	671	]=	3.66699E-01	;
    RnonCO2[	672	]=	3.66626E-01	;
    RnonCO2[	673	]=	3.66554E-01	;
    RnonCO2[	674	]=	3.66482E-01	;
    RnonCO2[	675	]=	3.66413E-01	;
    RnonCO2[	676	]=	3.66342E-01	;
    RnonCO2[	677	]=	3.66273E-01	;
    RnonCO2[	678	]=	3.66203E-01	;
    RnonCO2[	679	]=	3.66135E-01	;
    RnonCO2[	680	]=	3.66067E-01	;
    RnonCO2[	681	]=	3.66000E-01	;
    RnonCO2[	682	]=	3.65933E-01	;
    RnonCO2[	683	]=	3.65867E-01	;
    RnonCO2[	684	]=	3.65800E-01	;
    RnonCO2[	685	]=	3.65735E-01	;
    RnonCO2[	686	]=	3.65669E-01	;
    RnonCO2[	687	]=	3.65606E-01	;
    RnonCO2[	688	]=	3.65541E-01	;
    RnonCO2[	689	]=	3.65479E-01	;
    RnonCO2[	690	]=	3.65417E-01	;
    RnonCO2[	691	]=	3.65353E-01	;
    RnonCO2[	692	]=	3.65292E-01	;
    RnonCO2[	693	]=	3.65231E-01	;
    RnonCO2[	694	]=	3.65171E-01	;
    RnonCO2[	695	]=	3.65110E-01	;
    RnonCO2[	696	]=	3.65052E-01	;
    RnonCO2[	697	]=	3.64992E-01	;
    RnonCO2[	698	]=	3.64933E-01	;
    RnonCO2[	699	]=	3.64876E-01	;
    RnonCO2[	700	]=	3.64817E-01	;
    RnonCO2[	701	]=	3.64761E-01	;
    RnonCO2[	702	]=	3.64702E-01	;
    RnonCO2[	703	]=	3.64647E-01	;
    RnonCO2[	704	]=	3.64591E-01	;
    RnonCO2[	705	]=	3.64536E-01	;
    RnonCO2[	706	]=	3.64481E-01	;
    RnonCO2[	707	]=	3.64427E-01	;
    RnonCO2[	708	]=	3.64372E-01	;
    RnonCO2[	709	]=	3.64317E-01	;
    RnonCO2[	710	]=	3.64264E-01	;
    RnonCO2[	711	]=	3.64212E-01	;
    RnonCO2[	712	]=	3.64159E-01	;
    RnonCO2[	713	]=	3.64108E-01	;
    RnonCO2[	714	]=	3.64055E-01	;
    RnonCO2[	715	]=	3.64005E-01	;
    RnonCO2[	716	]=	3.63952E-01	;
    RnonCO2[	717	]=	3.63902E-01	;
    RnonCO2[	718	]=	3.63852E-01	;
    RnonCO2[	719	]=	3.63803E-01	;
    RnonCO2[	720	]=	3.63754E-01	;
    RnonCO2[	721	]=	3.63705E-01	;
    RnonCO2[	722	]=	3.63656E-01	;
    RnonCO2[	723	]=	3.63607E-01	;
    RnonCO2[	724	]=	3.63559E-01	;
    RnonCO2[	725	]=	3.63514E-01	;
    RnonCO2[	726	]=	3.63466E-01	;
    RnonCO2[	727	]=	3.63418E-01	;
    RnonCO2[	728	]=	3.63373E-01	;
    RnonCO2[	729	]=	3.63325E-01	;
    RnonCO2[	730	]=	3.63281E-01	;
    RnonCO2[	731	]=	3.63237E-01	;
    RnonCO2[	732	]=	3.63190E-01	;
    RnonCO2[	733	]=	3.63146E-01	;
    RnonCO2[	734	]=	3.63103E-01	;
    RnonCO2[	735	]=	3.63082E-01	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp126(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.16810E+00	;
    RnonCO2[	252	]=	-1.13378E+00	;
    RnonCO2[	253	]=	-1.09869E+00	;
    RnonCO2[	254	]=	-1.06280E+00	;
    RnonCO2[	255	]=	-1.02605E+00	;
    RnonCO2[	256	]=	-9.99778E-01	;
    RnonCO2[	257	]=	-9.73058E-01	;
    RnonCO2[	258	]=	-9.45874E-01	;
    RnonCO2[	259	]=	-9.18207E-01	;
    RnonCO2[	260	]=	-8.90035E-01	;
    RnonCO2[	261	]=	-8.61334E-01	;
    RnonCO2[	262	]=	-8.32081E-01	;
    RnonCO2[	263	]=	-8.02248E-01	;
    RnonCO2[	264	]=	-7.71808E-01	;
    RnonCO2[	265	]=	-7.40730E-01	;
    RnonCO2[	266	]=	-7.22327E-01	;
    RnonCO2[	267	]=	-7.03686E-01	;
    RnonCO2[	268	]=	-6.84800E-01	;
    RnonCO2[	269	]=	-6.65661E-01	;
    RnonCO2[	270	]=	-6.46261E-01	;
    RnonCO2[	271	]=	-6.26592E-01	;
    RnonCO2[	272	]=	-6.06645E-01	;
    RnonCO2[	273	]=	-5.86411E-01	;
    RnonCO2[	274	]=	-5.65879E-01	;
    RnonCO2[	275	]=	-5.45040E-01	;
    RnonCO2[	276	]=	-5.34278E-01	;
    RnonCO2[	277	]=	-5.23434E-01	;
    RnonCO2[	278	]=	-5.12507E-01	;
    RnonCO2[	279	]=	-5.01495E-01	;
    RnonCO2[	280	]=	-4.90398E-01	;
    RnonCO2[	281	]=	-4.79214E-01	;
    RnonCO2[	282	]=	-4.67940E-01	;
    RnonCO2[	283	]=	-4.56575E-01	;
    RnonCO2[	284	]=	-4.45117E-01	;
    RnonCO2[	285	]=	-4.33566E-01	;
    RnonCO2[	286	]=	-4.26881E-01	;
    RnonCO2[	287	]=	-4.20166E-01	;
    RnonCO2[	288	]=	-4.13420E-01	;
    RnonCO2[	289	]=	-4.06643E-01	;
    RnonCO2[	290	]=	-3.99834E-01	;
    RnonCO2[	291	]=	-3.92993E-01	;
    RnonCO2[	292	]=	-3.86119E-01	;
    RnonCO2[	293	]=	-3.79213E-01	;
    RnonCO2[	294	]=	-3.72274E-01	;
    RnonCO2[	295	]=	-3.65301E-01	;
    RnonCO2[	296	]=	-3.58907E-01	;
    RnonCO2[	297	]=	-3.52485E-01	;
    RnonCO2[	298	]=	-3.46034E-01	;
    RnonCO2[	299	]=	-3.39553E-01	;
    RnonCO2[	300	]=	-3.33043E-01	;
    RnonCO2[	301	]=	-3.26503E-01	;
    RnonCO2[	302	]=	-3.19933E-01	;
    RnonCO2[	303	]=	-3.13332E-01	;
    RnonCO2[	304	]=	-3.06700E-01	;
    RnonCO2[	305	]=	-3.00037E-01	;
    RnonCO2[	306	]=	-2.93105E-01	;
    RnonCO2[	307	]=	-2.86138E-01	;
    RnonCO2[	308	]=	-2.79136E-01	;
    RnonCO2[	309	]=	-2.72098E-01	;
    RnonCO2[	310	]=	-2.65024E-01	;
    RnonCO2[	311	]=	-2.57913E-01	;
    RnonCO2[	312	]=	-2.50766E-01	;
    RnonCO2[	313	]=	-2.43580E-01	;
    RnonCO2[	314	]=	-2.36357E-01	;
    RnonCO2[	315	]=	-2.29096E-01	;
    RnonCO2[	316	]=	-2.24336E-01	;
    RnonCO2[	317	]=	-2.19559E-01	;
    RnonCO2[	318	]=	-2.14765E-01	;
    RnonCO2[	319	]=	-2.09953E-01	;
    RnonCO2[	320	]=	-2.05124E-01	;
    RnonCO2[	321	]=	-2.00277E-01	;
    RnonCO2[	322	]=	-1.95413E-01	;
    RnonCO2[	323	]=	-1.90531E-01	;
    RnonCO2[	324	]=	-1.85631E-01	;
    RnonCO2[	325	]=	-1.80712E-01	;
    RnonCO2[	326	]=	-1.76804E-01	;
    RnonCO2[	327	]=	-1.72886E-01	;
    RnonCO2[	328	]=	-1.68957E-01	;
    RnonCO2[	329	]=	-1.65017E-01	;
    RnonCO2[	330	]=	-1.61066E-01	;
    RnonCO2[	331	]=	-1.57105E-01	;
    RnonCO2[	332	]=	-1.53133E-01	;
    RnonCO2[	333	]=	-1.49150E-01	;
    RnonCO2[	334	]=	-1.45155E-01	;
    RnonCO2[	335	]=	-1.41150E-01	;
    RnonCO2[	336	]=	-1.40296E-01	;
    RnonCO2[	337	]=	-1.39440E-01	;
    RnonCO2[	338	]=	-1.38585E-01	;
    RnonCO2[	339	]=	-1.37729E-01	;
    RnonCO2[	340	]=	-1.36872E-01	;
    RnonCO2[	341	]=	-1.36015E-01	;
    RnonCO2[	342	]=	-1.35158E-01	;
    RnonCO2[	343	]=	-1.34300E-01	;
    RnonCO2[	344	]=	-1.33441E-01	;
    RnonCO2[	345	]=	-1.32583E-01	;
    RnonCO2[	346	]=	-1.31724E-01	;
    RnonCO2[	347	]=	-1.30864E-01	;
    RnonCO2[	348	]=	-1.30005E-01	;
    RnonCO2[	349	]=	-1.29144E-01	;
    RnonCO2[	350	]=	-1.28284E-01	;
    RnonCO2[	351	]=	-1.27423E-01	;
    RnonCO2[	352	]=	-1.26561E-01	;
    RnonCO2[	353	]=	-1.25699E-01	;
    RnonCO2[	354	]=	-1.24837E-01	;
    RnonCO2[	355	]=	-1.23974E-01	;
    RnonCO2[	356	]=	-1.23110E-01	;
    RnonCO2[	357	]=	-1.22246E-01	;
    RnonCO2[	358	]=	-1.21382E-01	;
    RnonCO2[	359	]=	-1.20517E-01	;
    RnonCO2[	360	]=	-1.19651E-01	;
    RnonCO2[	361	]=	-1.18786E-01	;
    RnonCO2[	362	]=	-1.17919E-01	;
    RnonCO2[	363	]=	-1.17053E-01	;
    RnonCO2[	364	]=	-1.16185E-01	;
    RnonCO2[	365	]=	-1.15318E-01	;
    RnonCO2[	366	]=	-1.14449E-01	;
    RnonCO2[	367	]=	-1.13580E-01	;
    RnonCO2[	368	]=	-1.12711E-01	;
    RnonCO2[	369	]=	-1.11841E-01	;
    RnonCO2[	370	]=	-1.10971E-01	;
    RnonCO2[	371	]=	-1.10100E-01	;
    RnonCO2[	372	]=	-1.09229E-01	;
    RnonCO2[	373	]=	-1.08357E-01	;
    RnonCO2[	374	]=	-1.07485E-01	;
    RnonCO2[	375	]=	-1.06612E-01	;
    RnonCO2[	376	]=	-1.05740E-01	;
    RnonCO2[	377	]=	-1.04866E-01	;
    RnonCO2[	378	]=	-1.03993E-01	;
    RnonCO2[	379	]=	-1.03118E-01	;
    RnonCO2[	380	]=	-1.02244E-01	;
    RnonCO2[	381	]=	-1.01369E-01	;
    RnonCO2[	382	]=	-1.00493E-01	;
    RnonCO2[	383	]=	-9.96168E-02	;
    RnonCO2[	384	]=	-9.87403E-02	;
    RnonCO2[	385	]=	-9.78632E-02	;
    RnonCO2[	386	]=	-9.69852E-02	;
    RnonCO2[	387	]=	-9.61067E-02	;
    RnonCO2[	388	]=	-9.52277E-02	;
    RnonCO2[	389	]=	-9.43483E-02	;
    RnonCO2[	390	]=	-9.34684E-02	;
    RnonCO2[	391	]=	-9.25880E-02	;
    RnonCO2[	392	]=	-9.17071E-02	;
    RnonCO2[	393	]=	-9.08257E-02	;
    RnonCO2[	394	]=	-8.99438E-02	;
    RnonCO2[	395	]=	-8.90615E-02	;
    RnonCO2[	396	]=	-8.81791E-02	;
    RnonCO2[	397	]=	-8.72962E-02	;
    RnonCO2[	398	]=	-8.64128E-02	;
    RnonCO2[	399	]=	-8.55290E-02	;
    RnonCO2[	400	]=	-8.46447E-02	;
    RnonCO2[	401	]=	-8.37598E-02	;
    RnonCO2[	402	]=	-8.28745E-02	;
    RnonCO2[	403	]=	-8.19887E-02	;
    RnonCO2[	404	]=	-8.11024E-02	;
    RnonCO2[	405	]=	-8.02156E-02	;
    RnonCO2[	406	]=	-7.93278E-02	;
    RnonCO2[	407	]=	-7.84396E-02	;
    RnonCO2[	408	]=	-7.75509E-02	;
    RnonCO2[	409	]=	-7.66616E-02	;
    RnonCO2[	410	]=	-7.57719E-02	;
    RnonCO2[	411	]=	-7.48817E-02	;
    RnonCO2[	412	]=	-7.39909E-02	;
    RnonCO2[	413	]=	-7.30997E-02	;
    RnonCO2[	414	]=	-7.22080E-02	;
    RnonCO2[	415	]=	-7.13158E-02	;
    RnonCO2[	416	]=	-7.04235E-02	;
    RnonCO2[	417	]=	-6.95307E-02	;
    RnonCO2[	418	]=	-6.86375E-02	;
    RnonCO2[	419	]=	-6.77437E-02	;
    RnonCO2[	420	]=	-6.68494E-02	;
    RnonCO2[	421	]=	-6.59546E-02	;
    RnonCO2[	422	]=	-6.50593E-02	;
    RnonCO2[	423	]=	-6.41636E-02	;
    RnonCO2[	424	]=	-6.32673E-02	;
    RnonCO2[	425	]=	-6.23705E-02	;
    RnonCO2[	426	]=	-6.14731E-02	;
    RnonCO2[	427	]=	-6.05751E-02	;
    RnonCO2[	428	]=	-5.96767E-02	;
    RnonCO2[	429	]=	-5.87778E-02	;
    RnonCO2[	430	]=	-5.78783E-02	;
    RnonCO2[	431	]=	-5.69784E-02	;
    RnonCO2[	432	]=	-5.60779E-02	;
    RnonCO2[	433	]=	-5.51769E-02	;
    RnonCO2[	434	]=	-5.42755E-02	;
    RnonCO2[	435	]=	-5.33734E-02	;
    RnonCO2[	436	]=	-5.24707E-02	;
    RnonCO2[	437	]=	-5.15673E-02	;
    RnonCO2[	438	]=	-5.06635E-02	;
    RnonCO2[	439	]=	-4.97592E-02	;
    RnonCO2[	440	]=	-4.88543E-02	;
    RnonCO2[	441	]=	-4.79489E-02	;
    RnonCO2[	442	]=	-4.70430E-02	;
    RnonCO2[	443	]=	-4.61366E-02	;
    RnonCO2[	444	]=	-4.52297E-02	;
    RnonCO2[	445	]=	-4.43222E-02	;
    RnonCO2[	446	]=	-4.34146E-02	;
    RnonCO2[	447	]=	-4.25064E-02	;
    RnonCO2[	448	]=	-4.15978E-02	;
    RnonCO2[	449	]=	-4.06886E-02	;
    RnonCO2[	450	]=	-3.97789E-02	;
    RnonCO2[	451	]=	-3.88686E-02	;
    RnonCO2[	452	]=	-3.79579E-02	;
    RnonCO2[	453	]=	-3.70466E-02	;
    RnonCO2[	454	]=	-3.61348E-02	;
    RnonCO2[	455	]=	-3.52224E-02	;
    RnonCO2[	456	]=	-3.43091E-02	;
    RnonCO2[	457	]=	-3.33952E-02	;
    RnonCO2[	458	]=	-3.24808E-02	;
    RnonCO2[	459	]=	-3.15659E-02	;
    RnonCO2[	460	]=	-3.06504E-02	;
    RnonCO2[	461	]=	-2.97344E-02	;
    RnonCO2[	462	]=	-2.88179E-02	;
    RnonCO2[	463	]=	-2.79009E-02	;
    RnonCO2[	464	]=	-2.69833E-02	;
    RnonCO2[	465	]=	-2.60651E-02	;
    RnonCO2[	466	]=	-2.51469E-02	;
    RnonCO2[	467	]=	-2.42282E-02	;
    RnonCO2[	468	]=	-2.33089E-02	;
    RnonCO2[	469	]=	-2.23891E-02	;
    RnonCO2[	470	]=	-2.14687E-02	;
    RnonCO2[	471	]=	-2.05478E-02	;
    RnonCO2[	472	]=	-1.96263E-02	;
    RnonCO2[	473	]=	-1.87043E-02	;
    RnonCO2[	474	]=	-1.77818E-02	;
    RnonCO2[	475	]=	-1.68587E-02	;
    RnonCO2[	476	]=	-1.59350E-02	;
    RnonCO2[	477	]=	-1.50107E-02	;
    RnonCO2[	478	]=	-1.40859E-02	;
    RnonCO2[	479	]=	-1.31605E-02	;
    RnonCO2[	480	]=	-1.22346E-02	;
    RnonCO2[	481	]=	-1.13082E-02	;
    RnonCO2[	482	]=	-1.03811E-02	;
    RnonCO2[	483	]=	-9.45358E-03	;
    RnonCO2[	484	]=	-8.52547E-03	;
    RnonCO2[	485	]=	-7.59680E-03	;
    RnonCO2[	486	]=	-7.59680E-03	;
    RnonCO2[	487	]=	-7.59680E-03	;
    RnonCO2[	488	]=	-7.59680E-03	;
    RnonCO2[	489	]=	-7.59680E-03	;
    RnonCO2[	490	]=	-7.59680E-03	;
    RnonCO2[	491	]=	-7.59680E-03	;
    RnonCO2[	492	]=	-7.59680E-03	;
    RnonCO2[	493	]=	-7.59680E-03	;
    RnonCO2[	494	]=	-7.59680E-03	;
    RnonCO2[	495	]=	-7.59680E-03	;
    RnonCO2[	496	]=	-7.59680E-03	;
    RnonCO2[	497	]=	-7.59680E-03	;
    RnonCO2[	498	]=	-7.59680E-03	;
    RnonCO2[	499	]=	-7.59680E-03	;
    RnonCO2[	500	]=	-7.59680E-03	;
    RnonCO2[	501	]=	-7.59680E-03	;
    RnonCO2[	502	]=	-7.59680E-03	;
    RnonCO2[	503	]=	-7.59680E-03	;
    RnonCO2[	504	]=	-7.59680E-03	;
    RnonCO2[	505	]=	-7.59680E-03	;
    RnonCO2[	506	]=	-7.59680E-03	;
    RnonCO2[	507	]=	-7.59680E-03	;
    RnonCO2[	508	]=	-7.59680E-03	;
    RnonCO2[	509	]=	-7.59680E-03	;
    RnonCO2[	510	]=	-7.59680E-03	;
    RnonCO2[	511	]=	-7.59680E-03	;
    RnonCO2[	512	]=	-7.59680E-03	;
    RnonCO2[	513	]=	-7.59680E-03	;
    RnonCO2[	514	]=	-7.59680E-03	;
    RnonCO2[	515	]=	-7.59680E-03	;
    RnonCO2[	516	]=	-7.59680E-03	;
    RnonCO2[	517	]=	-7.59680E-03	;
    RnonCO2[	518	]=	-7.59680E-03	;
    RnonCO2[	519	]=	-7.59680E-03	;
    RnonCO2[	520	]=	-7.59680E-03	;
    RnonCO2[	521	]=	-7.59680E-03	;
    RnonCO2[	522	]=	-7.59680E-03	;
    RnonCO2[	523	]=	-7.59680E-03	;
    RnonCO2[	524	]=	-7.59680E-03	;
    RnonCO2[	525	]=	-7.59680E-03	;
    RnonCO2[	526	]=	-7.59680E-03	;
    RnonCO2[	527	]=	-7.59680E-03	;
    RnonCO2[	528	]=	-7.59680E-03	;
    RnonCO2[	529	]=	-7.59680E-03	;
    RnonCO2[	530	]=	-7.59680E-03	;
    RnonCO2[	531	]=	-7.59680E-03	;
    RnonCO2[	532	]=	-7.59680E-03	;
    RnonCO2[	533	]=	-7.59680E-03	;
    RnonCO2[	534	]=	-7.59680E-03	;
    RnonCO2[	535	]=	-7.59680E-03	;
    RnonCO2[	536	]=	-7.59680E-03	;
    RnonCO2[	537	]=	-7.59680E-03	;
    RnonCO2[	538	]=	-7.59680E-03	;
    RnonCO2[	539	]=	-7.59680E-03	;
    RnonCO2[	540	]=	-7.59680E-03	;
    RnonCO2[	541	]=	-7.59680E-03	;
    RnonCO2[	542	]=	-7.59680E-03	;
    RnonCO2[	543	]=	-7.59680E-03	;
    RnonCO2[	544	]=	-7.59680E-03	;
    RnonCO2[	545	]=	-7.59680E-03	;
    RnonCO2[	546	]=	-7.59680E-03	;
    RnonCO2[	547	]=	-7.59680E-03	;
    RnonCO2[	548	]=	-7.59680E-03	;
    RnonCO2[	549	]=	-7.59680E-03	;
    RnonCO2[	550	]=	-7.59680E-03	;
    RnonCO2[	551	]=	-7.59680E-03	;
    RnonCO2[	552	]=	-7.59680E-03	;
    RnonCO2[	553	]=	-7.59680E-03	;
    RnonCO2[	554	]=	-7.59680E-03	;
    RnonCO2[	555	]=	-7.59680E-03	;
    RnonCO2[	556	]=	-7.59680E-03	;
    RnonCO2[	557	]=	-7.59680E-03	;
    RnonCO2[	558	]=	-7.59680E-03	;
    RnonCO2[	559	]=	-7.59680E-03	;
    RnonCO2[	560	]=	-7.59680E-03	;
    RnonCO2[	561	]=	-7.59680E-03	;
    RnonCO2[	562	]=	-7.59680E-03	;
    RnonCO2[	563	]=	-7.59680E-03	;
    RnonCO2[	564	]=	-7.59680E-03	;
    RnonCO2[	565	]=	-7.59680E-03	;
    RnonCO2[	566	]=	-7.59680E-03	;
    RnonCO2[	567	]=	-7.59680E-03	;
    RnonCO2[	568	]=	-7.59680E-03	;
    RnonCO2[	569	]=	-7.59680E-03	;
    RnonCO2[	570	]=	-7.59680E-03	;
    RnonCO2[	571	]=	-7.59680E-03	;
    RnonCO2[	572	]=	-7.59680E-03	;
    RnonCO2[	573	]=	-7.59680E-03	;
    RnonCO2[	574	]=	-7.59680E-03	;
    RnonCO2[	575	]=	-7.59680E-03	;
    RnonCO2[	576	]=	-7.59680E-03	;
    RnonCO2[	577	]=	-7.59680E-03	;
    RnonCO2[	578	]=	-7.59680E-03	;
    RnonCO2[	579	]=	-7.59680E-03	;
    RnonCO2[	580	]=	-7.59680E-03	;
    RnonCO2[	581	]=	-7.59680E-03	;
    RnonCO2[	582	]=	-7.59680E-03	;
    RnonCO2[	583	]=	-7.59680E-03	;
    RnonCO2[	584	]=	-7.59680E-03	;
    RnonCO2[	585	]=	-7.59680E-03	;
    RnonCO2[	586	]=	-7.59680E-03	;
    RnonCO2[	587	]=	-7.59680E-03	;
    RnonCO2[	588	]=	-7.59680E-03	;
    RnonCO2[	589	]=	-7.59680E-03	;
    RnonCO2[	590	]=	-7.59680E-03	;
    RnonCO2[	591	]=	-7.59680E-03	;
    RnonCO2[	592	]=	-7.59680E-03	;
    RnonCO2[	593	]=	-7.59680E-03	;
    RnonCO2[	594	]=	-7.59680E-03	;
    RnonCO2[	595	]=	-7.59680E-03	;
    RnonCO2[	596	]=	-7.59680E-03	;
    RnonCO2[	597	]=	-7.59680E-03	;
    RnonCO2[	598	]=	-7.59680E-03	;
    RnonCO2[	599	]=	-7.59680E-03	;
    RnonCO2[	600	]=	-7.59680E-03	;
    RnonCO2[	601	]=	-7.59680E-03	;
    RnonCO2[	602	]=	-7.59680E-03	;
    RnonCO2[	603	]=	-7.59680E-03	;
    RnonCO2[	604	]=	-7.59680E-03	;
    RnonCO2[	605	]=	-7.59680E-03	;
    RnonCO2[	606	]=	-7.59680E-03	;
    RnonCO2[	607	]=	-7.59680E-03	;
    RnonCO2[	608	]=	-7.59680E-03	;
    RnonCO2[	609	]=	-7.59680E-03	;
    RnonCO2[	610	]=	-7.59680E-03	;
    RnonCO2[	611	]=	-7.59680E-03	;
    RnonCO2[	612	]=	-7.59680E-03	;
    RnonCO2[	613	]=	-7.59680E-03	;
    RnonCO2[	614	]=	-7.59680E-03	;
    RnonCO2[	615	]=	-7.59680E-03	;
    RnonCO2[	616	]=	-7.59680E-03	;
    RnonCO2[	617	]=	-7.59680E-03	;
    RnonCO2[	618	]=	-7.59680E-03	;
    RnonCO2[	619	]=	-7.59680E-03	;
    RnonCO2[	620	]=	-7.59680E-03	;
    RnonCO2[	621	]=	-7.59680E-03	;
    RnonCO2[	622	]=	-7.59680E-03	;
    RnonCO2[	623	]=	-7.59680E-03	;
    RnonCO2[	624	]=	-7.59680E-03	;
    RnonCO2[	625	]=	-7.59680E-03	;
    RnonCO2[	626	]=	-7.59680E-03	;
    RnonCO2[	627	]=	-7.59680E-03	;
    RnonCO2[	628	]=	-7.59680E-03	;
    RnonCO2[	629	]=	-7.59680E-03	;
    RnonCO2[	630	]=	-7.59680E-03	;
    RnonCO2[	631	]=	-7.59680E-03	;
    RnonCO2[	632	]=	-7.59680E-03	;
    RnonCO2[	633	]=	-7.59680E-03	;
    RnonCO2[	634	]=	-7.59680E-03	;
    RnonCO2[	635	]=	-7.59680E-03	;
    RnonCO2[	636	]=	-7.59680E-03	;
    RnonCO2[	637	]=	-7.59680E-03	;
    RnonCO2[	638	]=	-7.59680E-03	;
    RnonCO2[	639	]=	-7.59680E-03	;
    RnonCO2[	640	]=	-7.59680E-03	;
    RnonCO2[	641	]=	-7.59680E-03	;
    RnonCO2[	642	]=	-7.59680E-03	;
    RnonCO2[	643	]=	-7.59680E-03	;
    RnonCO2[	644	]=	-7.59680E-03	;
    RnonCO2[	645	]=	-7.59680E-03	;
    RnonCO2[	646	]=	-7.59680E-03	;
    RnonCO2[	647	]=	-7.59680E-03	;
    RnonCO2[	648	]=	-7.59680E-03	;
    RnonCO2[	649	]=	-7.59680E-03	;
    RnonCO2[	650	]=	-7.59680E-03	;
    RnonCO2[	651	]=	-7.59680E-03	;
    RnonCO2[	652	]=	-7.59680E-03	;
    RnonCO2[	653	]=	-7.59680E-03	;
    RnonCO2[	654	]=	-7.59680E-03	;
    RnonCO2[	655	]=	-7.59680E-03	;
    RnonCO2[	656	]=	-7.59680E-03	;
    RnonCO2[	657	]=	-7.59680E-03	;
    RnonCO2[	658	]=	-7.59680E-03	;
    RnonCO2[	659	]=	-7.59680E-03	;
    RnonCO2[	660	]=	-7.59680E-03	;
    RnonCO2[	661	]=	-7.59680E-03	;
    RnonCO2[	662	]=	-7.59680E-03	;
    RnonCO2[	663	]=	-7.59680E-03	;
    RnonCO2[	664	]=	-7.59680E-03	;
    RnonCO2[	665	]=	-7.59680E-03	;
    RnonCO2[	666	]=	-7.59680E-03	;
    RnonCO2[	667	]=	-7.59680E-03	;
    RnonCO2[	668	]=	-7.59680E-03	;
    RnonCO2[	669	]=	-7.59680E-03	;
    RnonCO2[	670	]=	-7.59680E-03	;
    RnonCO2[	671	]=	-7.59680E-03	;
    RnonCO2[	672	]=	-7.59680E-03	;
    RnonCO2[	673	]=	-7.59680E-03	;
    RnonCO2[	674	]=	-7.59680E-03	;
    RnonCO2[	675	]=	-7.59680E-03	;
    RnonCO2[	676	]=	-7.59680E-03	;
    RnonCO2[	677	]=	-7.59680E-03	;
    RnonCO2[	678	]=	-7.59680E-03	;
    RnonCO2[	679	]=	-7.59680E-03	;
    RnonCO2[	680	]=	-7.59680E-03	;
    RnonCO2[	681	]=	-7.59680E-03	;
    RnonCO2[	682	]=	-7.59680E-03	;
    RnonCO2[	683	]=	-7.59680E-03	;
    RnonCO2[	684	]=	-7.59680E-03	;
    RnonCO2[	685	]=	-7.59680E-03	;
    RnonCO2[	686	]=	-7.59680E-03	;
    RnonCO2[	687	]=	-7.59680E-03	;
    RnonCO2[	688	]=	-7.59680E-03	;
    RnonCO2[	689	]=	-7.59680E-03	;
    RnonCO2[	690	]=	-7.59680E-03	;
    RnonCO2[	691	]=	-7.59680E-03	;
    RnonCO2[	692	]=	-7.59680E-03	;
    RnonCO2[	693	]=	-7.59680E-03	;
    RnonCO2[	694	]=	-7.59680E-03	;
    RnonCO2[	695	]=	-7.59680E-03	;
    RnonCO2[	696	]=	-7.59680E-03	;
    RnonCO2[	697	]=	-7.59680E-03	;
    RnonCO2[	698	]=	-7.59680E-03	;
    RnonCO2[	699	]=	-7.59680E-03	;
    RnonCO2[	700	]=	-7.59680E-03	;
    RnonCO2[	701	]=	-7.59680E-03	;
    RnonCO2[	702	]=	-7.59680E-03	;
    RnonCO2[	703	]=	-7.59680E-03	;
    RnonCO2[	704	]=	-7.59680E-03	;
    RnonCO2[	705	]=	-7.59680E-03	;
    RnonCO2[	706	]=	-7.59680E-03	;
    RnonCO2[	707	]=	-7.59680E-03	;
    RnonCO2[	708	]=	-7.59680E-03	;
    RnonCO2[	709	]=	-7.59680E-03	;
    RnonCO2[	710	]=	-7.59680E-03	;
    RnonCO2[	711	]=	-7.59680E-03	;
    RnonCO2[	712	]=	-7.59680E-03	;
    RnonCO2[	713	]=	-7.59680E-03	;
    RnonCO2[	714	]=	-7.59680E-03	;
    RnonCO2[	715	]=	-7.59680E-03	;
    RnonCO2[	716	]=	-7.59680E-03	;
    RnonCO2[	717	]=	-7.59680E-03	;
    RnonCO2[	718	]=	-7.59680E-03	;
    RnonCO2[	719	]=	-7.59680E-03	;
    RnonCO2[	720	]=	-7.59680E-03	;
    RnonCO2[	721	]=	-7.59680E-03	;
    RnonCO2[	722	]=	-7.59680E-03	;
    RnonCO2[	723	]=	-7.59680E-03	;
    RnonCO2[	724	]=	-7.59680E-03	;
    RnonCO2[	725	]=	-7.59680E-03	;
    RnonCO2[	726	]=	-7.59680E-03	;
    RnonCO2[	727	]=	-7.59680E-03	;
    RnonCO2[	728	]=	-7.59680E-03	;
    RnonCO2[	729	]=	-7.59680E-03	;
    RnonCO2[	730	]=	-7.59680E-03	;
    RnonCO2[	731	]=	-7.59680E-03	;
    RnonCO2[	732	]=	-7.59680E-03	;
    RnonCO2[	733	]=	-7.59680E-03	;
    RnonCO2[	734	]=	-7.59680E-03	;
    RnonCO2[	735	]=	-7.59680E-03	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp245(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07202E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09052E+00	;
    RnonCO2[	253	]=	1.09847E+00	;
    RnonCO2[	254	]=	1.10631E+00	;
    RnonCO2[	255	]=	1.11391E+00	;
    RnonCO2[	256	]=	1.12134E+00	;
    RnonCO2[	257	]=	1.12832E+00	;
    RnonCO2[	258	]=	1.13464E+00	;
    RnonCO2[	259	]=	1.14047E+00	;
    RnonCO2[	260	]=	1.14591E+00	;
    RnonCO2[	261	]=	1.15104E+00	;
    RnonCO2[	262	]=	1.15576E+00	;
    RnonCO2[	263	]=	1.16001E+00	;
    RnonCO2[	264	]=	1.16391E+00	;
    RnonCO2[	265	]=	1.16755E+00	;
    RnonCO2[	266	]=	1.17100E+00	;
    RnonCO2[	267	]=	1.17399E+00	;
    RnonCO2[	268	]=	1.17630E+00	;
    RnonCO2[	269	]=	1.17804E+00	;
    RnonCO2[	270	]=	1.17932E+00	;
    RnonCO2[	271	]=	1.18023E+00	;
    RnonCO2[	272	]=	1.18081E+00	;
    RnonCO2[	273	]=	1.18113E+00	;
    RnonCO2[	274	]=	1.18122E+00	;
    RnonCO2[	275	]=	1.18112E+00	;
    RnonCO2[	276	]=	1.18085E+00	;
    RnonCO2[	277	]=	1.18035E+00	;
    RnonCO2[	278	]=	1.17953E+00	;
    RnonCO2[	279	]=	1.17843E+00	;
    RnonCO2[	280	]=	1.17707E+00	;
    RnonCO2[	281	]=	1.17547E+00	;
    RnonCO2[	282	]=	1.17365E+00	;
    RnonCO2[	283	]=	1.17163E+00	;
    RnonCO2[	284	]=	1.16942E+00	;
    RnonCO2[	285	]=	1.16703E+00	;
    RnonCO2[	286	]=	1.16448E+00	;
    RnonCO2[	287	]=	1.16180E+00	;
    RnonCO2[	288	]=	1.15900E+00	;
    RnonCO2[	289	]=	1.15609E+00	;
    RnonCO2[	290	]=	1.15309E+00	;
    RnonCO2[	291	]=	1.14999E+00	;
    RnonCO2[	292	]=	1.14681E+00	;
    RnonCO2[	293	]=	1.14354E+00	;
    RnonCO2[	294	]=	1.14019E+00	;
    RnonCO2[	295	]=	1.13677E+00	;
    RnonCO2[	296	]=	1.13328E+00	;
    RnonCO2[	297	]=	1.12982E+00	;
    RnonCO2[	298	]=	1.12648E+00	;
    RnonCO2[	299	]=	1.12324E+00	;
    RnonCO2[	300	]=	1.12009E+00	;
    RnonCO2[	301	]=	1.11704E+00	;
    RnonCO2[	302	]=	1.11406E+00	;
    RnonCO2[	303	]=	1.11116E+00	;
    RnonCO2[	304	]=	1.10833E+00	;
    RnonCO2[	305	]=	1.10556E+00	;
    RnonCO2[	306	]=	1.10284E+00	;
    RnonCO2[	307	]=	1.10013E+00	;
    RnonCO2[	308	]=	1.09739E+00	;
    RnonCO2[	309	]=	1.09461E+00	;
    RnonCO2[	310	]=	1.09179E+00	;
    RnonCO2[	311	]=	1.08894E+00	;
    RnonCO2[	312	]=	1.08606E+00	;
    RnonCO2[	313	]=	1.08314E+00	;
    RnonCO2[	314	]=	1.08020E+00	;
    RnonCO2[	315	]=	1.07722E+00	;
    RnonCO2[	316	]=	1.07422E+00	;
    RnonCO2[	317	]=	1.07127E+00	;
    RnonCO2[	318	]=	1.06846E+00	;
    RnonCO2[	319	]=	1.06577E+00	;
    RnonCO2[	320	]=	1.06320E+00	;
    RnonCO2[	321	]=	1.06072E+00	;
    RnonCO2[	322	]=	1.05835E+00	;
    RnonCO2[	323	]=	1.05605E+00	;
    RnonCO2[	324	]=	1.05384E+00	;
    RnonCO2[	325	]=	1.05170E+00	;
    RnonCO2[	326	]=	1.04962E+00	;
    RnonCO2[	327	]=	1.04760E+00	;
    RnonCO2[	328	]=	1.04560E+00	;
    RnonCO2[	329	]=	1.04362E+00	;
    RnonCO2[	330	]=	1.04166E+00	;
    RnonCO2[	331	]=	1.03972E+00	;
    RnonCO2[	332	]=	1.03778E+00	;
    RnonCO2[	333	]=	1.03587E+00	;
    RnonCO2[	334	]=	1.03396E+00	;
    RnonCO2[	335	]=	1.03205E+00	;
    RnonCO2[	336	]=	1.03016E+00	;
    RnonCO2[	337	]=	1.02823E+00	;
    RnonCO2[	338	]=	1.02622E+00	;
    RnonCO2[	339	]=	1.02413E+00	;
    RnonCO2[	340	]=	1.02197E+00	;
    RnonCO2[	341	]=	1.01974E+00	;
    RnonCO2[	342	]=	1.01745E+00	;
    RnonCO2[	343	]=	1.01510E+00	;
    RnonCO2[	344	]=	1.01270E+00	;
    RnonCO2[	345	]=	1.01024E+00	;
    RnonCO2[	346	]=	1.00773E+00	;
    RnonCO2[	347	]=	1.00517E+00	;
    RnonCO2[	348	]=	1.00257E+00	;
    RnonCO2[	349	]=	9.99938E-01	;
    RnonCO2[	350	]=	9.97262E-01	;
    RnonCO2[	351	]=	9.94546E-01	;
    RnonCO2[	352	]=	9.91797E-01	;
    RnonCO2[	353	]=	9.89016E-01	;
    RnonCO2[	354	]=	9.86206E-01	;
    RnonCO2[	355	]=	9.83363E-01	;
    RnonCO2[	356	]=	9.80496E-01	;
    RnonCO2[	357	]=	9.77605E-01	;
    RnonCO2[	358	]=	9.74685E-01	;
    RnonCO2[	359	]=	9.71747E-01	;
    RnonCO2[	360	]=	9.68784E-01	;
    RnonCO2[	361	]=	9.65798E-01	;
    RnonCO2[	362	]=	9.62797E-01	;
    RnonCO2[	363	]=	9.59773E-01	;
    RnonCO2[	364	]=	9.56734E-01	;
    RnonCO2[	365	]=	9.53676E-01	;
    RnonCO2[	366	]=	9.50604E-01	;
    RnonCO2[	367	]=	9.47518E-01	;
    RnonCO2[	368	]=	9.44416E-01	;
    RnonCO2[	369	]=	9.41302E-01	;
    RnonCO2[	370	]=	9.38170E-01	;
    RnonCO2[	371	]=	9.35034E-01	;
    RnonCO2[	372	]=	9.31877E-01	;
    RnonCO2[	373	]=	9.28716E-01	;
    RnonCO2[	374	]=	9.25537E-01	;
    RnonCO2[	375	]=	9.22353E-01	;
    RnonCO2[	376	]=	9.19155E-01	;
    RnonCO2[	377	]=	9.15950E-01	;
    RnonCO2[	378	]=	9.12736E-01	;
    RnonCO2[	379	]=	9.09512E-01	;
    RnonCO2[	380	]=	9.06280E-01	;
    RnonCO2[	381	]=	9.03042E-01	;
    RnonCO2[	382	]=	8.99794E-01	;
    RnonCO2[	383	]=	8.96537E-01	;
    RnonCO2[	384	]=	8.93276E-01	;
    RnonCO2[	385	]=	8.90010E-01	;
    RnonCO2[	386	]=	8.86731E-01	;
    RnonCO2[	387	]=	8.83447E-01	;
    RnonCO2[	388	]=	8.80163E-01	;
    RnonCO2[	389	]=	8.76869E-01	;
    RnonCO2[	390	]=	8.73569E-01	;
    RnonCO2[	391	]=	8.70268E-01	;
    RnonCO2[	392	]=	8.66955E-01	;
    RnonCO2[	393	]=	8.63641E-01	;
    RnonCO2[	394	]=	8.60324E-01	;
    RnonCO2[	395	]=	8.56998E-01	;
    RnonCO2[	396	]=	8.53670E-01	;
    RnonCO2[	397	]=	8.50340E-01	;
    RnonCO2[	398	]=	8.47003E-01	;
    RnonCO2[	399	]=	8.43663E-01	;
    RnonCO2[	400	]=	8.40323E-01	;
    RnonCO2[	401	]=	8.36978E-01	;
    RnonCO2[	402	]=	8.33630E-01	;
    RnonCO2[	403	]=	8.30275E-01	;
    RnonCO2[	404	]=	8.26923E-01	;
    RnonCO2[	405	]=	8.23560E-01	;
    RnonCO2[	406	]=	8.20198E-01	;
    RnonCO2[	407	]=	8.16837E-01	;
    RnonCO2[	408	]=	8.13467E-01	;
    RnonCO2[	409	]=	8.10098E-01	;
    RnonCO2[	410	]=	8.06722E-01	;
    RnonCO2[	411	]=	8.03350E-01	;
    RnonCO2[	412	]=	7.99969E-01	;
    RnonCO2[	413	]=	7.96587E-01	;
    RnonCO2[	414	]=	7.93208E-01	;
    RnonCO2[	415	]=	7.89818E-01	;
    RnonCO2[	416	]=	7.86432E-01	;
    RnonCO2[	417	]=	7.83040E-01	;
    RnonCO2[	418	]=	7.79651E-01	;
    RnonCO2[	419	]=	7.76255E-01	;
    RnonCO2[	420	]=	7.72859E-01	;
    RnonCO2[	421	]=	7.69456E-01	;
    RnonCO2[	422	]=	7.66057E-01	;
    RnonCO2[	423	]=	7.62651E-01	;
    RnonCO2[	424	]=	7.59245E-01	;
    RnonCO2[	425	]=	7.55832E-01	;
    RnonCO2[	426	]=	7.52423E-01	;
    RnonCO2[	427	]=	7.49009E-01	;
    RnonCO2[	428	]=	7.45592E-01	;
    RnonCO2[	429	]=	7.42176E-01	;
    RnonCO2[	430	]=	7.38757E-01	;
    RnonCO2[	431	]=	7.35333E-01	;
    RnonCO2[	432	]=	7.31906E-01	;
    RnonCO2[	433	]=	7.28475E-01	;
    RnonCO2[	434	]=	7.25047E-01	;
    RnonCO2[	435	]=	7.21616E-01	;
    RnonCO2[	436	]=	7.18182E-01	;
    RnonCO2[	437	]=	7.14743E-01	;
    RnonCO2[	438	]=	7.11304E-01	;
    RnonCO2[	439	]=	7.07862E-01	;
    RnonCO2[	440	]=	7.04419E-01	;
    RnonCO2[	441	]=	7.00973E-01	;
    RnonCO2[	442	]=	6.97526E-01	;
    RnonCO2[	443	]=	6.94075E-01	;
    RnonCO2[	444	]=	6.90620E-01	;
    RnonCO2[	445	]=	6.87161E-01	;
    RnonCO2[	446	]=	6.83705E-01	;
    RnonCO2[	447	]=	6.80245E-01	;
    RnonCO2[	448	]=	6.76781E-01	;
    RnonCO2[	449	]=	6.73313E-01	;
    RnonCO2[	450	]=	6.69845E-01	;
    RnonCO2[	451	]=	6.66376E-01	;
    RnonCO2[	452	]=	6.62902E-01	;
    RnonCO2[	453	]=	6.59425E-01	;
    RnonCO2[	454	]=	6.55942E-01	;
    RnonCO2[	455	]=	6.52464E-01	;
    RnonCO2[	456	]=	6.48980E-01	;
    RnonCO2[	457	]=	6.45492E-01	;
    RnonCO2[	458	]=	6.42003E-01	;
    RnonCO2[	459	]=	6.38508E-01	;
    RnonCO2[	460	]=	6.35015E-01	;
    RnonCO2[	461	]=	6.31516E-01	;
    RnonCO2[	462	]=	6.28016E-01	;
    RnonCO2[	463	]=	6.24511E-01	;
    RnonCO2[	464	]=	6.21004E-01	;
    RnonCO2[	465	]=	6.17498E-01	;
    RnonCO2[	466	]=	6.13981E-01	;
    RnonCO2[	467	]=	6.10465E-01	;
    RnonCO2[	468	]=	6.06947E-01	;
    RnonCO2[	469	]=	6.03428E-01	;
    RnonCO2[	470	]=	5.99903E-01	;
    RnonCO2[	471	]=	5.96375E-01	;
    RnonCO2[	472	]=	5.92848E-01	;
    RnonCO2[	473	]=	5.89312E-01	;
    RnonCO2[	474	]=	5.85775E-01	;
    RnonCO2[	475	]=	5.82235E-01	;
    RnonCO2[	476	]=	5.78692E-01	;
    RnonCO2[	477	]=	5.75144E-01	;
    RnonCO2[	478	]=	5.71594E-01	;
    RnonCO2[	479	]=	5.68041E-01	;
    RnonCO2[	480	]=	5.64485E-01	;
    RnonCO2[	481	]=	5.60927E-01	;
    RnonCO2[	482	]=	5.57406E-01	;
    RnonCO2[	483	]=	5.53937E-01	;
    RnonCO2[	484	]=	5.50530E-01	;
    RnonCO2[	485	]=	5.47164E-01	;
    RnonCO2[	486	]=	5.43842E-01	;
    RnonCO2[	487	]=	5.40663E-01	;
    RnonCO2[	488	]=	5.37729E-01	;
    RnonCO2[	489	]=	5.35004E-01	;
    RnonCO2[	490	]=	5.32478E-01	;
    RnonCO2[	491	]=	5.30125E-01	;
    RnonCO2[	492	]=	5.27931E-01	;
    RnonCO2[	493	]=	5.25877E-01	;
    RnonCO2[	494	]=	5.23960E-01	;
    RnonCO2[	495	]=	5.22154E-01	;
    RnonCO2[	496	]=	5.20457E-01	;
    RnonCO2[	497	]=	5.18856E-01	;
    RnonCO2[	498	]=	5.17347E-01	;
    RnonCO2[	499	]=	5.15914E-01	;
    RnonCO2[	500	]=	5.14560E-01	;
    RnonCO2[	501	]=	5.13271E-01	;
    RnonCO2[	502	]=	5.12036E-01	;
    RnonCO2[	503	]=	5.10864E-01	;
    RnonCO2[	504	]=	5.09743E-01	;
    RnonCO2[	505	]=	5.08667E-01	;
    RnonCO2[	506	]=	5.07633E-01	;
    RnonCO2[	507	]=	5.06643E-01	;
    RnonCO2[	508	]=	5.05687E-01	;
    RnonCO2[	509	]=	5.04768E-01	;
    RnonCO2[	510	]=	5.03878E-01	;
    RnonCO2[	511	]=	5.03021E-01	;
    RnonCO2[	512	]=	5.02189E-01	;
    RnonCO2[	513	]=	5.01379E-01	;
    RnonCO2[	514	]=	5.00595E-01	;
    RnonCO2[	515	]=	4.99830E-01	;
    RnonCO2[	516	]=	4.99092E-01	;
    RnonCO2[	517	]=	4.98367E-01	;
    RnonCO2[	518	]=	4.97666E-01	;
    RnonCO2[	519	]=	4.96983E-01	;
    RnonCO2[	520	]=	4.96310E-01	;
    RnonCO2[	521	]=	4.95656E-01	;
    RnonCO2[	522	]=	4.95017E-01	;
    RnonCO2[	523	]=	4.94392E-01	;
    RnonCO2[	524	]=	4.93779E-01	;
    RnonCO2[	525	]=	4.93178E-01	;
    RnonCO2[	526	]=	4.92594E-01	;
    RnonCO2[	527	]=	4.92018E-01	;
    RnonCO2[	528	]=	4.91454E-01	;
    RnonCO2[	529	]=	4.90895E-01	;
    RnonCO2[	530	]=	4.90354E-01	;
    RnonCO2[	531	]=	4.89820E-01	;
    RnonCO2[	532	]=	4.89292E-01	;
    RnonCO2[	533	]=	4.88777E-01	;
    RnonCO2[	534	]=	4.88270E-01	;
    RnonCO2[	535	]=	4.87769E-01	;
    RnonCO2[	536	]=	4.87280E-01	;
    RnonCO2[	537	]=	4.86797E-01	;
    RnonCO2[	538	]=	4.86321E-01	;
    RnonCO2[	539	]=	4.85855E-01	;
    RnonCO2[	540	]=	4.85393E-01	;
    RnonCO2[	541	]=	4.84939E-01	;
    RnonCO2[	542	]=	4.84490E-01	;
    RnonCO2[	543	]=	4.84049E-01	;
    RnonCO2[	544	]=	4.83616E-01	;
    RnonCO2[	545	]=	4.83192E-01	;
    RnonCO2[	546	]=	4.82768E-01	;
    RnonCO2[	547	]=	4.82350E-01	;
    RnonCO2[	548	]=	4.81940E-01	;
    RnonCO2[	549	]=	4.81539E-01	;
    RnonCO2[	550	]=	4.81137E-01	;
    RnonCO2[	551	]=	4.80745E-01	;
    RnonCO2[	552	]=	4.80358E-01	;
    RnonCO2[	553	]=	4.79973E-01	;
    RnonCO2[	554	]=	4.79595E-01	;
    RnonCO2[	555	]=	4.79225E-01	;
    RnonCO2[	556	]=	4.78856E-01	;
    RnonCO2[	557	]=	4.78491E-01	;
    RnonCO2[	558	]=	4.78134E-01	;
    RnonCO2[	559	]=	4.77781E-01	;
    RnonCO2[	560	]=	4.77428E-01	;
    RnonCO2[	561	]=	4.77080E-01	;
    RnonCO2[	562	]=	4.76744E-01	;
    RnonCO2[	563	]=	4.76406E-01	;
    RnonCO2[	564	]=	4.76070E-01	;
    RnonCO2[	565	]=	4.75740E-01	;
    RnonCO2[	566	]=	4.75418E-01	;
    RnonCO2[	567	]=	4.75096E-01	;
    RnonCO2[	568	]=	4.74777E-01	;
    RnonCO2[	569	]=	4.74463E-01	;
    RnonCO2[	570	]=	4.74151E-01	;
    RnonCO2[	571	]=	4.73845E-01	;
    RnonCO2[	572	]=	4.73541E-01	;
    RnonCO2[	573	]=	4.73244E-01	;
    RnonCO2[	574	]=	4.72947E-01	;
    RnonCO2[	575	]=	4.72656E-01	;
    RnonCO2[	576	]=	4.72363E-01	;
    RnonCO2[	577	]=	4.72079E-01	;
    RnonCO2[	578	]=	4.71793E-01	;
    RnonCO2[	579	]=	4.71513E-01	;
    RnonCO2[	580	]=	4.71234E-01	;
    RnonCO2[	581	]=	4.70960E-01	;
    RnonCO2[	582	]=	4.70688E-01	;
    RnonCO2[	583	]=	4.70421E-01	;
    RnonCO2[	584	]=	4.70155E-01	;
    RnonCO2[	585	]=	4.69891E-01	;
    RnonCO2[	586	]=	4.69632E-01	;
    RnonCO2[	587	]=	4.69369E-01	;
    RnonCO2[	588	]=	4.69116E-01	;
    RnonCO2[	589	]=	4.68865E-01	;
    RnonCO2[	590	]=	4.68615E-01	;
    RnonCO2[	591	]=	4.68369E-01	;
    RnonCO2[	592	]=	4.68125E-01	;
    RnonCO2[	593	]=	4.67882E-01	;
    RnonCO2[	594	]=	4.67639E-01	;
    RnonCO2[	595	]=	4.67402E-01	;
    RnonCO2[	596	]=	4.67169E-01	;
    RnonCO2[	597	]=	4.66938E-01	;
    RnonCO2[	598	]=	4.66703E-01	;
    RnonCO2[	599	]=	4.66477E-01	;
    RnonCO2[	600	]=	4.66250E-01	;
    RnonCO2[	601	]=	4.66029E-01	;
    RnonCO2[	602	]=	4.65802E-01	;
    RnonCO2[	603	]=	4.65584E-01	;
    RnonCO2[	604	]=	4.65370E-01	;
    RnonCO2[	605	]=	4.65149E-01	;
    RnonCO2[	606	]=	4.64936E-01	;
    RnonCO2[	607	]=	4.64726E-01	;
    RnonCO2[	608	]=	4.64514E-01	;
    RnonCO2[	609	]=	4.64307E-01	;
    RnonCO2[	610	]=	4.64100E-01	;
    RnonCO2[	611	]=	4.63896E-01	;
    RnonCO2[	612	]=	4.63694E-01	;
    RnonCO2[	613	]=	4.63493E-01	;
    RnonCO2[	614	]=	4.63296E-01	;
    RnonCO2[	615	]=	4.63099E-01	;
    RnonCO2[	616	]=	4.62903E-01	;
    RnonCO2[	617	]=	4.62708E-01	;
    RnonCO2[	618	]=	4.62517E-01	;
    RnonCO2[	619	]=	4.62326E-01	;
    RnonCO2[	620	]=	4.62136E-01	;
    RnonCO2[	621	]=	4.61950E-01	;
    RnonCO2[	622	]=	4.61764E-01	;
    RnonCO2[	623	]=	4.61580E-01	;
    RnonCO2[	624	]=	4.61399E-01	;
    RnonCO2[	625	]=	4.61218E-01	;
    RnonCO2[	626	]=	4.61038E-01	;
    RnonCO2[	627	]=	4.60859E-01	;
    RnonCO2[	628	]=	4.60684E-01	;
    RnonCO2[	629	]=	4.60509E-01	;
    RnonCO2[	630	]=	4.60334E-01	;
    RnonCO2[	631	]=	4.60163E-01	;
    RnonCO2[	632	]=	4.59990E-01	;
    RnonCO2[	633	]=	4.59823E-01	;
    RnonCO2[	634	]=	4.59654E-01	;
    RnonCO2[	635	]=	4.59484E-01	;
    RnonCO2[	636	]=	4.59319E-01	;
    RnonCO2[	637	]=	4.59154E-01	;
    RnonCO2[	638	]=	4.58993E-01	;
    RnonCO2[	639	]=	4.58828E-01	;
    RnonCO2[	640	]=	4.58668E-01	;
    RnonCO2[	641	]=	4.58508E-01	;
    RnonCO2[	642	]=	4.58351E-01	;
    RnonCO2[	643	]=	4.58192E-01	;
    RnonCO2[	644	]=	4.58035E-01	;
    RnonCO2[	645	]=	4.57880E-01	;
    RnonCO2[	646	]=	4.57728E-01	;
    RnonCO2[	647	]=	4.57572E-01	;
    RnonCO2[	648	]=	4.57421E-01	;
    RnonCO2[	649	]=	4.57269E-01	;
    RnonCO2[	650	]=	4.57121E-01	;
    RnonCO2[	651	]=	4.56970E-01	;
    RnonCO2[	652	]=	4.56823E-01	;
    RnonCO2[	653	]=	4.56675E-01	;
    RnonCO2[	654	]=	4.56528E-01	;
    RnonCO2[	655	]=	4.56384E-01	;
    RnonCO2[	656	]=	4.56240E-01	;
    RnonCO2[	657	]=	4.56094E-01	;
    RnonCO2[	658	]=	4.55953E-01	;
    RnonCO2[	659	]=	4.55811E-01	;
    RnonCO2[	660	]=	4.55672E-01	;
    RnonCO2[	661	]=	4.55532E-01	;
    RnonCO2[	662	]=	4.55397E-01	;
    RnonCO2[	663	]=	4.55266E-01	;
    RnonCO2[	664	]=	4.55134E-01	;
    RnonCO2[	665	]=	4.55007E-01	;
    RnonCO2[	666	]=	4.54880E-01	;
    RnonCO2[	667	]=	4.54755E-01	;
    RnonCO2[	668	]=	4.54631E-01	;
    RnonCO2[	669	]=	4.54508E-01	;
    RnonCO2[	670	]=	4.54388E-01	;
    RnonCO2[	671	]=	4.54270E-01	;
    RnonCO2[	672	]=	4.54152E-01	;
    RnonCO2[	673	]=	4.54035E-01	;
    RnonCO2[	674	]=	4.53923E-01	;
    RnonCO2[	675	]=	4.53810E-01	;
    RnonCO2[	676	]=	4.53695E-01	;
    RnonCO2[	677	]=	4.53584E-01	;
    RnonCO2[	678	]=	4.53476E-01	;
    RnonCO2[	679	]=	4.53366E-01	;
    RnonCO2[	680	]=	4.53259E-01	;
    RnonCO2[	681	]=	4.53153E-01	;
    RnonCO2[	682	]=	4.53048E-01	;
    RnonCO2[	683	]=	4.52942E-01	;
    RnonCO2[	684	]=	4.52838E-01	;
    RnonCO2[	685	]=	4.52736E-01	;
    RnonCO2[	686	]=	4.52632E-01	;
    RnonCO2[	687	]=	4.52531E-01	;
    RnonCO2[	688	]=	4.52431E-01	;
    RnonCO2[	689	]=	4.52334E-01	;
    RnonCO2[	690	]=	4.52235E-01	;
    RnonCO2[	691	]=	4.52136E-01	;
    RnonCO2[	692	]=	4.52039E-01	;
    RnonCO2[	693	]=	4.51944E-01	;
    RnonCO2[	694	]=	4.51849E-01	;
    RnonCO2[	695	]=	4.51754E-01	;
    RnonCO2[	696	]=	4.51662E-01	;
    RnonCO2[	697	]=	4.51568E-01	;
    RnonCO2[	698	]=	4.51476E-01	;
    RnonCO2[	699	]=	4.51386E-01	;
    RnonCO2[	700	]=	4.51295E-01	;
    RnonCO2[	701	]=	4.51205E-01	;
    RnonCO2[	702	]=	4.51118E-01	;
    RnonCO2[	703	]=	4.51028E-01	;
    RnonCO2[	704	]=	4.50942E-01	;
    RnonCO2[	705	]=	4.50856E-01	;
    RnonCO2[	706	]=	4.50770E-01	;
    RnonCO2[	707	]=	4.50684E-01	;
    RnonCO2[	708	]=	4.50599E-01	;
    RnonCO2[	709	]=	4.50516E-01	;
    RnonCO2[	710	]=	4.50431E-01	;
    RnonCO2[	711	]=	4.50349E-01	;
    RnonCO2[	712	]=	4.50268E-01	;
    RnonCO2[	713	]=	4.50187E-01	;
    RnonCO2[	714	]=	4.50105E-01	;
    RnonCO2[	715	]=	4.50024E-01	;
    RnonCO2[	716	]=	4.49947E-01	;
    RnonCO2[	717	]=	4.49866E-01	;
    RnonCO2[	718	]=	4.49789E-01	;
    RnonCO2[	719	]=	4.49712E-01	;
    RnonCO2[	720	]=	4.49635E-01	;
    RnonCO2[	721	]=	4.49559E-01	;
    RnonCO2[	722	]=	4.49482E-01	;
    RnonCO2[	723	]=	4.49409E-01	;
    RnonCO2[	724	]=	4.49333E-01	;
    RnonCO2[	725	]=	4.49260E-01	;
    RnonCO2[	726	]=	4.49187E-01	;
    RnonCO2[	727	]=	4.49115E-01	;
    RnonCO2[	728	]=	4.49043E-01	;
    RnonCO2[	729	]=	4.48971E-01	;
    RnonCO2[	730	]=	4.48899E-01	;
    RnonCO2[	731	]=	4.48830E-01	;
    RnonCO2[	732	]=	4.48759E-01	;
    RnonCO2[	733	]=	4.48690E-01	;
    RnonCO2[	734	]=	4.48622E-01	;
    RnonCO2[	735	]=	4.48585E-01	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp245(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.16854E+00	;
    RnonCO2[	252	]=	-1.13466E+00	;
    RnonCO2[	253	]=	-1.10000E+00	;
    RnonCO2[	254	]=	-1.06454E+00	;
    RnonCO2[	255	]=	-1.02822E+00	;
    RnonCO2[	256	]=	-1.02790E+00	;
    RnonCO2[	257	]=	-1.02759E+00	;
    RnonCO2[	258	]=	-1.02728E+00	;
    RnonCO2[	259	]=	-1.02696E+00	;
    RnonCO2[	260	]=	-1.02665E+00	;
    RnonCO2[	261	]=	-1.02633E+00	;
    RnonCO2[	262	]=	-1.02602E+00	;
    RnonCO2[	263	]=	-1.02570E+00	;
    RnonCO2[	264	]=	-1.02538E+00	;
    RnonCO2[	265	]=	-1.02506E+00	;
    RnonCO2[	266	]=	-1.01391E+00	;
    RnonCO2[	267	]=	-1.00268E+00	;
    RnonCO2[	268	]=	-9.91354E-01	;
    RnonCO2[	269	]=	-9.79945E-01	;
    RnonCO2[	270	]=	-9.68446E-01	;
    RnonCO2[	271	]=	-9.56856E-01	;
    RnonCO2[	272	]=	-9.45173E-01	;
    RnonCO2[	273	]=	-9.33396E-01	;
    RnonCO2[	274	]=	-9.21522E-01	;
    RnonCO2[	275	]=	-9.09549E-01	;
    RnonCO2[	276	]=	-8.96577E-01	;
    RnonCO2[	277	]=	-8.83488E-01	;
    RnonCO2[	278	]=	-8.70282E-01	;
    RnonCO2[	279	]=	-8.56955E-01	;
    RnonCO2[	280	]=	-8.43505E-01	;
    RnonCO2[	281	]=	-8.29930E-01	;
    RnonCO2[	282	]=	-8.16225E-01	;
    RnonCO2[	283	]=	-8.02389E-01	;
    RnonCO2[	284	]=	-7.88418E-01	;
    RnonCO2[	285	]=	-7.74309E-01	;
    RnonCO2[	286	]=	-7.66207E-01	;
    RnonCO2[	287	]=	-7.58062E-01	;
    RnonCO2[	288	]=	-7.49872E-01	;
    RnonCO2[	289	]=	-7.41638E-01	;
    RnonCO2[	290	]=	-7.33358E-01	;
    RnonCO2[	291	]=	-7.25032E-01	;
    RnonCO2[	292	]=	-7.16659E-01	;
    RnonCO2[	293	]=	-7.08239E-01	;
    RnonCO2[	294	]=	-6.99772E-01	;
    RnonCO2[	295	]=	-6.91256E-01	;
    RnonCO2[	296	]=	-6.86342E-01	;
    RnonCO2[	297	]=	-6.81414E-01	;
    RnonCO2[	298	]=	-6.76469E-01	;
    RnonCO2[	299	]=	-6.71509E-01	;
    RnonCO2[	300	]=	-6.66533E-01	;
    RnonCO2[	301	]=	-6.61540E-01	;
    RnonCO2[	302	]=	-6.56532E-01	;
    RnonCO2[	303	]=	-6.51507E-01	;
    RnonCO2[	304	]=	-6.46466E-01	;
    RnonCO2[	305	]=	-6.41408E-01	;
    RnonCO2[	306	]=	-6.37223E-01	;
    RnonCO2[	307	]=	-6.33027E-01	;
    RnonCO2[	308	]=	-6.28819E-01	;
    RnonCO2[	309	]=	-6.24598E-01	;
    RnonCO2[	310	]=	-6.20366E-01	;
    RnonCO2[	311	]=	-6.16122E-01	;
    RnonCO2[	312	]=	-6.11866E-01	;
    RnonCO2[	313	]=	-6.07598E-01	;
    RnonCO2[	314	]=	-6.03317E-01	;
    RnonCO2[	315	]=	-5.99024E-01	;
    RnonCO2[	316	]=	-5.92292E-01	;
    RnonCO2[	317	]=	-5.85529E-01	;
    RnonCO2[	318	]=	-5.78734E-01	;
    RnonCO2[	319	]=	-5.71908E-01	;
    RnonCO2[	320	]=	-5.65050E-01	;
    RnonCO2[	321	]=	-5.58160E-01	;
    RnonCO2[	322	]=	-5.51237E-01	;
    RnonCO2[	323	]=	-5.44281E-01	;
    RnonCO2[	324	]=	-5.37292E-01	;
    RnonCO2[	325	]=	-5.30269E-01	;
    RnonCO2[	326	]=	-5.27044E-01	;
    RnonCO2[	327	]=	-5.23812E-01	;
    RnonCO2[	328	]=	-5.20573E-01	;
    RnonCO2[	329	]=	-5.17328E-01	;
    RnonCO2[	330	]=	-5.14076E-01	;
    RnonCO2[	331	]=	-5.10818E-01	;
    RnonCO2[	332	]=	-5.07553E-01	;
    RnonCO2[	333	]=	-5.04281E-01	;
    RnonCO2[	334	]=	-5.01002E-01	;
    RnonCO2[	335	]=	-4.97717E-01	;
    RnonCO2[	336	]=	-4.94996E-01	;
    RnonCO2[	337	]=	-4.92271E-01	;
    RnonCO2[	338	]=	-4.89541E-01	;
    RnonCO2[	339	]=	-4.86806E-01	;
    RnonCO2[	340	]=	-4.84067E-01	;
    RnonCO2[	341	]=	-4.81323E-01	;
    RnonCO2[	342	]=	-4.78575E-01	;
    RnonCO2[	343	]=	-4.75821E-01	;
    RnonCO2[	344	]=	-4.73063E-01	;
    RnonCO2[	345	]=	-4.70300E-01	;
    RnonCO2[	346	]=	-4.67532E-01	;
    RnonCO2[	347	]=	-4.64759E-01	;
    RnonCO2[	348	]=	-4.61981E-01	;
    RnonCO2[	349	]=	-4.59198E-01	;
    RnonCO2[	350	]=	-4.56411E-01	;
    RnonCO2[	351	]=	-4.53618E-01	;
    RnonCO2[	352	]=	-4.50821E-01	;
    RnonCO2[	353	]=	-4.48018E-01	;
    RnonCO2[	354	]=	-4.45211E-01	;
    RnonCO2[	355	]=	-4.42398E-01	;
    RnonCO2[	356	]=	-4.39581E-01	;
    RnonCO2[	357	]=	-4.36758E-01	;
    RnonCO2[	358	]=	-4.33930E-01	;
    RnonCO2[	359	]=	-4.31097E-01	;
    RnonCO2[	360	]=	-4.28258E-01	;
    RnonCO2[	361	]=	-4.25415E-01	;
    RnonCO2[	362	]=	-4.22566E-01	;
    RnonCO2[	363	]=	-4.19713E-01	;
    RnonCO2[	364	]=	-4.16854E-01	;
    RnonCO2[	365	]=	-4.13989E-01	;
    RnonCO2[	366	]=	-4.11120E-01	;
    RnonCO2[	367	]=	-4.08246E-01	;
    RnonCO2[	368	]=	-4.05366E-01	;
    RnonCO2[	369	]=	-4.02480E-01	;
    RnonCO2[	370	]=	-3.99590E-01	;
    RnonCO2[	371	]=	-3.96694E-01	;
    RnonCO2[	372	]=	-3.93792E-01	;
    RnonCO2[	373	]=	-3.90885E-01	;
    RnonCO2[	374	]=	-3.87973E-01	;
    RnonCO2[	375	]=	-3.85055E-01	;
    RnonCO2[	376	]=	-3.82132E-01	;
    RnonCO2[	377	]=	-3.79203E-01	;
    RnonCO2[	378	]=	-3.76268E-01	;
    RnonCO2[	379	]=	-3.73328E-01	;
    RnonCO2[	380	]=	-3.70383E-01	;
    RnonCO2[	381	]=	-3.67431E-01	;
    RnonCO2[	382	]=	-3.64474E-01	;
    RnonCO2[	383	]=	-3.61512E-01	;
    RnonCO2[	384	]=	-3.58543E-01	;
    RnonCO2[	385	]=	-3.55569E-01	;
    RnonCO2[	386	]=	-3.52589E-01	;
    RnonCO2[	387	]=	-3.49603E-01	;
    RnonCO2[	388	]=	-3.46611E-01	;
    RnonCO2[	389	]=	-3.43614E-01	;
    RnonCO2[	390	]=	-3.40610E-01	;
    RnonCO2[	391	]=	-3.37601E-01	;
    RnonCO2[	392	]=	-3.34586E-01	;
    RnonCO2[	393	]=	-3.31564E-01	;
    RnonCO2[	394	]=	-3.28537E-01	;
    RnonCO2[	395	]=	-3.25503E-01	;
    RnonCO2[	396	]=	-3.22464E-01	;
    RnonCO2[	397	]=	-3.19418E-01	;
    RnonCO2[	398	]=	-3.16367E-01	;
    RnonCO2[	399	]=	-3.13309E-01	;
    RnonCO2[	400	]=	-3.10245E-01	;
    RnonCO2[	401	]=	-3.07174E-01	;
    RnonCO2[	402	]=	-3.04098E-01	;
    RnonCO2[	403	]=	-3.01015E-01	;
    RnonCO2[	404	]=	-2.97926E-01	;
    RnonCO2[	405	]=	-2.94830E-01	;
    RnonCO2[	406	]=	-2.91728E-01	;
    RnonCO2[	407	]=	-2.88620E-01	;
    RnonCO2[	408	]=	-2.85505E-01	;
    RnonCO2[	409	]=	-2.82384E-01	;
    RnonCO2[	410	]=	-2.79257E-01	;
    RnonCO2[	411	]=	-2.76122E-01	;
    RnonCO2[	412	]=	-2.72982E-01	;
    RnonCO2[	413	]=	-2.69834E-01	;
    RnonCO2[	414	]=	-2.66680E-01	;
    RnonCO2[	415	]=	-2.63520E-01	;
    RnonCO2[	416	]=	-2.60352E-01	;
    RnonCO2[	417	]=	-2.57177E-01	;
    RnonCO2[	418	]=	-2.53996E-01	;
    RnonCO2[	419	]=	-2.50808E-01	;
    RnonCO2[	420	]=	-2.47613E-01	;
    RnonCO2[	421	]=	-2.44412E-01	;
    RnonCO2[	422	]=	-2.41203E-01	;
    RnonCO2[	423	]=	-2.37987E-01	;
    RnonCO2[	424	]=	-2.34765E-01	;
    RnonCO2[	425	]=	-2.31535E-01	;
    RnonCO2[	426	]=	-2.28299E-01	;
    RnonCO2[	427	]=	-2.25056E-01	;
    RnonCO2[	428	]=	-2.21805E-01	;
    RnonCO2[	429	]=	-2.18548E-01	;
    RnonCO2[	430	]=	-2.15283E-01	;
    RnonCO2[	431	]=	-2.12011E-01	;
    RnonCO2[	432	]=	-2.08731E-01	;
    RnonCO2[	433	]=	-2.05445E-01	;
    RnonCO2[	434	]=	-2.02151E-01	;
    RnonCO2[	435	]=	-1.98849E-01	;
    RnonCO2[	436	]=	-1.95540E-01	;
    RnonCO2[	437	]=	-1.92224E-01	;
    RnonCO2[	438	]=	-1.88900E-01	;
    RnonCO2[	439	]=	-1.85569E-01	;
    RnonCO2[	440	]=	-1.82229E-01	;
    RnonCO2[	441	]=	-1.78883E-01	;
    RnonCO2[	442	]=	-1.75528E-01	;
    RnonCO2[	443	]=	-1.72166E-01	;
    RnonCO2[	444	]=	-1.68796E-01	;
    RnonCO2[	445	]=	-1.65419E-01	;
    RnonCO2[	446	]=	-1.62033E-01	;
    RnonCO2[	447	]=	-1.58640E-01	;
    RnonCO2[	448	]=	-1.55238E-01	;
    RnonCO2[	449	]=	-1.51829E-01	;
    RnonCO2[	450	]=	-1.48411E-01	;
    RnonCO2[	451	]=	-1.44986E-01	;
    RnonCO2[	452	]=	-1.41552E-01	;
    RnonCO2[	453	]=	-1.38111E-01	;
    RnonCO2[	454	]=	-1.34661E-01	;
    RnonCO2[	455	]=	-1.31202E-01	;
    RnonCO2[	456	]=	-1.27736E-01	;
    RnonCO2[	457	]=	-1.24261E-01	;
    RnonCO2[	458	]=	-1.20778E-01	;
    RnonCO2[	459	]=	-1.17286E-01	;
    RnonCO2[	460	]=	-1.13786E-01	;
    RnonCO2[	461	]=	-1.10277E-01	;
    RnonCO2[	462	]=	-1.06760E-01	;
    RnonCO2[	463	]=	-1.03234E-01	;
    RnonCO2[	464	]=	-9.96991E-02	;
    RnonCO2[	465	]=	-9.61557E-02	;
    RnonCO2[	466	]=	-9.26032E-02	;
    RnonCO2[	467	]=	-8.90418E-02	;
    RnonCO2[	468	]=	-8.54716E-02	;
    RnonCO2[	469	]=	-8.18924E-02	;
    RnonCO2[	470	]=	-7.83042E-02	;
    RnonCO2[	471	]=	-7.47070E-02	;
    RnonCO2[	472	]=	-7.11006E-02	;
    RnonCO2[	473	]=	-6.74851E-02	;
    RnonCO2[	474	]=	-6.38604E-02	;
    RnonCO2[	475	]=	-6.02264E-02	;
    RnonCO2[	476	]=	-5.65835E-02	;
    RnonCO2[	477	]=	-5.29313E-02	;
    RnonCO2[	478	]=	-4.92696E-02	;
    RnonCO2[	479	]=	-4.55984E-02	;
    RnonCO2[	480	]=	-4.19177E-02	;
    RnonCO2[	481	]=	-3.82274E-02	;
    RnonCO2[	482	]=	-3.45274E-02	;
    RnonCO2[	483	]=	-3.08177E-02	;
    RnonCO2[	484	]=	-2.70982E-02	;
    RnonCO2[	485	]=	-2.33688E-02	;
    RnonCO2[	486	]=	-2.33688E-02	;
    RnonCO2[	487	]=	-2.33688E-02	;
    RnonCO2[	488	]=	-2.33688E-02	;
    RnonCO2[	489	]=	-2.33688E-02	;
    RnonCO2[	490	]=	-2.33688E-02	;
    RnonCO2[	491	]=	-2.33688E-02	;
    RnonCO2[	492	]=	-2.33688E-02	;
    RnonCO2[	493	]=	-2.33688E-02	;
    RnonCO2[	494	]=	-2.33688E-02	;
    RnonCO2[	495	]=	-2.33688E-02	;
    RnonCO2[	496	]=	-2.33688E-02	;
    RnonCO2[	497	]=	-2.33688E-02	;
    RnonCO2[	498	]=	-2.33688E-02	;
    RnonCO2[	499	]=	-2.33688E-02	;
    RnonCO2[	500	]=	-2.33688E-02	;
    RnonCO2[	501	]=	-2.33688E-02	;
    RnonCO2[	502	]=	-2.33688E-02	;
    RnonCO2[	503	]=	-2.33688E-02	;
    RnonCO2[	504	]=	-2.33688E-02	;
    RnonCO2[	505	]=	-2.33688E-02	;
    RnonCO2[	506	]=	-2.33688E-02	;
    RnonCO2[	507	]=	-2.33688E-02	;
    RnonCO2[	508	]=	-2.33688E-02	;
    RnonCO2[	509	]=	-2.33688E-02	;
    RnonCO2[	510	]=	-2.33688E-02	;
    RnonCO2[	511	]=	-2.33688E-02	;
    RnonCO2[	512	]=	-2.33688E-02	;
    RnonCO2[	513	]=	-2.33688E-02	;
    RnonCO2[	514	]=	-2.33688E-02	;
    RnonCO2[	515	]=	-2.33688E-02	;
    RnonCO2[	516	]=	-2.33688E-02	;
    RnonCO2[	517	]=	-2.33688E-02	;
    RnonCO2[	518	]=	-2.33688E-02	;
    RnonCO2[	519	]=	-2.33688E-02	;
    RnonCO2[	520	]=	-2.33688E-02	;
    RnonCO2[	521	]=	-2.33688E-02	;
    RnonCO2[	522	]=	-2.33688E-02	;
    RnonCO2[	523	]=	-2.33688E-02	;
    RnonCO2[	524	]=	-2.33688E-02	;
    RnonCO2[	525	]=	-2.33688E-02	;
    RnonCO2[	526	]=	-2.33688E-02	;
    RnonCO2[	527	]=	-2.33688E-02	;
    RnonCO2[	528	]=	-2.33688E-02	;
    RnonCO2[	529	]=	-2.33688E-02	;
    RnonCO2[	530	]=	-2.33688E-02	;
    RnonCO2[	531	]=	-2.33688E-02	;
    RnonCO2[	532	]=	-2.33688E-02	;
    RnonCO2[	533	]=	-2.33688E-02	;
    RnonCO2[	534	]=	-2.33688E-02	;
    RnonCO2[	535	]=	-2.33688E-02	;
    RnonCO2[	536	]=	-2.33688E-02	;
    RnonCO2[	537	]=	-2.33688E-02	;
    RnonCO2[	538	]=	-2.33688E-02	;
    RnonCO2[	539	]=	-2.33688E-02	;
    RnonCO2[	540	]=	-2.33688E-02	;
    RnonCO2[	541	]=	-2.33688E-02	;
    RnonCO2[	542	]=	-2.33688E-02	;
    RnonCO2[	543	]=	-2.33688E-02	;
    RnonCO2[	544	]=	-2.33688E-02	;
    RnonCO2[	545	]=	-2.33688E-02	;
    RnonCO2[	546	]=	-2.33688E-02	;
    RnonCO2[	547	]=	-2.33688E-02	;
    RnonCO2[	548	]=	-2.33688E-02	;
    RnonCO2[	549	]=	-2.33688E-02	;
    RnonCO2[	550	]=	-2.33688E-02	;
    RnonCO2[	551	]=	-2.33688E-02	;
    RnonCO2[	552	]=	-2.33688E-02	;
    RnonCO2[	553	]=	-2.33688E-02	;
    RnonCO2[	554	]=	-2.33688E-02	;
    RnonCO2[	555	]=	-2.33688E-02	;
    RnonCO2[	556	]=	-2.33688E-02	;
    RnonCO2[	557	]=	-2.33688E-02	;
    RnonCO2[	558	]=	-2.33688E-02	;
    RnonCO2[	559	]=	-2.33688E-02	;
    RnonCO2[	560	]=	-2.33688E-02	;
    RnonCO2[	561	]=	-2.33688E-02	;
    RnonCO2[	562	]=	-2.33688E-02	;
    RnonCO2[	563	]=	-2.33688E-02	;
    RnonCO2[	564	]=	-2.33688E-02	;
    RnonCO2[	565	]=	-2.33688E-02	;
    RnonCO2[	566	]=	-2.33688E-02	;
    RnonCO2[	567	]=	-2.33688E-02	;
    RnonCO2[	568	]=	-2.33688E-02	;
    RnonCO2[	569	]=	-2.33688E-02	;
    RnonCO2[	570	]=	-2.33688E-02	;
    RnonCO2[	571	]=	-2.33688E-02	;
    RnonCO2[	572	]=	-2.33688E-02	;
    RnonCO2[	573	]=	-2.33688E-02	;
    RnonCO2[	574	]=	-2.33688E-02	;
    RnonCO2[	575	]=	-2.33688E-02	;
    RnonCO2[	576	]=	-2.33688E-02	;
    RnonCO2[	577	]=	-2.33688E-02	;
    RnonCO2[	578	]=	-2.33688E-02	;
    RnonCO2[	579	]=	-2.33688E-02	;
    RnonCO2[	580	]=	-2.33688E-02	;
    RnonCO2[	581	]=	-2.33688E-02	;
    RnonCO2[	582	]=	-2.33688E-02	;
    RnonCO2[	583	]=	-2.33688E-02	;
    RnonCO2[	584	]=	-2.33688E-02	;
    RnonCO2[	585	]=	-2.33688E-02	;
    RnonCO2[	586	]=	-2.33688E-02	;
    RnonCO2[	587	]=	-2.33688E-02	;
    RnonCO2[	588	]=	-2.33688E-02	;
    RnonCO2[	589	]=	-2.33688E-02	;
    RnonCO2[	590	]=	-2.33688E-02	;
    RnonCO2[	591	]=	-2.33688E-02	;
    RnonCO2[	592	]=	-2.33688E-02	;
    RnonCO2[	593	]=	-2.33688E-02	;
    RnonCO2[	594	]=	-2.33688E-02	;
    RnonCO2[	595	]=	-2.33688E-02	;
    RnonCO2[	596	]=	-2.33688E-02	;
    RnonCO2[	597	]=	-2.33688E-02	;
    RnonCO2[	598	]=	-2.33688E-02	;
    RnonCO2[	599	]=	-2.33688E-02	;
    RnonCO2[	600	]=	-2.33688E-02	;
    RnonCO2[	601	]=	-2.33688E-02	;
    RnonCO2[	602	]=	-2.33688E-02	;
    RnonCO2[	603	]=	-2.33688E-02	;
    RnonCO2[	604	]=	-2.33688E-02	;
    RnonCO2[	605	]=	-2.33688E-02	;
    RnonCO2[	606	]=	-2.33688E-02	;
    RnonCO2[	607	]=	-2.33688E-02	;
    RnonCO2[	608	]=	-2.33688E-02	;
    RnonCO2[	609	]=	-2.33688E-02	;
    RnonCO2[	610	]=	-2.33688E-02	;
    RnonCO2[	611	]=	-2.33688E-02	;
    RnonCO2[	612	]=	-2.33688E-02	;
    RnonCO2[	613	]=	-2.33688E-02	;
    RnonCO2[	614	]=	-2.33688E-02	;
    RnonCO2[	615	]=	-2.33688E-02	;
    RnonCO2[	616	]=	-2.33688E-02	;
    RnonCO2[	617	]=	-2.33688E-02	;
    RnonCO2[	618	]=	-2.33688E-02	;
    RnonCO2[	619	]=	-2.33688E-02	;
    RnonCO2[	620	]=	-2.33688E-02	;
    RnonCO2[	621	]=	-2.33688E-02	;
    RnonCO2[	622	]=	-2.33688E-02	;
    RnonCO2[	623	]=	-2.33688E-02	;
    RnonCO2[	624	]=	-2.33688E-02	;
    RnonCO2[	625	]=	-2.33688E-02	;
    RnonCO2[	626	]=	-2.33688E-02	;
    RnonCO2[	627	]=	-2.33688E-02	;
    RnonCO2[	628	]=	-2.33688E-02	;
    RnonCO2[	629	]=	-2.33688E-02	;
    RnonCO2[	630	]=	-2.33688E-02	;
    RnonCO2[	631	]=	-2.33688E-02	;
    RnonCO2[	632	]=	-2.33688E-02	;
    RnonCO2[	633	]=	-2.33688E-02	;
    RnonCO2[	634	]=	-2.33688E-02	;
    RnonCO2[	635	]=	-2.33688E-02	;
    RnonCO2[	636	]=	-2.33688E-02	;
    RnonCO2[	637	]=	-2.33688E-02	;
    RnonCO2[	638	]=	-2.33688E-02	;
    RnonCO2[	639	]=	-2.33688E-02	;
    RnonCO2[	640	]=	-2.33688E-02	;
    RnonCO2[	641	]=	-2.33688E-02	;
    RnonCO2[	642	]=	-2.33688E-02	;
    RnonCO2[	643	]=	-2.33688E-02	;
    RnonCO2[	644	]=	-2.33688E-02	;
    RnonCO2[	645	]=	-2.33688E-02	;
    RnonCO2[	646	]=	-2.33688E-02	;
    RnonCO2[	647	]=	-2.33688E-02	;
    RnonCO2[	648	]=	-2.33688E-02	;
    RnonCO2[	649	]=	-2.33688E-02	;
    RnonCO2[	650	]=	-2.33688E-02	;
    RnonCO2[	651	]=	-2.33688E-02	;
    RnonCO2[	652	]=	-2.33688E-02	;
    RnonCO2[	653	]=	-2.33688E-02	;
    RnonCO2[	654	]=	-2.33688E-02	;
    RnonCO2[	655	]=	-2.33688E-02	;
    RnonCO2[	656	]=	-2.33688E-02	;
    RnonCO2[	657	]=	-2.33688E-02	;
    RnonCO2[	658	]=	-2.33688E-02	;
    RnonCO2[	659	]=	-2.33688E-02	;
    RnonCO2[	660	]=	-2.33688E-02	;
    RnonCO2[	661	]=	-2.33688E-02	;
    RnonCO2[	662	]=	-2.33688E-02	;
    RnonCO2[	663	]=	-2.33688E-02	;
    RnonCO2[	664	]=	-2.33688E-02	;
    RnonCO2[	665	]=	-2.33688E-02	;
    RnonCO2[	666	]=	-2.33688E-02	;
    RnonCO2[	667	]=	-2.33688E-02	;
    RnonCO2[	668	]=	-2.33688E-02	;
    RnonCO2[	669	]=	-2.33688E-02	;
    RnonCO2[	670	]=	-2.33688E-02	;
    RnonCO2[	671	]=	-2.33688E-02	;
    RnonCO2[	672	]=	-2.33688E-02	;
    RnonCO2[	673	]=	-2.33688E-02	;
    RnonCO2[	674	]=	-2.33688E-02	;
    RnonCO2[	675	]=	-2.33688E-02	;
    RnonCO2[	676	]=	-2.33688E-02	;
    RnonCO2[	677	]=	-2.33688E-02	;
    RnonCO2[	678	]=	-2.33688E-02	;
    RnonCO2[	679	]=	-2.33688E-02	;
    RnonCO2[	680	]=	-2.33688E-02	;
    RnonCO2[	681	]=	-2.33688E-02	;
    RnonCO2[	682	]=	-2.33688E-02	;
    RnonCO2[	683	]=	-2.33688E-02	;
    RnonCO2[	684	]=	-2.33688E-02	;
    RnonCO2[	685	]=	-2.33688E-02	;
    RnonCO2[	686	]=	-2.33688E-02	;
    RnonCO2[	687	]=	-2.33688E-02	;
    RnonCO2[	688	]=	-2.33688E-02	;
    RnonCO2[	689	]=	-2.33688E-02	;
    RnonCO2[	690	]=	-2.33688E-02	;
    RnonCO2[	691	]=	-2.33688E-02	;
    RnonCO2[	692	]=	-2.33688E-02	;
    RnonCO2[	693	]=	-2.33688E-02	;
    RnonCO2[	694	]=	-2.33688E-02	;
    RnonCO2[	695	]=	-2.33688E-02	;
    RnonCO2[	696	]=	-2.33688E-02	;
    RnonCO2[	697	]=	-2.33688E-02	;
    RnonCO2[	698	]=	-2.33688E-02	;
    RnonCO2[	699	]=	-2.33688E-02	;
    RnonCO2[	700	]=	-2.33688E-02	;
    RnonCO2[	701	]=	-2.33688E-02	;
    RnonCO2[	702	]=	-2.33688E-02	;
    RnonCO2[	703	]=	-2.33688E-02	;
    RnonCO2[	704	]=	-2.33688E-02	;
    RnonCO2[	705	]=	-2.33688E-02	;
    RnonCO2[	706	]=	-2.33688E-02	;
    RnonCO2[	707	]=	-2.33688E-02	;
    RnonCO2[	708	]=	-2.33688E-02	;
    RnonCO2[	709	]=	-2.33688E-02	;
    RnonCO2[	710	]=	-2.33688E-02	;
    RnonCO2[	711	]=	-2.33688E-02	;
    RnonCO2[	712	]=	-2.33688E-02	;
    RnonCO2[	713	]=	-2.33688E-02	;
    RnonCO2[	714	]=	-2.33688E-02	;
    RnonCO2[	715	]=	-2.33688E-02	;
    RnonCO2[	716	]=	-2.33688E-02	;
    RnonCO2[	717	]=	-2.33688E-02	;
    RnonCO2[	718	]=	-2.33688E-02	;
    RnonCO2[	719	]=	-2.33688E-02	;
    RnonCO2[	720	]=	-2.33688E-02	;
    RnonCO2[	721	]=	-2.33688E-02	;
    RnonCO2[	722	]=	-2.33688E-02	;
    RnonCO2[	723	]=	-2.33688E-02	;
    RnonCO2[	724	]=	-2.33688E-02	;
    RnonCO2[	725	]=	-2.33688E-02	;
    RnonCO2[	726	]=	-2.33688E-02	;
    RnonCO2[	727	]=	-2.33688E-02	;
    RnonCO2[	728	]=	-2.33688E-02	;
    RnonCO2[	729	]=	-2.33688E-02	;
    RnonCO2[	730	]=	-2.33688E-02	;
    RnonCO2[	731	]=	-2.33688E-02	;
    RnonCO2[	732	]=	-2.33688E-02	;
    RnonCO2[	733	]=	-2.33688E-02	;
    RnonCO2[	734	]=	-2.33688E-02	;
    RnonCO2[	735	]=	-2.33688E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp370(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07201E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09073E+00	;
    RnonCO2[	253	]=	1.09924E+00	;
    RnonCO2[	254	]=	1.10798E+00	;
    RnonCO2[	255	]=	1.11679E+00	;
    RnonCO2[	256	]=	1.12570E+00	;
    RnonCO2[	257	]=	1.13447E+00	;
    RnonCO2[	258	]=	1.14293E+00	;
    RnonCO2[	259	]=	1.15124E+00	;
    RnonCO2[	260	]=	1.15946E+00	;
    RnonCO2[	261	]=	1.16766E+00	;
    RnonCO2[	262	]=	1.17571E+00	;
    RnonCO2[	263	]=	1.18353E+00	;
    RnonCO2[	264	]=	1.19121E+00	;
    RnonCO2[	265	]=	1.19883E+00	;
    RnonCO2[	266	]=	1.20645E+00	;
    RnonCO2[	267	]=	1.21392E+00	;
    RnonCO2[	268	]=	1.22115E+00	;
    RnonCO2[	269	]=	1.22820E+00	;
    RnonCO2[	270	]=	1.23516E+00	;
    RnonCO2[	271	]=	1.24208E+00	;
    RnonCO2[	272	]=	1.24900E+00	;
    RnonCO2[	273	]=	1.25595E+00	;
    RnonCO2[	274	]=	1.26295E+00	;
    RnonCO2[	275	]=	1.27002E+00	;
    RnonCO2[	276	]=	1.27716E+00	;
    RnonCO2[	277	]=	1.28437E+00	;
    RnonCO2[	278	]=	1.29166E+00	;
    RnonCO2[	279	]=	1.29902E+00	;
    RnonCO2[	280	]=	1.30645E+00	;
    RnonCO2[	281	]=	1.31396E+00	;
    RnonCO2[	282	]=	1.32154E+00	;
    RnonCO2[	283	]=	1.32918E+00	;
    RnonCO2[	284	]=	1.33690E+00	;
    RnonCO2[	285	]=	1.34467E+00	;
    RnonCO2[	286	]=	1.35250E+00	;
    RnonCO2[	287	]=	1.36040E+00	;
    RnonCO2[	288	]=	1.36835E+00	;
    RnonCO2[	289	]=	1.37636E+00	;
    RnonCO2[	290	]=	1.38441E+00	;
    RnonCO2[	291	]=	1.39250E+00	;
    RnonCO2[	292	]=	1.40064E+00	;
    RnonCO2[	293	]=	1.40880E+00	;
    RnonCO2[	294	]=	1.41699E+00	;
    RnonCO2[	295	]=	1.42520E+00	;
    RnonCO2[	296	]=	1.43343E+00	;
    RnonCO2[	297	]=	1.44170E+00	;
    RnonCO2[	298	]=	1.44999E+00	;
    RnonCO2[	299	]=	1.45832E+00	;
    RnonCO2[	300	]=	1.46667E+00	;
    RnonCO2[	301	]=	1.47503E+00	;
    RnonCO2[	302	]=	1.48342E+00	;
    RnonCO2[	303	]=	1.49182E+00	;
    RnonCO2[	304	]=	1.50023E+00	;
    RnonCO2[	305	]=	1.50864E+00	;
    RnonCO2[	306	]=	1.51706E+00	;
    RnonCO2[	307	]=	1.52549E+00	;
    RnonCO2[	308	]=	1.53396E+00	;
    RnonCO2[	309	]=	1.54245E+00	;
    RnonCO2[	310	]=	1.55096E+00	;
    RnonCO2[	311	]=	1.55948E+00	;
    RnonCO2[	312	]=	1.56801E+00	;
    RnonCO2[	313	]=	1.57655E+00	;
    RnonCO2[	314	]=	1.58510E+00	;
    RnonCO2[	315	]=	1.59365E+00	;
    RnonCO2[	316	]=	1.60220E+00	;
    RnonCO2[	317	]=	1.61072E+00	;
    RnonCO2[	318	]=	1.61916E+00	;
    RnonCO2[	319	]=	1.62753E+00	;
    RnonCO2[	320	]=	1.63584E+00	;
    RnonCO2[	321	]=	1.64409E+00	;
    RnonCO2[	322	]=	1.65228E+00	;
    RnonCO2[	323	]=	1.66041E+00	;
    RnonCO2[	324	]=	1.66848E+00	;
    RnonCO2[	325	]=	1.67651E+00	;
    RnonCO2[	326	]=	1.68448E+00	;
    RnonCO2[	327	]=	1.69242E+00	;
    RnonCO2[	328	]=	1.70033E+00	;
    RnonCO2[	329	]=	1.70822E+00	;
    RnonCO2[	330	]=	1.71607E+00	;
    RnonCO2[	331	]=	1.72390E+00	;
    RnonCO2[	332	]=	1.73170E+00	;
    RnonCO2[	333	]=	1.73947E+00	;
    RnonCO2[	334	]=	1.74722E+00	;
    RnonCO2[	335	]=	1.75494E+00	;
    RnonCO2[	336	]=	1.76264E+00	;
    RnonCO2[	337	]=	1.76994E+00	;
    RnonCO2[	338	]=	1.77652E+00	;
    RnonCO2[	339	]=	1.78244E+00	;
    RnonCO2[	340	]=	1.78773E+00	;
    RnonCO2[	341	]=	1.79245E+00	;
    RnonCO2[	342	]=	1.79664E+00	;
    RnonCO2[	343	]=	1.80033E+00	;
    RnonCO2[	344	]=	1.80356E+00	;
    RnonCO2[	345	]=	1.80635E+00	;
    RnonCO2[	346	]=	1.80875E+00	;
    RnonCO2[	347	]=	1.81077E+00	;
    RnonCO2[	348	]=	1.81244E+00	;
    RnonCO2[	349	]=	1.81379E+00	;
    RnonCO2[	350	]=	1.81483E+00	;
    RnonCO2[	351	]=	1.81558E+00	;
    RnonCO2[	352	]=	1.81608E+00	;
    RnonCO2[	353	]=	1.81633E+00	;
    RnonCO2[	354	]=	1.81634E+00	;
    RnonCO2[	355	]=	1.81613E+00	;
    RnonCO2[	356	]=	1.81573E+00	;
    RnonCO2[	357	]=	1.81513E+00	;
    RnonCO2[	358	]=	1.81435E+00	;
    RnonCO2[	359	]=	1.81341E+00	;
    RnonCO2[	360	]=	1.81231E+00	;
    RnonCO2[	361	]=	1.81107E+00	;
    RnonCO2[	362	]=	1.80968E+00	;
    RnonCO2[	363	]=	1.80817E+00	;
    RnonCO2[	364	]=	1.80654E+00	;
    RnonCO2[	365	]=	1.80478E+00	;
    RnonCO2[	366	]=	1.80293E+00	;
    RnonCO2[	367	]=	1.80097E+00	;
    RnonCO2[	368	]=	1.79892E+00	;
    RnonCO2[	369	]=	1.79678E+00	;
    RnonCO2[	370	]=	1.79455E+00	;
    RnonCO2[	371	]=	1.79225E+00	;
    RnonCO2[	372	]=	1.78986E+00	;
    RnonCO2[	373	]=	1.78741E+00	;
    RnonCO2[	374	]=	1.78489E+00	;
    RnonCO2[	375	]=	1.78231E+00	;
    RnonCO2[	376	]=	1.77967E+00	;
    RnonCO2[	377	]=	1.77696E+00	;
    RnonCO2[	378	]=	1.77421E+00	;
    RnonCO2[	379	]=	1.77141E+00	;
    RnonCO2[	380	]=	1.76855E+00	;
    RnonCO2[	381	]=	1.76565E+00	;
    RnonCO2[	382	]=	1.76271E+00	;
    RnonCO2[	383	]=	1.75973E+00	;
    RnonCO2[	384	]=	1.75671E+00	;
    RnonCO2[	385	]=	1.75364E+00	;
    RnonCO2[	386	]=	1.75055E+00	;
    RnonCO2[	387	]=	1.74741E+00	;
    RnonCO2[	388	]=	1.74425E+00	;
    RnonCO2[	389	]=	1.74105E+00	;
    RnonCO2[	390	]=	1.73783E+00	;
    RnonCO2[	391	]=	1.73457E+00	;
    RnonCO2[	392	]=	1.73129E+00	;
    RnonCO2[	393	]=	1.72798E+00	;
    RnonCO2[	394	]=	1.72464E+00	;
    RnonCO2[	395	]=	1.72128E+00	;
    RnonCO2[	396	]=	1.71790E+00	;
    RnonCO2[	397	]=	1.71449E+00	;
    RnonCO2[	398	]=	1.71106E+00	;
    RnonCO2[	399	]=	1.70761E+00	;
    RnonCO2[	400	]=	1.70414E+00	;
    RnonCO2[	401	]=	1.70065E+00	;
    RnonCO2[	402	]=	1.69714E+00	;
    RnonCO2[	403	]=	1.69361E+00	;
    RnonCO2[	404	]=	1.69006E+00	;
    RnonCO2[	405	]=	1.68649E+00	;
    RnonCO2[	406	]=	1.68291E+00	;
    RnonCO2[	407	]=	1.67931E+00	;
    RnonCO2[	408	]=	1.67569E+00	;
    RnonCO2[	409	]=	1.67206E+00	;
    RnonCO2[	410	]=	1.66841E+00	;
    RnonCO2[	411	]=	1.66474E+00	;
    RnonCO2[	412	]=	1.66106E+00	;
    RnonCO2[	413	]=	1.65737E+00	;
    RnonCO2[	414	]=	1.65366E+00	;
    RnonCO2[	415	]=	1.64993E+00	;
    RnonCO2[	416	]=	1.64620E+00	;
    RnonCO2[	417	]=	1.64244E+00	;
    RnonCO2[	418	]=	1.63868E+00	;
    RnonCO2[	419	]=	1.63490E+00	;
    RnonCO2[	420	]=	1.63111E+00	;
    RnonCO2[	421	]=	1.62731E+00	;
    RnonCO2[	422	]=	1.62349E+00	;
    RnonCO2[	423	]=	1.61966E+00	;
    RnonCO2[	424	]=	1.61582E+00	;
    RnonCO2[	425	]=	1.61196E+00	;
    RnonCO2[	426	]=	1.60810E+00	;
    RnonCO2[	427	]=	1.60422E+00	;
    RnonCO2[	428	]=	1.60033E+00	;
    RnonCO2[	429	]=	1.59643E+00	;
    RnonCO2[	430	]=	1.59251E+00	;
    RnonCO2[	431	]=	1.58859E+00	;
    RnonCO2[	432	]=	1.58465E+00	;
    RnonCO2[	433	]=	1.58070E+00	;
    RnonCO2[	434	]=	1.57674E+00	;
    RnonCO2[	435	]=	1.57277E+00	;
    RnonCO2[	436	]=	1.56879E+00	;
    RnonCO2[	437	]=	1.56480E+00	;
    RnonCO2[	438	]=	1.56079E+00	;
    RnonCO2[	439	]=	1.55677E+00	;
    RnonCO2[	440	]=	1.55275E+00	;
    RnonCO2[	441	]=	1.54871E+00	;
    RnonCO2[	442	]=	1.54466E+00	;
    RnonCO2[	443	]=	1.54060E+00	;
    RnonCO2[	444	]=	1.53653E+00	;
    RnonCO2[	445	]=	1.53245E+00	;
    RnonCO2[	446	]=	1.52836E+00	;
    RnonCO2[	447	]=	1.52426E+00	;
    RnonCO2[	448	]=	1.52014E+00	;
    RnonCO2[	449	]=	1.51602E+00	;
    RnonCO2[	450	]=	1.51188E+00	;
    RnonCO2[	451	]=	1.50774E+00	;
    RnonCO2[	452	]=	1.50358E+00	;
    RnonCO2[	453	]=	1.49942E+00	;
    RnonCO2[	454	]=	1.49524E+00	;
    RnonCO2[	455	]=	1.49105E+00	;
    RnonCO2[	456	]=	1.48685E+00	;
    RnonCO2[	457	]=	1.48264E+00	;
    RnonCO2[	458	]=	1.47841E+00	;
    RnonCO2[	459	]=	1.47418E+00	;
    RnonCO2[	460	]=	1.46994E+00	;
    RnonCO2[	461	]=	1.46569E+00	;
    RnonCO2[	462	]=	1.46142E+00	;
    RnonCO2[	463	]=	1.45714E+00	;
    RnonCO2[	464	]=	1.45286E+00	;
    RnonCO2[	465	]=	1.44856E+00	;
    RnonCO2[	466	]=	1.44426E+00	;
    RnonCO2[	467	]=	1.43994E+00	;
    RnonCO2[	468	]=	1.43561E+00	;
    RnonCO2[	469	]=	1.43126E+00	;
    RnonCO2[	470	]=	1.42691E+00	;
    RnonCO2[	471	]=	1.42255E+00	;
    RnonCO2[	472	]=	1.41818E+00	;
    RnonCO2[	473	]=	1.41380E+00	;
    RnonCO2[	474	]=	1.40940E+00	;
    RnonCO2[	475	]=	1.40499E+00	;
    RnonCO2[	476	]=	1.40057E+00	;
    RnonCO2[	477	]=	1.39614E+00	;
    RnonCO2[	478	]=	1.39171E+00	;
    RnonCO2[	479	]=	1.38726E+00	;
    RnonCO2[	480	]=	1.38279E+00	;
    RnonCO2[	481	]=	1.37832E+00	;
    RnonCO2[	482	]=	1.37383E+00	;
    RnonCO2[	483	]=	1.36934E+00	;
    RnonCO2[	484	]=	1.36483E+00	;
    RnonCO2[	485	]=	1.36031E+00	;
    RnonCO2[	486	]=	1.35578E+00	;
    RnonCO2[	487	]=	1.35140E+00	;
    RnonCO2[	488	]=	1.34732E+00	;
    RnonCO2[	489	]=	1.34350E+00	;
    RnonCO2[	490	]=	1.33994E+00	;
    RnonCO2[	491	]=	1.33660E+00	;
    RnonCO2[	492	]=	1.33348E+00	;
    RnonCO2[	493	]=	1.33056E+00	;
    RnonCO2[	494	]=	1.32782E+00	;
    RnonCO2[	495	]=	1.32525E+00	;
    RnonCO2[	496	]=	1.32283E+00	;
    RnonCO2[	497	]=	1.32057E+00	;
    RnonCO2[	498	]=	1.31843E+00	;
    RnonCO2[	499	]=	1.31643E+00	;
    RnonCO2[	500	]=	1.31453E+00	;
    RnonCO2[	501	]=	1.31275E+00	;
    RnonCO2[	502	]=	1.31106E+00	;
    RnonCO2[	503	]=	1.30947E+00	;
    RnonCO2[	504	]=	1.30797E+00	;
    RnonCO2[	505	]=	1.30654E+00	;
    RnonCO2[	506	]=	1.30519E+00	;
    RnonCO2[	507	]=	1.30391E+00	;
    RnonCO2[	508	]=	1.30269E+00	;
    RnonCO2[	509	]=	1.30153E+00	;
    RnonCO2[	510	]=	1.30043E+00	;
    RnonCO2[	511	]=	1.29939E+00	;
    RnonCO2[	512	]=	1.29839E+00	;
    RnonCO2[	513	]=	1.29743E+00	;
    RnonCO2[	514	]=	1.29652E+00	;
    RnonCO2[	515	]=	1.29565E+00	;
    RnonCO2[	516	]=	1.29482E+00	;
    RnonCO2[	517	]=	1.29402E+00	;
    RnonCO2[	518	]=	1.29325E+00	;
    RnonCO2[	519	]=	1.29252E+00	;
    RnonCO2[	520	]=	1.29181E+00	;
    RnonCO2[	521	]=	1.29114E+00	;
    RnonCO2[	522	]=	1.29049E+00	;
    RnonCO2[	523	]=	1.28986E+00	;
    RnonCO2[	524	]=	1.28925E+00	;
    RnonCO2[	525	]=	1.28867E+00	;
    RnonCO2[	526	]=	1.28811E+00	;
    RnonCO2[	527	]=	1.28757E+00	;
    RnonCO2[	528	]=	1.28704E+00	;
    RnonCO2[	529	]=	1.28653E+00	;
    RnonCO2[	530	]=	1.28604E+00	;
    RnonCO2[	531	]=	1.28557E+00	;
    RnonCO2[	532	]=	1.28511E+00	;
    RnonCO2[	533	]=	1.28466E+00	;
    RnonCO2[	534	]=	1.28423E+00	;
    RnonCO2[	535	]=	1.28381E+00	;
    RnonCO2[	536	]=	1.28340E+00	;
    RnonCO2[	537	]=	1.28300E+00	;
    RnonCO2[	538	]=	1.28262E+00	;
    RnonCO2[	539	]=	1.28224E+00	;
    RnonCO2[	540	]=	1.28188E+00	;
    RnonCO2[	541	]=	1.28153E+00	;
    RnonCO2[	542	]=	1.28118E+00	;
    RnonCO2[	543	]=	1.28084E+00	;
    RnonCO2[	544	]=	1.28052E+00	;
    RnonCO2[	545	]=	1.28020E+00	;
    RnonCO2[	546	]=	1.27989E+00	;
    RnonCO2[	547	]=	1.27958E+00	;
    RnonCO2[	548	]=	1.27928E+00	;
    RnonCO2[	549	]=	1.27900E+00	;
    RnonCO2[	550	]=	1.27871E+00	;
    RnonCO2[	551	]=	1.27843E+00	;
    RnonCO2[	552	]=	1.27817E+00	;
    RnonCO2[	553	]=	1.27790E+00	;
    RnonCO2[	554	]=	1.27764E+00	;
    RnonCO2[	555	]=	1.27739E+00	;
    RnonCO2[	556	]=	1.27714E+00	;
    RnonCO2[	557	]=	1.27690E+00	;
    RnonCO2[	558	]=	1.27666E+00	;
    RnonCO2[	559	]=	1.27643E+00	;
    RnonCO2[	560	]=	1.27620E+00	;
    RnonCO2[	561	]=	1.27598E+00	;
    RnonCO2[	562	]=	1.27576E+00	;
    RnonCO2[	563	]=	1.27555E+00	;
    RnonCO2[	564	]=	1.27534E+00	;
    RnonCO2[	565	]=	1.27513E+00	;
    RnonCO2[	566	]=	1.27493E+00	;
    RnonCO2[	567	]=	1.27473E+00	;
    RnonCO2[	568	]=	1.27453E+00	;
    RnonCO2[	569	]=	1.27434E+00	;
    RnonCO2[	570	]=	1.27415E+00	;
    RnonCO2[	571	]=	1.27397E+00	;
    RnonCO2[	572	]=	1.27378E+00	;
    RnonCO2[	573	]=	1.27361E+00	;
    RnonCO2[	574	]=	1.27343E+00	;
    RnonCO2[	575	]=	1.27326E+00	;
    RnonCO2[	576	]=	1.27309E+00	;
    RnonCO2[	577	]=	1.27292E+00	;
    RnonCO2[	578	]=	1.27276E+00	;
    RnonCO2[	579	]=	1.27260E+00	;
    RnonCO2[	580	]=	1.27244E+00	;
    RnonCO2[	581	]=	1.27228E+00	;
    RnonCO2[	582	]=	1.27213E+00	;
    RnonCO2[	583	]=	1.27197E+00	;
    RnonCO2[	584	]=	1.27182E+00	;
    RnonCO2[	585	]=	1.27167E+00	;
    RnonCO2[	586	]=	1.27153E+00	;
    RnonCO2[	587	]=	1.27138E+00	;
    RnonCO2[	588	]=	1.27125E+00	;
    RnonCO2[	589	]=	1.27111E+00	;
    RnonCO2[	590	]=	1.27097E+00	;
    RnonCO2[	591	]=	1.27083E+00	;
    RnonCO2[	592	]=	1.27070E+00	;
    RnonCO2[	593	]=	1.27057E+00	;
    RnonCO2[	594	]=	1.27044E+00	;
    RnonCO2[	595	]=	1.27031E+00	;
    RnonCO2[	596	]=	1.27018E+00	;
    RnonCO2[	597	]=	1.27006E+00	;
    RnonCO2[	598	]=	1.26993E+00	;
    RnonCO2[	599	]=	1.26981E+00	;
    RnonCO2[	600	]=	1.26969E+00	;
    RnonCO2[	601	]=	1.26957E+00	;
    RnonCO2[	602	]=	1.26945E+00	;
    RnonCO2[	603	]=	1.26934E+00	;
    RnonCO2[	604	]=	1.26922E+00	;
    RnonCO2[	605	]=	1.26911E+00	;
    RnonCO2[	606	]=	1.26899E+00	;
    RnonCO2[	607	]=	1.26888E+00	;
    RnonCO2[	608	]=	1.26877E+00	;
    RnonCO2[	609	]=	1.26866E+00	;
    RnonCO2[	610	]=	1.26856E+00	;
    RnonCO2[	611	]=	1.26845E+00	;
    RnonCO2[	612	]=	1.26835E+00	;
    RnonCO2[	613	]=	1.26824E+00	;
    RnonCO2[	614	]=	1.26814E+00	;
    RnonCO2[	615	]=	1.26804E+00	;
    RnonCO2[	616	]=	1.26794E+00	;
    RnonCO2[	617	]=	1.26783E+00	;
    RnonCO2[	618	]=	1.26774E+00	;
    RnonCO2[	619	]=	1.26764E+00	;
    RnonCO2[	620	]=	1.26754E+00	;
    RnonCO2[	621	]=	1.26744E+00	;
    RnonCO2[	622	]=	1.26735E+00	;
    RnonCO2[	623	]=	1.26725E+00	;
    RnonCO2[	624	]=	1.26716E+00	;
    RnonCO2[	625	]=	1.26707E+00	;
    RnonCO2[	626	]=	1.26698E+00	;
    RnonCO2[	627	]=	1.26688E+00	;
    RnonCO2[	628	]=	1.26679E+00	;
    RnonCO2[	629	]=	1.26670E+00	;
    RnonCO2[	630	]=	1.26661E+00	;
    RnonCO2[	631	]=	1.26652E+00	;
    RnonCO2[	632	]=	1.26644E+00	;
    RnonCO2[	633	]=	1.26635E+00	;
    RnonCO2[	634	]=	1.26626E+00	;
    RnonCO2[	635	]=	1.26618E+00	;
    RnonCO2[	636	]=	1.26609E+00	;
    RnonCO2[	637	]=	1.26601E+00	;
    RnonCO2[	638	]=	1.26593E+00	;
    RnonCO2[	639	]=	1.26584E+00	;
    RnonCO2[	640	]=	1.26576E+00	;
    RnonCO2[	641	]=	1.26568E+00	;
    RnonCO2[	642	]=	1.26560E+00	;
    RnonCO2[	643	]=	1.26552E+00	;
    RnonCO2[	644	]=	1.26543E+00	;
    RnonCO2[	645	]=	1.26536E+00	;
    RnonCO2[	646	]=	1.26527E+00	;
    RnonCO2[	647	]=	1.26520E+00	;
    RnonCO2[	648	]=	1.26512E+00	;
    RnonCO2[	649	]=	1.26504E+00	;
    RnonCO2[	650	]=	1.26496E+00	;
    RnonCO2[	651	]=	1.26489E+00	;
    RnonCO2[	652	]=	1.26481E+00	;
    RnonCO2[	653	]=	1.26473E+00	;
    RnonCO2[	654	]=	1.26466E+00	;
    RnonCO2[	655	]=	1.26458E+00	;
    RnonCO2[	656	]=	1.26451E+00	;
    RnonCO2[	657	]=	1.26444E+00	;
    RnonCO2[	658	]=	1.26436E+00	;
    RnonCO2[	659	]=	1.26429E+00	;
    RnonCO2[	660	]=	1.26422E+00	;
    RnonCO2[	661	]=	1.26414E+00	;
    RnonCO2[	662	]=	1.26407E+00	;
    RnonCO2[	663	]=	1.26400E+00	;
    RnonCO2[	664	]=	1.26393E+00	;
    RnonCO2[	665	]=	1.26386E+00	;
    RnonCO2[	666	]=	1.26379E+00	;
    RnonCO2[	667	]=	1.26372E+00	;
    RnonCO2[	668	]=	1.26365E+00	;
    RnonCO2[	669	]=	1.26358E+00	;
    RnonCO2[	670	]=	1.26351E+00	;
    RnonCO2[	671	]=	1.26344E+00	;
    RnonCO2[	672	]=	1.26337E+00	;
    RnonCO2[	673	]=	1.26330E+00	;
    RnonCO2[	674	]=	1.26324E+00	;
    RnonCO2[	675	]=	1.26317E+00	;
    RnonCO2[	676	]=	1.26310E+00	;
    RnonCO2[	677	]=	1.26304E+00	;
    RnonCO2[	678	]=	1.26297E+00	;
    RnonCO2[	679	]=	1.26290E+00	;
    RnonCO2[	680	]=	1.26284E+00	;
    RnonCO2[	681	]=	1.26277E+00	;
    RnonCO2[	682	]=	1.26271E+00	;
    RnonCO2[	683	]=	1.26264E+00	;
    RnonCO2[	684	]=	1.26258E+00	;
    RnonCO2[	685	]=	1.26251E+00	;
    RnonCO2[	686	]=	1.26245E+00	;
    RnonCO2[	687	]=	1.26238E+00	;
    RnonCO2[	688	]=	1.26232E+00	;
    RnonCO2[	689	]=	1.26226E+00	;
    RnonCO2[	690	]=	1.26220E+00	;
    RnonCO2[	691	]=	1.26213E+00	;
    RnonCO2[	692	]=	1.26207E+00	;
    RnonCO2[	693	]=	1.26201E+00	;
    RnonCO2[	694	]=	1.26195E+00	;
    RnonCO2[	695	]=	1.26188E+00	;
    RnonCO2[	696	]=	1.26182E+00	;
    RnonCO2[	697	]=	1.26176E+00	;
    RnonCO2[	698	]=	1.26170E+00	;
    RnonCO2[	699	]=	1.26164E+00	;
    RnonCO2[	700	]=	1.26158E+00	;
    RnonCO2[	701	]=	1.26151E+00	;
    RnonCO2[	702	]=	1.26146E+00	;
    RnonCO2[	703	]=	1.26139E+00	;
    RnonCO2[	704	]=	1.26134E+00	;
    RnonCO2[	705	]=	1.26128E+00	;
    RnonCO2[	706	]=	1.26122E+00	;
    RnonCO2[	707	]=	1.26116E+00	;
    RnonCO2[	708	]=	1.26110E+00	;
    RnonCO2[	709	]=	1.26104E+00	;
    RnonCO2[	710	]=	1.26098E+00	;
    RnonCO2[	711	]=	1.26093E+00	;
    RnonCO2[	712	]=	1.26086E+00	;
    RnonCO2[	713	]=	1.26081E+00	;
    RnonCO2[	714	]=	1.26075E+00	;
    RnonCO2[	715	]=	1.26069E+00	;
    RnonCO2[	716	]=	1.26064E+00	;
    RnonCO2[	717	]=	1.26058E+00	;
    RnonCO2[	718	]=	1.26052E+00	;
    RnonCO2[	719	]=	1.26046E+00	;
    RnonCO2[	720	]=	1.26041E+00	;
    RnonCO2[	721	]=	1.26035E+00	;
    RnonCO2[	722	]=	1.26029E+00	;
    RnonCO2[	723	]=	1.26024E+00	;
    RnonCO2[	724	]=	1.26018E+00	;
    RnonCO2[	725	]=	1.26013E+00	;
    RnonCO2[	726	]=	1.26007E+00	;
    RnonCO2[	727	]=	1.26002E+00	;
    RnonCO2[	728	]=	1.25996E+00	;
    RnonCO2[	729	]=	1.25990E+00	;
    RnonCO2[	730	]=	1.25985E+00	;
    RnonCO2[	731	]=	1.25979E+00	;
    RnonCO2[	732	]=	1.25974E+00	;
    RnonCO2[	733	]=	1.25968E+00	;
    RnonCO2[	734	]=	1.25963E+00	;
    RnonCO2[	735	]=	1.25960E+00	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp370(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.19876E+00	;
    RnonCO2[	252	]=	-1.19580E+00	;
    RnonCO2[	253	]=	-1.19284E+00	;
    RnonCO2[	254	]=	-1.18987E+00	;
    RnonCO2[	255	]=	-1.18689E+00	;
    RnonCO2[	256	]=	-1.18779E+00	;
    RnonCO2[	257	]=	-1.18870E+00	;
    RnonCO2[	258	]=	-1.18960E+00	;
    RnonCO2[	259	]=	-1.19050E+00	;
    RnonCO2[	260	]=	-1.19140E+00	;
    RnonCO2[	261	]=	-1.19231E+00	;
    RnonCO2[	262	]=	-1.19321E+00	;
    RnonCO2[	263	]=	-1.19411E+00	;
    RnonCO2[	264	]=	-1.19501E+00	;
    RnonCO2[	265	]=	-1.19591E+00	;
    RnonCO2[	266	]=	-1.19636E+00	;
    RnonCO2[	267	]=	-1.19681E+00	;
    RnonCO2[	268	]=	-1.19726E+00	;
    RnonCO2[	269	]=	-1.19771E+00	;
    RnonCO2[	270	]=	-1.19815E+00	;
    RnonCO2[	271	]=	-1.19860E+00	;
    RnonCO2[	272	]=	-1.19905E+00	;
    RnonCO2[	273	]=	-1.19950E+00	;
    RnonCO2[	274	]=	-1.19995E+00	;
    RnonCO2[	275	]=	-1.20040E+00	;
    RnonCO2[	276	]=	-1.20089E+00	;
    RnonCO2[	277	]=	-1.20139E+00	;
    RnonCO2[	278	]=	-1.20188E+00	;
    RnonCO2[	279	]=	-1.20238E+00	;
    RnonCO2[	280	]=	-1.20287E+00	;
    RnonCO2[	281	]=	-1.20337E+00	;
    RnonCO2[	282	]=	-1.20387E+00	;
    RnonCO2[	283	]=	-1.20436E+00	;
    RnonCO2[	284	]=	-1.20486E+00	;
    RnonCO2[	285	]=	-1.20535E+00	;
    RnonCO2[	286	]=	-1.20233E+00	;
    RnonCO2[	287	]=	-1.19930E+00	;
    RnonCO2[	288	]=	-1.19627E+00	;
    RnonCO2[	289	]=	-1.19323E+00	;
    RnonCO2[	290	]=	-1.19018E+00	;
    RnonCO2[	291	]=	-1.18713E+00	;
    RnonCO2[	292	]=	-1.18407E+00	;
    RnonCO2[	293	]=	-1.18100E+00	;
    RnonCO2[	294	]=	-1.17793E+00	;
    RnonCO2[	295	]=	-1.17485E+00	;
    RnonCO2[	296	]=	-1.17157E+00	;
    RnonCO2[	297	]=	-1.16828E+00	;
    RnonCO2[	298	]=	-1.16499E+00	;
    RnonCO2[	299	]=	-1.16169E+00	;
    RnonCO2[	300	]=	-1.15838E+00	;
    RnonCO2[	301	]=	-1.15506E+00	;
    RnonCO2[	302	]=	-1.15174E+00	;
    RnonCO2[	303	]=	-1.14841E+00	;
    RnonCO2[	304	]=	-1.14507E+00	;
    RnonCO2[	305	]=	-1.14173E+00	;
    RnonCO2[	306	]=	-1.13800E+00	;
    RnonCO2[	307	]=	-1.13426E+00	;
    RnonCO2[	308	]=	-1.13051E+00	;
    RnonCO2[	309	]=	-1.12676E+00	;
    RnonCO2[	310	]=	-1.12299E+00	;
    RnonCO2[	311	]=	-1.11922E+00	;
    RnonCO2[	312	]=	-1.11543E+00	;
    RnonCO2[	313	]=	-1.11164E+00	;
    RnonCO2[	314	]=	-1.10784E+00	;
    RnonCO2[	315	]=	-1.10402E+00	;
    RnonCO2[	316	]=	-1.10088E+00	;
    RnonCO2[	317	]=	-1.09774E+00	;
    RnonCO2[	318	]=	-1.09458E+00	;
    RnonCO2[	319	]=	-1.09142E+00	;
    RnonCO2[	320	]=	-1.08825E+00	;
    RnonCO2[	321	]=	-1.08508E+00	;
    RnonCO2[	322	]=	-1.08189E+00	;
    RnonCO2[	323	]=	-1.07870E+00	;
    RnonCO2[	324	]=	-1.07551E+00	;
    RnonCO2[	325	]=	-1.07230E+00	;
    RnonCO2[	326	]=	-1.06757E+00	;
    RnonCO2[	327	]=	-1.06282E+00	;
    RnonCO2[	328	]=	-1.05805E+00	;
    RnonCO2[	329	]=	-1.05327E+00	;
    RnonCO2[	330	]=	-1.04848E+00	;
    RnonCO2[	331	]=	-1.04367E+00	;
    RnonCO2[	332	]=	-1.03884E+00	;
    RnonCO2[	333	]=	-1.03400E+00	;
    RnonCO2[	334	]=	-1.02914E+00	;
    RnonCO2[	335	]=	-1.02426E+00	;
    RnonCO2[	336	]=	-1.01942E+00	;
    RnonCO2[	337	]=	-1.01457E+00	;
    RnonCO2[	338	]=	-1.00970E+00	;
    RnonCO2[	339	]=	-1.00482E+00	;
    RnonCO2[	340	]=	-9.99922E-01	;
    RnonCO2[	341	]=	-9.95011E-01	;
    RnonCO2[	342	]=	-9.90085E-01	;
    RnonCO2[	343	]=	-9.85145E-01	;
    RnonCO2[	344	]=	-9.80190E-01	;
    RnonCO2[	345	]=	-9.75221E-01	;
    RnonCO2[	346	]=	-9.70236E-01	;
    RnonCO2[	347	]=	-9.65236E-01	;
    RnonCO2[	348	]=	-9.60221E-01	;
    RnonCO2[	349	]=	-9.55191E-01	;
    RnonCO2[	350	]=	-9.50145E-01	;
    RnonCO2[	351	]=	-9.45084E-01	;
    RnonCO2[	352	]=	-9.40007E-01	;
    RnonCO2[	353	]=	-9.34915E-01	;
    RnonCO2[	354	]=	-9.29806E-01	;
    RnonCO2[	355	]=	-9.24682E-01	;
    RnonCO2[	356	]=	-9.19541E-01	;
    RnonCO2[	357	]=	-9.14384E-01	;
    RnonCO2[	358	]=	-9.09211E-01	;
    RnonCO2[	359	]=	-9.04022E-01	;
    RnonCO2[	360	]=	-8.98815E-01	;
    RnonCO2[	361	]=	-8.93592E-01	;
    RnonCO2[	362	]=	-8.88352E-01	;
    RnonCO2[	363	]=	-8.83095E-01	;
    RnonCO2[	364	]=	-8.77821E-01	;
    RnonCO2[	365	]=	-8.72529E-01	;
    RnonCO2[	366	]=	-8.67220E-01	;
    RnonCO2[	367	]=	-8.61893E-01	;
    RnonCO2[	368	]=	-8.56548E-01	;
    RnonCO2[	369	]=	-8.51186E-01	;
    RnonCO2[	370	]=	-8.45805E-01	;
    RnonCO2[	371	]=	-8.40406E-01	;
    RnonCO2[	372	]=	-8.34989E-01	;
    RnonCO2[	373	]=	-8.29553E-01	;
    RnonCO2[	374	]=	-8.24099E-01	;
    RnonCO2[	375	]=	-8.18625E-01	;
    RnonCO2[	376	]=	-8.13133E-01	;
    RnonCO2[	377	]=	-8.07621E-01	;
    RnonCO2[	378	]=	-8.02090E-01	;
    RnonCO2[	379	]=	-7.96539E-01	;
    RnonCO2[	380	]=	-7.90969E-01	;
    RnonCO2[	381	]=	-7.85379E-01	;
    RnonCO2[	382	]=	-7.79768E-01	;
    RnonCO2[	383	]=	-7.74138E-01	;
    RnonCO2[	384	]=	-7.68487E-01	;
    RnonCO2[	385	]=	-7.62816E-01	;
    RnonCO2[	386	]=	-7.57124E-01	;
    RnonCO2[	387	]=	-7.51411E-01	;
    RnonCO2[	388	]=	-7.45677E-01	;
    RnonCO2[	389	]=	-7.39921E-01	;
    RnonCO2[	390	]=	-7.34145E-01	;
    RnonCO2[	391	]=	-7.28346E-01	;
    RnonCO2[	392	]=	-7.22525E-01	;
    RnonCO2[	393	]=	-7.16683E-01	;
    RnonCO2[	394	]=	-7.10818E-01	;
    RnonCO2[	395	]=	-7.04930E-01	;
    RnonCO2[	396	]=	-6.99020E-01	;
    RnonCO2[	397	]=	-6.93087E-01	;
    RnonCO2[	398	]=	-6.87131E-01	;
    RnonCO2[	399	]=	-6.81151E-01	;
    RnonCO2[	400	]=	-6.75148E-01	;
    RnonCO2[	401	]=	-6.69121E-01	;
    RnonCO2[	402	]=	-6.63069E-01	;
    RnonCO2[	403	]=	-6.56994E-01	;
    RnonCO2[	404	]=	-6.50894E-01	;
    RnonCO2[	405	]=	-6.44769E-01	;
    RnonCO2[	406	]=	-6.38619E-01	;
    RnonCO2[	407	]=	-6.32443E-01	;
    RnonCO2[	408	]=	-6.26242E-01	;
    RnonCO2[	409	]=	-6.20016E-01	;
    RnonCO2[	410	]=	-6.13763E-01	;
    RnonCO2[	411	]=	-6.07484E-01	;
    RnonCO2[	412	]=	-6.01178E-01	;
    RnonCO2[	413	]=	-5.94846E-01	;
    RnonCO2[	414	]=	-5.88486E-01	;
    RnonCO2[	415	]=	-5.82099E-01	;
    RnonCO2[	416	]=	-5.75685E-01	;
    RnonCO2[	417	]=	-5.69242E-01	;
    RnonCO2[	418	]=	-5.62772E-01	;
    RnonCO2[	419	]=	-5.56273E-01	;
    RnonCO2[	420	]=	-5.49745E-01	;
    RnonCO2[	421	]=	-5.43188E-01	;
    RnonCO2[	422	]=	-5.36601E-01	;
    RnonCO2[	423	]=	-5.29985E-01	;
    RnonCO2[	424	]=	-5.23339E-01	;
    RnonCO2[	425	]=	-5.16662E-01	;
    RnonCO2[	426	]=	-5.09954E-01	;
    RnonCO2[	427	]=	-5.03215E-01	;
    RnonCO2[	428	]=	-4.96445E-01	;
    RnonCO2[	429	]=	-4.89643E-01	;
    RnonCO2[	430	]=	-4.82809E-01	;
    RnonCO2[	431	]=	-4.75942E-01	;
    RnonCO2[	432	]=	-4.69042E-01	;
    RnonCO2[	433	]=	-4.62109E-01	;
    RnonCO2[	434	]=	-4.55143E-01	;
    RnonCO2[	435	]=	-4.48143E-01	;
    RnonCO2[	436	]=	-4.41108E-01	;
    RnonCO2[	437	]=	-4.34039E-01	;
    RnonCO2[	438	]=	-4.26934E-01	;
    RnonCO2[	439	]=	-4.19794E-01	;
    RnonCO2[	440	]=	-4.12618E-01	;
    RnonCO2[	441	]=	-4.05405E-01	;
    RnonCO2[	442	]=	-3.98156E-01	;
    RnonCO2[	443	]=	-3.90869E-01	;
    RnonCO2[	444	]=	-3.83544E-01	;
    RnonCO2[	445	]=	-3.76181E-01	;
    RnonCO2[	446	]=	-3.68780E-01	;
    RnonCO2[	447	]=	-3.61339E-01	;
    RnonCO2[	448	]=	-3.53859E-01	;
    RnonCO2[	449	]=	-3.46338E-01	;
    RnonCO2[	450	]=	-3.38777E-01	;
    RnonCO2[	451	]=	-3.31175E-01	;
    RnonCO2[	452	]=	-3.23530E-01	;
    RnonCO2[	453	]=	-3.15844E-01	;
    RnonCO2[	454	]=	-3.08115E-01	;
    RnonCO2[	455	]=	-3.00343E-01	;
    RnonCO2[	456	]=	-2.92526E-01	;
    RnonCO2[	457	]=	-2.84665E-01	;
    RnonCO2[	458	]=	-2.76759E-01	;
    RnonCO2[	459	]=	-2.68807E-01	;
    RnonCO2[	460	]=	-2.60809E-01	;
    RnonCO2[	461	]=	-2.52764E-01	;
    RnonCO2[	462	]=	-2.44672E-01	;
    RnonCO2[	463	]=	-2.36531E-01	;
    RnonCO2[	464	]=	-2.28342E-01	;
    RnonCO2[	465	]=	-2.20103E-01	;
    RnonCO2[	466	]=	-2.11814E-01	;
    RnonCO2[	467	]=	-2.03474E-01	;
    RnonCO2[	468	]=	-1.95083E-01	;
    RnonCO2[	469	]=	-1.86639E-01	;
    RnonCO2[	470	]=	-1.78142E-01	;
    RnonCO2[	471	]=	-1.69592E-01	;
    RnonCO2[	472	]=	-1.60986E-01	;
    RnonCO2[	473	]=	-1.52326E-01	;
    RnonCO2[	474	]=	-1.43608E-01	;
    RnonCO2[	475	]=	-1.34834E-01	;
    RnonCO2[	476	]=	-1.26002E-01	;
    RnonCO2[	477	]=	-1.17111E-01	;
    RnonCO2[	478	]=	-1.08161E-01	;
    RnonCO2[	479	]=	-9.91496E-02	;
    RnonCO2[	480	]=	-9.00767E-02	;
    RnonCO2[	481	]=	-8.09414E-02	;
    RnonCO2[	482	]=	-7.17425E-02	;
    RnonCO2[	483	]=	-6.24791E-02	;
    RnonCO2[	484	]=	-5.31502E-02	;
    RnonCO2[	485	]=	-4.37547E-02	;
    RnonCO2[	486	]=	-4.37547E-02	;
    RnonCO2[	487	]=	-4.37547E-02	;
    RnonCO2[	488	]=	-4.37547E-02	;
    RnonCO2[	489	]=	-4.37547E-02	;
    RnonCO2[	490	]=	-4.37547E-02	;
    RnonCO2[	491	]=	-4.37547E-02	;
    RnonCO2[	492	]=	-4.37547E-02	;
    RnonCO2[	493	]=	-4.37547E-02	;
    RnonCO2[	494	]=	-4.37547E-02	;
    RnonCO2[	495	]=	-4.37547E-02	;
    RnonCO2[	496	]=	-4.37547E-02	;
    RnonCO2[	497	]=	-4.37547E-02	;
    RnonCO2[	498	]=	-4.37547E-02	;
    RnonCO2[	499	]=	-4.37547E-02	;
    RnonCO2[	500	]=	-4.37547E-02	;
    RnonCO2[	501	]=	-4.37547E-02	;
    RnonCO2[	502	]=	-4.37547E-02	;
    RnonCO2[	503	]=	-4.37547E-02	;
    RnonCO2[	504	]=	-4.37547E-02	;
    RnonCO2[	505	]=	-4.37547E-02	;
    RnonCO2[	506	]=	-4.37547E-02	;
    RnonCO2[	507	]=	-4.37547E-02	;
    RnonCO2[	508	]=	-4.37547E-02	;
    RnonCO2[	509	]=	-4.37547E-02	;
    RnonCO2[	510	]=	-4.37547E-02	;
    RnonCO2[	511	]=	-4.37547E-02	;
    RnonCO2[	512	]=	-4.37547E-02	;
    RnonCO2[	513	]=	-4.37547E-02	;
    RnonCO2[	514	]=	-4.37547E-02	;
    RnonCO2[	515	]=	-4.37547E-02	;
    RnonCO2[	516	]=	-4.37547E-02	;
    RnonCO2[	517	]=	-4.37547E-02	;
    RnonCO2[	518	]=	-4.37547E-02	;
    RnonCO2[	519	]=	-4.37547E-02	;
    RnonCO2[	520	]=	-4.37547E-02	;
    RnonCO2[	521	]=	-4.37547E-02	;
    RnonCO2[	522	]=	-4.37547E-02	;
    RnonCO2[	523	]=	-4.37547E-02	;
    RnonCO2[	524	]=	-4.37547E-02	;
    RnonCO2[	525	]=	-4.37547E-02	;
    RnonCO2[	526	]=	-4.37547E-02	;
    RnonCO2[	527	]=	-4.37547E-02	;
    RnonCO2[	528	]=	-4.37547E-02	;
    RnonCO2[	529	]=	-4.37547E-02	;
    RnonCO2[	530	]=	-4.37547E-02	;
    RnonCO2[	531	]=	-4.37547E-02	;
    RnonCO2[	532	]=	-4.37547E-02	;
    RnonCO2[	533	]=	-4.37547E-02	;
    RnonCO2[	534	]=	-4.37547E-02	;
    RnonCO2[	535	]=	-4.37547E-02	;
    RnonCO2[	536	]=	-4.37547E-02	;
    RnonCO2[	537	]=	-4.37547E-02	;
    RnonCO2[	538	]=	-4.37547E-02	;
    RnonCO2[	539	]=	-4.37547E-02	;
    RnonCO2[	540	]=	-4.37547E-02	;
    RnonCO2[	541	]=	-4.37547E-02	;
    RnonCO2[	542	]=	-4.37547E-02	;
    RnonCO2[	543	]=	-4.37547E-02	;
    RnonCO2[	544	]=	-4.37547E-02	;
    RnonCO2[	545	]=	-4.37547E-02	;
    RnonCO2[	546	]=	-4.37547E-02	;
    RnonCO2[	547	]=	-4.37547E-02	;
    RnonCO2[	548	]=	-4.37547E-02	;
    RnonCO2[	549	]=	-4.37547E-02	;
    RnonCO2[	550	]=	-4.37547E-02	;
    RnonCO2[	551	]=	-4.37547E-02	;
    RnonCO2[	552	]=	-4.37547E-02	;
    RnonCO2[	553	]=	-4.37547E-02	;
    RnonCO2[	554	]=	-4.37547E-02	;
    RnonCO2[	555	]=	-4.37547E-02	;
    RnonCO2[	556	]=	-4.37547E-02	;
    RnonCO2[	557	]=	-4.37547E-02	;
    RnonCO2[	558	]=	-4.37547E-02	;
    RnonCO2[	559	]=	-4.37547E-02	;
    RnonCO2[	560	]=	-4.37547E-02	;
    RnonCO2[	561	]=	-4.37547E-02	;
    RnonCO2[	562	]=	-4.37547E-02	;
    RnonCO2[	563	]=	-4.37547E-02	;
    RnonCO2[	564	]=	-4.37547E-02	;
    RnonCO2[	565	]=	-4.37547E-02	;
    RnonCO2[	566	]=	-4.37547E-02	;
    RnonCO2[	567	]=	-4.37547E-02	;
    RnonCO2[	568	]=	-4.37547E-02	;
    RnonCO2[	569	]=	-4.37547E-02	;
    RnonCO2[	570	]=	-4.37547E-02	;
    RnonCO2[	571	]=	-4.37547E-02	;
    RnonCO2[	572	]=	-4.37547E-02	;
    RnonCO2[	573	]=	-4.37547E-02	;
    RnonCO2[	574	]=	-4.37547E-02	;
    RnonCO2[	575	]=	-4.37547E-02	;
    RnonCO2[	576	]=	-4.37547E-02	;
    RnonCO2[	577	]=	-4.37547E-02	;
    RnonCO2[	578	]=	-4.37547E-02	;
    RnonCO2[	579	]=	-4.37547E-02	;
    RnonCO2[	580	]=	-4.37547E-02	;
    RnonCO2[	581	]=	-4.37547E-02	;
    RnonCO2[	582	]=	-4.37547E-02	;
    RnonCO2[	583	]=	-4.37547E-02	;
    RnonCO2[	584	]=	-4.37547E-02	;
    RnonCO2[	585	]=	-4.37547E-02	;
    RnonCO2[	586	]=	-4.37547E-02	;
    RnonCO2[	587	]=	-4.37547E-02	;
    RnonCO2[	588	]=	-4.37547E-02	;
    RnonCO2[	589	]=	-4.37547E-02	;
    RnonCO2[	590	]=	-4.37547E-02	;
    RnonCO2[	591	]=	-4.37547E-02	;
    RnonCO2[	592	]=	-4.37547E-02	;
    RnonCO2[	593	]=	-4.37547E-02	;
    RnonCO2[	594	]=	-4.37547E-02	;
    RnonCO2[	595	]=	-4.37547E-02	;
    RnonCO2[	596	]=	-4.37547E-02	;
    RnonCO2[	597	]=	-4.37547E-02	;
    RnonCO2[	598	]=	-4.37547E-02	;
    RnonCO2[	599	]=	-4.37547E-02	;
    RnonCO2[	600	]=	-4.37547E-02	;
    RnonCO2[	601	]=	-4.37547E-02	;
    RnonCO2[	602	]=	-4.37547E-02	;
    RnonCO2[	603	]=	-4.37547E-02	;
    RnonCO2[	604	]=	-4.37547E-02	;
    RnonCO2[	605	]=	-4.37547E-02	;
    RnonCO2[	606	]=	-4.37547E-02	;
    RnonCO2[	607	]=	-4.37547E-02	;
    RnonCO2[	608	]=	-4.37547E-02	;
    RnonCO2[	609	]=	-4.37547E-02	;
    RnonCO2[	610	]=	-4.37547E-02	;
    RnonCO2[	611	]=	-4.37547E-02	;
    RnonCO2[	612	]=	-4.37547E-02	;
    RnonCO2[	613	]=	-4.37547E-02	;
    RnonCO2[	614	]=	-4.37547E-02	;
    RnonCO2[	615	]=	-4.37547E-02	;
    RnonCO2[	616	]=	-4.37547E-02	;
    RnonCO2[	617	]=	-4.37547E-02	;
    RnonCO2[	618	]=	-4.37547E-02	;
    RnonCO2[	619	]=	-4.37547E-02	;
    RnonCO2[	620	]=	-4.37547E-02	;
    RnonCO2[	621	]=	-4.37547E-02	;
    RnonCO2[	622	]=	-4.37547E-02	;
    RnonCO2[	623	]=	-4.37547E-02	;
    RnonCO2[	624	]=	-4.37547E-02	;
    RnonCO2[	625	]=	-4.37547E-02	;
    RnonCO2[	626	]=	-4.37547E-02	;
    RnonCO2[	627	]=	-4.37547E-02	;
    RnonCO2[	628	]=	-4.37547E-02	;
    RnonCO2[	629	]=	-4.37547E-02	;
    RnonCO2[	630	]=	-4.37547E-02	;
    RnonCO2[	631	]=	-4.37547E-02	;
    RnonCO2[	632	]=	-4.37547E-02	;
    RnonCO2[	633	]=	-4.37547E-02	;
    RnonCO2[	634	]=	-4.37547E-02	;
    RnonCO2[	635	]=	-4.37547E-02	;
    RnonCO2[	636	]=	-4.37547E-02	;
    RnonCO2[	637	]=	-4.37547E-02	;
    RnonCO2[	638	]=	-4.37547E-02	;
    RnonCO2[	639	]=	-4.37547E-02	;
    RnonCO2[	640	]=	-4.37547E-02	;
    RnonCO2[	641	]=	-4.37547E-02	;
    RnonCO2[	642	]=	-4.37547E-02	;
    RnonCO2[	643	]=	-4.37547E-02	;
    RnonCO2[	644	]=	-4.37547E-02	;
    RnonCO2[	645	]=	-4.37547E-02	;
    RnonCO2[	646	]=	-4.37547E-02	;
    RnonCO2[	647	]=	-4.37547E-02	;
    RnonCO2[	648	]=	-4.37547E-02	;
    RnonCO2[	649	]=	-4.37547E-02	;
    RnonCO2[	650	]=	-4.37547E-02	;
    RnonCO2[	651	]=	-4.37547E-02	;
    RnonCO2[	652	]=	-4.37547E-02	;
    RnonCO2[	653	]=	-4.37547E-02	;
    RnonCO2[	654	]=	-4.37547E-02	;
    RnonCO2[	655	]=	-4.37547E-02	;
    RnonCO2[	656	]=	-4.37547E-02	;
    RnonCO2[	657	]=	-4.37547E-02	;
    RnonCO2[	658	]=	-4.37547E-02	;
    RnonCO2[	659	]=	-4.37547E-02	;
    RnonCO2[	660	]=	-4.37547E-02	;
    RnonCO2[	661	]=	-4.37547E-02	;
    RnonCO2[	662	]=	-4.37547E-02	;
    RnonCO2[	663	]=	-4.37547E-02	;
    RnonCO2[	664	]=	-4.37547E-02	;
    RnonCO2[	665	]=	-4.37547E-02	;
    RnonCO2[	666	]=	-4.37547E-02	;
    RnonCO2[	667	]=	-4.37547E-02	;
    RnonCO2[	668	]=	-4.37547E-02	;
    RnonCO2[	669	]=	-4.37547E-02	;
    RnonCO2[	670	]=	-4.37547E-02	;
    RnonCO2[	671	]=	-4.37547E-02	;
    RnonCO2[	672	]=	-4.37547E-02	;
    RnonCO2[	673	]=	-4.37547E-02	;
    RnonCO2[	674	]=	-4.37547E-02	;
    RnonCO2[	675	]=	-4.37547E-02	;
    RnonCO2[	676	]=	-4.37547E-02	;
    RnonCO2[	677	]=	-4.37547E-02	;
    RnonCO2[	678	]=	-4.37547E-02	;
    RnonCO2[	679	]=	-4.37547E-02	;
    RnonCO2[	680	]=	-4.37547E-02	;
    RnonCO2[	681	]=	-4.37547E-02	;
    RnonCO2[	682	]=	-4.37547E-02	;
    RnonCO2[	683	]=	-4.37547E-02	;
    RnonCO2[	684	]=	-4.37547E-02	;
    RnonCO2[	685	]=	-4.37547E-02	;
    RnonCO2[	686	]=	-4.37547E-02	;
    RnonCO2[	687	]=	-4.37547E-02	;
    RnonCO2[	688	]=	-4.37547E-02	;
    RnonCO2[	689	]=	-4.37547E-02	;
    RnonCO2[	690	]=	-4.37547E-02	;
    RnonCO2[	691	]=	-4.37547E-02	;
    RnonCO2[	692	]=	-4.37547E-02	;
    RnonCO2[	693	]=	-4.37547E-02	;
    RnonCO2[	694	]=	-4.37547E-02	;
    RnonCO2[	695	]=	-4.37547E-02	;
    RnonCO2[	696	]=	-4.37547E-02	;
    RnonCO2[	697	]=	-4.37547E-02	;
    RnonCO2[	698	]=	-4.37547E-02	;
    RnonCO2[	699	]=	-4.37547E-02	;
    RnonCO2[	700	]=	-4.37547E-02	;
    RnonCO2[	701	]=	-4.37547E-02	;
    RnonCO2[	702	]=	-4.37547E-02	;
    RnonCO2[	703	]=	-4.37547E-02	;
    RnonCO2[	704	]=	-4.37547E-02	;
    RnonCO2[	705	]=	-4.37547E-02	;
    RnonCO2[	706	]=	-4.37547E-02	;
    RnonCO2[	707	]=	-4.37547E-02	;
    RnonCO2[	708	]=	-4.37547E-02	;
    RnonCO2[	709	]=	-4.37547E-02	;
    RnonCO2[	710	]=	-4.37547E-02	;
    RnonCO2[	711	]=	-4.37547E-02	;
    RnonCO2[	712	]=	-4.37547E-02	;
    RnonCO2[	713	]=	-4.37547E-02	;
    RnonCO2[	714	]=	-4.37547E-02	;
    RnonCO2[	715	]=	-4.37547E-02	;
    RnonCO2[	716	]=	-4.37547E-02	;
    RnonCO2[	717	]=	-4.37547E-02	;
    RnonCO2[	718	]=	-4.37547E-02	;
    RnonCO2[	719	]=	-4.37547E-02	;
    RnonCO2[	720	]=	-4.37547E-02	;
    RnonCO2[	721	]=	-4.37547E-02	;
    RnonCO2[	722	]=	-4.37547E-02	;
    RnonCO2[	723	]=	-4.37547E-02	;
    RnonCO2[	724	]=	-4.37547E-02	;
    RnonCO2[	725	]=	-4.37547E-02	;
    RnonCO2[	726	]=	-4.37547E-02	;
    RnonCO2[	727	]=	-4.37547E-02	;
    RnonCO2[	728	]=	-4.37547E-02	;
    RnonCO2[	729	]=	-4.37547E-02	;
    RnonCO2[	730	]=	-4.37547E-02	;
    RnonCO2[	731	]=	-4.37547E-02	;
    RnonCO2[	732	]=	-4.37547E-02	;
    RnonCO2[	733	]=	-4.37547E-02	;
    RnonCO2[	734	]=	-4.37547E-02	;
    RnonCO2[	735	]=	-4.37547E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp370lowNTCF(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07201E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09063E+00	;
    RnonCO2[	253	]=	1.09885E+00	;
    RnonCO2[	254	]=	1.10713E+00	;
    RnonCO2[	255	]=	1.11533E+00	;
    RnonCO2[	256	]=	1.12348E+00	;
    RnonCO2[	257	]=	1.13025E+00	;
    RnonCO2[	258	]=	1.13446E+00	;
    RnonCO2[	259	]=	1.13641E+00	;
    RnonCO2[	260	]=	1.13633E+00	;
    RnonCO2[	261	]=	1.13440E+00	;
    RnonCO2[	262	]=	1.13061E+00	;
    RnonCO2[	263	]=	1.12497E+00	;
    RnonCO2[	264	]=	1.11766E+00	;
    RnonCO2[	265	]=	1.10885E+00	;
    RnonCO2[	266	]=	1.09865E+00	;
    RnonCO2[	267	]=	1.08771E+00	;
    RnonCO2[	268	]=	1.07670E+00	;
    RnonCO2[	269	]=	1.06569E+00	;
    RnonCO2[	270	]=	1.05474E+00	;
    RnonCO2[	271	]=	1.04390E+00	;
    RnonCO2[	272	]=	1.03322E+00	;
    RnonCO2[	273	]=	1.02270E+00	;
    RnonCO2[	274	]=	1.01238E+00	;
    RnonCO2[	275	]=	1.00224E+00	;
    RnonCO2[	276	]=	9.92304E-01	;
    RnonCO2[	277	]=	9.82836E-01	;
    RnonCO2[	278	]=	9.74111E-01	;
    RnonCO2[	279	]=	9.66081E-01	;
    RnonCO2[	280	]=	9.58722E-01	;
    RnonCO2[	281	]=	9.51999E-01	;
    RnonCO2[	282	]=	9.45878E-01	;
    RnonCO2[	283	]=	9.40328E-01	;
    RnonCO2[	284	]=	9.35315E-01	;
    RnonCO2[	285	]=	9.30813E-01	;
    RnonCO2[	286	]=	9.26788E-01	;
    RnonCO2[	287	]=	9.23247E-01	;
    RnonCO2[	288	]=	9.20206E-01	;
    RnonCO2[	289	]=	9.17631E-01	;
    RnonCO2[	290	]=	9.15499E-01	;
    RnonCO2[	291	]=	9.13781E-01	;
    RnonCO2[	292	]=	9.12449E-01	;
    RnonCO2[	293	]=	9.11486E-01	;
    RnonCO2[	294	]=	9.10859E-01	;
    RnonCO2[	295	]=	9.10550E-01	;
    RnonCO2[	296	]=	9.10537E-01	;
    RnonCO2[	297	]=	9.10738E-01	;
    RnonCO2[	298	]=	9.11068E-01	;
    RnonCO2[	299	]=	9.11523E-01	;
    RnonCO2[	300	]=	9.12083E-01	;
    RnonCO2[	301	]=	9.12743E-01	;
    RnonCO2[	302	]=	9.13504E-01	;
    RnonCO2[	303	]=	9.14360E-01	;
    RnonCO2[	304	]=	9.15295E-01	;
    RnonCO2[	305	]=	9.16307E-01	;
    RnonCO2[	306	]=	9.17395E-01	;
    RnonCO2[	307	]=	9.18683E-01	;
    RnonCO2[	308	]=	9.20277E-01	;
    RnonCO2[	309	]=	9.22161E-01	;
    RnonCO2[	310	]=	9.24313E-01	;
    RnonCO2[	311	]=	9.26706E-01	;
    RnonCO2[	312	]=	9.29330E-01	;
    RnonCO2[	313	]=	9.32166E-01	;
    RnonCO2[	314	]=	9.35197E-01	;
    RnonCO2[	315	]=	9.38406E-01	;
    RnonCO2[	316	]=	9.41781E-01	;
    RnonCO2[	317	]=	9.45255E-01	;
    RnonCO2[	318	]=	9.48764E-01	;
    RnonCO2[	319	]=	9.52314E-01	;
    RnonCO2[	320	]=	9.55893E-01	;
    RnonCO2[	321	]=	9.59502E-01	;
    RnonCO2[	322	]=	9.63144E-01	;
    RnonCO2[	323	]=	9.66805E-01	;
    RnonCO2[	324	]=	9.70493E-01	;
    RnonCO2[	325	]=	9.74205E-01	;
    RnonCO2[	326	]=	9.77939E-01	;
    RnonCO2[	327	]=	9.81742E-01	;
    RnonCO2[	328	]=	9.85647E-01	;
    RnonCO2[	329	]=	9.89656E-01	;
    RnonCO2[	330	]=	9.93751E-01	;
    RnonCO2[	331	]=	9.97928E-01	;
    RnonCO2[	332	]=	1.00218E+00	;
    RnonCO2[	333	]=	1.00650E+00	;
    RnonCO2[	334	]=	1.01089E+00	;
    RnonCO2[	335	]=	1.01534E+00	;
    RnonCO2[	336	]=	1.01984E+00	;
    RnonCO2[	337	]=	1.02422E+00	;
    RnonCO2[	338	]=	1.02831E+00	;
    RnonCO2[	339	]=	1.03215E+00	;
    RnonCO2[	340	]=	1.03573E+00	;
    RnonCO2[	341	]=	1.03909E+00	;
    RnonCO2[	342	]=	1.04223E+00	;
    RnonCO2[	343	]=	1.04517E+00	;
    RnonCO2[	344	]=	1.04793E+00	;
    RnonCO2[	345	]=	1.05051E+00	;
    RnonCO2[	346	]=	1.05293E+00	;
    RnonCO2[	347	]=	1.05519E+00	;
    RnonCO2[	348	]=	1.05731E+00	;
    RnonCO2[	349	]=	1.05928E+00	;
    RnonCO2[	350	]=	1.06113E+00	;
    RnonCO2[	351	]=	1.06286E+00	;
    RnonCO2[	352	]=	1.06447E+00	;
    RnonCO2[	353	]=	1.06597E+00	;
    RnonCO2[	354	]=	1.06737E+00	;
    RnonCO2[	355	]=	1.06868E+00	;
    RnonCO2[	356	]=	1.06989E+00	;
    RnonCO2[	357	]=	1.07101E+00	;
    RnonCO2[	358	]=	1.07205E+00	;
    RnonCO2[	359	]=	1.07301E+00	;
    RnonCO2[	360	]=	1.07389E+00	;
    RnonCO2[	361	]=	1.07470E+00	;
    RnonCO2[	362	]=	1.07544E+00	;
    RnonCO2[	363	]=	1.07612E+00	;
    RnonCO2[	364	]=	1.07674E+00	;
    RnonCO2[	365	]=	1.07729E+00	;
    RnonCO2[	366	]=	1.07779E+00	;
    RnonCO2[	367	]=	1.07823E+00	;
    RnonCO2[	368	]=	1.07862E+00	;
    RnonCO2[	369	]=	1.07895E+00	;
    RnonCO2[	370	]=	1.07925E+00	;
    RnonCO2[	371	]=	1.07949E+00	;
    RnonCO2[	372	]=	1.07968E+00	;
    RnonCO2[	373	]=	1.07984E+00	;
    RnonCO2[	374	]=	1.07995E+00	;
    RnonCO2[	375	]=	1.08003E+00	;
    RnonCO2[	376	]=	1.08006E+00	;
    RnonCO2[	377	]=	1.08005E+00	;
    RnonCO2[	378	]=	1.08001E+00	;
    RnonCO2[	379	]=	1.07993E+00	;
    RnonCO2[	380	]=	1.07982E+00	;
    RnonCO2[	381	]=	1.07968E+00	;
    RnonCO2[	382	]=	1.07950E+00	;
    RnonCO2[	383	]=	1.07929E+00	;
    RnonCO2[	384	]=	1.07905E+00	;
    RnonCO2[	385	]=	1.07879E+00	;
    RnonCO2[	386	]=	1.07849E+00	;
    RnonCO2[	387	]=	1.07816E+00	;
    RnonCO2[	388	]=	1.07782E+00	;
    RnonCO2[	389	]=	1.07744E+00	;
    RnonCO2[	390	]=	1.07703E+00	;
    RnonCO2[	391	]=	1.07660E+00	;
    RnonCO2[	392	]=	1.07615E+00	;
    RnonCO2[	393	]=	1.07567E+00	;
    RnonCO2[	394	]=	1.07518E+00	;
    RnonCO2[	395	]=	1.07465E+00	;
    RnonCO2[	396	]=	1.07410E+00	;
    RnonCO2[	397	]=	1.07353E+00	;
    RnonCO2[	398	]=	1.07295E+00	;
    RnonCO2[	399	]=	1.07233E+00	;
    RnonCO2[	400	]=	1.07171E+00	;
    RnonCO2[	401	]=	1.07105E+00	;
    RnonCO2[	402	]=	1.07038E+00	;
    RnonCO2[	403	]=	1.06969E+00	;
    RnonCO2[	404	]=	1.06898E+00	;
    RnonCO2[	405	]=	1.06825E+00	;
    RnonCO2[	406	]=	1.06751E+00	;
    RnonCO2[	407	]=	1.06675E+00	;
    RnonCO2[	408	]=	1.06597E+00	;
    RnonCO2[	409	]=	1.06516E+00	;
    RnonCO2[	410	]=	1.06435E+00	;
    RnonCO2[	411	]=	1.06352E+00	;
    RnonCO2[	412	]=	1.06267E+00	;
    RnonCO2[	413	]=	1.06180E+00	;
    RnonCO2[	414	]=	1.06092E+00	;
    RnonCO2[	415	]=	1.06003E+00	;
    RnonCO2[	416	]=	1.05912E+00	;
    RnonCO2[	417	]=	1.05819E+00	;
    RnonCO2[	418	]=	1.05725E+00	;
    RnonCO2[	419	]=	1.05629E+00	;
    RnonCO2[	420	]=	1.05532E+00	;
    RnonCO2[	421	]=	1.05433E+00	;
    RnonCO2[	422	]=	1.05333E+00	;
    RnonCO2[	423	]=	1.05232E+00	;
    RnonCO2[	424	]=	1.05129E+00	;
    RnonCO2[	425	]=	1.05025E+00	;
    RnonCO2[	426	]=	1.04920E+00	;
    RnonCO2[	427	]=	1.04813E+00	;
    RnonCO2[	428	]=	1.04705E+00	;
    RnonCO2[	429	]=	1.04596E+00	;
    RnonCO2[	430	]=	1.04485E+00	;
    RnonCO2[	431	]=	1.04373E+00	;
    RnonCO2[	432	]=	1.04260E+00	;
    RnonCO2[	433	]=	1.04146E+00	;
    RnonCO2[	434	]=	1.04031E+00	;
    RnonCO2[	435	]=	1.03914E+00	;
    RnonCO2[	436	]=	1.03796E+00	;
    RnonCO2[	437	]=	1.03677E+00	;
    RnonCO2[	438	]=	1.03557E+00	;
    RnonCO2[	439	]=	1.03436E+00	;
    RnonCO2[	440	]=	1.03314E+00	;
    RnonCO2[	441	]=	1.03190E+00	;
    RnonCO2[	442	]=	1.03065E+00	;
    RnonCO2[	443	]=	1.02940E+00	;
    RnonCO2[	444	]=	1.02813E+00	;
    RnonCO2[	445	]=	1.02685E+00	;
    RnonCO2[	446	]=	1.02556E+00	;
    RnonCO2[	447	]=	1.02426E+00	;
    RnonCO2[	448	]=	1.02295E+00	;
    RnonCO2[	449	]=	1.02164E+00	;
    RnonCO2[	450	]=	1.02030E+00	;
    RnonCO2[	451	]=	1.01896E+00	;
    RnonCO2[	452	]=	1.01761E+00	;
    RnonCO2[	453	]=	1.01625E+00	;
    RnonCO2[	454	]=	1.01488E+00	;
    RnonCO2[	455	]=	1.01350E+00	;
    RnonCO2[	456	]=	1.01211E+00	;
    RnonCO2[	457	]=	1.01071E+00	;
    RnonCO2[	458	]=	1.00930E+00	;
    RnonCO2[	459	]=	1.00788E+00	;
    RnonCO2[	460	]=	1.00646E+00	;
    RnonCO2[	461	]=	1.00503E+00	;
    RnonCO2[	462	]=	1.00358E+00	;
    RnonCO2[	463	]=	1.00213E+00	;
    RnonCO2[	464	]=	1.00066E+00	;
    RnonCO2[	465	]=	9.99190E-01	;
    RnonCO2[	466	]=	9.97712E-01	;
    RnonCO2[	467	]=	9.96223E-01	;
    RnonCO2[	468	]=	9.94721E-01	;
    RnonCO2[	469	]=	9.93216E-01	;
    RnonCO2[	470	]=	9.91702E-01	;
    RnonCO2[	471	]=	9.90173E-01	;
    RnonCO2[	472	]=	9.88643E-01	;
    RnonCO2[	473	]=	9.87101E-01	;
    RnonCO2[	474	]=	9.85554E-01	;
    RnonCO2[	475	]=	9.83991E-01	;
    RnonCO2[	476	]=	9.82425E-01	;
    RnonCO2[	477	]=	9.80851E-01	;
    RnonCO2[	478	]=	9.79270E-01	;
    RnonCO2[	479	]=	9.77680E-01	;
    RnonCO2[	480	]=	9.76082E-01	;
    RnonCO2[	481	]=	9.74474E-01	;
    RnonCO2[	482	]=	9.72858E-01	;
    RnonCO2[	483	]=	9.71238E-01	;
    RnonCO2[	484	]=	9.69607E-01	;
    RnonCO2[	485	]=	9.67973E-01	;
    RnonCO2[	486	]=	9.66325E-01	;
    RnonCO2[	487	]=	9.64726E-01	;
    RnonCO2[	488	]=	9.63210E-01	;
    RnonCO2[	489	]=	9.61764E-01	;
    RnonCO2[	490	]=	9.60389E-01	;
    RnonCO2[	491	]=	9.59078E-01	;
    RnonCO2[	492	]=	9.57828E-01	;
    RnonCO2[	493	]=	9.56633E-01	;
    RnonCO2[	494	]=	9.55493E-01	;
    RnonCO2[	495	]=	9.54401E-01	;
    RnonCO2[	496	]=	9.53350E-01	;
    RnonCO2[	497	]=	9.52347E-01	;
    RnonCO2[	498	]=	9.51385E-01	;
    RnonCO2[	499	]=	9.50461E-01	;
    RnonCO2[	500	]=	9.49571E-01	;
    RnonCO2[	501	]=	9.48721E-01	;
    RnonCO2[	502	]=	9.47898E-01	;
    RnonCO2[	503	]=	9.47110E-01	;
    RnonCO2[	504	]=	9.46348E-01	;
    RnonCO2[	505	]=	9.45611E-01	;
    RnonCO2[	506	]=	9.44904E-01	;
    RnonCO2[	507	]=	9.44222E-01	;
    RnonCO2[	508	]=	9.43558E-01	;
    RnonCO2[	509	]=	9.42919E-01	;
    RnonCO2[	510	]=	9.42306E-01	;
    RnonCO2[	511	]=	9.41706E-01	;
    RnonCO2[	512	]=	9.41127E-01	;
    RnonCO2[	513	]=	9.40570E-01	;
    RnonCO2[	514	]=	9.40027E-01	;
    RnonCO2[	515	]=	9.39502E-01	;
    RnonCO2[	516	]=	9.38991E-01	;
    RnonCO2[	517	]=	9.38496E-01	;
    RnonCO2[	518	]=	9.38018E-01	;
    RnonCO2[	519	]=	9.37550E-01	;
    RnonCO2[	520	]=	9.37100E-01	;
    RnonCO2[	521	]=	9.36661E-01	;
    RnonCO2[	522	]=	9.36233E-01	;
    RnonCO2[	523	]=	9.35817E-01	;
    RnonCO2[	524	]=	9.35411E-01	;
    RnonCO2[	525	]=	9.35016E-01	;
    RnonCO2[	526	]=	9.34632E-01	;
    RnonCO2[	527	]=	9.34257E-01	;
    RnonCO2[	528	]=	9.33890E-01	;
    RnonCO2[	529	]=	9.33537E-01	;
    RnonCO2[	530	]=	9.33190E-01	;
    RnonCO2[	531	]=	9.32849E-01	;
    RnonCO2[	532	]=	9.32520E-01	;
    RnonCO2[	533	]=	9.32197E-01	;
    RnonCO2[	534	]=	9.31885E-01	;
    RnonCO2[	535	]=	9.31574E-01	;
    RnonCO2[	536	]=	9.31276E-01	;
    RnonCO2[	537	]=	9.30978E-01	;
    RnonCO2[	538	]=	9.30693E-01	;
    RnonCO2[	539	]=	9.30409E-01	;
    RnonCO2[	540	]=	9.30135E-01	;
    RnonCO2[	541	]=	9.29863E-01	;
    RnonCO2[	542	]=	9.29600E-01	;
    RnonCO2[	543	]=	9.29344E-01	;
    RnonCO2[	544	]=	9.29088E-01	;
    RnonCO2[	545	]=	9.28841E-01	;
    RnonCO2[	546	]=	9.28600E-01	;
    RnonCO2[	547	]=	9.28357E-01	;
    RnonCO2[	548	]=	9.28124E-01	;
    RnonCO2[	549	]=	9.27894E-01	;
    RnonCO2[	550	]=	9.27669E-01	;
    RnonCO2[	551	]=	9.27444E-01	;
    RnonCO2[	552	]=	9.27229E-01	;
    RnonCO2[	553	]=	9.27016E-01	;
    RnonCO2[	554	]=	9.26805E-01	;
    RnonCO2[	555	]=	9.26601E-01	;
    RnonCO2[	556	]=	9.26397E-01	;
    RnonCO2[	557	]=	9.26199E-01	;
    RnonCO2[	558	]=	9.25997E-01	;
    RnonCO2[	559	]=	9.25805E-01	;
    RnonCO2[	560	]=	9.25614E-01	;
    RnonCO2[	561	]=	9.25426E-01	;
    RnonCO2[	562	]=	9.25247E-01	;
    RnonCO2[	563	]=	9.25067E-01	;
    RnonCO2[	564	]=	9.24887E-01	;
    RnonCO2[	565	]=	9.24709E-01	;
    RnonCO2[	566	]=	9.24536E-01	;
    RnonCO2[	567	]=	9.24363E-01	;
    RnonCO2[	568	]=	9.24192E-01	;
    RnonCO2[	569	]=	9.24030E-01	;
    RnonCO2[	570	]=	9.23865E-01	;
    RnonCO2[	571	]=	9.23701E-01	;
    RnonCO2[	572	]=	9.23543E-01	;
    RnonCO2[	573	]=	9.23384E-01	;
    RnonCO2[	574	]=	9.23226E-01	;
    RnonCO2[	575	]=	9.23073E-01	;
    RnonCO2[	576	]=	9.22918E-01	;
    RnonCO2[	577	]=	9.22771E-01	;
    RnonCO2[	578	]=	9.22620E-01	;
    RnonCO2[	579	]=	9.22475E-01	;
    RnonCO2[	580	]=	9.22331E-01	;
    RnonCO2[	581	]=	9.22183E-01	;
    RnonCO2[	582	]=	9.22044E-01	;
    RnonCO2[	583	]=	9.21904E-01	;
    RnonCO2[	584	]=	9.21764E-01	;
    RnonCO2[	585	]=	9.21629E-01	;
    RnonCO2[	586	]=	9.21493E-01	;
    RnonCO2[	587	]=	9.21353E-01	;
    RnonCO2[	588	]=	9.21219E-01	;
    RnonCO2[	589	]=	9.21088E-01	;
    RnonCO2[	590	]=	9.20957E-01	;
    RnonCO2[	591	]=	9.20829E-01	;
    RnonCO2[	592	]=	9.20701E-01	;
    RnonCO2[	593	]=	9.20572E-01	;
    RnonCO2[	594	]=	9.20445E-01	;
    RnonCO2[	595	]=	9.20319E-01	;
    RnonCO2[	596	]=	9.20197E-01	;
    RnonCO2[	597	]=	9.20072E-01	;
    RnonCO2[	598	]=	9.19953E-01	;
    RnonCO2[	599	]=	9.19831E-01	;
    RnonCO2[	600	]=	9.19707E-01	;
    RnonCO2[	601	]=	9.19590E-01	;
    RnonCO2[	602	]=	9.19474E-01	;
    RnonCO2[	603	]=	9.19352E-01	;
    RnonCO2[	604	]=	9.19238E-01	;
    RnonCO2[	605	]=	9.19123E-01	;
    RnonCO2[	606	]=	9.19010E-01	;
    RnonCO2[	607	]=	9.18890E-01	;
    RnonCO2[	608	]=	9.18779E-01	;
    RnonCO2[	609	]=	9.18666E-01	;
    RnonCO2[	610	]=	9.18555E-01	;
    RnonCO2[	611	]=	9.18444E-01	;
    RnonCO2[	612	]=	9.18333E-01	;
    RnonCO2[	613	]=	9.18222E-01	;
    RnonCO2[	614	]=	9.18112E-01	;
    RnonCO2[	615	]=	9.18008E-01	;
    RnonCO2[	616	]=	9.17901E-01	;
    RnonCO2[	617	]=	9.17791E-01	;
    RnonCO2[	618	]=	9.17688E-01	;
    RnonCO2[	619	]=	9.17580E-01	;
    RnonCO2[	620	]=	9.17479E-01	;
    RnonCO2[	621	]=	9.17371E-01	;
    RnonCO2[	622	]=	9.17268E-01	;
    RnonCO2[	623	]=	9.17161E-01	;
    RnonCO2[	624	]=	9.17061E-01	;
    RnonCO2[	625	]=	9.16961E-01	;
    RnonCO2[	626	]=	9.16854E-01	;
    RnonCO2[	627	]=	9.16753E-01	;
    RnonCO2[	628	]=	9.16653E-01	;
    RnonCO2[	629	]=	9.16554E-01	;
    RnonCO2[	630	]=	9.16455E-01	;
    RnonCO2[	631	]=	9.16355E-01	;
    RnonCO2[	632	]=	9.16257E-01	;
    RnonCO2[	633	]=	9.16158E-01	;
    RnonCO2[	634	]=	9.16058E-01	;
    RnonCO2[	635	]=	9.15960E-01	;
    RnonCO2[	636	]=	9.15868E-01	;
    RnonCO2[	637	]=	9.15769E-01	;
    RnonCO2[	638	]=	9.15671E-01	;
    RnonCO2[	639	]=	9.15578E-01	;
    RnonCO2[	640	]=	9.15479E-01	;
    RnonCO2[	641	]=	9.15387E-01	;
    RnonCO2[	642	]=	9.15289E-01	;
    RnonCO2[	643	]=	9.15198E-01	;
    RnonCO2[	644	]=	9.15106E-01	;
    RnonCO2[	645	]=	9.15007E-01	;
    RnonCO2[	646	]=	9.14916E-01	;
    RnonCO2[	647	]=	9.14823E-01	;
    RnonCO2[	648	]=	9.14732E-01	;
    RnonCO2[	649	]=	9.14640E-01	;
    RnonCO2[	650	]=	9.14549E-01	;
    RnonCO2[	651	]=	9.14458E-01	;
    RnonCO2[	652	]=	9.14365E-01	;
    RnonCO2[	653	]=	9.14275E-01	;
    RnonCO2[	654	]=	9.14182E-01	;
    RnonCO2[	655	]=	9.14091E-01	;
    RnonCO2[	656	]=	9.14005E-01	;
    RnonCO2[	657	]=	9.13914E-01	;
    RnonCO2[	658	]=	9.13824E-01	;
    RnonCO2[	659	]=	9.13736E-01	;
    RnonCO2[	660	]=	9.13647E-01	;
    RnonCO2[	661	]=	9.13560E-01	;
    RnonCO2[	662	]=	9.13469E-01	;
    RnonCO2[	663	]=	9.13383E-01	;
    RnonCO2[	664	]=	9.13298E-01	;
    RnonCO2[	665	]=	9.13206E-01	;
    RnonCO2[	666	]=	9.13121E-01	;
    RnonCO2[	667	]=	9.13034E-01	;
    RnonCO2[	668	]=	9.12948E-01	;
    RnonCO2[	669	]=	9.12862E-01	;
    RnonCO2[	670	]=	9.12776E-01	;
    RnonCO2[	671	]=	9.12691E-01	;
    RnonCO2[	672	]=	9.12604E-01	;
    RnonCO2[	673	]=	9.12519E-01	;
    RnonCO2[	674	]=	9.12432E-01	;
    RnonCO2[	675	]=	9.12346E-01	;
    RnonCO2[	676	]=	9.12265E-01	;
    RnonCO2[	677	]=	9.12179E-01	;
    RnonCO2[	678	]=	9.12094E-01	;
    RnonCO2[	679	]=	9.12014E-01	;
    RnonCO2[	680	]=	9.11927E-01	;
    RnonCO2[	681	]=	9.11847E-01	;
    RnonCO2[	682	]=	9.11760E-01	;
    RnonCO2[	683	]=	9.11679E-01	;
    RnonCO2[	684	]=	9.11598E-01	;
    RnonCO2[	685	]=	9.11512E-01	;
    RnonCO2[	686	]=	9.11431E-01	;
    RnonCO2[	687	]=	9.11349E-01	;
    RnonCO2[	688	]=	9.11269E-01	;
    RnonCO2[	689	]=	9.11187E-01	;
    RnonCO2[	690	]=	9.11107E-01	;
    RnonCO2[	691	]=	9.11026E-01	;
    RnonCO2[	692	]=	9.10944E-01	;
    RnonCO2[	693	]=	9.10863E-01	;
    RnonCO2[	694	]=	9.10782E-01	;
    RnonCO2[	695	]=	9.10699E-01	;
    RnonCO2[	696	]=	9.10618E-01	;
    RnonCO2[	697	]=	9.10541E-01	;
    RnonCO2[	698	]=	9.10461E-01	;
    RnonCO2[	699	]=	9.10379E-01	;
    RnonCO2[	700	]=	9.10302E-01	;
    RnonCO2[	701	]=	9.10220E-01	;
    RnonCO2[	702	]=	9.10143E-01	;
    RnonCO2[	703	]=	9.10062E-01	;
    RnonCO2[	704	]=	9.09983E-01	;
    RnonCO2[	705	]=	9.09907E-01	;
    RnonCO2[	706	]=	9.09829E-01	;
    RnonCO2[	707	]=	9.09749E-01	;
    RnonCO2[	708	]=	9.09671E-01	;
    RnonCO2[	709	]=	9.09594E-01	;
    RnonCO2[	710	]=	9.09516E-01	;
    RnonCO2[	711	]=	9.09439E-01	;
    RnonCO2[	712	]=	9.09362E-01	;
    RnonCO2[	713	]=	9.09285E-01	;
    RnonCO2[	714	]=	9.09208E-01	;
    RnonCO2[	715	]=	9.09130E-01	;
    RnonCO2[	716	]=	9.09053E-01	;
    RnonCO2[	717	]=	9.08980E-01	;
    RnonCO2[	718	]=	9.08901E-01	;
    RnonCO2[	719	]=	9.08823E-01	;
    RnonCO2[	720	]=	9.08750E-01	;
    RnonCO2[	721	]=	9.08672E-01	;
    RnonCO2[	722	]=	9.08594E-01	;
    RnonCO2[	723	]=	9.08522E-01	;
    RnonCO2[	724	]=	9.08445E-01	;
    RnonCO2[	725	]=	9.08372E-01	;
    RnonCO2[	726	]=	9.08298E-01	;
    RnonCO2[	727	]=	9.08221E-01	;
    RnonCO2[	728	]=	9.08146E-01	;
    RnonCO2[	729	]=	9.08072E-01	;
    RnonCO2[	730	]=	9.07999E-01	;
    RnonCO2[	731	]=	9.07925E-01	;
    RnonCO2[	732	]=	9.07846E-01	;
    RnonCO2[	733	]=	9.07773E-01	;
    RnonCO2[	734	]=	9.07699E-01	;
    RnonCO2[	735	]=	9.07665E-01	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp370lowNTCF(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.18868E+00	;
    RnonCO2[	252	]=	-1.17554E+00	;
    RnonCO2[	253	]=	-1.16229E+00	;
    RnonCO2[	254	]=	-1.14891E+00	;
    RnonCO2[	255	]=	-1.13543E+00	;
    RnonCO2[	256	]=	-1.12294E+00	;
    RnonCO2[	257	]=	-1.11035E+00	;
    RnonCO2[	258	]=	-1.09765E+00	;
    RnonCO2[	259	]=	-1.08484E+00	;
    RnonCO2[	260	]=	-1.07193E+00	;
    RnonCO2[	261	]=	-1.05891E+00	;
    RnonCO2[	262	]=	-1.04577E+00	;
    RnonCO2[	263	]=	-1.03251E+00	;
    RnonCO2[	264	]=	-1.01913E+00	;
    RnonCO2[	265	]=	-1.00564E+00	;
    RnonCO2[	266	]=	-9.93429E-01	;
    RnonCO2[	267	]=	-9.81122E-01	;
    RnonCO2[	268	]=	-9.68715E-01	;
    RnonCO2[	269	]=	-9.56206E-01	;
    RnonCO2[	270	]=	-9.43593E-01	;
    RnonCO2[	271	]=	-9.30873E-01	;
    RnonCO2[	272	]=	-9.18045E-01	;
    RnonCO2[	273	]=	-9.05106E-01	;
    RnonCO2[	274	]=	-8.92054E-01	;
    RnonCO2[	275	]=	-8.78886E-01	;
    RnonCO2[	276	]=	-8.60355E-01	;
    RnonCO2[	277	]=	-8.41593E-01	;
    RnonCO2[	278	]=	-8.22593E-01	;
    RnonCO2[	279	]=	-8.03347E-01	;
    RnonCO2[	280	]=	-7.83848E-01	;
    RnonCO2[	281	]=	-7.64088E-01	;
    RnonCO2[	282	]=	-7.44057E-01	;
    RnonCO2[	283	]=	-7.23748E-01	;
    RnonCO2[	284	]=	-7.03150E-01	;
    RnonCO2[	285	]=	-6.82254E-01	;
    RnonCO2[	286	]=	-6.79015E-01	;
    RnonCO2[	287	]=	-6.75769E-01	;
    RnonCO2[	288	]=	-6.72516E-01	;
    RnonCO2[	289	]=	-6.69256E-01	;
    RnonCO2[	290	]=	-6.65989E-01	;
    RnonCO2[	291	]=	-6.62714E-01	;
    RnonCO2[	292	]=	-6.59433E-01	;
    RnonCO2[	293	]=	-6.56144E-01	;
    RnonCO2[	294	]=	-6.52849E-01	;
    RnonCO2[	295	]=	-6.49546E-01	;
    RnonCO2[	296	]=	-6.46250E-01	;
    RnonCO2[	297	]=	-6.42947E-01	;
    RnonCO2[	298	]=	-6.39636E-01	;
    RnonCO2[	299	]=	-6.36319E-01	;
    RnonCO2[	300	]=	-6.32994E-01	;
    RnonCO2[	301	]=	-6.29662E-01	;
    RnonCO2[	302	]=	-6.26323E-01	;
    RnonCO2[	303	]=	-6.22976E-01	;
    RnonCO2[	304	]=	-6.19622E-01	;
    RnonCO2[	305	]=	-6.16261E-01	;
    RnonCO2[	306	]=	-6.12559E-01	;
    RnonCO2[	307	]=	-6.08849E-01	;
    RnonCO2[	308	]=	-6.05129E-01	;
    RnonCO2[	309	]=	-6.01400E-01	;
    RnonCO2[	310	]=	-5.97662E-01	;
    RnonCO2[	311	]=	-5.93915E-01	;
    RnonCO2[	312	]=	-5.90158E-01	;
    RnonCO2[	313	]=	-5.86392E-01	;
    RnonCO2[	314	]=	-5.82617E-01	;
    RnonCO2[	315	]=	-5.78832E-01	;
    RnonCO2[	316	]=	-5.75472E-01	;
    RnonCO2[	317	]=	-5.72105E-01	;
    RnonCO2[	318	]=	-5.68730E-01	;
    RnonCO2[	319	]=	-5.65347E-01	;
    RnonCO2[	320	]=	-5.61957E-01	;
    RnonCO2[	321	]=	-5.58558E-01	;
    RnonCO2[	322	]=	-5.55151E-01	;
    RnonCO2[	323	]=	-5.51736E-01	;
    RnonCO2[	324	]=	-5.48314E-01	;
    RnonCO2[	325	]=	-5.44883E-01	;
    RnonCO2[	326	]=	-5.41236E-01	;
    RnonCO2[	327	]=	-5.37579E-01	;
    RnonCO2[	328	]=	-5.33913E-01	;
    RnonCO2[	329	]=	-5.30238E-01	;
    RnonCO2[	330	]=	-5.26553E-01	;
    RnonCO2[	331	]=	-5.22859E-01	;
    RnonCO2[	332	]=	-5.19155E-01	;
    RnonCO2[	333	]=	-5.15442E-01	;
    RnonCO2[	334	]=	-5.11718E-01	;
    RnonCO2[	335	]=	-5.07985E-01	;
    RnonCO2[	336	]=	-5.05230E-01	;
    RnonCO2[	337	]=	-5.02469E-01	;
    RnonCO2[	338	]=	-4.99703E-01	;
    RnonCO2[	339	]=	-4.96932E-01	;
    RnonCO2[	340	]=	-4.94156E-01	;
    RnonCO2[	341	]=	-4.91374E-01	;
    RnonCO2[	342	]=	-4.88588E-01	;
    RnonCO2[	343	]=	-4.85796E-01	;
    RnonCO2[	344	]=	-4.82998E-01	;
    RnonCO2[	345	]=	-4.80196E-01	;
    RnonCO2[	346	]=	-4.77388E-01	;
    RnonCO2[	347	]=	-4.74575E-01	;
    RnonCO2[	348	]=	-4.71756E-01	;
    RnonCO2[	349	]=	-4.68932E-01	;
    RnonCO2[	350	]=	-4.66103E-01	;
    RnonCO2[	351	]=	-4.63268E-01	;
    RnonCO2[	352	]=	-4.60428E-01	;
    RnonCO2[	353	]=	-4.57582E-01	;
    RnonCO2[	354	]=	-4.54731E-01	;
    RnonCO2[	355	]=	-4.51874E-01	;
    RnonCO2[	356	]=	-4.49012E-01	;
    RnonCO2[	357	]=	-4.46144E-01	;
    RnonCO2[	358	]=	-4.43271E-01	;
    RnonCO2[	359	]=	-4.40392E-01	;
    RnonCO2[	360	]=	-4.37507E-01	;
    RnonCO2[	361	]=	-4.34616E-01	;
    RnonCO2[	362	]=	-4.31720E-01	;
    RnonCO2[	363	]=	-4.28818E-01	;
    RnonCO2[	364	]=	-4.25911E-01	;
    RnonCO2[	365	]=	-4.22997E-01	;
    RnonCO2[	366	]=	-4.20078E-01	;
    RnonCO2[	367	]=	-4.17152E-01	;
    RnonCO2[	368	]=	-4.14221E-01	;
    RnonCO2[	369	]=	-4.11283E-01	;
    RnonCO2[	370	]=	-4.08340E-01	;
    RnonCO2[	371	]=	-4.05391E-01	;
    RnonCO2[	372	]=	-4.02436E-01	;
    RnonCO2[	373	]=	-3.99474E-01	;
    RnonCO2[	374	]=	-3.96507E-01	;
    RnonCO2[	375	]=	-3.93534E-01	;
    RnonCO2[	376	]=	-3.90554E-01	;
    RnonCO2[	377	]=	-3.87568E-01	;
    RnonCO2[	378	]=	-3.84576E-01	;
    RnonCO2[	379	]=	-3.81578E-01	;
    RnonCO2[	380	]=	-3.78574E-01	;
    RnonCO2[	381	]=	-3.75563E-01	;
    RnonCO2[	382	]=	-3.72546E-01	;
    RnonCO2[	383	]=	-3.69523E-01	;
    RnonCO2[	384	]=	-3.66493E-01	;
    RnonCO2[	385	]=	-3.63457E-01	;
    RnonCO2[	386	]=	-3.60414E-01	;
    RnonCO2[	387	]=	-3.57365E-01	;
    RnonCO2[	388	]=	-3.54310E-01	;
    RnonCO2[	389	]=	-3.51248E-01	;
    RnonCO2[	390	]=	-3.48179E-01	;
    RnonCO2[	391	]=	-3.45104E-01	;
    RnonCO2[	392	]=	-3.42022E-01	;
    RnonCO2[	393	]=	-3.38934E-01	;
    RnonCO2[	394	]=	-3.35838E-01	;
    RnonCO2[	395	]=	-3.32736E-01	;
    RnonCO2[	396	]=	-3.29628E-01	;
    RnonCO2[	397	]=	-3.26512E-01	;
    RnonCO2[	398	]=	-3.23390E-01	;
    RnonCO2[	399	]=	-3.20261E-01	;
    RnonCO2[	400	]=	-3.17124E-01	;
    RnonCO2[	401	]=	-3.13981E-01	;
    RnonCO2[	402	]=	-3.10831E-01	;
    RnonCO2[	403	]=	-3.07674E-01	;
    RnonCO2[	404	]=	-3.04510E-01	;
    RnonCO2[	405	]=	-3.01339E-01	;
    RnonCO2[	406	]=	-2.98161E-01	;
    RnonCO2[	407	]=	-2.94975E-01	;
    RnonCO2[	408	]=	-2.91782E-01	;
    RnonCO2[	409	]=	-2.88582E-01	;
    RnonCO2[	410	]=	-2.85375E-01	;
    RnonCO2[	411	]=	-2.82161E-01	;
    RnonCO2[	412	]=	-2.78939E-01	;
    RnonCO2[	413	]=	-2.75710E-01	;
    RnonCO2[	414	]=	-2.72473E-01	;
    RnonCO2[	415	]=	-2.69229E-01	;
    RnonCO2[	416	]=	-2.65977E-01	;
    RnonCO2[	417	]=	-2.62718E-01	;
    RnonCO2[	418	]=	-2.59452E-01	;
    RnonCO2[	419	]=	-2.56177E-01	;
    RnonCO2[	420	]=	-2.52896E-01	;
    RnonCO2[	421	]=	-2.49606E-01	;
    RnonCO2[	422	]=	-2.46309E-01	;
    RnonCO2[	423	]=	-2.43004E-01	;
    RnonCO2[	424	]=	-2.39691E-01	;
    RnonCO2[	425	]=	-2.36370E-01	;
    RnonCO2[	426	]=	-2.33041E-01	;
    RnonCO2[	427	]=	-2.29703E-01	;
    RnonCO2[	428	]=	-2.26358E-01	;
    RnonCO2[	429	]=	-2.23005E-01	;
    RnonCO2[	430	]=	-2.19644E-01	;
    RnonCO2[	431	]=	-2.16274E-01	;
    RnonCO2[	432	]=	-2.12897E-01	;
    RnonCO2[	433	]=	-2.09511E-01	;
    RnonCO2[	434	]=	-2.06117E-01	;
    RnonCO2[	435	]=	-2.02714E-01	;
    RnonCO2[	436	]=	-1.99303E-01	;
    RnonCO2[	437	]=	-1.95884E-01	;
    RnonCO2[	438	]=	-1.92456E-01	;
    RnonCO2[	439	]=	-1.89019E-01	;
    RnonCO2[	440	]=	-1.85574E-01	;
    RnonCO2[	441	]=	-1.82121E-01	;
    RnonCO2[	442	]=	-1.78658E-01	;
    RnonCO2[	443	]=	-1.75187E-01	;
    RnonCO2[	444	]=	-1.71708E-01	;
    RnonCO2[	445	]=	-1.68219E-01	;
    RnonCO2[	446	]=	-1.64721E-01	;
    RnonCO2[	447	]=	-1.61215E-01	;
    RnonCO2[	448	]=	-1.57699E-01	;
    RnonCO2[	449	]=	-1.54175E-01	;
    RnonCO2[	450	]=	-1.50641E-01	;
    RnonCO2[	451	]=	-1.47098E-01	;
    RnonCO2[	452	]=	-1.43546E-01	;
    RnonCO2[	453	]=	-1.39985E-01	;
    RnonCO2[	454	]=	-1.36414E-01	;
    RnonCO2[	455	]=	-1.32834E-01	;
    RnonCO2[	456	]=	-1.29245E-01	;
    RnonCO2[	457	]=	-1.25646E-01	;
    RnonCO2[	458	]=	-1.22038E-01	;
    RnonCO2[	459	]=	-1.18420E-01	;
    RnonCO2[	460	]=	-1.14792E-01	;
    RnonCO2[	461	]=	-1.11155E-01	;
    RnonCO2[	462	]=	-1.07507E-01	;
    RnonCO2[	463	]=	-1.03850E-01	;
    RnonCO2[	464	]=	-1.00183E-01	;
    RnonCO2[	465	]=	-9.65066E-02	;
    RnonCO2[	466	]=	-9.28201E-02	;
    RnonCO2[	467	]=	-8.91235E-02	;
    RnonCO2[	468	]=	-8.54168E-02	;
    RnonCO2[	469	]=	-8.16998E-02	;
    RnonCO2[	470	]=	-7.79726E-02	;
    RnonCO2[	471	]=	-7.42351E-02	;
    RnonCO2[	472	]=	-7.04871E-02	;
    RnonCO2[	473	]=	-6.67287E-02	;
    RnonCO2[	474	]=	-6.29597E-02	;
    RnonCO2[	475	]=	-5.91801E-02	;
    RnonCO2[	476	]=	-5.53894E-02	;
    RnonCO2[	477	]=	-5.15880E-02	;
    RnonCO2[	478	]=	-4.77757E-02	;
    RnonCO2[	479	]=	-4.39526E-02	;
    RnonCO2[	480	]=	-4.01185E-02	;
    RnonCO2[	481	]=	-3.62733E-02	;
    RnonCO2[	482	]=	-3.24171E-02	;
    RnonCO2[	483	]=	-2.85497E-02	;
    RnonCO2[	484	]=	-2.46711E-02	;
    RnonCO2[	485	]=	-2.07811E-02	;
    RnonCO2[	486	]=	-2.07811E-02	;
    RnonCO2[	487	]=	-2.07811E-02	;
    RnonCO2[	488	]=	-2.07811E-02	;
    RnonCO2[	489	]=	-2.07811E-02	;
    RnonCO2[	490	]=	-2.07811E-02	;
    RnonCO2[	491	]=	-2.07811E-02	;
    RnonCO2[	492	]=	-2.07811E-02	;
    RnonCO2[	493	]=	-2.07811E-02	;
    RnonCO2[	494	]=	-2.07811E-02	;
    RnonCO2[	495	]=	-2.07811E-02	;
    RnonCO2[	496	]=	-2.07811E-02	;
    RnonCO2[	497	]=	-2.07811E-02	;
    RnonCO2[	498	]=	-2.07811E-02	;
    RnonCO2[	499	]=	-2.07811E-02	;
    RnonCO2[	500	]=	-2.07811E-02	;
    RnonCO2[	501	]=	-2.07811E-02	;
    RnonCO2[	502	]=	-2.07811E-02	;
    RnonCO2[	503	]=	-2.07811E-02	;
    RnonCO2[	504	]=	-2.07811E-02	;
    RnonCO2[	505	]=	-2.07811E-02	;
    RnonCO2[	506	]=	-2.07811E-02	;
    RnonCO2[	507	]=	-2.07811E-02	;
    RnonCO2[	508	]=	-2.07811E-02	;
    RnonCO2[	509	]=	-2.07811E-02	;
    RnonCO2[	510	]=	-2.07811E-02	;
    RnonCO2[	511	]=	-2.07811E-02	;
    RnonCO2[	512	]=	-2.07811E-02	;
    RnonCO2[	513	]=	-2.07811E-02	;
    RnonCO2[	514	]=	-2.07811E-02	;
    RnonCO2[	515	]=	-2.07811E-02	;
    RnonCO2[	516	]=	-2.07811E-02	;
    RnonCO2[	517	]=	-2.07811E-02	;
    RnonCO2[	518	]=	-2.07811E-02	;
    RnonCO2[	519	]=	-2.07811E-02	;
    RnonCO2[	520	]=	-2.07811E-02	;
    RnonCO2[	521	]=	-2.07811E-02	;
    RnonCO2[	522	]=	-2.07811E-02	;
    RnonCO2[	523	]=	-2.07811E-02	;
    RnonCO2[	524	]=	-2.07811E-02	;
    RnonCO2[	525	]=	-2.07811E-02	;
    RnonCO2[	526	]=	-2.07811E-02	;
    RnonCO2[	527	]=	-2.07811E-02	;
    RnonCO2[	528	]=	-2.07811E-02	;
    RnonCO2[	529	]=	-2.07811E-02	;
    RnonCO2[	530	]=	-2.07811E-02	;
    RnonCO2[	531	]=	-2.07811E-02	;
    RnonCO2[	532	]=	-2.07811E-02	;
    RnonCO2[	533	]=	-2.07811E-02	;
    RnonCO2[	534	]=	-2.07811E-02	;
    RnonCO2[	535	]=	-2.07811E-02	;
    RnonCO2[	536	]=	-2.07811E-02	;
    RnonCO2[	537	]=	-2.07811E-02	;
    RnonCO2[	538	]=	-2.07811E-02	;
    RnonCO2[	539	]=	-2.07811E-02	;
    RnonCO2[	540	]=	-2.07811E-02	;
    RnonCO2[	541	]=	-2.07811E-02	;
    RnonCO2[	542	]=	-2.07811E-02	;
    RnonCO2[	543	]=	-2.07811E-02	;
    RnonCO2[	544	]=	-2.07811E-02	;
    RnonCO2[	545	]=	-2.07811E-02	;
    RnonCO2[	546	]=	-2.07811E-02	;
    RnonCO2[	547	]=	-2.07811E-02	;
    RnonCO2[	548	]=	-2.07811E-02	;
    RnonCO2[	549	]=	-2.07811E-02	;
    RnonCO2[	550	]=	-2.07811E-02	;
    RnonCO2[	551	]=	-2.07811E-02	;
    RnonCO2[	552	]=	-2.07811E-02	;
    RnonCO2[	553	]=	-2.07811E-02	;
    RnonCO2[	554	]=	-2.07811E-02	;
    RnonCO2[	555	]=	-2.07811E-02	;
    RnonCO2[	556	]=	-2.07811E-02	;
    RnonCO2[	557	]=	-2.07811E-02	;
    RnonCO2[	558	]=	-2.07811E-02	;
    RnonCO2[	559	]=	-2.07811E-02	;
    RnonCO2[	560	]=	-2.07811E-02	;
    RnonCO2[	561	]=	-2.07811E-02	;
    RnonCO2[	562	]=	-2.07811E-02	;
    RnonCO2[	563	]=	-2.07811E-02	;
    RnonCO2[	564	]=	-2.07811E-02	;
    RnonCO2[	565	]=	-2.07811E-02	;
    RnonCO2[	566	]=	-2.07811E-02	;
    RnonCO2[	567	]=	-2.07811E-02	;
    RnonCO2[	568	]=	-2.07811E-02	;
    RnonCO2[	569	]=	-2.07811E-02	;
    RnonCO2[	570	]=	-2.07811E-02	;
    RnonCO2[	571	]=	-2.07811E-02	;
    RnonCO2[	572	]=	-2.07811E-02	;
    RnonCO2[	573	]=	-2.07811E-02	;
    RnonCO2[	574	]=	-2.07811E-02	;
    RnonCO2[	575	]=	-2.07811E-02	;
    RnonCO2[	576	]=	-2.07811E-02	;
    RnonCO2[	577	]=	-2.07811E-02	;
    RnonCO2[	578	]=	-2.07811E-02	;
    RnonCO2[	579	]=	-2.07811E-02	;
    RnonCO2[	580	]=	-2.07811E-02	;
    RnonCO2[	581	]=	-2.07811E-02	;
    RnonCO2[	582	]=	-2.07811E-02	;
    RnonCO2[	583	]=	-2.07811E-02	;
    RnonCO2[	584	]=	-2.07811E-02	;
    RnonCO2[	585	]=	-2.07811E-02	;
    RnonCO2[	586	]=	-2.07811E-02	;
    RnonCO2[	587	]=	-2.07811E-02	;
    RnonCO2[	588	]=	-2.07811E-02	;
    RnonCO2[	589	]=	-2.07811E-02	;
    RnonCO2[	590	]=	-2.07811E-02	;
    RnonCO2[	591	]=	-2.07811E-02	;
    RnonCO2[	592	]=	-2.07811E-02	;
    RnonCO2[	593	]=	-2.07811E-02	;
    RnonCO2[	594	]=	-2.07811E-02	;
    RnonCO2[	595	]=	-2.07811E-02	;
    RnonCO2[	596	]=	-2.07811E-02	;
    RnonCO2[	597	]=	-2.07811E-02	;
    RnonCO2[	598	]=	-2.07811E-02	;
    RnonCO2[	599	]=	-2.07811E-02	;
    RnonCO2[	600	]=	-2.07811E-02	;
    RnonCO2[	601	]=	-2.07811E-02	;
    RnonCO2[	602	]=	-2.07811E-02	;
    RnonCO2[	603	]=	-2.07811E-02	;
    RnonCO2[	604	]=	-2.07811E-02	;
    RnonCO2[	605	]=	-2.07811E-02	;
    RnonCO2[	606	]=	-2.07811E-02	;
    RnonCO2[	607	]=	-2.07811E-02	;
    RnonCO2[	608	]=	-2.07811E-02	;
    RnonCO2[	609	]=	-2.07811E-02	;
    RnonCO2[	610	]=	-2.07811E-02	;
    RnonCO2[	611	]=	-2.07811E-02	;
    RnonCO2[	612	]=	-2.07811E-02	;
    RnonCO2[	613	]=	-2.07811E-02	;
    RnonCO2[	614	]=	-2.07811E-02	;
    RnonCO2[	615	]=	-2.07811E-02	;
    RnonCO2[	616	]=	-2.07811E-02	;
    RnonCO2[	617	]=	-2.07811E-02	;
    RnonCO2[	618	]=	-2.07811E-02	;
    RnonCO2[	619	]=	-2.07811E-02	;
    RnonCO2[	620	]=	-2.07811E-02	;
    RnonCO2[	621	]=	-2.07811E-02	;
    RnonCO2[	622	]=	-2.07811E-02	;
    RnonCO2[	623	]=	-2.07811E-02	;
    RnonCO2[	624	]=	-2.07811E-02	;
    RnonCO2[	625	]=	-2.07811E-02	;
    RnonCO2[	626	]=	-2.07811E-02	;
    RnonCO2[	627	]=	-2.07811E-02	;
    RnonCO2[	628	]=	-2.07811E-02	;
    RnonCO2[	629	]=	-2.07811E-02	;
    RnonCO2[	630	]=	-2.07811E-02	;
    RnonCO2[	631	]=	-2.07811E-02	;
    RnonCO2[	632	]=	-2.07811E-02	;
    RnonCO2[	633	]=	-2.07811E-02	;
    RnonCO2[	634	]=	-2.07811E-02	;
    RnonCO2[	635	]=	-2.07811E-02	;
    RnonCO2[	636	]=	-2.07811E-02	;
    RnonCO2[	637	]=	-2.07811E-02	;
    RnonCO2[	638	]=	-2.07811E-02	;
    RnonCO2[	639	]=	-2.07811E-02	;
    RnonCO2[	640	]=	-2.07811E-02	;
    RnonCO2[	641	]=	-2.07811E-02	;
    RnonCO2[	642	]=	-2.07811E-02	;
    RnonCO2[	643	]=	-2.07811E-02	;
    RnonCO2[	644	]=	-2.07811E-02	;
    RnonCO2[	645	]=	-2.07811E-02	;
    RnonCO2[	646	]=	-2.07811E-02	;
    RnonCO2[	647	]=	-2.07811E-02	;
    RnonCO2[	648	]=	-2.07811E-02	;
    RnonCO2[	649	]=	-2.07811E-02	;
    RnonCO2[	650	]=	-2.07811E-02	;
    RnonCO2[	651	]=	-2.07811E-02	;
    RnonCO2[	652	]=	-2.07811E-02	;
    RnonCO2[	653	]=	-2.07811E-02	;
    RnonCO2[	654	]=	-2.07811E-02	;
    RnonCO2[	655	]=	-2.07811E-02	;
    RnonCO2[	656	]=	-2.07811E-02	;
    RnonCO2[	657	]=	-2.07811E-02	;
    RnonCO2[	658	]=	-2.07811E-02	;
    RnonCO2[	659	]=	-2.07811E-02	;
    RnonCO2[	660	]=	-2.07811E-02	;
    RnonCO2[	661	]=	-2.07811E-02	;
    RnonCO2[	662	]=	-2.07811E-02	;
    RnonCO2[	663	]=	-2.07811E-02	;
    RnonCO2[	664	]=	-2.07811E-02	;
    RnonCO2[	665	]=	-2.07811E-02	;
    RnonCO2[	666	]=	-2.07811E-02	;
    RnonCO2[	667	]=	-2.07811E-02	;
    RnonCO2[	668	]=	-2.07811E-02	;
    RnonCO2[	669	]=	-2.07811E-02	;
    RnonCO2[	670	]=	-2.07811E-02	;
    RnonCO2[	671	]=	-2.07811E-02	;
    RnonCO2[	672	]=	-2.07811E-02	;
    RnonCO2[	673	]=	-2.07811E-02	;
    RnonCO2[	674	]=	-2.07811E-02	;
    RnonCO2[	675	]=	-2.07811E-02	;
    RnonCO2[	676	]=	-2.07811E-02	;
    RnonCO2[	677	]=	-2.07811E-02	;
    RnonCO2[	678	]=	-2.07811E-02	;
    RnonCO2[	679	]=	-2.07811E-02	;
    RnonCO2[	680	]=	-2.07811E-02	;
    RnonCO2[	681	]=	-2.07811E-02	;
    RnonCO2[	682	]=	-2.07811E-02	;
    RnonCO2[	683	]=	-2.07811E-02	;
    RnonCO2[	684	]=	-2.07811E-02	;
    RnonCO2[	685	]=	-2.07811E-02	;
    RnonCO2[	686	]=	-2.07811E-02	;
    RnonCO2[	687	]=	-2.07811E-02	;
    RnonCO2[	688	]=	-2.07811E-02	;
    RnonCO2[	689	]=	-2.07811E-02	;
    RnonCO2[	690	]=	-2.07811E-02	;
    RnonCO2[	691	]=	-2.07811E-02	;
    RnonCO2[	692	]=	-2.07811E-02	;
    RnonCO2[	693	]=	-2.07811E-02	;
    RnonCO2[	694	]=	-2.07811E-02	;
    RnonCO2[	695	]=	-2.07811E-02	;
    RnonCO2[	696	]=	-2.07811E-02	;
    RnonCO2[	697	]=	-2.07811E-02	;
    RnonCO2[	698	]=	-2.07811E-02	;
    RnonCO2[	699	]=	-2.07811E-02	;
    RnonCO2[	700	]=	-2.07811E-02	;
    RnonCO2[	701	]=	-2.07811E-02	;
    RnonCO2[	702	]=	-2.07811E-02	;
    RnonCO2[	703	]=	-2.07811E-02	;
    RnonCO2[	704	]=	-2.07811E-02	;
    RnonCO2[	705	]=	-2.07811E-02	;
    RnonCO2[	706	]=	-2.07811E-02	;
    RnonCO2[	707	]=	-2.07811E-02	;
    RnonCO2[	708	]=	-2.07811E-02	;
    RnonCO2[	709	]=	-2.07811E-02	;
    RnonCO2[	710	]=	-2.07811E-02	;
    RnonCO2[	711	]=	-2.07811E-02	;
    RnonCO2[	712	]=	-2.07811E-02	;
    RnonCO2[	713	]=	-2.07811E-02	;
    RnonCO2[	714	]=	-2.07811E-02	;
    RnonCO2[	715	]=	-2.07811E-02	;
    RnonCO2[	716	]=	-2.07811E-02	;
    RnonCO2[	717	]=	-2.07811E-02	;
    RnonCO2[	718	]=	-2.07811E-02	;
    RnonCO2[	719	]=	-2.07811E-02	;
    RnonCO2[	720	]=	-2.07811E-02	;
    RnonCO2[	721	]=	-2.07811E-02	;
    RnonCO2[	722	]=	-2.07811E-02	;
    RnonCO2[	723	]=	-2.07811E-02	;
    RnonCO2[	724	]=	-2.07811E-02	;
    RnonCO2[	725	]=	-2.07811E-02	;
    RnonCO2[	726	]=	-2.07811E-02	;
    RnonCO2[	727	]=	-2.07811E-02	;
    RnonCO2[	728	]=	-2.07811E-02	;
    RnonCO2[	729	]=	-2.07811E-02	;
    RnonCO2[	730	]=	-2.07811E-02	;
    RnonCO2[	731	]=	-2.07811E-02	;
    RnonCO2[	732	]=	-2.07811E-02	;
    RnonCO2[	733	]=	-2.07811E-02	;
    RnonCO2[	734	]=	-2.07811E-02	;
    RnonCO2[	735	]=	-2.07811E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp434(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07201E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09085E+00	;
    RnonCO2[	253	]=	1.09962E+00	;
    RnonCO2[	254	]=	1.10891E+00	;
    RnonCO2[	255	]=	1.11848E+00	;
    RnonCO2[	256	]=	1.12836E+00	;
    RnonCO2[	257	]=	1.13751E+00	;
    RnonCO2[	258	]=	1.14503E+00	;
    RnonCO2[	259	]=	1.15113E+00	;
    RnonCO2[	260	]=	1.15597E+00	;
    RnonCO2[	261	]=	1.15967E+00	;
    RnonCO2[	262	]=	1.16220E+00	;
    RnonCO2[	263	]=	1.16355E+00	;
    RnonCO2[	264	]=	1.16388E+00	;
    RnonCO2[	265	]=	1.16332E+00	;
    RnonCO2[	266	]=	1.16198E+00	;
    RnonCO2[	267	]=	1.16032E+00	;
    RnonCO2[	268	]=	1.15873E+00	;
    RnonCO2[	269	]=	1.15728E+00	;
    RnonCO2[	270	]=	1.15601E+00	;
    RnonCO2[	271	]=	1.15494E+00	;
    RnonCO2[	272	]=	1.15411E+00	;
    RnonCO2[	273	]=	1.15353E+00	;
    RnonCO2[	274	]=	1.15321E+00	;
    RnonCO2[	275	]=	1.15314E+00	;
    RnonCO2[	276	]=	1.15333E+00	;
    RnonCO2[	277	]=	1.15368E+00	;
    RnonCO2[	278	]=	1.15409E+00	;
    RnonCO2[	279	]=	1.15458E+00	;
    RnonCO2[	280	]=	1.15516E+00	;
    RnonCO2[	281	]=	1.15581E+00	;
    RnonCO2[	282	]=	1.15655E+00	;
    RnonCO2[	283	]=	1.15738E+00	;
    RnonCO2[	284	]=	1.15829E+00	;
    RnonCO2[	285	]=	1.15928E+00	;
    RnonCO2[	286	]=	1.16036E+00	;
    RnonCO2[	287	]=	1.16150E+00	;
    RnonCO2[	288	]=	1.16269E+00	;
    RnonCO2[	289	]=	1.16391E+00	;
    RnonCO2[	290	]=	1.16519E+00	;
    RnonCO2[	291	]=	1.16652E+00	;
    RnonCO2[	292	]=	1.16789E+00	;
    RnonCO2[	293	]=	1.16930E+00	;
    RnonCO2[	294	]=	1.17077E+00	;
    RnonCO2[	295	]=	1.17227E+00	;
    RnonCO2[	296	]=	1.17383E+00	;
    RnonCO2[	297	]=	1.17541E+00	;
    RnonCO2[	298	]=	1.17700E+00	;
    RnonCO2[	299	]=	1.17859E+00	;
    RnonCO2[	300	]=	1.18018E+00	;
    RnonCO2[	301	]=	1.18180E+00	;
    RnonCO2[	302	]=	1.18342E+00	;
    RnonCO2[	303	]=	1.18506E+00	;
    RnonCO2[	304	]=	1.18671E+00	;
    RnonCO2[	305	]=	1.18838E+00	;
    RnonCO2[	306	]=	1.19008E+00	;
    RnonCO2[	307	]=	1.19173E+00	;
    RnonCO2[	308	]=	1.19331E+00	;
    RnonCO2[	309	]=	1.19482E+00	;
    RnonCO2[	310	]=	1.19626E+00	;
    RnonCO2[	311	]=	1.19764E+00	;
    RnonCO2[	312	]=	1.19898E+00	;
    RnonCO2[	313	]=	1.20026E+00	;
    RnonCO2[	314	]=	1.20151E+00	;
    RnonCO2[	315	]=	1.20273E+00	;
    RnonCO2[	316	]=	1.20391E+00	;
    RnonCO2[	317	]=	1.20501E+00	;
    RnonCO2[	318	]=	1.20594E+00	;
    RnonCO2[	319	]=	1.20673E+00	;
    RnonCO2[	320	]=	1.20739E+00	;
    RnonCO2[	321	]=	1.20793E+00	;
    RnonCO2[	322	]=	1.20836E+00	;
    RnonCO2[	323	]=	1.20868E+00	;
    RnonCO2[	324	]=	1.20892E+00	;
    RnonCO2[	325	]=	1.20907E+00	;
    RnonCO2[	326	]=	1.20914E+00	;
    RnonCO2[	327	]=	1.20914E+00	;
    RnonCO2[	328	]=	1.20909E+00	;
    RnonCO2[	329	]=	1.20898E+00	;
    RnonCO2[	330	]=	1.20882E+00	;
    RnonCO2[	331	]=	1.20861E+00	;
    RnonCO2[	332	]=	1.20836E+00	;
    RnonCO2[	333	]=	1.20807E+00	;
    RnonCO2[	334	]=	1.20775E+00	;
    RnonCO2[	335	]=	1.20739E+00	;
    RnonCO2[	336	]=	1.20702E+00	;
    RnonCO2[	337	]=	1.20665E+00	;
    RnonCO2[	338	]=	1.20631E+00	;
    RnonCO2[	339	]=	1.20600E+00	;
    RnonCO2[	340	]=	1.20572E+00	;
    RnonCO2[	341	]=	1.20547E+00	;
    RnonCO2[	342	]=	1.20524E+00	;
    RnonCO2[	343	]=	1.20504E+00	;
    RnonCO2[	344	]=	1.20485E+00	;
    RnonCO2[	345	]=	1.20469E+00	;
    RnonCO2[	346	]=	1.20454E+00	;
    RnonCO2[	347	]=	1.20440E+00	;
    RnonCO2[	348	]=	1.20428E+00	;
    RnonCO2[	349	]=	1.20417E+00	;
    RnonCO2[	350	]=	1.20407E+00	;
    RnonCO2[	351	]=	1.20398E+00	;
    RnonCO2[	352	]=	1.20390E+00	;
    RnonCO2[	353	]=	1.20382E+00	;
    RnonCO2[	354	]=	1.20375E+00	;
    RnonCO2[	355	]=	1.20369E+00	;
    RnonCO2[	356	]=	1.20362E+00	;
    RnonCO2[	357	]=	1.20356E+00	;
    RnonCO2[	358	]=	1.20350E+00	;
    RnonCO2[	359	]=	1.20345E+00	;
    RnonCO2[	360	]=	1.20339E+00	;
    RnonCO2[	361	]=	1.20333E+00	;
    RnonCO2[	362	]=	1.20327E+00	;
    RnonCO2[	363	]=	1.20321E+00	;
    RnonCO2[	364	]=	1.20314E+00	;
    RnonCO2[	365	]=	1.20307E+00	;
    RnonCO2[	366	]=	1.20300E+00	;
    RnonCO2[	367	]=	1.20293E+00	;
    RnonCO2[	368	]=	1.20285E+00	;
    RnonCO2[	369	]=	1.20276E+00	;
    RnonCO2[	370	]=	1.20267E+00	;
    RnonCO2[	371	]=	1.20258E+00	;
    RnonCO2[	372	]=	1.20248E+00	;
    RnonCO2[	373	]=	1.20237E+00	;
    RnonCO2[	374	]=	1.20226E+00	;
    RnonCO2[	375	]=	1.20214E+00	;
    RnonCO2[	376	]=	1.20201E+00	;
    RnonCO2[	377	]=	1.20188E+00	;
    RnonCO2[	378	]=	1.20173E+00	;
    RnonCO2[	379	]=	1.20158E+00	;
    RnonCO2[	380	]=	1.20142E+00	;
    RnonCO2[	381	]=	1.20126E+00	;
    RnonCO2[	382	]=	1.20107E+00	;
    RnonCO2[	383	]=	1.20088E+00	;
    RnonCO2[	384	]=	1.20068E+00	;
    RnonCO2[	385	]=	1.20046E+00	;
    RnonCO2[	386	]=	1.20024E+00	;
    RnonCO2[	387	]=	1.20000E+00	;
    RnonCO2[	388	]=	1.19975E+00	;
    RnonCO2[	389	]=	1.19948E+00	;
    RnonCO2[	390	]=	1.19919E+00	;
    RnonCO2[	391	]=	1.19890E+00	;
    RnonCO2[	392	]=	1.19858E+00	;
    RnonCO2[	393	]=	1.19826E+00	;
    RnonCO2[	394	]=	1.19791E+00	;
    RnonCO2[	395	]=	1.19755E+00	;
    RnonCO2[	396	]=	1.19718E+00	;
    RnonCO2[	397	]=	1.19678E+00	;
    RnonCO2[	398	]=	1.19637E+00	;
    RnonCO2[	399	]=	1.19594E+00	;
    RnonCO2[	400	]=	1.19550E+00	;
    RnonCO2[	401	]=	1.19503E+00	;
    RnonCO2[	402	]=	1.19455E+00	;
    RnonCO2[	403	]=	1.19405E+00	;
    RnonCO2[	404	]=	1.19354E+00	;
    RnonCO2[	405	]=	1.19301E+00	;
    RnonCO2[	406	]=	1.19246E+00	;
    RnonCO2[	407	]=	1.19190E+00	;
    RnonCO2[	408	]=	1.19132E+00	;
    RnonCO2[	409	]=	1.19072E+00	;
    RnonCO2[	410	]=	1.19011E+00	;
    RnonCO2[	411	]=	1.18949E+00	;
    RnonCO2[	412	]=	1.18884E+00	;
    RnonCO2[	413	]=	1.18817E+00	;
    RnonCO2[	414	]=	1.18750E+00	;
    RnonCO2[	415	]=	1.18680E+00	;
    RnonCO2[	416	]=	1.18609E+00	;
    RnonCO2[	417	]=	1.18536E+00	;
    RnonCO2[	418	]=	1.18461E+00	;
    RnonCO2[	419	]=	1.18384E+00	;
    RnonCO2[	420	]=	1.18306E+00	;
    RnonCO2[	421	]=	1.18226E+00	;
    RnonCO2[	422	]=	1.18144E+00	;
    RnonCO2[	423	]=	1.18061E+00	;
    RnonCO2[	424	]=	1.17975E+00	;
    RnonCO2[	425	]=	1.17888E+00	;
    RnonCO2[	426	]=	1.17799E+00	;
    RnonCO2[	427	]=	1.17709E+00	;
    RnonCO2[	428	]=	1.17616E+00	;
    RnonCO2[	429	]=	1.17523E+00	;
    RnonCO2[	430	]=	1.17427E+00	;
    RnonCO2[	431	]=	1.17330E+00	;
    RnonCO2[	432	]=	1.17231E+00	;
    RnonCO2[	433	]=	1.17132E+00	;
    RnonCO2[	434	]=	1.17030E+00	;
    RnonCO2[	435	]=	1.16927E+00	;
    RnonCO2[	436	]=	1.16823E+00	;
    RnonCO2[	437	]=	1.16718E+00	;
    RnonCO2[	438	]=	1.16611E+00	;
    RnonCO2[	439	]=	1.16503E+00	;
    RnonCO2[	440	]=	1.16394E+00	;
    RnonCO2[	441	]=	1.16284E+00	;
    RnonCO2[	442	]=	1.16172E+00	;
    RnonCO2[	443	]=	1.16059E+00	;
    RnonCO2[	444	]=	1.15946E+00	;
    RnonCO2[	445	]=	1.15831E+00	;
    RnonCO2[	446	]=	1.15715E+00	;
    RnonCO2[	447	]=	1.15598E+00	;
    RnonCO2[	448	]=	1.15480E+00	;
    RnonCO2[	449	]=	1.15362E+00	;
    RnonCO2[	450	]=	1.15242E+00	;
    RnonCO2[	451	]=	1.15121E+00	;
    RnonCO2[	452	]=	1.14999E+00	;
    RnonCO2[	453	]=	1.14877E+00	;
    RnonCO2[	454	]=	1.14753E+00	;
    RnonCO2[	455	]=	1.14628E+00	;
    RnonCO2[	456	]=	1.14502E+00	;
    RnonCO2[	457	]=	1.14376E+00	;
    RnonCO2[	458	]=	1.14249E+00	;
    RnonCO2[	459	]=	1.14121E+00	;
    RnonCO2[	460	]=	1.13991E+00	;
    RnonCO2[	461	]=	1.13861E+00	;
    RnonCO2[	462	]=	1.13731E+00	;
    RnonCO2[	463	]=	1.13599E+00	;
    RnonCO2[	464	]=	1.13466E+00	;
    RnonCO2[	465	]=	1.13333E+00	;
    RnonCO2[	466	]=	1.13199E+00	;
    RnonCO2[	467	]=	1.13064E+00	;
    RnonCO2[	468	]=	1.12928E+00	;
    RnonCO2[	469	]=	1.12791E+00	;
    RnonCO2[	470	]=	1.12654E+00	;
    RnonCO2[	471	]=	1.12515E+00	;
    RnonCO2[	472	]=	1.12376E+00	;
    RnonCO2[	473	]=	1.12236E+00	;
    RnonCO2[	474	]=	1.12095E+00	;
    RnonCO2[	475	]=	1.11954E+00	;
    RnonCO2[	476	]=	1.11811E+00	;
    RnonCO2[	477	]=	1.11668E+00	;
    RnonCO2[	478	]=	1.11524E+00	;
    RnonCO2[	479	]=	1.11379E+00	;
    RnonCO2[	480	]=	1.11234E+00	;
    RnonCO2[	481	]=	1.11088E+00	;
    RnonCO2[	482	]=	1.10940E+00	;
    RnonCO2[	483	]=	1.10792E+00	;
    RnonCO2[	484	]=	1.10644E+00	;
    RnonCO2[	485	]=	1.10494E+00	;
    RnonCO2[	486	]=	1.10344E+00	;
    RnonCO2[	487	]=	1.10198E+00	;
    RnonCO2[	488	]=	1.10060E+00	;
    RnonCO2[	489	]=	1.09931E+00	;
    RnonCO2[	490	]=	1.09810E+00	;
    RnonCO2[	491	]=	1.09695E+00	;
    RnonCO2[	492	]=	1.09587E+00	;
    RnonCO2[	493	]=	1.09485E+00	;
    RnonCO2[	494	]=	1.09389E+00	;
    RnonCO2[	495	]=	1.09298E+00	;
    RnonCO2[	496	]=	1.09212E+00	;
    RnonCO2[	497	]=	1.09132E+00	;
    RnonCO2[	498	]=	1.09055E+00	;
    RnonCO2[	499	]=	1.08982E+00	;
    RnonCO2[	500	]=	1.08914E+00	;
    RnonCO2[	501	]=	1.08850E+00	;
    RnonCO2[	502	]=	1.08789E+00	;
    RnonCO2[	503	]=	1.08732E+00	;
    RnonCO2[	504	]=	1.08678E+00	;
    RnonCO2[	505	]=	1.08627E+00	;
    RnonCO2[	506	]=	1.08578E+00	;
    RnonCO2[	507	]=	1.08532E+00	;
    RnonCO2[	508	]=	1.08489E+00	;
    RnonCO2[	509	]=	1.08447E+00	;
    RnonCO2[	510	]=	1.08408E+00	;
    RnonCO2[	511	]=	1.08371E+00	;
    RnonCO2[	512	]=	1.08336E+00	;
    RnonCO2[	513	]=	1.08302E+00	;
    RnonCO2[	514	]=	1.08271E+00	;
    RnonCO2[	515	]=	1.08240E+00	;
    RnonCO2[	516	]=	1.08212E+00	;
    RnonCO2[	517	]=	1.08184E+00	;
    RnonCO2[	518	]=	1.08158E+00	;
    RnonCO2[	519	]=	1.08133E+00	;
    RnonCO2[	520	]=	1.08109E+00	;
    RnonCO2[	521	]=	1.08086E+00	;
    RnonCO2[	522	]=	1.08064E+00	;
    RnonCO2[	523	]=	1.08043E+00	;
    RnonCO2[	524	]=	1.08023E+00	;
    RnonCO2[	525	]=	1.08004E+00	;
    RnonCO2[	526	]=	1.07985E+00	;
    RnonCO2[	527	]=	1.07967E+00	;
    RnonCO2[	528	]=	1.07950E+00	;
    RnonCO2[	529	]=	1.07934E+00	;
    RnonCO2[	530	]=	1.07918E+00	;
    RnonCO2[	531	]=	1.07903E+00	;
    RnonCO2[	532	]=	1.07888E+00	;
    RnonCO2[	533	]=	1.07873E+00	;
    RnonCO2[	534	]=	1.07860E+00	;
    RnonCO2[	535	]=	1.07847E+00	;
    RnonCO2[	536	]=	1.07834E+00	;
    RnonCO2[	537	]=	1.07821E+00	;
    RnonCO2[	538	]=	1.07809E+00	;
    RnonCO2[	539	]=	1.07797E+00	;
    RnonCO2[	540	]=	1.07786E+00	;
    RnonCO2[	541	]=	1.07774E+00	;
    RnonCO2[	542	]=	1.07763E+00	;
    RnonCO2[	543	]=	1.07753E+00	;
    RnonCO2[	544	]=	1.07742E+00	;
    RnonCO2[	545	]=	1.07733E+00	;
    RnonCO2[	546	]=	1.07723E+00	;
    RnonCO2[	547	]=	1.07713E+00	;
    RnonCO2[	548	]=	1.07703E+00	;
    RnonCO2[	549	]=	1.07695E+00	;
    RnonCO2[	550	]=	1.07686E+00	;
    RnonCO2[	551	]=	1.07677E+00	;
    RnonCO2[	552	]=	1.07668E+00	;
    RnonCO2[	553	]=	1.07660E+00	;
    RnonCO2[	554	]=	1.07651E+00	;
    RnonCO2[	555	]=	1.07643E+00	;
    RnonCO2[	556	]=	1.07636E+00	;
    RnonCO2[	557	]=	1.07628E+00	;
    RnonCO2[	558	]=	1.07620E+00	;
    RnonCO2[	559	]=	1.07612E+00	;
    RnonCO2[	560	]=	1.07605E+00	;
    RnonCO2[	561	]=	1.07597E+00	;
    RnonCO2[	562	]=	1.07590E+00	;
    RnonCO2[	563	]=	1.07583E+00	;
    RnonCO2[	564	]=	1.07576E+00	;
    RnonCO2[	565	]=	1.07569E+00	;
    RnonCO2[	566	]=	1.07562E+00	;
    RnonCO2[	567	]=	1.07556E+00	;
    RnonCO2[	568	]=	1.07549E+00	;
    RnonCO2[	569	]=	1.07543E+00	;
    RnonCO2[	570	]=	1.07536E+00	;
    RnonCO2[	571	]=	1.07530E+00	;
    RnonCO2[	572	]=	1.07524E+00	;
    RnonCO2[	573	]=	1.07517E+00	;
    RnonCO2[	574	]=	1.07511E+00	;
    RnonCO2[	575	]=	1.07505E+00	;
    RnonCO2[	576	]=	1.07499E+00	;
    RnonCO2[	577	]=	1.07493E+00	;
    RnonCO2[	578	]=	1.07487E+00	;
    RnonCO2[	579	]=	1.07482E+00	;
    RnonCO2[	580	]=	1.07476E+00	;
    RnonCO2[	581	]=	1.07470E+00	;
    RnonCO2[	582	]=	1.07465E+00	;
    RnonCO2[	583	]=	1.07459E+00	;
    RnonCO2[	584	]=	1.07454E+00	;
    RnonCO2[	585	]=	1.07449E+00	;
    RnonCO2[	586	]=	1.07443E+00	;
    RnonCO2[	587	]=	1.07438E+00	;
    RnonCO2[	588	]=	1.07432E+00	;
    RnonCO2[	589	]=	1.07427E+00	;
    RnonCO2[	590	]=	1.07422E+00	;
    RnonCO2[	591	]=	1.07417E+00	;
    RnonCO2[	592	]=	1.07412E+00	;
    RnonCO2[	593	]=	1.07407E+00	;
    RnonCO2[	594	]=	1.07402E+00	;
    RnonCO2[	595	]=	1.07397E+00	;
    RnonCO2[	596	]=	1.07393E+00	;
    RnonCO2[	597	]=	1.07387E+00	;
    RnonCO2[	598	]=	1.07383E+00	;
    RnonCO2[	599	]=	1.07378E+00	;
    RnonCO2[	600	]=	1.07373E+00	;
    RnonCO2[	601	]=	1.07369E+00	;
    RnonCO2[	602	]=	1.07364E+00	;
    RnonCO2[	603	]=	1.07359E+00	;
    RnonCO2[	604	]=	1.07355E+00	;
    RnonCO2[	605	]=	1.07351E+00	;
    RnonCO2[	606	]=	1.07346E+00	;
    RnonCO2[	607	]=	1.07341E+00	;
    RnonCO2[	608	]=	1.07337E+00	;
    RnonCO2[	609	]=	1.07333E+00	;
    RnonCO2[	610	]=	1.07329E+00	;
    RnonCO2[	611	]=	1.07324E+00	;
    RnonCO2[	612	]=	1.07320E+00	;
    RnonCO2[	613	]=	1.07316E+00	;
    RnonCO2[	614	]=	1.07311E+00	;
    RnonCO2[	615	]=	1.07307E+00	;
    RnonCO2[	616	]=	1.07303E+00	;
    RnonCO2[	617	]=	1.07299E+00	;
    RnonCO2[	618	]=	1.07295E+00	;
    RnonCO2[	619	]=	1.07291E+00	;
    RnonCO2[	620	]=	1.07287E+00	;
    RnonCO2[	621	]=	1.07283E+00	;
    RnonCO2[	622	]=	1.07279E+00	;
    RnonCO2[	623	]=	1.07275E+00	;
    RnonCO2[	624	]=	1.07271E+00	;
    RnonCO2[	625	]=	1.07267E+00	;
    RnonCO2[	626	]=	1.07263E+00	;
    RnonCO2[	627	]=	1.07260E+00	;
    RnonCO2[	628	]=	1.07256E+00	;
    RnonCO2[	629	]=	1.07252E+00	;
    RnonCO2[	630	]=	1.07248E+00	;
    RnonCO2[	631	]=	1.07244E+00	;
    RnonCO2[	632	]=	1.07241E+00	;
    RnonCO2[	633	]=	1.07237E+00	;
    RnonCO2[	634	]=	1.07234E+00	;
    RnonCO2[	635	]=	1.07230E+00	;
    RnonCO2[	636	]=	1.07226E+00	;
    RnonCO2[	637	]=	1.07223E+00	;
    RnonCO2[	638	]=	1.07219E+00	;
    RnonCO2[	639	]=	1.07215E+00	;
    RnonCO2[	640	]=	1.07212E+00	;
    RnonCO2[	641	]=	1.07209E+00	;
    RnonCO2[	642	]=	1.07205E+00	;
    RnonCO2[	643	]=	1.07202E+00	;
    RnonCO2[	644	]=	1.07199E+00	;
    RnonCO2[	645	]=	1.07195E+00	;
    RnonCO2[	646	]=	1.07192E+00	;
    RnonCO2[	647	]=	1.07188E+00	;
    RnonCO2[	648	]=	1.07185E+00	;
    RnonCO2[	649	]=	1.07181E+00	;
    RnonCO2[	650	]=	1.07178E+00	;
    RnonCO2[	651	]=	1.07175E+00	;
    RnonCO2[	652	]=	1.07172E+00	;
    RnonCO2[	653	]=	1.07169E+00	;
    RnonCO2[	654	]=	1.07165E+00	;
    RnonCO2[	655	]=	1.07162E+00	;
    RnonCO2[	656	]=	1.07159E+00	;
    RnonCO2[	657	]=	1.07156E+00	;
    RnonCO2[	658	]=	1.07153E+00	;
    RnonCO2[	659	]=	1.07149E+00	;
    RnonCO2[	660	]=	1.07146E+00	;
    RnonCO2[	661	]=	1.07143E+00	;
    RnonCO2[	662	]=	1.07140E+00	;
    RnonCO2[	663	]=	1.07137E+00	;
    RnonCO2[	664	]=	1.07134E+00	;
    RnonCO2[	665	]=	1.07131E+00	;
    RnonCO2[	666	]=	1.07128E+00	;
    RnonCO2[	667	]=	1.07125E+00	;
    RnonCO2[	668	]=	1.07122E+00	;
    RnonCO2[	669	]=	1.07119E+00	;
    RnonCO2[	670	]=	1.07116E+00	;
    RnonCO2[	671	]=	1.07113E+00	;
    RnonCO2[	672	]=	1.07110E+00	;
    RnonCO2[	673	]=	1.07107E+00	;
    RnonCO2[	674	]=	1.07104E+00	;
    RnonCO2[	675	]=	1.07101E+00	;
    RnonCO2[	676	]=	1.07099E+00	;
    RnonCO2[	677	]=	1.07096E+00	;
    RnonCO2[	678	]=	1.07093E+00	;
    RnonCO2[	679	]=	1.07090E+00	;
    RnonCO2[	680	]=	1.07087E+00	;
    RnonCO2[	681	]=	1.07085E+00	;
    RnonCO2[	682	]=	1.07082E+00	;
    RnonCO2[	683	]=	1.07079E+00	;
    RnonCO2[	684	]=	1.07076E+00	;
    RnonCO2[	685	]=	1.07073E+00	;
    RnonCO2[	686	]=	1.07071E+00	;
    RnonCO2[	687	]=	1.07068E+00	;
    RnonCO2[	688	]=	1.07065E+00	;
    RnonCO2[	689	]=	1.07063E+00	;
    RnonCO2[	690	]=	1.07060E+00	;
    RnonCO2[	691	]=	1.07057E+00	;
    RnonCO2[	692	]=	1.07054E+00	;
    RnonCO2[	693	]=	1.07052E+00	;
    RnonCO2[	694	]=	1.07049E+00	;
    RnonCO2[	695	]=	1.07046E+00	;
    RnonCO2[	696	]=	1.07044E+00	;
    RnonCO2[	697	]=	1.07041E+00	;
    RnonCO2[	698	]=	1.07038E+00	;
    RnonCO2[	699	]=	1.07036E+00	;
    RnonCO2[	700	]=	1.07033E+00	;
    RnonCO2[	701	]=	1.07030E+00	;
    RnonCO2[	702	]=	1.07028E+00	;
    RnonCO2[	703	]=	1.07025E+00	;
    RnonCO2[	704	]=	1.07023E+00	;
    RnonCO2[	705	]=	1.07020E+00	;
    RnonCO2[	706	]=	1.07017E+00	;
    RnonCO2[	707	]=	1.07015E+00	;
    RnonCO2[	708	]=	1.07012E+00	;
    RnonCO2[	709	]=	1.07010E+00	;
    RnonCO2[	710	]=	1.07007E+00	;
    RnonCO2[	711	]=	1.07005E+00	;
    RnonCO2[	712	]=	1.07002E+00	;
    RnonCO2[	713	]=	1.07000E+00	;
    RnonCO2[	714	]=	1.06997E+00	;
    RnonCO2[	715	]=	1.06995E+00	;
    RnonCO2[	716	]=	1.06992E+00	;
    RnonCO2[	717	]=	1.06990E+00	;
    RnonCO2[	718	]=	1.06987E+00	;
    RnonCO2[	719	]=	1.06985E+00	;
    RnonCO2[	720	]=	1.06982E+00	;
    RnonCO2[	721	]=	1.06980E+00	;
    RnonCO2[	722	]=	1.06977E+00	;
    RnonCO2[	723	]=	1.06975E+00	;
    RnonCO2[	724	]=	1.06972E+00	;
    RnonCO2[	725	]=	1.06970E+00	;
    RnonCO2[	726	]=	1.06967E+00	;
    RnonCO2[	727	]=	1.06965E+00	;
    RnonCO2[	728	]=	1.06962E+00	;
    RnonCO2[	729	]=	1.06960E+00	;
    RnonCO2[	730	]=	1.06957E+00	;
    RnonCO2[	731	]=	1.06955E+00	;
    RnonCO2[	732	]=	1.06953E+00	;
    RnonCO2[	733	]=	1.06950E+00	;
    RnonCO2[	734	]=	1.06947E+00	;
    RnonCO2[	735	]=	1.06946E+00	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp434(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.18135E+00	;
    RnonCO2[	252	]=	-1.16072E+00	;
    RnonCO2[	253	]=	-1.13983E+00	;
    RnonCO2[	254	]=	-1.11865E+00	;
    RnonCO2[	255	]=	-1.09719E+00	;
    RnonCO2[	256	]=	-1.08354E+00	;
    RnonCO2[	257	]=	-1.06976E+00	;
    RnonCO2[	258	]=	-1.05584E+00	;
    RnonCO2[	259	]=	-1.04178E+00	;
    RnonCO2[	260	]=	-1.02757E+00	;
    RnonCO2[	261	]=	-1.01322E+00	;
    RnonCO2[	262	]=	-9.98721E-01	;
    RnonCO2[	263	]=	-9.84065E-01	;
    RnonCO2[	264	]=	-9.69252E-01	;
    RnonCO2[	265	]=	-9.54277E-01	;
    RnonCO2[	266	]=	-9.39644E-01	;
    RnonCO2[	267	]=	-9.24852E-01	;
    RnonCO2[	268	]=	-9.09896E-01	;
    RnonCO2[	269	]=	-8.94772E-01	;
    RnonCO2[	270	]=	-8.79476E-01	;
    RnonCO2[	271	]=	-8.64002E-01	;
    RnonCO2[	272	]=	-8.48347E-01	;
    RnonCO2[	273	]=	-8.32506E-01	;
    RnonCO2[	274	]=	-8.16472E-01	;
    RnonCO2[	275	]=	-8.00242E-01	;
    RnonCO2[	276	]=	-7.83793E-01	;
    RnonCO2[	277	]=	-7.67137E-01	;
    RnonCO2[	278	]=	-7.50269E-01	;
    RnonCO2[	279	]=	-7.33183E-01	;
    RnonCO2[	280	]=	-7.15871E-01	;
    RnonCO2[	281	]=	-6.98328E-01	;
    RnonCO2[	282	]=	-6.80546E-01	;
    RnonCO2[	283	]=	-6.62518E-01	;
    RnonCO2[	284	]=	-6.44236E-01	;
    RnonCO2[	285	]=	-6.25691E-01	;
    RnonCO2[	286	]=	-6.15875E-01	;
    RnonCO2[	287	]=	-6.05983E-01	;
    RnonCO2[	288	]=	-5.96015E-01	;
    RnonCO2[	289	]=	-5.85969E-01	;
    RnonCO2[	290	]=	-5.75843E-01	;
    RnonCO2[	291	]=	-5.65637E-01	;
    RnonCO2[	292	]=	-5.55349E-01	;
    RnonCO2[	293	]=	-5.44977E-01	;
    RnonCO2[	294	]=	-5.34520E-01	;
    RnonCO2[	295	]=	-5.23976E-01	;
    RnonCO2[	296	]=	-5.17708E-01	;
    RnonCO2[	297	]=	-5.11407E-01	;
    RnonCO2[	298	]=	-5.05073E-01	;
    RnonCO2[	299	]=	-4.98704E-01	;
    RnonCO2[	300	]=	-4.92302E-01	;
    RnonCO2[	301	]=	-4.85864E-01	;
    RnonCO2[	302	]=	-4.79392E-01	;
    RnonCO2[	303	]=	-4.72884E-01	;
    RnonCO2[	304	]=	-4.66340E-01	;
    RnonCO2[	305	]=	-4.59760E-01	;
    RnonCO2[	306	]=	-4.54460E-01	;
    RnonCO2[	307	]=	-4.49138E-01	;
    RnonCO2[	308	]=	-4.43794E-01	;
    RnonCO2[	309	]=	-4.38427E-01	;
    RnonCO2[	310	]=	-4.33037E-01	;
    RnonCO2[	311	]=	-4.27625E-01	;
    RnonCO2[	312	]=	-4.22189E-01	;
    RnonCO2[	313	]=	-4.16730E-01	;
    RnonCO2[	314	]=	-4.11248E-01	;
    RnonCO2[	315	]=	-4.05742E-01	;
    RnonCO2[	316	]=	-4.01671E-01	;
    RnonCO2[	317	]=	-3.97591E-01	;
    RnonCO2[	318	]=	-3.93501E-01	;
    RnonCO2[	319	]=	-3.89401E-01	;
    RnonCO2[	320	]=	-3.85292E-01	;
    RnonCO2[	321	]=	-3.81173E-01	;
    RnonCO2[	322	]=	-3.77044E-01	;
    RnonCO2[	323	]=	-3.72904E-01	;
    RnonCO2[	324	]=	-3.68755E-01	;
    RnonCO2[	325	]=	-3.64596E-01	;
    RnonCO2[	326	]=	-3.61713E-01	;
    RnonCO2[	327	]=	-3.58826E-01	;
    RnonCO2[	328	]=	-3.55935E-01	;
    RnonCO2[	329	]=	-3.53039E-01	;
    RnonCO2[	330	]=	-3.50140E-01	;
    RnonCO2[	331	]=	-3.47236E-01	;
    RnonCO2[	332	]=	-3.44328E-01	;
    RnonCO2[	333	]=	-3.41416E-01	;
    RnonCO2[	334	]=	-3.38499E-01	;
    RnonCO2[	335	]=	-3.35578E-01	;
    RnonCO2[	336	]=	-3.33769E-01	;
    RnonCO2[	337	]=	-3.31957E-01	;
    RnonCO2[	338	]=	-3.30143E-01	;
    RnonCO2[	339	]=	-3.28327E-01	;
    RnonCO2[	340	]=	-3.26509E-01	;
    RnonCO2[	341	]=	-3.24689E-01	;
    RnonCO2[	342	]=	-3.22867E-01	;
    RnonCO2[	343	]=	-3.21043E-01	;
    RnonCO2[	344	]=	-3.19216E-01	;
    RnonCO2[	345	]=	-3.17388E-01	;
    RnonCO2[	346	]=	-3.15558E-01	;
    RnonCO2[	347	]=	-3.13725E-01	;
    RnonCO2[	348	]=	-3.11891E-01	;
    RnonCO2[	349	]=	-3.10054E-01	;
    RnonCO2[	350	]=	-3.08215E-01	;
    RnonCO2[	351	]=	-3.06375E-01	;
    RnonCO2[	352	]=	-3.04532E-01	;
    RnonCO2[	353	]=	-3.02686E-01	;
    RnonCO2[	354	]=	-3.00839E-01	;
    RnonCO2[	355	]=	-2.98990E-01	;
    RnonCO2[	356	]=	-2.97138E-01	;
    RnonCO2[	357	]=	-2.95284E-01	;
    RnonCO2[	358	]=	-2.93428E-01	;
    RnonCO2[	359	]=	-2.91569E-01	;
    RnonCO2[	360	]=	-2.89709E-01	;
    RnonCO2[	361	]=	-2.87846E-01	;
    RnonCO2[	362	]=	-2.85981E-01	;
    RnonCO2[	363	]=	-2.84114E-01	;
    RnonCO2[	364	]=	-2.82244E-01	;
    RnonCO2[	365	]=	-2.80373E-01	;
    RnonCO2[	366	]=	-2.78499E-01	;
    RnonCO2[	367	]=	-2.76624E-01	;
    RnonCO2[	368	]=	-2.74746E-01	;
    RnonCO2[	369	]=	-2.72866E-01	;
    RnonCO2[	370	]=	-2.70983E-01	;
    RnonCO2[	371	]=	-2.69099E-01	;
    RnonCO2[	372	]=	-2.67212E-01	;
    RnonCO2[	373	]=	-2.65323E-01	;
    RnonCO2[	374	]=	-2.63431E-01	;
    RnonCO2[	375	]=	-2.61538E-01	;
    RnonCO2[	376	]=	-2.59641E-01	;
    RnonCO2[	377	]=	-2.57743E-01	;
    RnonCO2[	378	]=	-2.55842E-01	;
    RnonCO2[	379	]=	-2.53939E-01	;
    RnonCO2[	380	]=	-2.52034E-01	;
    RnonCO2[	381	]=	-2.50126E-01	;
    RnonCO2[	382	]=	-2.48216E-01	;
    RnonCO2[	383	]=	-2.46303E-01	;
    RnonCO2[	384	]=	-2.44389E-01	;
    RnonCO2[	385	]=	-2.42472E-01	;
    RnonCO2[	386	]=	-2.40553E-01	;
    RnonCO2[	387	]=	-2.38631E-01	;
    RnonCO2[	388	]=	-2.36707E-01	;
    RnonCO2[	389	]=	-2.34781E-01	;
    RnonCO2[	390	]=	-2.32853E-01	;
    RnonCO2[	391	]=	-2.30922E-01	;
    RnonCO2[	392	]=	-2.28989E-01	;
    RnonCO2[	393	]=	-2.27053E-01	;
    RnonCO2[	394	]=	-2.25115E-01	;
    RnonCO2[	395	]=	-2.23174E-01	;
    RnonCO2[	396	]=	-2.21231E-01	;
    RnonCO2[	397	]=	-2.19286E-01	;
    RnonCO2[	398	]=	-2.17338E-01	;
    RnonCO2[	399	]=	-2.15388E-01	;
    RnonCO2[	400	]=	-2.13435E-01	;
    RnonCO2[	401	]=	-2.11480E-01	;
    RnonCO2[	402	]=	-2.09523E-01	;
    RnonCO2[	403	]=	-2.07562E-01	;
    RnonCO2[	404	]=	-2.05600E-01	;
    RnonCO2[	405	]=	-2.03635E-01	;
    RnonCO2[	406	]=	-2.01667E-01	;
    RnonCO2[	407	]=	-1.99697E-01	;
    RnonCO2[	408	]=	-1.97724E-01	;
    RnonCO2[	409	]=	-1.95749E-01	;
    RnonCO2[	410	]=	-1.93771E-01	;
    RnonCO2[	411	]=	-1.91791E-01	;
    RnonCO2[	412	]=	-1.89808E-01	;
    RnonCO2[	413	]=	-1.87822E-01	;
    RnonCO2[	414	]=	-1.85834E-01	;
    RnonCO2[	415	]=	-1.83844E-01	;
    RnonCO2[	416	]=	-1.81851E-01	;
    RnonCO2[	417	]=	-1.79855E-01	;
    RnonCO2[	418	]=	-1.77857E-01	;
    RnonCO2[	419	]=	-1.75857E-01	;
    RnonCO2[	420	]=	-1.73853E-01	;
    RnonCO2[	421	]=	-1.71848E-01	;
    RnonCO2[	422	]=	-1.69839E-01	;
    RnonCO2[	423	]=	-1.67828E-01	;
    RnonCO2[	424	]=	-1.65814E-01	;
    RnonCO2[	425	]=	-1.63798E-01	;
    RnonCO2[	426	]=	-1.61778E-01	;
    RnonCO2[	427	]=	-1.59756E-01	;
    RnonCO2[	428	]=	-1.57732E-01	;
    RnonCO2[	429	]=	-1.55704E-01	;
    RnonCO2[	430	]=	-1.53674E-01	;
    RnonCO2[	431	]=	-1.51641E-01	;
    RnonCO2[	432	]=	-1.49606E-01	;
    RnonCO2[	433	]=	-1.47568E-01	;
    RnonCO2[	434	]=	-1.45527E-01	;
    RnonCO2[	435	]=	-1.43483E-01	;
    RnonCO2[	436	]=	-1.41437E-01	;
    RnonCO2[	437	]=	-1.39388E-01	;
    RnonCO2[	438	]=	-1.37336E-01	;
    RnonCO2[	439	]=	-1.35282E-01	;
    RnonCO2[	440	]=	-1.33225E-01	;
    RnonCO2[	441	]=	-1.31165E-01	;
    RnonCO2[	442	]=	-1.29102E-01	;
    RnonCO2[	443	]=	-1.27037E-01	;
    RnonCO2[	444	]=	-1.24968E-01	;
    RnonCO2[	445	]=	-1.22897E-01	;
    RnonCO2[	446	]=	-1.20823E-01	;
    RnonCO2[	447	]=	-1.18746E-01	;
    RnonCO2[	448	]=	-1.16667E-01	;
    RnonCO2[	449	]=	-1.14584E-01	;
    RnonCO2[	450	]=	-1.12499E-01	;
    RnonCO2[	451	]=	-1.10410E-01	;
    RnonCO2[	452	]=	-1.08319E-01	;
    RnonCO2[	453	]=	-1.06225E-01	;
    RnonCO2[	454	]=	-1.04128E-01	;
    RnonCO2[	455	]=	-1.02028E-01	;
    RnonCO2[	456	]=	-9.99248E-02	;
    RnonCO2[	457	]=	-9.78186E-02	;
    RnonCO2[	458	]=	-9.57095E-02	;
    RnonCO2[	459	]=	-9.35975E-02	;
    RnonCO2[	460	]=	-9.14824E-02	;
    RnonCO2[	461	]=	-8.93644E-02	;
    RnonCO2[	462	]=	-8.72434E-02	;
    RnonCO2[	463	]=	-8.51194E-02	;
    RnonCO2[	464	]=	-8.29924E-02	;
    RnonCO2[	465	]=	-8.08624E-02	;
    RnonCO2[	466	]=	-7.87298E-02	;
    RnonCO2[	467	]=	-7.65941E-02	;
    RnonCO2[	468	]=	-7.44554E-02	;
    RnonCO2[	469	]=	-7.23137E-02	;
    RnonCO2[	470	]=	-7.01688E-02	;
    RnonCO2[	471	]=	-6.80209E-02	;
    RnonCO2[	472	]=	-6.58699E-02	;
    RnonCO2[	473	]=	-6.37158E-02	;
    RnonCO2[	474	]=	-6.15586E-02	;
    RnonCO2[	475	]=	-5.93983E-02	;
    RnonCO2[	476	]=	-5.72343E-02	;
    RnonCO2[	477	]=	-5.50672E-02	;
    RnonCO2[	478	]=	-5.28970E-02	;
    RnonCO2[	479	]=	-5.07236E-02	;
    RnonCO2[	480	]=	-4.85470E-02	;
    RnonCO2[	481	]=	-4.63672E-02	;
    RnonCO2[	482	]=	-4.41842E-02	;
    RnonCO2[	483	]=	-4.19980E-02	;
    RnonCO2[	484	]=	-3.98085E-02	;
    RnonCO2[	485	]=	-3.76159E-02	;
    RnonCO2[	486	]=	-3.76159E-02	;
    RnonCO2[	487	]=	-3.76159E-02	;
    RnonCO2[	488	]=	-3.76159E-02	;
    RnonCO2[	489	]=	-3.76159E-02	;
    RnonCO2[	490	]=	-3.76159E-02	;
    RnonCO2[	491	]=	-3.76159E-02	;
    RnonCO2[	492	]=	-3.76159E-02	;
    RnonCO2[	493	]=	-3.76159E-02	;
    RnonCO2[	494	]=	-3.76159E-02	;
    RnonCO2[	495	]=	-3.76159E-02	;
    RnonCO2[	496	]=	-3.76159E-02	;
    RnonCO2[	497	]=	-3.76159E-02	;
    RnonCO2[	498	]=	-3.76159E-02	;
    RnonCO2[	499	]=	-3.76159E-02	;
    RnonCO2[	500	]=	-3.76159E-02	;
    RnonCO2[	501	]=	-3.76159E-02	;
    RnonCO2[	502	]=	-3.76159E-02	;
    RnonCO2[	503	]=	-3.76159E-02	;
    RnonCO2[	504	]=	-3.76159E-02	;
    RnonCO2[	505	]=	-3.76159E-02	;
    RnonCO2[	506	]=	-3.76159E-02	;
    RnonCO2[	507	]=	-3.76159E-02	;
    RnonCO2[	508	]=	-3.76159E-02	;
    RnonCO2[	509	]=	-3.76159E-02	;
    RnonCO2[	510	]=	-3.76159E-02	;
    RnonCO2[	511	]=	-3.76159E-02	;
    RnonCO2[	512	]=	-3.76159E-02	;
    RnonCO2[	513	]=	-3.76159E-02	;
    RnonCO2[	514	]=	-3.76159E-02	;
    RnonCO2[	515	]=	-3.76159E-02	;
    RnonCO2[	516	]=	-3.76159E-02	;
    RnonCO2[	517	]=	-3.76159E-02	;
    RnonCO2[	518	]=	-3.76159E-02	;
    RnonCO2[	519	]=	-3.76159E-02	;
    RnonCO2[	520	]=	-3.76159E-02	;
    RnonCO2[	521	]=	-3.76159E-02	;
    RnonCO2[	522	]=	-3.76159E-02	;
    RnonCO2[	523	]=	-3.76159E-02	;
    RnonCO2[	524	]=	-3.76159E-02	;
    RnonCO2[	525	]=	-3.76159E-02	;
    RnonCO2[	526	]=	-3.76159E-02	;
    RnonCO2[	527	]=	-3.76159E-02	;
    RnonCO2[	528	]=	-3.76159E-02	;
    RnonCO2[	529	]=	-3.76159E-02	;
    RnonCO2[	530	]=	-3.76159E-02	;
    RnonCO2[	531	]=	-3.76159E-02	;
    RnonCO2[	532	]=	-3.76159E-02	;
    RnonCO2[	533	]=	-3.76159E-02	;
    RnonCO2[	534	]=	-3.76159E-02	;
    RnonCO2[	535	]=	-3.76159E-02	;
    RnonCO2[	536	]=	-3.76159E-02	;
    RnonCO2[	537	]=	-3.76159E-02	;
    RnonCO2[	538	]=	-3.76159E-02	;
    RnonCO2[	539	]=	-3.76159E-02	;
    RnonCO2[	540	]=	-3.76159E-02	;
    RnonCO2[	541	]=	-3.76159E-02	;
    RnonCO2[	542	]=	-3.76159E-02	;
    RnonCO2[	543	]=	-3.76159E-02	;
    RnonCO2[	544	]=	-3.76159E-02	;
    RnonCO2[	545	]=	-3.76159E-02	;
    RnonCO2[	546	]=	-3.76159E-02	;
    RnonCO2[	547	]=	-3.76159E-02	;
    RnonCO2[	548	]=	-3.76159E-02	;
    RnonCO2[	549	]=	-3.76159E-02	;
    RnonCO2[	550	]=	-3.76159E-02	;
    RnonCO2[	551	]=	-3.76159E-02	;
    RnonCO2[	552	]=	-3.76159E-02	;
    RnonCO2[	553	]=	-3.76159E-02	;
    RnonCO2[	554	]=	-3.76159E-02	;
    RnonCO2[	555	]=	-3.76159E-02	;
    RnonCO2[	556	]=	-3.76159E-02	;
    RnonCO2[	557	]=	-3.76159E-02	;
    RnonCO2[	558	]=	-3.76159E-02	;
    RnonCO2[	559	]=	-3.76159E-02	;
    RnonCO2[	560	]=	-3.76159E-02	;
    RnonCO2[	561	]=	-3.76159E-02	;
    RnonCO2[	562	]=	-3.76159E-02	;
    RnonCO2[	563	]=	-3.76159E-02	;
    RnonCO2[	564	]=	-3.76159E-02	;
    RnonCO2[	565	]=	-3.76159E-02	;
    RnonCO2[	566	]=	-3.76159E-02	;
    RnonCO2[	567	]=	-3.76159E-02	;
    RnonCO2[	568	]=	-3.76159E-02	;
    RnonCO2[	569	]=	-3.76159E-02	;
    RnonCO2[	570	]=	-3.76159E-02	;
    RnonCO2[	571	]=	-3.76159E-02	;
    RnonCO2[	572	]=	-3.76159E-02	;
    RnonCO2[	573	]=	-3.76159E-02	;
    RnonCO2[	574	]=	-3.76159E-02	;
    RnonCO2[	575	]=	-3.76159E-02	;
    RnonCO2[	576	]=	-3.76159E-02	;
    RnonCO2[	577	]=	-3.76159E-02	;
    RnonCO2[	578	]=	-3.76159E-02	;
    RnonCO2[	579	]=	-3.76159E-02	;
    RnonCO2[	580	]=	-3.76159E-02	;
    RnonCO2[	581	]=	-3.76159E-02	;
    RnonCO2[	582	]=	-3.76159E-02	;
    RnonCO2[	583	]=	-3.76159E-02	;
    RnonCO2[	584	]=	-3.76159E-02	;
    RnonCO2[	585	]=	-3.76159E-02	;
    RnonCO2[	586	]=	-3.76159E-02	;
    RnonCO2[	587	]=	-3.76159E-02	;
    RnonCO2[	588	]=	-3.76159E-02	;
    RnonCO2[	589	]=	-3.76159E-02	;
    RnonCO2[	590	]=	-3.76159E-02	;
    RnonCO2[	591	]=	-3.76159E-02	;
    RnonCO2[	592	]=	-3.76159E-02	;
    RnonCO2[	593	]=	-3.76159E-02	;
    RnonCO2[	594	]=	-3.76159E-02	;
    RnonCO2[	595	]=	-3.76159E-02	;
    RnonCO2[	596	]=	-3.76159E-02	;
    RnonCO2[	597	]=	-3.76159E-02	;
    RnonCO2[	598	]=	-3.76159E-02	;
    RnonCO2[	599	]=	-3.76159E-02	;
    RnonCO2[	600	]=	-3.76159E-02	;
    RnonCO2[	601	]=	-3.76159E-02	;
    RnonCO2[	602	]=	-3.76159E-02	;
    RnonCO2[	603	]=	-3.76159E-02	;
    RnonCO2[	604	]=	-3.76159E-02	;
    RnonCO2[	605	]=	-3.76159E-02	;
    RnonCO2[	606	]=	-3.76159E-02	;
    RnonCO2[	607	]=	-3.76159E-02	;
    RnonCO2[	608	]=	-3.76159E-02	;
    RnonCO2[	609	]=	-3.76159E-02	;
    RnonCO2[	610	]=	-3.76159E-02	;
    RnonCO2[	611	]=	-3.76159E-02	;
    RnonCO2[	612	]=	-3.76159E-02	;
    RnonCO2[	613	]=	-3.76159E-02	;
    RnonCO2[	614	]=	-3.76159E-02	;
    RnonCO2[	615	]=	-3.76159E-02	;
    RnonCO2[	616	]=	-3.76159E-02	;
    RnonCO2[	617	]=	-3.76159E-02	;
    RnonCO2[	618	]=	-3.76159E-02	;
    RnonCO2[	619	]=	-3.76159E-02	;
    RnonCO2[	620	]=	-3.76159E-02	;
    RnonCO2[	621	]=	-3.76159E-02	;
    RnonCO2[	622	]=	-3.76159E-02	;
    RnonCO2[	623	]=	-3.76159E-02	;
    RnonCO2[	624	]=	-3.76159E-02	;
    RnonCO2[	625	]=	-3.76159E-02	;
    RnonCO2[	626	]=	-3.76159E-02	;
    RnonCO2[	627	]=	-3.76159E-02	;
    RnonCO2[	628	]=	-3.76159E-02	;
    RnonCO2[	629	]=	-3.76159E-02	;
    RnonCO2[	630	]=	-3.76159E-02	;
    RnonCO2[	631	]=	-3.76159E-02	;
    RnonCO2[	632	]=	-3.76159E-02	;
    RnonCO2[	633	]=	-3.76159E-02	;
    RnonCO2[	634	]=	-3.76159E-02	;
    RnonCO2[	635	]=	-3.76159E-02	;
    RnonCO2[	636	]=	-3.76159E-02	;
    RnonCO2[	637	]=	-3.76159E-02	;
    RnonCO2[	638	]=	-3.76159E-02	;
    RnonCO2[	639	]=	-3.76159E-02	;
    RnonCO2[	640	]=	-3.76159E-02	;
    RnonCO2[	641	]=	-3.76159E-02	;
    RnonCO2[	642	]=	-3.76159E-02	;
    RnonCO2[	643	]=	-3.76159E-02	;
    RnonCO2[	644	]=	-3.76159E-02	;
    RnonCO2[	645	]=	-3.76159E-02	;
    RnonCO2[	646	]=	-3.76159E-02	;
    RnonCO2[	647	]=	-3.76159E-02	;
    RnonCO2[	648	]=	-3.76159E-02	;
    RnonCO2[	649	]=	-3.76159E-02	;
    RnonCO2[	650	]=	-3.76159E-02	;
    RnonCO2[	651	]=	-3.76159E-02	;
    RnonCO2[	652	]=	-3.76159E-02	;
    RnonCO2[	653	]=	-3.76159E-02	;
    RnonCO2[	654	]=	-3.76159E-02	;
    RnonCO2[	655	]=	-3.76159E-02	;
    RnonCO2[	656	]=	-3.76159E-02	;
    RnonCO2[	657	]=	-3.76159E-02	;
    RnonCO2[	658	]=	-3.76159E-02	;
    RnonCO2[	659	]=	-3.76159E-02	;
    RnonCO2[	660	]=	-3.76159E-02	;
    RnonCO2[	661	]=	-3.76159E-02	;
    RnonCO2[	662	]=	-3.76159E-02	;
    RnonCO2[	663	]=	-3.76159E-02	;
    RnonCO2[	664	]=	-3.76159E-02	;
    RnonCO2[	665	]=	-3.76159E-02	;
    RnonCO2[	666	]=	-3.76159E-02	;
    RnonCO2[	667	]=	-3.76159E-02	;
    RnonCO2[	668	]=	-3.76159E-02	;
    RnonCO2[	669	]=	-3.76159E-02	;
    RnonCO2[	670	]=	-3.76159E-02	;
    RnonCO2[	671	]=	-3.76159E-02	;
    RnonCO2[	672	]=	-3.76159E-02	;
    RnonCO2[	673	]=	-3.76159E-02	;
    RnonCO2[	674	]=	-3.76159E-02	;
    RnonCO2[	675	]=	-3.76159E-02	;
    RnonCO2[	676	]=	-3.76159E-02	;
    RnonCO2[	677	]=	-3.76159E-02	;
    RnonCO2[	678	]=	-3.76159E-02	;
    RnonCO2[	679	]=	-3.76159E-02	;
    RnonCO2[	680	]=	-3.76159E-02	;
    RnonCO2[	681	]=	-3.76159E-02	;
    RnonCO2[	682	]=	-3.76159E-02	;
    RnonCO2[	683	]=	-3.76159E-02	;
    RnonCO2[	684	]=	-3.76159E-02	;
    RnonCO2[	685	]=	-3.76159E-02	;
    RnonCO2[	686	]=	-3.76159E-02	;
    RnonCO2[	687	]=	-3.76159E-02	;
    RnonCO2[	688	]=	-3.76159E-02	;
    RnonCO2[	689	]=	-3.76159E-02	;
    RnonCO2[	690	]=	-3.76159E-02	;
    RnonCO2[	691	]=	-3.76159E-02	;
    RnonCO2[	692	]=	-3.76159E-02	;
    RnonCO2[	693	]=	-3.76159E-02	;
    RnonCO2[	694	]=	-3.76159E-02	;
    RnonCO2[	695	]=	-3.76159E-02	;
    RnonCO2[	696	]=	-3.76159E-02	;
    RnonCO2[	697	]=	-3.76159E-02	;
    RnonCO2[	698	]=	-3.76159E-02	;
    RnonCO2[	699	]=	-3.76159E-02	;
    RnonCO2[	700	]=	-3.76159E-02	;
    RnonCO2[	701	]=	-3.76159E-02	;
    RnonCO2[	702	]=	-3.76159E-02	;
    RnonCO2[	703	]=	-3.76159E-02	;
    RnonCO2[	704	]=	-3.76159E-02	;
    RnonCO2[	705	]=	-3.76159E-02	;
    RnonCO2[	706	]=	-3.76159E-02	;
    RnonCO2[	707	]=	-3.76159E-02	;
    RnonCO2[	708	]=	-3.76159E-02	;
    RnonCO2[	709	]=	-3.76159E-02	;
    RnonCO2[	710	]=	-3.76159E-02	;
    RnonCO2[	711	]=	-3.76159E-02	;
    RnonCO2[	712	]=	-3.76159E-02	;
    RnonCO2[	713	]=	-3.76159E-02	;
    RnonCO2[	714	]=	-3.76159E-02	;
    RnonCO2[	715	]=	-3.76159E-02	;
    RnonCO2[	716	]=	-3.76159E-02	;
    RnonCO2[	717	]=	-3.76159E-02	;
    RnonCO2[	718	]=	-3.76159E-02	;
    RnonCO2[	719	]=	-3.76159E-02	;
    RnonCO2[	720	]=	-3.76159E-02	;
    RnonCO2[	721	]=	-3.76159E-02	;
    RnonCO2[	722	]=	-3.76159E-02	;
    RnonCO2[	723	]=	-3.76159E-02	;
    RnonCO2[	724	]=	-3.76159E-02	;
    RnonCO2[	725	]=	-3.76159E-02	;
    RnonCO2[	726	]=	-3.76159E-02	;
    RnonCO2[	727	]=	-3.76159E-02	;
    RnonCO2[	728	]=	-3.76159E-02	;
    RnonCO2[	729	]=	-3.76159E-02	;
    RnonCO2[	730	]=	-3.76159E-02	;
    RnonCO2[	731	]=	-3.76159E-02	;
    RnonCO2[	732	]=	-3.76159E-02	;
    RnonCO2[	733	]=	-3.76159E-02	;
    RnonCO2[	734	]=	-3.76159E-02	;
    RnonCO2[	735	]=	-3.76159E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp460(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07201E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09085E+00	;
    RnonCO2[	253	]=	1.09962E+00	;
    RnonCO2[	254	]=	1.10891E+00	;
    RnonCO2[	255	]=	1.11848E+00	;
    RnonCO2[	256	]=	1.12836E+00	;
    RnonCO2[	257	]=	1.13843E+00	;
    RnonCO2[	258	]=	1.14857E+00	;
    RnonCO2[	259	]=	1.15882E+00	;
    RnonCO2[	260	]=	1.16921E+00	;
    RnonCO2[	261	]=	1.17980E+00	;
    RnonCO2[	262	]=	1.19045E+00	;
    RnonCO2[	263	]=	1.20108E+00	;
    RnonCO2[	264	]=	1.21178E+00	;
    RnonCO2[	265	]=	1.22262E+00	;
    RnonCO2[	266	]=	1.23365E+00	;
    RnonCO2[	267	]=	1.24441E+00	;
    RnonCO2[	268	]=	1.25454E+00	;
    RnonCO2[	269	]=	1.26419E+00	;
    RnonCO2[	270	]=	1.27347E+00	;
    RnonCO2[	271	]=	1.28246E+00	;
    RnonCO2[	272	]=	1.29122E+00	;
    RnonCO2[	273	]=	1.29978E+00	;
    RnonCO2[	274	]=	1.30820E+00	;
    RnonCO2[	275	]=	1.31650E+00	;
    RnonCO2[	276	]=	1.32469E+00	;
    RnonCO2[	277	]=	1.33266E+00	;
    RnonCO2[	278	]=	1.34030E+00	;
    RnonCO2[	279	]=	1.34763E+00	;
    RnonCO2[	280	]=	1.35468E+00	;
    RnonCO2[	281	]=	1.36147E+00	;
    RnonCO2[	282	]=	1.36803E+00	;
    RnonCO2[	283	]=	1.37437E+00	;
    RnonCO2[	284	]=	1.38050E+00	;
    RnonCO2[	285	]=	1.38645E+00	;
    RnonCO2[	286	]=	1.39222E+00	;
    RnonCO2[	287	]=	1.39772E+00	;
    RnonCO2[	288	]=	1.40287E+00	;
    RnonCO2[	289	]=	1.40771E+00	;
    RnonCO2[	290	]=	1.41225E+00	;
    RnonCO2[	291	]=	1.41650E+00	;
    RnonCO2[	292	]=	1.42049E+00	;
    RnonCO2[	293	]=	1.42422E+00	;
    RnonCO2[	294	]=	1.42771E+00	;
    RnonCO2[	295	]=	1.43097E+00	;
    RnonCO2[	296	]=	1.43401E+00	;
    RnonCO2[	297	]=	1.43678E+00	;
    RnonCO2[	298	]=	1.43923E+00	;
    RnonCO2[	299	]=	1.44137E+00	;
    RnonCO2[	300	]=	1.44323E+00	;
    RnonCO2[	301	]=	1.44481E+00	;
    RnonCO2[	302	]=	1.44614E+00	;
    RnonCO2[	303	]=	1.44722E+00	;
    RnonCO2[	304	]=	1.44808E+00	;
    RnonCO2[	305	]=	1.44871E+00	;
    RnonCO2[	306	]=	1.44913E+00	;
    RnonCO2[	307	]=	1.44933E+00	;
    RnonCO2[	308	]=	1.44928E+00	;
    RnonCO2[	309	]=	1.44899E+00	;
    RnonCO2[	310	]=	1.44848E+00	;
    RnonCO2[	311	]=	1.44776E+00	;
    RnonCO2[	312	]=	1.44685E+00	;
    RnonCO2[	313	]=	1.44575E+00	;
    RnonCO2[	314	]=	1.44447E+00	;
    RnonCO2[	315	]=	1.44303E+00	;
    RnonCO2[	316	]=	1.44142E+00	;
    RnonCO2[	317	]=	1.43970E+00	;
    RnonCO2[	318	]=	1.43788E+00	;
    RnonCO2[	319	]=	1.43597E+00	;
    RnonCO2[	320	]=	1.43397E+00	;
    RnonCO2[	321	]=	1.43189E+00	;
    RnonCO2[	322	]=	1.42973E+00	;
    RnonCO2[	323	]=	1.42750E+00	;
    RnonCO2[	324	]=	1.42521E+00	;
    RnonCO2[	325	]=	1.42285E+00	;
    RnonCO2[	326	]=	1.42044E+00	;
    RnonCO2[	327	]=	1.41803E+00	;
    RnonCO2[	328	]=	1.41567E+00	;
    RnonCO2[	329	]=	1.41336E+00	;
    RnonCO2[	330	]=	1.41109E+00	;
    RnonCO2[	331	]=	1.40887E+00	;
    RnonCO2[	332	]=	1.40668E+00	;
    RnonCO2[	333	]=	1.40454E+00	;
    RnonCO2[	334	]=	1.40244E+00	;
    RnonCO2[	335	]=	1.40038E+00	;
    RnonCO2[	336	]=	1.39836E+00	;
    RnonCO2[	337	]=	1.39637E+00	;
    RnonCO2[	338	]=	1.39438E+00	;
    RnonCO2[	339	]=	1.39240E+00	;
    RnonCO2[	340	]=	1.39041E+00	;
    RnonCO2[	341	]=	1.38843E+00	;
    RnonCO2[	342	]=	1.38645E+00	;
    RnonCO2[	343	]=	1.38448E+00	;
    RnonCO2[	344	]=	1.38251E+00	;
    RnonCO2[	345	]=	1.38054E+00	;
    RnonCO2[	346	]=	1.37858E+00	;
    RnonCO2[	347	]=	1.37663E+00	;
    RnonCO2[	348	]=	1.37468E+00	;
    RnonCO2[	349	]=	1.37274E+00	;
    RnonCO2[	350	]=	1.37081E+00	;
    RnonCO2[	351	]=	1.36889E+00	;
    RnonCO2[	352	]=	1.36697E+00	;
    RnonCO2[	353	]=	1.36506E+00	;
    RnonCO2[	354	]=	1.36316E+00	;
    RnonCO2[	355	]=	1.36126E+00	;
    RnonCO2[	356	]=	1.35938E+00	;
    RnonCO2[	357	]=	1.35750E+00	;
    RnonCO2[	358	]=	1.35563E+00	;
    RnonCO2[	359	]=	1.35377E+00	;
    RnonCO2[	360	]=	1.35191E+00	;
    RnonCO2[	361	]=	1.35006E+00	;
    RnonCO2[	362	]=	1.34822E+00	;
    RnonCO2[	363	]=	1.34639E+00	;
    RnonCO2[	364	]=	1.34456E+00	;
    RnonCO2[	365	]=	1.34275E+00	;
    RnonCO2[	366	]=	1.34093E+00	;
    RnonCO2[	367	]=	1.33913E+00	;
    RnonCO2[	368	]=	1.33733E+00	;
    RnonCO2[	369	]=	1.33554E+00	;
    RnonCO2[	370	]=	1.33375E+00	;
    RnonCO2[	371	]=	1.33197E+00	;
    RnonCO2[	372	]=	1.33020E+00	;
    RnonCO2[	373	]=	1.32843E+00	;
    RnonCO2[	374	]=	1.32667E+00	;
    RnonCO2[	375	]=	1.32491E+00	;
    RnonCO2[	376	]=	1.32316E+00	;
    RnonCO2[	377	]=	1.32141E+00	;
    RnonCO2[	378	]=	1.31967E+00	;
    RnonCO2[	379	]=	1.31794E+00	;
    RnonCO2[	380	]=	1.31620E+00	;
    RnonCO2[	381	]=	1.31447E+00	;
    RnonCO2[	382	]=	1.31274E+00	;
    RnonCO2[	383	]=	1.31102E+00	;
    RnonCO2[	384	]=	1.30930E+00	;
    RnonCO2[	385	]=	1.30758E+00	;
    RnonCO2[	386	]=	1.30587E+00	;
    RnonCO2[	387	]=	1.30416E+00	;
    RnonCO2[	388	]=	1.30245E+00	;
    RnonCO2[	389	]=	1.30075E+00	;
    RnonCO2[	390	]=	1.29904E+00	;
    RnonCO2[	391	]=	1.29734E+00	;
    RnonCO2[	392	]=	1.29564E+00	;
    RnonCO2[	393	]=	1.29395E+00	;
    RnonCO2[	394	]=	1.29225E+00	;
    RnonCO2[	395	]=	1.29056E+00	;
    RnonCO2[	396	]=	1.28886E+00	;
    RnonCO2[	397	]=	1.28717E+00	;
    RnonCO2[	398	]=	1.28548E+00	;
    RnonCO2[	399	]=	1.28379E+00	;
    RnonCO2[	400	]=	1.28210E+00	;
    RnonCO2[	401	]=	1.28041E+00	;
    RnonCO2[	402	]=	1.27872E+00	;
    RnonCO2[	403	]=	1.27702E+00	;
    RnonCO2[	404	]=	1.27534E+00	;
    RnonCO2[	405	]=	1.27365E+00	;
    RnonCO2[	406	]=	1.27195E+00	;
    RnonCO2[	407	]=	1.27026E+00	;
    RnonCO2[	408	]=	1.26857E+00	;
    RnonCO2[	409	]=	1.26687E+00	;
    RnonCO2[	410	]=	1.26518E+00	;
    RnonCO2[	411	]=	1.26348E+00	;
    RnonCO2[	412	]=	1.26179E+00	;
    RnonCO2[	413	]=	1.26009E+00	;
    RnonCO2[	414	]=	1.25839E+00	;
    RnonCO2[	415	]=	1.25669E+00	;
    RnonCO2[	416	]=	1.25499E+00	;
    RnonCO2[	417	]=	1.25328E+00	;
    RnonCO2[	418	]=	1.25158E+00	;
    RnonCO2[	419	]=	1.24987E+00	;
    RnonCO2[	420	]=	1.24816E+00	;
    RnonCO2[	421	]=	1.24645E+00	;
    RnonCO2[	422	]=	1.24474E+00	;
    RnonCO2[	423	]=	1.24302E+00	;
    RnonCO2[	424	]=	1.24130E+00	;
    RnonCO2[	425	]=	1.23958E+00	;
    RnonCO2[	426	]=	1.23785E+00	;
    RnonCO2[	427	]=	1.23613E+00	;
    RnonCO2[	428	]=	1.23440E+00	;
    RnonCO2[	429	]=	1.23266E+00	;
    RnonCO2[	430	]=	1.23092E+00	;
    RnonCO2[	431	]=	1.22918E+00	;
    RnonCO2[	432	]=	1.22744E+00	;
    RnonCO2[	433	]=	1.22569E+00	;
    RnonCO2[	434	]=	1.22394E+00	;
    RnonCO2[	435	]=	1.22219E+00	;
    RnonCO2[	436	]=	1.22043E+00	;
    RnonCO2[	437	]=	1.21867E+00	;
    RnonCO2[	438	]=	1.21690E+00	;
    RnonCO2[	439	]=	1.21514E+00	;
    RnonCO2[	440	]=	1.21336E+00	;
    RnonCO2[	441	]=	1.21159E+00	;
    RnonCO2[	442	]=	1.20980E+00	;
    RnonCO2[	443	]=	1.20802E+00	;
    RnonCO2[	444	]=	1.20624E+00	;
    RnonCO2[	445	]=	1.20444E+00	;
    RnonCO2[	446	]=	1.20265E+00	;
    RnonCO2[	447	]=	1.20084E+00	;
    RnonCO2[	448	]=	1.19904E+00	;
    RnonCO2[	449	]=	1.19723E+00	;
    RnonCO2[	450	]=	1.19542E+00	;
    RnonCO2[	451	]=	1.19360E+00	;
    RnonCO2[	452	]=	1.19178E+00	;
    RnonCO2[	453	]=	1.18995E+00	;
    RnonCO2[	454	]=	1.18812E+00	;
    RnonCO2[	455	]=	1.18629E+00	;
    RnonCO2[	456	]=	1.18445E+00	;
    RnonCO2[	457	]=	1.18260E+00	;
    RnonCO2[	458	]=	1.18075E+00	;
    RnonCO2[	459	]=	1.17890E+00	;
    RnonCO2[	460	]=	1.17704E+00	;
    RnonCO2[	461	]=	1.17518E+00	;
    RnonCO2[	462	]=	1.17331E+00	;
    RnonCO2[	463	]=	1.17144E+00	;
    RnonCO2[	464	]=	1.16956E+00	;
    RnonCO2[	465	]=	1.16768E+00	;
    RnonCO2[	466	]=	1.16580E+00	;
    RnonCO2[	467	]=	1.16390E+00	;
    RnonCO2[	468	]=	1.16200E+00	;
    RnonCO2[	469	]=	1.16010E+00	;
    RnonCO2[	470	]=	1.15820E+00	;
    RnonCO2[	471	]=	1.15628E+00	;
    RnonCO2[	472	]=	1.15437E+00	;
    RnonCO2[	473	]=	1.15244E+00	;
    RnonCO2[	474	]=	1.15052E+00	;
    RnonCO2[	475	]=	1.14859E+00	;
    RnonCO2[	476	]=	1.14665E+00	;
    RnonCO2[	477	]=	1.14470E+00	;
    RnonCO2[	478	]=	1.14276E+00	;
    RnonCO2[	479	]=	1.14080E+00	;
    RnonCO2[	480	]=	1.13884E+00	;
    RnonCO2[	481	]=	1.13688E+00	;
    RnonCO2[	482	]=	1.13491E+00	;
    RnonCO2[	483	]=	1.13294E+00	;
    RnonCO2[	484	]=	1.13096E+00	;
    RnonCO2[	485	]=	1.12897E+00	;
    RnonCO2[	486	]=	1.12698E+00	;
    RnonCO2[	487	]=	1.12506E+00	;
    RnonCO2[	488	]=	1.12327E+00	;
    RnonCO2[	489	]=	1.12159E+00	;
    RnonCO2[	490	]=	1.12003E+00	;
    RnonCO2[	491	]=	1.11857E+00	;
    RnonCO2[	492	]=	1.11721E+00	;
    RnonCO2[	493	]=	1.11593E+00	;
    RnonCO2[	494	]=	1.11474E+00	;
    RnonCO2[	495	]=	1.11362E+00	;
    RnonCO2[	496	]=	1.11257E+00	;
    RnonCO2[	497	]=	1.11159E+00	;
    RnonCO2[	498	]=	1.11067E+00	;
    RnonCO2[	499	]=	1.10980E+00	;
    RnonCO2[	500	]=	1.10899E+00	;
    RnonCO2[	501	]=	1.10823E+00	;
    RnonCO2[	502	]=	1.10751E+00	;
    RnonCO2[	503	]=	1.10682E+00	;
    RnonCO2[	504	]=	1.10618E+00	;
    RnonCO2[	505	]=	1.10558E+00	;
    RnonCO2[	506	]=	1.10501E+00	;
    RnonCO2[	507	]=	1.10446E+00	;
    RnonCO2[	508	]=	1.10395E+00	;
    RnonCO2[	509	]=	1.10347E+00	;
    RnonCO2[	510	]=	1.10300E+00	;
    RnonCO2[	511	]=	1.10256E+00	;
    RnonCO2[	512	]=	1.10215E+00	;
    RnonCO2[	513	]=	1.10175E+00	;
    RnonCO2[	514	]=	1.10137E+00	;
    RnonCO2[	515	]=	1.10101E+00	;
    RnonCO2[	516	]=	1.10066E+00	;
    RnonCO2[	517	]=	1.10033E+00	;
    RnonCO2[	518	]=	1.10001E+00	;
    RnonCO2[	519	]=	1.09970E+00	;
    RnonCO2[	520	]=	1.09941E+00	;
    RnonCO2[	521	]=	1.09912E+00	;
    RnonCO2[	522	]=	1.09886E+00	;
    RnonCO2[	523	]=	1.09859E+00	;
    RnonCO2[	524	]=	1.09834E+00	;
    RnonCO2[	525	]=	1.09809E+00	;
    RnonCO2[	526	]=	1.09786E+00	;
    RnonCO2[	527	]=	1.09763E+00	;
    RnonCO2[	528	]=	1.09741E+00	;
    RnonCO2[	529	]=	1.09719E+00	;
    RnonCO2[	530	]=	1.09698E+00	;
    RnonCO2[	531	]=	1.09678E+00	;
    RnonCO2[	532	]=	1.09658E+00	;
    RnonCO2[	533	]=	1.09638E+00	;
    RnonCO2[	534	]=	1.09620E+00	;
    RnonCO2[	535	]=	1.09601E+00	;
    RnonCO2[	536	]=	1.09583E+00	;
    RnonCO2[	537	]=	1.09566E+00	;
    RnonCO2[	538	]=	1.09549E+00	;
    RnonCO2[	539	]=	1.09532E+00	;
    RnonCO2[	540	]=	1.09515E+00	;
    RnonCO2[	541	]=	1.09499E+00	;
    RnonCO2[	542	]=	1.09483E+00	;
    RnonCO2[	543	]=	1.09468E+00	;
    RnonCO2[	544	]=	1.09452E+00	;
    RnonCO2[	545	]=	1.09437E+00	;
    RnonCO2[	546	]=	1.09423E+00	;
    RnonCO2[	547	]=	1.09408E+00	;
    RnonCO2[	548	]=	1.09394E+00	;
    RnonCO2[	549	]=	1.09380E+00	;
    RnonCO2[	550	]=	1.09367E+00	;
    RnonCO2[	551	]=	1.09353E+00	;
    RnonCO2[	552	]=	1.09340E+00	;
    RnonCO2[	553	]=	1.09327E+00	;
    RnonCO2[	554	]=	1.09313E+00	;
    RnonCO2[	555	]=	1.09300E+00	;
    RnonCO2[	556	]=	1.09288E+00	;
    RnonCO2[	557	]=	1.09275E+00	;
    RnonCO2[	558	]=	1.09263E+00	;
    RnonCO2[	559	]=	1.09251E+00	;
    RnonCO2[	560	]=	1.09239E+00	;
    RnonCO2[	561	]=	1.09227E+00	;
    RnonCO2[	562	]=	1.09216E+00	;
    RnonCO2[	563	]=	1.09204E+00	;
    RnonCO2[	564	]=	1.09193E+00	;
    RnonCO2[	565	]=	1.09181E+00	;
    RnonCO2[	566	]=	1.09170E+00	;
    RnonCO2[	567	]=	1.09159E+00	;
    RnonCO2[	568	]=	1.09148E+00	;
    RnonCO2[	569	]=	1.09138E+00	;
    RnonCO2[	570	]=	1.09127E+00	;
    RnonCO2[	571	]=	1.09116E+00	;
    RnonCO2[	572	]=	1.09106E+00	;
    RnonCO2[	573	]=	1.09096E+00	;
    RnonCO2[	574	]=	1.09085E+00	;
    RnonCO2[	575	]=	1.09075E+00	;
    RnonCO2[	576	]=	1.09065E+00	;
    RnonCO2[	577	]=	1.09055E+00	;
    RnonCO2[	578	]=	1.09045E+00	;
    RnonCO2[	579	]=	1.09036E+00	;
    RnonCO2[	580	]=	1.09026E+00	;
    RnonCO2[	581	]=	1.09017E+00	;
    RnonCO2[	582	]=	1.09007E+00	;
    RnonCO2[	583	]=	1.08998E+00	;
    RnonCO2[	584	]=	1.08989E+00	;
    RnonCO2[	585	]=	1.08979E+00	;
    RnonCO2[	586	]=	1.08970E+00	;
    RnonCO2[	587	]=	1.08961E+00	;
    RnonCO2[	588	]=	1.08953E+00	;
    RnonCO2[	589	]=	1.08943E+00	;
    RnonCO2[	590	]=	1.08935E+00	;
    RnonCO2[	591	]=	1.08926E+00	;
    RnonCO2[	592	]=	1.08918E+00	;
    RnonCO2[	593	]=	1.08909E+00	;
    RnonCO2[	594	]=	1.08901E+00	;
    RnonCO2[	595	]=	1.08892E+00	;
    RnonCO2[	596	]=	1.08884E+00	;
    RnonCO2[	597	]=	1.08876E+00	;
    RnonCO2[	598	]=	1.08868E+00	;
    RnonCO2[	599	]=	1.08859E+00	;
    RnonCO2[	600	]=	1.08851E+00	;
    RnonCO2[	601	]=	1.08844E+00	;
    RnonCO2[	602	]=	1.08836E+00	;
    RnonCO2[	603	]=	1.08828E+00	;
    RnonCO2[	604	]=	1.08820E+00	;
    RnonCO2[	605	]=	1.08812E+00	;
    RnonCO2[	606	]=	1.08805E+00	;
    RnonCO2[	607	]=	1.08797E+00	;
    RnonCO2[	608	]=	1.08790E+00	;
    RnonCO2[	609	]=	1.08782E+00	;
    RnonCO2[	610	]=	1.08775E+00	;
    RnonCO2[	611	]=	1.08767E+00	;
    RnonCO2[	612	]=	1.08760E+00	;
    RnonCO2[	613	]=	1.08753E+00	;
    RnonCO2[	614	]=	1.08746E+00	;
    RnonCO2[	615	]=	1.08739E+00	;
    RnonCO2[	616	]=	1.08732E+00	;
    RnonCO2[	617	]=	1.08725E+00	;
    RnonCO2[	618	]=	1.08718E+00	;
    RnonCO2[	619	]=	1.08711E+00	;
    RnonCO2[	620	]=	1.08704E+00	;
    RnonCO2[	621	]=	1.08697E+00	;
    RnonCO2[	622	]=	1.08691E+00	;
    RnonCO2[	623	]=	1.08684E+00	;
    RnonCO2[	624	]=	1.08677E+00	;
    RnonCO2[	625	]=	1.08671E+00	;
    RnonCO2[	626	]=	1.08664E+00	;
    RnonCO2[	627	]=	1.08658E+00	;
    RnonCO2[	628	]=	1.08652E+00	;
    RnonCO2[	629	]=	1.08645E+00	;
    RnonCO2[	630	]=	1.08639E+00	;
    RnonCO2[	631	]=	1.08633E+00	;
    RnonCO2[	632	]=	1.08626E+00	;
    RnonCO2[	633	]=	1.08620E+00	;
    RnonCO2[	634	]=	1.08614E+00	;
    RnonCO2[	635	]=	1.08608E+00	;
    RnonCO2[	636	]=	1.08602E+00	;
    RnonCO2[	637	]=	1.08596E+00	;
    RnonCO2[	638	]=	1.08590E+00	;
    RnonCO2[	639	]=	1.08584E+00	;
    RnonCO2[	640	]=	1.08578E+00	;
    RnonCO2[	641	]=	1.08573E+00	;
    RnonCO2[	642	]=	1.08567E+00	;
    RnonCO2[	643	]=	1.08561E+00	;
    RnonCO2[	644	]=	1.08555E+00	;
    RnonCO2[	645	]=	1.08549E+00	;
    RnonCO2[	646	]=	1.08544E+00	;
    RnonCO2[	647	]=	1.08538E+00	;
    RnonCO2[	648	]=	1.08533E+00	;
    RnonCO2[	649	]=	1.08527E+00	;
    RnonCO2[	650	]=	1.08522E+00	;
    RnonCO2[	651	]=	1.08516E+00	;
    RnonCO2[	652	]=	1.08511E+00	;
    RnonCO2[	653	]=	1.08505E+00	;
    RnonCO2[	654	]=	1.08501E+00	;
    RnonCO2[	655	]=	1.08495E+00	;
    RnonCO2[	656	]=	1.08490E+00	;
    RnonCO2[	657	]=	1.08484E+00	;
    RnonCO2[	658	]=	1.08479E+00	;
    RnonCO2[	659	]=	1.08474E+00	;
    RnonCO2[	660	]=	1.08469E+00	;
    RnonCO2[	661	]=	1.08464E+00	;
    RnonCO2[	662	]=	1.08459E+00	;
    RnonCO2[	663	]=	1.08454E+00	;
    RnonCO2[	664	]=	1.08449E+00	;
    RnonCO2[	665	]=	1.08444E+00	;
    RnonCO2[	666	]=	1.08439E+00	;
    RnonCO2[	667	]=	1.08434E+00	;
    RnonCO2[	668	]=	1.08429E+00	;
    RnonCO2[	669	]=	1.08425E+00	;
    RnonCO2[	670	]=	1.08420E+00	;
    RnonCO2[	671	]=	1.08415E+00	;
    RnonCO2[	672	]=	1.08410E+00	;
    RnonCO2[	673	]=	1.08406E+00	;
    RnonCO2[	674	]=	1.08401E+00	;
    RnonCO2[	675	]=	1.08396E+00	;
    RnonCO2[	676	]=	1.08391E+00	;
    RnonCO2[	677	]=	1.08387E+00	;
    RnonCO2[	678	]=	1.08382E+00	;
    RnonCO2[	679	]=	1.08378E+00	;
    RnonCO2[	680	]=	1.08374E+00	;
    RnonCO2[	681	]=	1.08369E+00	;
    RnonCO2[	682	]=	1.08364E+00	;
    RnonCO2[	683	]=	1.08360E+00	;
    RnonCO2[	684	]=	1.08355E+00	;
    RnonCO2[	685	]=	1.08351E+00	;
    RnonCO2[	686	]=	1.08347E+00	;
    RnonCO2[	687	]=	1.08342E+00	;
    RnonCO2[	688	]=	1.08338E+00	;
    RnonCO2[	689	]=	1.08334E+00	;
    RnonCO2[	690	]=	1.08330E+00	;
    RnonCO2[	691	]=	1.08325E+00	;
    RnonCO2[	692	]=	1.08321E+00	;
    RnonCO2[	693	]=	1.08317E+00	;
    RnonCO2[	694	]=	1.08313E+00	;
    RnonCO2[	695	]=	1.08309E+00	;
    RnonCO2[	696	]=	1.08304E+00	;
    RnonCO2[	697	]=	1.08300E+00	;
    RnonCO2[	698	]=	1.08296E+00	;
    RnonCO2[	699	]=	1.08292E+00	;
    RnonCO2[	700	]=	1.08288E+00	;
    RnonCO2[	701	]=	1.08284E+00	;
    RnonCO2[	702	]=	1.08280E+00	;
    RnonCO2[	703	]=	1.08276E+00	;
    RnonCO2[	704	]=	1.08272E+00	;
    RnonCO2[	705	]=	1.08268E+00	;
    RnonCO2[	706	]=	1.08264E+00	;
    RnonCO2[	707	]=	1.08260E+00	;
    RnonCO2[	708	]=	1.08256E+00	;
    RnonCO2[	709	]=	1.08252E+00	;
    RnonCO2[	710	]=	1.08248E+00	;
    RnonCO2[	711	]=	1.08245E+00	;
    RnonCO2[	712	]=	1.08241E+00	;
    RnonCO2[	713	]=	1.08237E+00	;
    RnonCO2[	714	]=	1.08233E+00	;
    RnonCO2[	715	]=	1.08229E+00	;
    RnonCO2[	716	]=	1.08226E+00	;
    RnonCO2[	717	]=	1.08222E+00	;
    RnonCO2[	718	]=	1.08218E+00	;
    RnonCO2[	719	]=	1.08214E+00	;
    RnonCO2[	720	]=	1.08211E+00	;
    RnonCO2[	721	]=	1.08207E+00	;
    RnonCO2[	722	]=	1.08203E+00	;
    RnonCO2[	723	]=	1.08200E+00	;
    RnonCO2[	724	]=	1.08196E+00	;
    RnonCO2[	725	]=	1.08192E+00	;
    RnonCO2[	726	]=	1.08189E+00	;
    RnonCO2[	727	]=	1.08185E+00	;
    RnonCO2[	728	]=	1.08182E+00	;
    RnonCO2[	729	]=	1.08178E+00	;
    RnonCO2[	730	]=	1.08174E+00	;
    RnonCO2[	731	]=	1.08171E+00	;
    RnonCO2[	732	]=	1.08167E+00	;
    RnonCO2[	733	]=	1.08164E+00	;
    RnonCO2[	734	]=	1.08160E+00	;
    RnonCO2[	735	]=	1.08158E+00	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp460(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.18135E+00	;
    RnonCO2[	252	]=	-1.16072E+00	;
    RnonCO2[	253	]=	-1.13983E+00	;
    RnonCO2[	254	]=	-1.11865E+00	;
    RnonCO2[	255	]=	-1.09719E+00	;
    RnonCO2[	256	]=	-1.09871E+00	;
    RnonCO2[	257	]=	-1.10022E+00	;
    RnonCO2[	258	]=	-1.10174E+00	;
    RnonCO2[	259	]=	-1.10326E+00	;
    RnonCO2[	260	]=	-1.10477E+00	;
    RnonCO2[	261	]=	-1.10628E+00	;
    RnonCO2[	262	]=	-1.10779E+00	;
    RnonCO2[	263	]=	-1.10930E+00	;
    RnonCO2[	264	]=	-1.11081E+00	;
    RnonCO2[	265	]=	-1.11232E+00	;
    RnonCO2[	266	]=	-1.10955E+00	;
    RnonCO2[	267	]=	-1.10677E+00	;
    RnonCO2[	268	]=	-1.10399E+00	;
    RnonCO2[	269	]=	-1.10119E+00	;
    RnonCO2[	270	]=	-1.09839E+00	;
    RnonCO2[	271	]=	-1.09559E+00	;
    RnonCO2[	272	]=	-1.09277E+00	;
    RnonCO2[	273	]=	-1.08995E+00	;
    RnonCO2[	274	]=	-1.08712E+00	;
    RnonCO2[	275	]=	-1.08429E+00	;
    RnonCO2[	276	]=	-1.07828E+00	;
    RnonCO2[	277	]=	-1.07224E+00	;
    RnonCO2[	278	]=	-1.06618E+00	;
    RnonCO2[	279	]=	-1.06008E+00	;
    RnonCO2[	280	]=	-1.05396E+00	;
    RnonCO2[	281	]=	-1.04781E+00	;
    RnonCO2[	282	]=	-1.04163E+00	;
    RnonCO2[	283	]=	-1.03543E+00	;
    RnonCO2[	284	]=	-1.02919E+00	;
    RnonCO2[	285	]=	-1.02292E+00	;
    RnonCO2[	286	]=	-1.01661E+00	;
    RnonCO2[	287	]=	-1.01027E+00	;
    RnonCO2[	288	]=	-1.00390E+00	;
    RnonCO2[	289	]=	-9.97493E-01	;
    RnonCO2[	290	]=	-9.91056E-01	;
    RnonCO2[	291	]=	-9.84587E-01	;
    RnonCO2[	292	]=	-9.78085E-01	;
    RnonCO2[	293	]=	-9.71549E-01	;
    RnonCO2[	294	]=	-9.64980E-01	;
    RnonCO2[	295	]=	-9.58377E-01	;
    RnonCO2[	296	]=	-9.50122E-01	;
    RnonCO2[	297	]=	-9.41816E-01	;
    RnonCO2[	298	]=	-9.33457E-01	;
    RnonCO2[	299	]=	-9.25045E-01	;
    RnonCO2[	300	]=	-9.16579E-01	;
    RnonCO2[	301	]=	-9.08057E-01	;
    RnonCO2[	302	]=	-8.99480E-01	;
    RnonCO2[	303	]=	-8.90847E-01	;
    RnonCO2[	304	]=	-8.82156E-01	;
    RnonCO2[	305	]=	-8.73406E-01	;
    RnonCO2[	306	]=	-8.60452E-01	;
    RnonCO2[	307	]=	-8.47374E-01	;
    RnonCO2[	308	]=	-8.34170E-01	;
    RnonCO2[	309	]=	-8.20838E-01	;
    RnonCO2[	310	]=	-8.07375E-01	;
    RnonCO2[	311	]=	-7.93777E-01	;
    RnonCO2[	312	]=	-7.80042E-01	;
    RnonCO2[	313	]=	-7.66165E-01	;
    RnonCO2[	314	]=	-7.52145E-01	;
    RnonCO2[	315	]=	-7.37977E-01	;
    RnonCO2[	316	]=	-7.27296E-01	;
    RnonCO2[	317	]=	-7.16529E-01	;
    RnonCO2[	318	]=	-7.05674E-01	;
    RnonCO2[	319	]=	-6.94729E-01	;
    RnonCO2[	320	]=	-6.83693E-01	;
    RnonCO2[	321	]=	-6.72565E-01	;
    RnonCO2[	322	]=	-6.61341E-01	;
    RnonCO2[	323	]=	-6.50021E-01	;
    RnonCO2[	324	]=	-6.38603E-01	;
    RnonCO2[	325	]=	-6.27084E-01	;
    RnonCO2[	326	]=	-6.18338E-01	;
    RnonCO2[	327	]=	-6.09534E-01	;
    RnonCO2[	328	]=	-6.00672E-01	;
    RnonCO2[	329	]=	-5.91751E-01	;
    RnonCO2[	330	]=	-5.82769E-01	;
    RnonCO2[	331	]=	-5.73726E-01	;
    RnonCO2[	332	]=	-5.64621E-01	;
    RnonCO2[	333	]=	-5.55453E-01	;
    RnonCO2[	334	]=	-5.46221E-01	;
    RnonCO2[	335	]=	-5.36923E-01	;
    RnonCO2[	336	]=	-5.34132E-01	;
    RnonCO2[	337	]=	-5.31335E-01	;
    RnonCO2[	338	]=	-5.28534E-01	;
    RnonCO2[	339	]=	-5.25728E-01	;
    RnonCO2[	340	]=	-5.22917E-01	;
    RnonCO2[	341	]=	-5.20101E-01	;
    RnonCO2[	342	]=	-5.17280E-01	;
    RnonCO2[	343	]=	-5.14454E-01	;
    RnonCO2[	344	]=	-5.11623E-01	;
    RnonCO2[	345	]=	-5.08786E-01	;
    RnonCO2[	346	]=	-5.05945E-01	;
    RnonCO2[	347	]=	-5.03099E-01	;
    RnonCO2[	348	]=	-5.00248E-01	;
    RnonCO2[	349	]=	-4.97392E-01	;
    RnonCO2[	350	]=	-4.94530E-01	;
    RnonCO2[	351	]=	-4.91664E-01	;
    RnonCO2[	352	]=	-4.88792E-01	;
    RnonCO2[	353	]=	-4.85915E-01	;
    RnonCO2[	354	]=	-4.83032E-01	;
    RnonCO2[	355	]=	-4.80144E-01	;
    RnonCO2[	356	]=	-4.77251E-01	;
    RnonCO2[	357	]=	-4.74353E-01	;
    RnonCO2[	358	]=	-4.71449E-01	;
    RnonCO2[	359	]=	-4.68540E-01	;
    RnonCO2[	360	]=	-4.65625E-01	;
    RnonCO2[	361	]=	-4.62705E-01	;
    RnonCO2[	362	]=	-4.59780E-01	;
    RnonCO2[	363	]=	-4.56849E-01	;
    RnonCO2[	364	]=	-4.53912E-01	;
    RnonCO2[	365	]=	-4.50970E-01	;
    RnonCO2[	366	]=	-4.48023E-01	;
    RnonCO2[	367	]=	-4.45069E-01	;
    RnonCO2[	368	]=	-4.42110E-01	;
    RnonCO2[	369	]=	-4.39145E-01	;
    RnonCO2[	370	]=	-4.36175E-01	;
    RnonCO2[	371	]=	-4.33199E-01	;
    RnonCO2[	372	]=	-4.30217E-01	;
    RnonCO2[	373	]=	-4.27229E-01	;
    RnonCO2[	374	]=	-4.24236E-01	;
    RnonCO2[	375	]=	-4.21237E-01	;
    RnonCO2[	376	]=	-4.18232E-01	;
    RnonCO2[	377	]=	-4.15221E-01	;
    RnonCO2[	378	]=	-4.12205E-01	;
    RnonCO2[	379	]=	-4.09182E-01	;
    RnonCO2[	380	]=	-4.06154E-01	;
    RnonCO2[	381	]=	-4.03120E-01	;
    RnonCO2[	382	]=	-4.00079E-01	;
    RnonCO2[	383	]=	-3.97033E-01	;
    RnonCO2[	384	]=	-3.93980E-01	;
    RnonCO2[	385	]=	-3.90922E-01	;
    RnonCO2[	386	]=	-3.87857E-01	;
    RnonCO2[	387	]=	-3.84786E-01	;
    RnonCO2[	388	]=	-3.81710E-01	;
    RnonCO2[	389	]=	-3.78626E-01	;
    RnonCO2[	390	]=	-3.75537E-01	;
    RnonCO2[	391	]=	-3.72441E-01	;
    RnonCO2[	392	]=	-3.69339E-01	;
    RnonCO2[	393	]=	-3.66231E-01	;
    RnonCO2[	394	]=	-3.63116E-01	;
    RnonCO2[	395	]=	-3.59995E-01	;
    RnonCO2[	396	]=	-3.56868E-01	;
    RnonCO2[	397	]=	-3.53733E-01	;
    RnonCO2[	398	]=	-3.50593E-01	;
    RnonCO2[	399	]=	-3.47445E-01	;
    RnonCO2[	400	]=	-3.44292E-01	;
    RnonCO2[	401	]=	-3.41131E-01	;
    RnonCO2[	402	]=	-3.37964E-01	;
    RnonCO2[	403	]=	-3.34790E-01	;
    RnonCO2[	404	]=	-3.31610E-01	;
    RnonCO2[	405	]=	-3.28423E-01	;
    RnonCO2[	406	]=	-3.25229E-01	;
    RnonCO2[	407	]=	-3.22029E-01	;
    RnonCO2[	408	]=	-3.18822E-01	;
    RnonCO2[	409	]=	-3.15608E-01	;
    RnonCO2[	410	]=	-3.12386E-01	;
    RnonCO2[	411	]=	-3.09159E-01	;
    RnonCO2[	412	]=	-3.05924E-01	;
    RnonCO2[	413	]=	-3.02682E-01	;
    RnonCO2[	414	]=	-2.99433E-01	;
    RnonCO2[	415	]=	-2.96177E-01	;
    RnonCO2[	416	]=	-2.92914E-01	;
    RnonCO2[	417	]=	-2.89643E-01	;
    RnonCO2[	418	]=	-2.86366E-01	;
    RnonCO2[	419	]=	-2.83081E-01	;
    RnonCO2[	420	]=	-2.79789E-01	;
    RnonCO2[	421	]=	-2.76490E-01	;
    RnonCO2[	422	]=	-2.73183E-01	;
    RnonCO2[	423	]=	-2.69869E-01	;
    RnonCO2[	424	]=	-2.66548E-01	;
    RnonCO2[	425	]=	-2.63219E-01	;
    RnonCO2[	426	]=	-2.59883E-01	;
    RnonCO2[	427	]=	-2.56538E-01	;
    RnonCO2[	428	]=	-2.53187E-01	;
    RnonCO2[	429	]=	-2.49827E-01	;
    RnonCO2[	430	]=	-2.46460E-01	;
    RnonCO2[	431	]=	-2.43085E-01	;
    RnonCO2[	432	]=	-2.39703E-01	;
    RnonCO2[	433	]=	-2.36312E-01	;
    RnonCO2[	434	]=	-2.32914E-01	;
    RnonCO2[	435	]=	-2.29508E-01	;
    RnonCO2[	436	]=	-2.26094E-01	;
    RnonCO2[	437	]=	-2.22673E-01	;
    RnonCO2[	438	]=	-2.19243E-01	;
    RnonCO2[	439	]=	-2.15805E-01	;
    RnonCO2[	440	]=	-2.12360E-01	;
    RnonCO2[	441	]=	-2.08906E-01	;
    RnonCO2[	442	]=	-2.05444E-01	;
    RnonCO2[	443	]=	-2.01973E-01	;
    RnonCO2[	444	]=	-1.98495E-01	;
    RnonCO2[	445	]=	-1.95008E-01	;
    RnonCO2[	446	]=	-1.91512E-01	;
    RnonCO2[	447	]=	-1.88008E-01	;
    RnonCO2[	448	]=	-1.84496E-01	;
    RnonCO2[	449	]=	-1.80975E-01	;
    RnonCO2[	450	]=	-1.77445E-01	;
    RnonCO2[	451	]=	-1.73907E-01	;
    RnonCO2[	452	]=	-1.70361E-01	;
    RnonCO2[	453	]=	-1.66805E-01	;
    RnonCO2[	454	]=	-1.63241E-01	;
    RnonCO2[	455	]=	-1.59668E-01	;
    RnonCO2[	456	]=	-1.56086E-01	;
    RnonCO2[	457	]=	-1.52495E-01	;
    RnonCO2[	458	]=	-1.48895E-01	;
    RnonCO2[	459	]=	-1.45285E-01	;
    RnonCO2[	460	]=	-1.41667E-01	;
    RnonCO2[	461	]=	-1.38040E-01	;
    RnonCO2[	462	]=	-1.34403E-01	;
    RnonCO2[	463	]=	-1.30757E-01	;
    RnonCO2[	464	]=	-1.27102E-01	;
    RnonCO2[	465	]=	-1.23438E-01	;
    RnonCO2[	466	]=	-1.19764E-01	;
    RnonCO2[	467	]=	-1.16081E-01	;
    RnonCO2[	468	]=	-1.12389E-01	;
    RnonCO2[	469	]=	-1.08687E-01	;
    RnonCO2[	470	]=	-1.04975E-01	;
    RnonCO2[	471	]=	-1.01253E-01	;
    RnonCO2[	472	]=	-9.75221E-02	;
    RnonCO2[	473	]=	-9.37810E-02	;
    RnonCO2[	474	]=	-9.00301E-02	;
    RnonCO2[	475	]=	-8.62692E-02	;
    RnonCO2[	476	]=	-8.24983E-02	;
    RnonCO2[	477	]=	-7.87173E-02	;
    RnonCO2[	478	]=	-7.49262E-02	;
    RnonCO2[	479	]=	-7.11249E-02	;
    RnonCO2[	480	]=	-6.73133E-02	;
    RnonCO2[	481	]=	-6.34914E-02	;
    RnonCO2[	482	]=	-5.96591E-02	;
    RnonCO2[	483	]=	-5.58164E-02	;
    RnonCO2[	484	]=	-5.19631E-02	;
    RnonCO2[	485	]=	-4.80993E-02	;
    RnonCO2[	486	]=	-4.80993E-02	;
    RnonCO2[	487	]=	-4.80993E-02	;
    RnonCO2[	488	]=	-4.80993E-02	;
    RnonCO2[	489	]=	-4.80993E-02	;
    RnonCO2[	490	]=	-4.80993E-02	;
    RnonCO2[	491	]=	-4.80993E-02	;
    RnonCO2[	492	]=	-4.80993E-02	;
    RnonCO2[	493	]=	-4.80993E-02	;
    RnonCO2[	494	]=	-4.80993E-02	;
    RnonCO2[	495	]=	-4.80993E-02	;
    RnonCO2[	496	]=	-4.80993E-02	;
    RnonCO2[	497	]=	-4.80993E-02	;
    RnonCO2[	498	]=	-4.80993E-02	;
    RnonCO2[	499	]=	-4.80993E-02	;
    RnonCO2[	500	]=	-4.80993E-02	;
    RnonCO2[	501	]=	-4.80993E-02	;
    RnonCO2[	502	]=	-4.80993E-02	;
    RnonCO2[	503	]=	-4.80993E-02	;
    RnonCO2[	504	]=	-4.80993E-02	;
    RnonCO2[	505	]=	-4.80993E-02	;
    RnonCO2[	506	]=	-4.80993E-02	;
    RnonCO2[	507	]=	-4.80993E-02	;
    RnonCO2[	508	]=	-4.80993E-02	;
    RnonCO2[	509	]=	-4.80993E-02	;
    RnonCO2[	510	]=	-4.80993E-02	;
    RnonCO2[	511	]=	-4.80993E-02	;
    RnonCO2[	512	]=	-4.80993E-02	;
    RnonCO2[	513	]=	-4.80993E-02	;
    RnonCO2[	514	]=	-4.80993E-02	;
    RnonCO2[	515	]=	-4.80993E-02	;
    RnonCO2[	516	]=	-4.80993E-02	;
    RnonCO2[	517	]=	-4.80993E-02	;
    RnonCO2[	518	]=	-4.80993E-02	;
    RnonCO2[	519	]=	-4.80993E-02	;
    RnonCO2[	520	]=	-4.80993E-02	;
    RnonCO2[	521	]=	-4.80993E-02	;
    RnonCO2[	522	]=	-4.80993E-02	;
    RnonCO2[	523	]=	-4.80993E-02	;
    RnonCO2[	524	]=	-4.80993E-02	;
    RnonCO2[	525	]=	-4.80993E-02	;
    RnonCO2[	526	]=	-4.80993E-02	;
    RnonCO2[	527	]=	-4.80993E-02	;
    RnonCO2[	528	]=	-4.80993E-02	;
    RnonCO2[	529	]=	-4.80993E-02	;
    RnonCO2[	530	]=	-4.80993E-02	;
    RnonCO2[	531	]=	-4.80993E-02	;
    RnonCO2[	532	]=	-4.80993E-02	;
    RnonCO2[	533	]=	-4.80993E-02	;
    RnonCO2[	534	]=	-4.80993E-02	;
    RnonCO2[	535	]=	-4.80993E-02	;
    RnonCO2[	536	]=	-4.80993E-02	;
    RnonCO2[	537	]=	-4.80993E-02	;
    RnonCO2[	538	]=	-4.80993E-02	;
    RnonCO2[	539	]=	-4.80993E-02	;
    RnonCO2[	540	]=	-4.80993E-02	;
    RnonCO2[	541	]=	-4.80993E-02	;
    RnonCO2[	542	]=	-4.80993E-02	;
    RnonCO2[	543	]=	-4.80993E-02	;
    RnonCO2[	544	]=	-4.80993E-02	;
    RnonCO2[	545	]=	-4.80993E-02	;
    RnonCO2[	546	]=	-4.80993E-02	;
    RnonCO2[	547	]=	-4.80993E-02	;
    RnonCO2[	548	]=	-4.80993E-02	;
    RnonCO2[	549	]=	-4.80993E-02	;
    RnonCO2[	550	]=	-4.80993E-02	;
    RnonCO2[	551	]=	-4.80993E-02	;
    RnonCO2[	552	]=	-4.80993E-02	;
    RnonCO2[	553	]=	-4.80993E-02	;
    RnonCO2[	554	]=	-4.80993E-02	;
    RnonCO2[	555	]=	-4.80993E-02	;
    RnonCO2[	556	]=	-4.80993E-02	;
    RnonCO2[	557	]=	-4.80993E-02	;
    RnonCO2[	558	]=	-4.80993E-02	;
    RnonCO2[	559	]=	-4.80993E-02	;
    RnonCO2[	560	]=	-4.80993E-02	;
    RnonCO2[	561	]=	-4.80993E-02	;
    RnonCO2[	562	]=	-4.80993E-02	;
    RnonCO2[	563	]=	-4.80993E-02	;
    RnonCO2[	564	]=	-4.80993E-02	;
    RnonCO2[	565	]=	-4.80993E-02	;
    RnonCO2[	566	]=	-4.80993E-02	;
    RnonCO2[	567	]=	-4.80993E-02	;
    RnonCO2[	568	]=	-4.80993E-02	;
    RnonCO2[	569	]=	-4.80993E-02	;
    RnonCO2[	570	]=	-4.80993E-02	;
    RnonCO2[	571	]=	-4.80993E-02	;
    RnonCO2[	572	]=	-4.80993E-02	;
    RnonCO2[	573	]=	-4.80993E-02	;
    RnonCO2[	574	]=	-4.80993E-02	;
    RnonCO2[	575	]=	-4.80993E-02	;
    RnonCO2[	576	]=	-4.80993E-02	;
    RnonCO2[	577	]=	-4.80993E-02	;
    RnonCO2[	578	]=	-4.80993E-02	;
    RnonCO2[	579	]=	-4.80993E-02	;
    RnonCO2[	580	]=	-4.80993E-02	;
    RnonCO2[	581	]=	-4.80993E-02	;
    RnonCO2[	582	]=	-4.80993E-02	;
    RnonCO2[	583	]=	-4.80993E-02	;
    RnonCO2[	584	]=	-4.80993E-02	;
    RnonCO2[	585	]=	-4.80993E-02	;
    RnonCO2[	586	]=	-4.80993E-02	;
    RnonCO2[	587	]=	-4.80993E-02	;
    RnonCO2[	588	]=	-4.80993E-02	;
    RnonCO2[	589	]=	-4.80993E-02	;
    RnonCO2[	590	]=	-4.80993E-02	;
    RnonCO2[	591	]=	-4.80993E-02	;
    RnonCO2[	592	]=	-4.80993E-02	;
    RnonCO2[	593	]=	-4.80993E-02	;
    RnonCO2[	594	]=	-4.80993E-02	;
    RnonCO2[	595	]=	-4.80993E-02	;
    RnonCO2[	596	]=	-4.80993E-02	;
    RnonCO2[	597	]=	-4.80993E-02	;
    RnonCO2[	598	]=	-4.80993E-02	;
    RnonCO2[	599	]=	-4.80993E-02	;
    RnonCO2[	600	]=	-4.80993E-02	;
    RnonCO2[	601	]=	-4.80993E-02	;
    RnonCO2[	602	]=	-4.80993E-02	;
    RnonCO2[	603	]=	-4.80993E-02	;
    RnonCO2[	604	]=	-4.80993E-02	;
    RnonCO2[	605	]=	-4.80993E-02	;
    RnonCO2[	606	]=	-4.80993E-02	;
    RnonCO2[	607	]=	-4.80993E-02	;
    RnonCO2[	608	]=	-4.80993E-02	;
    RnonCO2[	609	]=	-4.80993E-02	;
    RnonCO2[	610	]=	-4.80993E-02	;
    RnonCO2[	611	]=	-4.80993E-02	;
    RnonCO2[	612	]=	-4.80993E-02	;
    RnonCO2[	613	]=	-4.80993E-02	;
    RnonCO2[	614	]=	-4.80993E-02	;
    RnonCO2[	615	]=	-4.80993E-02	;
    RnonCO2[	616	]=	-4.80993E-02	;
    RnonCO2[	617	]=	-4.80993E-02	;
    RnonCO2[	618	]=	-4.80993E-02	;
    RnonCO2[	619	]=	-4.80993E-02	;
    RnonCO2[	620	]=	-4.80993E-02	;
    RnonCO2[	621	]=	-4.80993E-02	;
    RnonCO2[	622	]=	-4.80993E-02	;
    RnonCO2[	623	]=	-4.80993E-02	;
    RnonCO2[	624	]=	-4.80993E-02	;
    RnonCO2[	625	]=	-4.80993E-02	;
    RnonCO2[	626	]=	-4.80993E-02	;
    RnonCO2[	627	]=	-4.80993E-02	;
    RnonCO2[	628	]=	-4.80993E-02	;
    RnonCO2[	629	]=	-4.80993E-02	;
    RnonCO2[	630	]=	-4.80993E-02	;
    RnonCO2[	631	]=	-4.80993E-02	;
    RnonCO2[	632	]=	-4.80993E-02	;
    RnonCO2[	633	]=	-4.80993E-02	;
    RnonCO2[	634	]=	-4.80993E-02	;
    RnonCO2[	635	]=	-4.80993E-02	;
    RnonCO2[	636	]=	-4.80993E-02	;
    RnonCO2[	637	]=	-4.80993E-02	;
    RnonCO2[	638	]=	-4.80993E-02	;
    RnonCO2[	639	]=	-4.80993E-02	;
    RnonCO2[	640	]=	-4.80993E-02	;
    RnonCO2[	641	]=	-4.80993E-02	;
    RnonCO2[	642	]=	-4.80993E-02	;
    RnonCO2[	643	]=	-4.80993E-02	;
    RnonCO2[	644	]=	-4.80993E-02	;
    RnonCO2[	645	]=	-4.80993E-02	;
    RnonCO2[	646	]=	-4.80993E-02	;
    RnonCO2[	647	]=	-4.80993E-02	;
    RnonCO2[	648	]=	-4.80993E-02	;
    RnonCO2[	649	]=	-4.80993E-02	;
    RnonCO2[	650	]=	-4.80993E-02	;
    RnonCO2[	651	]=	-4.80993E-02	;
    RnonCO2[	652	]=	-4.80993E-02	;
    RnonCO2[	653	]=	-4.80993E-02	;
    RnonCO2[	654	]=	-4.80993E-02	;
    RnonCO2[	655	]=	-4.80993E-02	;
    RnonCO2[	656	]=	-4.80993E-02	;
    RnonCO2[	657	]=	-4.80993E-02	;
    RnonCO2[	658	]=	-4.80993E-02	;
    RnonCO2[	659	]=	-4.80993E-02	;
    RnonCO2[	660	]=	-4.80993E-02	;
    RnonCO2[	661	]=	-4.80993E-02	;
    RnonCO2[	662	]=	-4.80993E-02	;
    RnonCO2[	663	]=	-4.80993E-02	;
    RnonCO2[	664	]=	-4.80993E-02	;
    RnonCO2[	665	]=	-4.80993E-02	;
    RnonCO2[	666	]=	-4.80993E-02	;
    RnonCO2[	667	]=	-4.80993E-02	;
    RnonCO2[	668	]=	-4.80993E-02	;
    RnonCO2[	669	]=	-4.80993E-02	;
    RnonCO2[	670	]=	-4.80993E-02	;
    RnonCO2[	671	]=	-4.80993E-02	;
    RnonCO2[	672	]=	-4.80993E-02	;
    RnonCO2[	673	]=	-4.80993E-02	;
    RnonCO2[	674	]=	-4.80993E-02	;
    RnonCO2[	675	]=	-4.80993E-02	;
    RnonCO2[	676	]=	-4.80993E-02	;
    RnonCO2[	677	]=	-4.80993E-02	;
    RnonCO2[	678	]=	-4.80993E-02	;
    RnonCO2[	679	]=	-4.80993E-02	;
    RnonCO2[	680	]=	-4.80993E-02	;
    RnonCO2[	681	]=	-4.80993E-02	;
    RnonCO2[	682	]=	-4.80993E-02	;
    RnonCO2[	683	]=	-4.80993E-02	;
    RnonCO2[	684	]=	-4.80993E-02	;
    RnonCO2[	685	]=	-4.80993E-02	;
    RnonCO2[	686	]=	-4.80993E-02	;
    RnonCO2[	687	]=	-4.80993E-02	;
    RnonCO2[	688	]=	-4.80993E-02	;
    RnonCO2[	689	]=	-4.80993E-02	;
    RnonCO2[	690	]=	-4.80993E-02	;
    RnonCO2[	691	]=	-4.80993E-02	;
    RnonCO2[	692	]=	-4.80993E-02	;
    RnonCO2[	693	]=	-4.80993E-02	;
    RnonCO2[	694	]=	-4.80993E-02	;
    RnonCO2[	695	]=	-4.80993E-02	;
    RnonCO2[	696	]=	-4.80993E-02	;
    RnonCO2[	697	]=	-4.80993E-02	;
    RnonCO2[	698	]=	-4.80993E-02	;
    RnonCO2[	699	]=	-4.80993E-02	;
    RnonCO2[	700	]=	-4.80993E-02	;
    RnonCO2[	701	]=	-4.80993E-02	;
    RnonCO2[	702	]=	-4.80993E-02	;
    RnonCO2[	703	]=	-4.80993E-02	;
    RnonCO2[	704	]=	-4.80993E-02	;
    RnonCO2[	705	]=	-4.80993E-02	;
    RnonCO2[	706	]=	-4.80993E-02	;
    RnonCO2[	707	]=	-4.80993E-02	;
    RnonCO2[	708	]=	-4.80993E-02	;
    RnonCO2[	709	]=	-4.80993E-02	;
    RnonCO2[	710	]=	-4.80993E-02	;
    RnonCO2[	711	]=	-4.80993E-02	;
    RnonCO2[	712	]=	-4.80993E-02	;
    RnonCO2[	713	]=	-4.80993E-02	;
    RnonCO2[	714	]=	-4.80993E-02	;
    RnonCO2[	715	]=	-4.80993E-02	;
    RnonCO2[	716	]=	-4.80993E-02	;
    RnonCO2[	717	]=	-4.80993E-02	;
    RnonCO2[	718	]=	-4.80993E-02	;
    RnonCO2[	719	]=	-4.80993E-02	;
    RnonCO2[	720	]=	-4.80993E-02	;
    RnonCO2[	721	]=	-4.80993E-02	;
    RnonCO2[	722	]=	-4.80993E-02	;
    RnonCO2[	723	]=	-4.80993E-02	;
    RnonCO2[	724	]=	-4.80993E-02	;
    RnonCO2[	725	]=	-4.80993E-02	;
    RnonCO2[	726	]=	-4.80993E-02	;
    RnonCO2[	727	]=	-4.80993E-02	;
    RnonCO2[	728	]=	-4.80993E-02	;
    RnonCO2[	729	]=	-4.80993E-02	;
    RnonCO2[	730	]=	-4.80993E-02	;
    RnonCO2[	731	]=	-4.80993E-02	;
    RnonCO2[	732	]=	-4.80993E-02	;
    RnonCO2[	733	]=	-4.80993E-02	;
    RnonCO2[	734	]=	-4.80993E-02	;
    RnonCO2[	735	]=	-4.80993E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp534(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07202E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09048E+00	;
    RnonCO2[	253	]=	1.09835E+00	;
    RnonCO2[	254	]=	1.10604E+00	;
    RnonCO2[	255	]=	1.11342E+00	;
    RnonCO2[	256	]=	1.12056E+00	;
    RnonCO2[	257	]=	1.12758E+00	;
    RnonCO2[	258	]=	1.13465E+00	;
    RnonCO2[	259	]=	1.14191E+00	;
    RnonCO2[	260	]=	1.14939E+00	;
    RnonCO2[	261	]=	1.15715E+00	;
    RnonCO2[	262	]=	1.16505E+00	;
    RnonCO2[	263	]=	1.17297E+00	;
    RnonCO2[	264	]=	1.18100E+00	;
    RnonCO2[	265	]=	1.18921E+00	;
    RnonCO2[	266	]=	1.19763E+00	;
    RnonCO2[	267	]=	1.20623E+00	;
    RnonCO2[	268	]=	1.21499E+00	;
    RnonCO2[	269	]=	1.22397E+00	;
    RnonCO2[	270	]=	1.23324E+00	;
    RnonCO2[	271	]=	1.24279E+00	;
    RnonCO2[	272	]=	1.25264E+00	;
    RnonCO2[	273	]=	1.26278E+00	;
    RnonCO2[	274	]=	1.27323E+00	;
    RnonCO2[	275	]=	1.28395E+00	;
    RnonCO2[	276	]=	1.29493E+00	;
    RnonCO2[	277	]=	1.30398E+00	;
    RnonCO2[	278	]=	1.30910E+00	;
    RnonCO2[	279	]=	1.31060E+00	;
    RnonCO2[	280	]=	1.30874E+00	;
    RnonCO2[	281	]=	1.30371E+00	;
    RnonCO2[	282	]=	1.29570E+00	;
    RnonCO2[	283	]=	1.28485E+00	;
    RnonCO2[	284	]=	1.27129E+00	;
    RnonCO2[	285	]=	1.25510E+00	;
    RnonCO2[	286	]=	1.23639E+00	;
    RnonCO2[	287	]=	1.21623E+00	;
    RnonCO2[	288	]=	1.19571E+00	;
    RnonCO2[	289	]=	1.17487E+00	;
    RnonCO2[	290	]=	1.15371E+00	;
    RnonCO2[	291	]=	1.13222E+00	;
    RnonCO2[	292	]=	1.11044E+00	;
    RnonCO2[	293	]=	1.08836E+00	;
    RnonCO2[	294	]=	1.06598E+00	;
    RnonCO2[	295	]=	1.04330E+00	;
    RnonCO2[	296	]=	1.02033E+00	;
    RnonCO2[	297	]=	9.97886E-01	;
    RnonCO2[	298	]=	9.76727E-01	;
    RnonCO2[	299	]=	9.56737E-01	;
    RnonCO2[	300	]=	9.37847E-01	;
    RnonCO2[	301	]=	9.19992E-01	;
    RnonCO2[	302	]=	9.03115E-01	;
    RnonCO2[	303	]=	8.87163E-01	;
    RnonCO2[	304	]=	8.72086E-01	;
    RnonCO2[	305	]=	8.57827E-01	;
    RnonCO2[	306	]=	8.44339E-01	;
    RnonCO2[	307	]=	8.31628E-01	;
    RnonCO2[	308	]=	8.19698E-01	;
    RnonCO2[	309	]=	8.08501E-01	;
    RnonCO2[	310	]=	7.97994E-01	;
    RnonCO2[	311	]=	7.88139E-01	;
    RnonCO2[	312	]=	7.78883E-01	;
    RnonCO2[	313	]=	7.70196E-01	;
    RnonCO2[	314	]=	7.62036E-01	;
    RnonCO2[	315	]=	7.54368E-01	;
    RnonCO2[	316	]=	7.47161E-01	;
    RnonCO2[	317	]=	7.40341E-01	;
    RnonCO2[	318	]=	7.33844E-01	;
    RnonCO2[	319	]=	7.27649E-01	;
    RnonCO2[	320	]=	7.21741E-01	;
    RnonCO2[	321	]=	7.16085E-01	;
    RnonCO2[	322	]=	7.10679E-01	;
    RnonCO2[	323	]=	7.05501E-01	;
    RnonCO2[	324	]=	7.00522E-01	;
    RnonCO2[	325	]=	6.95801E-01	;
    RnonCO2[	326	]=	6.91366E-01	;
    RnonCO2[	327	]=	6.87191E-01	;
    RnonCO2[	328	]=	6.83270E-01	;
    RnonCO2[	329	]=	6.79567E-01	;
    RnonCO2[	330	]=	6.76065E-01	;
    RnonCO2[	331	]=	6.72745E-01	;
    RnonCO2[	332	]=	6.69583E-01	;
    RnonCO2[	333	]=	6.66570E-01	;
    RnonCO2[	334	]=	6.63692E-01	;
    RnonCO2[	335	]=	6.60925E-01	;
    RnonCO2[	336	]=	6.58275E-01	;
    RnonCO2[	337	]=	6.55785E-01	;
    RnonCO2[	338	]=	6.53501E-01	;
    RnonCO2[	339	]=	6.51399E-01	;
    RnonCO2[	340	]=	6.49465E-01	;
    RnonCO2[	341	]=	6.47680E-01	;
    RnonCO2[	342	]=	6.46028E-01	;
    RnonCO2[	343	]=	6.44498E-01	;
    RnonCO2[	344	]=	6.43081E-01	;
    RnonCO2[	345	]=	6.41761E-01	;
    RnonCO2[	346	]=	6.40531E-01	;
    RnonCO2[	347	]=	6.39383E-01	;
    RnonCO2[	348	]=	6.38306E-01	;
    RnonCO2[	349	]=	6.37296E-01	;
    RnonCO2[	350	]=	6.36346E-01	;
    RnonCO2[	351	]=	6.35448E-01	;
    RnonCO2[	352	]=	6.34601E-01	;
    RnonCO2[	353	]=	6.33796E-01	;
    RnonCO2[	354	]=	6.33031E-01	;
    RnonCO2[	355	]=	6.32302E-01	;
    RnonCO2[	356	]=	6.31606E-01	;
    RnonCO2[	357	]=	6.30938E-01	;
    RnonCO2[	358	]=	6.30297E-01	;
    RnonCO2[	359	]=	6.29683E-01	;
    RnonCO2[	360	]=	6.29086E-01	;
    RnonCO2[	361	]=	6.28508E-01	;
    RnonCO2[	362	]=	6.27952E-01	;
    RnonCO2[	363	]=	6.27420E-01	;
    RnonCO2[	364	]=	6.26907E-01	;
    RnonCO2[	365	]=	6.26411E-01	;
    RnonCO2[	366	]=	6.25932E-01	;
    RnonCO2[	367	]=	6.25467E-01	;
    RnonCO2[	368	]=	6.25017E-01	;
    RnonCO2[	369	]=	6.24578E-01	;
    RnonCO2[	370	]=	6.24153E-01	;
    RnonCO2[	371	]=	6.23736E-01	;
    RnonCO2[	372	]=	6.23329E-01	;
    RnonCO2[	373	]=	6.22930E-01	;
    RnonCO2[	374	]=	6.22538E-01	;
    RnonCO2[	375	]=	6.22150E-01	;
    RnonCO2[	376	]=	6.21773E-01	;
    RnonCO2[	377	]=	6.21397E-01	;
    RnonCO2[	378	]=	6.21027E-01	;
    RnonCO2[	379	]=	6.20658E-01	;
    RnonCO2[	380	]=	6.20288E-01	;
    RnonCO2[	381	]=	6.19920E-01	;
    RnonCO2[	382	]=	6.19552E-01	;
    RnonCO2[	383	]=	6.19182E-01	;
    RnonCO2[	384	]=	6.18806E-01	;
    RnonCO2[	385	]=	6.18429E-01	;
    RnonCO2[	386	]=	6.18046E-01	;
    RnonCO2[	387	]=	6.17655E-01	;
    RnonCO2[	388	]=	6.17260E-01	;
    RnonCO2[	389	]=	6.16865E-01	;
    RnonCO2[	390	]=	6.16463E-01	;
    RnonCO2[	391	]=	6.16065E-01	;
    RnonCO2[	392	]=	6.15664E-01	;
    RnonCO2[	393	]=	6.15259E-01	;
    RnonCO2[	394	]=	6.14851E-01	;
    RnonCO2[	395	]=	6.14441E-01	;
    RnonCO2[	396	]=	6.14025E-01	;
    RnonCO2[	397	]=	6.13603E-01	;
    RnonCO2[	398	]=	6.13176E-01	;
    RnonCO2[	399	]=	6.12743E-01	;
    RnonCO2[	400	]=	6.12303E-01	;
    RnonCO2[	401	]=	6.11856E-01	;
    RnonCO2[	402	]=	6.11401E-01	;
    RnonCO2[	403	]=	6.10939E-01	;
    RnonCO2[	404	]=	6.10468E-01	;
    RnonCO2[	405	]=	6.09989E-01	;
    RnonCO2[	406	]=	6.09504E-01	;
    RnonCO2[	407	]=	6.09007E-01	;
    RnonCO2[	408	]=	6.08504E-01	;
    RnonCO2[	409	]=	6.07994E-01	;
    RnonCO2[	410	]=	6.07475E-01	;
    RnonCO2[	411	]=	6.06949E-01	;
    RnonCO2[	412	]=	6.06416E-01	;
    RnonCO2[	413	]=	6.05878E-01	;
    RnonCO2[	414	]=	6.05333E-01	;
    RnonCO2[	415	]=	6.04781E-01	;
    RnonCO2[	416	]=	6.04223E-01	;
    RnonCO2[	417	]=	6.03661E-01	;
    RnonCO2[	418	]=	6.03091E-01	;
    RnonCO2[	419	]=	6.02516E-01	;
    RnonCO2[	420	]=	6.01937E-01	;
    RnonCO2[	421	]=	6.01354E-01	;
    RnonCO2[	422	]=	6.00763E-01	;
    RnonCO2[	423	]=	6.00171E-01	;
    RnonCO2[	424	]=	5.99581E-01	;
    RnonCO2[	425	]=	5.98990E-01	;
    RnonCO2[	426	]=	5.98401E-01	;
    RnonCO2[	427	]=	5.97812E-01	;
    RnonCO2[	428	]=	5.97221E-01	;
    RnonCO2[	429	]=	5.96632E-01	;
    RnonCO2[	430	]=	5.96044E-01	;
    RnonCO2[	431	]=	5.95457E-01	;
    RnonCO2[	432	]=	5.94868E-01	;
    RnonCO2[	433	]=	5.94276E-01	;
    RnonCO2[	434	]=	5.93687E-01	;
    RnonCO2[	435	]=	5.93095E-01	;
    RnonCO2[	436	]=	5.92500E-01	;
    RnonCO2[	437	]=	5.91907E-01	;
    RnonCO2[	438	]=	5.91312E-01	;
    RnonCO2[	439	]=	5.90715E-01	;
    RnonCO2[	440	]=	5.90114E-01	;
    RnonCO2[	441	]=	5.89516E-01	;
    RnonCO2[	442	]=	5.88913E-01	;
    RnonCO2[	443	]=	5.88309E-01	;
    RnonCO2[	444	]=	5.87704E-01	;
    RnonCO2[	445	]=	5.87093E-01	;
    RnonCO2[	446	]=	5.86485E-01	;
    RnonCO2[	447	]=	5.85871E-01	;
    RnonCO2[	448	]=	5.85258E-01	;
    RnonCO2[	449	]=	5.84641E-01	;
    RnonCO2[	450	]=	5.84021E-01	;
    RnonCO2[	451	]=	5.83399E-01	;
    RnonCO2[	452	]=	5.82775E-01	;
    RnonCO2[	453	]=	5.82149E-01	;
    RnonCO2[	454	]=	5.81520E-01	;
    RnonCO2[	455	]=	5.80888E-01	;
    RnonCO2[	456	]=	5.80254E-01	;
    RnonCO2[	457	]=	5.79616E-01	;
    RnonCO2[	458	]=	5.78976E-01	;
    RnonCO2[	459	]=	5.78336E-01	;
    RnonCO2[	460	]=	5.77689E-01	;
    RnonCO2[	461	]=	5.77040E-01	;
    RnonCO2[	462	]=	5.76390E-01	;
    RnonCO2[	463	]=	5.75735E-01	;
    RnonCO2[	464	]=	5.75078E-01	;
    RnonCO2[	465	]=	5.74418E-01	;
    RnonCO2[	466	]=	5.73755E-01	;
    RnonCO2[	467	]=	5.73088E-01	;
    RnonCO2[	468	]=	5.72420E-01	;
    RnonCO2[	469	]=	5.71748E-01	;
    RnonCO2[	470	]=	5.71069E-01	;
    RnonCO2[	471	]=	5.70392E-01	;
    RnonCO2[	472	]=	5.69708E-01	;
    RnonCO2[	473	]=	5.69023E-01	;
    RnonCO2[	474	]=	5.68333E-01	;
    RnonCO2[	475	]=	5.67639E-01	;
    RnonCO2[	476	]=	5.66940E-01	;
    RnonCO2[	477	]=	5.66239E-01	;
    RnonCO2[	478	]=	5.65534E-01	;
    RnonCO2[	479	]=	5.64828E-01	;
    RnonCO2[	480	]=	5.64119E-01	;
    RnonCO2[	481	]=	5.63406E-01	;
    RnonCO2[	482	]=	5.62694E-01	;
    RnonCO2[	483	]=	5.61979E-01	;
    RnonCO2[	484	]=	5.61265E-01	;
    RnonCO2[	485	]=	5.60552E-01	;
    RnonCO2[	486	]=	5.59839E-01	;
    RnonCO2[	487	]=	5.59145E-01	;
    RnonCO2[	488	]=	5.58485E-01	;
    RnonCO2[	489	]=	5.57856E-01	;
    RnonCO2[	490	]=	5.57258E-01	;
    RnonCO2[	491	]=	5.56681E-01	;
    RnonCO2[	492	]=	5.56131E-01	;
    RnonCO2[	493	]=	5.55605E-01	;
    RnonCO2[	494	]=	5.55096E-01	;
    RnonCO2[	495	]=	5.54607E-01	;
    RnonCO2[	496	]=	5.54138E-01	;
    RnonCO2[	497	]=	5.53680E-01	;
    RnonCO2[	498	]=	5.53240E-01	;
    RnonCO2[	499	]=	5.52812E-01	;
    RnonCO2[	500	]=	5.52396E-01	;
    RnonCO2[	501	]=	5.51994E-01	;
    RnonCO2[	502	]=	5.51602E-01	;
    RnonCO2[	503	]=	5.51220E-01	;
    RnonCO2[	504	]=	5.50849E-01	;
    RnonCO2[	505	]=	5.50483E-01	;
    RnonCO2[	506	]=	5.50128E-01	;
    RnonCO2[	507	]=	5.49779E-01	;
    RnonCO2[	508	]=	5.49440E-01	;
    RnonCO2[	509	]=	5.49107E-01	;
    RnonCO2[	510	]=	5.48781E-01	;
    RnonCO2[	511	]=	5.48459E-01	;
    RnonCO2[	512	]=	5.48143E-01	;
    RnonCO2[	513	]=	5.47834E-01	;
    RnonCO2[	514	]=	5.47531E-01	;
    RnonCO2[	515	]=	5.47231E-01	;
    RnonCO2[	516	]=	5.46938E-01	;
    RnonCO2[	517	]=	5.46647E-01	;
    RnonCO2[	518	]=	5.46362E-01	;
    RnonCO2[	519	]=	5.46080E-01	;
    RnonCO2[	520	]=	5.45805E-01	;
    RnonCO2[	521	]=	5.45530E-01	;
    RnonCO2[	522	]=	5.45262E-01	;
    RnonCO2[	523	]=	5.44996E-01	;
    RnonCO2[	524	]=	5.44735E-01	;
    RnonCO2[	525	]=	5.44476E-01	;
    RnonCO2[	526	]=	5.44221E-01	;
    RnonCO2[	527	]=	5.43969E-01	;
    RnonCO2[	528	]=	5.43719E-01	;
    RnonCO2[	529	]=	5.43472E-01	;
    RnonCO2[	530	]=	5.43230E-01	;
    RnonCO2[	531	]=	5.42990E-01	;
    RnonCO2[	532	]=	5.42752E-01	;
    RnonCO2[	533	]=	5.42517E-01	;
    RnonCO2[	534	]=	5.42286E-01	;
    RnonCO2[	535	]=	5.42054E-01	;
    RnonCO2[	536	]=	5.41827E-01	;
    RnonCO2[	537	]=	5.41602E-01	;
    RnonCO2[	538	]=	5.41379E-01	;
    RnonCO2[	539	]=	5.41160E-01	;
    RnonCO2[	540	]=	5.40943E-01	;
    RnonCO2[	541	]=	5.40725E-01	;
    RnonCO2[	542	]=	5.40512E-01	;
    RnonCO2[	543	]=	5.40303E-01	;
    RnonCO2[	544	]=	5.40092E-01	;
    RnonCO2[	545	]=	5.39885E-01	;
    RnonCO2[	546	]=	5.39681E-01	;
    RnonCO2[	547	]=	5.39478E-01	;
    RnonCO2[	548	]=	5.39275E-01	;
    RnonCO2[	549	]=	5.39075E-01	;
    RnonCO2[	550	]=	5.38878E-01	;
    RnonCO2[	551	]=	5.38683E-01	;
    RnonCO2[	552	]=	5.38489E-01	;
    RnonCO2[	553	]=	5.38296E-01	;
    RnonCO2[	554	]=	5.38104E-01	;
    RnonCO2[	555	]=	5.37913E-01	;
    RnonCO2[	556	]=	5.37727E-01	;
    RnonCO2[	557	]=	5.37541E-01	;
    RnonCO2[	558	]=	5.37356E-01	;
    RnonCO2[	559	]=	5.37172E-01	;
    RnonCO2[	560	]=	5.36990E-01	;
    RnonCO2[	561	]=	5.36810E-01	;
    RnonCO2[	562	]=	5.36632E-01	;
    RnonCO2[	563	]=	5.36452E-01	;
    RnonCO2[	564	]=	5.36275E-01	;
    RnonCO2[	565	]=	5.36099E-01	;
    RnonCO2[	566	]=	5.35927E-01	;
    RnonCO2[	567	]=	5.35752E-01	;
    RnonCO2[	568	]=	5.35582E-01	;
    RnonCO2[	569	]=	5.35411E-01	;
    RnonCO2[	570	]=	5.35242E-01	;
    RnonCO2[	571	]=	5.35073E-01	;
    RnonCO2[	572	]=	5.34904E-01	;
    RnonCO2[	573	]=	5.34735E-01	;
    RnonCO2[	574	]=	5.34571E-01	;
    RnonCO2[	575	]=	5.34406E-01	;
    RnonCO2[	576	]=	5.34242E-01	;
    RnonCO2[	577	]=	5.34078E-01	;
    RnonCO2[	578	]=	5.33914E-01	;
    RnonCO2[	579	]=	5.33751E-01	;
    RnonCO2[	580	]=	5.33590E-01	;
    RnonCO2[	581	]=	5.33427E-01	;
    RnonCO2[	582	]=	5.33267E-01	;
    RnonCO2[	583	]=	5.33107E-01	;
    RnonCO2[	584	]=	5.32947E-01	;
    RnonCO2[	585	]=	5.32789E-01	;
    RnonCO2[	586	]=	5.32632E-01	;
    RnonCO2[	587	]=	5.32480E-01	;
    RnonCO2[	588	]=	5.32325E-01	;
    RnonCO2[	589	]=	5.32174E-01	;
    RnonCO2[	590	]=	5.32025E-01	;
    RnonCO2[	591	]=	5.31877E-01	;
    RnonCO2[	592	]=	5.31733E-01	;
    RnonCO2[	593	]=	5.31591E-01	;
    RnonCO2[	594	]=	5.31452E-01	;
    RnonCO2[	595	]=	5.31318E-01	;
    RnonCO2[	596	]=	5.31186E-01	;
    RnonCO2[	597	]=	5.31054E-01	;
    RnonCO2[	598	]=	5.30926E-01	;
    RnonCO2[	599	]=	5.30801E-01	;
    RnonCO2[	600	]=	5.30676E-01	;
    RnonCO2[	601	]=	5.30557E-01	;
    RnonCO2[	602	]=	5.30436E-01	;
    RnonCO2[	603	]=	5.30316E-01	;
    RnonCO2[	604	]=	5.30200E-01	;
    RnonCO2[	605	]=	5.30086E-01	;
    RnonCO2[	606	]=	5.29972E-01	;
    RnonCO2[	607	]=	5.29861E-01	;
    RnonCO2[	608	]=	5.29749E-01	;
    RnonCO2[	609	]=	5.29640E-01	;
    RnonCO2[	610	]=	5.29530E-01	;
    RnonCO2[	611	]=	5.29425E-01	;
    RnonCO2[	612	]=	5.29318E-01	;
    RnonCO2[	613	]=	5.29214E-01	;
    RnonCO2[	614	]=	5.29111E-01	;
    RnonCO2[	615	]=	5.29006E-01	;
    RnonCO2[	616	]=	5.28905E-01	;
    RnonCO2[	617	]=	5.28804E-01	;
    RnonCO2[	618	]=	5.28707E-01	;
    RnonCO2[	619	]=	5.28608E-01	;
    RnonCO2[	620	]=	5.28509E-01	;
    RnonCO2[	621	]=	5.28414E-01	;
    RnonCO2[	622	]=	5.28317E-01	;
    RnonCO2[	623	]=	5.28223E-01	;
    RnonCO2[	624	]=	5.28130E-01	;
    RnonCO2[	625	]=	5.28038E-01	;
    RnonCO2[	626	]=	5.27945E-01	;
    RnonCO2[	627	]=	5.27854E-01	;
    RnonCO2[	628	]=	5.27763E-01	;
    RnonCO2[	629	]=	5.27675E-01	;
    RnonCO2[	630	]=	5.27585E-01	;
    RnonCO2[	631	]=	5.27499E-01	;
    RnonCO2[	632	]=	5.27410E-01	;
    RnonCO2[	633	]=	5.27324E-01	;
    RnonCO2[	634	]=	5.27239E-01	;
    RnonCO2[	635	]=	5.27152E-01	;
    RnonCO2[	636	]=	5.27068E-01	;
    RnonCO2[	637	]=	5.26987E-01	;
    RnonCO2[	638	]=	5.26904E-01	;
    RnonCO2[	639	]=	5.26821E-01	;
    RnonCO2[	640	]=	5.26739E-01	;
    RnonCO2[	641	]=	5.26660E-01	;
    RnonCO2[	642	]=	5.26579E-01	;
    RnonCO2[	643	]=	5.26500E-01	;
    RnonCO2[	644	]=	5.26422E-01	;
    RnonCO2[	645	]=	5.26342E-01	;
    RnonCO2[	646	]=	5.26266E-01	;
    RnonCO2[	647	]=	5.26189E-01	;
    RnonCO2[	648	]=	5.26113E-01	;
    RnonCO2[	649	]=	5.26037E-01	;
    RnonCO2[	650	]=	5.25965E-01	;
    RnonCO2[	651	]=	5.25890E-01	;
    RnonCO2[	652	]=	5.25815E-01	;
    RnonCO2[	653	]=	5.25744E-01	;
    RnonCO2[	654	]=	5.25670E-01	;
    RnonCO2[	655	]=	5.25599E-01	;
    RnonCO2[	656	]=	5.25527E-01	;
    RnonCO2[	657	]=	5.25456E-01	;
    RnonCO2[	658	]=	5.25387E-01	;
    RnonCO2[	659	]=	5.25317E-01	;
    RnonCO2[	660	]=	5.25249E-01	;
    RnonCO2[	661	]=	5.25180E-01	;
    RnonCO2[	662	]=	5.25112E-01	;
    RnonCO2[	663	]=	5.25044E-01	;
    RnonCO2[	664	]=	5.24979E-01	;
    RnonCO2[	665	]=	5.24912E-01	;
    RnonCO2[	666	]=	5.24848E-01	;
    RnonCO2[	667	]=	5.24781E-01	;
    RnonCO2[	668	]=	5.24718E-01	;
    RnonCO2[	669	]=	5.24652E-01	;
    RnonCO2[	670	]=	5.24589E-01	;
    RnonCO2[	671	]=	5.24527E-01	;
    RnonCO2[	672	]=	5.24464E-01	;
    RnonCO2[	673	]=	5.24403E-01	;
    RnonCO2[	674	]=	5.24340E-01	;
    RnonCO2[	675	]=	5.24279E-01	;
    RnonCO2[	676	]=	5.24218E-01	;
    RnonCO2[	677	]=	5.24157E-01	;
    RnonCO2[	678	]=	5.24100E-01	;
    RnonCO2[	679	]=	5.24039E-01	;
    RnonCO2[	680	]=	5.23979E-01	;
    RnonCO2[	681	]=	5.23922E-01	;
    RnonCO2[	682	]=	5.23863E-01	;
    RnonCO2[	683	]=	5.23807E-01	;
    RnonCO2[	684	]=	5.23750E-01	;
    RnonCO2[	685	]=	5.23692E-01	;
    RnonCO2[	686	]=	5.23636E-01	;
    RnonCO2[	687	]=	5.23580E-01	;
    RnonCO2[	688	]=	5.23525E-01	;
    RnonCO2[	689	]=	5.23470E-01	;
    RnonCO2[	690	]=	5.23415E-01	;
    RnonCO2[	691	]=	5.23361E-01	;
    RnonCO2[	692	]=	5.23307E-01	;
    RnonCO2[	693	]=	5.23252E-01	;
    RnonCO2[	694	]=	5.23202E-01	;
    RnonCO2[	695	]=	5.23148E-01	;
    RnonCO2[	696	]=	5.23094E-01	;
    RnonCO2[	697	]=	5.23044E-01	;
    RnonCO2[	698	]=	5.22991E-01	;
    RnonCO2[	699	]=	5.22941E-01	;
    RnonCO2[	700	]=	5.22891E-01	;
    RnonCO2[	701	]=	5.22839E-01	;
    RnonCO2[	702	]=	5.22789E-01	;
    RnonCO2[	703	]=	5.22740E-01	;
    RnonCO2[	704	]=	5.22691E-01	;
    RnonCO2[	705	]=	5.22642E-01	;
    RnonCO2[	706	]=	5.22591E-01	;
    RnonCO2[	707	]=	5.22542E-01	;
    RnonCO2[	708	]=	5.22497E-01	;
    RnonCO2[	709	]=	5.22449E-01	;
    RnonCO2[	710	]=	5.22401E-01	;
    RnonCO2[	711	]=	5.22353E-01	;
    RnonCO2[	712	]=	5.22306E-01	;
    RnonCO2[	713	]=	5.22261E-01	;
    RnonCO2[	714	]=	5.22213E-01	;
    RnonCO2[	715	]=	5.22166E-01	;
    RnonCO2[	716	]=	5.22122E-01	;
    RnonCO2[	717	]=	5.22075E-01	;
    RnonCO2[	718	]=	5.22031E-01	;
    RnonCO2[	719	]=	5.21984E-01	;
    RnonCO2[	720	]=	5.21941E-01	;
    RnonCO2[	721	]=	5.21897E-01	;
    RnonCO2[	722	]=	5.21854E-01	;
    RnonCO2[	723	]=	5.21808E-01	;
    RnonCO2[	724	]=	5.21765E-01	;
    RnonCO2[	725	]=	5.21722E-01	;
    RnonCO2[	726	]=	5.21679E-01	;
    RnonCO2[	727	]=	5.21636E-01	;
    RnonCO2[	728	]=	5.21593E-01	;
    RnonCO2[	729	]=	5.21550E-01	;
    RnonCO2[	730	]=	5.21508E-01	;
    RnonCO2[	731	]=	5.21466E-01	;
    RnonCO2[	732	]=	5.21426E-01	;
    RnonCO2[	733	]=	5.21384E-01	;
    RnonCO2[	734	]=	5.21342E-01	;
    RnonCO2[	735	]=	5.21322E-01	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp534(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.16860E+00	;
    RnonCO2[	252	]=	-1.13476E+00	;
    RnonCO2[	253	]=	-1.10017E+00	;
    RnonCO2[	254	]=	-1.06477E+00	;
    RnonCO2[	255	]=	-1.02852E+00	;
    RnonCO2[	256	]=	-1.02126E+00	;
    RnonCO2[	257	]=	-1.01395E+00	;
    RnonCO2[	258	]=	-1.00661E+00	;
    RnonCO2[	259	]=	-9.99226E-01	;
    RnonCO2[	260	]=	-9.91799E-01	;
    RnonCO2[	261	]=	-9.84330E-01	;
    RnonCO2[	262	]=	-9.76819E-01	;
    RnonCO2[	263	]=	-9.69265E-01	;
    RnonCO2[	264	]=	-9.61666E-01	;
    RnonCO2[	265	]=	-9.54024E-01	;
    RnonCO2[	266	]=	-9.54281E-01	;
    RnonCO2[	267	]=	-9.54537E-01	;
    RnonCO2[	268	]=	-9.54794E-01	;
    RnonCO2[	269	]=	-9.55050E-01	;
    RnonCO2[	270	]=	-9.55307E-01	;
    RnonCO2[	271	]=	-9.55563E-01	;
    RnonCO2[	272	]=	-9.55820E-01	;
    RnonCO2[	273	]=	-9.56076E-01	;
    RnonCO2[	274	]=	-9.56333E-01	;
    RnonCO2[	275	]=	-9.56589E-01	;
    RnonCO2[	276	]=	-9.24692E-01	;
    RnonCO2[	277	]=	-8.92093E-01	;
    RnonCO2[	278	]=	-8.58752E-01	;
    RnonCO2[	279	]=	-8.24630E-01	;
    RnonCO2[	280	]=	-7.89681E-01	;
    RnonCO2[	281	]=	-7.53856E-01	;
    RnonCO2[	282	]=	-7.17104E-01	;
    RnonCO2[	283	]=	-6.79365E-01	;
    RnonCO2[	284	]=	-6.40576E-01	;
    RnonCO2[	285	]=	-6.00668E-01	;
    RnonCO2[	286	]=	-5.85363E-01	;
    RnonCO2[	287	]=	-5.69883E-01	;
    RnonCO2[	288	]=	-5.54225E-01	;
    RnonCO2[	289	]=	-5.38382E-01	;
    RnonCO2[	290	]=	-5.22350E-01	;
    RnonCO2[	291	]=	-5.06125E-01	;
    RnonCO2[	292	]=	-4.89700E-01	;
    RnonCO2[	293	]=	-4.73069E-01	;
    RnonCO2[	294	]=	-4.56228E-01	;
    RnonCO2[	295	]=	-4.39170E-01	;
    RnonCO2[	296	]=	-4.28761E-01	;
    RnonCO2[	297	]=	-4.18271E-01	;
    RnonCO2[	298	]=	-4.07698E-01	;
    RnonCO2[	299	]=	-3.97039E-01	;
    RnonCO2[	300	]=	-3.86295E-01	;
    RnonCO2[	301	]=	-3.75463E-01	;
    RnonCO2[	302	]=	-3.64541E-01	;
    RnonCO2[	303	]=	-3.53528E-01	;
    RnonCO2[	304	]=	-3.42422E-01	;
    RnonCO2[	305	]=	-3.31221E-01	;
    RnonCO2[	306	]=	-3.24943E-01	;
    RnonCO2[	307	]=	-3.18637E-01	;
    RnonCO2[	308	]=	-3.12301E-01	;
    RnonCO2[	309	]=	-3.05936E-01	;
    RnonCO2[	310	]=	-2.99542E-01	;
    RnonCO2[	311	]=	-2.93117E-01	;
    RnonCO2[	312	]=	-2.86662E-01	;
    RnonCO2[	313	]=	-2.80177E-01	;
    RnonCO2[	314	]=	-2.73660E-01	;
    RnonCO2[	315	]=	-2.67112E-01	;
    RnonCO2[	316	]=	-2.64511E-01	;
    RnonCO2[	317	]=	-2.61903E-01	;
    RnonCO2[	318	]=	-2.59290E-01	;
    RnonCO2[	319	]=	-2.56670E-01	;
    RnonCO2[	320	]=	-2.54044E-01	;
    RnonCO2[	321	]=	-2.51413E-01	;
    RnonCO2[	322	]=	-2.48774E-01	;
    RnonCO2[	323	]=	-2.46130E-01	;
    RnonCO2[	324	]=	-2.43479E-01	;
    RnonCO2[	325	]=	-2.40823E-01	;
    RnonCO2[	326	]=	-2.39432E-01	;
    RnonCO2[	327	]=	-2.38039E-01	;
    RnonCO2[	328	]=	-2.36646E-01	;
    RnonCO2[	329	]=	-2.35251E-01	;
    RnonCO2[	330	]=	-2.33854E-01	;
    RnonCO2[	331	]=	-2.32456E-01	;
    RnonCO2[	332	]=	-2.31057E-01	;
    RnonCO2[	333	]=	-2.29656E-01	;
    RnonCO2[	334	]=	-2.28254E-01	;
    RnonCO2[	335	]=	-2.26850E-01	;
    RnonCO2[	336	]=	-2.25720E-01	;
    RnonCO2[	337	]=	-2.24590E-01	;
    RnonCO2[	338	]=	-2.23458E-01	;
    RnonCO2[	339	]=	-2.22326E-01	;
    RnonCO2[	340	]=	-2.21193E-01	;
    RnonCO2[	341	]=	-2.20059E-01	;
    RnonCO2[	342	]=	-2.18924E-01	;
    RnonCO2[	343	]=	-2.17789E-01	;
    RnonCO2[	344	]=	-2.16653E-01	;
    RnonCO2[	345	]=	-2.15516E-01	;
    RnonCO2[	346	]=	-2.14378E-01	;
    RnonCO2[	347	]=	-2.13240E-01	;
    RnonCO2[	348	]=	-2.12101E-01	;
    RnonCO2[	349	]=	-2.10961E-01	;
    RnonCO2[	350	]=	-2.09820E-01	;
    RnonCO2[	351	]=	-2.08678E-01	;
    RnonCO2[	352	]=	-2.07536E-01	;
    RnonCO2[	353	]=	-2.06392E-01	;
    RnonCO2[	354	]=	-2.05248E-01	;
    RnonCO2[	355	]=	-2.04103E-01	;
    RnonCO2[	356	]=	-2.02957E-01	;
    RnonCO2[	357	]=	-2.01810E-01	;
    RnonCO2[	358	]=	-2.00662E-01	;
    RnonCO2[	359	]=	-1.99513E-01	;
    RnonCO2[	360	]=	-1.98364E-01	;
    RnonCO2[	361	]=	-1.97213E-01	;
    RnonCO2[	362	]=	-1.96062E-01	;
    RnonCO2[	363	]=	-1.94910E-01	;
    RnonCO2[	364	]=	-1.93757E-01	;
    RnonCO2[	365	]=	-1.92603E-01	;
    RnonCO2[	366	]=	-1.91449E-01	;
    RnonCO2[	367	]=	-1.90293E-01	;
    RnonCO2[	368	]=	-1.89137E-01	;
    RnonCO2[	369	]=	-1.87980E-01	;
    RnonCO2[	370	]=	-1.86823E-01	;
    RnonCO2[	371	]=	-1.85664E-01	;
    RnonCO2[	372	]=	-1.84504E-01	;
    RnonCO2[	373	]=	-1.83344E-01	;
    RnonCO2[	374	]=	-1.82183E-01	;
    RnonCO2[	375	]=	-1.81021E-01	;
    RnonCO2[	376	]=	-1.79858E-01	;
    RnonCO2[	377	]=	-1.78693E-01	;
    RnonCO2[	378	]=	-1.77528E-01	;
    RnonCO2[	379	]=	-1.76362E-01	;
    RnonCO2[	380	]=	-1.75196E-01	;
    RnonCO2[	381	]=	-1.74028E-01	;
    RnonCO2[	382	]=	-1.72860E-01	;
    RnonCO2[	383	]=	-1.71690E-01	;
    RnonCO2[	384	]=	-1.70520E-01	;
    RnonCO2[	385	]=	-1.69349E-01	;
    RnonCO2[	386	]=	-1.68177E-01	;
    RnonCO2[	387	]=	-1.67004E-01	;
    RnonCO2[	388	]=	-1.65830E-01	;
    RnonCO2[	389	]=	-1.64655E-01	;
    RnonCO2[	390	]=	-1.63480E-01	;
    RnonCO2[	391	]=	-1.62303E-01	;
    RnonCO2[	392	]=	-1.61126E-01	;
    RnonCO2[	393	]=	-1.59948E-01	;
    RnonCO2[	394	]=	-1.58768E-01	;
    RnonCO2[	395	]=	-1.57588E-01	;
    RnonCO2[	396	]=	-1.56408E-01	;
    RnonCO2[	397	]=	-1.55226E-01	;
    RnonCO2[	398	]=	-1.54044E-01	;
    RnonCO2[	399	]=	-1.52860E-01	;
    RnonCO2[	400	]=	-1.51676E-01	;
    RnonCO2[	401	]=	-1.50491E-01	;
    RnonCO2[	402	]=	-1.49305E-01	;
    RnonCO2[	403	]=	-1.48118E-01	;
    RnonCO2[	404	]=	-1.46930E-01	;
    RnonCO2[	405	]=	-1.45741E-01	;
    RnonCO2[	406	]=	-1.44551E-01	;
    RnonCO2[	407	]=	-1.43360E-01	;
    RnonCO2[	408	]=	-1.42168E-01	;
    RnonCO2[	409	]=	-1.40976E-01	;
    RnonCO2[	410	]=	-1.39782E-01	;
    RnonCO2[	411	]=	-1.38587E-01	;
    RnonCO2[	412	]=	-1.37392E-01	;
    RnonCO2[	413	]=	-1.36195E-01	;
    RnonCO2[	414	]=	-1.34998E-01	;
    RnonCO2[	415	]=	-1.33799E-01	;
    RnonCO2[	416	]=	-1.32600E-01	;
    RnonCO2[	417	]=	-1.31400E-01	;
    RnonCO2[	418	]=	-1.30198E-01	;
    RnonCO2[	419	]=	-1.28996E-01	;
    RnonCO2[	420	]=	-1.27793E-01	;
    RnonCO2[	421	]=	-1.26589E-01	;
    RnonCO2[	422	]=	-1.25384E-01	;
    RnonCO2[	423	]=	-1.24178E-01	;
    RnonCO2[	424	]=	-1.22971E-01	;
    RnonCO2[	425	]=	-1.21764E-01	;
    RnonCO2[	426	]=	-1.20555E-01	;
    RnonCO2[	427	]=	-1.19346E-01	;
    RnonCO2[	428	]=	-1.18136E-01	;
    RnonCO2[	429	]=	-1.16925E-01	;
    RnonCO2[	430	]=	-1.15713E-01	;
    RnonCO2[	431	]=	-1.14499E-01	;
    RnonCO2[	432	]=	-1.13285E-01	;
    RnonCO2[	433	]=	-1.12070E-01	;
    RnonCO2[	434	]=	-1.10854E-01	;
    RnonCO2[	435	]=	-1.09637E-01	;
    RnonCO2[	436	]=	-1.08419E-01	;
    RnonCO2[	437	]=	-1.07200E-01	;
    RnonCO2[	438	]=	-1.05979E-01	;
    RnonCO2[	439	]=	-1.04758E-01	;
    RnonCO2[	440	]=	-1.03536E-01	;
    RnonCO2[	441	]=	-1.02312E-01	;
    RnonCO2[	442	]=	-1.01088E-01	;
    RnonCO2[	443	]=	-9.98630E-02	;
    RnonCO2[	444	]=	-9.86368E-02	;
    RnonCO2[	445	]=	-9.74096E-02	;
    RnonCO2[	446	]=	-9.61814E-02	;
    RnonCO2[	447	]=	-9.49522E-02	;
    RnonCO2[	448	]=	-9.37221E-02	;
    RnonCO2[	449	]=	-9.24909E-02	;
    RnonCO2[	450	]=	-9.12587E-02	;
    RnonCO2[	451	]=	-9.00256E-02	;
    RnonCO2[	452	]=	-8.87914E-02	;
    RnonCO2[	453	]=	-8.75562E-02	;
    RnonCO2[	454	]=	-8.63201E-02	;
    RnonCO2[	455	]=	-8.50829E-02	;
    RnonCO2[	456	]=	-8.38451E-02	;
    RnonCO2[	457	]=	-8.26062E-02	;
    RnonCO2[	458	]=	-8.13664E-02	;
    RnonCO2[	459	]=	-8.01255E-02	;
    RnonCO2[	460	]=	-7.88836E-02	;
    RnonCO2[	461	]=	-7.76407E-02	;
    RnonCO2[	462	]=	-7.63967E-02	;
    RnonCO2[	463	]=	-7.51518E-02	;
    RnonCO2[	464	]=	-7.39058E-02	;
    RnonCO2[	465	]=	-7.26588E-02	;
    RnonCO2[	466	]=	-7.14104E-02	;
    RnonCO2[	467	]=	-7.01610E-02	;
    RnonCO2[	468	]=	-6.89106E-02	;
    RnonCO2[	469	]=	-6.76591E-02	;
    RnonCO2[	470	]=	-6.64066E-02	;
    RnonCO2[	471	]=	-6.51530E-02	;
    RnonCO2[	472	]=	-6.38984E-02	;
    RnonCO2[	473	]=	-6.26428E-02	;
    RnonCO2[	474	]=	-6.13861E-02	;
    RnonCO2[	475	]=	-6.01283E-02	;
    RnonCO2[	476	]=	-5.88695E-02	;
    RnonCO2[	477	]=	-5.76097E-02	;
    RnonCO2[	478	]=	-5.63488E-02	;
    RnonCO2[	479	]=	-5.50868E-02	;
    RnonCO2[	480	]=	-5.38238E-02	;
    RnonCO2[	481	]=	-5.25597E-02	;
    RnonCO2[	482	]=	-5.12946E-02	;
    RnonCO2[	483	]=	-5.00283E-02	;
    RnonCO2[	484	]=	-4.87611E-02	;
    RnonCO2[	485	]=	-4.74927E-02	;
    RnonCO2[	486	]=	-4.74927E-02	;
    RnonCO2[	487	]=	-4.74927E-02	;
    RnonCO2[	488	]=	-4.74927E-02	;
    RnonCO2[	489	]=	-4.74927E-02	;
    RnonCO2[	490	]=	-4.74927E-02	;
    RnonCO2[	491	]=	-4.74927E-02	;
    RnonCO2[	492	]=	-4.74927E-02	;
    RnonCO2[	493	]=	-4.74927E-02	;
    RnonCO2[	494	]=	-4.74927E-02	;
    RnonCO2[	495	]=	-4.74927E-02	;
    RnonCO2[	496	]=	-4.74927E-02	;
    RnonCO2[	497	]=	-4.74927E-02	;
    RnonCO2[	498	]=	-4.74927E-02	;
    RnonCO2[	499	]=	-4.74927E-02	;
    RnonCO2[	500	]=	-4.74927E-02	;
    RnonCO2[	501	]=	-4.74927E-02	;
    RnonCO2[	502	]=	-4.74927E-02	;
    RnonCO2[	503	]=	-4.74927E-02	;
    RnonCO2[	504	]=	-4.74927E-02	;
    RnonCO2[	505	]=	-4.74927E-02	;
    RnonCO2[	506	]=	-4.74927E-02	;
    RnonCO2[	507	]=	-4.74927E-02	;
    RnonCO2[	508	]=	-4.74927E-02	;
    RnonCO2[	509	]=	-4.74927E-02	;
    RnonCO2[	510	]=	-4.74927E-02	;
    RnonCO2[	511	]=	-4.74927E-02	;
    RnonCO2[	512	]=	-4.74927E-02	;
    RnonCO2[	513	]=	-4.74927E-02	;
    RnonCO2[	514	]=	-4.74927E-02	;
    RnonCO2[	515	]=	-4.74927E-02	;
    RnonCO2[	516	]=	-4.74927E-02	;
    RnonCO2[	517	]=	-4.74927E-02	;
    RnonCO2[	518	]=	-4.74927E-02	;
    RnonCO2[	519	]=	-4.74927E-02	;
    RnonCO2[	520	]=	-4.74927E-02	;
    RnonCO2[	521	]=	-4.74927E-02	;
    RnonCO2[	522	]=	-4.74927E-02	;
    RnonCO2[	523	]=	-4.74927E-02	;
    RnonCO2[	524	]=	-4.74927E-02	;
    RnonCO2[	525	]=	-4.74927E-02	;
    RnonCO2[	526	]=	-4.74927E-02	;
    RnonCO2[	527	]=	-4.74927E-02	;
    RnonCO2[	528	]=	-4.74927E-02	;
    RnonCO2[	529	]=	-4.74927E-02	;
    RnonCO2[	530	]=	-4.74927E-02	;
    RnonCO2[	531	]=	-4.74927E-02	;
    RnonCO2[	532	]=	-4.74927E-02	;
    RnonCO2[	533	]=	-4.74927E-02	;
    RnonCO2[	534	]=	-4.74927E-02	;
    RnonCO2[	535	]=	-4.74927E-02	;
    RnonCO2[	536	]=	-4.74927E-02	;
    RnonCO2[	537	]=	-4.74927E-02	;
    RnonCO2[	538	]=	-4.74927E-02	;
    RnonCO2[	539	]=	-4.74927E-02	;
    RnonCO2[	540	]=	-4.74927E-02	;
    RnonCO2[	541	]=	-4.74927E-02	;
    RnonCO2[	542	]=	-4.74927E-02	;
    RnonCO2[	543	]=	-4.74927E-02	;
    RnonCO2[	544	]=	-4.74927E-02	;
    RnonCO2[	545	]=	-4.74927E-02	;
    RnonCO2[	546	]=	-4.74927E-02	;
    RnonCO2[	547	]=	-4.74927E-02	;
    RnonCO2[	548	]=	-4.74927E-02	;
    RnonCO2[	549	]=	-4.74927E-02	;
    RnonCO2[	550	]=	-4.74927E-02	;
    RnonCO2[	551	]=	-4.74927E-02	;
    RnonCO2[	552	]=	-4.74927E-02	;
    RnonCO2[	553	]=	-4.74927E-02	;
    RnonCO2[	554	]=	-4.74927E-02	;
    RnonCO2[	555	]=	-4.74927E-02	;
    RnonCO2[	556	]=	-4.74927E-02	;
    RnonCO2[	557	]=	-4.74927E-02	;
    RnonCO2[	558	]=	-4.74927E-02	;
    RnonCO2[	559	]=	-4.74927E-02	;
    RnonCO2[	560	]=	-4.74927E-02	;
    RnonCO2[	561	]=	-4.74927E-02	;
    RnonCO2[	562	]=	-4.74927E-02	;
    RnonCO2[	563	]=	-4.74927E-02	;
    RnonCO2[	564	]=	-4.74927E-02	;
    RnonCO2[	565	]=	-4.74927E-02	;
    RnonCO2[	566	]=	-4.74927E-02	;
    RnonCO2[	567	]=	-4.74927E-02	;
    RnonCO2[	568	]=	-4.74927E-02	;
    RnonCO2[	569	]=	-4.74927E-02	;
    RnonCO2[	570	]=	-4.74927E-02	;
    RnonCO2[	571	]=	-4.74927E-02	;
    RnonCO2[	572	]=	-4.74927E-02	;
    RnonCO2[	573	]=	-4.74927E-02	;
    RnonCO2[	574	]=	-4.74927E-02	;
    RnonCO2[	575	]=	-4.74927E-02	;
    RnonCO2[	576	]=	-4.74927E-02	;
    RnonCO2[	577	]=	-4.74927E-02	;
    RnonCO2[	578	]=	-4.74927E-02	;
    RnonCO2[	579	]=	-4.74927E-02	;
    RnonCO2[	580	]=	-4.74927E-02	;
    RnonCO2[	581	]=	-4.74927E-02	;
    RnonCO2[	582	]=	-4.74927E-02	;
    RnonCO2[	583	]=	-4.74927E-02	;
    RnonCO2[	584	]=	-4.74927E-02	;
    RnonCO2[	585	]=	-4.74927E-02	;
    RnonCO2[	586	]=	-4.74927E-02	;
    RnonCO2[	587	]=	-4.74927E-02	;
    RnonCO2[	588	]=	-4.74927E-02	;
    RnonCO2[	589	]=	-4.74927E-02	;
    RnonCO2[	590	]=	-4.74927E-02	;
    RnonCO2[	591	]=	-4.74927E-02	;
    RnonCO2[	592	]=	-4.74927E-02	;
    RnonCO2[	593	]=	-4.74927E-02	;
    RnonCO2[	594	]=	-4.74927E-02	;
    RnonCO2[	595	]=	-4.74927E-02	;
    RnonCO2[	596	]=	-4.74927E-02	;
    RnonCO2[	597	]=	-4.74927E-02	;
    RnonCO2[	598	]=	-4.74927E-02	;
    RnonCO2[	599	]=	-4.74927E-02	;
    RnonCO2[	600	]=	-4.74927E-02	;
    RnonCO2[	601	]=	-4.74927E-02	;
    RnonCO2[	602	]=	-4.74927E-02	;
    RnonCO2[	603	]=	-4.74927E-02	;
    RnonCO2[	604	]=	-4.74927E-02	;
    RnonCO2[	605	]=	-4.74927E-02	;
    RnonCO2[	606	]=	-4.74927E-02	;
    RnonCO2[	607	]=	-4.74927E-02	;
    RnonCO2[	608	]=	-4.74927E-02	;
    RnonCO2[	609	]=	-4.74927E-02	;
    RnonCO2[	610	]=	-4.74927E-02	;
    RnonCO2[	611	]=	-4.74927E-02	;
    RnonCO2[	612	]=	-4.74927E-02	;
    RnonCO2[	613	]=	-4.74927E-02	;
    RnonCO2[	614	]=	-4.74927E-02	;
    RnonCO2[	615	]=	-4.74927E-02	;
    RnonCO2[	616	]=	-4.74927E-02	;
    RnonCO2[	617	]=	-4.74927E-02	;
    RnonCO2[	618	]=	-4.74927E-02	;
    RnonCO2[	619	]=	-4.74927E-02	;
    RnonCO2[	620	]=	-4.74927E-02	;
    RnonCO2[	621	]=	-4.74927E-02	;
    RnonCO2[	622	]=	-4.74927E-02	;
    RnonCO2[	623	]=	-4.74927E-02	;
    RnonCO2[	624	]=	-4.74927E-02	;
    RnonCO2[	625	]=	-4.74927E-02	;
    RnonCO2[	626	]=	-4.74927E-02	;
    RnonCO2[	627	]=	-4.74927E-02	;
    RnonCO2[	628	]=	-4.74927E-02	;
    RnonCO2[	629	]=	-4.74927E-02	;
    RnonCO2[	630	]=	-4.74927E-02	;
    RnonCO2[	631	]=	-4.74927E-02	;
    RnonCO2[	632	]=	-4.74927E-02	;
    RnonCO2[	633	]=	-4.74927E-02	;
    RnonCO2[	634	]=	-4.74927E-02	;
    RnonCO2[	635	]=	-4.74927E-02	;
    RnonCO2[	636	]=	-4.74927E-02	;
    RnonCO2[	637	]=	-4.74927E-02	;
    RnonCO2[	638	]=	-4.74927E-02	;
    RnonCO2[	639	]=	-4.74927E-02	;
    RnonCO2[	640	]=	-4.74927E-02	;
    RnonCO2[	641	]=	-4.74927E-02	;
    RnonCO2[	642	]=	-4.74927E-02	;
    RnonCO2[	643	]=	-4.74927E-02	;
    RnonCO2[	644	]=	-4.74927E-02	;
    RnonCO2[	645	]=	-4.74927E-02	;
    RnonCO2[	646	]=	-4.74927E-02	;
    RnonCO2[	647	]=	-4.74927E-02	;
    RnonCO2[	648	]=	-4.74927E-02	;
    RnonCO2[	649	]=	-4.74927E-02	;
    RnonCO2[	650	]=	-4.74927E-02	;
    RnonCO2[	651	]=	-4.74927E-02	;
    RnonCO2[	652	]=	-4.74927E-02	;
    RnonCO2[	653	]=	-4.74927E-02	;
    RnonCO2[	654	]=	-4.74927E-02	;
    RnonCO2[	655	]=	-4.74927E-02	;
    RnonCO2[	656	]=	-4.74927E-02	;
    RnonCO2[	657	]=	-4.74927E-02	;
    RnonCO2[	658	]=	-4.74927E-02	;
    RnonCO2[	659	]=	-4.74927E-02	;
    RnonCO2[	660	]=	-4.74927E-02	;
    RnonCO2[	661	]=	-4.74927E-02	;
    RnonCO2[	662	]=	-4.74927E-02	;
    RnonCO2[	663	]=	-4.74927E-02	;
    RnonCO2[	664	]=	-4.74927E-02	;
    RnonCO2[	665	]=	-4.74927E-02	;
    RnonCO2[	666	]=	-4.74927E-02	;
    RnonCO2[	667	]=	-4.74927E-02	;
    RnonCO2[	668	]=	-4.74927E-02	;
    RnonCO2[	669	]=	-4.74927E-02	;
    RnonCO2[	670	]=	-4.74927E-02	;
    RnonCO2[	671	]=	-4.74927E-02	;
    RnonCO2[	672	]=	-4.74927E-02	;
    RnonCO2[	673	]=	-4.74927E-02	;
    RnonCO2[	674	]=	-4.74927E-02	;
    RnonCO2[	675	]=	-4.74927E-02	;
    RnonCO2[	676	]=	-4.74927E-02	;
    RnonCO2[	677	]=	-4.74927E-02	;
    RnonCO2[	678	]=	-4.74927E-02	;
    RnonCO2[	679	]=	-4.74927E-02	;
    RnonCO2[	680	]=	-4.74927E-02	;
    RnonCO2[	681	]=	-4.74927E-02	;
    RnonCO2[	682	]=	-4.74927E-02	;
    RnonCO2[	683	]=	-4.74927E-02	;
    RnonCO2[	684	]=	-4.74927E-02	;
    RnonCO2[	685	]=	-4.74927E-02	;
    RnonCO2[	686	]=	-4.74927E-02	;
    RnonCO2[	687	]=	-4.74927E-02	;
    RnonCO2[	688	]=	-4.74927E-02	;
    RnonCO2[	689	]=	-4.74927E-02	;
    RnonCO2[	690	]=	-4.74927E-02	;
    RnonCO2[	691	]=	-4.74927E-02	;
    RnonCO2[	692	]=	-4.74927E-02	;
    RnonCO2[	693	]=	-4.74927E-02	;
    RnonCO2[	694	]=	-4.74927E-02	;
    RnonCO2[	695	]=	-4.74927E-02	;
    RnonCO2[	696	]=	-4.74927E-02	;
    RnonCO2[	697	]=	-4.74927E-02	;
    RnonCO2[	698	]=	-4.74927E-02	;
    RnonCO2[	699	]=	-4.74927E-02	;
    RnonCO2[	700	]=	-4.74927E-02	;
    RnonCO2[	701	]=	-4.74927E-02	;
    RnonCO2[	702	]=	-4.74927E-02	;
    RnonCO2[	703	]=	-4.74927E-02	;
    RnonCO2[	704	]=	-4.74927E-02	;
    RnonCO2[	705	]=	-4.74927E-02	;
    RnonCO2[	706	]=	-4.74927E-02	;
    RnonCO2[	707	]=	-4.74927E-02	;
    RnonCO2[	708	]=	-4.74927E-02	;
    RnonCO2[	709	]=	-4.74927E-02	;
    RnonCO2[	710	]=	-4.74927E-02	;
    RnonCO2[	711	]=	-4.74927E-02	;
    RnonCO2[	712	]=	-4.74927E-02	;
    RnonCO2[	713	]=	-4.74927E-02	;
    RnonCO2[	714	]=	-4.74927E-02	;
    RnonCO2[	715	]=	-4.74927E-02	;
    RnonCO2[	716	]=	-4.74927E-02	;
    RnonCO2[	717	]=	-4.74927E-02	;
    RnonCO2[	718	]=	-4.74927E-02	;
    RnonCO2[	719	]=	-4.74927E-02	;
    RnonCO2[	720	]=	-4.74927E-02	;
    RnonCO2[	721	]=	-4.74927E-02	;
    RnonCO2[	722	]=	-4.74927E-02	;
    RnonCO2[	723	]=	-4.74927E-02	;
    RnonCO2[	724	]=	-4.74927E-02	;
    RnonCO2[	725	]=	-4.74927E-02	;
    RnonCO2[	726	]=	-4.74927E-02	;
    RnonCO2[	727	]=	-4.74927E-02	;
    RnonCO2[	728	]=	-4.74927E-02	;
    RnonCO2[	729	]=	-4.74927E-02	;
    RnonCO2[	730	]=	-4.74927E-02	;
    RnonCO2[	731	]=	-4.74927E-02	;
    RnonCO2[	732	]=	-4.74927E-02	;
    RnonCO2[	733	]=	-4.74927E-02	;
    RnonCO2[	734	]=	-4.74927E-02	;
    RnonCO2[	735	]=	-4.74927E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setR_WMGHG_nonCO2_ssp585(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	7.10331E-03	;
    RnonCO2[	2	]=	7.78316E-03	;
    RnonCO2[	3	]=	8.16421E-03	;
    RnonCO2[	4	]=	8.56523E-03	;
    RnonCO2[	5	]=	9.00462E-03	;
    RnonCO2[	6	]=	9.42355E-03	;
    RnonCO2[	7	]=	1.02046E-02	;
    RnonCO2[	8	]=	1.06626E-02	;
    RnonCO2[	9	]=	1.08584E-02	;
    RnonCO2[	10	]=	1.12123E-02	;
    RnonCO2[	11	]=	1.16896E-02	;
    RnonCO2[	12	]=	1.21616E-02	;
    RnonCO2[	13	]=	1.22110E-02	;
    RnonCO2[	14	]=	1.23459E-02	;
    RnonCO2[	15	]=	1.25826E-02	;
    RnonCO2[	16	]=	1.29443E-02	;
    RnonCO2[	17	]=	1.32957E-02	;
    RnonCO2[	18	]=	1.35199E-02	;
    RnonCO2[	19	]=	1.37321E-02	;
    RnonCO2[	20	]=	1.39477E-02	;
    RnonCO2[	21	]=	1.41663E-02	;
    RnonCO2[	22	]=	1.42387E-02	;
    RnonCO2[	23	]=	1.45426E-02	;
    RnonCO2[	24	]=	1.48494E-02	;
    RnonCO2[	25	]=	1.51686E-02	;
    RnonCO2[	26	]=	1.54978E-02	;
    RnonCO2[	27	]=	1.58532E-02	;
    RnonCO2[	28	]=	1.60544E-02	;
    RnonCO2[	29	]=	1.63723E-02	;
    RnonCO2[	30	]=	1.66816E-02	;
    RnonCO2[	31	]=	1.70490E-02	;
    RnonCO2[	32	]=	1.74609E-02	;
    RnonCO2[	33	]=	1.79364E-02	;
    RnonCO2[	34	]=	1.84043E-02	;
    RnonCO2[	35	]=	1.88359E-02	;
    RnonCO2[	36	]=	1.92955E-02	;
    RnonCO2[	37	]=	1.98378E-02	;
    RnonCO2[	38	]=	2.03977E-02	;
    RnonCO2[	39	]=	2.09735E-02	;
    RnonCO2[	40	]=	2.16056E-02	;
    RnonCO2[	41	]=	2.22393E-02	;
    RnonCO2[	42	]=	2.29311E-02	;
    RnonCO2[	43	]=	2.36748E-02	;
    RnonCO2[	44	]=	2.44046E-02	;
    RnonCO2[	45	]=	2.52467E-02	;
    RnonCO2[	46	]=	2.61263E-02	;
    RnonCO2[	47	]=	2.69429E-02	;
    RnonCO2[	48	]=	2.77341E-02	;
    RnonCO2[	49	]=	2.83045E-02	;
    RnonCO2[	50	]=	2.89403E-02	;
    RnonCO2[	51	]=	2.95720E-02	;
    RnonCO2[	52	]=	3.04369E-02	;
    RnonCO2[	53	]=	3.11179E-02	;
    RnonCO2[	54	]=	3.17335E-02	;
    RnonCO2[	55	]=	3.21995E-02	;
    RnonCO2[	56	]=	3.27710E-02	;
    RnonCO2[	57	]=	3.34925E-02	;
    RnonCO2[	58	]=	3.41349E-02	;
    RnonCO2[	59	]=	3.47361E-02	;
    RnonCO2[	60	]=	3.52835E-02	;
    RnonCO2[	61	]=	3.57663E-02	;
    RnonCO2[	62	]=	3.62250E-02	;
    RnonCO2[	63	]=	3.67789E-02	;
    RnonCO2[	64	]=	3.72639E-02	;
    RnonCO2[	65	]=	3.77173E-02	;
    RnonCO2[	66	]=	3.80834E-02	;
    RnonCO2[	67	]=	3.82917E-02	;
    RnonCO2[	68	]=	3.83779E-02	;
    RnonCO2[	69	]=	3.83993E-02	;
    RnonCO2[	70	]=	3.84178E-02	;
    RnonCO2[	71	]=	3.81604E-02	;
    RnonCO2[	72	]=	3.78918E-02	;
    RnonCO2[	73	]=	3.77599E-02	;
    RnonCO2[	74	]=	3.77237E-02	;
    RnonCO2[	75	]=	3.78048E-02	;
    RnonCO2[	76	]=	3.78386E-02	;
    RnonCO2[	77	]=	3.80441E-02	;
    RnonCO2[	78	]=	3.90290E-02	;
    RnonCO2[	79	]=	4.04504E-02	;
    RnonCO2[	80	]=	4.16551E-02	;
    RnonCO2[	81	]=	4.29170E-02	;
    RnonCO2[	82	]=	4.36076E-02	;
    RnonCO2[	83	]=	4.39447E-02	;
    RnonCO2[	84	]=	4.42524E-02	;
    RnonCO2[	85	]=	4.44999E-02	;
    RnonCO2[	86	]=	4.48464E-02	;
    RnonCO2[	87	]=	4.55468E-02	;
    RnonCO2[	88	]=	4.66165E-02	;
    RnonCO2[	89	]=	4.77478E-02	;
    RnonCO2[	90	]=	4.90682E-02	;
    RnonCO2[	91	]=	5.03096E-02	;
    RnonCO2[	92	]=	5.16276E-02	;
    RnonCO2[	93	]=	5.30376E-02	;
    RnonCO2[	94	]=	5.47244E-02	;
    RnonCO2[	95	]=	5.64095E-02	;
    RnonCO2[	96	]=	5.82723E-02	;
    RnonCO2[	97	]=	6.04282E-02	;
    RnonCO2[	98	]=	6.28104E-02	;
    RnonCO2[	99	]=	6.53463E-02	;
    RnonCO2[	100	]=	6.78273E-02	;
    RnonCO2[	101	]=	7.04356E-02	;
    RnonCO2[	102	]=	7.31258E-02	;
    RnonCO2[	103	]=	7.56328E-02	;
    RnonCO2[	104	]=	7.78906E-02	;
    RnonCO2[	105	]=	7.97720E-02	;
    RnonCO2[	106	]=	8.12966E-02	;
    RnonCO2[	107	]=	8.26077E-02	;
    RnonCO2[	108	]=	8.37307E-02	;
    RnonCO2[	109	]=	8.52498E-02	;
    RnonCO2[	110	]=	8.67760E-02	;
    RnonCO2[	111	]=	8.80870E-02	;
    RnonCO2[	112	]=	8.94019E-02	;
    RnonCO2[	113	]=	9.08851E-02	;
    RnonCO2[	114	]=	9.25656E-02	;
    RnonCO2[	115	]=	9.44031E-02	;
    RnonCO2[	116	]=	9.60891E-02	;
    RnonCO2[	117	]=	9.77705E-02	;
    RnonCO2[	118	]=	9.94766E-02	;
    RnonCO2[	119	]=	1.01287E-01	;
    RnonCO2[	120	]=	1.03273E-01	;
    RnonCO2[	121	]=	1.05186E-01	;
    RnonCO2[	122	]=	1.07323E-01	;
    RnonCO2[	123	]=	1.09315E-01	;
    RnonCO2[	124	]=	1.11526E-01	;
    RnonCO2[	125	]=	1.13634E-01	;
    RnonCO2[	126	]=	1.15744E-01	;
    RnonCO2[	127	]=	1.18252E-01	;
    RnonCO2[	128	]=	1.20738E-01	;
    RnonCO2[	129	]=	1.22995E-01	;
    RnonCO2[	130	]=	1.25015E-01	;
    RnonCO2[	131	]=	1.26244E-01	;
    RnonCO2[	132	]=	1.27462E-01	;
    RnonCO2[	133	]=	1.29373E-01	;
    RnonCO2[	134	]=	1.31684E-01	;
    RnonCO2[	135	]=	1.33998E-01	;
    RnonCO2[	136	]=	1.36339E-01	;
    RnonCO2[	137	]=	1.39352E-01	;
    RnonCO2[	138	]=	1.42583E-01	;
    RnonCO2[	139	]=	1.46453E-01	;
    RnonCO2[	140	]=	1.50302E-01	;
    RnonCO2[	141	]=	1.54323E-01	;
    RnonCO2[	142	]=	1.58631E-01	;
    RnonCO2[	143	]=	1.62437E-01	;
    RnonCO2[	144	]=	1.66457E-01	;
    RnonCO2[	145	]=	1.70591E-01	;
    RnonCO2[	146	]=	1.74483E-01	;
    RnonCO2[	147	]=	1.77711E-01	;
    RnonCO2[	148	]=	1.80270E-01	;
    RnonCO2[	149	]=	1.82730E-01	;
    RnonCO2[	150	]=	1.85377E-01	;
    RnonCO2[	151	]=	1.90039E-01	;
    RnonCO2[	152	]=	1.93816E-01	;
    RnonCO2[	153	]=	1.97971E-01	;
    RnonCO2[	154	]=	2.02136E-01	;
    RnonCO2[	155	]=	2.06346E-01	;
    RnonCO2[	156	]=	2.10480E-01	;
    RnonCO2[	157	]=	2.14559E-01	;
    RnonCO2[	158	]=	2.18733E-01	;
    RnonCO2[	159	]=	2.21484E-01	;
    RnonCO2[	160	]=	2.23104E-01	;
    RnonCO2[	161	]=	2.24051E-01	;
    RnonCO2[	162	]=	2.25386E-01	;
    RnonCO2[	163	]=	2.28284E-01	;
    RnonCO2[	164	]=	2.31683E-01	;
    RnonCO2[	165	]=	2.35027E-01	;
    RnonCO2[	166	]=	2.38256E-01	;
    RnonCO2[	167	]=	2.40995E-01	;
    RnonCO2[	168	]=	2.43957E-01	;
    RnonCO2[	169	]=	2.47090E-01	;
    RnonCO2[	170	]=	2.50368E-01	;
    RnonCO2[	171	]=	2.53541E-01	;
    RnonCO2[	172	]=	2.56739E-01	;
    RnonCO2[	173	]=	2.59959E-01	;
    RnonCO2[	174	]=	2.64036E-01	;
    RnonCO2[	175	]=	2.66719E-01	;
    RnonCO2[	176	]=	2.69455E-01	;
    RnonCO2[	177	]=	2.73293E-01	;
    RnonCO2[	178	]=	2.78184E-01	;
    RnonCO2[	179	]=	2.81375E-01	;
    RnonCO2[	180	]=	2.84248E-01	;
    RnonCO2[	181	]=	2.87860E-01	;
    RnonCO2[	182	]=	2.91940E-01	;
    RnonCO2[	183	]=	2.95965E-01	;
    RnonCO2[	184	]=	2.99381E-01	;
    RnonCO2[	185	]=	3.02519E-01	;
    RnonCO2[	186	]=	3.06383E-01	;
    RnonCO2[	187	]=	3.10608E-01	;
    RnonCO2[	188	]=	3.17149E-01	;
    RnonCO2[	189	]=	3.24509E-01	;
    RnonCO2[	190	]=	3.32836E-01	;
    RnonCO2[	191	]=	3.42549E-01	;
    RnonCO2[	192	]=	3.52494E-01	;
    RnonCO2[	193	]=	3.60845E-01	;
    RnonCO2[	194	]=	3.68298E-01	;
    RnonCO2[	195	]=	3.74807E-01	;
    RnonCO2[	196	]=	3.81073E-01	;
    RnonCO2[	197	]=	3.91436E-01	;
    RnonCO2[	198	]=	4.04761E-01	;
    RnonCO2[	199	]=	4.17746E-01	;
    RnonCO2[	200	]=	4.29906E-01	;
    RnonCO2[	201	]=	4.41574E-01	;
    RnonCO2[	202	]=	4.54222E-01	;
    RnonCO2[	203	]=	4.69974E-01	;
    RnonCO2[	204	]=	4.86584E-01	;
    RnonCO2[	205	]=	5.05689E-01	;
    RnonCO2[	206	]=	5.24626E-01	;
    RnonCO2[	207	]=	5.43502E-01	;
    RnonCO2[	208	]=	5.61469E-01	;
    RnonCO2[	209	]=	5.80450E-01	;
    RnonCO2[	210	]=	6.00643E-01	;
    RnonCO2[	211	]=	6.21376E-01	;
    RnonCO2[	212	]=	6.42603E-01	;
    RnonCO2[	213	]=	6.63903E-01	;
    RnonCO2[	214	]=	6.84476E-01	;
    RnonCO2[	215	]=	7.04205E-01	;
    RnonCO2[	216	]=	7.24133E-01	;
    RnonCO2[	217	]=	7.43103E-01	;
    RnonCO2[	218	]=	7.61404E-01	;
    RnonCO2[	219	]=	7.77964E-01	;
    RnonCO2[	220	]=	7.97595E-01	;
    RnonCO2[	221	]=	8.16964E-01	;
    RnonCO2[	222	]=	8.39075E-01	;
    RnonCO2[	223	]=	8.61591E-01	;
    RnonCO2[	224	]=	8.83592E-01	;
    RnonCO2[	225	]=	9.01452E-01	;
    RnonCO2[	226	]=	9.16684E-01	;
    RnonCO2[	227	]=	9.29776E-01	;
    RnonCO2[	228	]=	9.35938E-01	;
    RnonCO2[	229	]=	9.43530E-01	;
    RnonCO2[	230	]=	9.50693E-01	;
    RnonCO2[	231	]=	9.58473E-01	;
    RnonCO2[	232	]=	9.64386E-01	;
    RnonCO2[	233	]=	9.72568E-01	;
    RnonCO2[	234	]=	9.79885E-01	;
    RnonCO2[	235	]=	9.84974E-01	;
    RnonCO2[	236	]=	9.88604E-01	;
    RnonCO2[	237	]=	9.92932E-01	;
    RnonCO2[	238	]=	9.97888E-01	;
    RnonCO2[	239	]=	1.00145E+00	;
    RnonCO2[	240	]=	1.00527E+00	;
    RnonCO2[	241	]=	1.00942E+00	;
    RnonCO2[	242	]=	1.01543E+00	;
    RnonCO2[	243	]=	1.02385E+00	;
    RnonCO2[	244	]=	1.02861E+00	;
    RnonCO2[	245	]=	1.03536E+00	;
    RnonCO2[	246	]=	1.04219E+00	;
    RnonCO2[	247	]=	1.04692E+00	;
    RnonCO2[	248	]=	1.05506E+00	;
    RnonCO2[	249	]=	1.06283E+00	;
    RnonCO2[	250	]=	1.07202E+00	;
    RnonCO2[	251	]=	1.08034E+00	;
    RnonCO2[	252	]=	1.09042E+00	;
    RnonCO2[	253	]=	1.09810E+00	;
    RnonCO2[	254	]=	1.10548E+00	;
    RnonCO2[	255	]=	1.11245E+00	;
    RnonCO2[	256	]=	1.11908E+00	;
    RnonCO2[	257	]=	1.12555E+00	;
    RnonCO2[	258	]=	1.13209E+00	;
    RnonCO2[	259	]=	1.13884E+00	;
    RnonCO2[	260	]=	1.14583E+00	;
    RnonCO2[	261	]=	1.15311E+00	;
    RnonCO2[	262	]=	1.16055E+00	;
    RnonCO2[	263	]=	1.16802E+00	;
    RnonCO2[	264	]=	1.17563E+00	;
    RnonCO2[	265	]=	1.18342E+00	;
    RnonCO2[	266	]=	1.19144E+00	;
    RnonCO2[	267	]=	1.19966E+00	;
    RnonCO2[	268	]=	1.20807E+00	;
    RnonCO2[	269	]=	1.21675E+00	;
    RnonCO2[	270	]=	1.22572E+00	;
    RnonCO2[	271	]=	1.23501E+00	;
    RnonCO2[	272	]=	1.24463E+00	;
    RnonCO2[	273	]=	1.25456E+00	;
    RnonCO2[	274	]=	1.26481E+00	;
    RnonCO2[	275	]=	1.27537E+00	;
    RnonCO2[	276	]=	1.28620E+00	;
    RnonCO2[	277	]=	1.29724E+00	;
    RnonCO2[	278	]=	1.30840E+00	;
    RnonCO2[	279	]=	1.31967E+00	;
    RnonCO2[	280	]=	1.33103E+00	;
    RnonCO2[	281	]=	1.34248E+00	;
    RnonCO2[	282	]=	1.35402E+00	;
    RnonCO2[	283	]=	1.36564E+00	;
    RnonCO2[	284	]=	1.37734E+00	;
    RnonCO2[	285	]=	1.38911E+00	;
    RnonCO2[	286	]=	1.40094E+00	;
    RnonCO2[	287	]=	1.41257E+00	;
    RnonCO2[	288	]=	1.42375E+00	;
    RnonCO2[	289	]=	1.43453E+00	;
    RnonCO2[	290	]=	1.44492E+00	;
    RnonCO2[	291	]=	1.45497E+00	;
    RnonCO2[	292	]=	1.46470E+00	;
    RnonCO2[	293	]=	1.47414E+00	;
    RnonCO2[	294	]=	1.48331E+00	;
    RnonCO2[	295	]=	1.49223E+00	;
    RnonCO2[	296	]=	1.50092E+00	;
    RnonCO2[	297	]=	1.50943E+00	;
    RnonCO2[	298	]=	1.51781E+00	;
    RnonCO2[	299	]=	1.52606E+00	;
    RnonCO2[	300	]=	1.53421E+00	;
    RnonCO2[	301	]=	1.54224E+00	;
    RnonCO2[	302	]=	1.55017E+00	;
    RnonCO2[	303	]=	1.55802E+00	;
    RnonCO2[	304	]=	1.56578E+00	;
    RnonCO2[	305	]=	1.57346E+00	;
    RnonCO2[	306	]=	1.58108E+00	;
    RnonCO2[	307	]=	1.58843E+00	;
    RnonCO2[	308	]=	1.59535E+00	;
    RnonCO2[	309	]=	1.60187E+00	;
    RnonCO2[	310	]=	1.60802E+00	;
    RnonCO2[	311	]=	1.61382E+00	;
    RnonCO2[	312	]=	1.61929E+00	;
    RnonCO2[	313	]=	1.62445E+00	;
    RnonCO2[	314	]=	1.62932E+00	;
    RnonCO2[	315	]=	1.63393E+00	;
    RnonCO2[	316	]=	1.63828E+00	;
    RnonCO2[	317	]=	1.64217E+00	;
    RnonCO2[	318	]=	1.64542E+00	;
    RnonCO2[	319	]=	1.64809E+00	;
    RnonCO2[	320	]=	1.65020E+00	;
    RnonCO2[	321	]=	1.65179E+00	;
    RnonCO2[	322	]=	1.65289E+00	;
    RnonCO2[	323	]=	1.65352E+00	;
    RnonCO2[	324	]=	1.65372E+00	;
    RnonCO2[	325	]=	1.65350E+00	;
    RnonCO2[	326	]=	1.65290E+00	;
    RnonCO2[	327	]=	1.65201E+00	;
    RnonCO2[	328	]=	1.65097E+00	;
    RnonCO2[	329	]=	1.64976E+00	;
    RnonCO2[	330	]=	1.64841E+00	;
    RnonCO2[	331	]=	1.64690E+00	;
    RnonCO2[	332	]=	1.64526E+00	;
    RnonCO2[	333	]=	1.64348E+00	;
    RnonCO2[	334	]=	1.64157E+00	;
    RnonCO2[	335	]=	1.63953E+00	;
    RnonCO2[	336	]=	1.63736E+00	;
    RnonCO2[	337	]=	1.63502E+00	;
    RnonCO2[	338	]=	1.63246E+00	;
    RnonCO2[	339	]=	1.62970E+00	;
    RnonCO2[	340	]=	1.62675E+00	;
    RnonCO2[	341	]=	1.62362E+00	;
    RnonCO2[	342	]=	1.62032E+00	;
    RnonCO2[	343	]=	1.61685E+00	;
    RnonCO2[	344	]=	1.61324E+00	;
    RnonCO2[	345	]=	1.60948E+00	;
    RnonCO2[	346	]=	1.60559E+00	;
    RnonCO2[	347	]=	1.60157E+00	;
    RnonCO2[	348	]=	1.59743E+00	;
    RnonCO2[	349	]=	1.59318E+00	;
    RnonCO2[	350	]=	1.58882E+00	;
    RnonCO2[	351	]=	1.58436E+00	;
    RnonCO2[	352	]=	1.57980E+00	;
    RnonCO2[	353	]=	1.57516E+00	;
    RnonCO2[	354	]=	1.57043E+00	;
    RnonCO2[	355	]=	1.56561E+00	;
    RnonCO2[	356	]=	1.56072E+00	;
    RnonCO2[	357	]=	1.55576E+00	;
    RnonCO2[	358	]=	1.55073E+00	;
    RnonCO2[	359	]=	1.54564E+00	;
    RnonCO2[	360	]=	1.54048E+00	;
    RnonCO2[	361	]=	1.53527E+00	;
    RnonCO2[	362	]=	1.53001E+00	;
    RnonCO2[	363	]=	1.52468E+00	;
    RnonCO2[	364	]=	1.51932E+00	;
    RnonCO2[	365	]=	1.51391E+00	;
    RnonCO2[	366	]=	1.50845E+00	;
    RnonCO2[	367	]=	1.50295E+00	;
    RnonCO2[	368	]=	1.49741E+00	;
    RnonCO2[	369	]=	1.49184E+00	;
    RnonCO2[	370	]=	1.48623E+00	;
    RnonCO2[	371	]=	1.48058E+00	;
    RnonCO2[	372	]=	1.47491E+00	;
    RnonCO2[	373	]=	1.46921E+00	;
    RnonCO2[	374	]=	1.46348E+00	;
    RnonCO2[	375	]=	1.45772E+00	;
    RnonCO2[	376	]=	1.45194E+00	;
    RnonCO2[	377	]=	1.44613E+00	;
    RnonCO2[	378	]=	1.44030E+00	;
    RnonCO2[	379	]=	1.43445E+00	;
    RnonCO2[	380	]=	1.42858E+00	;
    RnonCO2[	381	]=	1.42269E+00	;
    RnonCO2[	382	]=	1.41678E+00	;
    RnonCO2[	383	]=	1.41085E+00	;
    RnonCO2[	384	]=	1.40491E+00	;
    RnonCO2[	385	]=	1.39896E+00	;
    RnonCO2[	386	]=	1.39299E+00	;
    RnonCO2[	387	]=	1.38701E+00	;
    RnonCO2[	388	]=	1.38101E+00	;
    RnonCO2[	389	]=	1.37500E+00	;
    RnonCO2[	390	]=	1.36898E+00	;
    RnonCO2[	391	]=	1.36295E+00	;
    RnonCO2[	392	]=	1.35691E+00	;
    RnonCO2[	393	]=	1.35085E+00	;
    RnonCO2[	394	]=	1.34479E+00	;
    RnonCO2[	395	]=	1.33872E+00	;
    RnonCO2[	396	]=	1.33264E+00	;
    RnonCO2[	397	]=	1.32656E+00	;
    RnonCO2[	398	]=	1.32047E+00	;
    RnonCO2[	399	]=	1.31436E+00	;
    RnonCO2[	400	]=	1.30826E+00	;
    RnonCO2[	401	]=	1.30215E+00	;
    RnonCO2[	402	]=	1.29603E+00	;
    RnonCO2[	403	]=	1.28990E+00	;
    RnonCO2[	404	]=	1.28377E+00	;
    RnonCO2[	405	]=	1.27763E+00	;
    RnonCO2[	406	]=	1.27149E+00	;
    RnonCO2[	407	]=	1.26535E+00	;
    RnonCO2[	408	]=	1.25919E+00	;
    RnonCO2[	409	]=	1.25304E+00	;
    RnonCO2[	410	]=	1.24688E+00	;
    RnonCO2[	411	]=	1.24072E+00	;
    RnonCO2[	412	]=	1.23455E+00	;
    RnonCO2[	413	]=	1.22838E+00	;
    RnonCO2[	414	]=	1.22220E+00	;
    RnonCO2[	415	]=	1.21602E+00	;
    RnonCO2[	416	]=	1.20984E+00	;
    RnonCO2[	417	]=	1.20365E+00	;
    RnonCO2[	418	]=	1.19746E+00	;
    RnonCO2[	419	]=	1.19127E+00	;
    RnonCO2[	420	]=	1.18508E+00	;
    RnonCO2[	421	]=	1.17888E+00	;
    RnonCO2[	422	]=	1.17268E+00	;
    RnonCO2[	423	]=	1.16647E+00	;
    RnonCO2[	424	]=	1.16026E+00	;
    RnonCO2[	425	]=	1.15405E+00	;
    RnonCO2[	426	]=	1.14784E+00	;
    RnonCO2[	427	]=	1.14162E+00	;
    RnonCO2[	428	]=	1.13540E+00	;
    RnonCO2[	429	]=	1.12918E+00	;
    RnonCO2[	430	]=	1.12295E+00	;
    RnonCO2[	431	]=	1.11672E+00	;
    RnonCO2[	432	]=	1.11049E+00	;
    RnonCO2[	433	]=	1.10426E+00	;
    RnonCO2[	434	]=	1.09802E+00	;
    RnonCO2[	435	]=	1.09178E+00	;
    RnonCO2[	436	]=	1.08553E+00	;
    RnonCO2[	437	]=	1.07929E+00	;
    RnonCO2[	438	]=	1.07303E+00	;
    RnonCO2[	439	]=	1.06678E+00	;
    RnonCO2[	440	]=	1.06052E+00	;
    RnonCO2[	441	]=	1.05426E+00	;
    RnonCO2[	442	]=	1.04800E+00	;
    RnonCO2[	443	]=	1.04173E+00	;
    RnonCO2[	444	]=	1.03546E+00	;
    RnonCO2[	445	]=	1.02918E+00	;
    RnonCO2[	446	]=	1.02291E+00	;
    RnonCO2[	447	]=	1.01662E+00	;
    RnonCO2[	448	]=	1.01034E+00	;
    RnonCO2[	449	]=	1.00405E+00	;
    RnonCO2[	450	]=	9.97753E-01	;
    RnonCO2[	451	]=	9.91453E-01	;
    RnonCO2[	452	]=	9.85150E-01	;
    RnonCO2[	453	]=	9.78841E-01	;
    RnonCO2[	454	]=	9.72529E-01	;
    RnonCO2[	455	]=	9.66215E-01	;
    RnonCO2[	456	]=	9.59891E-01	;
    RnonCO2[	457	]=	9.53567E-01	;
    RnonCO2[	458	]=	9.47236E-01	;
    RnonCO2[	459	]=	9.40901E-01	;
    RnonCO2[	460	]=	9.34561E-01	;
    RnonCO2[	461	]=	9.28216E-01	;
    RnonCO2[	462	]=	9.21867E-01	;
    RnonCO2[	463	]=	9.15511E-01	;
    RnonCO2[	464	]=	9.09153E-01	;
    RnonCO2[	465	]=	9.02789E-01	;
    RnonCO2[	466	]=	8.96420E-01	;
    RnonCO2[	467	]=	8.90040E-01	;
    RnonCO2[	468	]=	8.83664E-01	;
    RnonCO2[	469	]=	8.77275E-01	;
    RnonCO2[	470	]=	8.70881E-01	;
    RnonCO2[	471	]=	8.64484E-01	;
    RnonCO2[	472	]=	8.58080E-01	;
    RnonCO2[	473	]=	8.51673E-01	;
    RnonCO2[	474	]=	8.45256E-01	;
    RnonCO2[	475	]=	8.38835E-01	;
    RnonCO2[	476	]=	8.32405E-01	;
    RnonCO2[	477	]=	8.25968E-01	;
    RnonCO2[	478	]=	8.19527E-01	;
    RnonCO2[	479	]=	8.13081E-01	;
    RnonCO2[	480	]=	8.06628E-01	;
    RnonCO2[	481	]=	8.00166E-01	;
    RnonCO2[	482	]=	7.93700E-01	;
    RnonCO2[	483	]=	7.87225E-01	;
    RnonCO2[	484	]=	7.80740E-01	;
    RnonCO2[	485	]=	7.74250E-01	;
    RnonCO2[	486	]=	7.67755E-01	;
    RnonCO2[	487	]=	7.61486E-01	;
    RnonCO2[	488	]=	7.55644E-01	;
    RnonCO2[	489	]=	7.50189E-01	;
    RnonCO2[	490	]=	7.45089E-01	;
    RnonCO2[	491	]=	7.40316E-01	;
    RnonCO2[	492	]=	7.35837E-01	;
    RnonCO2[	493	]=	7.31638E-01	;
    RnonCO2[	494	]=	7.27689E-01	;
    RnonCO2[	495	]=	7.23976E-01	;
    RnonCO2[	496	]=	7.20477E-01	;
    RnonCO2[	497	]=	7.17175E-01	;
    RnonCO2[	498	]=	7.14051E-01	;
    RnonCO2[	499	]=	7.11103E-01	;
    RnonCO2[	500	]=	7.08306E-01	;
    RnonCO2[	501	]=	7.05651E-01	;
    RnonCO2[	502	]=	7.03134E-01	;
    RnonCO2[	503	]=	7.00736E-01	;
    RnonCO2[	504	]=	6.98455E-01	;
    RnonCO2[	505	]=	6.96280E-01	;
    RnonCO2[	506	]=	6.94204E-01	;
    RnonCO2[	507	]=	6.92219E-01	;
    RnonCO2[	508	]=	6.90318E-01	;
    RnonCO2[	509	]=	6.88499E-01	;
    RnonCO2[	510	]=	6.86750E-01	;
    RnonCO2[	511	]=	6.85077E-01	;
    RnonCO2[	512	]=	6.83464E-01	;
    RnonCO2[	513	]=	6.81913E-01	;
    RnonCO2[	514	]=	6.80418E-01	;
    RnonCO2[	515	]=	6.78978E-01	;
    RnonCO2[	516	]=	6.77590E-01	;
    RnonCO2[	517	]=	6.76245E-01	;
    RnonCO2[	518	]=	6.74950E-01	;
    RnonCO2[	519	]=	6.73689E-01	;
    RnonCO2[	520	]=	6.72472E-01	;
    RnonCO2[	521	]=	6.71296E-01	;
    RnonCO2[	522	]=	6.70154E-01	;
    RnonCO2[	523	]=	6.69041E-01	;
    RnonCO2[	524	]=	6.67961E-01	;
    RnonCO2[	525	]=	6.66916E-01	;
    RnonCO2[	526	]=	6.65892E-01	;
    RnonCO2[	527	]=	6.64900E-01	;
    RnonCO2[	528	]=	6.63935E-01	;
    RnonCO2[	529	]=	6.62994E-01	;
    RnonCO2[	530	]=	6.62077E-01	;
    RnonCO2[	531	]=	6.61180E-01	;
    RnonCO2[	532	]=	6.60306E-01	;
    RnonCO2[	533	]=	6.59453E-01	;
    RnonCO2[	534	]=	6.58619E-01	;
    RnonCO2[	535	]=	6.57800E-01	;
    RnonCO2[	536	]=	6.57005E-01	;
    RnonCO2[	537	]=	6.56223E-01	;
    RnonCO2[	538	]=	6.55459E-01	;
    RnonCO2[	539	]=	6.54714E-01	;
    RnonCO2[	540	]=	6.53979E-01	;
    RnonCO2[	541	]=	6.53262E-01	;
    RnonCO2[	542	]=	6.52561E-01	;
    RnonCO2[	543	]=	6.51870E-01	;
    RnonCO2[	544	]=	6.51192E-01	;
    RnonCO2[	545	]=	6.50530E-01	;
    RnonCO2[	546	]=	6.49876E-01	;
    RnonCO2[	547	]=	6.49239E-01	;
    RnonCO2[	548	]=	6.48607E-01	;
    RnonCO2[	549	]=	6.47990E-01	;
    RnonCO2[	550	]=	6.47384E-01	;
    RnonCO2[	551	]=	6.46787E-01	;
    RnonCO2[	552	]=	6.46198E-01	;
    RnonCO2[	553	]=	6.45623E-01	;
    RnonCO2[	554	]=	6.45053E-01	;
    RnonCO2[	555	]=	6.44495E-01	;
    RnonCO2[	556	]=	6.43940E-01	;
    RnonCO2[	557	]=	6.43400E-01	;
    RnonCO2[	558	]=	6.42866E-01	;
    RnonCO2[	559	]=	6.42340E-01	;
    RnonCO2[	560	]=	6.41820E-01	;
    RnonCO2[	561	]=	6.41314E-01	;
    RnonCO2[	562	]=	6.40809E-01	;
    RnonCO2[	563	]=	6.40314E-01	;
    RnonCO2[	564	]=	6.39820E-01	;
    RnonCO2[	565	]=	6.39340E-01	;
    RnonCO2[	566	]=	6.38859E-01	;
    RnonCO2[	567	]=	6.38389E-01	;
    RnonCO2[	568	]=	6.37927E-01	;
    RnonCO2[	569	]=	6.37467E-01	;
    RnonCO2[	570	]=	6.37014E-01	;
    RnonCO2[	571	]=	6.36566E-01	;
    RnonCO2[	572	]=	6.36130E-01	;
    RnonCO2[	573	]=	6.35695E-01	;
    RnonCO2[	574	]=	6.35273E-01	;
    RnonCO2[	575	]=	6.34864E-01	;
    RnonCO2[	576	]=	6.34458E-01	;
    RnonCO2[	577	]=	6.34062E-01	;
    RnonCO2[	578	]=	6.33673E-01	;
    RnonCO2[	579	]=	6.33292E-01	;
    RnonCO2[	580	]=	6.32915E-01	;
    RnonCO2[	581	]=	6.32544E-01	;
    RnonCO2[	582	]=	6.32181E-01	;
    RnonCO2[	583	]=	6.31819E-01	;
    RnonCO2[	584	]=	6.31470E-01	;
    RnonCO2[	585	]=	6.31121E-01	;
    RnonCO2[	586	]=	6.30778E-01	;
    RnonCO2[	587	]=	6.30436E-01	;
    RnonCO2[	588	]=	6.30098E-01	;
    RnonCO2[	589	]=	6.29771E-01	;
    RnonCO2[	590	]=	6.29439E-01	;
    RnonCO2[	591	]=	6.29117E-01	;
    RnonCO2[	592	]=	6.28798E-01	;
    RnonCO2[	593	]=	6.28481E-01	;
    RnonCO2[	594	]=	6.28171E-01	;
    RnonCO2[	595	]=	6.27859E-01	;
    RnonCO2[	596	]=	6.27551E-01	;
    RnonCO2[	597	]=	6.27251E-01	;
    RnonCO2[	598	]=	6.26952E-01	;
    RnonCO2[	599	]=	6.26651E-01	;
    RnonCO2[	600	]=	6.26359E-01	;
    RnonCO2[	601	]=	6.26067E-01	;
    RnonCO2[	602	]=	6.25779E-01	;
    RnonCO2[	603	]=	6.25493E-01	;
    RnonCO2[	604	]=	6.25209E-01	;
    RnonCO2[	605	]=	6.24929E-01	;
    RnonCO2[	606	]=	6.24653E-01	;
    RnonCO2[	607	]=	6.24376E-01	;
    RnonCO2[	608	]=	6.24106E-01	;
    RnonCO2[	609	]=	6.23832E-01	;
    RnonCO2[	610	]=	6.23565E-01	;
    RnonCO2[	611	]=	6.23303E-01	;
    RnonCO2[	612	]=	6.23039E-01	;
    RnonCO2[	613	]=	6.22779E-01	;
    RnonCO2[	614	]=	6.22520E-01	;
    RnonCO2[	615	]=	6.22263E-01	;
    RnonCO2[	616	]=	6.22015E-01	;
    RnonCO2[	617	]=	6.21760E-01	;
    RnonCO2[	618	]=	6.21514E-01	;
    RnonCO2[	619	]=	6.21269E-01	;
    RnonCO2[	620	]=	6.21021E-01	;
    RnonCO2[	621	]=	6.20779E-01	;
    RnonCO2[	622	]=	6.20538E-01	;
    RnonCO2[	623	]=	6.20300E-01	;
    RnonCO2[	624	]=	6.20061E-01	;
    RnonCO2[	625	]=	6.19826E-01	;
    RnonCO2[	626	]=	6.19592E-01	;
    RnonCO2[	627	]=	6.19358E-01	;
    RnonCO2[	628	]=	6.19126E-01	;
    RnonCO2[	629	]=	6.18902E-01	;
    RnonCO2[	630	]=	6.18672E-01	;
    RnonCO2[	631	]=	6.18445E-01	;
    RnonCO2[	632	]=	6.18224E-01	;
    RnonCO2[	633	]=	6.18004E-01	;
    RnonCO2[	634	]=	6.17779E-01	;
    RnonCO2[	635	]=	6.17563E-01	;
    RnonCO2[	636	]=	6.17346E-01	;
    RnonCO2[	637	]=	6.17126E-01	;
    RnonCO2[	638	]=	6.16910E-01	;
    RnonCO2[	639	]=	6.16697E-01	;
    RnonCO2[	640	]=	6.16486E-01	;
    RnonCO2[	641	]=	6.16277E-01	;
    RnonCO2[	642	]=	6.16066E-01	;
    RnonCO2[	643	]=	6.15857E-01	;
    RnonCO2[	644	]=	6.15655E-01	;
    RnonCO2[	645	]=	6.15449E-01	;
    RnonCO2[	646	]=	6.15241E-01	;
    RnonCO2[	647	]=	6.15042E-01	;
    RnonCO2[	648	]=	6.14840E-01	;
    RnonCO2[	649	]=	6.14642E-01	;
    RnonCO2[	650	]=	6.14439E-01	;
    RnonCO2[	651	]=	6.14245E-01	;
    RnonCO2[	652	]=	6.14043E-01	;
    RnonCO2[	653	]=	6.13850E-01	;
    RnonCO2[	654	]=	6.13657E-01	;
    RnonCO2[	655	]=	6.13465E-01	;
    RnonCO2[	656	]=	6.13273E-01	;
    RnonCO2[	657	]=	6.13084E-01	;
    RnonCO2[	658	]=	6.12894E-01	;
    RnonCO2[	659	]=	6.12703E-01	;
    RnonCO2[	660	]=	6.12516E-01	;
    RnonCO2[	661	]=	6.12330E-01	;
    RnonCO2[	662	]=	6.12143E-01	;
    RnonCO2[	663	]=	6.11963E-01	;
    RnonCO2[	664	]=	6.11778E-01	;
    RnonCO2[	665	]=	6.11593E-01	;
    RnonCO2[	666	]=	6.11413E-01	;
    RnonCO2[	667	]=	6.11232E-01	;
    RnonCO2[	668	]=	6.11053E-01	;
    RnonCO2[	669	]=	6.10873E-01	;
    RnonCO2[	670	]=	6.10698E-01	;
    RnonCO2[	671	]=	6.10523E-01	;
    RnonCO2[	672	]=	6.10349E-01	;
    RnonCO2[	673	]=	6.10170E-01	;
    RnonCO2[	674	]=	6.09996E-01	;
    RnonCO2[	675	]=	6.09826E-01	;
    RnonCO2[	676	]=	6.09653E-01	;
    RnonCO2[	677	]=	6.09483E-01	;
    RnonCO2[	678	]=	6.09311E-01	;
    RnonCO2[	679	]=	6.09147E-01	;
    RnonCO2[	680	]=	6.08978E-01	;
    RnonCO2[	681	]=	6.08809E-01	;
    RnonCO2[	682	]=	6.08641E-01	;
    RnonCO2[	683	]=	6.08479E-01	;
    RnonCO2[	684	]=	6.08311E-01	;
    RnonCO2[	685	]=	6.08151E-01	;
    RnonCO2[	686	]=	6.07984E-01	;
    RnonCO2[	687	]=	6.07825E-01	;
    RnonCO2[	688	]=	6.07659E-01	;
    RnonCO2[	689	]=	6.07500E-01	;
    RnonCO2[	690	]=	6.07342E-01	;
    RnonCO2[	691	]=	6.07179E-01	;
    RnonCO2[	692	]=	6.07022E-01	;
    RnonCO2[	693	]=	6.06865E-01	;
    RnonCO2[	694	]=	6.06707E-01	;
    RnonCO2[	695	]=	6.06553E-01	;
    RnonCO2[	696	]=	6.06397E-01	;
    RnonCO2[	697	]=	6.06243E-01	;
    RnonCO2[	698	]=	6.06087E-01	;
    RnonCO2[	699	]=	6.05934E-01	;
    RnonCO2[	700	]=	6.05786E-01	;
    RnonCO2[	701	]=	6.05630E-01	;
    RnonCO2[	702	]=	6.05478E-01	;
    RnonCO2[	703	]=	6.05331E-01	;
    RnonCO2[	704	]=	6.05179E-01	;
    RnonCO2[	705	]=	6.05035E-01	;
    RnonCO2[	706	]=	6.04883E-01	;
    RnonCO2[	707	]=	6.04736E-01	;
    RnonCO2[	708	]=	6.04588E-01	;
    RnonCO2[	709	]=	6.04442E-01	;
    RnonCO2[	710	]=	6.04299E-01	;
    RnonCO2[	711	]=	6.04156E-01	;
    RnonCO2[	712	]=	6.04006E-01	;
    RnonCO2[	713	]=	6.03863E-01	;
    RnonCO2[	714	]=	6.03721E-01	;
    RnonCO2[	715	]=	6.03579E-01	;
    RnonCO2[	716	]=	6.03437E-01	;
    RnonCO2[	717	]=	6.03295E-01	;
    RnonCO2[	718	]=	6.03156E-01	;
    RnonCO2[	719	]=	6.03019E-01	;
    RnonCO2[	720	]=	6.02878E-01	;
    RnonCO2[	721	]=	6.02740E-01	;
    RnonCO2[	722	]=	6.02599E-01	;
    RnonCO2[	723	]=	6.02466E-01	;
    RnonCO2[	724	]=	6.02328E-01	;
    RnonCO2[	725	]=	6.02187E-01	;
    RnonCO2[	726	]=	6.02055E-01	;
    RnonCO2[	727	]=	6.01918E-01	;
    RnonCO2[	728	]=	6.01785E-01	;
    RnonCO2[	729	]=	6.01653E-01	;
    RnonCO2[	730	]=	6.01516E-01	;
    RnonCO2[	731	]=	6.01384E-01	;
    RnonCO2[	732	]=	6.01255E-01	;
    RnonCO2[	733	]=	6.01124E-01	;
    RnonCO2[	734	]=	6.00992E-01	;
    RnonCO2[	735	]=	6.00924E-01	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}
void setR_aerosol_ssp585(void)
{
    RnonCO2[	0	]=	0.0	;
    RnonCO2[	1	]=	-6.79053E-04	;
    RnonCO2[	2	]=	-6.75623E-04	;
    RnonCO2[	3	]=	-3.20299E-03	;
    RnonCO2[	4	]=	-2.14050E-03	;
    RnonCO2[	5	]=	-2.29077E-03	;
    RnonCO2[	6	]=	-1.26596E-04	;
    RnonCO2[	7	]=	5.51179E-04	;
    RnonCO2[	8	]=	3.51339E-04	;
    RnonCO2[	9	]=	-2.04197E-03	;
    RnonCO2[	10	]=	-1.08968E-03	;
    RnonCO2[	11	]=	-3.37204E-04	;
    RnonCO2[	12	]=	-1.55748E-03	;
    RnonCO2[	13	]=	-2.50422E-03	;
    RnonCO2[	14	]=	-1.20724E-03	;
    RnonCO2[	15	]=	-2.36389E-03	;
    RnonCO2[	16	]=	-2.19334E-03	;
    RnonCO2[	17	]=	-1.55190E-03	;
    RnonCO2[	18	]=	-1.36646E-03	;
    RnonCO2[	19	]=	-2.78889E-04	;
    RnonCO2[	20	]=	-1.75519E-03	;
    RnonCO2[	21	]=	-1.35779E-03	;
    RnonCO2[	22	]=	-2.21269E-03	;
    RnonCO2[	23	]=	-4.45176E-03	;
    RnonCO2[	24	]=	-3.23794E-03	;
    RnonCO2[	25	]=	-3.42205E-03	;
    RnonCO2[	26	]=	-2.24255E-03	;
    RnonCO2[	27	]=	-1.87945E-03	;
    RnonCO2[	28	]=	-1.81396E-03	;
    RnonCO2[	29	]=	-4.26007E-03	;
    RnonCO2[	30	]=	-3.31338E-03	;
    RnonCO2[	31	]=	-2.36036E-03	;
    RnonCO2[	32	]=	-3.88016E-03	;
    RnonCO2[	33	]=	-4.88692E-03	;
    RnonCO2[	34	]=	-4.39422E-03	;
    RnonCO2[	35	]=	-5.30164E-03	;
    RnonCO2[	36	]=	-4.88152E-03	;
    RnonCO2[	37	]=	-5.65280E-03	;
    RnonCO2[	38	]=	-4.46738E-03	;
    RnonCO2[	39	]=	-4.51684E-03	;
    RnonCO2[	40	]=	-5.67112E-03	;
    RnonCO2[	41	]=	-5.61787E-03	;
    RnonCO2[	42	]=	-6.47124E-03	;
    RnonCO2[	43	]=	-8.36506E-03	;
    RnonCO2[	44	]=	-7.31098E-03	;
    RnonCO2[	45	]=	-7.77701E-03	;
    RnonCO2[	46	]=	-7.04205E-03	;
    RnonCO2[	47	]=	-6.45646E-03	;
    RnonCO2[	48	]=	-6.81091E-03	;
    RnonCO2[	49	]=	-9.29863E-03	;
    RnonCO2[	50	]=	-8.76033E-03	;
    RnonCO2[	51	]=	-8.94449E-03	;
    RnonCO2[	52	]=	-9.81138E-03	;
    RnonCO2[	53	]=	-1.12878E-02	;
    RnonCO2[	54	]=	-1.02770E-02	;
    RnonCO2[	55	]=	-1.13284E-02	;
    RnonCO2[	56	]=	-1.13651E-02	;
    RnonCO2[	57	]=	-1.11215E-02	;
    RnonCO2[	58	]=	-1.08405E-02	;
    RnonCO2[	59	]=	-1.11615E-02	;
    RnonCO2[	60	]=	-1.24311E-02	;
    RnonCO2[	61	]=	-1.19956E-02	;
    RnonCO2[	62	]=	-1.33503E-02	;
    RnonCO2[	63	]=	-1.58898E-02	;
    RnonCO2[	64	]=	-1.48984E-02	;
    RnonCO2[	65	]=	-1.88469E-02	;
    RnonCO2[	66	]=	-1.67936E-02	;
    RnonCO2[	67	]=	-1.66228E-02	;
    RnonCO2[	68	]=	-1.72464E-02	;
    RnonCO2[	69	]=	-1.95640E-02	;
    RnonCO2[	70	]=	-1.90599E-02	;
    RnonCO2[	71	]=	-2.14245E-02	;
    RnonCO2[	72	]=	-2.20021E-02	;
    RnonCO2[	73	]=	-2.38356E-02	;
    RnonCO2[	74	]=	-2.37541E-02	;
    RnonCO2[	75	]=	-2.49537E-02	;
    RnonCO2[	76	]=	-2.65406E-02	;
    RnonCO2[	77	]=	-2.70217E-02	;
    RnonCO2[	78	]=	-2.65722E-02	;
    RnonCO2[	79	]=	-2.86094E-02	;
    RnonCO2[	80	]=	-3.21576E-02	;
    RnonCO2[	81	]=	-3.16139E-02	;
    RnonCO2[	82	]=	-3.47649E-02	;
    RnonCO2[	83	]=	-3.70876E-02	;
    RnonCO2[	84	]=	-3.75872E-02	;
    RnonCO2[	85	]=	-3.94755E-02	;
    RnonCO2[	86	]=	-3.82697E-02	;
    RnonCO2[	87	]=	-3.87036E-02	;
    RnonCO2[	88	]=	-4.05559E-02	;
    RnonCO2[	89	]=	-4.84745E-02	;
    RnonCO2[	90	]=	-4.79100E-02	;
    RnonCO2[	91	]=	-5.02153E-02	;
    RnonCO2[	92	]=	-5.21821E-02	;
    RnonCO2[	93	]=	-5.37006E-02	;
    RnonCO2[	94	]=	-5.64467E-02	;
    RnonCO2[	95	]=	-6.11331E-02	;
    RnonCO2[	96	]=	-6.34825E-02	;
    RnonCO2[	97	]=	-6.36904E-02	;
    RnonCO2[	98	]=	-6.63038E-02	;
    RnonCO2[	99	]=	-7.06027E-02	;
    RnonCO2[	100	]=	-7.57575E-02	;
    RnonCO2[	101	]=	-7.75654E-02	;
    RnonCO2[	102	]=	-8.39245E-02	;
    RnonCO2[	103	]=	-8.79345E-02	;
    RnonCO2[	104	]=	-9.16874E-02	;
    RnonCO2[	105	]=	-9.52346E-02	;
    RnonCO2[	106	]=	-9.90567E-02	;
    RnonCO2[	107	]=	-1.06468E-01	;
    RnonCO2[	108	]=	-1.14497E-01	;
    RnonCO2[	109	]=	-1.11949E-01	;
    RnonCO2[	110	]=	-1.17028E-01	;
    RnonCO2[	111	]=	-1.20288E-01	;
    RnonCO2[	112	]=	-1.24372E-01	;
    RnonCO2[	113	]=	-1.26000E-01	;
    RnonCO2[	114	]=	-1.34430E-01	;
    RnonCO2[	115	]=	-1.48013E-01	;
    RnonCO2[	116	]=	-1.53718E-01	;
    RnonCO2[	117	]=	-1.60739E-01	;
    RnonCO2[	118	]=	-1.68503E-01	;
    RnonCO2[	119	]=	-1.72169E-01	;
    RnonCO2[	120	]=	-1.74054E-01	;
    RnonCO2[	121	]=	-1.75752E-01	;
    RnonCO2[	122	]=	-1.83967E-01	;
    RnonCO2[	123	]=	-2.02375E-01	;
    RnonCO2[	124	]=	-2.02092E-01	;
    RnonCO2[	125	]=	-2.19215E-01	;
    RnonCO2[	126	]=	-2.27720E-01	;
    RnonCO2[	127	]=	-2.31761E-01	;
    RnonCO2[	128	]=	-2.30731E-01	;
    RnonCO2[	129	]=	-2.40237E-01	;
    RnonCO2[	130	]=	-2.52929E-01	;
    RnonCO2[	131	]=	-2.59897E-01	;
    RnonCO2[	132	]=	-2.72947E-01	;
    RnonCO2[	133	]=	-2.87151E-01	;
    RnonCO2[	134	]=	-3.11371E-01	;
    RnonCO2[	135	]=	-3.25784E-01	;
    RnonCO2[	136	]=	-3.37518E-01	;
    RnonCO2[	137	]=	-3.46564E-01	;
    RnonCO2[	138	]=	-3.72259E-01	;
    RnonCO2[	139	]=	-3.79310E-01	;
    RnonCO2[	140	]=	-4.01660E-01	;
    RnonCO2[	141	]=	-4.19182E-01	;
    RnonCO2[	142	]=	-4.58692E-01	;
    RnonCO2[	143	]=	-4.41648E-01	;
    RnonCO2[	144	]=	-4.61602E-01	;
    RnonCO2[	145	]=	-4.81295E-01	;
    RnonCO2[	146	]=	-4.83850E-01	;
    RnonCO2[	147	]=	-5.02355E-01	;
    RnonCO2[	148	]=	-5.29441E-01	;
    RnonCO2[	149	]=	-4.94045E-01	;
    RnonCO2[	150	]=	-4.93140E-01	;
    RnonCO2[	151	]=	-5.30098E-01	;
    RnonCO2[	152	]=	-5.50924E-01	;
    RnonCO2[	153	]=	-5.47527E-01	;
    RnonCO2[	154	]=	-4.80172E-01	;
    RnonCO2[	155	]=	-5.25337E-01	;
    RnonCO2[	156	]=	-4.56101E-01	;
    RnonCO2[	157	]=	-4.78983E-01	;
    RnonCO2[	158	]=	-5.48720E-01	;
    RnonCO2[	159	]=	-5.43419E-01	;
    RnonCO2[	160	]=	-5.49132E-01	;
    RnonCO2[	161	]=	-5.51547E-01	;
    RnonCO2[	162	]=	-5.83554E-01	;
    RnonCO2[	163	]=	-5.82308E-01	;
    RnonCO2[	164	]=	-6.14273E-01	;
    RnonCO2[	165	]=	-5.77395E-01	;
    RnonCO2[	166	]=	-5.17214E-01	;
    RnonCO2[	167	]=	-4.62116E-01	;
    RnonCO2[	168	]=	-4.83883E-01	;
    RnonCO2[	169	]=	-5.26686E-01	;
    RnonCO2[	170	]=	-5.60812E-01	;
    RnonCO2[	171	]=	-5.97655E-01	;
    RnonCO2[	172	]=	-6.35479E-01	;
    RnonCO2[	173	]=	-5.95841E-01	;
    RnonCO2[	174	]=	-6.30765E-01	;
    RnonCO2[	175	]=	-6.78819E-01	;
    RnonCO2[	176	]=	-6.99934E-01	;
    RnonCO2[	177	]=	-7.13182E-01	;
    RnonCO2[	178	]=	-7.22195E-01	;
    RnonCO2[	179	]=	-7.11705E-01	;
    RnonCO2[	180	]=	-6.42255E-01	;
    RnonCO2[	181	]=	-6.35800E-01	;
    RnonCO2[	182	]=	-7.00059E-01	;
    RnonCO2[	183	]=	-7.26703E-01	;
    RnonCO2[	184	]=	-7.06762E-01	;
    RnonCO2[	185	]=	-7.70925E-01	;
    RnonCO2[	186	]=	-7.95266E-01	;
    RnonCO2[	187	]=	-8.04648E-01	;
    RnonCO2[	188	]=	-8.18439E-01	;
    RnonCO2[	189	]=	-8.22984E-01	;
    RnonCO2[	190	]=	-8.82269E-01	;
    RnonCO2[	191	]=	-9.32650E-01	;
    RnonCO2[	192	]=	-9.66402E-01	;
    RnonCO2[	193	]=	-9.72670E-01	;
    RnonCO2[	194	]=	-1.00848E+00	;
    RnonCO2[	195	]=	-1.03801E+00	;
    RnonCO2[	196	]=	-1.13465E+00	;
    RnonCO2[	197	]=	-1.15071E+00	;
    RnonCO2[	198	]=	-1.18117E+00	;
    RnonCO2[	199	]=	-1.21008E+00	;
    RnonCO2[	200	]=	-1.23266E+00	;
    RnonCO2[	201	]=	-1.25347E+00	;
    RnonCO2[	202	]=	-1.24926E+00	;
    RnonCO2[	203	]=	-1.28315E+00	;
    RnonCO2[	204	]=	-1.30844E+00	;
    RnonCO2[	205	]=	-1.35840E+00	;
    RnonCO2[	206	]=	-1.36191E+00	;
    RnonCO2[	207	]=	-1.39174E+00	;
    RnonCO2[	208	]=	-1.43047E+00	;
    RnonCO2[	209	]=	-1.41626E+00	;
    RnonCO2[	210	]=	-1.39766E+00	;
    RnonCO2[	211	]=	-1.44245E+00	;
    RnonCO2[	212	]=	-1.45183E+00	;
    RnonCO2[	213	]=	-1.45602E+00	;
    RnonCO2[	214	]=	-1.47234E+00	;
    RnonCO2[	215	]=	-1.46829E+00	;
    RnonCO2[	216	]=	-1.43775E+00	;
    RnonCO2[	217	]=	-1.42569E+00	;
    RnonCO2[	218	]=	-1.40579E+00	;
    RnonCO2[	219	]=	-1.41822E+00	;
    RnonCO2[	220	]=	-1.42111E+00	;
    RnonCO2[	221	]=	-1.42234E+00	;
    RnonCO2[	222	]=	-1.44260E+00	;
    RnonCO2[	223	]=	-1.44995E+00	;
    RnonCO2[	224	]=	-1.45008E+00	;
    RnonCO2[	225	]=	-1.44713E+00	;
    RnonCO2[	226	]=	-1.45028E+00	;
    RnonCO2[	227	]=	-1.40609E+00	;
    RnonCO2[	228	]=	-1.39300E+00	;
    RnonCO2[	229	]=	-1.38070E+00	;
    RnonCO2[	230	]=	-1.35563E+00	;
    RnonCO2[	231	]=	-1.34007E+00	;
    RnonCO2[	232	]=	-1.36196E+00	;
    RnonCO2[	233	]=	-1.33516E+00	;
    RnonCO2[	234	]=	-1.28051E+00	;
    RnonCO2[	235	]=	-1.28077E+00	;
    RnonCO2[	236	]=	-1.28593E+00	;
    RnonCO2[	237	]=	-1.28767E+00	;
    RnonCO2[	238	]=	-1.31655E+00	;
    RnonCO2[	239	]=	-1.35496E+00	;
    RnonCO2[	240	]=	-1.38748E+00	;
    RnonCO2[	241	]=	-1.39872E+00	;
    RnonCO2[	242	]=	-1.38807E+00	;
    RnonCO2[	243	]=	-1.36751E+00	;
    RnonCO2[	244	]=	-1.32922E+00	;
    RnonCO2[	245	]=	-1.32198E+00	;
    RnonCO2[	246	]=	-1.33026E+00	;
    RnonCO2[	247	]=	-1.32012E+00	;
    RnonCO2[	248	]=	-1.30895E+00	;
    RnonCO2[	249	]=	-1.30858E+00	;
    RnonCO2[	250	]=	-1.20171E+00	;
    RnonCO2[	251	]=	-1.16860E+00	;
    RnonCO2[	252	]=	-1.13476E+00	;
    RnonCO2[	253	]=	-1.10017E+00	;
    RnonCO2[	254	]=	-1.06477E+00	;
    RnonCO2[	255	]=	-1.02852E+00	;
    RnonCO2[	256	]=	-1.02126E+00	;
    RnonCO2[	257	]=	-1.01395E+00	;
    RnonCO2[	258	]=	-1.00661E+00	;
    RnonCO2[	259	]=	-9.99226E-01	;
    RnonCO2[	260	]=	-9.91799E-01	;
    RnonCO2[	261	]=	-9.84330E-01	;
    RnonCO2[	262	]=	-9.76819E-01	;
    RnonCO2[	263	]=	-9.69265E-01	;
    RnonCO2[	264	]=	-9.61666E-01	;
    RnonCO2[	265	]=	-9.54024E-01	;
    RnonCO2[	266	]=	-9.54281E-01	;
    RnonCO2[	267	]=	-9.54537E-01	;
    RnonCO2[	268	]=	-9.54794E-01	;
    RnonCO2[	269	]=	-9.55050E-01	;
    RnonCO2[	270	]=	-9.55307E-01	;
    RnonCO2[	271	]=	-9.55563E-01	;
    RnonCO2[	272	]=	-9.55820E-01	;
    RnonCO2[	273	]=	-9.56076E-01	;
    RnonCO2[	274	]=	-9.56333E-01	;
    RnonCO2[	275	]=	-9.56589E-01	;
    RnonCO2[	276	]=	-9.46630E-01	;
    RnonCO2[	277	]=	-9.36596E-01	;
    RnonCO2[	278	]=	-9.26486E-01	;
    RnonCO2[	279	]=	-9.16299E-01	;
    RnonCO2[	280	]=	-9.06034E-01	;
    RnonCO2[	281	]=	-8.95689E-01	;
    RnonCO2[	282	]=	-8.85264E-01	;
    RnonCO2[	283	]=	-8.74755E-01	;
    RnonCO2[	284	]=	-8.64163E-01	;
    RnonCO2[	285	]=	-8.53485E-01	;
    RnonCO2[	286	]=	-8.57559E-01	;
    RnonCO2[	287	]=	-8.61625E-01	;
    RnonCO2[	288	]=	-8.65682E-01	;
    RnonCO2[	289	]=	-8.69732E-01	;
    RnonCO2[	290	]=	-8.73773E-01	;
    RnonCO2[	291	]=	-8.77805E-01	;
    RnonCO2[	292	]=	-8.81830E-01	;
    RnonCO2[	293	]=	-8.85847E-01	;
    RnonCO2[	294	]=	-8.89855E-01	;
    RnonCO2[	295	]=	-8.93856E-01	;
    RnonCO2[	296	]=	-8.91641E-01	;
    RnonCO2[	297	]=	-8.89422E-01	;
    RnonCO2[	298	]=	-8.87198E-01	;
    RnonCO2[	299	]=	-8.84970E-01	;
    RnonCO2[	300	]=	-8.82739E-01	;
    RnonCO2[	301	]=	-8.80503E-01	;
    RnonCO2[	302	]=	-8.78262E-01	;
    RnonCO2[	303	]=	-8.76018E-01	;
    RnonCO2[	304	]=	-8.73769E-01	;
    RnonCO2[	305	]=	-8.71516E-01	;
    RnonCO2[	306	]=	-8.63378E-01	;
    RnonCO2[	307	]=	-8.55193E-01	;
    RnonCO2[	308	]=	-8.46960E-01	;
    RnonCO2[	309	]=	-8.38680E-01	;
    RnonCO2[	310	]=	-8.30350E-01	;
    RnonCO2[	311	]=	-8.21971E-01	;
    RnonCO2[	312	]=	-8.13541E-01	;
    RnonCO2[	313	]=	-8.05061E-01	;
    RnonCO2[	314	]=	-7.96529E-01	;
    RnonCO2[	315	]=	-7.87945E-01	;
    RnonCO2[	316	]=	-7.75718E-01	;
    RnonCO2[	317	]=	-7.63385E-01	;
    RnonCO2[	318	]=	-7.50943E-01	;
    RnonCO2[	319	]=	-7.38390E-01	;
    RnonCO2[	320	]=	-7.25723E-01	;
    RnonCO2[	321	]=	-7.12942E-01	;
    RnonCO2[	322	]=	-7.00042E-01	;
    RnonCO2[	323	]=	-6.87021E-01	;
    RnonCO2[	324	]=	-6.73877E-01	;
    RnonCO2[	325	]=	-6.60607E-01	;
    RnonCO2[	326	]=	-6.45434E-01	;
    RnonCO2[	327	]=	-6.30103E-01	;
    RnonCO2[	328	]=	-6.14611E-01	;
    RnonCO2[	329	]=	-5.98952E-01	;
    RnonCO2[	330	]=	-5.83124E-01	;
    RnonCO2[	331	]=	-5.67120E-01	;
    RnonCO2[	332	]=	-5.50938E-01	;
    RnonCO2[	333	]=	-5.34571E-01	;
    RnonCO2[	334	]=	-5.18015E-01	;
    RnonCO2[	335	]=	-5.01265E-01	;
    RnonCO2[	336	]=	-4.98597E-01	;
    RnonCO2[	337	]=	-4.95925E-01	;
    RnonCO2[	338	]=	-4.93248E-01	;
    RnonCO2[	339	]=	-4.90567E-01	;
    RnonCO2[	340	]=	-4.87881E-01	;
    RnonCO2[	341	]=	-4.85191E-01	;
    RnonCO2[	342	]=	-4.82496E-01	;
    RnonCO2[	343	]=	-4.79797E-01	;
    RnonCO2[	344	]=	-4.77094E-01	;
    RnonCO2[	345	]=	-4.74386E-01	;
    RnonCO2[	346	]=	-4.71673E-01	;
    RnonCO2[	347	]=	-4.68956E-01	;
    RnonCO2[	348	]=	-4.66235E-01	;
    RnonCO2[	349	]=	-4.63509E-01	;
    RnonCO2[	350	]=	-4.60778E-01	;
    RnonCO2[	351	]=	-4.58043E-01	;
    RnonCO2[	352	]=	-4.55303E-01	;
    RnonCO2[	353	]=	-4.52558E-01	;
    RnonCO2[	354	]=	-4.49808E-01	;
    RnonCO2[	355	]=	-4.47054E-01	;
    RnonCO2[	356	]=	-4.44295E-01	;
    RnonCO2[	357	]=	-4.41531E-01	;
    RnonCO2[	358	]=	-4.38763E-01	;
    RnonCO2[	359	]=	-4.35989E-01	;
    RnonCO2[	360	]=	-4.33211E-01	;
    RnonCO2[	361	]=	-4.30428E-01	;
    RnonCO2[	362	]=	-4.27640E-01	;
    RnonCO2[	363	]=	-4.24847E-01	;
    RnonCO2[	364	]=	-4.22049E-01	;
    RnonCO2[	365	]=	-4.19246E-01	;
    RnonCO2[	366	]=	-4.16439E-01	;
    RnonCO2[	367	]=	-4.13627E-01	;
    RnonCO2[	368	]=	-4.10810E-01	;
    RnonCO2[	369	]=	-4.07987E-01	;
    RnonCO2[	370	]=	-4.05160E-01	;
    RnonCO2[	371	]=	-4.02328E-01	;
    RnonCO2[	372	]=	-3.99490E-01	;
    RnonCO2[	373	]=	-3.96648E-01	;
    RnonCO2[	374	]=	-3.93800E-01	;
    RnonCO2[	375	]=	-3.90947E-01	;
    RnonCO2[	376	]=	-3.88089E-01	;
    RnonCO2[	377	]=	-3.85226E-01	;
    RnonCO2[	378	]=	-3.82358E-01	;
    RnonCO2[	379	]=	-3.79484E-01	;
    RnonCO2[	380	]=	-3.76605E-01	;
    RnonCO2[	381	]=	-3.73721E-01	;
    RnonCO2[	382	]=	-3.70832E-01	;
    RnonCO2[	383	]=	-3.67937E-01	;
    RnonCO2[	384	]=	-3.65037E-01	;
    RnonCO2[	385	]=	-3.62131E-01	;
    RnonCO2[	386	]=	-3.59220E-01	;
    RnonCO2[	387	]=	-3.56304E-01	;
    RnonCO2[	388	]=	-3.53382E-01	;
    RnonCO2[	389	]=	-3.50454E-01	;
    RnonCO2[	390	]=	-3.47521E-01	;
    RnonCO2[	391	]=	-3.44582E-01	;
    RnonCO2[	392	]=	-3.41638E-01	;
    RnonCO2[	393	]=	-3.38689E-01	;
    RnonCO2[	394	]=	-3.35733E-01	;
    RnonCO2[	395	]=	-3.32772E-01	;
    RnonCO2[	396	]=	-3.29806E-01	;
    RnonCO2[	397	]=	-3.26834E-01	;
    RnonCO2[	398	]=	-3.23856E-01	;
    RnonCO2[	399	]=	-3.20873E-01	;
    RnonCO2[	400	]=	-3.17884E-01	;
    RnonCO2[	401	]=	-3.14889E-01	;
    RnonCO2[	402	]=	-3.11888E-01	;
    RnonCO2[	403	]=	-3.08881E-01	;
    RnonCO2[	404	]=	-3.05869E-01	;
    RnonCO2[	405	]=	-3.02850E-01	;
    RnonCO2[	406	]=	-2.99826E-01	;
    RnonCO2[	407	]=	-2.96796E-01	;
    RnonCO2[	408	]=	-2.93759E-01	;
    RnonCO2[	409	]=	-2.90717E-01	;
    RnonCO2[	410	]=	-2.87669E-01	;
    RnonCO2[	411	]=	-2.84614E-01	;
    RnonCO2[	412	]=	-2.81554E-01	;
    RnonCO2[	413	]=	-2.78487E-01	;
    RnonCO2[	414	]=	-2.75414E-01	;
    RnonCO2[	415	]=	-2.72335E-01	;
    RnonCO2[	416	]=	-2.69250E-01	;
    RnonCO2[	417	]=	-2.66158E-01	;
    RnonCO2[	418	]=	-2.63060E-01	;
    RnonCO2[	419	]=	-2.59956E-01	;
    RnonCO2[	420	]=	-2.56845E-01	;
    RnonCO2[	421	]=	-2.53728E-01	;
    RnonCO2[	422	]=	-2.50605E-01	;
    RnonCO2[	423	]=	-2.47475E-01	;
    RnonCO2[	424	]=	-2.44338E-01	;
    RnonCO2[	425	]=	-2.41195E-01	;
    RnonCO2[	426	]=	-2.38046E-01	;
    RnonCO2[	427	]=	-2.34890E-01	;
    RnonCO2[	428	]=	-2.31728E-01	;
    RnonCO2[	429	]=	-2.28559E-01	;
    RnonCO2[	430	]=	-2.25383E-01	;
    RnonCO2[	431	]=	-2.22201E-01	;
    RnonCO2[	432	]=	-2.19012E-01	;
    RnonCO2[	433	]=	-2.15816E-01	;
    RnonCO2[	434	]=	-2.12613E-01	;
    RnonCO2[	435	]=	-2.09404E-01	;
    RnonCO2[	436	]=	-2.06187E-01	;
    RnonCO2[	437	]=	-2.02963E-01	;
    RnonCO2[	438	]=	-1.99733E-01	;
    RnonCO2[	439	]=	-1.96495E-01	;
    RnonCO2[	440	]=	-1.93251E-01	;
    RnonCO2[	441	]=	-1.89999E-01	;
    RnonCO2[	442	]=	-1.86740E-01	;
    RnonCO2[	443	]=	-1.83474E-01	;
    RnonCO2[	444	]=	-1.80201E-01	;
    RnonCO2[	445	]=	-1.76921E-01	;
    RnonCO2[	446	]=	-1.73634E-01	;
    RnonCO2[	447	]=	-1.70339E-01	;
    RnonCO2[	448	]=	-1.67037E-01	;
    RnonCO2[	449	]=	-1.63728E-01	;
    RnonCO2[	450	]=	-1.60412E-01	;
    RnonCO2[	451	]=	-1.57088E-01	;
    RnonCO2[	452	]=	-1.53756E-01	;
    RnonCO2[	453	]=	-1.50417E-01	;
    RnonCO2[	454	]=	-1.47070E-01	;
    RnonCO2[	455	]=	-1.43716E-01	;
    RnonCO2[	456	]=	-1.40354E-01	;
    RnonCO2[	457	]=	-1.36985E-01	;
    RnonCO2[	458	]=	-1.33608E-01	;
    RnonCO2[	459	]=	-1.30223E-01	;
    RnonCO2[	460	]=	-1.26830E-01	;
    RnonCO2[	461	]=	-1.23429E-01	;
    RnonCO2[	462	]=	-1.20021E-01	;
    RnonCO2[	463	]=	-1.16604E-01	;
    RnonCO2[	464	]=	-1.13180E-01	;
    RnonCO2[	465	]=	-1.09747E-01	;
    RnonCO2[	466	]=	-1.06306E-01	;
    RnonCO2[	467	]=	-1.02857E-01	;
    RnonCO2[	468	]=	-9.93999E-02	;
    RnonCO2[	469	]=	-9.59344E-02	;
    RnonCO2[	470	]=	-9.24607E-02	;
    RnonCO2[	471	]=	-8.89787E-02	;
    RnonCO2[	472	]=	-8.54883E-02	;
    RnonCO2[	473	]=	-8.19895E-02	;
    RnonCO2[	474	]=	-7.84823E-02	;
    RnonCO2[	475	]=	-7.49666E-02	;
    RnonCO2[	476	]=	-7.14427E-02	;
    RnonCO2[	477	]=	-6.79101E-02	;
    RnonCO2[	478	]=	-6.43690E-02	;
    RnonCO2[	479	]=	-6.08191E-02	;
    RnonCO2[	480	]=	-5.72605E-02	;
    RnonCO2[	481	]=	-5.36932E-02	;
    RnonCO2[	482	]=	-5.01169E-02	;
    RnonCO2[	483	]=	-4.65318E-02	;
    RnonCO2[	484	]=	-4.29377E-02	;
    RnonCO2[	485	]=	-3.93347E-02	;
    RnonCO2[	486	]=	-3.93347E-02	;
    RnonCO2[	487	]=	-3.93347E-02	;
    RnonCO2[	488	]=	-3.93347E-02	;
    RnonCO2[	489	]=	-3.93347E-02	;
    RnonCO2[	490	]=	-3.93347E-02	;
    RnonCO2[	491	]=	-3.93347E-02	;
    RnonCO2[	492	]=	-3.93347E-02	;
    RnonCO2[	493	]=	-3.93347E-02	;
    RnonCO2[	494	]=	-3.93347E-02	;
    RnonCO2[	495	]=	-3.93347E-02	;
    RnonCO2[	496	]=	-3.93347E-02	;
    RnonCO2[	497	]=	-3.93347E-02	;
    RnonCO2[	498	]=	-3.93347E-02	;
    RnonCO2[	499	]=	-3.93347E-02	;
    RnonCO2[	500	]=	-3.93347E-02	;
    RnonCO2[	501	]=	-3.93347E-02	;
    RnonCO2[	502	]=	-3.93347E-02	;
    RnonCO2[	503	]=	-3.93347E-02	;
    RnonCO2[	504	]=	-3.93347E-02	;
    RnonCO2[	505	]=	-3.93347E-02	;
    RnonCO2[	506	]=	-3.93347E-02	;
    RnonCO2[	507	]=	-3.93347E-02	;
    RnonCO2[	508	]=	-3.93347E-02	;
    RnonCO2[	509	]=	-3.93347E-02	;
    RnonCO2[	510	]=	-3.93347E-02	;
    RnonCO2[	511	]=	-3.93347E-02	;
    RnonCO2[	512	]=	-3.93347E-02	;
    RnonCO2[	513	]=	-3.93347E-02	;
    RnonCO2[	514	]=	-3.93347E-02	;
    RnonCO2[	515	]=	-3.93347E-02	;
    RnonCO2[	516	]=	-3.93347E-02	;
    RnonCO2[	517	]=	-3.93347E-02	;
    RnonCO2[	518	]=	-3.93347E-02	;
    RnonCO2[	519	]=	-3.93347E-02	;
    RnonCO2[	520	]=	-3.93347E-02	;
    RnonCO2[	521	]=	-3.93347E-02	;
    RnonCO2[	522	]=	-3.93347E-02	;
    RnonCO2[	523	]=	-3.93347E-02	;
    RnonCO2[	524	]=	-3.93347E-02	;
    RnonCO2[	525	]=	-3.93347E-02	;
    RnonCO2[	526	]=	-3.93347E-02	;
    RnonCO2[	527	]=	-3.93347E-02	;
    RnonCO2[	528	]=	-3.93347E-02	;
    RnonCO2[	529	]=	-3.93347E-02	;
    RnonCO2[	530	]=	-3.93347E-02	;
    RnonCO2[	531	]=	-3.93347E-02	;
    RnonCO2[	532	]=	-3.93347E-02	;
    RnonCO2[	533	]=	-3.93347E-02	;
    RnonCO2[	534	]=	-3.93347E-02	;
    RnonCO2[	535	]=	-3.93347E-02	;
    RnonCO2[	536	]=	-3.93347E-02	;
    RnonCO2[	537	]=	-3.93347E-02	;
    RnonCO2[	538	]=	-3.93347E-02	;
    RnonCO2[	539	]=	-3.93347E-02	;
    RnonCO2[	540	]=	-3.93347E-02	;
    RnonCO2[	541	]=	-3.93347E-02	;
    RnonCO2[	542	]=	-3.93347E-02	;
    RnonCO2[	543	]=	-3.93347E-02	;
    RnonCO2[	544	]=	-3.93347E-02	;
    RnonCO2[	545	]=	-3.93347E-02	;
    RnonCO2[	546	]=	-3.93347E-02	;
    RnonCO2[	547	]=	-3.93347E-02	;
    RnonCO2[	548	]=	-3.93347E-02	;
    RnonCO2[	549	]=	-3.93347E-02	;
    RnonCO2[	550	]=	-3.93347E-02	;
    RnonCO2[	551	]=	-3.93347E-02	;
    RnonCO2[	552	]=	-3.93347E-02	;
    RnonCO2[	553	]=	-3.93347E-02	;
    RnonCO2[	554	]=	-3.93347E-02	;
    RnonCO2[	555	]=	-3.93347E-02	;
    RnonCO2[	556	]=	-3.93347E-02	;
    RnonCO2[	557	]=	-3.93347E-02	;
    RnonCO2[	558	]=	-3.93347E-02	;
    RnonCO2[	559	]=	-3.93347E-02	;
    RnonCO2[	560	]=	-3.93347E-02	;
    RnonCO2[	561	]=	-3.93347E-02	;
    RnonCO2[	562	]=	-3.93347E-02	;
    RnonCO2[	563	]=	-3.93347E-02	;
    RnonCO2[	564	]=	-3.93347E-02	;
    RnonCO2[	565	]=	-3.93347E-02	;
    RnonCO2[	566	]=	-3.93347E-02	;
    RnonCO2[	567	]=	-3.93347E-02	;
    RnonCO2[	568	]=	-3.93347E-02	;
    RnonCO2[	569	]=	-3.93347E-02	;
    RnonCO2[	570	]=	-3.93347E-02	;
    RnonCO2[	571	]=	-3.93347E-02	;
    RnonCO2[	572	]=	-3.93347E-02	;
    RnonCO2[	573	]=	-3.93347E-02	;
    RnonCO2[	574	]=	-3.93347E-02	;
    RnonCO2[	575	]=	-3.93347E-02	;
    RnonCO2[	576	]=	-3.93347E-02	;
    RnonCO2[	577	]=	-3.93347E-02	;
    RnonCO2[	578	]=	-3.93347E-02	;
    RnonCO2[	579	]=	-3.93347E-02	;
    RnonCO2[	580	]=	-3.93347E-02	;
    RnonCO2[	581	]=	-3.93347E-02	;
    RnonCO2[	582	]=	-3.93347E-02	;
    RnonCO2[	583	]=	-3.93347E-02	;
    RnonCO2[	584	]=	-3.93347E-02	;
    RnonCO2[	585	]=	-3.93347E-02	;
    RnonCO2[	586	]=	-3.93347E-02	;
    RnonCO2[	587	]=	-3.93347E-02	;
    RnonCO2[	588	]=	-3.93347E-02	;
    RnonCO2[	589	]=	-3.93347E-02	;
    RnonCO2[	590	]=	-3.93347E-02	;
    RnonCO2[	591	]=	-3.93347E-02	;
    RnonCO2[	592	]=	-3.93347E-02	;
    RnonCO2[	593	]=	-3.93347E-02	;
    RnonCO2[	594	]=	-3.93347E-02	;
    RnonCO2[	595	]=	-3.93347E-02	;
    RnonCO2[	596	]=	-3.93347E-02	;
    RnonCO2[	597	]=	-3.93347E-02	;
    RnonCO2[	598	]=	-3.93347E-02	;
    RnonCO2[	599	]=	-3.93347E-02	;
    RnonCO2[	600	]=	-3.93347E-02	;
    RnonCO2[	601	]=	-3.93347E-02	;
    RnonCO2[	602	]=	-3.93347E-02	;
    RnonCO2[	603	]=	-3.93347E-02	;
    RnonCO2[	604	]=	-3.93347E-02	;
    RnonCO2[	605	]=	-3.93347E-02	;
    RnonCO2[	606	]=	-3.93347E-02	;
    RnonCO2[	607	]=	-3.93347E-02	;
    RnonCO2[	608	]=	-3.93347E-02	;
    RnonCO2[	609	]=	-3.93347E-02	;
    RnonCO2[	610	]=	-3.93347E-02	;
    RnonCO2[	611	]=	-3.93347E-02	;
    RnonCO2[	612	]=	-3.93347E-02	;
    RnonCO2[	613	]=	-3.93347E-02	;
    RnonCO2[	614	]=	-3.93347E-02	;
    RnonCO2[	615	]=	-3.93347E-02	;
    RnonCO2[	616	]=	-3.93347E-02	;
    RnonCO2[	617	]=	-3.93347E-02	;
    RnonCO2[	618	]=	-3.93347E-02	;
    RnonCO2[	619	]=	-3.93347E-02	;
    RnonCO2[	620	]=	-3.93347E-02	;
    RnonCO2[	621	]=	-3.93347E-02	;
    RnonCO2[	622	]=	-3.93347E-02	;
    RnonCO2[	623	]=	-3.93347E-02	;
    RnonCO2[	624	]=	-3.93347E-02	;
    RnonCO2[	625	]=	-3.93347E-02	;
    RnonCO2[	626	]=	-3.93347E-02	;
    RnonCO2[	627	]=	-3.93347E-02	;
    RnonCO2[	628	]=	-3.93347E-02	;
    RnonCO2[	629	]=	-3.93347E-02	;
    RnonCO2[	630	]=	-3.93347E-02	;
    RnonCO2[	631	]=	-3.93347E-02	;
    RnonCO2[	632	]=	-3.93347E-02	;
    RnonCO2[	633	]=	-3.93347E-02	;
    RnonCO2[	634	]=	-3.93347E-02	;
    RnonCO2[	635	]=	-3.93347E-02	;
    RnonCO2[	636	]=	-3.93347E-02	;
    RnonCO2[	637	]=	-3.93347E-02	;
    RnonCO2[	638	]=	-3.93347E-02	;
    RnonCO2[	639	]=	-3.93347E-02	;
    RnonCO2[	640	]=	-3.93347E-02	;
    RnonCO2[	641	]=	-3.93347E-02	;
    RnonCO2[	642	]=	-3.93347E-02	;
    RnonCO2[	643	]=	-3.93347E-02	;
    RnonCO2[	644	]=	-3.93347E-02	;
    RnonCO2[	645	]=	-3.93347E-02	;
    RnonCO2[	646	]=	-3.93347E-02	;
    RnonCO2[	647	]=	-3.93347E-02	;
    RnonCO2[	648	]=	-3.93347E-02	;
    RnonCO2[	649	]=	-3.93347E-02	;
    RnonCO2[	650	]=	-3.93347E-02	;
    RnonCO2[	651	]=	-3.93347E-02	;
    RnonCO2[	652	]=	-3.93347E-02	;
    RnonCO2[	653	]=	-3.93347E-02	;
    RnonCO2[	654	]=	-3.93347E-02	;
    RnonCO2[	655	]=	-3.93347E-02	;
    RnonCO2[	656	]=	-3.93347E-02	;
    RnonCO2[	657	]=	-3.93347E-02	;
    RnonCO2[	658	]=	-3.93347E-02	;
    RnonCO2[	659	]=	-3.93347E-02	;
    RnonCO2[	660	]=	-3.93347E-02	;
    RnonCO2[	661	]=	-3.93347E-02	;
    RnonCO2[	662	]=	-3.93347E-02	;
    RnonCO2[	663	]=	-3.93347E-02	;
    RnonCO2[	664	]=	-3.93347E-02	;
    RnonCO2[	665	]=	-3.93347E-02	;
    RnonCO2[	666	]=	-3.93347E-02	;
    RnonCO2[	667	]=	-3.93347E-02	;
    RnonCO2[	668	]=	-3.93347E-02	;
    RnonCO2[	669	]=	-3.93347E-02	;
    RnonCO2[	670	]=	-3.93347E-02	;
    RnonCO2[	671	]=	-3.93347E-02	;
    RnonCO2[	672	]=	-3.93347E-02	;
    RnonCO2[	673	]=	-3.93347E-02	;
    RnonCO2[	674	]=	-3.93347E-02	;
    RnonCO2[	675	]=	-3.93347E-02	;
    RnonCO2[	676	]=	-3.93347E-02	;
    RnonCO2[	677	]=	-3.93347E-02	;
    RnonCO2[	678	]=	-3.93347E-02	;
    RnonCO2[	679	]=	-3.93347E-02	;
    RnonCO2[	680	]=	-3.93347E-02	;
    RnonCO2[	681	]=	-3.93347E-02	;
    RnonCO2[	682	]=	-3.93347E-02	;
    RnonCO2[	683	]=	-3.93347E-02	;
    RnonCO2[	684	]=	-3.93347E-02	;
    RnonCO2[	685	]=	-3.93347E-02	;
    RnonCO2[	686	]=	-3.93347E-02	;
    RnonCO2[	687	]=	-3.93347E-02	;
    RnonCO2[	688	]=	-3.93347E-02	;
    RnonCO2[	689	]=	-3.93347E-02	;
    RnonCO2[	690	]=	-3.93347E-02	;
    RnonCO2[	691	]=	-3.93347E-02	;
    RnonCO2[	692	]=	-3.93347E-02	;
    RnonCO2[	693	]=	-3.93347E-02	;
    RnonCO2[	694	]=	-3.93347E-02	;
    RnonCO2[	695	]=	-3.93347E-02	;
    RnonCO2[	696	]=	-3.93347E-02	;
    RnonCO2[	697	]=	-3.93347E-02	;
    RnonCO2[	698	]=	-3.93347E-02	;
    RnonCO2[	699	]=	-3.93347E-02	;
    RnonCO2[	700	]=	-3.93347E-02	;
    RnonCO2[	701	]=	-3.93347E-02	;
    RnonCO2[	702	]=	-3.93347E-02	;
    RnonCO2[	703	]=	-3.93347E-02	;
    RnonCO2[	704	]=	-3.93347E-02	;
    RnonCO2[	705	]=	-3.93347E-02	;
    RnonCO2[	706	]=	-3.93347E-02	;
    RnonCO2[	707	]=	-3.93347E-02	;
    RnonCO2[	708	]=	-3.93347E-02	;
    RnonCO2[	709	]=	-3.93347E-02	;
    RnonCO2[	710	]=	-3.93347E-02	;
    RnonCO2[	711	]=	-3.93347E-02	;
    RnonCO2[	712	]=	-3.93347E-02	;
    RnonCO2[	713	]=	-3.93347E-02	;
    RnonCO2[	714	]=	-3.93347E-02	;
    RnonCO2[	715	]=	-3.93347E-02	;
    RnonCO2[	716	]=	-3.93347E-02	;
    RnonCO2[	717	]=	-3.93347E-02	;
    RnonCO2[	718	]=	-3.93347E-02	;
    RnonCO2[	719	]=	-3.93347E-02	;
    RnonCO2[	720	]=	-3.93347E-02	;
    RnonCO2[	721	]=	-3.93347E-02	;
    RnonCO2[	722	]=	-3.93347E-02	;
    RnonCO2[	723	]=	-3.93347E-02	;
    RnonCO2[	724	]=	-3.93347E-02	;
    RnonCO2[	725	]=	-3.93347E-02	;
    RnonCO2[	726	]=	-3.93347E-02	;
    RnonCO2[	727	]=	-3.93347E-02	;
    RnonCO2[	728	]=	-3.93347E-02	;
    RnonCO2[	729	]=	-3.93347E-02	;
    RnonCO2[	730	]=	-3.93347E-02	;
    RnonCO2[	731	]=	-3.93347E-02	;
    RnonCO2[	732	]=	-3.93347E-02	;
    RnonCO2[	733	]=	-3.93347E-02	;
    RnonCO2[	734	]=	-3.93347E-02	;
    RnonCO2[	735	]=	-3.93347E-02	;
    
    for(int i = 736; i<tmax; i++)
    {
        
        RnonCO2[i] = RnonCO2[i-1];
        
    }
    
}

void setCO2_ssp119(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9491	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7510	/coeff;
    CO2[	253	]=	408.5870	/coeff;
    CO2[	254	]=	411.4050	/coeff;
    CO2[	255	]=	414.2140	/coeff;
    CO2[	256	]=	417.0140	/coeff;
    CO2[	257	]=	419.6990	/coeff;
    CO2[	258	]=	422.1700	/coeff;
    CO2[	259	]=	424.4430	/coeff;
    CO2[	260	]=	426.5250	/coeff;
    CO2[	261	]=	428.4260	/coeff;
    CO2[	262	]=	430.1510	/coeff;
    CO2[	263	]=	431.7060	/coeff;
    CO2[	264	]=	433.0960	/coeff;
    CO2[	265	]=	434.3240	/coeff;
    CO2[	266	]=	435.3940	/coeff;
    CO2[	267	]=	436.3370	/coeff;
    CO2[	268	]=	437.1790	/coeff;
    CO2[	269	]=	437.9170	/coeff;
    CO2[	270	]=	438.5530	/coeff;
    CO2[	271	]=	439.0840	/coeff;
    CO2[	272	]=	439.5130	/coeff;
    CO2[	273	]=	439.8370	/coeff;
    CO2[	274	]=	440.0590	/coeff;
    CO2[	275	]=	440.1790	/coeff;
    CO2[	276	]=	440.1970	/coeff;
    CO2[	277	]=	440.1390	/coeff;
    CO2[	278	]=	440.0270	/coeff;
    CO2[	279	]=	439.8600	/coeff;
    CO2[	280	]=	439.6350	/coeff;
    CO2[	281	]=	439.3520	/coeff;
    CO2[	282	]=	439.0110	/coeff;
    CO2[	283	]=	438.6110	/coeff;
    CO2[	284	]=	438.1510	/coeff;
    CO2[	285	]=	437.6320	/coeff;
    CO2[	286	]=	437.0540	/coeff;
    CO2[	287	]=	436.4460	/coeff;
    CO2[	288	]=	435.8360	/coeff;
    CO2[	289	]=	435.2200	/coeff;
    CO2[	290	]=	434.5970	/coeff;
    CO2[	291	]=	433.9640	/coeff;
    CO2[	292	]=	433.3210	/coeff;
    CO2[	293	]=	432.6650	/coeff;
    CO2[	294	]=	431.9970	/coeff;
    CO2[	295	]=	431.3140	/coeff;
    CO2[	296	]=	430.6170	/coeff;
    CO2[	297	]=	429.9080	/coeff;
    CO2[	298	]=	429.1900	/coeff;
    CO2[	299	]=	428.4630	/coeff;
    CO2[	300	]=	427.7260	/coeff;
    CO2[	301	]=	426.9790	/coeff;
    CO2[	302	]=	426.2210	/coeff;
    CO2[	303	]=	425.4520	/coeff;
    CO2[	304	]=	424.6700	/coeff;
    CO2[	305	]=	423.8770	/coeff;
    CO2[	306	]=	423.0710	/coeff;
    CO2[	307	]=	422.2540	/coeff;
    CO2[	308	]=	421.4250	/coeff;
    CO2[	309	]=	420.5840	/coeff;
    CO2[	310	]=	419.7310	/coeff;
    CO2[	311	]=	418.8670	/coeff;
    CO2[	312	]=	417.9910	/coeff;
    CO2[	313	]=	417.1020	/coeff;
    CO2[	314	]=	416.2020	/coeff;
    CO2[	315	]=	415.2880	/coeff;
    CO2[	316	]=	414.3620	/coeff;
    CO2[	317	]=	413.4210	/coeff;
    CO2[	318	]=	412.4610	/coeff;
    CO2[	319	]=	411.4840	/coeff;
    CO2[	320	]=	410.4900	/coeff;
    CO2[	321	]=	409.4770	/coeff;
    CO2[	322	]=	408.4480	/coeff;
    CO2[	323	]=	407.4010	/coeff;
    CO2[	324	]=	406.3360	/coeff;
    CO2[	325	]=	405.2550	/coeff;
    CO2[	326	]=	404.1570	/coeff;
    CO2[	327	]=	403.0410	/coeff;
    CO2[	328	]=	401.9080	/coeff;
    CO2[	329	]=	400.7580	/coeff;
    CO2[	330	]=	399.5910	/coeff;
    CO2[	331	]=	398.4070	/coeff;
    CO2[	332	]=	397.2060	/coeff;
    CO2[	333	]=	395.9890	/coeff;
    CO2[	334	]=	394.7560	/coeff;
    CO2[	335	]=	393.5060	/coeff;
    CO2[	336	]=	392.2410	/coeff;
    CO2[	337	]=	390.9830	/coeff;
    CO2[	338	]=	389.7550	/coeff;
    CO2[	339	]=	388.5520	/coeff;
    CO2[	340	]=	387.3730	/coeff;
    CO2[	341	]=	386.2160	/coeff;
    CO2[	342	]=	385.0800	/coeff;
    CO2[	343	]=	383.9640	/coeff;
    CO2[	344	]=	382.8670	/coeff;
    CO2[	345	]=	381.7880	/coeff;
    CO2[	346	]=	380.7250	/coeff;
    CO2[	347	]=	379.6790	/coeff;
    CO2[	348	]=	378.6480	/coeff;
    CO2[	349	]=	377.6330	/coeff;
    CO2[	350	]=	376.6310	/coeff;
    CO2[	351	]=	375.6440	/coeff;
    CO2[	352	]=	374.6690	/coeff;
    CO2[	353	]=	373.7080	/coeff;
    CO2[	354	]=	372.7590	/coeff;
    CO2[	355	]=	371.8220	/coeff;
    CO2[	356	]=	370.8970	/coeff;
    CO2[	357	]=	369.9830	/coeff;
    CO2[	358	]=	369.0800	/coeff;
    CO2[	359	]=	368.1880	/coeff;
    CO2[	360	]=	367.3060	/coeff;
    CO2[	361	]=	366.4350	/coeff;
    CO2[	362	]=	365.5730	/coeff;
    CO2[	363	]=	364.7210	/coeff;
    CO2[	364	]=	363.8790	/coeff;
    CO2[	365	]=	363.0450	/coeff;
    CO2[	366	]=	362.2210	/coeff;
    CO2[	367	]=	361.4060	/coeff;
    CO2[	368	]=	360.5990	/coeff;
    CO2[	369	]=	359.8010	/coeff;
    CO2[	370	]=	359.0100	/coeff;
    CO2[	371	]=	358.2280	/coeff;
    CO2[	372	]=	357.4540	/coeff;
    CO2[	373	]=	356.6870	/coeff;
    CO2[	374	]=	355.9280	/coeff;
    CO2[	375	]=	355.1770	/coeff;
    CO2[	376	]=	354.4330	/coeff;
    CO2[	377	]=	353.7100	/coeff;
    CO2[	378	]=	353.0200	/coeff;
    CO2[	379	]=	352.3630	/coeff;
    CO2[	380	]=	351.7350	/coeff;
    CO2[	381	]=	351.1360	/coeff;
    CO2[	382	]=	350.5640	/coeff;
    CO2[	383	]=	350.0190	/coeff;
    CO2[	384	]=	349.5000	/coeff;
    CO2[	385	]=	349.0050	/coeff;
    CO2[	386	]=	348.5340	/coeff;
    CO2[	387	]=	348.0830	/coeff;
    CO2[	388	]=	347.6500	/coeff;
    CO2[	389	]=	347.2340	/coeff;
    CO2[	390	]=	346.8350	/coeff;
    CO2[	391	]=	346.4530	/coeff;
    CO2[	392	]=	346.0880	/coeff;
    CO2[	393	]=	345.7410	/coeff;
    CO2[	394	]=	345.4090	/coeff;
    CO2[	395	]=	345.0940	/coeff;
    CO2[	396	]=	344.7950	/coeff;
    CO2[	397	]=	344.5130	/coeff;
    CO2[	398	]=	344.2460	/coeff;
    CO2[	399	]=	343.9940	/coeff;
    CO2[	400	]=	343.7580	/coeff;
    CO2[	401	]=	343.5380	/coeff;
    CO2[	402	]=	343.3320	/coeff;
    CO2[	403	]=	343.1420	/coeff;
    CO2[	404	]=	342.9660	/coeff;
    CO2[	405	]=	342.8050	/coeff;
    CO2[	406	]=	342.6590	/coeff;
    CO2[	407	]=	342.5280	/coeff;
    CO2[	408	]=	342.4100	/coeff;
    CO2[	409	]=	342.3070	/coeff;
    CO2[	410	]=	342.2190	/coeff;
    CO2[	411	]=	342.1440	/coeff;
    CO2[	412	]=	342.0830	/coeff;
    CO2[	413	]=	342.0360	/coeff;
    CO2[	414	]=	342.0030	/coeff;
    CO2[	415	]=	341.9840	/coeff;
    CO2[	416	]=	341.9780	/coeff;
    CO2[	417	]=	341.9860	/coeff;
    CO2[	418	]=	342.0070	/coeff;
    CO2[	419	]=	342.0410	/coeff;
    CO2[	420	]=	342.0890	/coeff;
    CO2[	421	]=	342.1510	/coeff;
    CO2[	422	]=	342.2250	/coeff;
    CO2[	423	]=	342.3130	/coeff;
    CO2[	424	]=	342.4130	/coeff;
    CO2[	425	]=	342.5270	/coeff;
    CO2[	426	]=	342.6530	/coeff;
    CO2[	427	]=	342.7790	/coeff;
    CO2[	428	]=	342.8900	/coeff;
    CO2[	429	]=	342.9900	/coeff;
    CO2[	430	]=	343.0800	/coeff;
    CO2[	431	]=	343.1600	/coeff;
    CO2[	432	]=	343.2320	/coeff;
    CO2[	433	]=	343.2970	/coeff;
    CO2[	434	]=	343.3550	/coeff;
    CO2[	435	]=	343.4070	/coeff;
    CO2[	436	]=	343.4530	/coeff;
    CO2[	437	]=	343.4950	/coeff;
    CO2[	438	]=	343.5320	/coeff;
    CO2[	439	]=	343.5650	/coeff;
    CO2[	440	]=	343.5940	/coeff;
    CO2[	441	]=	343.6190	/coeff;
    CO2[	442	]=	343.6410	/coeff;
    CO2[	443	]=	343.6600	/coeff;
    CO2[	444	]=	343.6770	/coeff;
    CO2[	445	]=	343.6900	/coeff;
    CO2[	446	]=	343.7020	/coeff;
    CO2[	447	]=	343.7100	/coeff;
    CO2[	448	]=	343.7170	/coeff;
    CO2[	449	]=	343.7220	/coeff;
    CO2[	450	]=	343.7240	/coeff;
    CO2[	451	]=	343.7250	/coeff;
    CO2[	452	]=	343.7250	/coeff;
    CO2[	453	]=	343.7230	/coeff;
    CO2[	454	]=	343.7200	/coeff;
    CO2[	455	]=	343.7160	/coeff;
    CO2[	456	]=	343.7110	/coeff;
    CO2[	457	]=	343.7050	/coeff;
    CO2[	458	]=	343.6990	/coeff;
    CO2[	459	]=	343.6910	/coeff;
    CO2[	460	]=	343.6830	/coeff;
    CO2[	461	]=	343.6740	/coeff;
    CO2[	462	]=	343.6640	/coeff;
    CO2[	463	]=	343.6540	/coeff;
    CO2[	464	]=	343.6430	/coeff;
    CO2[	465	]=	343.6310	/coeff;
    CO2[	466	]=	343.6190	/coeff;
    CO2[	467	]=	343.6070	/coeff;
    CO2[	468	]=	343.5940	/coeff;
    CO2[	469	]=	343.5800	/coeff;
    CO2[	470	]=	343.5660	/coeff;
    CO2[	471	]=	343.5510	/coeff;
    CO2[	472	]=	343.5360	/coeff;
    CO2[	473	]=	343.5210	/coeff;
    CO2[	474	]=	343.5050	/coeff;
    CO2[	475	]=	343.4890	/coeff;
    CO2[	476	]=	343.4730	/coeff;
    CO2[	477	]=	343.4560	/coeff;
    CO2[	478	]=	343.4390	/coeff;
    CO2[	479	]=	343.4220	/coeff;
    CO2[	480	]=	343.4040	/coeff;
    CO2[	481	]=	343.3860	/coeff;
    CO2[	482	]=	343.3680	/coeff;
    CO2[	483	]=	343.3490	/coeff;
    CO2[	484	]=	343.3310	/coeff;
    CO2[	485	]=	343.3120	/coeff;
    CO2[	486	]=	343.2930	/coeff;
    CO2[	487	]=	343.2730	/coeff;
    CO2[	488	]=	343.2530	/coeff;
    CO2[	489	]=	343.2330	/coeff;
    CO2[	490	]=	343.2120	/coeff;
    CO2[	491	]=	343.1910	/coeff;
    CO2[	492	]=	343.1690	/coeff;
    CO2[	493	]=	343.1460	/coeff;
    CO2[	494	]=	343.1230	/coeff;
    CO2[	495	]=	343.1000	/coeff;
    CO2[	496	]=	343.0760	/coeff;
    CO2[	497	]=	343.0510	/coeff;
    CO2[	498	]=	343.0260	/coeff;
    CO2[	499	]=	343.0010	/coeff;
    CO2[	500	]=	342.9750	/coeff;
    CO2[	501	]=	342.9490	/coeff;
    CO2[	502	]=	342.9230	/coeff;
    CO2[	503	]=	342.8970	/coeff;
    CO2[	504	]=	342.8710	/coeff;
    CO2[	505	]=	342.8440	/coeff;
    CO2[	506	]=	342.8170	/coeff;
    CO2[	507	]=	342.7900	/coeff;
    CO2[	508	]=	342.7630	/coeff;
    CO2[	509	]=	342.7360	/coeff;
    CO2[	510	]=	342.7080	/coeff;
    CO2[	511	]=	342.6810	/coeff;
    CO2[	512	]=	342.6530	/coeff;
    CO2[	513	]=	342.6260	/coeff;
    CO2[	514	]=	342.5980	/coeff;
    CO2[	515	]=	342.5700	/coeff;
    CO2[	516	]=	342.5430	/coeff;
    CO2[	517	]=	342.5150	/coeff;
    CO2[	518	]=	342.4870	/coeff;
    CO2[	519	]=	342.4590	/coeff;
    CO2[	520	]=	342.4310	/coeff;
    CO2[	521	]=	342.4030	/coeff;
    CO2[	522	]=	342.3750	/coeff;
    CO2[	523	]=	342.3480	/coeff;
    CO2[	524	]=	342.3200	/coeff;
    CO2[	525	]=	342.2920	/coeff;
    CO2[	526	]=	342.2640	/coeff;
    CO2[	527	]=	342.2360	/coeff;
    CO2[	528	]=	342.2080	/coeff;
    CO2[	529	]=	342.1800	/coeff;
    CO2[	530	]=	342.1520	/coeff;
    CO2[	531	]=	342.1230	/coeff;
    CO2[	532	]=	342.0950	/coeff;
    CO2[	533	]=	342.0670	/coeff;
    CO2[	534	]=	342.0390	/coeff;
    CO2[	535	]=	342.0110	/coeff;
    CO2[	536	]=	341.9830	/coeff;
    CO2[	537	]=	341.9550	/coeff;
    CO2[	538	]=	341.9270	/coeff;
    CO2[	539	]=	341.8990	/coeff;
    CO2[	540	]=	341.8710	/coeff;
    CO2[	541	]=	341.8430	/coeff;
    CO2[	542	]=	341.8150	/coeff;
    CO2[	543	]=	341.7870	/coeff;
    CO2[	544	]=	341.7590	/coeff;
    CO2[	545	]=	341.7310	/coeff;
    CO2[	546	]=	341.7030	/coeff;
    CO2[	547	]=	341.6750	/coeff;
    CO2[	548	]=	341.6470	/coeff;
    CO2[	549	]=	341.6190	/coeff;
    CO2[	550	]=	341.5910	/coeff;
    CO2[	551	]=	341.5630	/coeff;
    CO2[	552	]=	341.5350	/coeff;
    CO2[	553	]=	341.5070	/coeff;
    CO2[	554	]=	341.4780	/coeff;
    CO2[	555	]=	341.4500	/coeff;
    CO2[	556	]=	341.4220	/coeff;
    CO2[	557	]=	341.3940	/coeff;
    CO2[	558	]=	341.3660	/coeff;
    CO2[	559	]=	341.3380	/coeff;
    CO2[	560	]=	341.3100	/coeff;
    CO2[	561	]=	341.2820	/coeff;
    CO2[	562	]=	341.2540	/coeff;
    CO2[	563	]=	341.2260	/coeff;
    CO2[	564	]=	341.1970	/coeff;
    CO2[	565	]=	341.1690	/coeff;
    CO2[	566	]=	341.1410	/coeff;
    CO2[	567	]=	341.1130	/coeff;
    CO2[	568	]=	341.0840	/coeff;
    CO2[	569	]=	341.0560	/coeff;
    CO2[	570	]=	341.0280	/coeff;
    CO2[	571	]=	341.0000	/coeff;
    CO2[	572	]=	340.9710	/coeff;
    CO2[	573	]=	340.9430	/coeff;
    CO2[	574	]=	340.9140	/coeff;
    CO2[	575	]=	340.8860	/coeff;
    CO2[	576	]=	340.8570	/coeff;
    CO2[	577	]=	340.8290	/coeff;
    CO2[	578	]=	340.8000	/coeff;
    CO2[	579	]=	340.7710	/coeff;
    CO2[	580	]=	340.7430	/coeff;
    CO2[	581	]=	340.7140	/coeff;
    CO2[	582	]=	340.6850	/coeff;
    CO2[	583	]=	340.6560	/coeff;
    CO2[	584	]=	340.6270	/coeff;
    CO2[	585	]=	340.5980	/coeff;
    CO2[	586	]=	340.5690	/coeff;
    CO2[	587	]=	340.5400	/coeff;
    CO2[	588	]=	340.5110	/coeff;
    CO2[	589	]=	340.4810	/coeff;
    CO2[	590	]=	340.4520	/coeff;
    CO2[	591	]=	340.4230	/coeff;
    CO2[	592	]=	340.3940	/coeff;
    CO2[	593	]=	340.3650	/coeff;
    CO2[	594	]=	340.3360	/coeff;
    CO2[	595	]=	340.3070	/coeff;
    CO2[	596	]=	340.2780	/coeff;
    CO2[	597	]=	340.2500	/coeff;
    CO2[	598	]=	340.2210	/coeff;
    CO2[	599	]=	340.1930	/coeff;
    CO2[	600	]=	340.1650	/coeff;
    CO2[	601	]=	340.1370	/coeff;
    CO2[	602	]=	340.1080	/coeff;
    CO2[	603	]=	340.0800	/coeff;
    CO2[	604	]=	340.0520	/coeff;
    CO2[	605	]=	340.0250	/coeff;
    CO2[	606	]=	339.9970	/coeff;
    CO2[	607	]=	339.9690	/coeff;
    CO2[	608	]=	339.9410	/coeff;
    CO2[	609	]=	339.9140	/coeff;
    CO2[	610	]=	339.8860	/coeff;
    CO2[	611	]=	339.8590	/coeff;
    CO2[	612	]=	339.8310	/coeff;
    CO2[	613	]=	339.8040	/coeff;
    CO2[	614	]=	339.7770	/coeff;
    CO2[	615	]=	339.7500	/coeff;
    CO2[	616	]=	339.7230	/coeff;
    CO2[	617	]=	339.6960	/coeff;
    CO2[	618	]=	339.6690	/coeff;
    CO2[	619	]=	339.6420	/coeff;
    CO2[	620	]=	339.6150	/coeff;
    CO2[	621	]=	339.5880	/coeff;
    CO2[	622	]=	339.5610	/coeff;
    CO2[	623	]=	339.5350	/coeff;
    CO2[	624	]=	339.5080	/coeff;
    CO2[	625	]=	339.4810	/coeff;
    CO2[	626	]=	339.4550	/coeff;
    CO2[	627	]=	339.4290	/coeff;
    CO2[	628	]=	339.4020	/coeff;
    CO2[	629	]=	339.3760	/coeff;
    CO2[	630	]=	339.3500	/coeff;
    CO2[	631	]=	339.3230	/coeff;
    CO2[	632	]=	339.2970	/coeff;
    CO2[	633	]=	339.2710	/coeff;
    CO2[	634	]=	339.2450	/coeff;
    CO2[	635	]=	339.2190	/coeff;
    CO2[	636	]=	339.1930	/coeff;
    CO2[	637	]=	339.1670	/coeff;
    CO2[	638	]=	339.1410	/coeff;
    CO2[	639	]=	339.1160	/coeff;
    CO2[	640	]=	339.0900	/coeff;
    CO2[	641	]=	339.0640	/coeff;
    CO2[	642	]=	339.0390	/coeff;
    CO2[	643	]=	339.0130	/coeff;
    CO2[	644	]=	338.9880	/coeff;
    CO2[	645	]=	338.9620	/coeff;
    CO2[	646	]=	338.9370	/coeff;
    CO2[	647	]=	338.9110	/coeff;
    CO2[	648	]=	338.8860	/coeff;
    CO2[	649	]=	338.8610	/coeff;
    CO2[	650	]=	338.8350	/coeff;
    CO2[	651	]=	338.8100	/coeff;
    CO2[	652	]=	338.7850	/coeff;
    CO2[	653	]=	338.7600	/coeff;
    CO2[	654	]=	338.7350	/coeff;
    CO2[	655	]=	338.7100	/coeff;
    CO2[	656	]=	338.6850	/coeff;
    CO2[	657	]=	338.6600	/coeff;
    CO2[	658	]=	338.6360	/coeff;
    CO2[	659	]=	338.6110	/coeff;
    CO2[	660	]=	338.5860	/coeff;
    CO2[	661	]=	338.5610	/coeff;
    CO2[	662	]=	338.5370	/coeff;
    CO2[	663	]=	338.5120	/coeff;
    CO2[	664	]=	338.4880	/coeff;
    CO2[	665	]=	338.4630	/coeff;
    CO2[	666	]=	338.4390	/coeff;
    CO2[	667	]=	338.4140	/coeff;
    CO2[	668	]=	338.3900	/coeff;
    CO2[	669	]=	338.3660	/coeff;
    CO2[	670	]=	338.3410	/coeff;
    CO2[	671	]=	338.3170	/coeff;
    CO2[	672	]=	338.2930	/coeff;
    CO2[	673	]=	338.2690	/coeff;
    CO2[	674	]=	338.2450	/coeff;
    CO2[	675	]=	338.2210	/coeff;
    CO2[	676	]=	338.1970	/coeff;
    CO2[	677	]=	338.1730	/coeff;
    CO2[	678	]=	338.1490	/coeff;
    CO2[	679	]=	338.1250	/coeff;
    CO2[	680	]=	338.1010	/coeff;
    CO2[	681	]=	338.0770	/coeff;
    CO2[	682	]=	338.0530	/coeff;
    CO2[	683	]=	338.0300	/coeff;
    CO2[	684	]=	338.0060	/coeff;
    CO2[	685	]=	337.9820	/coeff;
    CO2[	686	]=	337.9590	/coeff;
    CO2[	687	]=	337.9350	/coeff;
    CO2[	688	]=	337.9120	/coeff;
    CO2[	689	]=	337.8880	/coeff;
    CO2[	690	]=	337.8650	/coeff;
    CO2[	691	]=	337.8420	/coeff;
    CO2[	692	]=	337.8180	/coeff;
    CO2[	693	]=	337.7950	/coeff;
    CO2[	694	]=	337.7720	/coeff;
    CO2[	695	]=	337.7490	/coeff;
    CO2[	696	]=	337.7250	/coeff;
    CO2[	697	]=	337.7020	/coeff;
    CO2[	698	]=	337.6790	/coeff;
    CO2[	699	]=	337.6560	/coeff;
    CO2[	700	]=	337.6330	/coeff;
    CO2[	701	]=	337.6100	/coeff;
    CO2[	702	]=	337.5870	/coeff;
    CO2[	703	]=	337.5640	/coeff;
    CO2[	704	]=	337.5420	/coeff;
    CO2[	705	]=	337.5190	/coeff;
    CO2[	706	]=	337.4960	/coeff;
    CO2[	707	]=	337.4730	/coeff;
    CO2[	708	]=	337.4510	/coeff;
    CO2[	709	]=	337.4280	/coeff;
    CO2[	710	]=	337.4050	/coeff;
    CO2[	711	]=	337.3830	/coeff;
    CO2[	712	]=	337.3600	/coeff;
    CO2[	713	]=	337.3380	/coeff;
    CO2[	714	]=	337.3150	/coeff;
    CO2[	715	]=	337.2930	/coeff;
    CO2[	716	]=	337.2710	/coeff;
    CO2[	717	]=	337.2480	/coeff;
    CO2[	718	]=	337.2260	/coeff;
    CO2[	719	]=	337.2040	/coeff;
    CO2[	720	]=	337.1810	/coeff;
    CO2[	721	]=	337.1590	/coeff;
    CO2[	722	]=	337.1370	/coeff;
    CO2[	723	]=	337.1150	/coeff;
    CO2[	724	]=	337.0930	/coeff;
    CO2[	725	]=	337.0710	/coeff;
    CO2[	726	]=	337.0490	/coeff;
    CO2[	727	]=	337.0270	/coeff;
    CO2[	728	]=	337.0050	/coeff;
    CO2[	729	]=	336.9830	/coeff;
    CO2[	730	]=	336.9610	/coeff;
    CO2[	731	]=	336.9400	/coeff;
    CO2[	732	]=	336.9180	/coeff;
    CO2[	733	]=	336.8960	/coeff;
    CO2[	734	]=	336.8740	/coeff;
    CO2[	735	]=	336.8630	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp126(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9492	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7520	/coeff;
    CO2[	253	]=	408.5920	/coeff;
    CO2[	254	]=	411.4170	/coeff;
    CO2[	255	]=	414.2320	/coeff;
    CO2[	256	]=	417.0420	/coeff;
    CO2[	257	]=	419.8090	/coeff;
    CO2[	258	]=	422.4990	/coeff;
    CO2[	259	]=	425.1200	/coeff;
    CO2[	260	]=	427.6740	/coeff;
    CO2[	261	]=	430.1660	/coeff;
    CO2[	262	]=	432.5980	/coeff;
    CO2[	263	]=	434.9740	/coeff;
    CO2[	264	]=	437.2950	/coeff;
    CO2[	265	]=	439.5640	/coeff;
    CO2[	266	]=	441.7810	/coeff;
    CO2[	267	]=	443.9290	/coeff;
    CO2[	268	]=	445.9900	/coeff;
    CO2[	269	]=	447.9690	/coeff;
    CO2[	270	]=	449.8660	/coeff;
    CO2[	271	]=	451.6850	/coeff;
    CO2[	272	]=	453.4260	/coeff;
    CO2[	273	]=	455.0920	/coeff;
    CO2[	274	]=	456.6840	/coeff;
    CO2[	275	]=	458.2010	/coeff;
    CO2[	276	]=	459.6470	/coeff;
    CO2[	277	]=	461.0190	/coeff;
    CO2[	278	]=	462.3150	/coeff;
    CO2[	279	]=	463.5360	/coeff;
    CO2[	280	]=	464.6830	/coeff;
    CO2[	281	]=	465.7550	/coeff;
    CO2[	282	]=	466.7530	/coeff;
    CO2[	283	]=	467.6780	/coeff;
    CO2[	284	]=	468.5300	/coeff;
    CO2[	285	]=	469.3100	/coeff;
    CO2[	286	]=	470.0190	/coeff;
    CO2[	287	]=	470.6630	/coeff;
    CO2[	288	]=	471.2500	/coeff;
    CO2[	289	]=	471.7790	/coeff;
    CO2[	290	]=	472.2510	/coeff;
    CO2[	291	]=	472.6650	/coeff;
    CO2[	292	]=	473.0220	/coeff;
    CO2[	293	]=	473.3220	/coeff;
    CO2[	294	]=	473.5640	/coeff;
    CO2[	295	]=	473.7500	/coeff;
    CO2[	296	]=	473.8780	/coeff;
    CO2[	297	]=	473.9590	/coeff;
    CO2[	298	]=	473.9990	/coeff;
    CO2[	299	]=	473.9990	/coeff;
    CO2[	300	]=	473.9570	/coeff;
    CO2[	301	]=	473.8730	/coeff;
    CO2[	302	]=	473.7470	/coeff;
    CO2[	303	]=	473.5780	/coeff;
    CO2[	304	]=	473.3650	/coeff;
    CO2[	305	]=	473.1100	/coeff;
    CO2[	306	]=	472.8110	/coeff;
    CO2[	307	]=	472.4580	/coeff;
    CO2[	308	]=	472.0410	/coeff;
    CO2[	309	]=	471.5610	/coeff;
    CO2[	310	]=	471.0180	/coeff;
    CO2[	311	]=	470.4140	/coeff;
    CO2[	312	]=	469.7490	/coeff;
    CO2[	313	]=	469.0220	/coeff;
    CO2[	314	]=	468.2360	/coeff;
    CO2[	315	]=	467.3900	/coeff;
    CO2[	316	]=	466.4840	/coeff;
    CO2[	317	]=	465.5360	/coeff;
    CO2[	318	]=	464.5610	/coeff;
    CO2[	319	]=	463.5580	/coeff;
    CO2[	320	]=	462.5270	/coeff;
    CO2[	321	]=	461.4660	/coeff;
    CO2[	322	]=	460.3750	/coeff;
    CO2[	323	]=	459.2550	/coeff;
    CO2[	324	]=	458.1040	/coeff;
    CO2[	325	]=	456.9240	/coeff;
    CO2[	326	]=	455.7130	/coeff;
    CO2[	327	]=	454.5020	/coeff;
    CO2[	328	]=	453.3190	/coeff;
    CO2[	329	]=	452.1600	/coeff;
    CO2[	330	]=	451.0240	/coeff;
    CO2[	331	]=	449.9090	/coeff;
    CO2[	332	]=	448.8120	/coeff;
    CO2[	333	]=	447.7340	/coeff;
    CO2[	334	]=	446.6720	/coeff;
    CO2[	335	]=	445.6250	/coeff;
    CO2[	336	]=	444.5920	/coeff;
    CO2[	337	]=	443.5780	/coeff;
    CO2[	338	]=	442.5860	/coeff;
    CO2[	339	]=	441.6140	/coeff;
    CO2[	340	]=	440.6620	/coeff;
    CO2[	341	]=	439.7290	/coeff;
    CO2[	342	]=	438.8130	/coeff;
    CO2[	343	]=	437.9140	/coeff;
    CO2[	344	]=	437.0310	/coeff;
    CO2[	345	]=	436.1630	/coeff;
    CO2[	346	]=	435.3110	/coeff;
    CO2[	347	]=	434.4730	/coeff;
    CO2[	348	]=	433.6500	/coeff;
    CO2[	349	]=	432.8400	/coeff;
    CO2[	350	]=	432.0440	/coeff;
    CO2[	351	]=	431.2610	/coeff;
    CO2[	352	]=	430.4910	/coeff;
    CO2[	353	]=	429.7340	/coeff;
    CO2[	354	]=	428.9880	/coeff;
    CO2[	355	]=	428.2540	/coeff;
    CO2[	356	]=	427.5320	/coeff;
    CO2[	357	]=	426.8210	/coeff;
    CO2[	358	]=	426.1200	/coeff;
    CO2[	359	]=	425.4310	/coeff;
    CO2[	360	]=	424.7510	/coeff;
    CO2[	361	]=	424.0820	/coeff;
    CO2[	362	]=	423.4230	/coeff;
    CO2[	363	]=	422.7740	/coeff;
    CO2[	364	]=	422.1340	/coeff;
    CO2[	365	]=	421.5040	/coeff;
    CO2[	366	]=	420.8820	/coeff;
    CO2[	367	]=	420.2700	/coeff;
    CO2[	368	]=	419.6670	/coeff;
    CO2[	369	]=	419.0720	/coeff;
    CO2[	370	]=	418.4850	/coeff;
    CO2[	371	]=	417.9070	/coeff;
    CO2[	372	]=	417.3370	/coeff;
    CO2[	373	]=	416.7750	/coeff;
    CO2[	374	]=	416.2210	/coeff;
    CO2[	375	]=	415.6750	/coeff;
    CO2[	376	]=	415.1360	/coeff;
    CO2[	377	]=	414.6120	/coeff;
    CO2[	378	]=	414.1080	/coeff;
    CO2[	379	]=	413.6250	/coeff;
    CO2[	380	]=	413.1610	/coeff;
    CO2[	381	]=	412.7150	/coeff;
    CO2[	382	]=	412.2880	/coeff;
    CO2[	383	]=	411.8780	/coeff;
    CO2[	384	]=	411.4850	/coeff;
    CO2[	385	]=	411.1090	/coeff;
    CO2[	386	]=	410.7490	/coeff;
    CO2[	387	]=	410.4020	/coeff;
    CO2[	388	]=	410.0630	/coeff;
    CO2[	389	]=	409.7340	/coeff;
    CO2[	390	]=	409.4130	/coeff;
    CO2[	391	]=	409.1020	/coeff;
    CO2[	392	]=	408.7990	/coeff;
    CO2[	393	]=	408.5060	/coeff;
    CO2[	394	]=	408.2210	/coeff;
    CO2[	395	]=	407.9450	/coeff;
    CO2[	396	]=	407.6790	/coeff;
    CO2[	397	]=	407.4200	/coeff;
    CO2[	398	]=	407.1710	/coeff;
    CO2[	399	]=	406.9310	/coeff;
    CO2[	400	]=	406.6990	/coeff;
    CO2[	401	]=	406.4750	/coeff;
    CO2[	402	]=	406.2600	/coeff;
    CO2[	403	]=	406.0540	/coeff;
    CO2[	404	]=	405.8560	/coeff;
    CO2[	405	]=	405.6670	/coeff;
    CO2[	406	]=	405.4860	/coeff;
    CO2[	407	]=	405.3130	/coeff;
    CO2[	408	]=	405.1490	/coeff;
    CO2[	409	]=	404.9930	/coeff;
    CO2[	410	]=	404.8440	/coeff;
    CO2[	411	]=	404.7040	/coeff;
    CO2[	412	]=	404.5730	/coeff;
    CO2[	413	]=	404.4490	/coeff;
    CO2[	414	]=	404.3330	/coeff;
    CO2[	415	]=	404.2250	/coeff;
    CO2[	416	]=	404.1250	/coeff;
    CO2[	417	]=	404.0330	/coeff;
    CO2[	418	]=	403.9480	/coeff;
    CO2[	419	]=	403.8710	/coeff;
    CO2[	420	]=	403.8020	/coeff;
    CO2[	421	]=	403.7410	/coeff;
    CO2[	422	]=	403.6870	/coeff;
    CO2[	423	]=	403.6420	/coeff;
    CO2[	424	]=	403.6040	/coeff;
    CO2[	425	]=	403.5750	/coeff;
    CO2[	426	]=	403.5530	/coeff;
    CO2[	427	]=	403.5320	/coeff;
    CO2[	428	]=	403.5050	/coeff;
    CO2[	429	]=	403.4740	/coeff;
    CO2[	430	]=	403.4380	/coeff;
    CO2[	431	]=	403.3990	/coeff;
    CO2[	432	]=	403.3560	/coeff;
    CO2[	433	]=	403.3100	/coeff;
    CO2[	434	]=	403.2620	/coeff;
    CO2[	435	]=	403.2110	/coeff;
    CO2[	436	]=	403.1580	/coeff;
    CO2[	437	]=	403.1030	/coeff;
    CO2[	438	]=	403.0460	/coeff;
    CO2[	439	]=	402.9880	/coeff;
    CO2[	440	]=	402.9280	/coeff;
    CO2[	441	]=	402.8660	/coeff;
    CO2[	442	]=	402.8040	/coeff;
    CO2[	443	]=	402.7400	/coeff;
    CO2[	444	]=	402.6760	/coeff;
    CO2[	445	]=	402.6100	/coeff;
    CO2[	446	]=	402.5440	/coeff;
    CO2[	447	]=	402.4770	/coeff;
    CO2[	448	]=	402.4090	/coeff;
    CO2[	449	]=	402.3410	/coeff;
    CO2[	450	]=	402.2720	/coeff;
    CO2[	451	]=	402.2020	/coeff;
    CO2[	452	]=	402.1320	/coeff;
    CO2[	453	]=	402.0620	/coeff;
    CO2[	454	]=	401.9910	/coeff;
    CO2[	455	]=	401.9200	/coeff;
    CO2[	456	]=	401.8480	/coeff;
    CO2[	457	]=	401.7760	/coeff;
    CO2[	458	]=	401.7040	/coeff;
    CO2[	459	]=	401.6320	/coeff;
    CO2[	460	]=	401.5590	/coeff;
    CO2[	461	]=	401.4860	/coeff;
    CO2[	462	]=	401.4130	/coeff;
    CO2[	463	]=	401.3400	/coeff;
    CO2[	464	]=	401.2670	/coeff;
    CO2[	465	]=	401.1930	/coeff;
    CO2[	466	]=	401.1200	/coeff;
    CO2[	467	]=	401.0460	/coeff;
    CO2[	468	]=	400.9720	/coeff;
    CO2[	469	]=	400.8980	/coeff;
    CO2[	470	]=	400.8250	/coeff;
    CO2[	471	]=	400.7510	/coeff;
    CO2[	472	]=	400.6770	/coeff;
    CO2[	473	]=	400.6030	/coeff;
    CO2[	474	]=	400.5290	/coeff;
    CO2[	475	]=	400.4540	/coeff;
    CO2[	476	]=	400.3800	/coeff;
    CO2[	477	]=	400.3060	/coeff;
    CO2[	478	]=	400.2320	/coeff;
    CO2[	479	]=	400.1580	/coeff;
    CO2[	480	]=	400.0840	/coeff;
    CO2[	481	]=	400.0100	/coeff;
    CO2[	482	]=	399.9360	/coeff;
    CO2[	483	]=	399.8620	/coeff;
    CO2[	484	]=	399.7880	/coeff;
    CO2[	485	]=	399.7140	/coeff;
    CO2[	486	]=	399.6400	/coeff;
    CO2[	487	]=	399.5660	/coeff;
    CO2[	488	]=	399.4920	/coeff;
    CO2[	489	]=	399.4180	/coeff;
    CO2[	490	]=	399.3440	/coeff;
    CO2[	491	]=	399.2690	/coeff;
    CO2[	492	]=	399.1940	/coeff;
    CO2[	493	]=	399.1180	/coeff;
    CO2[	494	]=	399.0420	/coeff;
    CO2[	495	]=	398.9660	/coeff;
    CO2[	496	]=	398.8900	/coeff;
    CO2[	497	]=	398.8130	/coeff;
    CO2[	498	]=	398.7370	/coeff;
    CO2[	499	]=	398.6600	/coeff;
    CO2[	500	]=	398.5830	/coeff;
    CO2[	501	]=	398.5060	/coeff;
    CO2[	502	]=	398.4290	/coeff;
    CO2[	503	]=	398.3520	/coeff;
    CO2[	504	]=	398.2750	/coeff;
    CO2[	505	]=	398.1980	/coeff;
    CO2[	506	]=	398.1220	/coeff;
    CO2[	507	]=	398.0450	/coeff;
    CO2[	508	]=	397.9680	/coeff;
    CO2[	509	]=	397.8920	/coeff;
    CO2[	510	]=	397.8160	/coeff;
    CO2[	511	]=	397.7390	/coeff;
    CO2[	512	]=	397.6630	/coeff;
    CO2[	513	]=	397.5870	/coeff;
    CO2[	514	]=	397.5120	/coeff;
    CO2[	515	]=	397.4360	/coeff;
    CO2[	516	]=	397.3610	/coeff;
    CO2[	517	]=	397.2850	/coeff;
    CO2[	518	]=	397.2100	/coeff;
    CO2[	519	]=	397.1350	/coeff;
    CO2[	520	]=	397.0610	/coeff;
    CO2[	521	]=	396.9860	/coeff;
    CO2[	522	]=	396.9120	/coeff;
    CO2[	523	]=	396.8380	/coeff;
    CO2[	524	]=	396.7640	/coeff;
    CO2[	525	]=	396.6900	/coeff;
    CO2[	526	]=	396.6160	/coeff;
    CO2[	527	]=	396.5430	/coeff;
    CO2[	528	]=	396.4690	/coeff;
    CO2[	529	]=	396.3960	/coeff;
    CO2[	530	]=	396.3230	/coeff;
    CO2[	531	]=	396.2510	/coeff;
    CO2[	532	]=	396.1780	/coeff;
    CO2[	533	]=	396.1060	/coeff;
    CO2[	534	]=	396.0340	/coeff;
    CO2[	535	]=	395.9620	/coeff;
    CO2[	536	]=	395.8900	/coeff;
    CO2[	537	]=	395.8180	/coeff;
    CO2[	538	]=	395.7470	/coeff;
    CO2[	539	]=	395.6760	/coeff;
    CO2[	540	]=	395.6040	/coeff;
    CO2[	541	]=	395.5330	/coeff;
    CO2[	542	]=	395.4630	/coeff;
    CO2[	543	]=	395.3920	/coeff;
    CO2[	544	]=	395.3220	/coeff;
    CO2[	545	]=	395.2510	/coeff;
    CO2[	546	]=	395.1810	/coeff;
    CO2[	547	]=	395.1110	/coeff;
    CO2[	548	]=	395.0420	/coeff;
    CO2[	549	]=	394.9720	/coeff;
    CO2[	550	]=	394.9020	/coeff;
    CO2[	551	]=	394.8330	/coeff;
    CO2[	552	]=	394.7640	/coeff;
    CO2[	553	]=	394.6950	/coeff;
    CO2[	554	]=	394.6260	/coeff;
    CO2[	555	]=	394.5570	/coeff;
    CO2[	556	]=	394.4890	/coeff;
    CO2[	557	]=	394.4200	/coeff;
    CO2[	558	]=	394.3520	/coeff;
    CO2[	559	]=	394.2840	/coeff;
    CO2[	560	]=	394.2160	/coeff;
    CO2[	561	]=	394.1480	/coeff;
    CO2[	562	]=	394.0800	/coeff;
    CO2[	563	]=	394.0130	/coeff;
    CO2[	564	]=	393.9450	/coeff;
    CO2[	565	]=	393.8780	/coeff;
    CO2[	566	]=	393.8100	/coeff;
    CO2[	567	]=	393.7430	/coeff;
    CO2[	568	]=	393.6760	/coeff;
    CO2[	569	]=	393.6100	/coeff;
    CO2[	570	]=	393.5430	/coeff;
    CO2[	571	]=	393.4760	/coeff;
    CO2[	572	]=	393.4100	/coeff;
    CO2[	573	]=	393.3430	/coeff;
    CO2[	574	]=	393.2770	/coeff;
    CO2[	575	]=	393.2110	/coeff;
    CO2[	576	]=	393.1450	/coeff;
    CO2[	577	]=	393.0790	/coeff;
    CO2[	578	]=	393.0130	/coeff;
    CO2[	579	]=	392.9470	/coeff;
    CO2[	580	]=	392.8810	/coeff;
    CO2[	581	]=	392.8160	/coeff;
    CO2[	582	]=	392.7500	/coeff;
    CO2[	583	]=	392.6850	/coeff;
    CO2[	584	]=	392.6200	/coeff;
    CO2[	585	]=	392.5540	/coeff;
    CO2[	586	]=	392.4890	/coeff;
    CO2[	587	]=	392.4240	/coeff;
    CO2[	588	]=	392.3590	/coeff;
    CO2[	589	]=	392.2940	/coeff;
    CO2[	590	]=	392.2290	/coeff;
    CO2[	591	]=	392.1640	/coeff;
    CO2[	592	]=	392.1000	/coeff;
    CO2[	593	]=	392.0350	/coeff;
    CO2[	594	]=	391.9700	/coeff;
    CO2[	595	]=	391.9060	/coeff;
    CO2[	596	]=	391.8410	/coeff;
    CO2[	597	]=	391.7770	/coeff;
    CO2[	598	]=	391.7120	/coeff;
    CO2[	599	]=	391.6480	/coeff;
    CO2[	600	]=	391.5840	/coeff;
    CO2[	601	]=	391.5200	/coeff;
    CO2[	602	]=	391.4560	/coeff;
    CO2[	603	]=	391.3930	/coeff;
    CO2[	604	]=	391.3290	/coeff;
    CO2[	605	]=	391.2660	/coeff;
    CO2[	606	]=	391.2030	/coeff;
    CO2[	607	]=	391.1400	/coeff;
    CO2[	608	]=	391.0780	/coeff;
    CO2[	609	]=	391.0150	/coeff;
    CO2[	610	]=	390.9530	/coeff;
    CO2[	611	]=	390.8910	/coeff;
    CO2[	612	]=	390.8290	/coeff;
    CO2[	613	]=	390.7670	/coeff;
    CO2[	614	]=	390.7060	/coeff;
    CO2[	615	]=	390.6440	/coeff;
    CO2[	616	]=	390.5830	/coeff;
    CO2[	617	]=	390.5220	/coeff;
    CO2[	618	]=	390.4610	/coeff;
    CO2[	619	]=	390.4010	/coeff;
    CO2[	620	]=	390.3400	/coeff;
    CO2[	621	]=	390.2800	/coeff;
    CO2[	622	]=	390.2190	/coeff;
    CO2[	623	]=	390.1590	/coeff;
    CO2[	624	]=	390.0990	/coeff;
    CO2[	625	]=	390.0400	/coeff;
    CO2[	626	]=	389.9800	/coeff;
    CO2[	627	]=	389.9210	/coeff;
    CO2[	628	]=	389.8610	/coeff;
    CO2[	629	]=	389.8020	/coeff;
    CO2[	630	]=	389.7430	/coeff;
    CO2[	631	]=	389.6840	/coeff;
    CO2[	632	]=	389.6250	/coeff;
    CO2[	633	]=	389.5670	/coeff;
    CO2[	634	]=	389.5080	/coeff;
    CO2[	635	]=	389.4500	/coeff;
    CO2[	636	]=	389.3920	/coeff;
    CO2[	637	]=	389.3340	/coeff;
    CO2[	638	]=	389.2760	/coeff;
    CO2[	639	]=	389.2180	/coeff;
    CO2[	640	]=	389.1610	/coeff;
    CO2[	641	]=	389.1030	/coeff;
    CO2[	642	]=	389.0460	/coeff;
    CO2[	643	]=	388.9890	/coeff;
    CO2[	644	]=	388.9320	/coeff;
    CO2[	645	]=	388.8750	/coeff;
    CO2[	646	]=	388.8180	/coeff;
    CO2[	647	]=	388.7620	/coeff;
    CO2[	648	]=	388.7050	/coeff;
    CO2[	649	]=	388.6490	/coeff;
    CO2[	650	]=	388.5930	/coeff;
    CO2[	651	]=	388.5360	/coeff;
    CO2[	652	]=	388.4800	/coeff;
    CO2[	653	]=	388.4250	/coeff;
    CO2[	654	]=	388.3690	/coeff;
    CO2[	655	]=	388.3130	/coeff;
    CO2[	656	]=	388.2580	/coeff;
    CO2[	657	]=	388.2020	/coeff;
    CO2[	658	]=	388.1470	/coeff;
    CO2[	659	]=	388.0920	/coeff;
    CO2[	660	]=	388.0370	/coeff;
    CO2[	661	]=	387.9820	/coeff;
    CO2[	662	]=	387.9280	/coeff;
    CO2[	663	]=	387.8730	/coeff;
    CO2[	664	]=	387.8190	/coeff;
    CO2[	665	]=	387.7640	/coeff;
    CO2[	666	]=	387.7100	/coeff;
    CO2[	667	]=	387.6560	/coeff;
    CO2[	668	]=	387.6020	/coeff;
    CO2[	669	]=	387.5480	/coeff;
    CO2[	670	]=	387.4940	/coeff;
    CO2[	671	]=	387.4410	/coeff;
    CO2[	672	]=	387.3870	/coeff;
    CO2[	673	]=	387.3340	/coeff;
    CO2[	674	]=	387.2800	/coeff;
    CO2[	675	]=	387.2270	/coeff;
    CO2[	676	]=	387.1740	/coeff;
    CO2[	677	]=	387.1210	/coeff;
    CO2[	678	]=	387.0680	/coeff;
    CO2[	679	]=	387.0160	/coeff;
    CO2[	680	]=	386.9630	/coeff;
    CO2[	681	]=	386.9110	/coeff;
    CO2[	682	]=	386.8580	/coeff;
    CO2[	683	]=	386.8060	/coeff;
    CO2[	684	]=	386.7540	/coeff;
    CO2[	685	]=	386.7020	/coeff;
    CO2[	686	]=	386.6500	/coeff;
    CO2[	687	]=	386.5980	/coeff;
    CO2[	688	]=	386.5460	/coeff;
    CO2[	689	]=	386.4950	/coeff;
    CO2[	690	]=	386.4430	/coeff;
    CO2[	691	]=	386.3920	/coeff;
    CO2[	692	]=	386.3400	/coeff;
    CO2[	693	]=	386.2890	/coeff;
    CO2[	694	]=	386.2380	/coeff;
    CO2[	695	]=	386.1870	/coeff;
    CO2[	696	]=	386.1360	/coeff;
    CO2[	697	]=	386.0860	/coeff;
    CO2[	698	]=	386.0350	/coeff;
    CO2[	699	]=	385.9840	/coeff;
    CO2[	700	]=	385.9340	/coeff;
    CO2[	701	]=	385.8840	/coeff;
    CO2[	702	]=	385.8330	/coeff;
    CO2[	703	]=	385.7830	/coeff;
    CO2[	704	]=	385.7330	/coeff;
    CO2[	705	]=	385.6830	/coeff;
    CO2[	706	]=	385.6330	/coeff;
    CO2[	707	]=	385.5840	/coeff;
    CO2[	708	]=	385.5340	/coeff;
    CO2[	709	]=	385.4840	/coeff;
    CO2[	710	]=	385.4350	/coeff;
    CO2[	711	]=	385.3860	/coeff;
    CO2[	712	]=	385.3360	/coeff;
    CO2[	713	]=	385.2870	/coeff;
    CO2[	714	]=	385.2380	/coeff;
    CO2[	715	]=	385.1890	/coeff;
    CO2[	716	]=	385.1400	/coeff;
    CO2[	717	]=	385.0920	/coeff;
    CO2[	718	]=	385.0430	/coeff;
    CO2[	719	]=	384.9950	/coeff;
    CO2[	720	]=	384.9460	/coeff;
    CO2[	721	]=	384.8980	/coeff;
    CO2[	722	]=	384.8490	/coeff;
    CO2[	723	]=	384.8010	/coeff;
    CO2[	724	]=	384.7530	/coeff;
    CO2[	725	]=	384.7050	/coeff;
    CO2[	726	]=	384.6570	/coeff;
    CO2[	727	]=	384.6100	/coeff;
    CO2[	728	]=	384.5620	/coeff;
    CO2[	729	]=	384.5140	/coeff;
    CO2[	730	]=	384.4670	/coeff;
    CO2[	731	]=	384.4190	/coeff;
    CO2[	732	]=	384.3720	/coeff;
    CO2[	733	]=	384.3250	/coeff;
    CO2[	734	]=	384.2780	/coeff;
    CO2[	735	]=	384.2540	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp245(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9491	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7620	/coeff;
    CO2[	253	]=	408.6320	/coeff;
    CO2[	254	]=	411.5060	/coeff;
    CO2[	255	]=	414.3900	/coeff;
    CO2[	256	]=	417.2870	/coeff;
    CO2[	257	]=	420.1980	/coeff;
    CO2[	258	]=	423.1250	/coeff;
    CO2[	259	]=	426.0690	/coeff;
    CO2[	260	]=	429.0300	/coeff;
    CO2[	261	]=	432.0110	/coeff;
    CO2[	262	]=	435.0120	/coeff;
    CO2[	263	]=	438.0330	/coeff;
    CO2[	264	]=	441.0770	/coeff;
    CO2[	265	]=	444.1430	/coeff;
    CO2[	266	]=	447.2320	/coeff;
    CO2[	267	]=	450.3330	/coeff;
    CO2[	268	]=	453.4350	/coeff;
    CO2[	269	]=	456.5410	/coeff;
    CO2[	270	]=	459.6520	/coeff;
    CO2[	271	]=	462.7700	/coeff;
    CO2[	272	]=	465.8970	/coeff;
    CO2[	273	]=	469.0330	/coeff;
    CO2[	274	]=	472.1790	/coeff;
    CO2[	275	]=	475.3360	/coeff;
    CO2[	276	]=	478.5040	/coeff;
    CO2[	277	]=	481.6740	/coeff;
    CO2[	278	]=	484.8380	/coeff;
    CO2[	279	]=	487.9960	/coeff;
    CO2[	280	]=	491.1500	/coeff;
    CO2[	281	]=	494.3000	/coeff;
    CO2[	282	]=	497.4470	/coeff;
    CO2[	283	]=	500.5920	/coeff;
    CO2[	284	]=	503.7340	/coeff;
    CO2[	285	]=	506.8750	/coeff;
    CO2[	286	]=	510.0140	/coeff;
    CO2[	287	]=	513.1370	/coeff;
    CO2[	288	]=	516.2300	/coeff;
    CO2[	289	]=	519.2920	/coeff;
    CO2[	290	]=	522.3260	/coeff;
    CO2[	291	]=	525.3320	/coeff;
    CO2[	292	]=	528.3100	/coeff;
    CO2[	293	]=	531.2610	/coeff;
    CO2[	294	]=	534.1860	/coeff;
    CO2[	295	]=	537.0850	/coeff;
    CO2[	296	]=	539.9580	/coeff;
    CO2[	297	]=	542.7950	/coeff;
    CO2[	298	]=	545.5869	/coeff;
    CO2[	299	]=	548.3350	/coeff;
    CO2[	300	]=	551.0390	/coeff;
    CO2[	301	]=	553.7000	/coeff;
    CO2[	302	]=	556.3190	/coeff;
    CO2[	303	]=	558.8950	/coeff;
    CO2[	304	]=	561.4310	/coeff;
    CO2[	305	]=	563.9250	/coeff;
    CO2[	306	]=	566.3800	/coeff;
    CO2[	307	]=	568.7720	/coeff;
    CO2[	308	]=	571.0830	/coeff;
    CO2[	309	]=	573.3140	/coeff;
    CO2[	310	]=	575.4660	/coeff;
    CO2[	311	]=	577.5400	/coeff;
    CO2[	312	]=	579.5370	/coeff;
    CO2[	313	]=	581.4580	/coeff;
    CO2[	314	]=	583.3040	/coeff;
    CO2[	315	]=	585.0740	/coeff;
    CO2[	316	]=	586.7700	/coeff;
    CO2[	317	]=	588.3780	/coeff;
    CO2[	318	]=	589.8860	/coeff;
    CO2[	319	]=	591.2960	/coeff;
    CO2[	320	]=	592.6090	/coeff;
    CO2[	321	]=	593.8250	/coeff;
    CO2[	322	]=	594.9450	/coeff;
    CO2[	323	]=	595.9700	/coeff;
    CO2[	324	]=	596.9000	/coeff;
    CO2[	325	]=	597.7350	/coeff;
    CO2[	326	]=	598.4770	/coeff;
    CO2[	327	]=	599.1500	/coeff;
    CO2[	328	]=	599.7760	/coeff;
    CO2[	329	]=	600.3550	/coeff;
    CO2[	330	]=	600.8860	/coeff;
    CO2[	331	]=	601.3660	/coeff;
    CO2[	332	]=	601.7970	/coeff;
    CO2[	333	]=	602.1770	/coeff;
    CO2[	334	]=	602.5050	/coeff;
    CO2[	335	]=	602.7820	/coeff;
    CO2[	336	]=	603.0050	/coeff;
    CO2[	337	]=	603.2180	/coeff;
    CO2[	338	]=	603.4590	/coeff;
    CO2[	339	]=	603.7240	/coeff;
    CO2[	340	]=	604.0120	/coeff;
    CO2[	341	]=	604.3220	/coeff;
    CO2[	342	]=	604.6500	/coeff;
    CO2[	343	]=	604.9960	/coeff;
    CO2[	344	]=	605.3570	/coeff;
    CO2[	345	]=	605.7340	/coeff;
    CO2[	346	]=	606.1240	/coeff;
    CO2[	347	]=	606.5270	/coeff;
    CO2[	348	]=	606.9420	/coeff;
    CO2[	349	]=	607.3670	/coeff;
    CO2[	350	]=	607.8030	/coeff;
    CO2[	351	]=	608.2480	/coeff;
    CO2[	352	]=	608.7010	/coeff;
    CO2[	353	]=	609.1630	/coeff;
    CO2[	354	]=	609.6330	/coeff;
    CO2[	355	]=	610.1100	/coeff;
    CO2[	356	]=	610.5930	/coeff;
    CO2[	357	]=	611.0820	/coeff;
    CO2[	358	]=	611.5780	/coeff;
    CO2[	359	]=	612.0790	/coeff;
    CO2[	360	]=	612.5850	/coeff;
    CO2[	361	]=	613.0950	/coeff;
    CO2[	362	]=	613.6110	/coeff;
    CO2[	363	]=	614.1300	/coeff;
    CO2[	364	]=	614.6540	/coeff;
    CO2[	365	]=	615.1810	/coeff;
    CO2[	366	]=	615.7120	/coeff;
    CO2[	367	]=	616.2460	/coeff;
    CO2[	368	]=	616.7840	/coeff;
    CO2[	369	]=	617.3240	/coeff;
    CO2[	370	]=	617.8670	/coeff;
    CO2[	371	]=	618.4130	/coeff;
    CO2[	372	]=	618.9610	/coeff;
    CO2[	373	]=	619.5120	/coeff;
    CO2[	374	]=	620.0640	/coeff;
    CO2[	375	]=	620.6190	/coeff;
    CO2[	376	]=	621.1760	/coeff;
    CO2[	377	]=	621.7340	/coeff;
    CO2[	378	]=	622.2950	/coeff;
    CO2[	379	]=	622.8570	/coeff;
    CO2[	380	]=	623.4200	/coeff;
    CO2[	381	]=	623.9850	/coeff;
    CO2[	382	]=	624.5510	/coeff;
    CO2[	383	]=	625.1190	/coeff;
    CO2[	384	]=	625.6870	/coeff;
    CO2[	385	]=	626.2570	/coeff;
    CO2[	386	]=	626.8280	/coeff;
    CO2[	387	]=	627.3940	/coeff;
    CO2[	388	]=	627.9490	/coeff;
    CO2[	389	]=	628.4940	/coeff;
    CO2[	390	]=	629.0270	/coeff;
    CO2[	391	]=	629.5510	/coeff;
    CO2[	392	]=	630.0640	/coeff;
    CO2[	393	]=	630.5670	/coeff;
    CO2[	394	]=	631.0610	/coeff;
    CO2[	395	]=	631.5440	/coeff;
    CO2[	396	]=	632.0170	/coeff;
    CO2[	397	]=	632.4810	/coeff;
    CO2[	398	]=	632.9340	/coeff;
    CO2[	399	]=	633.3780	/coeff;
    CO2[	400	]=	633.8130	/coeff;
    CO2[	401	]=	634.2380	/coeff;
    CO2[	402	]=	634.6530	/coeff;
    CO2[	403	]=	635.0590	/coeff;
    CO2[	404	]=	635.4550	/coeff;
    CO2[	405	]=	635.8420	/coeff;
    CO2[	406	]=	636.2190	/coeff;
    CO2[	407	]=	636.5870	/coeff;
    CO2[	408	]=	636.9450	/coeff;
    CO2[	409	]=	637.2940	/coeff;
    CO2[	410	]=	637.6340	/coeff;
    CO2[	411	]=	637.9640	/coeff;
    CO2[	412	]=	638.2850	/coeff;
    CO2[	413	]=	638.5970	/coeff;
    CO2[	414	]=	638.8990	/coeff;
    CO2[	415	]=	639.1920	/coeff;
    CO2[	416	]=	639.4750	/coeff;
    CO2[	417	]=	639.7500	/coeff;
    CO2[	418	]=	640.0150	/coeff;
    CO2[	419	]=	640.2700	/coeff;
    CO2[	420	]=	640.5170	/coeff;
    CO2[	421	]=	640.7540	/coeff;
    CO2[	422	]=	640.9820	/coeff;
    CO2[	423	]=	641.2000	/coeff;
    CO2[	424	]=	641.4100	/coeff;
    CO2[	425	]=	641.6100	/coeff;
    CO2[	426	]=	641.8010	/coeff;
    CO2[	427	]=	641.9820	/coeff;
    CO2[	428	]=	642.1550	/coeff;
    CO2[	429	]=	642.3180	/coeff;
    CO2[	430	]=	642.4720	/coeff;
    CO2[	431	]=	642.6170	/coeff;
    CO2[	432	]=	642.7520	/coeff;
    CO2[	433	]=	642.8790	/coeff;
    CO2[	434	]=	642.9960	/coeff;
    CO2[	435	]=	643.1040	/coeff;
    CO2[	436	]=	643.2030	/coeff;
    CO2[	437	]=	643.2920	/coeff;
    CO2[	438	]=	643.3730	/coeff;
    CO2[	439	]=	643.4440	/coeff;
    CO2[	440	]=	643.5060	/coeff;
    CO2[	441	]=	643.5590	/coeff;
    CO2[	442	]=	643.6030	/coeff;
    CO2[	443	]=	643.6380	/coeff;
    CO2[	444	]=	643.6630	/coeff;
    CO2[	445	]=	643.6800	/coeff;
    CO2[	446	]=	643.6870	/coeff;
    CO2[	447	]=	643.6860	/coeff;
    CO2[	448	]=	643.6750	/coeff;
    CO2[	449	]=	643.6550	/coeff;
    CO2[	450	]=	643.6260	/coeff;
    CO2[	451	]=	643.5880	/coeff;
    CO2[	452	]=	643.5400	/coeff;
    CO2[	453	]=	643.4840	/coeff;
    CO2[	454	]=	643.4190	/coeff;
    CO2[	455	]=	643.3450	/coeff;
    CO2[	456	]=	643.2610	/coeff;
    CO2[	457	]=	643.1690	/coeff;
    CO2[	458	]=	643.0670	/coeff;
    CO2[	459	]=	642.9570	/coeff;
    CO2[	460	]=	642.8380	/coeff;
    CO2[	461	]=	642.7090	/coeff;
    CO2[	462	]=	642.5720	/coeff;
    CO2[	463	]=	642.4250	/coeff;
    CO2[	464	]=	642.2700	/coeff;
    CO2[	465	]=	642.1060	/coeff;
    CO2[	466	]=	641.9330	/coeff;
    CO2[	467	]=	641.7500	/coeff;
    CO2[	468	]=	641.5590	/coeff;
    CO2[	469	]=	641.3590	/coeff;
    CO2[	470	]=	641.1500	/coeff;
    CO2[	471	]=	640.9320	/coeff;
    CO2[	472	]=	640.7060	/coeff;
    CO2[	473	]=	640.4700	/coeff;
    CO2[	474	]=	640.2260	/coeff;
    CO2[	475	]=	639.9730	/coeff;
    CO2[	476	]=	639.7110	/coeff;
    CO2[	477	]=	639.4400	/coeff;
    CO2[	478	]=	639.1600	/coeff;
    CO2[	479	]=	638.8720	/coeff;
    CO2[	480	]=	638.5740	/coeff;
    CO2[	481	]=	638.2680	/coeff;
    CO2[	482	]=	637.9540	/coeff;
    CO2[	483	]=	637.6300	/coeff;
    CO2[	484	]=	637.2980	/coeff;
    CO2[	485	]=	636.9570	/coeff;
    CO2[	486	]=	636.6070	/coeff;
    CO2[	487	]=	636.2550	/coeff;
    CO2[	488	]=	635.9070	/coeff;
    CO2[	489	]=	635.5600	/coeff;
    CO2[	490	]=	635.2160	/coeff;
    CO2[	491	]=	634.8730	/coeff;
    CO2[	492	]=	634.5320	/coeff;
    CO2[	493	]=	634.1930	/coeff;
    CO2[	494	]=	633.8550	/coeff;
    CO2[	495	]=	633.5180	/coeff;
    CO2[	496	]=	633.1830	/coeff;
    CO2[	497	]=	632.8490	/coeff;
    CO2[	498	]=	632.5170	/coeff;
    CO2[	499	]=	632.1860	/coeff;
    CO2[	500	]=	631.8570	/coeff;
    CO2[	501	]=	631.5290	/coeff;
    CO2[	502	]=	631.2030	/coeff;
    CO2[	503	]=	630.8790	/coeff;
    CO2[	504	]=	630.5560	/coeff;
    CO2[	505	]=	630.2340	/coeff;
    CO2[	506	]=	629.9150	/coeff;
    CO2[	507	]=	629.5970	/coeff;
    CO2[	508	]=	629.2800	/coeff;
    CO2[	509	]=	628.9660	/coeff;
    CO2[	510	]=	628.6530	/coeff;
    CO2[	511	]=	628.3410	/coeff;
    CO2[	512	]=	628.0310	/coeff;
    CO2[	513	]=	627.7230	/coeff;
    CO2[	514	]=	627.4170	/coeff;
    CO2[	515	]=	627.1120	/coeff;
    CO2[	516	]=	626.8080	/coeff;
    CO2[	517	]=	626.5060	/coeff;
    CO2[	518	]=	626.2060	/coeff;
    CO2[	519	]=	625.9070	/coeff;
    CO2[	520	]=	625.6100	/coeff;
    CO2[	521	]=	625.3140	/coeff;
    CO2[	522	]=	625.0200	/coeff;
    CO2[	523	]=	624.7270	/coeff;
    CO2[	524	]=	624.4360	/coeff;
    CO2[	525	]=	624.1460	/coeff;
    CO2[	526	]=	623.8570	/coeff;
    CO2[	527	]=	623.5700	/coeff;
    CO2[	528	]=	623.2840	/coeff;
    CO2[	529	]=	622.9990	/coeff;
    CO2[	530	]=	622.7160	/coeff;
    CO2[	531	]=	622.4340	/coeff;
    CO2[	532	]=	622.1530	/coeff;
    CO2[	533	]=	621.8730	/coeff;
    CO2[	534	]=	621.5950	/coeff;
    CO2[	535	]=	621.3180	/coeff;
    CO2[	536	]=	621.0420	/coeff;
    CO2[	537	]=	620.7670	/coeff;
    CO2[	538	]=	620.4940	/coeff;
    CO2[	539	]=	620.2210	/coeff;
    CO2[	540	]=	619.9500	/coeff;
    CO2[	541	]=	619.6800	/coeff;
    CO2[	542	]=	619.4100	/coeff;
    CO2[	543	]=	619.1420	/coeff;
    CO2[	544	]=	618.8750	/coeff;
    CO2[	545	]=	618.6090	/coeff;
    CO2[	546	]=	618.3450	/coeff;
    CO2[	547	]=	618.0810	/coeff;
    CO2[	548	]=	617.8180	/coeff;
    CO2[	549	]=	617.5560	/coeff;
    CO2[	550	]=	617.2950	/coeff;
    CO2[	551	]=	617.0350	/coeff;
    CO2[	552	]=	616.7760	/coeff;
    CO2[	553	]=	616.5180	/coeff;
    CO2[	554	]=	616.2610	/coeff;
    CO2[	555	]=	616.0040	/coeff;
    CO2[	556	]=	615.7490	/coeff;
    CO2[	557	]=	615.4950	/coeff;
    CO2[	558	]=	615.2410	/coeff;
    CO2[	559	]=	614.9880	/coeff;
    CO2[	560	]=	614.7360	/coeff;
    CO2[	561	]=	614.4850	/coeff;
    CO2[	562	]=	614.2350	/coeff;
    CO2[	563	]=	613.9860	/coeff;
    CO2[	564	]=	613.7370	/coeff;
    CO2[	565	]=	613.4900	/coeff;
    CO2[	566	]=	613.2430	/coeff;
    CO2[	567	]=	612.9970	/coeff;
    CO2[	568	]=	612.7520	/coeff;
    CO2[	569	]=	612.5070	/coeff;
    CO2[	570	]=	612.2630	/coeff;
    CO2[	571	]=	612.0200	/coeff;
    CO2[	572	]=	611.7780	/coeff;
    CO2[	573	]=	611.5370	/coeff;
    CO2[	574	]=	611.2960	/coeff;
    CO2[	575	]=	611.0560	/coeff;
    CO2[	576	]=	610.8160	/coeff;
    CO2[	577	]=	610.5780	/coeff;
    CO2[	578	]=	610.3400	/coeff;
    CO2[	579	]=	610.1030	/coeff;
    CO2[	580	]=	609.8660	/coeff;
    CO2[	581	]=	609.6300	/coeff;
    CO2[	582	]=	609.3950	/coeff;
    CO2[	583	]=	609.1610	/coeff;
    CO2[	584	]=	608.9270	/coeff;
    CO2[	585	]=	608.6940	/coeff;
    CO2[	586	]=	608.4620	/coeff;
    CO2[	587	]=	608.2300	/coeff;
    CO2[	588	]=	607.9990	/coeff;
    CO2[	589	]=	607.7680	/coeff;
    CO2[	590	]=	607.5380	/coeff;
    CO2[	591	]=	607.3090	/coeff;
    CO2[	592	]=	607.0800	/coeff;
    CO2[	593	]=	606.8520	/coeff;
    CO2[	594	]=	606.6250	/coeff;
    CO2[	595	]=	606.3980	/coeff;
    CO2[	596	]=	606.1710	/coeff;
    CO2[	597	]=	605.9460	/coeff;
    CO2[	598	]=	605.7210	/coeff;
    CO2[	599	]=	605.4960	/coeff;
    CO2[	600	]=	605.2720	/coeff;
    CO2[	601	]=	605.0490	/coeff;
    CO2[	602	]=	604.8260	/coeff;
    CO2[	603	]=	604.6040	/coeff;
    CO2[	604	]=	604.3820	/coeff;
    CO2[	605	]=	604.1610	/coeff;
    CO2[	606	]=	603.9410	/coeff;
    CO2[	607	]=	603.7210	/coeff;
    CO2[	608	]=	603.5010	/coeff;
    CO2[	609	]=	603.2820	/coeff;
    CO2[	610	]=	603.0640	/coeff;
    CO2[	611	]=	602.8460	/coeff;
    CO2[	612	]=	602.6280	/coeff;
    CO2[	613	]=	602.4110	/coeff;
    CO2[	614	]=	602.1950	/coeff;
    CO2[	615	]=	601.9790	/coeff;
    CO2[	616	]=	601.7640	/coeff;
    CO2[	617	]=	601.5490	/coeff;
    CO2[	618	]=	601.3340	/coeff;
    CO2[	619	]=	601.1200	/coeff;
    CO2[	620	]=	600.9070	/coeff;
    CO2[	621	]=	600.6940	/coeff;
    CO2[	622	]=	600.4820	/coeff;
    CO2[	623	]=	600.2700	/coeff;
    CO2[	624	]=	600.0580	/coeff;
    CO2[	625	]=	599.8470	/coeff;
    CO2[	626	]=	599.6360	/coeff;
    CO2[	627	]=	599.4260	/coeff;
    CO2[	628	]=	599.2160	/coeff;
    CO2[	629	]=	599.0070	/coeff;
    CO2[	630	]=	598.7980	/coeff;
    CO2[	631	]=	598.5900	/coeff;
    CO2[	632	]=	598.3820	/coeff;
    CO2[	633	]=	598.1740	/coeff;
    CO2[	634	]=	597.9670	/coeff;
    CO2[	635	]=	597.7600	/coeff;
    CO2[	636	]=	597.5540	/coeff;
    CO2[	637	]=	597.3480	/coeff;
    CO2[	638	]=	597.1420	/coeff;
    CO2[	639	]=	596.9370	/coeff;
    CO2[	640	]=	596.7320	/coeff;
    CO2[	641	]=	596.5280	/coeff;
    CO2[	642	]=	596.3240	/coeff;
    CO2[	643	]=	596.1210	/coeff;
    CO2[	644	]=	595.9170	/coeff;
    CO2[	645	]=	595.7150	/coeff;
    CO2[	646	]=	595.5120	/coeff;
    CO2[	647	]=	595.3100	/coeff;
    CO2[	648	]=	595.1080	/coeff;
    CO2[	649	]=	594.9070	/coeff;
    CO2[	650	]=	594.7060	/coeff;
    CO2[	651	]=	594.5050	/coeff;
    CO2[	652	]=	594.3050	/coeff;
    CO2[	653	]=	594.1050	/coeff;
    CO2[	654	]=	593.9050	/coeff;
    CO2[	655	]=	593.7060	/coeff;
    CO2[	656	]=	593.5070	/coeff;
    CO2[	657	]=	593.3080	/coeff;
    CO2[	658	]=	593.1090	/coeff;
    CO2[	659	]=	592.9110	/coeff;
    CO2[	660	]=	592.7140	/coeff;
    CO2[	661	]=	592.5160	/coeff;
    CO2[	662	]=	592.3200	/coeff;
    CO2[	663	]=	592.1240	/coeff;
    CO2[	664	]=	591.9280	/coeff;
    CO2[	665	]=	591.7320	/coeff;
    CO2[	666	]=	591.5380	/coeff;
    CO2[	667	]=	591.3430	/coeff;
    CO2[	668	]=	591.1490	/coeff;
    CO2[	669	]=	590.9560	/coeff;
    CO2[	670	]=	590.7630	/coeff;
    CO2[	671	]=	590.5700	/coeff;
    CO2[	672	]=	590.3780	/coeff;
    CO2[	673	]=	590.1870	/coeff;
    CO2[	674	]=	589.9950	/coeff;
    CO2[	675	]=	589.8050	/coeff;
    CO2[	676	]=	589.6140	/coeff;
    CO2[	677	]=	589.4250	/coeff;
    CO2[	678	]=	589.2350	/coeff;
    CO2[	679	]=	589.0460	/coeff;
    CO2[	680	]=	588.8580	/coeff;
    CO2[	681	]=	588.6690	/coeff;
    CO2[	682	]=	588.4820	/coeff;
    CO2[	683	]=	588.2940	/coeff;
    CO2[	684	]=	588.1080	/coeff;
    CO2[	685	]=	587.9210	/coeff;
    CO2[	686	]=	587.7350	/coeff;
    CO2[	687	]=	587.5500	/coeff;
    CO2[	688	]=	587.3640	/coeff;
    CO2[	689	]=	587.1800	/coeff;
    CO2[	690	]=	586.9950	/coeff;
    CO2[	691	]=	586.8110	/coeff;
    CO2[	692	]=	586.6280	/coeff;
    CO2[	693	]=	586.4450	/coeff;
    CO2[	694	]=	586.2620	/coeff;
    CO2[	695	]=	586.0800	/coeff;
    CO2[	696	]=	585.8980	/coeff;
    CO2[	697	]=	585.7160	/coeff;
    CO2[	698	]=	585.5350	/coeff;
    CO2[	699	]=	585.3540	/coeff;
    CO2[	700	]=	585.1740	/coeff;
    CO2[	701	]=	584.9940	/coeff;
    CO2[	702	]=	584.8140	/coeff;
    CO2[	703	]=	584.6350	/coeff;
    CO2[	704	]=	584.4560	/coeff;
    CO2[	705	]=	584.2780	/coeff;
    CO2[	706	]=	584.1000	/coeff;
    CO2[	707	]=	583.9220	/coeff;
    CO2[	708	]=	583.7450	/coeff;
    CO2[	709	]=	583.5680	/coeff;
    CO2[	710	]=	583.3910	/coeff;
    CO2[	711	]=	583.2150	/coeff;
    CO2[	712	]=	583.0400	/coeff;
    CO2[	713	]=	582.8640	/coeff;
    CO2[	714	]=	582.6890	/coeff;
    CO2[	715	]=	582.5140	/coeff;
    CO2[	716	]=	582.3400	/coeff;
    CO2[	717	]=	582.1660	/coeff;
    CO2[	718	]=	581.9930	/coeff;
    CO2[	719	]=	581.8190	/coeff;
    CO2[	720	]=	581.6470	/coeff;
    CO2[	721	]=	581.4740	/coeff;
    CO2[	722	]=	581.3020	/coeff;
    CO2[	723	]=	581.1300	/coeff;
    CO2[	724	]=	580.9590	/coeff;
    CO2[	725	]=	580.7880	/coeff;
    CO2[	726	]=	580.6170	/coeff;
    CO2[	727	]=	580.4470	/coeff;
    CO2[	728	]=	580.2770	/coeff;
    CO2[	729	]=	580.1070	/coeff;
    CO2[	730	]=	579.9380	/coeff;
    CO2[	731	]=	579.7690	/coeff;
    CO2[	732	]=	579.6000	/coeff;
    CO2[	733	]=	579.4320	/coeff;
    CO2[	734	]=	579.2640	/coeff;
    CO2[	735	]=	579.1800	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp370(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9484	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.8130	/coeff;
    CO2[	253	]=	408.8320	/coeff;
    CO2[	254	]=	411.9460	/coeff;
    CO2[	255	]=	415.1550	/coeff;
    CO2[	256	]=	418.4610	/coeff;
    CO2[	257	]=	421.8430	/coeff;
    CO2[	258	]=	425.2830	/coeff;
    CO2[	259	]=	428.7840	/coeff;
    CO2[	260	]=	432.3470	/coeff;
    CO2[	261	]=	435.9750	/coeff;
    CO2[	262	]=	439.6699	/coeff;
    CO2[	263	]=	443.4320	/coeff;
    CO2[	264	]=	447.2629	/coeff;
    CO2[	265	]=	451.1640	/coeff;
    CO2[	266	]=	455.1360	/coeff;
    CO2[	267	]=	459.1659	/coeff;
    CO2[	268	]=	463.2419	/coeff;
    CO2[	269	]=	467.3649	/coeff;
    CO2[	270	]=	471.5389	/coeff;
    CO2[	271	]=	475.7649	/coeff;
    CO2[	272	]=	480.0449	/coeff;
    CO2[	273	]=	484.3799	/coeff;
    CO2[	274	]=	488.7719	/coeff;
    CO2[	275	]=	493.2209	/coeff;
    CO2[	276	]=	497.7309	/coeff;
    CO2[	277	]=	502.2919	/coeff;
    CO2[	278	]=	506.9009	/coeff;
    CO2[	279	]=	511.5569	/coeff;
    CO2[	280	]=	516.2639	/coeff;
    CO2[	281	]=	521.0209	/coeff;
    CO2[	282	]=	525.8299	/coeff;
    CO2[	283	]=	530.6919	/coeff;
    CO2[	284	]=	535.6089	/coeff;
    CO2[	285	]=	540.5809	/coeff;
    CO2[	286	]=	545.6099	/coeff;
    CO2[	287	]=	550.6909	/coeff;
    CO2[	288	]=	555.8219	/coeff;
    CO2[	289	]=	561.0039	/coeff;
    CO2[	290	]=	566.2389	/coeff;
    CO2[	291	]=	571.5259	/coeff;
    CO2[	292	]=	576.8679	/coeff;
    CO2[	293	]=	582.2659	/coeff;
    CO2[	294	]=	587.7189	/coeff;
    CO2[	295	]=	593.2299	/coeff;
    CO2[	296	]=	598.7979	/coeff;
    CO2[	297	]=	604.4239	/coeff;
    CO2[	298	]=	610.1069	/coeff;
    CO2[	299	]=	615.8469	/coeff;
    CO2[	300	]=	621.6469	/coeff;
    CO2[	301	]=	627.5049	/coeff;
    CO2[	302	]=	633.4229	/coeff;
    CO2[	303	]=	639.4019	/coeff;
    CO2[	304	]=	645.4419	/coeff;
    CO2[	305	]=	651.5439	/coeff;
    CO2[	306	]=	657.7079	/coeff;
    CO2[	307	]=	663.9339	/coeff;
    CO2[	308	]=	670.2219	/coeff;
    CO2[	309	]=	676.5719	/coeff;
    CO2[	310	]=	682.9849	/coeff;
    CO2[	311	]=	689.4609	/coeff;
    CO2[	312	]=	696.0019	/coeff;
    CO2[	313	]=	702.6059	/coeff;
    CO2[	314	]=	709.2749	/coeff;
    CO2[	315	]=	716.0079	/coeff;
    CO2[	316	]=	722.8079	/coeff;
    CO2[	317	]=	729.6789	/coeff;
    CO2[	318	]=	736.6289	/coeff;
    CO2[	319	]=	743.6569	/coeff;
    CO2[	320	]=	750.7639	/coeff;
    CO2[	321	]=	757.9509	/coeff;
    CO2[	322	]=	765.2159	/coeff;
    CO2[	323	]=	772.5609	/coeff;
    CO2[	324	]=	779.9839	/coeff;
    CO2[	325	]=	787.4879	/coeff;
    CO2[	326	]=	795.0699	/coeff;
    CO2[	327	]=	802.7359	/coeff;
    CO2[	328	]=	810.4889	/coeff;
    CO2[	329	]=	818.3279	/coeff;
    CO2[	330	]=	826.2539	/coeff;
    CO2[	331	]=	834.2669	/coeff;
    CO2[	332	]=	842.3669	/coeff;
    CO2[	333	]=	850.5539	/coeff;
    CO2[	334	]=	858.8289	/coeff;
    CO2[	335	]=	867.1909	/coeff;
    CO2[	336	]=	875.6399	/coeff;
    CO2[	337	]=	884.1099	/coeff;
    CO2[	338	]=	892.5329	/coeff;
    CO2[	339	]=	900.9109	/coeff;
    CO2[	340	]=	909.2469	/coeff;
    CO2[	341	]=	917.5409	/coeff;
    CO2[	342	]=	925.7929	/coeff;
    CO2[	343	]=	934.0049	/coeff;
    CO2[	344	]=	942.1769	/coeff;
    CO2[	345	]=	950.3079	/coeff;
    CO2[	346	]=	958.3969	/coeff;
    CO2[	347	]=	966.4449	/coeff;
    CO2[	348	]=	974.4519	/coeff;
    CO2[	349	]=	982.4159	/coeff;
    CO2[	350	]=	990.3369	/coeff;
    CO2[	351	]=	998.2139	/coeff;
    CO2[	352	]=	1006.0499	/coeff;
    CO2[	353	]=	1013.8399	/coeff;
    CO2[	354	]=	1021.5799	/coeff;
    CO2[	355	]=	1029.2699	/coeff;
    CO2[	356	]=	1036.9199	/coeff;
    CO2[	357	]=	1044.5199	/coeff;
    CO2[	358	]=	1052.0799	/coeff;
    CO2[	359	]=	1059.5799	/coeff;
    CO2[	360	]=	1067.0299	/coeff;
    CO2[	361	]=	1074.4399	/coeff;
    CO2[	362	]=	1081.7899	/coeff;
    CO2[	363	]=	1089.0899	/coeff;
    CO2[	364	]=	1096.3299	/coeff;
    CO2[	365	]=	1103.5299	/coeff;
    CO2[	366	]=	1110.6699	/coeff;
    CO2[	367	]=	1117.7499	/coeff;
    CO2[	368	]=	1124.7799	/coeff;
    CO2[	369	]=	1131.7599	/coeff;
    CO2[	370	]=	1138.6699	/coeff;
    CO2[	371	]=	1145.5299	/coeff;
    CO2[	372	]=	1152.3399	/coeff;
    CO2[	373	]=	1159.0799	/coeff;
    CO2[	374	]=	1165.7699	/coeff;
    CO2[	375	]=	1172.3999	/coeff;
    CO2[	376	]=	1178.9599	/coeff;
    CO2[	377	]=	1185.4699	/coeff;
    CO2[	378	]=	1191.9200	/coeff;
    CO2[	379	]=	1198.3099	/coeff;
    CO2[	380	]=	1204.6300	/coeff;
    CO2[	381	]=	1210.8900	/coeff;
    CO2[	382	]=	1217.0900	/coeff;
    CO2[	383	]=	1223.2299	/coeff;
    CO2[	384	]=	1229.2999	/coeff;
    CO2[	385	]=	1235.3200	/coeff;
    CO2[	386	]=	1241.2599	/coeff;
    CO2[	387	]=	1247.1499	/coeff;
    CO2[	388	]=	1252.9699	/coeff;
    CO2[	389	]=	1258.7400	/coeff;
    CO2[	390	]=	1264.4500	/coeff;
    CO2[	391	]=	1270.0999	/coeff;
    CO2[	392	]=	1275.7000	/coeff;
    CO2[	393	]=	1281.2300	/coeff;
    CO2[	394	]=	1286.7000	/coeff;
    CO2[	395	]=	1292.1100	/coeff;
    CO2[	396	]=	1297.4699	/coeff;
    CO2[	397	]=	1302.7599	/coeff;
    CO2[	398	]=	1307.9900	/coeff;
    CO2[	399	]=	1313.1600	/coeff;
    CO2[	400	]=	1318.2600	/coeff;
    CO2[	401	]=	1323.3099	/coeff;
    CO2[	402	]=	1328.2899	/coeff;
    CO2[	403	]=	1333.2100	/coeff;
    CO2[	404	]=	1338.0699	/coeff;
    CO2[	405	]=	1342.8700	/coeff;
    CO2[	406	]=	1347.6000	/coeff;
    CO2[	407	]=	1352.2700	/coeff;
    CO2[	408	]=	1356.8800	/coeff;
    CO2[	409	]=	1361.4200	/coeff;
    CO2[	410	]=	1365.9000	/coeff;
    CO2[	411	]=	1370.3200	/coeff;
    CO2[	412	]=	1374.6700	/coeff;
    CO2[	413	]=	1378.9600	/coeff;
    CO2[	414	]=	1383.1800	/coeff;
    CO2[	415	]=	1387.3400	/coeff;
    CO2[	416	]=	1391.4400	/coeff;
    CO2[	417	]=	1395.4700	/coeff;
    CO2[	418	]=	1399.4300	/coeff;
    CO2[	419	]=	1403.3300	/coeff;
    CO2[	420	]=	1407.1600	/coeff;
    CO2[	421	]=	1410.9300	/coeff;
    CO2[	422	]=	1414.6400	/coeff;
    CO2[	423	]=	1418.2700	/coeff;
    CO2[	424	]=	1421.8500	/coeff;
    CO2[	425	]=	1425.3500	/coeff;
    CO2[	426	]=	1428.8000	/coeff;
    CO2[	427	]=	1432.1700	/coeff;
    CO2[	428	]=	1435.4800	/coeff;
    CO2[	429	]=	1438.7200	/coeff;
    CO2[	430	]=	1441.9000	/coeff;
    CO2[	431	]=	1445.0100	/coeff;
    CO2[	432	]=	1448.0500	/coeff;
    CO2[	433	]=	1451.0300	/coeff;
    CO2[	434	]=	1453.9400	/coeff;
    CO2[	435	]=	1456.7900	/coeff;
    CO2[	436	]=	1459.5700	/coeff;
    CO2[	437	]=	1462.2800	/coeff;
    CO2[	438	]=	1464.9200	/coeff;
    CO2[	439	]=	1467.5000	/coeff;
    CO2[	440	]=	1470.0100	/coeff;
    CO2[	441	]=	1472.4600	/coeff;
    CO2[	442	]=	1474.8300	/coeff;
    CO2[	443	]=	1477.1400	/coeff;
    CO2[	444	]=	1479.3900	/coeff;
    CO2[	445	]=	1481.5600	/coeff;
    CO2[	446	]=	1483.6700	/coeff;
    CO2[	447	]=	1485.7200	/coeff;
    CO2[	448	]=	1487.6900	/coeff;
    CO2[	449	]=	1489.6000	/coeff;
    CO2[	450	]=	1491.4400	/coeff;
    CO2[	451	]=	1493.2200	/coeff;
    CO2[	452	]=	1494.9200	/coeff;
    CO2[	453	]=	1496.5600	/coeff;
    CO2[	454	]=	1498.1400	/coeff;
    CO2[	455	]=	1499.6400	/coeff;
    CO2[	456	]=	1501.0800	/coeff;
    CO2[	457	]=	1502.4500	/coeff;
    CO2[	458	]=	1503.7600	/coeff;
    CO2[	459	]=	1504.9900	/coeff;
    CO2[	460	]=	1506.1600	/coeff;
    CO2[	461	]=	1507.2600	/coeff;
    CO2[	462	]=	1508.3000	/coeff;
    CO2[	463	]=	1509.2700	/coeff;
    CO2[	464	]=	1510.1700	/coeff;
    CO2[	465	]=	1511.0000	/coeff;
    CO2[	466	]=	1511.7700	/coeff;
    CO2[	467	]=	1512.4700	/coeff;
    CO2[	468	]=	1513.1000	/coeff;
    CO2[	469	]=	1513.6700	/coeff;
    CO2[	470	]=	1514.1700	/coeff;
    CO2[	471	]=	1514.6000	/coeff;
    CO2[	472	]=	1514.9700	/coeff;
    CO2[	473	]=	1515.2700	/coeff;
    CO2[	474	]=	1515.5000	/coeff;
    CO2[	475	]=	1515.6600	/coeff;
    CO2[	476	]=	1515.7600	/coeff;
    CO2[	477	]=	1515.7900	/coeff;
    CO2[	478	]=	1515.7600	/coeff;
    CO2[	479	]=	1515.6600	/coeff;
    CO2[	480	]=	1515.4900	/coeff;
    CO2[	481	]=	1515.2500	/coeff;
    CO2[	482	]=	1514.9500	/coeff;
    CO2[	483	]=	1514.5800	/coeff;
    CO2[	484	]=	1514.1500	/coeff;
    CO2[	485	]=	1513.6500	/coeff;
    CO2[	486	]=	1513.0800	/coeff;
    CO2[	487	]=	1512.4800	/coeff;
    CO2[	488	]=	1511.8900	/coeff;
    CO2[	489	]=	1511.2900	/coeff;
    CO2[	490	]=	1510.6900	/coeff;
    CO2[	491	]=	1510.1000	/coeff;
    CO2[	492	]=	1509.5000	/coeff;
    CO2[	493	]=	1508.8900	/coeff;
    CO2[	494	]=	1508.2900	/coeff;
    CO2[	495	]=	1507.6800	/coeff;
    CO2[	496	]=	1507.0800	/coeff;
    CO2[	497	]=	1506.4700	/coeff;
    CO2[	498	]=	1505.8600	/coeff;
    CO2[	499	]=	1505.2400	/coeff;
    CO2[	500	]=	1504.6300	/coeff;
    CO2[	501	]=	1504.0100	/coeff;
    CO2[	502	]=	1503.3900	/coeff;
    CO2[	503	]=	1502.7700	/coeff;
    CO2[	504	]=	1502.1500	/coeff;
    CO2[	505	]=	1501.5300	/coeff;
    CO2[	506	]=	1500.9000	/coeff;
    CO2[	507	]=	1500.2800	/coeff;
    CO2[	508	]=	1499.6600	/coeff;
    CO2[	509	]=	1499.0300	/coeff;
    CO2[	510	]=	1498.4000	/coeff;
    CO2[	511	]=	1497.7800	/coeff;
    CO2[	512	]=	1497.1500	/coeff;
    CO2[	513	]=	1496.5200	/coeff;
    CO2[	514	]=	1495.8900	/coeff;
    CO2[	515	]=	1495.2700	/coeff;
    CO2[	516	]=	1494.6400	/coeff;
    CO2[	517	]=	1494.0100	/coeff;
    CO2[	518	]=	1493.3800	/coeff;
    CO2[	519	]=	1492.7500	/coeff;
    CO2[	520	]=	1492.1200	/coeff;
    CO2[	521	]=	1491.5000	/coeff;
    CO2[	522	]=	1490.8700	/coeff;
    CO2[	523	]=	1490.2400	/coeff;
    CO2[	524	]=	1489.6200	/coeff;
    CO2[	525	]=	1488.9900	/coeff;
    CO2[	526	]=	1488.3600	/coeff;
    CO2[	527	]=	1487.7400	/coeff;
    CO2[	528	]=	1487.1100	/coeff;
    CO2[	529	]=	1486.4900	/coeff;
    CO2[	530	]=	1485.8600	/coeff;
    CO2[	531	]=	1485.2400	/coeff;
    CO2[	532	]=	1484.6100	/coeff;
    CO2[	533	]=	1483.9900	/coeff;
    CO2[	534	]=	1483.3700	/coeff;
    CO2[	535	]=	1482.7500	/coeff;
    CO2[	536	]=	1482.1200	/coeff;
    CO2[	537	]=	1481.5000	/coeff;
    CO2[	538	]=	1480.8800	/coeff;
    CO2[	539	]=	1480.2600	/coeff;
    CO2[	540	]=	1479.6400	/coeff;
    CO2[	541	]=	1479.0200	/coeff;
    CO2[	542	]=	1478.4000	/coeff;
    CO2[	543	]=	1477.7900	/coeff;
    CO2[	544	]=	1477.1700	/coeff;
    CO2[	545	]=	1476.5500	/coeff;
    CO2[	546	]=	1475.9400	/coeff;
    CO2[	547	]=	1475.3200	/coeff;
    CO2[	548	]=	1474.7100	/coeff;
    CO2[	549	]=	1474.0900	/coeff;
    CO2[	550	]=	1473.4800	/coeff;
    CO2[	551	]=	1472.8700	/coeff;
    CO2[	552	]=	1472.2500	/coeff;
    CO2[	553	]=	1471.6400	/coeff;
    CO2[	554	]=	1471.0300	/coeff;
    CO2[	555	]=	1470.4200	/coeff;
    CO2[	556	]=	1469.8100	/coeff;
    CO2[	557	]=	1469.2000	/coeff;
    CO2[	558	]=	1468.5900	/coeff;
    CO2[	559	]=	1467.9800	/coeff;
    CO2[	560	]=	1467.3800	/coeff;
    CO2[	561	]=	1466.7700	/coeff;
    CO2[	562	]=	1466.1600	/coeff;
    CO2[	563	]=	1465.5600	/coeff;
    CO2[	564	]=	1464.9500	/coeff;
    CO2[	565	]=	1464.3500	/coeff;
    CO2[	566	]=	1463.7400	/coeff;
    CO2[	567	]=	1463.1400	/coeff;
    CO2[	568	]=	1462.5400	/coeff;
    CO2[	569	]=	1461.9300	/coeff;
    CO2[	570	]=	1461.3300	/coeff;
    CO2[	571	]=	1460.7300	/coeff;
    CO2[	572	]=	1460.1300	/coeff;
    CO2[	573	]=	1459.5300	/coeff;
    CO2[	574	]=	1458.9300	/coeff;
    CO2[	575	]=	1458.3400	/coeff;
    CO2[	576	]=	1457.7400	/coeff;
    CO2[	577	]=	1457.1400	/coeff;
    CO2[	578	]=	1456.5400	/coeff;
    CO2[	579	]=	1455.9500	/coeff;
    CO2[	580	]=	1455.3500	/coeff;
    CO2[	581	]=	1454.7600	/coeff;
    CO2[	582	]=	1454.1600	/coeff;
    CO2[	583	]=	1453.5700	/coeff;
    CO2[	584	]=	1452.9800	/coeff;
    CO2[	585	]=	1452.3900	/coeff;
    CO2[	586	]=	1451.7900	/coeff;
    CO2[	587	]=	1451.2000	/coeff;
    CO2[	588	]=	1450.6100	/coeff;
    CO2[	589	]=	1450.0200	/coeff;
    CO2[	590	]=	1449.4300	/coeff;
    CO2[	591	]=	1448.8500	/coeff;
    CO2[	592	]=	1448.2600	/coeff;
    CO2[	593	]=	1447.6700	/coeff;
    CO2[	594	]=	1447.0900	/coeff;
    CO2[	595	]=	1446.5000	/coeff;
    CO2[	596	]=	1445.9100	/coeff;
    CO2[	597	]=	1445.3300	/coeff;
    CO2[	598	]=	1444.7500	/coeff;
    CO2[	599	]=	1444.1600	/coeff;
    CO2[	600	]=	1443.5800	/coeff;
    CO2[	601	]=	1443.0000	/coeff;
    CO2[	602	]=	1442.4200	/coeff;
    CO2[	603	]=	1441.8400	/coeff;
    CO2[	604	]=	1441.2600	/coeff;
    CO2[	605	]=	1440.6800	/coeff;
    CO2[	606	]=	1440.1000	/coeff;
    CO2[	607	]=	1439.5200	/coeff;
    CO2[	608	]=	1438.9400	/coeff;
    CO2[	609	]=	1438.3700	/coeff;
    CO2[	610	]=	1437.7900	/coeff;
    CO2[	611	]=	1437.2100	/coeff;
    CO2[	612	]=	1436.6400	/coeff;
    CO2[	613	]=	1436.0600	/coeff;
    CO2[	614	]=	1435.4900	/coeff;
    CO2[	615	]=	1434.9200	/coeff;
    CO2[	616	]=	1434.3500	/coeff;
    CO2[	617	]=	1433.7700	/coeff;
    CO2[	618	]=	1433.2000	/coeff;
    CO2[	619	]=	1432.6300	/coeff;
    CO2[	620	]=	1432.0600	/coeff;
    CO2[	621	]=	1431.4900	/coeff;
    CO2[	622	]=	1430.9200	/coeff;
    CO2[	623	]=	1430.3600	/coeff;
    CO2[	624	]=	1429.7900	/coeff;
    CO2[	625	]=	1429.2200	/coeff;
    CO2[	626	]=	1428.6600	/coeff;
    CO2[	627	]=	1428.0900	/coeff;
    CO2[	628	]=	1427.5300	/coeff;
    CO2[	629	]=	1426.9600	/coeff;
    CO2[	630	]=	1426.4000	/coeff;
    CO2[	631	]=	1425.8400	/coeff;
    CO2[	632	]=	1425.2800	/coeff;
    CO2[	633	]=	1424.7100	/coeff;
    CO2[	634	]=	1424.1500	/coeff;
    CO2[	635	]=	1423.5900	/coeff;
    CO2[	636	]=	1423.0300	/coeff;
    CO2[	637	]=	1422.4800	/coeff;
    CO2[	638	]=	1421.9200	/coeff;
    CO2[	639	]=	1421.3600	/coeff;
    CO2[	640	]=	1420.8000	/coeff;
    CO2[	641	]=	1420.2500	/coeff;
    CO2[	642	]=	1419.6900	/coeff;
    CO2[	643	]=	1419.1400	/coeff;
    CO2[	644	]=	1418.5800	/coeff;
    CO2[	645	]=	1418.0300	/coeff;
    CO2[	646	]=	1417.4800	/coeff;
    CO2[	647	]=	1416.9200	/coeff;
    CO2[	648	]=	1416.3700	/coeff;
    CO2[	649	]=	1415.8200	/coeff;
    CO2[	650	]=	1415.2700	/coeff;
    CO2[	651	]=	1414.7200	/coeff;
    CO2[	652	]=	1414.1700	/coeff;
    CO2[	653	]=	1413.6300	/coeff;
    CO2[	654	]=	1413.0800	/coeff;
    CO2[	655	]=	1412.5300	/coeff;
    CO2[	656	]=	1411.9800	/coeff;
    CO2[	657	]=	1411.4400	/coeff;
    CO2[	658	]=	1410.8900	/coeff;
    CO2[	659	]=	1410.3500	/coeff;
    CO2[	660	]=	1409.8100	/coeff;
    CO2[	661	]=	1409.2600	/coeff;
    CO2[	662	]=	1408.7200	/coeff;
    CO2[	663	]=	1408.1800	/coeff;
    CO2[	664	]=	1407.6400	/coeff;
    CO2[	665	]=	1407.1000	/coeff;
    CO2[	666	]=	1406.5600	/coeff;
    CO2[	667	]=	1406.0200	/coeff;
    CO2[	668	]=	1405.4800	/coeff;
    CO2[	669	]=	1404.9400	/coeff;
    CO2[	670	]=	1404.4100	/coeff;
    CO2[	671	]=	1403.8700	/coeff;
    CO2[	672	]=	1403.3300	/coeff;
    CO2[	673	]=	1402.8000	/coeff;
    CO2[	674	]=	1402.2600	/coeff;
    CO2[	675	]=	1401.7300	/coeff;
    CO2[	676	]=	1401.2000	/coeff;
    CO2[	677	]=	1400.6600	/coeff;
    CO2[	678	]=	1400.1300	/coeff;
    CO2[	679	]=	1399.6000	/coeff;
    CO2[	680	]=	1399.0700	/coeff;
    CO2[	681	]=	1398.5400	/coeff;
    CO2[	682	]=	1398.0100	/coeff;
    CO2[	683	]=	1397.4800	/coeff;
    CO2[	684	]=	1396.9500	/coeff;
    CO2[	685	]=	1396.4300	/coeff;
    CO2[	686	]=	1395.9000	/coeff;
    CO2[	687	]=	1395.3700	/coeff;
    CO2[	688	]=	1394.8500	/coeff;
    CO2[	689	]=	1394.3200	/coeff;
    CO2[	690	]=	1393.8000	/coeff;
    CO2[	691	]=	1393.2800	/coeff;
    CO2[	692	]=	1392.7500	/coeff;
    CO2[	693	]=	1392.2300	/coeff;
    CO2[	694	]=	1391.7100	/coeff;
    CO2[	695	]=	1391.1900	/coeff;
    CO2[	696	]=	1390.6700	/coeff;
    CO2[	697	]=	1390.1500	/coeff;
    CO2[	698	]=	1389.6300	/coeff;
    CO2[	699	]=	1389.1100	/coeff;
    CO2[	700	]=	1388.6000	/coeff;
    CO2[	701	]=	1388.0800	/coeff;
    CO2[	702	]=	1387.5600	/coeff;
    CO2[	703	]=	1387.0500	/coeff;
    CO2[	704	]=	1386.5300	/coeff;
    CO2[	705	]=	1386.0200	/coeff;
    CO2[	706	]=	1385.5000	/coeff;
    CO2[	707	]=	1384.9900	/coeff;
    CO2[	708	]=	1384.4800	/coeff;
    CO2[	709	]=	1383.9700	/coeff;
    CO2[	710	]=	1383.4500	/coeff;
    CO2[	711	]=	1382.9400	/coeff;
    CO2[	712	]=	1382.4300	/coeff;
    CO2[	713	]=	1381.9300	/coeff;
    CO2[	714	]=	1381.4200	/coeff;
    CO2[	715	]=	1380.9100	/coeff;
    CO2[	716	]=	1380.4000	/coeff;
    CO2[	717	]=	1379.8900	/coeff;
    CO2[	718	]=	1379.3900	/coeff;
    CO2[	719	]=	1378.8800	/coeff;
    CO2[	720	]=	1378.3800	/coeff;
    CO2[	721	]=	1377.8700	/coeff;
    CO2[	722	]=	1377.3700	/coeff;
    CO2[	723	]=	1376.8700	/coeff;
    CO2[	724	]=	1376.3600	/coeff;
    CO2[	725	]=	1375.8600	/coeff;
    CO2[	726	]=	1375.3600	/coeff;
    CO2[	727	]=	1374.8600	/coeff;
    CO2[	728	]=	1374.3600	/coeff;
    CO2[	729	]=	1373.8600	/coeff;
    CO2[	730	]=	1373.3600	/coeff;
    CO2[	731	]=	1372.8700	/coeff;
    CO2[	732	]=	1372.3700	/coeff;
    CO2[	733	]=	1371.8700	/coeff;
    CO2[	734	]=	1371.3800	/coeff;
    CO2[	735	]=	1371.1300	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp370lowNTCF(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9484	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.8140	/coeff;
    CO2[	253	]=	408.8340	/coeff;
    CO2[	254	]=	411.9510	/coeff;
    CO2[	255	]=	415.1650	/coeff;
    CO2[	256	]=	418.4780	/coeff;
    CO2[	257	]=	421.8680	/coeff;
    CO2[	258	]=	425.3190	/coeff;
    CO2[	259	]=	428.8320	/coeff;
    CO2[	260	]=	432.4079	/coeff;
    CO2[	261	]=	436.0480	/coeff;
    CO2[	262	]=	439.7520	/coeff;
    CO2[	263	]=	443.5200	/coeff;
    CO2[	264	]=	447.3520	/coeff;
    CO2[	265	]=	451.2479	/coeff;
    CO2[	266	]=	455.2069	/coeff;
    CO2[	267	]=	459.2159	/coeff;
    CO2[	268	]=	463.2640	/coeff;
    CO2[	269	]=	467.3519	/coeff;
    CO2[	270	]=	471.4820	/coeff;
    CO2[	271	]=	475.6549	/coeff;
    CO2[	272	]=	479.8739	/coeff;
    CO2[	273	]=	484.1389	/coeff;
    CO2[	274	]=	488.4529	/coeff;
    CO2[	275	]=	492.8159	/coeff;
    CO2[	276	]=	497.2299	/coeff;
    CO2[	277	]=	501.6879	/coeff;
    CO2[	278	]=	506.1829	/coeff;
    CO2[	279	]=	510.7169	/coeff;
    CO2[	280	]=	515.2919	/coeff;
    CO2[	281	]=	519.9099	/coeff;
    CO2[	282	]=	524.5729	/coeff;
    CO2[	283	]=	529.2829	/coeff;
    CO2[	284	]=	534.0409	/coeff;
    CO2[	285	]=	538.8489	/coeff;
    CO2[	286	]=	543.7089	/coeff;
    CO2[	287	]=	548.6209	/coeff;
    CO2[	288	]=	553.5839	/coeff;
    CO2[	289	]=	558.5999	/coeff;
    CO2[	290	]=	563.6679	/coeff;
    CO2[	291	]=	568.7909	/coeff;
    CO2[	292	]=	573.9689	/coeff;
    CO2[	293	]=	579.2039	/coeff;
    CO2[	294	]=	584.4949	/coeff;
    CO2[	295	]=	589.8459	/coeff;
    CO2[	296	]=	595.2559	/coeff;
    CO2[	297	]=	600.7249	/coeff;
    CO2[	298	]=	606.2529	/coeff;
    CO2[	299	]=	611.8399	/coeff;
    CO2[	300	]=	617.4889	/coeff;
    CO2[	301	]=	623.1979	/coeff;
    CO2[	302	]=	628.9699	/coeff;
    CO2[	303	]=	634.8039	/coeff;
    CO2[	304	]=	640.7019	/coeff;
    CO2[	305	]=	646.6649	/coeff;
    CO2[	306	]=	652.6919	/coeff;
    CO2[	307	]=	658.7839	/coeff;
    CO2[	308	]=	664.9419	/coeff;
    CO2[	309	]=	671.1659	/coeff;
    CO2[	310	]=	677.4569	/coeff;
    CO2[	311	]=	683.8149	/coeff;
    CO2[	312	]=	690.2409	/coeff;
    CO2[	313	]=	696.7349	/coeff;
    CO2[	314	]=	703.2989	/coeff;
    CO2[	315	]=	709.9329	/coeff;
    CO2[	316	]=	716.6369	/coeff;
    CO2[	317	]=	723.4129	/coeff;
    CO2[	318	]=	730.2629	/coeff;
    CO2[	319	]=	737.1869	/coeff;
    CO2[	320	]=	744.1869	/coeff;
    CO2[	321	]=	751.2609	/coeff;
    CO2[	322	]=	758.4119	/coeff;
    CO2[	323	]=	765.6379	/coeff;
    CO2[	324	]=	772.9409	/coeff;
    CO2[	325	]=	780.3209	/coeff;
    CO2[	326	]=	787.7769	/coeff;
    CO2[	327	]=	795.3149	/coeff;
    CO2[	328	]=	802.9359	/coeff;
    CO2[	329	]=	810.6419	/coeff;
    CO2[	330	]=	818.4319	/coeff;
    CO2[	331	]=	826.3059	/coeff;
    CO2[	332	]=	834.2649	/coeff;
    CO2[	333	]=	842.3099	/coeff;
    CO2[	334	]=	850.4389	/coeff;
    CO2[	335	]=	858.6539	/coeff;
    CO2[	336	]=	866.9549	/coeff;
    CO2[	337	]=	875.2719	/coeff;
    CO2[	338	]=	883.5399	/coeff;
    CO2[	339	]=	891.7599	/coeff;
    CO2[	340	]=	899.9339	/coeff;
    CO2[	341	]=	908.0649	/coeff;
    CO2[	342	]=	916.1529	/coeff;
    CO2[	343	]=	924.1989	/coeff;
    CO2[	344	]=	932.2049	/coeff;
    CO2[	345	]=	940.1689	/coeff;
    CO2[	346	]=	948.0919	/coeff;
    CO2[	347	]=	955.9749	/coeff;
    CO2[	348	]=	963.8179	/coeff;
    CO2[	349	]=	971.6199	/coeff;
    CO2[	350	]=	979.3809	/coeff;
    CO2[	351	]=	987.1009	/coeff;
    CO2[	352	]=	994.7789	/coeff;
    CO2[	353	]=	1002.4199	/coeff;
    CO2[	354	]=	1010.0099	/coeff;
    CO2[	355	]=	1017.5599	/coeff;
    CO2[	356	]=	1025.0699	/coeff;
    CO2[	357	]=	1032.5299	/coeff;
    CO2[	358	]=	1039.9599	/coeff;
    CO2[	359	]=	1047.3299	/coeff;
    CO2[	360	]=	1054.6599	/coeff;
    CO2[	361	]=	1061.9499	/coeff;
    CO2[	362	]=	1069.1799	/coeff;
    CO2[	363	]=	1076.3799	/coeff;
    CO2[	364	]=	1083.5199	/coeff;
    CO2[	365	]=	1090.6199	/coeff;
    CO2[	366	]=	1097.6599	/coeff;
    CO2[	367	]=	1104.6599	/coeff;
    CO2[	368	]=	1111.6099	/coeff;
    CO2[	369	]=	1118.5099	/coeff;
    CO2[	370	]=	1125.3499	/coeff;
    CO2[	371	]=	1132.1499	/coeff;
    CO2[	372	]=	1138.8899	/coeff;
    CO2[	373	]=	1145.5799	/coeff;
    CO2[	374	]=	1152.2099	/coeff;
    CO2[	375	]=	1158.7999	/coeff;
    CO2[	376	]=	1165.3199	/coeff;
    CO2[	377	]=	1171.7999	/coeff;
    CO2[	378	]=	1178.2100	/coeff;
    CO2[	379	]=	1184.5799	/coeff;
    CO2[	380	]=	1190.8799	/coeff;
    CO2[	381	]=	1197.1299	/coeff;
    CO2[	382	]=	1203.3199	/coeff;
    CO2[	383	]=	1209.4499	/coeff;
    CO2[	384	]=	1215.5199	/coeff;
    CO2[	385	]=	1221.5400	/coeff;
    CO2[	386	]=	1227.4899	/coeff;
    CO2[	387	]=	1233.3899	/coeff;
    CO2[	388	]=	1239.2299	/coeff;
    CO2[	389	]=	1245.0200	/coeff;
    CO2[	390	]=	1250.7599	/coeff;
    CO2[	391	]=	1256.4399	/coeff;
    CO2[	392	]=	1262.0699	/coeff;
    CO2[	393	]=	1267.6399	/coeff;
    CO2[	394	]=	1273.1499	/coeff;
    CO2[	395	]=	1278.6099	/coeff;
    CO2[	396	]=	1284.0099	/coeff;
    CO2[	397	]=	1289.3600	/coeff;
    CO2[	398	]=	1294.6399	/coeff;
    CO2[	399	]=	1299.8700	/coeff;
    CO2[	400	]=	1305.0400	/coeff;
    CO2[	401	]=	1310.1600	/coeff;
    CO2[	402	]=	1315.2099	/coeff;
    CO2[	403	]=	1320.2000	/coeff;
    CO2[	404	]=	1325.1399	/coeff;
    CO2[	405	]=	1330.0100	/coeff;
    CO2[	406	]=	1334.8299	/coeff;
    CO2[	407	]=	1339.5800	/coeff;
    CO2[	408	]=	1344.2800	/coeff;
    CO2[	409	]=	1348.9100	/coeff;
    CO2[	410	]=	1353.4800	/coeff;
    CO2[	411	]=	1357.9900	/coeff;
    CO2[	412	]=	1362.4400	/coeff;
    CO2[	413	]=	1366.8200	/coeff;
    CO2[	414	]=	1371.1499	/coeff;
    CO2[	415	]=	1375.4100	/coeff;
    CO2[	416	]=	1379.6100	/coeff;
    CO2[	417	]=	1383.7399	/coeff;
    CO2[	418	]=	1387.8199	/coeff;
    CO2[	419	]=	1391.8200	/coeff;
    CO2[	420	]=	1395.7700	/coeff;
    CO2[	421	]=	1399.6500	/coeff;
    CO2[	422	]=	1403.4700	/coeff;
    CO2[	423	]=	1407.2200	/coeff;
    CO2[	424	]=	1410.9100	/coeff;
    CO2[	425	]=	1414.5300	/coeff;
    CO2[	426	]=	1418.0900	/coeff;
    CO2[	427	]=	1421.5900	/coeff;
    CO2[	428	]=	1425.0200	/coeff;
    CO2[	429	]=	1428.3800	/coeff;
    CO2[	430	]=	1431.6800	/coeff;
    CO2[	431	]=	1434.9100	/coeff;
    CO2[	432	]=	1438.0800	/coeff;
    CO2[	433	]=	1441.1800	/coeff;
    CO2[	434	]=	1444.2200	/coeff;
    CO2[	435	]=	1447.1900	/coeff;
    CO2[	436	]=	1450.0900	/coeff;
    CO2[	437	]=	1452.9300	/coeff;
    CO2[	438	]=	1455.7000	/coeff;
    CO2[	439	]=	1458.4000	/coeff;
    CO2[	440	]=	1461.0400	/coeff;
    CO2[	441	]=	1463.6100	/coeff;
    CO2[	442	]=	1466.1100	/coeff;
    CO2[	443	]=	1468.5500	/coeff;
    CO2[	444	]=	1470.9200	/coeff;
    CO2[	445	]=	1473.2200	/coeff;
    CO2[	446	]=	1475.4600	/coeff;
    CO2[	447	]=	1477.6300	/coeff;
    CO2[	448	]=	1479.7300	/coeff;
    CO2[	449	]=	1481.7600	/coeff;
    CO2[	450	]=	1483.7300	/coeff;
    CO2[	451	]=	1485.6300	/coeff;
    CO2[	452	]=	1487.4600	/coeff;
    CO2[	453	]=	1489.2200	/coeff;
    CO2[	454	]=	1490.9100	/coeff;
    CO2[	455	]=	1492.5400	/coeff;
    CO2[	456	]=	1494.1000	/coeff;
    CO2[	457	]=	1495.5900	/coeff;
    CO2[	458	]=	1497.0200	/coeff;
    CO2[	459	]=	1498.3700	/coeff;
    CO2[	460	]=	1499.6600	/coeff;
    CO2[	461	]=	1500.8800	/coeff;
    CO2[	462	]=	1502.0400	/coeff;
    CO2[	463	]=	1503.1200	/coeff;
    CO2[	464	]=	1504.1400	/coeff;
    CO2[	465	]=	1505.0800	/coeff;
    CO2[	466	]=	1505.9600	/coeff;
    CO2[	467	]=	1506.7700	/coeff;
    CO2[	468	]=	1507.5200	/coeff;
    CO2[	469	]=	1508.1900	/coeff;
    CO2[	470	]=	1508.8000	/coeff;
    CO2[	471	]=	1509.3400	/coeff;
    CO2[	472	]=	1509.8100	/coeff;
    CO2[	473	]=	1510.2100	/coeff;
    CO2[	474	]=	1510.5500	/coeff;
    CO2[	475	]=	1510.8100	/coeff;
    CO2[	476	]=	1511.0100	/coeff;
    CO2[	477	]=	1511.1400	/coeff;
    CO2[	478	]=	1511.2000	/coeff;
    CO2[	479	]=	1511.2000	/coeff;
    CO2[	480	]=	1511.1200	/coeff;
    CO2[	481	]=	1510.9800	/coeff;
    CO2[	482	]=	1510.7700	/coeff;
    CO2[	483	]=	1510.4900	/coeff;
    CO2[	484	]=	1510.1500	/coeff;
    CO2[	485	]=	1509.7300	/coeff;
    CO2[	486	]=	1509.2500	/coeff;
    CO2[	487	]=	1508.7300	/coeff;
    CO2[	488	]=	1508.2200	/coeff;
    CO2[	489	]=	1507.7100	/coeff;
    CO2[	490	]=	1507.2000	/coeff;
    CO2[	491	]=	1506.6900	/coeff;
    CO2[	492	]=	1506.1800	/coeff;
    CO2[	493	]=	1505.6600	/coeff;
    CO2[	494	]=	1505.1500	/coeff;
    CO2[	495	]=	1504.6300	/coeff;
    CO2[	496	]=	1504.1200	/coeff;
    CO2[	497	]=	1503.6000	/coeff;
    CO2[	498	]=	1503.0800	/coeff;
    CO2[	499	]=	1502.5600	/coeff;
    CO2[	500	]=	1502.0300	/coeff;
    CO2[	501	]=	1501.5100	/coeff;
    CO2[	502	]=	1500.9800	/coeff;
    CO2[	503	]=	1500.4500	/coeff;
    CO2[	504	]=	1499.9200	/coeff;
    CO2[	505	]=	1499.3800	/coeff;
    CO2[	506	]=	1498.8500	/coeff;
    CO2[	507	]=	1498.3100	/coeff;
    CO2[	508	]=	1497.7700	/coeff;
    CO2[	509	]=	1497.2300	/coeff;
    CO2[	510	]=	1496.6900	/coeff;
    CO2[	511	]=	1496.1500	/coeff;
    CO2[	512	]=	1495.6000	/coeff;
    CO2[	513	]=	1495.0600	/coeff;
    CO2[	514	]=	1494.5100	/coeff;
    CO2[	515	]=	1493.9600	/coeff;
    CO2[	516	]=	1493.4100	/coeff;
    CO2[	517	]=	1492.8600	/coeff;
    CO2[	518	]=	1492.3000	/coeff;
    CO2[	519	]=	1491.7500	/coeff;
    CO2[	520	]=	1491.1900	/coeff;
    CO2[	521	]=	1490.6400	/coeff;
    CO2[	522	]=	1490.0800	/coeff;
    CO2[	523	]=	1489.5200	/coeff;
    CO2[	524	]=	1488.9600	/coeff;
    CO2[	525	]=	1488.4000	/coeff;
    CO2[	526	]=	1487.8400	/coeff;
    CO2[	527	]=	1487.2800	/coeff;
    CO2[	528	]=	1486.7100	/coeff;
    CO2[	529	]=	1486.1500	/coeff;
    CO2[	530	]=	1485.5800	/coeff;
    CO2[	531	]=	1485.0200	/coeff;
    CO2[	532	]=	1484.4500	/coeff;
    CO2[	533	]=	1483.8900	/coeff;
    CO2[	534	]=	1483.3200	/coeff;
    CO2[	535	]=	1482.7500	/coeff;
    CO2[	536	]=	1482.1800	/coeff;
    CO2[	537	]=	1481.6100	/coeff;
    CO2[	538	]=	1481.0400	/coeff;
    CO2[	539	]=	1480.4700	/coeff;
    CO2[	540	]=	1479.9000	/coeff;
    CO2[	541	]=	1479.3300	/coeff;
    CO2[	542	]=	1478.7600	/coeff;
    CO2[	543	]=	1478.1900	/coeff;
    CO2[	544	]=	1477.6200	/coeff;
    CO2[	545	]=	1477.0500	/coeff;
    CO2[	546	]=	1476.4700	/coeff;
    CO2[	547	]=	1475.9000	/coeff;
    CO2[	548	]=	1475.3300	/coeff;
    CO2[	549	]=	1474.7600	/coeff;
    CO2[	550	]=	1474.1800	/coeff;
    CO2[	551	]=	1473.6100	/coeff;
    CO2[	552	]=	1473.0400	/coeff;
    CO2[	553	]=	1472.4600	/coeff;
    CO2[	554	]=	1471.8900	/coeff;
    CO2[	555	]=	1471.3100	/coeff;
    CO2[	556	]=	1470.7400	/coeff;
    CO2[	557	]=	1470.1700	/coeff;
    CO2[	558	]=	1469.5900	/coeff;
    CO2[	559	]=	1469.0200	/coeff;
    CO2[	560	]=	1468.4400	/coeff;
    CO2[	561	]=	1467.8700	/coeff;
    CO2[	562	]=	1467.3000	/coeff;
    CO2[	563	]=	1466.7200	/coeff;
    CO2[	564	]=	1466.1500	/coeff;
    CO2[	565	]=	1465.5700	/coeff;
    CO2[	566	]=	1465.0000	/coeff;
    CO2[	567	]=	1464.4200	/coeff;
    CO2[	568	]=	1463.8500	/coeff;
    CO2[	569	]=	1463.2800	/coeff;
    CO2[	570	]=	1462.7000	/coeff;
    CO2[	571	]=	1462.1300	/coeff;
    CO2[	572	]=	1461.5600	/coeff;
    CO2[	573	]=	1460.9800	/coeff;
    CO2[	574	]=	1460.4100	/coeff;
    CO2[	575	]=	1459.8400	/coeff;
    CO2[	576	]=	1459.2600	/coeff;
    CO2[	577	]=	1458.6900	/coeff;
    CO2[	578	]=	1458.1200	/coeff;
    CO2[	579	]=	1457.5500	/coeff;
    CO2[	580	]=	1456.9700	/coeff;
    CO2[	581	]=	1456.4000	/coeff;
    CO2[	582	]=	1455.8300	/coeff;
    CO2[	583	]=	1455.2600	/coeff;
    CO2[	584	]=	1454.6900	/coeff;
    CO2[	585	]=	1454.1200	/coeff;
    CO2[	586	]=	1453.5500	/coeff;
    CO2[	587	]=	1452.9800	/coeff;
    CO2[	588	]=	1452.4100	/coeff;
    CO2[	589	]=	1451.8400	/coeff;
    CO2[	590	]=	1451.2700	/coeff;
    CO2[	591	]=	1450.7000	/coeff;
    CO2[	592	]=	1450.1300	/coeff;
    CO2[	593	]=	1449.5600	/coeff;
    CO2[	594	]=	1449.0000	/coeff;
    CO2[	595	]=	1448.4300	/coeff;
    CO2[	596	]=	1447.8600	/coeff;
    CO2[	597	]=	1447.2900	/coeff;
    CO2[	598	]=	1446.7300	/coeff;
    CO2[	599	]=	1446.1600	/coeff;
    CO2[	600	]=	1445.5900	/coeff;
    CO2[	601	]=	1445.0300	/coeff;
    CO2[	602	]=	1444.4600	/coeff;
    CO2[	603	]=	1443.9000	/coeff;
    CO2[	604	]=	1443.3300	/coeff;
    CO2[	605	]=	1442.7700	/coeff;
    CO2[	606	]=	1442.2100	/coeff;
    CO2[	607	]=	1441.6400	/coeff;
    CO2[	608	]=	1441.0800	/coeff;
    CO2[	609	]=	1440.5200	/coeff;
    CO2[	610	]=	1439.9600	/coeff;
    CO2[	611	]=	1439.4000	/coeff;
    CO2[	612	]=	1438.8300	/coeff;
    CO2[	613	]=	1438.2700	/coeff;
    CO2[	614	]=	1437.7100	/coeff;
    CO2[	615	]=	1437.1500	/coeff;
    CO2[	616	]=	1436.5900	/coeff;
    CO2[	617	]=	1436.0400	/coeff;
    CO2[	618	]=	1435.4800	/coeff;
    CO2[	619	]=	1434.9200	/coeff;
    CO2[	620	]=	1434.3600	/coeff;
    CO2[	621	]=	1433.8000	/coeff;
    CO2[	622	]=	1433.2500	/coeff;
    CO2[	623	]=	1432.6900	/coeff;
    CO2[	624	]=	1432.1400	/coeff;
    CO2[	625	]=	1431.5800	/coeff;
    CO2[	626	]=	1431.0300	/coeff;
    CO2[	627	]=	1430.4700	/coeff;
    CO2[	628	]=	1429.9200	/coeff;
    CO2[	629	]=	1429.3600	/coeff;
    CO2[	630	]=	1428.8100	/coeff;
    CO2[	631	]=	1428.2600	/coeff;
    CO2[	632	]=	1427.7100	/coeff;
    CO2[	633	]=	1427.1600	/coeff;
    CO2[	634	]=	1426.6100	/coeff;
    CO2[	635	]=	1426.0600	/coeff;
    CO2[	636	]=	1425.5100	/coeff;
    CO2[	637	]=	1424.9600	/coeff;
    CO2[	638	]=	1424.4100	/coeff;
    CO2[	639	]=	1423.8600	/coeff;
    CO2[	640	]=	1423.3100	/coeff;
    CO2[	641	]=	1422.7600	/coeff;
    CO2[	642	]=	1422.2200	/coeff;
    CO2[	643	]=	1421.6700	/coeff;
    CO2[	644	]=	1421.1300	/coeff;
    CO2[	645	]=	1420.5800	/coeff;
    CO2[	646	]=	1420.0400	/coeff;
    CO2[	647	]=	1419.4900	/coeff;
    CO2[	648	]=	1418.9500	/coeff;
    CO2[	649	]=	1418.4100	/coeff;
    CO2[	650	]=	1417.8600	/coeff;
    CO2[	651	]=	1417.3200	/coeff;
    CO2[	652	]=	1416.7800	/coeff;
    CO2[	653	]=	1416.2400	/coeff;
    CO2[	654	]=	1415.7000	/coeff;
    CO2[	655	]=	1415.1600	/coeff;
    CO2[	656	]=	1414.6200	/coeff;
    CO2[	657	]=	1414.0800	/coeff;
    CO2[	658	]=	1413.5400	/coeff;
    CO2[	659	]=	1413.0100	/coeff;
    CO2[	660	]=	1412.4700	/coeff;
    CO2[	661	]=	1411.9300	/coeff;
    CO2[	662	]=	1411.4000	/coeff;
    CO2[	663	]=	1410.8600	/coeff;
    CO2[	664	]=	1410.3300	/coeff;
    CO2[	665	]=	1409.7900	/coeff;
    CO2[	666	]=	1409.2600	/coeff;
    CO2[	667	]=	1408.7300	/coeff;
    CO2[	668	]=	1408.1900	/coeff;
    CO2[	669	]=	1407.6600	/coeff;
    CO2[	670	]=	1407.1300	/coeff;
    CO2[	671	]=	1406.6000	/coeff;
    CO2[	672	]=	1406.0700	/coeff;
    CO2[	673	]=	1405.5400	/coeff;
    CO2[	674	]=	1405.0100	/coeff;
    CO2[	675	]=	1404.4800	/coeff;
    CO2[	676	]=	1403.9500	/coeff;
    CO2[	677	]=	1403.4300	/coeff;
    CO2[	678	]=	1402.9000	/coeff;
    CO2[	679	]=	1402.3700	/coeff;
    CO2[	680	]=	1401.8500	/coeff;
    CO2[	681	]=	1401.3200	/coeff;
    CO2[	682	]=	1400.8000	/coeff;
    CO2[	683	]=	1400.2700	/coeff;
    CO2[	684	]=	1399.7500	/coeff;
    CO2[	685	]=	1399.2300	/coeff;
    CO2[	686	]=	1398.7100	/coeff;
    CO2[	687	]=	1398.1800	/coeff;
    CO2[	688	]=	1397.6600	/coeff;
    CO2[	689	]=	1397.1400	/coeff;
    CO2[	690	]=	1396.6200	/coeff;
    CO2[	691	]=	1396.1000	/coeff;
    CO2[	692	]=	1395.5800	/coeff;
    CO2[	693	]=	1395.0700	/coeff;
    CO2[	694	]=	1394.5500	/coeff;
    CO2[	695	]=	1394.0300	/coeff;
    CO2[	696	]=	1393.5200	/coeff;
    CO2[	697	]=	1393.0000	/coeff;
    CO2[	698	]=	1392.4800	/coeff;
    CO2[	699	]=	1391.9700	/coeff;
    CO2[	700	]=	1391.4500	/coeff;
    CO2[	701	]=	1390.9400	/coeff;
    CO2[	702	]=	1390.4300	/coeff;
    CO2[	703	]=	1389.9200	/coeff;
    CO2[	704	]=	1389.4000	/coeff;
    CO2[	705	]=	1388.8900	/coeff;
    CO2[	706	]=	1388.3800	/coeff;
    CO2[	707	]=	1387.8700	/coeff;
    CO2[	708	]=	1387.3600	/coeff;
    CO2[	709	]=	1386.8500	/coeff;
    CO2[	710	]=	1386.3500	/coeff;
    CO2[	711	]=	1385.8400	/coeff;
    CO2[	712	]=	1385.3300	/coeff;
    CO2[	713	]=	1384.8200	/coeff;
    CO2[	714	]=	1384.3200	/coeff;
    CO2[	715	]=	1383.8100	/coeff;
    CO2[	716	]=	1383.3100	/coeff;
    CO2[	717	]=	1382.8000	/coeff;
    CO2[	718	]=	1382.3000	/coeff;
    CO2[	719	]=	1381.8000	/coeff;
    CO2[	720	]=	1381.3000	/coeff;
    CO2[	721	]=	1380.7900	/coeff;
    CO2[	722	]=	1380.2900	/coeff;
    CO2[	723	]=	1379.7900	/coeff;
    CO2[	724	]=	1379.2900	/coeff;
    CO2[	725	]=	1378.7900	/coeff;
    CO2[	726	]=	1378.2900	/coeff;
    CO2[	727	]=	1377.7900	/coeff;
    CO2[	728	]=	1377.3000	/coeff;
    CO2[	729	]=	1376.8000	/coeff;
    CO2[	730	]=	1376.3000	/coeff;
    CO2[	731	]=	1375.8100	/coeff;
    CO2[	732	]=	1375.3100	/coeff;
    CO2[	733	]=	1374.8200	/coeff;
    CO2[	734	]=	1374.3200	/coeff;
    CO2[	735	]=	1374.0800	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp434(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9493	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7430	/coeff;
    CO2[	253	]=	408.5570	/coeff;
    CO2[	254	]=	411.3400	/coeff;
    CO2[	255	]=	414.1010	/coeff;
    CO2[	256	]=	416.8430	/coeff;
    CO2[	257	]=	419.5440	/coeff;
    CO2[	258	]=	422.1820	/coeff;
    CO2[	259	]=	424.7630	/coeff;
    CO2[	260	]=	427.2910	/coeff;
    CO2[	261	]=	429.7690	/coeff;
    CO2[	262	]=	432.1990	/coeff;
    CO2[	263	]=	434.5850	/coeff;
    CO2[	264	]=	436.9270	/coeff;
    CO2[	265	]=	439.2260	/coeff;
    CO2[	266	]=	441.4840	/coeff;
    CO2[	267	]=	443.6880	/coeff;
    CO2[	268	]=	445.8270	/coeff;
    CO2[	269	]=	447.9030	/coeff;
    CO2[	270	]=	449.9170	/coeff;
    CO2[	271	]=	451.8710	/coeff;
    CO2[	272	]=	453.7660	/coeff;
    CO2[	273	]=	455.6030	/coeff;
    CO2[	274	]=	457.3830	/coeff;
    CO2[	275	]=	459.1070	/coeff;
    CO2[	276	]=	460.7770	/coeff;
    CO2[	277	]=	462.3860	/coeff;
    CO2[	278	]=	463.9270	/coeff;
    CO2[	279	]=	465.4020	/coeff;
    CO2[	280	]=	466.8130	/coeff;
    CO2[	281	]=	468.1590	/coeff;
    CO2[	282	]=	469.4420	/coeff;
    CO2[	283	]=	470.6620	/coeff;
    CO2[	284	]=	471.8200	/coeff;
    CO2[	285	]=	472.9170	/coeff;
    CO2[	286	]=	473.9520	/coeff;
    CO2[	287	]=	474.9460	/coeff;
    CO2[	288	]=	475.9170	/coeff;
    CO2[	289	]=	476.8630	/coeff;
    CO2[	290	]=	477.7840	/coeff;
    CO2[	291	]=	478.6770	/coeff;
    CO2[	292	]=	479.5440	/coeff;
    CO2[	293	]=	480.3820	/coeff;
    CO2[	294	]=	481.1910	/coeff;
    CO2[	295	]=	481.9720	/coeff;
    CO2[	296	]=	482.7220	/coeff;
    CO2[	297	]=	483.4470	/coeff;
    CO2[	298	]=	484.1470	/coeff;
    CO2[	299	]=	484.8240	/coeff;
    CO2[	300	]=	485.4750	/coeff;
    CO2[	301	]=	486.1000	/coeff;
    CO2[	302	]=	486.6990	/coeff;
    CO2[	303	]=	487.2720	/coeff;
    CO2[	304	]=	487.8170	/coeff;
    CO2[	305	]=	488.3340	/coeff;
    CO2[	306	]=	488.8240	/coeff;
    CO2[	307	]=	489.2670	/coeff;
    CO2[	308	]=	489.6460	/coeff;
    CO2[	309	]=	489.9630	/coeff;
    CO2[	310	]=	490.2180	/coeff;
    CO2[	311	]=	490.4130	/coeff;
    CO2[	312	]=	490.5460	/coeff;
    CO2[	313	]=	490.6200	/coeff;
    CO2[	314	]=	490.6350	/coeff;
    CO2[	315	]=	490.5910	/coeff;
    CO2[	316	]=	490.4880	/coeff;
    CO2[	317	]=	490.3100	/coeff;
    CO2[	318	]=	490.0450	/coeff;
    CO2[	319	]=	489.6920	/coeff;
    CO2[	320	]=	489.2550	/coeff;
    CO2[	321	]=	488.7330	/coeff;
    CO2[	322	]=	488.1280	/coeff;
    CO2[	323	]=	487.4410	/coeff;
    CO2[	324	]=	486.6720	/coeff;
    CO2[	325	]=	485.8230	/coeff;
    CO2[	326	]=	484.8930	/coeff;
    CO2[	327	]=	483.8900	/coeff;
    CO2[	328	]=	482.8170	/coeff;
    CO2[	329	]=	481.6750	/coeff;
    CO2[	330	]=	480.4640	/coeff;
    CO2[	331	]=	479.1840	/coeff;
    CO2[	332	]=	477.8350	/coeff;
    CO2[	333	]=	476.4180	/coeff;
    CO2[	334	]=	474.9330	/coeff;
    CO2[	335	]=	473.3810	/coeff;
    CO2[	336	]=	471.7610	/coeff;
    CO2[	337	]=	470.1280	/coeff;
    CO2[	338	]=	468.5310	/coeff;
    CO2[	339	]=	466.9640	/coeff;
    CO2[	340	]=	465.4260	/coeff;
    CO2[	341	]=	463.9130	/coeff;
    CO2[	342	]=	462.4220	/coeff;
    CO2[	343	]=	460.9520	/coeff;
    CO2[	344	]=	459.5000	/coeff;
    CO2[	345	]=	458.0650	/coeff;
    CO2[	346	]=	456.6460	/coeff;
    CO2[	347	]=	455.2420	/coeff;
    CO2[	348	]=	453.8510	/coeff;
    CO2[	349	]=	452.4720	/coeff;
    CO2[	350	]=	451.1050	/coeff;
    CO2[	351	]=	449.7490	/coeff;
    CO2[	352	]=	448.4040	/coeff;
    CO2[	353	]=	447.0670	/coeff;
    CO2[	354	]=	445.7400	/coeff;
    CO2[	355	]=	444.4210	/coeff;
    CO2[	356	]=	443.1100	/coeff;
    CO2[	357	]=	441.8060	/coeff;
    CO2[	358	]=	440.5090	/coeff;
    CO2[	359	]=	439.2200	/coeff;
    CO2[	360	]=	437.9360	/coeff;
    CO2[	361	]=	436.6590	/coeff;
    CO2[	362	]=	435.3870	/coeff;
    CO2[	363	]=	434.1210	/coeff;
    CO2[	364	]=	432.8600	/coeff;
    CO2[	365	]=	431.6050	/coeff;
    CO2[	366	]=	430.3540	/coeff;
    CO2[	367	]=	429.1080	/coeff;
    CO2[	368	]=	427.8660	/coeff;
    CO2[	369	]=	426.6290	/coeff;
    CO2[	370	]=	425.3960	/coeff;
    CO2[	371	]=	424.1670	/coeff;
    CO2[	372	]=	422.9430	/coeff;
    CO2[	373	]=	421.7210	/coeff;
    CO2[	374	]=	420.5040	/coeff;
    CO2[	375	]=	419.2900	/coeff;
    CO2[	376	]=	418.0800	/coeff;
    CO2[	377	]=	416.8930	/coeff;
    CO2[	378	]=	415.7490	/coeff;
    CO2[	379	]=	414.6430	/coeff;
    CO2[	380	]=	413.5750	/coeff;
    CO2[	381	]=	412.5430	/coeff;
    CO2[	382	]=	411.5460	/coeff;
    CO2[	383	]=	410.5830	/coeff;
    CO2[	384	]=	409.6530	/coeff;
    CO2[	385	]=	408.7530	/coeff;
    CO2[	386	]=	407.8850	/coeff;
    CO2[	387	]=	407.0480	/coeff;
    CO2[	388	]=	406.2440	/coeff;
    CO2[	389	]=	405.4720	/coeff;
    CO2[	390	]=	404.7310	/coeff;
    CO2[	391	]=	404.0210	/coeff;
    CO2[	392	]=	403.3400	/coeff;
    CO2[	393	]=	402.6880	/coeff;
    CO2[	394	]=	402.0650	/coeff;
    CO2[	395	]=	401.4700	/coeff;
    CO2[	396	]=	400.9030	/coeff;
    CO2[	397	]=	400.3630	/coeff;
    CO2[	398	]=	399.8500	/coeff;
    CO2[	399	]=	399.3630	/coeff;
    CO2[	400	]=	398.9020	/coeff;
    CO2[	401	]=	398.4670	/coeff;
    CO2[	402	]=	398.0570	/coeff;
    CO2[	403	]=	397.6720	/coeff;
    CO2[	404	]=	397.3130	/coeff;
    CO2[	405	]=	396.9780	/coeff;
    CO2[	406	]=	396.6690	/coeff;
    CO2[	407	]=	396.3830	/coeff;
    CO2[	408	]=	396.1220	/coeff;
    CO2[	409	]=	395.8850	/coeff;
    CO2[	410	]=	395.6720	/coeff;
    CO2[	411	]=	395.4830	/coeff;
    CO2[	412	]=	395.3170	/coeff;
    CO2[	413	]=	395.1740	/coeff;
    CO2[	414	]=	395.0540	/coeff;
    CO2[	415	]=	394.9570	/coeff;
    CO2[	416	]=	394.8820	/coeff;
    CO2[	417	]=	394.8310	/coeff;
    CO2[	418	]=	394.8010	/coeff;
    CO2[	419	]=	394.7940	/coeff;
    CO2[	420	]=	394.8090	/coeff;
    CO2[	421	]=	394.8470	/coeff;
    CO2[	422	]=	394.9060	/coeff;
    CO2[	423	]=	394.9870	/coeff;
    CO2[	424	]=	395.0890	/coeff;
    CO2[	425	]=	395.2130	/coeff;
    CO2[	426	]=	395.3590	/coeff;
    CO2[	427	]=	395.5060	/coeff;
    CO2[	428	]=	395.6360	/coeff;
    CO2[	429	]=	395.7510	/coeff;
    CO2[	430	]=	395.8530	/coeff;
    CO2[	431	]=	395.9440	/coeff;
    CO2[	432	]=	396.0250	/coeff;
    CO2[	433	]=	396.0960	/coeff;
    CO2[	434	]=	396.1580	/coeff;
    CO2[	435	]=	396.2130	/coeff;
    CO2[	436	]=	396.2610	/coeff;
    CO2[	437	]=	396.3030	/coeff;
    CO2[	438	]=	396.3380	/coeff;
    CO2[	439	]=	396.3690	/coeff;
    CO2[	440	]=	396.3940	/coeff;
    CO2[	441	]=	396.4150	/coeff;
    CO2[	442	]=	396.4310	/coeff;
    CO2[	443	]=	396.4440	/coeff;
    CO2[	444	]=	396.4530	/coeff;
    CO2[	445	]=	396.4580	/coeff;
    CO2[	446	]=	396.4600	/coeff;
    CO2[	447	]=	396.4600	/coeff;
    CO2[	448	]=	396.4560	/coeff;
    CO2[	449	]=	396.4500	/coeff;
    CO2[	450	]=	396.4420	/coeff;
    CO2[	451	]=	396.4310	/coeff;
    CO2[	452	]=	396.4180	/coeff;
    CO2[	453	]=	396.4030	/coeff;
    CO2[	454	]=	396.3860	/coeff;
    CO2[	455	]=	396.3670	/coeff;
    CO2[	456	]=	396.3460	/coeff;
    CO2[	457	]=	396.3240	/coeff;
    CO2[	458	]=	396.3000	/coeff;
    CO2[	459	]=	396.2740	/coeff;
    CO2[	460	]=	396.2480	/coeff;
    CO2[	461	]=	396.2190	/coeff;
    CO2[	462	]=	396.1900	/coeff;
    CO2[	463	]=	396.1590	/coeff;
    CO2[	464	]=	396.1270	/coeff;
    CO2[	465	]=	396.0940	/coeff;
    CO2[	466	]=	396.0590	/coeff;
    CO2[	467	]=	396.0240	/coeff;
    CO2[	468	]=	395.9880	/coeff;
    CO2[	469	]=	395.9500	/coeff;
    CO2[	470	]=	395.9120	/coeff;
    CO2[	471	]=	395.8720	/coeff;
    CO2[	472	]=	395.8320	/coeff;
    CO2[	473	]=	395.7910	/coeff;
    CO2[	474	]=	395.7490	/coeff;
    CO2[	475	]=	395.7060	/coeff;
    CO2[	476	]=	395.6630	/coeff;
    CO2[	477	]=	395.6180	/coeff;
    CO2[	478	]=	395.5730	/coeff;
    CO2[	479	]=	395.5270	/coeff;
    CO2[	480	]=	395.4810	/coeff;
    CO2[	481	]=	395.4330	/coeff;
    CO2[	482	]=	395.3850	/coeff;
    CO2[	483	]=	395.3370	/coeff;
    CO2[	484	]=	395.2870	/coeff;
    CO2[	485	]=	395.2370	/coeff;
    CO2[	486	]=	395.1870	/coeff;
    CO2[	487	]=	395.1350	/coeff;
    CO2[	488	]=	395.0830	/coeff;
    CO2[	489	]=	395.0300	/coeff;
    CO2[	490	]=	394.9760	/coeff;
    CO2[	491	]=	394.9220	/coeff;
    CO2[	492	]=	394.8660	/coeff;
    CO2[	493	]=	394.8100	/coeff;
    CO2[	494	]=	394.7520	/coeff;
    CO2[	495	]=	394.6940	/coeff;
    CO2[	496	]=	394.6360	/coeff;
    CO2[	497	]=	394.5760	/coeff;
    CO2[	498	]=	394.5160	/coeff;
    CO2[	499	]=	394.4560	/coeff;
    CO2[	500	]=	394.3960	/coeff;
    CO2[	501	]=	394.3350	/coeff;
    CO2[	502	]=	394.2740	/coeff;
    CO2[	503	]=	394.2140	/coeff;
    CO2[	504	]=	394.1530	/coeff;
    CO2[	505	]=	394.0930	/coeff;
    CO2[	506	]=	394.0320	/coeff;
    CO2[	507	]=	393.9720	/coeff;
    CO2[	508	]=	393.9110	/coeff;
    CO2[	509	]=	393.8510	/coeff;
    CO2[	510	]=	393.7910	/coeff;
    CO2[	511	]=	393.7310	/coeff;
    CO2[	512	]=	393.6710	/coeff;
    CO2[	513	]=	393.6110	/coeff;
    CO2[	514	]=	393.5520	/coeff;
    CO2[	515	]=	393.4930	/coeff;
    CO2[	516	]=	393.4340	/coeff;
    CO2[	517	]=	393.3750	/coeff;
    CO2[	518	]=	393.3160	/coeff;
    CO2[	519	]=	393.2580	/coeff;
    CO2[	520	]=	393.1990	/coeff;
    CO2[	521	]=	393.1410	/coeff;
    CO2[	522	]=	393.0840	/coeff;
    CO2[	523	]=	393.0260	/coeff;
    CO2[	524	]=	392.9690	/coeff;
    CO2[	525	]=	392.9110	/coeff;
    CO2[	526	]=	392.8550	/coeff;
    CO2[	527	]=	392.7980	/coeff;
    CO2[	528	]=	392.7410	/coeff;
    CO2[	529	]=	392.6850	/coeff;
    CO2[	530	]=	392.6290	/coeff;
    CO2[	531	]=	392.5730	/coeff;
    CO2[	532	]=	392.5180	/coeff;
    CO2[	533	]=	392.4620	/coeff;
    CO2[	534	]=	392.4070	/coeff;
    CO2[	535	]=	392.3520	/coeff;
    CO2[	536	]=	392.2970	/coeff;
    CO2[	537	]=	392.2430	/coeff;
    CO2[	538	]=	392.1880	/coeff;
    CO2[	539	]=	392.1340	/coeff;
    CO2[	540	]=	392.0800	/coeff;
    CO2[	541	]=	392.0270	/coeff;
    CO2[	542	]=	391.9730	/coeff;
    CO2[	543	]=	391.9190	/coeff;
    CO2[	544	]=	391.8660	/coeff;
    CO2[	545	]=	391.8130	/coeff;
    CO2[	546	]=	391.7600	/coeff;
    CO2[	547	]=	391.7080	/coeff;
    CO2[	548	]=	391.6550	/coeff;
    CO2[	549	]=	391.6030	/coeff;
    CO2[	550	]=	391.5500	/coeff;
    CO2[	551	]=	391.4980	/coeff;
    CO2[	552	]=	391.4460	/coeff;
    CO2[	553	]=	391.3950	/coeff;
    CO2[	554	]=	391.3430	/coeff;
    CO2[	555	]=	391.2920	/coeff;
    CO2[	556	]=	391.2400	/coeff;
    CO2[	557	]=	391.1890	/coeff;
    CO2[	558	]=	391.1380	/coeff;
    CO2[	559	]=	391.0870	/coeff;
    CO2[	560	]=	391.0370	/coeff;
    CO2[	561	]=	390.9860	/coeff;
    CO2[	562	]=	390.9360	/coeff;
    CO2[	563	]=	390.8850	/coeff;
    CO2[	564	]=	390.8350	/coeff;
    CO2[	565	]=	390.7850	/coeff;
    CO2[	566	]=	390.7350	/coeff;
    CO2[	567	]=	390.6850	/coeff;
    CO2[	568	]=	390.6350	/coeff;
    CO2[	569	]=	390.5860	/coeff;
    CO2[	570	]=	390.5360	/coeff;
    CO2[	571	]=	390.4870	/coeff;
    CO2[	572	]=	390.4380	/coeff;
    CO2[	573	]=	390.3890	/coeff;
    CO2[	574	]=	390.3400	/coeff;
    CO2[	575	]=	390.2910	/coeff;
    CO2[	576	]=	390.2420	/coeff;
    CO2[	577	]=	390.1930	/coeff;
    CO2[	578	]=	390.1450	/coeff;
    CO2[	579	]=	390.0960	/coeff;
    CO2[	580	]=	390.0480	/coeff;
    CO2[	581	]=	390.0000	/coeff;
    CO2[	582	]=	389.9510	/coeff;
    CO2[	583	]=	389.9030	/coeff;
    CO2[	584	]=	389.8550	/coeff;
    CO2[	585	]=	389.8080	/coeff;
    CO2[	586	]=	389.7600	/coeff;
    CO2[	587	]=	389.7120	/coeff;
    CO2[	588	]=	389.6640	/coeff;
    CO2[	589	]=	389.6170	/coeff;
    CO2[	590	]=	389.5690	/coeff;
    CO2[	591	]=	389.5220	/coeff;
    CO2[	592	]=	389.4750	/coeff;
    CO2[	593	]=	389.4280	/coeff;
    CO2[	594	]=	389.3810	/coeff;
    CO2[	595	]=	389.3340	/coeff;
    CO2[	596	]=	389.2870	/coeff;
    CO2[	597	]=	389.2400	/coeff;
    CO2[	598	]=	389.1930	/coeff;
    CO2[	599	]=	389.1460	/coeff;
    CO2[	600	]=	389.1000	/coeff;
    CO2[	601	]=	389.0530	/coeff;
    CO2[	602	]=	389.0070	/coeff;
    CO2[	603	]=	388.9600	/coeff;
    CO2[	604	]=	388.9140	/coeff;
    CO2[	605	]=	388.8680	/coeff;
    CO2[	606	]=	388.8220	/coeff;
    CO2[	607	]=	388.7760	/coeff;
    CO2[	608	]=	388.7300	/coeff;
    CO2[	609	]=	388.6840	/coeff;
    CO2[	610	]=	388.6380	/coeff;
    CO2[	611	]=	388.5920	/coeff;
    CO2[	612	]=	388.5460	/coeff;
    CO2[	613	]=	388.5010	/coeff;
    CO2[	614	]=	388.4550	/coeff;
    CO2[	615	]=	388.4100	/coeff;
    CO2[	616	]=	388.3640	/coeff;
    CO2[	617	]=	388.3190	/coeff;
    CO2[	618	]=	388.2740	/coeff;
    CO2[	619	]=	388.2280	/coeff;
    CO2[	620	]=	388.1830	/coeff;
    CO2[	621	]=	388.1380	/coeff;
    CO2[	622	]=	388.0930	/coeff;
    CO2[	623	]=	388.0480	/coeff;
    CO2[	624	]=	388.0030	/coeff;
    CO2[	625	]=	387.9580	/coeff;
    CO2[	626	]=	387.9140	/coeff;
    CO2[	627	]=	387.8690	/coeff;
    CO2[	628	]=	387.8240	/coeff;
    CO2[	629	]=	387.7800	/coeff;
    CO2[	630	]=	387.7350	/coeff;
    CO2[	631	]=	387.6910	/coeff;
    CO2[	632	]=	387.6460	/coeff;
    CO2[	633	]=	387.6020	/coeff;
    CO2[	634	]=	387.5580	/coeff;
    CO2[	635	]=	387.5130	/coeff;
    CO2[	636	]=	387.4690	/coeff;
    CO2[	637	]=	387.4250	/coeff;
    CO2[	638	]=	387.3810	/coeff;
    CO2[	639	]=	387.3370	/coeff;
    CO2[	640	]=	387.2930	/coeff;
    CO2[	641	]=	387.2490	/coeff;
    CO2[	642	]=	387.2050	/coeff;
    CO2[	643	]=	387.1610	/coeff;
    CO2[	644	]=	387.1180	/coeff;
    CO2[	645	]=	387.0740	/coeff;
    CO2[	646	]=	387.0300	/coeff;
    CO2[	647	]=	386.9870	/coeff;
    CO2[	648	]=	386.9430	/coeff;
    CO2[	649	]=	386.9000	/coeff;
    CO2[	650	]=	386.8560	/coeff;
    CO2[	651	]=	386.8130	/coeff;
    CO2[	652	]=	386.7700	/coeff;
    CO2[	653	]=	386.7270	/coeff;
    CO2[	654	]=	386.6830	/coeff;
    CO2[	655	]=	386.6400	/coeff;
    CO2[	656	]=	386.5970	/coeff;
    CO2[	657	]=	386.5540	/coeff;
    CO2[	658	]=	386.5110	/coeff;
    CO2[	659	]=	386.4680	/coeff;
    CO2[	660	]=	386.4250	/coeff;
    CO2[	661	]=	386.3820	/coeff;
    CO2[	662	]=	386.3400	/coeff;
    CO2[	663	]=	386.2970	/coeff;
    CO2[	664	]=	386.2540	/coeff;
    CO2[	665	]=	386.2120	/coeff;
    CO2[	666	]=	386.1690	/coeff;
    CO2[	667	]=	386.1270	/coeff;
    CO2[	668	]=	386.0840	/coeff;
    CO2[	669	]=	386.0420	/coeff;
    CO2[	670	]=	385.9990	/coeff;
    CO2[	671	]=	385.9570	/coeff;
    CO2[	672	]=	385.9150	/coeff;
    CO2[	673	]=	385.8720	/coeff;
    CO2[	674	]=	385.8300	/coeff;
    CO2[	675	]=	385.7880	/coeff;
    CO2[	676	]=	385.7460	/coeff;
    CO2[	677	]=	385.7040	/coeff;
    CO2[	678	]=	385.6620	/coeff;
    CO2[	679	]=	385.6200	/coeff;
    CO2[	680	]=	385.5780	/coeff;
    CO2[	681	]=	385.5360	/coeff;
    CO2[	682	]=	385.4940	/coeff;
    CO2[	683	]=	385.4520	/coeff;
    CO2[	684	]=	385.4110	/coeff;
    CO2[	685	]=	385.3690	/coeff;
    CO2[	686	]=	385.3270	/coeff;
    CO2[	687	]=	385.2860	/coeff;
    CO2[	688	]=	385.2440	/coeff;
    CO2[	689	]=	385.2030	/coeff;
    CO2[	690	]=	385.1610	/coeff;
    CO2[	691	]=	385.1200	/coeff;
    CO2[	692	]=	385.0780	/coeff;
    CO2[	693	]=	385.0370	/coeff;
    CO2[	694	]=	384.9960	/coeff;
    CO2[	695	]=	384.9540	/coeff;
    CO2[	696	]=	384.9130	/coeff;
    CO2[	697	]=	384.8720	/coeff;
    CO2[	698	]=	384.8310	/coeff;
    CO2[	699	]=	384.7900	/coeff;
    CO2[	700	]=	384.7490	/coeff;
    CO2[	701	]=	384.7080	/coeff;
    CO2[	702	]=	384.6670	/coeff;
    CO2[	703	]=	384.6260	/coeff;
    CO2[	704	]=	384.5850	/coeff;
    CO2[	705	]=	384.5440	/coeff;
    CO2[	706	]=	384.5030	/coeff;
    CO2[	707	]=	384.4630	/coeff;
    CO2[	708	]=	384.4220	/coeff;
    CO2[	709	]=	384.3810	/coeff;
    CO2[	710	]=	384.3410	/coeff;
    CO2[	711	]=	384.3000	/coeff;
    CO2[	712	]=	384.2590	/coeff;
    CO2[	713	]=	384.2190	/coeff;
    CO2[	714	]=	384.1780	/coeff;
    CO2[	715	]=	384.1380	/coeff;
    CO2[	716	]=	384.0980	/coeff;
    CO2[	717	]=	384.0570	/coeff;
    CO2[	718	]=	384.0170	/coeff;
    CO2[	719	]=	383.9770	/coeff;
    CO2[	720	]=	383.9360	/coeff;
    CO2[	721	]=	383.8960	/coeff;
    CO2[	722	]=	383.8560	/coeff;
    CO2[	723	]=	383.8160	/coeff;
    CO2[	724	]=	383.7760	/coeff;
    CO2[	725	]=	383.7360	/coeff;
    CO2[	726	]=	383.6960	/coeff;
    CO2[	727	]=	383.6560	/coeff;
    CO2[	728	]=	383.6160	/coeff;
    CO2[	729	]=	383.5760	/coeff;
    CO2[	730	]=	383.5360	/coeff;
    CO2[	731	]=	383.4960	/coeff;
    CO2[	732	]=	383.4560	/coeff;
    CO2[	733	]=	383.4160	/coeff;
    CO2[	734	]=	383.3770	/coeff;
    CO2[	735	]=	383.3570	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp460(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9494	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7430	/coeff;
    CO2[	253	]=	408.5570	/coeff;
    CO2[	254	]=	411.3400	/coeff;
    CO2[	255	]=	414.1010	/coeff;
    CO2[	256	]=	416.8430	/coeff;
    CO2[	257	]=	419.6110	/coeff;
    CO2[	258	]=	422.4420	/coeff;
    CO2[	259	]=	425.3350	/coeff;
    CO2[	260	]=	428.2900	/coeff;
    CO2[	261	]=	431.3080	/coeff;
    CO2[	262	]=	434.3870	/coeff;
    CO2[	263	]=	437.5280	/coeff;
    CO2[	264	]=	440.7310	/coeff;
    CO2[	265	]=	443.9970	/coeff;
    CO2[	266	]=	447.3250	/coeff;
    CO2[	267	]=	450.6960	/coeff;
    CO2[	268	]=	454.0930	/coeff;
    CO2[	269	]=	457.5180	/coeff;
    CO2[	270	]=	460.9730	/coeff;
    CO2[	271	]=	464.4570	/coeff;
    CO2[	272	]=	467.9730	/coeff;
    CO2[	273	]=	471.5210	/coeff;
    CO2[	274	]=	475.1019	/coeff;
    CO2[	275	]=	478.7170	/coeff;
    CO2[	276	]=	482.3659	/coeff;
    CO2[	277	]=	486.0329	/coeff;
    CO2[	278	]=	489.7030	/coeff;
    CO2[	279	]=	493.3780	/coeff;
    CO2[	280	]=	497.0590	/coeff;
    CO2[	281	]=	500.7470	/coeff;
    CO2[	282	]=	504.4440	/coeff;
    CO2[	283	]=	508.1500	/coeff;
    CO2[	284	]=	511.8670	/coeff;
    CO2[	285	]=	515.5939	/coeff;
    CO2[	286	]=	519.3319	/coeff;
    CO2[	287	]=	523.0740	/coeff;
    CO2[	288	]=	526.8130	/coeff;
    CO2[	289	]=	530.5480	/coeff;
    CO2[	290	]=	534.2810	/coeff;
    CO2[	291	]=	538.0129	/coeff;
    CO2[	292	]=	541.7439	/coeff;
    CO2[	293	]=	545.4750	/coeff;
    CO2[	294	]=	549.2059	/coeff;
    CO2[	295	]=	552.9370	/coeff;
    CO2[	296	]=	556.6680	/coeff;
    CO2[	297	]=	560.3910	/coeff;
    CO2[	298	]=	564.0970	/coeff;
    CO2[	299	]=	567.7870	/coeff;
    CO2[	300	]=	571.4619	/coeff;
    CO2[	301	]=	575.1210	/coeff;
    CO2[	302	]=	578.7650	/coeff;
    CO2[	303	]=	582.3940	/coeff;
    CO2[	304	]=	586.0090	/coeff;
    CO2[	305	]=	589.6100	/coeff;
    CO2[	306	]=	593.1970	/coeff;
    CO2[	307	]=	596.7400	/coeff;
    CO2[	308	]=	600.2109	/coeff;
    CO2[	309	]=	603.6140	/coeff;
    CO2[	310	]=	606.9490	/coeff;
    CO2[	311	]=	610.2170	/coeff;
    CO2[	312	]=	613.4200	/coeff;
    CO2[	313	]=	616.5580	/coeff;
    CO2[	314	]=	619.6310	/coeff;
    CO2[	315	]=	622.6400	/coeff;
    CO2[	316	]=	625.5850	/coeff;
    CO2[	317	]=	628.4630	/coeff;
    CO2[	318	]=	631.2720	/coeff;
    CO2[	319	]=	634.0120	/coeff;
    CO2[	320	]=	636.6820	/coeff;
    CO2[	321	]=	639.2830	/coeff;
    CO2[	322	]=	641.8140	/coeff;
    CO2[	323	]=	644.2760	/coeff;
    CO2[	324	]=	646.6690	/coeff;
    CO2[	325	]=	648.9920	/coeff;
    CO2[	326	]=	651.2450	/coeff;
    CO2[	327	]=	653.4290	/coeff;
    CO2[	328	]=	655.5450	/coeff;
    CO2[	329	]=	657.5910	/coeff;
    CO2[	330	]=	659.5680	/coeff;
    CO2[	331	]=	661.4750	/coeff;
    CO2[	332	]=	663.3120	/coeff;
    CO2[	333	]=	665.0790	/coeff;
    CO2[	334	]=	666.7770	/coeff;
    CO2[	335	]=	668.4040	/coeff;
    CO2[	336	]=	669.9600	/coeff;
    CO2[	337	]=	671.4880	/coeff;
    CO2[	338	]=	673.0240	/coeff;
    CO2[	339	]=	674.5670	/coeff;
    CO2[	340	]=	676.1160	/coeff;
    CO2[	341	]=	677.6680	/coeff;
    CO2[	342	]=	679.2230	/coeff;
    CO2[	343	]=	680.7790	/coeff;
    CO2[	344	]=	682.3360	/coeff;
    CO2[	345	]=	683.8920	/coeff;
    CO2[	346	]=	685.4460	/coeff;
    CO2[	347	]=	686.9990	/coeff;
    CO2[	348	]=	688.5490	/coeff;
    CO2[	349	]=	690.0950	/coeff;
    CO2[	350	]=	691.6380	/coeff;
    CO2[	351	]=	693.1770	/coeff;
    CO2[	352	]=	694.7100	/coeff;
    CO2[	353	]=	696.2390	/coeff;
    CO2[	354	]=	697.7620	/coeff;
    CO2[	355	]=	699.2790	/coeff;
    CO2[	356	]=	700.7890	/coeff;
    CO2[	357	]=	702.2930	/coeff;
    CO2[	358	]=	703.7910	/coeff;
    CO2[	359	]=	705.2810	/coeff;
    CO2[	360	]=	706.7630	/coeff;
    CO2[	361	]=	708.2380	/coeff;
    CO2[	362	]=	709.7060	/coeff;
    CO2[	363	]=	711.1650	/coeff;
    CO2[	364	]=	712.6160	/coeff;
    CO2[	365	]=	714.0590	/coeff;
    CO2[	366	]=	715.4930	/coeff;
    CO2[	367	]=	716.9180	/coeff;
    CO2[	368	]=	718.3350	/coeff;
    CO2[	369	]=	719.7430	/coeff;
    CO2[	370	]=	721.1420	/coeff;
    CO2[	371	]=	722.5320	/coeff;
    CO2[	372	]=	723.9120	/coeff;
    CO2[	373	]=	725.2830	/coeff;
    CO2[	374	]=	726.6440	/coeff;
    CO2[	375	]=	727.9960	/coeff;
    CO2[	376	]=	729.3380	/coeff;
    CO2[	377	]=	730.6700	/coeff;
    CO2[	378	]=	731.9920	/coeff;
    CO2[	379	]=	733.3040	/coeff;
    CO2[	380	]=	734.6060	/coeff;
    CO2[	381	]=	735.8980	/coeff;
    CO2[	382	]=	737.1800	/coeff;
    CO2[	383	]=	738.4510	/coeff;
    CO2[	384	]=	739.7120	/coeff;
    CO2[	385	]=	740.9620	/coeff;
    CO2[	386	]=	742.2020	/coeff;
    CO2[	387	]=	743.4290	/coeff;
    CO2[	388	]=	744.6410	/coeff;
    CO2[	389	]=	745.8370	/coeff;
    CO2[	390	]=	747.0180	/coeff;
    CO2[	391	]=	748.1830	/coeff;
    CO2[	392	]=	749.3330	/coeff;
    CO2[	393	]=	750.4670	/coeff;
    CO2[	394	]=	751.5860	/coeff;
    CO2[	395	]=	752.6900	/coeff;
    CO2[	396	]=	753.7780	/coeff;
    CO2[	397	]=	754.8500	/coeff;
    CO2[	398	]=	755.9070	/coeff;
    CO2[	399	]=	756.9490	/coeff;
    CO2[	400	]=	757.9740	/coeff;
    CO2[	401	]=	758.9840	/coeff;
    CO2[	402	]=	759.9790	/coeff;
    CO2[	403	]=	760.9570	/coeff;
    CO2[	404	]=	761.9200	/coeff;
    CO2[	405	]=	762.8670	/coeff;
    CO2[	406	]=	763.7990	/coeff;
    CO2[	407	]=	764.7150	/coeff;
    CO2[	408	]=	765.6140	/coeff;
    CO2[	409	]=	766.4990	/coeff;
    CO2[	410	]=	767.3670	/coeff;
    CO2[	411	]=	768.2190	/coeff;
    CO2[	412	]=	769.0560	/coeff;
    CO2[	413	]=	769.8760	/coeff;
    CO2[	414	]=	770.6810	/coeff;
    CO2[	415	]=	771.4700	/coeff;
    CO2[	416	]=	772.2430	/coeff;
    CO2[	417	]=	772.9990	/coeff;
    CO2[	418	]=	773.7400	/coeff;
    CO2[	419	]=	774.4650	/coeff;
    CO2[	420	]=	775.1730	/coeff;
    CO2[	421	]=	775.8660	/coeff;
    CO2[	422	]=	776.5420	/coeff;
    CO2[	423	]=	777.2020	/coeff;
    CO2[	424	]=	777.8460	/coeff;
    CO2[	425	]=	778.4740	/coeff;
    CO2[	426	]=	779.0860	/coeff;
    CO2[	427	]=	779.6810	/coeff;
    CO2[	428	]=	780.2610	/coeff;
    CO2[	429	]=	780.8230	/coeff;
    CO2[	430	]=	781.3700	/coeff;
    CO2[	431	]=	781.9000	/coeff;
    CO2[	432	]=	782.4140	/coeff;
    CO2[	433	]=	782.9120	/coeff;
    CO2[	434	]=	783.3930	/coeff;
    CO2[	435	]=	783.8580	/coeff;
    CO2[	436	]=	784.3060	/coeff;
    CO2[	437	]=	784.7380	/coeff;
    CO2[	438	]=	785.1540	/coeff;
    CO2[	439	]=	785.5530	/coeff;
    CO2[	440	]=	785.9360	/coeff;
    CO2[	441	]=	786.3030	/coeff;
    CO2[	442	]=	786.6530	/coeff;
    CO2[	443	]=	786.9870	/coeff;
    CO2[	444	]=	787.3040	/coeff;
    CO2[	445	]=	787.6050	/coeff;
    CO2[	446	]=	787.8890	/coeff;
    CO2[	447	]=	788.1570	/coeff;
    CO2[	448	]=	788.4090	/coeff;
    CO2[	449	]=	788.6440	/coeff;
    CO2[	450	]=	788.8620	/coeff;
    CO2[	451	]=	789.0650	/coeff;
    CO2[	452	]=	789.2500	/coeff;
    CO2[	453	]=	789.4200	/coeff;
    CO2[	454	]=	789.5720	/coeff;
    CO2[	455	]=	789.7090	/coeff;
    CO2[	456	]=	789.8290	/coeff;
    CO2[	457	]=	789.9320	/coeff;
    CO2[	458	]=	790.0190	/coeff;
    CO2[	459	]=	790.0890	/coeff;
    CO2[	460	]=	790.1430	/coeff;
    CO2[	461	]=	790.1810	/coeff;
    CO2[	462	]=	790.2020	/coeff;
    CO2[	463	]=	790.2060	/coeff;
    CO2[	464	]=	790.1950	/coeff;
    CO2[	465	]=	790.1660	/coeff;
    CO2[	466	]=	790.1220	/coeff;
    CO2[	467	]=	790.0600	/coeff;
    CO2[	468	]=	789.9830	/coeff;
    CO2[	469	]=	789.8890	/coeff;
    CO2[	470	]=	789.7780	/coeff;
    CO2[	471	]=	789.6510	/coeff;
    CO2[	472	]=	789.5080	/coeff;
    CO2[	473	]=	789.3480	/coeff;
    CO2[	474	]=	789.1720	/coeff;
    CO2[	475	]=	788.9790	/coeff;
    CO2[	476	]=	788.7700	/coeff;
    CO2[	477	]=	788.5450	/coeff;
    CO2[	478	]=	788.3030	/coeff;
    CO2[	479	]=	788.0450	/coeff;
    CO2[	480	]=	787.7710	/coeff;
    CO2[	481	]=	787.4800	/coeff;
    CO2[	482	]=	787.1730	/coeff;
    CO2[	483	]=	786.8490	/coeff;
    CO2[	484	]=	786.5100	/coeff;
    CO2[	485	]=	786.1540	/coeff;
    CO2[	486	]=	785.7820	/coeff;
    CO2[	487	]=	785.4030	/coeff;
    CO2[	488	]=	785.0280	/coeff;
    CO2[	489	]=	784.6560	/coeff;
    CO2[	490	]=	784.2860	/coeff;
    CO2[	491	]=	783.9180	/coeff;
    CO2[	492	]=	783.5510	/coeff;
    CO2[	493	]=	783.1860	/coeff;
    CO2[	494	]=	782.8220	/coeff;
    CO2[	495	]=	782.4590	/coeff;
    CO2[	496	]=	782.0970	/coeff;
    CO2[	497	]=	781.7360	/coeff;
    CO2[	498	]=	781.3770	/coeff;
    CO2[	499	]=	781.0180	/coeff;
    CO2[	500	]=	780.6600	/coeff;
    CO2[	501	]=	780.3030	/coeff;
    CO2[	502	]=	779.9470	/coeff;
    CO2[	503	]=	779.5920	/coeff;
    CO2[	504	]=	779.2370	/coeff;
    CO2[	505	]=	778.8840	/coeff;
    CO2[	506	]=	778.5320	/coeff;
    CO2[	507	]=	778.1810	/coeff;
    CO2[	508	]=	777.8310	/coeff;
    CO2[	509	]=	777.4810	/coeff;
    CO2[	510	]=	777.1330	/coeff;
    CO2[	511	]=	776.7850	/coeff;
    CO2[	512	]=	776.4390	/coeff;
    CO2[	513	]=	776.0940	/coeff;
    CO2[	514	]=	775.7490	/coeff;
    CO2[	515	]=	775.4060	/coeff;
    CO2[	516	]=	775.0630	/coeff;
    CO2[	517	]=	774.7220	/coeff;
    CO2[	518	]=	774.3810	/coeff;
    CO2[	519	]=	774.0410	/coeff;
    CO2[	520	]=	773.7020	/coeff;
    CO2[	521	]=	773.3650	/coeff;
    CO2[	522	]=	773.0280	/coeff;
    CO2[	523	]=	772.6920	/coeff;
    CO2[	524	]=	772.3570	/coeff;
    CO2[	525	]=	772.0230	/coeff;
    CO2[	526	]=	771.6890	/coeff;
    CO2[	527	]=	771.3570	/coeff;
    CO2[	528	]=	771.0250	/coeff;
    CO2[	529	]=	770.6940	/coeff;
    CO2[	530	]=	770.3650	/coeff;
    CO2[	531	]=	770.0360	/coeff;
    CO2[	532	]=	769.7070	/coeff;
    CO2[	533	]=	769.3800	/coeff;
    CO2[	534	]=	769.0530	/coeff;
    CO2[	535	]=	768.7280	/coeff;
    CO2[	536	]=	768.4030	/coeff;
    CO2[	537	]=	768.0780	/coeff;
    CO2[	538	]=	767.7550	/coeff;
    CO2[	539	]=	767.4320	/coeff;
    CO2[	540	]=	767.1100	/coeff;
    CO2[	541	]=	766.7890	/coeff;
    CO2[	542	]=	766.4680	/coeff;
    CO2[	543	]=	766.1490	/coeff;
    CO2[	544	]=	765.8300	/coeff;
    CO2[	545	]=	765.5110	/coeff;
    CO2[	546	]=	765.1940	/coeff;
    CO2[	547	]=	764.8770	/coeff;
    CO2[	548	]=	764.5600	/coeff;
    CO2[	549	]=	764.2450	/coeff;
    CO2[	550	]=	763.9300	/coeff;
    CO2[	551	]=	763.6150	/coeff;
    CO2[	552	]=	763.3020	/coeff;
    CO2[	553	]=	762.9890	/coeff;
    CO2[	554	]=	762.6760	/coeff;
    CO2[	555	]=	762.3640	/coeff;
    CO2[	556	]=	762.0530	/coeff;
    CO2[	557	]=	761.7430	/coeff;
    CO2[	558	]=	761.4330	/coeff;
    CO2[	559	]=	761.1240	/coeff;
    CO2[	560	]=	760.8150	/coeff;
    CO2[	561	]=	760.5070	/coeff;
    CO2[	562	]=	760.1990	/coeff;
    CO2[	563	]=	759.8920	/coeff;
    CO2[	564	]=	759.5860	/coeff;
    CO2[	565	]=	759.2800	/coeff;
    CO2[	566	]=	758.9750	/coeff;
    CO2[	567	]=	758.6700	/coeff;
    CO2[	568	]=	758.3660	/coeff;
    CO2[	569	]=	758.0630	/coeff;
    CO2[	570	]=	757.7600	/coeff;
    CO2[	571	]=	757.4570	/coeff;
    CO2[	572	]=	757.1560	/coeff;
    CO2[	573	]=	756.8540	/coeff;
    CO2[	574	]=	756.5530	/coeff;
    CO2[	575	]=	756.2530	/coeff;
    CO2[	576	]=	755.9530	/coeff;
    CO2[	577	]=	755.6540	/coeff;
    CO2[	578	]=	755.3560	/coeff;
    CO2[	579	]=	755.0570	/coeff;
    CO2[	580	]=	754.7600	/coeff;
    CO2[	581	]=	754.4630	/coeff;
    CO2[	582	]=	754.1660	/coeff;
    CO2[	583	]=	753.8700	/coeff;
    CO2[	584	]=	753.5740	/coeff;
    CO2[	585	]=	753.2790	/coeff;
    CO2[	586	]=	752.9850	/coeff;
    CO2[	587	]=	752.6900	/coeff;
    CO2[	588	]=	752.3970	/coeff;
    CO2[	589	]=	752.1040	/coeff;
    CO2[	590	]=	751.8110	/coeff;
    CO2[	591	]=	751.5190	/coeff;
    CO2[	592	]=	751.2270	/coeff;
    CO2[	593	]=	750.9360	/coeff;
    CO2[	594	]=	750.6460	/coeff;
    CO2[	595	]=	750.3550	/coeff;
    CO2[	596	]=	750.0660	/coeff;
    CO2[	597	]=	749.7760	/coeff;
    CO2[	598	]=	749.4880	/coeff;
    CO2[	599	]=	749.1990	/coeff;
    CO2[	600	]=	748.9110	/coeff;
    CO2[	601	]=	748.6240	/coeff;
    CO2[	602	]=	748.3370	/coeff;
    CO2[	603	]=	748.0510	/coeff;
    CO2[	604	]=	747.7650	/coeff;
    CO2[	605	]=	747.4790	/coeff;
    CO2[	606	]=	747.1940	/coeff;
    CO2[	607	]=	746.9100	/coeff;
    CO2[	608	]=	746.6260	/coeff;
    CO2[	609	]=	746.3420	/coeff;
    CO2[	610	]=	746.0590	/coeff;
    CO2[	611	]=	745.7760	/coeff;
    CO2[	612	]=	745.4940	/coeff;
    CO2[	613	]=	745.2120	/coeff;
    CO2[	614	]=	744.9300	/coeff;
    CO2[	615	]=	744.6490	/coeff;
    CO2[	616	]=	744.3690	/coeff;
    CO2[	617	]=	744.0890	/coeff;
    CO2[	618	]=	743.8090	/coeff;
    CO2[	619	]=	743.5300	/coeff;
    CO2[	620	]=	743.2510	/coeff;
    CO2[	621	]=	742.9730	/coeff;
    CO2[	622	]=	742.6950	/coeff;
    CO2[	623	]=	742.4170	/coeff;
    CO2[	624	]=	742.1400	/coeff;
    CO2[	625	]=	741.8640	/coeff;
    CO2[	626	]=	741.5880	/coeff;
    CO2[	627	]=	741.3120	/coeff;
    CO2[	628	]=	741.0370	/coeff;
    CO2[	629	]=	740.7620	/coeff;
    CO2[	630	]=	740.4870	/coeff;
    CO2[	631	]=	740.2130	/coeff;
    CO2[	632	]=	739.9400	/coeff;
    CO2[	633	]=	739.6670	/coeff;
    CO2[	634	]=	739.3940	/coeff;
    CO2[	635	]=	739.1220	/coeff;
    CO2[	636	]=	738.8500	/coeff;
    CO2[	637	]=	738.5780	/coeff;
    CO2[	638	]=	738.3070	/coeff;
    CO2[	639	]=	738.0370	/coeff;
    CO2[	640	]=	737.7660	/coeff;
    CO2[	641	]=	737.4970	/coeff;
    CO2[	642	]=	737.2270	/coeff;
    CO2[	643	]=	736.9580	/coeff;
    CO2[	644	]=	736.6900	/coeff;
    CO2[	645	]=	736.4220	/coeff;
    CO2[	646	]=	736.1540	/coeff;
    CO2[	647	]=	735.8870	/coeff;
    CO2[	648	]=	735.6200	/coeff;
    CO2[	649	]=	735.3530	/coeff;
    CO2[	650	]=	735.0870	/coeff;
    CO2[	651	]=	734.8210	/coeff;
    CO2[	652	]=	734.5560	/coeff;
    CO2[	653	]=	734.2910	/coeff;
    CO2[	654	]=	734.0270	/coeff;
    CO2[	655	]=	733.7630	/coeff;
    CO2[	656	]=	733.4990	/coeff;
    CO2[	657	]=	733.2360	/coeff;
    CO2[	658	]=	732.9730	/coeff;
    CO2[	659	]=	732.7110	/coeff;
    CO2[	660	]=	732.4490	/coeff;
    CO2[	661	]=	732.1870	/coeff;
    CO2[	662	]=	731.9260	/coeff;
    CO2[	663	]=	731.6650	/coeff;
    CO2[	664	]=	731.4050	/coeff;
    CO2[	665	]=	731.1450	/coeff;
    CO2[	666	]=	730.8850	/coeff;
    CO2[	667	]=	730.6260	/coeff;
    CO2[	668	]=	730.3670	/coeff;
    CO2[	669	]=	730.1080	/coeff;
    CO2[	670	]=	729.8500	/coeff;
    CO2[	671	]=	729.5930	/coeff;
    CO2[	672	]=	729.3350	/coeff;
    CO2[	673	]=	729.0790	/coeff;
    CO2[	674	]=	728.8220	/coeff;
    CO2[	675	]=	728.5660	/coeff;
    CO2[	676	]=	728.3100	/coeff;
    CO2[	677	]=	728.0550	/coeff;
    CO2[	678	]=	727.8000	/coeff;
    CO2[	679	]=	727.5450	/coeff;
    CO2[	680	]=	727.2910	/coeff;
    CO2[	681	]=	727.0370	/coeff;
    CO2[	682	]=	726.7840	/coeff;
    CO2[	683	]=	726.5310	/coeff;
    CO2[	684	]=	726.2780	/coeff;
    CO2[	685	]=	726.0260	/coeff;
    CO2[	686	]=	725.7740	/coeff;
    CO2[	687	]=	725.5220	/coeff;
    CO2[	688	]=	725.2710	/coeff;
    CO2[	689	]=	725.0200	/coeff;
    CO2[	690	]=	724.7700	/coeff;
    CO2[	691	]=	724.5200	/coeff;
    CO2[	692	]=	724.2700	/coeff;
    CO2[	693	]=	724.0210	/coeff;
    CO2[	694	]=	723.7720	/coeff;
    CO2[	695	]=	723.5240	/coeff;
    CO2[	696	]=	723.2750	/coeff;
    CO2[	697	]=	723.0280	/coeff;
    CO2[	698	]=	722.7800	/coeff;
    CO2[	699	]=	722.5330	/coeff;
    CO2[	700	]=	722.2860	/coeff;
    CO2[	701	]=	722.0400	/coeff;
    CO2[	702	]=	721.7940	/coeff;
    CO2[	703	]=	721.5480	/coeff;
    CO2[	704	]=	721.3030	/coeff;
    CO2[	705	]=	721.0580	/coeff;
    CO2[	706	]=	720.8140	/coeff;
    CO2[	707	]=	720.5690	/coeff;
    CO2[	708	]=	720.3260	/coeff;
    CO2[	709	]=	720.0820	/coeff;
    CO2[	710	]=	719.8390	/coeff;
    CO2[	711	]=	719.5960	/coeff;
    CO2[	712	]=	719.3540	/coeff;
    CO2[	713	]=	719.1120	/coeff;
    CO2[	714	]=	718.8700	/coeff;
    CO2[	715	]=	718.6290	/coeff;
    CO2[	716	]=	718.3880	/coeff;
    CO2[	717	]=	718.1470	/coeff;
    CO2[	718	]=	717.9070	/coeff;
    CO2[	719	]=	717.6670	/coeff;
    CO2[	720	]=	717.4270	/coeff;
    CO2[	721	]=	717.1880	/coeff;
    CO2[	722	]=	716.9490	/coeff;
    CO2[	723	]=	716.7100	/coeff;
    CO2[	724	]=	716.4720	/coeff;
    CO2[	725	]=	716.2340	/coeff;
    CO2[	726	]=	715.9970	/coeff;
    CO2[	727	]=	715.7590	/coeff;
    CO2[	728	]=	715.5220	/coeff;
    CO2[	729	]=	715.2860	/coeff;
    CO2[	730	]=	715.0500	/coeff;
    CO2[	731	]=	714.8140	/coeff;
    CO2[	732	]=	714.5780	/coeff;
    CO2[	733	]=	714.3430	/coeff;
    CO2[	734	]=	714.1080	/coeff;
    CO2[	735	]=	713.9910	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp534(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9487	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.8000	/coeff;
    CO2[	253	]=	408.7830	/coeff;
    CO2[	254	]=	411.8410	/coeff;
    CO2[	255	]=	414.9820	/coeff;
    CO2[	256	]=	418.2050	/coeff;
    CO2[	257	]=	421.5300	/coeff;
    CO2[	258	]=	424.9690	/coeff;
    CO2[	259	]=	428.5200	/coeff;
    CO2[	260	]=	432.1820	/coeff;
    CO2[	261	]=	435.9539	/coeff;
    CO2[	262	]=	439.8350	/coeff;
    CO2[	263	]=	443.8240	/coeff;
    CO2[	264	]=	447.9240	/coeff;
    CO2[	265	]=	452.1319	/coeff;
    CO2[	266	]=	456.4519	/coeff;
    CO2[	267	]=	460.8939	/coeff;
    CO2[	268	]=	465.4699	/coeff;
    CO2[	269	]=	470.1789	/coeff;
    CO2[	270	]=	475.0209	/coeff;
    CO2[	271	]=	479.9949	/coeff;
    CO2[	272	]=	485.1019	/coeff;
    CO2[	273	]=	490.3439	/coeff;
    CO2[	274	]=	495.7199	/coeff;
    CO2[	275	]=	501.2329	/coeff;
    CO2[	276	]=	506.8829	/coeff;
    CO2[	277	]=	512.4729	/coeff;
    CO2[	278	]=	517.8179	/coeff;
    CO2[	279	]=	522.9369	/coeff;
    CO2[	280	]=	527.8389	/coeff;
    CO2[	281	]=	532.5319	/coeff;
    CO2[	282	]=	537.0229	/coeff;
    CO2[	283	]=	541.3159	/coeff;
    CO2[	284	]=	545.4139	/coeff;
    CO2[	285	]=	549.3190	/coeff;
    CO2[	286	]=	553.0350	/coeff;
    CO2[	287	]=	556.4660	/coeff;
    CO2[	288	]=	559.5240	/coeff;
    CO2[	289	]=	562.2170	/coeff;
    CO2[	290	]=	564.5510	/coeff;
    CO2[	291	]=	566.5300	/coeff;
    CO2[	292	]=	568.1600	/coeff;
    CO2[	293	]=	569.4430	/coeff;
    CO2[	294	]=	570.3840	/coeff;
    CO2[	295	]=	570.9860	/coeff;
    CO2[	296	]=	571.2520	/coeff;
    CO2[	297	]=	571.2560	/coeff;
    CO2[	298	]=	571.0650	/coeff;
    CO2[	299	]=	570.6770	/coeff;
    CO2[	300	]=	570.0880	/coeff;
    CO2[	301	]=	569.2990	/coeff;
    CO2[	302	]=	568.3090	/coeff;
    CO2[	303	]=	567.1170	/coeff;
    CO2[	304	]=	565.7240	/coeff;
    CO2[	305	]=	564.1300	/coeff;
    CO2[	306	]=	562.3370	/coeff;
    CO2[	307	]=	560.4280	/coeff;
    CO2[	308	]=	558.4830	/coeff;
    CO2[	309	]=	556.4950	/coeff;
    CO2[	310	]=	554.4620	/coeff;
    CO2[	311	]=	552.3800	/coeff;
    CO2[	312	]=	550.2470	/coeff;
    CO2[	313	]=	548.0620	/coeff;
    CO2[	314	]=	545.8230	/coeff;
    CO2[	315	]=	543.5280	/coeff;
    CO2[	316	]=	541.1780	/coeff;
    CO2[	317	]=	538.8040	/coeff;
    CO2[	318	]=	536.4390	/coeff;
    CO2[	319	]=	534.0780	/coeff;
    CO2[	320	]=	531.7190	/coeff;
    CO2[	321	]=	529.3610	/coeff;
    CO2[	322	]=	527.0030	/coeff;
    CO2[	323	]=	524.6420	/coeff;
    CO2[	324	]=	522.2770	/coeff;
    CO2[	325	]=	519.9070	/coeff;
    CO2[	326	]=	517.5310	/coeff;
    CO2[	327	]=	515.1600	/coeff;
    CO2[	328	]=	512.8050	/coeff;
    CO2[	329	]=	510.4640	/coeff;
    CO2[	330	]=	508.1350	/coeff;
    CO2[	331	]=	505.8180	/coeff;
    CO2[	332	]=	503.5110	/coeff;
    CO2[	333	]=	501.2140	/coeff;
    CO2[	334	]=	498.9250	/coeff;
    CO2[	335	]=	496.6440	/coeff;
    CO2[	336	]=	494.3700	/coeff;
    CO2[	337	]=	492.1150	/coeff;
    CO2[	338	]=	489.8900	/coeff;
    CO2[	339	]=	487.6930	/coeff;
    CO2[	340	]=	485.5240	/coeff;
    CO2[	341	]=	483.3800	/coeff;
    CO2[	342	]=	481.2620	/coeff;
    CO2[	343	]=	479.1690	/coeff;
    CO2[	344	]=	477.0990	/coeff;
    CO2[	345	]=	475.0520	/coeff;
    CO2[	346	]=	473.0270	/coeff;
    CO2[	347	]=	471.0240	/coeff;
    CO2[	348	]=	469.0410	/coeff;
    CO2[	349	]=	467.0790	/coeff;
    CO2[	350	]=	465.1360	/coeff;
    CO2[	351	]=	463.2120	/coeff;
    CO2[	352	]=	461.3070	/coeff;
    CO2[	353	]=	459.4200	/coeff;
    CO2[	354	]=	457.5500	/coeff;
    CO2[	355	]=	455.6970	/coeff;
    CO2[	356	]=	453.8610	/coeff;
    CO2[	357	]=	452.0410	/coeff;
    CO2[	358	]=	450.2360	/coeff;
    CO2[	359	]=	448.4470	/coeff;
    CO2[	360	]=	446.6720	/coeff;
    CO2[	361	]=	444.9120	/coeff;
    CO2[	362	]=	443.1670	/coeff;
    CO2[	363	]=	441.4370	/coeff;
    CO2[	364	]=	439.7210	/coeff;
    CO2[	365	]=	438.0190	/coeff;
    CO2[	366	]=	436.3310	/coeff;
    CO2[	367	]=	434.6570	/coeff;
    CO2[	368	]=	432.9960	/coeff;
    CO2[	369	]=	431.3480	/coeff;
    CO2[	370	]=	429.7130	/coeff;
    CO2[	371	]=	428.0900	/coeff;
    CO2[	372	]=	426.4800	/coeff;
    CO2[	373	]=	424.8820	/coeff;
    CO2[	374	]=	423.2950	/coeff;
    CO2[	375	]=	421.7210	/coeff;
    CO2[	376	]=	420.1570	/coeff;
    CO2[	377	]=	418.6460	/coeff;
    CO2[	378	]=	417.2220	/coeff;
    CO2[	379	]=	415.8800	/coeff;
    CO2[	380	]=	414.6190	/coeff;
    CO2[	381	]=	413.4330	/coeff;
    CO2[	382	]=	412.3210	/coeff;
    CO2[	383	]=	411.2810	/coeff;
    CO2[	384	]=	410.3090	/coeff;
    CO2[	385	]=	409.4040	/coeff;
    CO2[	386	]=	408.5630	/coeff;
    CO2[	387	]=	407.7850	/coeff;
    CO2[	388	]=	407.0670	/coeff;
    CO2[	389	]=	406.4080	/coeff;
    CO2[	390	]=	405.8080	/coeff;
    CO2[	391	]=	405.2640	/coeff;
    CO2[	392	]=	404.7770	/coeff;
    CO2[	393	]=	404.3460	/coeff;
    CO2[	394	]=	403.9680	/coeff;
    CO2[	395	]=	403.6450	/coeff;
    CO2[	396	]=	403.3740	/coeff;
    CO2[	397	]=	403.1550	/coeff;
    CO2[	398	]=	402.9880	/coeff;
    CO2[	399	]=	402.8710	/coeff;
    CO2[	400	]=	402.8050	/coeff;
    CO2[	401	]=	402.7880	/coeff;
    CO2[	402	]=	402.8200	/coeff;
    CO2[	403	]=	402.9010	/coeff;
    CO2[	404	]=	403.0300	/coeff;
    CO2[	405	]=	403.2070	/coeff;
    CO2[	406	]=	403.4310	/coeff;
    CO2[	407	]=	403.6620	/coeff;
    CO2[	408	]=	403.8630	/coeff;
    CO2[	409	]=	404.0390	/coeff;
    CO2[	410	]=	404.1920	/coeff;
    CO2[	411	]=	404.3250	/coeff;
    CO2[	412	]=	404.4400	/coeff;
    CO2[	413	]=	404.5400	/coeff;
    CO2[	414	]=	404.6250	/coeff;
    CO2[	415	]=	404.6980	/coeff;
    CO2[	416	]=	404.7590	/coeff;
    CO2[	417	]=	404.8090	/coeff;
    CO2[	418	]=	404.8500	/coeff;
    CO2[	419	]=	404.8820	/coeff;
    CO2[	420	]=	404.9060	/coeff;
    CO2[	421	]=	404.9220	/coeff;
    CO2[	422	]=	404.9320	/coeff;
    CO2[	423	]=	404.9350	/coeff;
    CO2[	424	]=	404.9330	/coeff;
    CO2[	425	]=	404.9260	/coeff;
    CO2[	426	]=	404.9160	/coeff;
    CO2[	427	]=	404.9010	/coeff;
    CO2[	428	]=	404.8830	/coeff;
    CO2[	429	]=	404.8610	/coeff;
    CO2[	430	]=	404.8360	/coeff;
    CO2[	431	]=	404.8090	/coeff;
    CO2[	432	]=	404.7790	/coeff;
    CO2[	433	]=	404.7470	/coeff;
    CO2[	434	]=	404.7120	/coeff;
    CO2[	435	]=	404.6760	/coeff;
    CO2[	436	]=	404.6370	/coeff;
    CO2[	437	]=	404.5970	/coeff;
    CO2[	438	]=	404.5550	/coeff;
    CO2[	439	]=	404.5120	/coeff;
    CO2[	440	]=	404.4670	/coeff;
    CO2[	441	]=	404.4210	/coeff;
    CO2[	442	]=	404.3740	/coeff;
    CO2[	443	]=	404.3260	/coeff;
    CO2[	444	]=	404.2760	/coeff;
    CO2[	445	]=	404.2260	/coeff;
    CO2[	446	]=	404.1750	/coeff;
    CO2[	447	]=	404.1230	/coeff;
    CO2[	448	]=	404.0700	/coeff;
    CO2[	449	]=	404.0160	/coeff;
    CO2[	450	]=	403.9620	/coeff;
    CO2[	451	]=	403.9070	/coeff;
    CO2[	452	]=	403.8510	/coeff;
    CO2[	453	]=	403.7950	/coeff;
    CO2[	454	]=	403.7390	/coeff;
    CO2[	455	]=	403.6810	/coeff;
    CO2[	456	]=	403.6240	/coeff;
    CO2[	457	]=	403.5650	/coeff;
    CO2[	458	]=	403.5070	/coeff;
    CO2[	459	]=	403.4480	/coeff;
    CO2[	460	]=	403.3890	/coeff;
    CO2[	461	]=	403.3290	/coeff;
    CO2[	462	]=	403.2690	/coeff;
    CO2[	463	]=	403.2080	/coeff;
    CO2[	464	]=	403.1470	/coeff;
    CO2[	465	]=	403.0860	/coeff;
    CO2[	466	]=	403.0250	/coeff;
    CO2[	467	]=	402.9630	/coeff;
    CO2[	468	]=	402.9010	/coeff;
    CO2[	469	]=	402.8380	/coeff;
    CO2[	470	]=	402.7750	/coeff;
    CO2[	471	]=	402.7120	/coeff;
    CO2[	472	]=	402.6490	/coeff;
    CO2[	473	]=	402.5850	/coeff;
    CO2[	474	]=	402.5210	/coeff;
    CO2[	475	]=	402.4560	/coeff;
    CO2[	476	]=	402.3920	/coeff;
    CO2[	477	]=	402.3270	/coeff;
    CO2[	478	]=	402.2610	/coeff;
    CO2[	479	]=	402.1950	/coeff;
    CO2[	480	]=	402.1290	/coeff;
    CO2[	481	]=	402.0630	/coeff;
    CO2[	482	]=	401.9960	/coeff;
    CO2[	483	]=	401.9290	/coeff;
    CO2[	484	]=	401.8620	/coeff;
    CO2[	485	]=	401.7950	/coeff;
    CO2[	486	]=	401.7290	/coeff;
    CO2[	487	]=	401.6620	/coeff;
    CO2[	488	]=	401.5960	/coeff;
    CO2[	489	]=	401.5290	/coeff;
    CO2[	490	]=	401.4630	/coeff;
    CO2[	491	]=	401.3960	/coeff;
    CO2[	492	]=	401.3290	/coeff;
    CO2[	493	]=	401.2610	/coeff;
    CO2[	494	]=	401.1940	/coeff;
    CO2[	495	]=	401.1270	/coeff;
    CO2[	496	]=	401.0590	/coeff;
    CO2[	497	]=	400.9910	/coeff;
    CO2[	498	]=	400.9230	/coeff;
    CO2[	499	]=	400.8550	/coeff;
    CO2[	500	]=	400.7880	/coeff;
    CO2[	501	]=	400.7200	/coeff;
    CO2[	502	]=	400.6520	/coeff;
    CO2[	503	]=	400.5840	/coeff;
    CO2[	504	]=	400.5160	/coeff;
    CO2[	505	]=	400.4480	/coeff;
    CO2[	506	]=	400.3800	/coeff;
    CO2[	507	]=	400.3120	/coeff;
    CO2[	508	]=	400.2450	/coeff;
    CO2[	509	]=	400.1770	/coeff;
    CO2[	510	]=	400.1100	/coeff;
    CO2[	511	]=	400.0420	/coeff;
    CO2[	512	]=	399.9750	/coeff;
    CO2[	513	]=	399.9080	/coeff;
    CO2[	514	]=	399.8410	/coeff;
    CO2[	515	]=	399.7730	/coeff;
    CO2[	516	]=	399.7070	/coeff;
    CO2[	517	]=	399.6400	/coeff;
    CO2[	518	]=	399.5730	/coeff;
    CO2[	519	]=	399.5060	/coeff;
    CO2[	520	]=	399.4400	/coeff;
    CO2[	521	]=	399.3740	/coeff;
    CO2[	522	]=	399.3070	/coeff;
    CO2[	523	]=	399.2410	/coeff;
    CO2[	524	]=	399.1750	/coeff;
    CO2[	525	]=	399.1100	/coeff;
    CO2[	526	]=	399.0440	/coeff;
    CO2[	527	]=	398.9780	/coeff;
    CO2[	528	]=	398.9130	/coeff;
    CO2[	529	]=	398.8470	/coeff;
    CO2[	530	]=	398.7820	/coeff;
    CO2[	531	]=	398.7170	/coeff;
    CO2[	532	]=	398.6520	/coeff;
    CO2[	533	]=	398.5870	/coeff;
    CO2[	534	]=	398.5230	/coeff;
    CO2[	535	]=	398.4580	/coeff;
    CO2[	536	]=	398.3940	/coeff;
    CO2[	537	]=	398.3290	/coeff;
    CO2[	538	]=	398.2650	/coeff;
    CO2[	539	]=	398.2010	/coeff;
    CO2[	540	]=	398.1370	/coeff;
    CO2[	541	]=	398.0730	/coeff;
    CO2[	542	]=	398.0090	/coeff;
    CO2[	543	]=	397.9460	/coeff;
    CO2[	544	]=	397.8820	/coeff;
    CO2[	545	]=	397.8190	/coeff;
    CO2[	546	]=	397.7550	/coeff;
    CO2[	547	]=	397.6920	/coeff;
    CO2[	548	]=	397.6290	/coeff;
    CO2[	549	]=	397.5660	/coeff;
    CO2[	550	]=	397.5030	/coeff;
    CO2[	551	]=	397.4400	/coeff;
    CO2[	552	]=	397.3780	/coeff;
    CO2[	553	]=	397.3150	/coeff;
    CO2[	554	]=	397.2530	/coeff;
    CO2[	555	]=	397.1900	/coeff;
    CO2[	556	]=	397.1280	/coeff;
    CO2[	557	]=	397.0660	/coeff;
    CO2[	558	]=	397.0040	/coeff;
    CO2[	559	]=	396.9420	/coeff;
    CO2[	560	]=	396.8800	/coeff;
    CO2[	561	]=	396.8180	/coeff;
    CO2[	562	]=	396.7560	/coeff;
    CO2[	563	]=	396.6940	/coeff;
    CO2[	564	]=	396.6330	/coeff;
    CO2[	565	]=	396.5710	/coeff;
    CO2[	566	]=	396.5100	/coeff;
    CO2[	567	]=	396.4480	/coeff;
    CO2[	568	]=	396.3870	/coeff;
    CO2[	569	]=	396.3250	/coeff;
    CO2[	570	]=	396.2640	/coeff;
    CO2[	571	]=	396.2030	/coeff;
    CO2[	572	]=	396.1410	/coeff;
    CO2[	573	]=	396.0800	/coeff;
    CO2[	574	]=	396.0190	/coeff;
    CO2[	575	]=	395.9580	/coeff;
    CO2[	576	]=	395.8970	/coeff;
    CO2[	577	]=	395.8360	/coeff;
    CO2[	578	]=	395.7740	/coeff;
    CO2[	579	]=	395.7130	/coeff;
    CO2[	580	]=	395.6520	/coeff;
    CO2[	581	]=	395.5910	/coeff;
    CO2[	582	]=	395.5300	/coeff;
    CO2[	583	]=	395.4690	/coeff;
    CO2[	584	]=	395.4070	/coeff;
    CO2[	585	]=	395.3460	/coeff;
    CO2[	586	]=	395.2850	/coeff;
    CO2[	587	]=	395.2230	/coeff;
    CO2[	588	]=	395.1620	/coeff;
    CO2[	589	]=	395.1000	/coeff;
    CO2[	590	]=	395.0390	/coeff;
    CO2[	591	]=	394.9780	/coeff;
    CO2[	592	]=	394.9160	/coeff;
    CO2[	593	]=	394.8550	/coeff;
    CO2[	594	]=	394.7950	/coeff;
    CO2[	595	]=	394.7340	/coeff;
    CO2[	596	]=	394.6740	/coeff;
    CO2[	597	]=	394.6130	/coeff;
    CO2[	598	]=	394.5530	/coeff;
    CO2[	599	]=	394.4930	/coeff;
    CO2[	600	]=	394.4340	/coeff;
    CO2[	601	]=	394.3740	/coeff;
    CO2[	602	]=	394.3150	/coeff;
    CO2[	603	]=	394.2560	/coeff;
    CO2[	604	]=	394.1960	/coeff;
    CO2[	605	]=	394.1380	/coeff;
    CO2[	606	]=	394.0790	/coeff;
    CO2[	607	]=	394.0200	/coeff;
    CO2[	608	]=	393.9620	/coeff;
    CO2[	609	]=	393.9030	/coeff;
    CO2[	610	]=	393.8450	/coeff;
    CO2[	611	]=	393.7870	/coeff;
    CO2[	612	]=	393.7290	/coeff;
    CO2[	613	]=	393.6710	/coeff;
    CO2[	614	]=	393.6140	/coeff;
    CO2[	615	]=	393.5560	/coeff;
    CO2[	616	]=	393.4990	/coeff;
    CO2[	617	]=	393.4420	/coeff;
    CO2[	618	]=	393.3850	/coeff;
    CO2[	619	]=	393.3280	/coeff;
    CO2[	620	]=	393.2710	/coeff;
    CO2[	621	]=	393.2140	/coeff;
    CO2[	622	]=	393.1580	/coeff;
    CO2[	623	]=	393.1010	/coeff;
    CO2[	624	]=	393.0450	/coeff;
    CO2[	625	]=	392.9890	/coeff;
    CO2[	626	]=	392.9330	/coeff;
    CO2[	627	]=	392.8770	/coeff;
    CO2[	628	]=	392.8210	/coeff;
    CO2[	629	]=	392.7650	/coeff;
    CO2[	630	]=	392.7100	/coeff;
    CO2[	631	]=	392.6540	/coeff;
    CO2[	632	]=	392.5990	/coeff;
    CO2[	633	]=	392.5440	/coeff;
    CO2[	634	]=	392.4890	/coeff;
    CO2[	635	]=	392.4340	/coeff;
    CO2[	636	]=	392.3790	/coeff;
    CO2[	637	]=	392.3240	/coeff;
    CO2[	638	]=	392.2690	/coeff;
    CO2[	639	]=	392.2150	/coeff;
    CO2[	640	]=	392.1600	/coeff;
    CO2[	641	]=	392.1060	/coeff;
    CO2[	642	]=	392.0520	/coeff;
    CO2[	643	]=	391.9980	/coeff;
    CO2[	644	]=	391.9440	/coeff;
    CO2[	645	]=	391.8900	/coeff;
    CO2[	646	]=	391.8360	/coeff;
    CO2[	647	]=	391.7830	/coeff;
    CO2[	648	]=	391.7290	/coeff;
    CO2[	649	]=	391.6760	/coeff;
    CO2[	650	]=	391.6230	/coeff;
    CO2[	651	]=	391.5690	/coeff;
    CO2[	652	]=	391.5160	/coeff;
    CO2[	653	]=	391.4630	/coeff;
    CO2[	654	]=	391.4100	/coeff;
    CO2[	655	]=	391.3580	/coeff;
    CO2[	656	]=	391.3050	/coeff;
    CO2[	657	]=	391.2520	/coeff;
    CO2[	658	]=	391.2000	/coeff;
    CO2[	659	]=	391.1470	/coeff;
    CO2[	660	]=	391.0950	/coeff;
    CO2[	661	]=	391.0430	/coeff;
    CO2[	662	]=	390.9910	/coeff;
    CO2[	663	]=	390.9390	/coeff;
    CO2[	664	]=	390.8870	/coeff;
    CO2[	665	]=	390.8350	/coeff;
    CO2[	666	]=	390.7840	/coeff;
    CO2[	667	]=	390.7320	/coeff;
    CO2[	668	]=	390.6810	/coeff;
    CO2[	669	]=	390.6290	/coeff;
    CO2[	670	]=	390.5780	/coeff;
    CO2[	671	]=	390.5270	/coeff;
    CO2[	672	]=	390.4760	/coeff;
    CO2[	673	]=	390.4250	/coeff;
    CO2[	674	]=	390.3740	/coeff;
    CO2[	675	]=	390.3230	/coeff;
    CO2[	676	]=	390.2720	/coeff;
    CO2[	677	]=	390.2210	/coeff;
    CO2[	678	]=	390.1710	/coeff;
    CO2[	679	]=	390.1210	/coeff;
    CO2[	680	]=	390.0700	/coeff;
    CO2[	681	]=	390.0200	/coeff;
    CO2[	682	]=	389.9700	/coeff;
    CO2[	683	]=	389.9200	/coeff;
    CO2[	684	]=	389.8700	/coeff;
    CO2[	685	]=	389.8200	/coeff;
    CO2[	686	]=	389.7700	/coeff;
    CO2[	687	]=	389.7200	/coeff;
    CO2[	688	]=	389.6710	/coeff;
    CO2[	689	]=	389.6210	/coeff;
    CO2[	690	]=	389.5720	/coeff;
    CO2[	691	]=	389.5220	/coeff;
    CO2[	692	]=	389.4730	/coeff;
    CO2[	693	]=	389.4240	/coeff;
    CO2[	694	]=	389.3750	/coeff;
    CO2[	695	]=	389.3260	/coeff;
    CO2[	696	]=	389.2770	/coeff;
    CO2[	697	]=	389.2280	/coeff;
    CO2[	698	]=	389.1790	/coeff;
    CO2[	699	]=	389.1310	/coeff;
    CO2[	700	]=	389.0820	/coeff;
    CO2[	701	]=	389.0330	/coeff;
    CO2[	702	]=	388.9850	/coeff;
    CO2[	703	]=	388.9370	/coeff;
    CO2[	704	]=	388.8880	/coeff;
    CO2[	705	]=	388.8400	/coeff;
    CO2[	706	]=	388.7920	/coeff;
    CO2[	707	]=	388.7440	/coeff;
    CO2[	708	]=	388.6960	/coeff;
    CO2[	709	]=	388.6480	/coeff;
    CO2[	710	]=	388.6010	/coeff;
    CO2[	711	]=	388.5530	/coeff;
    CO2[	712	]=	388.5050	/coeff;
    CO2[	713	]=	388.4580	/coeff;
    CO2[	714	]=	388.4100	/coeff;
    CO2[	715	]=	388.3630	/coeff;
    CO2[	716	]=	388.3160	/coeff;
    CO2[	717	]=	388.2680	/coeff;
    CO2[	718	]=	388.2210	/coeff;
    CO2[	719	]=	388.1740	/coeff;
    CO2[	720	]=	388.1270	/coeff;
    CO2[	721	]=	388.0800	/coeff;
    CO2[	722	]=	388.0340	/coeff;
    CO2[	723	]=	387.9870	/coeff;
    CO2[	724	]=	387.9400	/coeff;
    CO2[	725	]=	387.8940	/coeff;
    CO2[	726	]=	387.8470	/coeff;
    CO2[	727	]=	387.8010	/coeff;
    CO2[	728	]=	387.7540	/coeff;
    CO2[	729	]=	387.7080	/coeff;
    CO2[	730	]=	387.6620	/coeff;
    CO2[	731	]=	387.6150	/coeff;
    CO2[	732	]=	387.5690	/coeff;
    CO2[	733	]=	387.5230	/coeff;
    CO2[	734	]=	387.4770	/coeff;
    CO2[	735	]=	387.4540	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}

void setCO2_ssp585(double coeff)
{
    CO2[	0	]=	277.9130	/coeff;
    CO2[	1	]=	277.9580	/coeff;
    CO2[	2	]=	278.0170	/coeff;
    CO2[	3	]=	278.0780	/coeff;
    CO2[	4	]=	278.1350	/coeff;
    CO2[	5	]=	278.1940	/coeff;
    CO2[	6	]=	278.2700	/coeff;
    CO2[	7	]=	278.3340	/coeff;
    CO2[	8	]=	278.4120	/coeff;
    CO2[	9	]=	278.4910	/coeff;
    CO2[	10	]=	278.5860	/coeff;
    CO2[	11	]=	278.6830	/coeff;
    CO2[	12	]=	278.7740	/coeff;
    CO2[	13	]=	278.8660	/coeff;
    CO2[	14	]=	278.9590	/coeff;
    CO2[	15	]=	279.0540	/coeff;
    CO2[	16	]=	279.1450	/coeff;
    CO2[	17	]=	279.2430	/coeff;
    CO2[	18	]=	279.3400	/coeff;
    CO2[	19	]=	279.4340	/coeff;
    CO2[	20	]=	279.5320	/coeff;
    CO2[	21	]=	279.6290	/coeff;
    CO2[	22	]=	279.7290	/coeff;
    CO2[	23	]=	279.8310	/coeff;
    CO2[	24	]=	279.9330	/coeff;
    CO2[	25	]=	280.0370	/coeff;
    CO2[	26	]=	280.1410	/coeff;
    CO2[	27	]=	280.2410	/coeff;
    CO2[	28	]=	280.3320	/coeff;
    CO2[	29	]=	280.4150	/coeff;
    CO2[	30	]=	280.4920	/coeff;
    CO2[	31	]=	280.5550	/coeff;
    CO2[	32	]=	280.6230	/coeff;
    CO2[	33	]=	280.6820	/coeff;
    CO2[	34	]=	280.7530	/coeff;
    CO2[	35	]=	280.8340	/coeff;
    CO2[	36	]=	280.9190	/coeff;
    CO2[	37	]=	280.9940	/coeff;
    CO2[	38	]=	281.0730	/coeff;
    CO2[	39	]=	281.1570	/coeff;
    CO2[	40	]=	281.2340	/coeff;
    CO2[	41	]=	281.3220	/coeff;
    CO2[	42	]=	281.4090	/coeff;
    CO2[	43	]=	281.4960	/coeff;
    CO2[	44	]=	281.5660	/coeff;
    CO2[	45	]=	281.6480	/coeff;
    CO2[	46	]=	281.7180	/coeff;
    CO2[	47	]=	281.7900	/coeff;
    CO2[	48	]=	281.8580	/coeff;
    CO2[	49	]=	281.9310	/coeff;
    CO2[	50	]=	281.9920	/coeff;
    CO2[	51	]=	282.0590	/coeff;
    CO2[	52	]=	282.1270	/coeff;
    CO2[	53	]=	282.2000	/coeff;
    CO2[	54	]=	282.2720	/coeff;
    CO2[	55	]=	282.3460	/coeff;
    CO2[	56	]=	282.4150	/coeff;
    CO2[	57	]=	282.4770	/coeff;
    CO2[	58	]=	282.5400	/coeff;
    CO2[	59	]=	282.6180	/coeff;
    CO2[	60	]=	282.6760	/coeff;
    CO2[	61	]=	282.6930	/coeff;
    CO2[	62	]=	282.6930	/coeff;
    CO2[	63	]=	282.7080	/coeff;
    CO2[	64	]=	282.7610	/coeff;
    CO2[	65	]=	282.8250	/coeff;
    CO2[	66	]=	282.8910	/coeff;
    CO2[	67	]=	282.9220	/coeff;
    CO2[	68	]=	282.9660	/coeff;
    CO2[	69	]=	283.0280	/coeff;
    CO2[	70	]=	283.0860	/coeff;
    CO2[	71	]=	283.1490	/coeff;
    CO2[	72	]=	283.1980	/coeff;
    CO2[	73	]=	283.2530	/coeff;
    CO2[	74	]=	283.3110	/coeff;
    CO2[	75	]=	283.3820	/coeff;
    CO2[	76	]=	283.4670	/coeff;
    CO2[	77	]=	283.5280	/coeff;
    CO2[	78	]=	283.5660	/coeff;
    CO2[	79	]=	283.6090	/coeff;
    CO2[	80	]=	283.7250	/coeff;
    CO2[	81	]=	283.8470	/coeff;
    CO2[	82	]=	283.9360	/coeff;
    CO2[	83	]=	284.0680	/coeff;
    CO2[	84	]=	284.2070	/coeff;
    CO2[	85	]=	284.3170	/coeff;
    CO2[	86	]=	284.4510	/coeff;
    CO2[	87	]=	284.5980	/coeff;
    CO2[	88	]=	284.7310	/coeff;
    CO2[	89	]=	284.8460	/coeff;
    CO2[	90	]=	284.9410	/coeff;
    CO2[	91	]=	285.0490	/coeff;
    CO2[	92	]=	285.2040	/coeff;
    CO2[	93	]=	285.3690	/coeff;
    CO2[	94	]=	285.5450	/coeff;
    CO2[	95	]=	285.7390	/coeff;
    CO2[	96	]=	285.9330	/coeff;
    CO2[	97	]=	286.1000	/coeff;
    CO2[	98	]=	286.2710	/coeff;
    CO2[	99	]=	286.4420	/coeff;
    CO2[	100	]=	286.6140	/coeff;
    CO2[	101	]=	286.7810	/coeff;
    CO2[	102	]=	286.9550	/coeff;
    CO2[	103	]=	287.1050	/coeff;
    CO2[	104	]=	287.2250	/coeff;
    CO2[	105	]=	287.3550	/coeff;
    CO2[	106	]=	287.4940	/coeff;
    CO2[	107	]=	287.6640	/coeff;
    CO2[	108	]=	287.8600	/coeff;
    CO2[	109	]=	288.0610	/coeff;
    CO2[	110	]=	288.2910	/coeff;
    CO2[	111	]=	288.5200	/coeff;
    CO2[	112	]=	288.7520	/coeff;
    CO2[	113	]=	288.9930	/coeff;
    CO2[	114	]=	289.2210	/coeff;
    CO2[	115	]=	289.4700	/coeff;
    CO2[	116	]=	289.7370	/coeff;
    CO2[	117	]=	290.0190	/coeff;
    CO2[	118	]=	290.2630	/coeff;
    CO2[	119	]=	290.5120	/coeff;
    CO2[	120	]=	290.7970	/coeff;
    CO2[	121	]=	291.1000	/coeff;
    CO2[	122	]=	291.4140	/coeff;
    CO2[	123	]=	291.7630	/coeff;
    CO2[	124	]=	292.1130	/coeff;
    CO2[	125	]=	292.4580	/coeff;
    CO2[	126	]=	292.8160	/coeff;
    CO2[	127	]=	293.1670	/coeff;
    CO2[	128	]=	293.4770	/coeff;
    CO2[	129	]=	293.7910	/coeff;
    CO2[	130	]=	294.0790	/coeff;
    CO2[	131	]=	294.3650	/coeff;
    CO2[	132	]=	294.6460	/coeff;
    CO2[	133	]=	294.9540	/coeff;
    CO2[	134	]=	295.3000	/coeff;
    CO2[	135	]=	295.6750	/coeff;
    CO2[	136	]=	296.0070	/coeff;
    CO2[	137	]=	296.3250	/coeff;
    CO2[	138	]=	296.6540	/coeff;
    CO2[	139	]=	296.9540	/coeff;
    CO2[	140	]=	297.2890	/coeff;
    CO2[	141	]=	297.6620	/coeff;
    CO2[	142	]=	298.0980	/coeff;
    CO2[	143	]=	298.5180	/coeff;
    CO2[	144	]=	298.9360	/coeff;
    CO2[	145	]=	299.3770	/coeff;
    CO2[	146	]=	299.8290	/coeff;
    CO2[	147	]=	300.3530	/coeff;
    CO2[	148	]=	300.9100	/coeff;
    CO2[	149	]=	301.4190	/coeff;
    CO2[	150	]=	301.9370	/coeff;
    CO2[	151	]=	302.4850	/coeff;
    CO2[	152	]=	303.0110	/coeff;
    CO2[	153	]=	303.4490	/coeff;
    CO2[	154	]=	303.8140	/coeff;
    CO2[	155	]=	304.2460	/coeff;
    CO2[	156	]=	304.6000	/coeff;
    CO2[	157	]=	304.9450	/coeff;
    CO2[	158	]=	305.2710	/coeff;
    CO2[	159	]=	305.6300	/coeff;
    CO2[	160	]=	305.8130	/coeff;
    CO2[	161	]=	305.9540	/coeff;
    CO2[	162	]=	306.1770	/coeff;
    CO2[	163	]=	306.3290	/coeff;
    CO2[	164	]=	306.4950	/coeff;
    CO2[	165	]=	306.6200	/coeff;
    CO2[	166	]=	306.8220	/coeff;
    CO2[	167	]=	307.0930	/coeff;
    CO2[	168	]=	307.4020	/coeff;
    CO2[	169	]=	307.7850	/coeff;
    CO2[	170	]=	308.2270	/coeff;
    CO2[	171	]=	309.0120	/coeff;
    CO2[	172	]=	309.7640	/coeff;
    CO2[	173	]=	310.2940	/coeff;
    CO2[	174	]=	310.8510	/coeff;
    CO2[	175	]=	311.3570	/coeff;
    CO2[	176	]=	311.8110	/coeff;
    CO2[	177	]=	312.1720	/coeff;
    CO2[	178	]=	312.3900	/coeff;
    CO2[	179	]=	312.4130	/coeff;
    CO2[	180	]=	312.3850	/coeff;
    CO2[	181	]=	312.3900	/coeff;
    CO2[	182	]=	312.4860	/coeff;
    CO2[	183	]=	312.5210	/coeff;
    CO2[	184	]=	312.6320	/coeff;
    CO2[	185	]=	312.8210	/coeff;
    CO2[	186	]=	313.0140	/coeff;
    CO2[	187	]=	313.3420	/coeff;
    CO2[	188	]=	313.7300	/coeff;
    CO2[	189	]=	314.0950	/coeff;
    CO2[	190	]=	314.4150	/coeff;
    CO2[	191	]=	314.6980	/coeff;
    CO2[	192	]=	314.9920	/coeff;
    CO2[	193	]=	315.3450	/coeff;
    CO2[	194	]=	315.8070	/coeff;
    CO2[	195	]=	316.6250	/coeff;
    CO2[	196	]=	317.2990	/coeff;
    CO2[	197	]=	318.0440	/coeff;
    CO2[	198	]=	318.6500	/coeff;
    CO2[	199	]=	319.3330	/coeff;
    CO2[	200	]=	319.8160	/coeff;
    CO2[	201	]=	320.8800	/coeff;
    CO2[	202	]=	321.4800	/coeff;
    CO2[	203	]=	322.3890	/coeff;
    CO2[	204	]=	323.2510	/coeff;
    CO2[	205	]=	324.7830	/coeff;
    CO2[	206	]=	325.4000	/coeff;
    CO2[	207	]=	327.3490	/coeff;
    CO2[	208	]=	329.9090	/coeff;
    CO2[	209	]=	330.7560	/coeff;
    CO2[	210	]=	330.8270	/coeff;
    CO2[	211	]=	331.5449	/coeff;
    CO2[	212	]=	333.3529	/coeff;
    CO2[	213	]=	335.0099	/coeff;
    CO2[	214	]=	336.6049	/coeff;
    CO2[	215	]=	338.7049	/coeff;
    CO2[	216	]=	340.0589	/coeff;
    CO2[	217	]=	340.6439	/coeff;
    CO2[	218	]=	342.2659	/coeff;
    CO2[	219	]=	344.0079	/coeff;
    CO2[	220	]=	345.4590	/coeff;
    CO2[	221	]=	346.9029	/coeff;
    CO2[	222	]=	348.7749	/coeff;
    CO2[	223	]=	351.2759	/coeff;
    CO2[	224	]=	352.8939	/coeff;
    CO2[	225	]=	354.0729	/coeff;
    CO2[	226	]=	355.3529	/coeff;
    CO2[	227	]=	356.2289	/coeff;
    CO2[	228	]=	356.9250	/coeff;
    CO2[	229	]=	358.2540	/coeff;
    CO2[	230	]=	360.2390	/coeff;
    CO2[	231	]=	362.0050	/coeff;
    CO2[	232	]=	363.2520	/coeff;
    CO2[	233	]=	365.9330	/coeff;
    CO2[	234	]=	367.8450	/coeff;
    CO2[	235	]=	369.1250	/coeff;
    CO2[	236	]=	370.6730	/coeff;
    CO2[	237	]=	372.8350	/coeff;
    CO2[	238	]=	375.4110	/coeff;
    CO2[	239	]=	376.9870	/coeff;
    CO2[	240	]=	378.9070	/coeff;
    CO2[	241	]=	381.0100	/coeff;
    CO2[	242	]=	382.6030	/coeff;
    CO2[	243	]=	384.7390	/coeff;
    CO2[	244	]=	386.2800	/coeff;
    CO2[	245	]=	388.7170	/coeff;
    CO2[	246	]=	390.9440	/coeff;
    CO2[	247	]=	393.0160	/coeff;
    CO2[	248	]=	395.7250	/coeff;
    CO2[	249	]=	397.5470	/coeff;
    CO2[	250	]=	399.9488	/coeff;
    CO2[	251	]=	403.1170	/coeff;
    CO2[	252	]=	405.7940	/coeff;
    CO2[	253	]=	408.7600	/coeff;
    CO2[	254	]=	411.7900	/coeff;
    CO2[	255	]=	414.8910	/coeff;
    CO2[	256	]=	418.0650	/coeff;
    CO2[	257	]=	421.3350	/coeff;
    CO2[	258	]=	424.7210	/coeff;
    CO2[	259	]=	428.2200	/coeff;
    CO2[	260	]=	431.8300	/coeff;
    CO2[	261	]=	435.5500	/coeff;
    CO2[	262	]=	439.3780	/coeff;
    CO2[	263	]=	443.3150	/coeff;
    CO2[	264	]=	447.3609	/coeff;
    CO2[	265	]=	451.5149	/coeff;
    CO2[	266	]=	455.7789	/coeff;
    CO2[	267	]=	460.1639	/coeff;
    CO2[	268	]=	464.6819	/coeff;
    CO2[	269	]=	469.3309	/coeff;
    CO2[	270	]=	474.1119	/coeff;
    CO2[	271	]=	479.0249	/coeff;
    CO2[	272	]=	484.0719	/coeff;
    CO2[	273	]=	489.2519	/coeff;
    CO2[	274	]=	494.5669	/coeff;
    CO2[	275	]=	500.0189	/coeff;
    CO2[	276	]=	505.6079	/coeff;
    CO2[	277	]=	511.3419	/coeff;
    CO2[	278	]=	517.2279	/coeff;
    CO2[	279	]=	523.2669	/coeff;
    CO2[	280	]=	529.4599	/coeff;
    CO2[	281	]=	535.8089	/coeff;
    CO2[	282	]=	542.3139	/coeff;
    CO2[	283	]=	548.9769	/coeff;
    CO2[	284	]=	555.7999	/coeff;
    CO2[	285	]=	562.7839	/coeff;
    CO2[	286	]=	569.9299	/coeff;
    CO2[	287	]=	577.2579	/coeff;
    CO2[	288	]=	584.7839	/coeff;
    CO2[	289	]=	592.5069	/coeff;
    CO2[	290	]=	600.4289	/coeff;
    CO2[	291	]=	608.5499	/coeff;
    CO2[	292	]=	616.8699	/coeff;
    CO2[	293	]=	625.3909	/coeff;
    CO2[	294	]=	634.1139	/coeff;
    CO2[	295	]=	643.0409	/coeff;
    CO2[	296	]=	652.1719	/coeff;
    CO2[	297	]=	661.5069	/coeff;
    CO2[	298	]=	671.0449	/coeff;
    CO2[	299	]=	680.7889	/coeff;
    CO2[	300	]=	690.7389	/coeff;
    CO2[	301	]=	700.8989	/coeff;
    CO2[	302	]=	711.2689	/coeff;
    CO2[	303	]=	721.8509	/coeff;
    CO2[	304	]=	732.6479	/coeff;
    CO2[	305	]=	743.6619	/coeff;
    CO2[	306	]=	754.8929	/coeff;
    CO2[	307	]=	766.3229	/coeff;
    CO2[	308	]=	777.9299	/coeff;
    CO2[	309	]=	789.7189	/coeff;
    CO2[	310	]=	801.6909	/coeff;
    CO2[	311	]=	813.8479	/coeff;
    CO2[	312	]=	826.1929	/coeff;
    CO2[	313	]=	838.7269	/coeff;
    CO2[	314	]=	851.4519	/coeff;
    CO2[	315	]=	864.3689	/coeff;
    CO2[	316	]=	877.4799	/coeff;
    CO2[	317	]=	890.7089	/coeff;
    CO2[	318	]=	903.9809	/coeff;
    CO2[	319	]=	917.3009	/coeff;
    CO2[	320	]=	930.6709	/coeff;
    CO2[	321	]=	944.0919	/coeff;
    CO2[	322	]=	957.5669	/coeff;
    CO2[	323	]=	971.0959	/coeff;
    CO2[	324	]=	984.6809	/coeff;
    CO2[	325	]=	998.3209	/coeff;
    CO2[	326	]=	1012.0199	/coeff;
    CO2[	327	]=	1025.7399	/coeff;
    CO2[	328	]=	1039.4499	/coeff;
    CO2[	329	]=	1053.1499	/coeff;
    CO2[	330	]=	1066.8499	/coeff;
    CO2[	331	]=	1080.5299	/coeff;
    CO2[	332	]=	1094.2099	/coeff;
    CO2[	333	]=	1107.8899	/coeff;
    CO2[	334	]=	1121.5499	/coeff;
    CO2[	335	]=	1135.2099	/coeff;
    CO2[	336	]=	1148.8599	/coeff;
    CO2[	337	]=	1162.4699	/coeff;
    CO2[	338	]=	1176.0299	/coeff;
    CO2[	339	]=	1189.5299	/coeff;
    CO2[	340	]=	1202.9799	/coeff;
    CO2[	341	]=	1216.3699	/coeff;
    CO2[	342	]=	1229.6999	/coeff;
    CO2[	343	]=	1242.9699	/coeff;
    CO2[	344	]=	1256.1899	/coeff;
    CO2[	345	]=	1269.3499	/coeff;
    CO2[	346	]=	1282.4499	/coeff;
    CO2[	347	]=	1295.4899	/coeff;
    CO2[	348	]=	1308.4699	/coeff;
    CO2[	349	]=	1321.3899	/coeff;
    CO2[	350	]=	1334.2499	/coeff;
    CO2[	351	]=	1347.0499	/coeff;
    CO2[	352	]=	1359.7799	/coeff;
    CO2[	353	]=	1372.4399	/coeff;
    CO2[	354	]=	1385.0399	/coeff;
    CO2[	355	]=	1397.5699	/coeff;
    CO2[	356	]=	1410.0399	/coeff;
    CO2[	357	]=	1422.4299	/coeff;
    CO2[	358	]=	1434.7599	/coeff;
    CO2[	359	]=	1447.0099	/coeff;
    CO2[	360	]=	1459.1899	/coeff;
    CO2[	361	]=	1471.2899	/coeff;
    CO2[	362	]=	1483.3199	/coeff;
    CO2[	363	]=	1495.2799	/coeff;
    CO2[	364	]=	1507.1599	/coeff;
    CO2[	365	]=	1518.9599	/coeff;
    CO2[	366	]=	1530.6799	/coeff;
    CO2[	367	]=	1542.3199	/coeff;
    CO2[	368	]=	1553.8799	/coeff;
    CO2[	369	]=	1565.3599	/coeff;
    CO2[	370	]=	1576.7599	/coeff;
    CO2[	371	]=	1588.0799	/coeff;
    CO2[	372	]=	1599.3099	/coeff;
    CO2[	373	]=	1610.4499	/coeff;
    CO2[	374	]=	1621.5099	/coeff;
    CO2[	375	]=	1632.4899	/coeff;
    CO2[	376	]=	1643.3799	/coeff;
    CO2[	377	]=	1654.1699	/coeff;
    CO2[	378	]=	1664.8799	/coeff;
    CO2[	379	]=	1675.5099	/coeff;
    CO2[	380	]=	1686.0399	/coeff;
    CO2[	381	]=	1696.4799	/coeff;
    CO2[	382	]=	1706.8199	/coeff;
    CO2[	383	]=	1717.0799	/coeff;
    CO2[	384	]=	1727.2399	/coeff;
    CO2[	385	]=	1737.3199	/coeff;
    CO2[	386	]=	1747.2899	/coeff;
    CO2[	387	]=	1757.1699	/coeff;
    CO2[	388	]=	1766.9499	/coeff;
    CO2[	389	]=	1776.6399	/coeff;
    CO2[	390	]=	1786.2199	/coeff;
    CO2[	391	]=	1795.6999	/coeff;
    CO2[	392	]=	1805.0799	/coeff;
    CO2[	393	]=	1814.3599	/coeff;
    CO2[	394	]=	1823.5399	/coeff;
    CO2[	395	]=	1832.6099	/coeff;
    CO2[	396	]=	1841.5799	/coeff;
    CO2[	397	]=	1850.4599	/coeff;
    CO2[	398	]=	1859.2199	/coeff;
    CO2[	399	]=	1867.8899	/coeff;
    CO2[	400	]=	1876.4499	/coeff;
    CO2[	401	]=	1884.8999	/coeff;
    CO2[	402	]=	1893.2399	/coeff;
    CO2[	403	]=	1901.4899	/coeff;
    CO2[	404	]=	1909.6199	/coeff;
    CO2[	405	]=	1917.6499	/coeff;
    CO2[	406	]=	1925.5799	/coeff;
    CO2[	407	]=	1933.3999	/coeff;
    CO2[	408	]=	1941.1099	/coeff;
    CO2[	409	]=	1948.7099	/coeff;
    CO2[	410	]=	1956.2099	/coeff;
    CO2[	411	]=	1963.5999	/coeff;
    CO2[	412	]=	1970.8799	/coeff;
    CO2[	413	]=	1978.0499	/coeff;
    CO2[	414	]=	1985.1100	/coeff;
    CO2[	415	]=	1992.0699	/coeff;
    CO2[	416	]=	1998.9299	/coeff;
    CO2[	417	]=	2005.6699	/coeff;
    CO2[	418	]=	2012.2999	/coeff;
    CO2[	419	]=	2018.8299	/coeff;
    CO2[	420	]=	2025.2499	/coeff;
    CO2[	421	]=	2031.5599	/coeff;
    CO2[	422	]=	2037.7600	/coeff;
    CO2[	423	]=	2043.8500	/coeff;
    CO2[	424	]=	2049.8099	/coeff;
    CO2[	425	]=	2055.6599	/coeff;
    CO2[	426	]=	2061.4200	/coeff;
    CO2[	427	]=	2067.0900	/coeff;
    CO2[	428	]=	2072.6400	/coeff;
    CO2[	429	]=	2078.0599	/coeff;
    CO2[	430	]=	2083.3800	/coeff;
    CO2[	431	]=	2088.5899	/coeff;
    CO2[	432	]=	2093.6800	/coeff;
    CO2[	433	]=	2098.6700	/coeff;
    CO2[	434	]=	2103.5400	/coeff;
    CO2[	435	]=	2108.3100	/coeff;
    CO2[	436	]=	2112.9599	/coeff;
    CO2[	437	]=	2117.5099	/coeff;
    CO2[	438	]=	2121.9499	/coeff;
    CO2[	439	]=	2126.2700	/coeff;
    CO2[	440	]=	2130.4900	/coeff;
    CO2[	441	]=	2134.5899	/coeff;
    CO2[	442	]=	2138.6000	/coeff;
    CO2[	443	]=	2142.4800	/coeff;
    CO2[	444	]=	2146.2599	/coeff;
    CO2[	445	]=	2149.9300	/coeff;
    CO2[	446	]=	2153.4800	/coeff;
    CO2[	447	]=	2156.9200	/coeff;
    CO2[	448	]=	2160.2399	/coeff;
    CO2[	449	]=	2163.4599	/coeff;
    CO2[	450	]=	2166.5700	/coeff;
    CO2[	451	]=	2169.5800	/coeff;
    CO2[	452	]=	2172.4799	/coeff;
    CO2[	453	]=	2175.2700	/coeff;
    CO2[	454	]=	2177.9300	/coeff;
    CO2[	455	]=	2180.4900	/coeff;
    CO2[	456	]=	2182.9500	/coeff;
    CO2[	457	]=	2185.2899	/coeff;
    CO2[	458	]=	2187.5200	/coeff;
    CO2[	459	]=	2189.6500	/coeff;
    CO2[	460	]=	2191.6700	/coeff;
    CO2[	461	]=	2193.5700	/coeff;
    CO2[	462	]=	2195.3300	/coeff;
    CO2[	463	]=	2197.0100	/coeff;
    CO2[	464	]=	2198.5900	/coeff;
    CO2[	465	]=	2200.0700	/coeff;
    CO2[	466	]=	2201.4300	/coeff;
    CO2[	467	]=	2202.6600	/coeff;
    CO2[	468	]=	2203.7900	/coeff;
    CO2[	469	]=	2204.8100	/coeff;
    CO2[	470	]=	2205.7300	/coeff;
    CO2[	471	]=	2206.5300	/coeff;
    CO2[	472	]=	2207.2300	/coeff;
    CO2[	473	]=	2207.8100	/coeff;
    CO2[	474	]=	2208.2900	/coeff;
    CO2[	475	]=	2208.6500	/coeff;
    CO2[	476	]=	2208.9100	/coeff;
    CO2[	477	]=	2209.0699	/coeff;
    CO2[	478	]=	2209.1100	/coeff;
    CO2[	479	]=	2209.0300	/coeff;
    CO2[	480	]=	2208.8400	/coeff;
    CO2[	481	]=	2208.5700	/coeff;
    CO2[	482	]=	2208.1900	/coeff;
    CO2[	483	]=	2207.6900	/coeff;
    CO2[	484	]=	2207.0700	/coeff;
    CO2[	485	]=	2206.3500	/coeff;
    CO2[	486	]=	2205.5200	/coeff;
    CO2[	487	]=	2204.6400	/coeff;
    CO2[	488	]=	2203.7500	/coeff;
    CO2[	489	]=	2202.8600	/coeff;
    CO2[	490	]=	2201.9700	/coeff;
    CO2[	491	]=	2201.1000	/coeff;
    CO2[	492	]=	2200.2200	/coeff;
    CO2[	493	]=	2199.3400	/coeff;
    CO2[	494	]=	2198.4400	/coeff;
    CO2[	495	]=	2197.5400	/coeff;
    CO2[	496	]=	2196.6300	/coeff;
    CO2[	497	]=	2195.7300	/coeff;
    CO2[	498	]=	2194.8300	/coeff;
    CO2[	499	]=	2193.9500	/coeff;
    CO2[	500	]=	2193.0600	/coeff;
    CO2[	501	]=	2192.1600	/coeff;
    CO2[	502	]=	2191.2500	/coeff;
    CO2[	503	]=	2190.3400	/coeff;
    CO2[	504	]=	2189.4300	/coeff;
    CO2[	505	]=	2188.5300	/coeff;
    CO2[	506	]=	2187.6200	/coeff;
    CO2[	507	]=	2186.7200	/coeff;
    CO2[	508	]=	2185.8200	/coeff;
    CO2[	509	]=	2184.9000	/coeff;
    CO2[	510	]=	2183.9900	/coeff;
    CO2[	511	]=	2183.0900	/coeff;
    CO2[	512	]=	2182.1900	/coeff;
    CO2[	513	]=	2181.2900	/coeff;
    CO2[	514	]=	2180.4000	/coeff;
    CO2[	515	]=	2179.5000	/coeff;
    CO2[	516	]=	2178.6000	/coeff;
    CO2[	517	]=	2177.7000	/coeff;
    CO2[	518	]=	2176.8000	/coeff;
    CO2[	519	]=	2175.9100	/coeff;
    CO2[	520	]=	2175.0100	/coeff;
    CO2[	521	]=	2174.1200	/coeff;
    CO2[	522	]=	2173.2300	/coeff;
    CO2[	523	]=	2172.3400	/coeff;
    CO2[	524	]=	2171.4600	/coeff;
    CO2[	525	]=	2170.5700	/coeff;
    CO2[	526	]=	2169.6800	/coeff;
    CO2[	527	]=	2168.7900	/coeff;
    CO2[	528	]=	2167.9100	/coeff;
    CO2[	529	]=	2167.0300	/coeff;
    CO2[	530	]=	2166.1400	/coeff;
    CO2[	531	]=	2165.2700	/coeff;
    CO2[	532	]=	2164.4000	/coeff;
    CO2[	533	]=	2163.5200	/coeff;
    CO2[	534	]=	2162.6301	/coeff;
    CO2[	535	]=	2161.7400	/coeff;
    CO2[	536	]=	2160.8700	/coeff;
    CO2[	537	]=	2160.0000	/coeff;
    CO2[	538	]=	2159.1400	/coeff;
    CO2[	539	]=	2158.2700	/coeff;
    CO2[	540	]=	2157.4000	/coeff;
    CO2[	541	]=	2156.5300	/coeff;
    CO2[	542	]=	2155.6600	/coeff;
    CO2[	543	]=	2154.7900	/coeff;
    CO2[	544	]=	2153.9200	/coeff;
    CO2[	545	]=	2153.0600	/coeff;
    CO2[	546	]=	2152.2200	/coeff;
    CO2[	547	]=	2151.3700	/coeff;
    CO2[	548	]=	2150.5200	/coeff;
    CO2[	549	]=	2149.6600	/coeff;
    CO2[	550	]=	2148.8100	/coeff;
    CO2[	551	]=	2147.9501	/coeff;
    CO2[	552	]=	2147.0900	/coeff;
    CO2[	553	]=	2146.2400	/coeff;
    CO2[	554	]=	2145.3900	/coeff;
    CO2[	555	]=	2144.5400	/coeff;
    CO2[	556	]=	2143.7000	/coeff;
    CO2[	557	]=	2142.8600	/coeff;
    CO2[	558	]=	2142.0200	/coeff;
    CO2[	559	]=	2141.1700	/coeff;
    CO2[	560	]=	2140.3100	/coeff;
    CO2[	561	]=	2139.4600	/coeff;
    CO2[	562	]=	2138.6200	/coeff;
    CO2[	563	]=	2137.8000	/coeff;
    CO2[	564	]=	2136.9600	/coeff;
    CO2[	565	]=	2136.1400	/coeff;
    CO2[	566	]=	2135.3200	/coeff;
    CO2[	567	]=	2134.4700	/coeff;
    CO2[	568	]=	2133.6200	/coeff;
    CO2[	569	]=	2132.8000	/coeff;
    CO2[	570	]=	2131.9900	/coeff;
    CO2[	571	]=	2131.1400	/coeff;
    CO2[	572	]=	2130.2900	/coeff;
    CO2[	573	]=	2129.4700	/coeff;
    CO2[	574	]=	2128.6500	/coeff;
    CO2[	575	]=	2127.8300	/coeff;
    CO2[	576	]=	2127.0000	/coeff;
    CO2[	577	]=	2126.1800	/coeff;
    CO2[	578	]=	2125.3800	/coeff;
    CO2[	579	]=	2124.5700	/coeff;
    CO2[	580	]=	2123.7500	/coeff;
    CO2[	581	]=	2122.9200	/coeff;
    CO2[	582	]=	2122.1000	/coeff;
    CO2[	583	]=	2121.2900	/coeff;
    CO2[	584	]=	2120.4800	/coeff;
    CO2[	585	]=	2119.6700	/coeff;
    CO2[	586	]=	2118.8600	/coeff;
    CO2[	587	]=	2118.0500	/coeff;
    CO2[	588	]=	2117.2400	/coeff;
    CO2[	589	]=	2116.4300	/coeff;
    CO2[	590	]=	2115.6300	/coeff;
    CO2[	591	]=	2114.8200	/coeff;
    CO2[	592	]=	2114.0200	/coeff;
    CO2[	593	]=	2113.2100	/coeff;
    CO2[	594	]=	2112.4100	/coeff;
    CO2[	595	]=	2111.6000	/coeff;
    CO2[	596	]=	2110.8101	/coeff;
    CO2[	597	]=	2110.0100	/coeff;
    CO2[	598	]=	2109.2200	/coeff;
    CO2[	599	]=	2108.4200	/coeff;
    CO2[	600	]=	2107.6200	/coeff;
    CO2[	601	]=	2106.8300	/coeff;
    CO2[	602	]=	2106.0300	/coeff;
    CO2[	603	]=	2105.2400	/coeff;
    CO2[	604	]=	2104.4500	/coeff;
    CO2[	605	]=	2103.6600	/coeff;
    CO2[	606	]=	2102.8800	/coeff;
    CO2[	607	]=	2102.0900	/coeff;
    CO2[	608	]=	2101.3000	/coeff;
    CO2[	609	]=	2100.5300	/coeff;
    CO2[	610	]=	2099.7399	/coeff;
    CO2[	611	]=	2098.9500	/coeff;
    CO2[	612	]=	2098.1700	/coeff;
    CO2[	613	]=	2097.3900	/coeff;
    CO2[	614	]=	2096.6100	/coeff;
    CO2[	615	]=	2095.8300	/coeff;
    CO2[	616	]=	2095.0400	/coeff;
    CO2[	617	]=	2094.2600	/coeff;
    CO2[	618	]=	2093.4900	/coeff;
    CO2[	619	]=	2092.7300	/coeff;
    CO2[	620	]=	2091.9500	/coeff;
    CO2[	621	]=	2091.1700	/coeff;
    CO2[	622	]=	2090.3900	/coeff;
    CO2[	623	]=	2089.6200	/coeff;
    CO2[	624	]=	2088.8700	/coeff;
    CO2[	625	]=	2088.0900	/coeff;
    CO2[	626	]=	2087.3000	/coeff;
    CO2[	627	]=	2086.5500	/coeff;
    CO2[	628	]=	2085.8000	/coeff;
    CO2[	629	]=	2085.0300	/coeff;
    CO2[	630	]=	2084.2500	/coeff;
    CO2[	631	]=	2083.4800	/coeff;
    CO2[	632	]=	2082.7300	/coeff;
    CO2[	633	]=	2081.9700	/coeff;
    CO2[	634	]=	2081.2300	/coeff;
    CO2[	635	]=	2080.4800	/coeff;
    CO2[	636	]=	2079.7000	/coeff;
    CO2[	637	]=	2078.9500	/coeff;
    CO2[	638	]=	2078.2200	/coeff;
    CO2[	639	]=	2077.4600	/coeff;
    CO2[	640	]=	2076.6900	/coeff;
    CO2[	641	]=	2075.9400	/coeff;
    CO2[	642	]=	2075.1900	/coeff;
    CO2[	643	]=	2074.4400	/coeff;
    CO2[	644	]=	2073.6900	/coeff;
    CO2[	645	]=	2072.9500	/coeff;
    CO2[	646	]=	2072.2000	/coeff;
    CO2[	647	]=	2071.4400	/coeff;
    CO2[	648	]=	2070.7100	/coeff;
    CO2[	649	]=	2069.9700	/coeff;
    CO2[	650	]=	2069.2200	/coeff;
    CO2[	651	]=	2068.4800	/coeff;
    CO2[	652	]=	2067.7400	/coeff;
    CO2[	653	]=	2067.0000	/coeff;
    CO2[	654	]=	2066.2600	/coeff;
    CO2[	655	]=	2065.5300	/coeff;
    CO2[	656	]=	2064.7900	/coeff;
    CO2[	657	]=	2064.0500	/coeff;
    CO2[	658	]=	2063.3200	/coeff;
    CO2[	659	]=	2062.5900	/coeff;
    CO2[	660	]=	2061.8600	/coeff;
    CO2[	661	]=	2061.1300	/coeff;
    CO2[	662	]=	2060.4000	/coeff;
    CO2[	663	]=	2059.6600	/coeff;
    CO2[	664	]=	2058.9300	/coeff;
    CO2[	665	]=	2058.2100	/coeff;
    CO2[	666	]=	2057.4900	/coeff;
    CO2[	667	]=	2056.7700	/coeff;
    CO2[	668	]=	2056.0500	/coeff;
    CO2[	669	]=	2055.3200	/coeff;
    CO2[	670	]=	2054.6000	/coeff;
    CO2[	671	]=	2053.8700	/coeff;
    CO2[	672	]=	2053.1400	/coeff;
    CO2[	673	]=	2052.4200	/coeff;
    CO2[	674	]=	2051.7000	/coeff;
    CO2[	675	]=	2050.9800	/coeff;
    CO2[	676	]=	2050.2600	/coeff;
    CO2[	677	]=	2049.5500	/coeff;
    CO2[	678	]=	2048.8300	/coeff;
    CO2[	679	]=	2048.1200	/coeff;
    CO2[	680	]=	2047.4100	/coeff;
    CO2[	681	]=	2046.7000	/coeff;
    CO2[	682	]=	2045.9800	/coeff;
    CO2[	683	]=	2045.2800	/coeff;
    CO2[	684	]=	2044.5800	/coeff;
    CO2[	685	]=	2043.8800	/coeff;
    CO2[	686	]=	2043.1700	/coeff;
    CO2[	687	]=	2042.4600	/coeff;
    CO2[	688	]=	2041.7500	/coeff;
    CO2[	689	]=	2041.0500	/coeff;
    CO2[	690	]=	2040.3600	/coeff;
    CO2[	691	]=	2039.6500	/coeff;
    CO2[	692	]=	2038.9400	/coeff;
    CO2[	693	]=	2038.2400	/coeff;
    CO2[	694	]=	2037.5500	/coeff;
    CO2[	695	]=	2036.8600	/coeff;
    CO2[	696	]=	2036.1500	/coeff;
    CO2[	697	]=	2035.4500	/coeff;
    CO2[	698	]=	2034.7500	/coeff;
    CO2[	699	]=	2034.0600	/coeff;
    CO2[	700	]=	2033.3700	/coeff;
    CO2[	701	]=	2032.6900	/coeff;
    CO2[	702	]=	2032.0000	/coeff;
    CO2[	703	]=	2031.3000	/coeff;
    CO2[	704	]=	2030.6000	/coeff;
    CO2[	705	]=	2029.9200	/coeff;
    CO2[	706	]=	2029.2400	/coeff;
    CO2[	707	]=	2028.5500	/coeff;
    CO2[	708	]=	2027.8500	/coeff;
    CO2[	709	]=	2027.1600	/coeff;
    CO2[	710	]=	2026.4700	/coeff;
    CO2[	711	]=	2025.7900	/coeff;
    CO2[	712	]=	2025.1100	/coeff;
    CO2[	713	]=	2024.4300	/coeff;
    CO2[	714	]=	2023.7400	/coeff;
    CO2[	715	]=	2023.0700	/coeff;
    CO2[	716	]=	2022.4200	/coeff;
    CO2[	717	]=	2021.7200	/coeff;
    CO2[	718	]=	2021.0400	/coeff;
    CO2[	719	]=	2020.4000	/coeff;
    CO2[	720	]=	2019.7000	/coeff;
    CO2[	721	]=	2019.0200	/coeff;
    CO2[	722	]=	2018.3700	/coeff;
    CO2[	723	]=	2017.6700	/coeff;
    CO2[	724	]=	2016.9900	/coeff;
    CO2[	725	]=	2016.3500	/coeff;
    CO2[	726	]=	2015.6800	/coeff;
    CO2[	727	]=	2015.0000	/coeff;
    CO2[	728	]=	2014.3300	/coeff;
    CO2[	729	]=	2013.6700	/coeff;
    CO2[	730	]=	2013.0100	/coeff;
    CO2[	731	]=	2012.3400	/coeff;
    CO2[	732	]=	2011.6700	/coeff;
    CO2[	733	]=	2011.0100	/coeff;
    CO2[	734	]=	2010.3600	/coeff;
    CO2[	735	]=	2010.0200	/coeff;
    
    for(int i = 736; i<tmax; i++)
    {
        
        CO2[i] = CO2[i-1];
        
    }
}




double ratio_volcanic_CO2_albedo(int number)
{
    double temp_value;
    temp_value = 0.2;
    
    return temp_value;
    
    
}

void set_concs_RCP85() //1765 to 2500, concentrations adapted from RCMIP concentration csv file. Annual values.
{
    CH4={721.9397628013699,722.3010368961187,722.9680867897922,723.6661903368391,724.341526357306,724.9941847682647,725.6268126899218,726.2490111413404,726.8581883367578,727.4542218732877,728.0346901969647,728.602632737705,729.1531259657535,729.6856814109589,730.1977377031277,730.6892168738926,731.1509877625571,731.5818627203197,731.9866193650784,732.3773573967986,732.7611048984018,733.1479632990868,733.5466260628851,733.9697509748357,734.4240141449771,734.9171549554794,735.4498296256082,736.0234581655063,736.630841089041,737.2696577283104,737.9354778073895,738.6304643525838,739.3472875856164,740.083884219178,740.8383492876713,741.6135709942923,742.4200796700912,743.2665574554794,744.1492611549703,745.0678183545924,746.0085591621005,746.9648053013699,747.9266448486413,748.8934531715698,749.8516516849314,750.7992286906393,751.7385347205194,752.6834961117725,753.6306917522833,754.5808121175797,755.5308679826834,756.4870124561468,757.4421350456623,758.3965170456619,759.3472115934202,760.3007481039749,761.2511084041097,762.2001010285388,763.1461802962858,764.0967108992314,765.0458140764841,765.9949816609591,766.9424475540709,767.8955662332386,768.8481928321918,769.7995994920092,770.74333295004,771.6837842241812,772.6171007819635,773.5492958527398,774.4834507390024,775.4316885528732,776.3930258481734,777.3737620034244,778.3771440793661,779.4189166115725,780.502183936073,781.6311746130136,782.7956862037204,783.9920723650348,785.1996332910958,786.4068436563927,787.5981627443235,788.7693410975872,789.8991226643835,791.0060171415525,792.2776818120368,793.7522250916986,795.2529109589042,796.7213470319635,797.9991453951143,799.2834181700229,800.7529109589042,802.2529109589042,803.7489744741373,805.2522250916986,806.7529109589042,808.2529109589042,809.7489744741373,811.2837890186391,813.0033961187214,814.7218321917809,816.2489744741373,817.7522250916986,819.2844748858447,821.0033961187214,822.7176673965117,824.2522250916986,825.7529109589042,827.2844748858447,828.9988035531602,830.7210320133744,832.2529109589042,833.7529109589042,835.2801106307858,837.0341598672554,839.0038812785388,841.0038812785388,842.9674964755346,844.7210320133744,846.2844748858447,848.034960045662,849.9986326321831,852.0029667889312,854.0038812785388,856.0354452054795,858.2795978678542,860.7221445592236,862.9728025114155,865.0354452054795,867.2795978678542,869.7221445592236,872.0043664383562,874.2859303652968,876.7864155251141,879.6000285388128,883.0699200913242,887.0393264840183,891.2782305000377,895.7566752750955,900.2587328767125,904.7587328767125,909.2780595790604,914.0386100506522,918.9781392694064,923.7276541095893,928.2780595790604,933.0701739775931,938.291752283105,943.7606735159817,949.2462397385034,954.7581586695611,960.2922374429223,966.0427226027396,971.9647617399006,977.7269655912369,983.2922374429223,989.0427226027396,994.9958978965492,1001.0089003667939,1007.0116438356164,1013.0116438356164,1018.9958978965492,1024.9773364398532,1030.7295947488585,1036.2606735159818,1041.7462397385034,1047.2581586695612,1052.729109589041,1057.9786244292238,1062.9965815804576,1068.0074169723284,1073.0097031963471,1078.0097031963471,1083.027717737106,1088.2893517478853,1093.729109589041,1098.9786244292238,1104.027717737106,1109.2893517478853,1114.7922374429222,1120.5742865296802,1126.7768631322203,1133.2912059909675,1140.0762271689498,1147.3271974885845,1155.0881099196547,1163.60730063378,1172.7995148401826,1182.3,1192.0556063951892,1202.3283326471542,1213.0524257990867,1224.052910958904,1235.3045808693264,1247.0805577388528,1259.3369006849316,1272.0563070776254,1285.0222482658382,1298.3327828305512,1312.0582477168948,1326.0587328767124,1340.3025298176012,1355.0850079222498,1370.3111586757989,1385.7800799086756,1401.2705390560675,1417.0549273897748,1433.0310502283103,1449.0310502283103,1464.9890610574641,1481.0552982383908,1497.3130993150687,1513.782020547945,1530.3632638421038,1547.965342964793,1566.8500000000001,1586.2998367579905,1605.6155182866733,1623.2804449091748,1637.7872851027398,1650.3736081621003,1662.080489018016,1673.0267843151933,1683.459881278539,1693.6531889269409,1703.5359140685434,1711.3708931369617,1716.3280679223744,1721.0993119292243,1726.1374272260275,1730.1603076484018,1735.216328481735,1742.5536087328767,1748.6461354969808,1750.7606347343863,1750.9335176940642,1752.3283065068492,1754.475836282344,1754.8590243531205,1753.9984397260275,1754.8615948630138,1758.272683701687,1763.635729810116,1770.608822762557,1778.8322951369862,1788.1746690065374,1798.795631923672,1810.6957260388128,1823.8287312899545,1838.0836782514286,1853.4609572739037,1869.8040823515983,1887.016759452055,1905.0127351670535,1923.7250238996494,1943.0001114497716,1962.6776196232875,1982.6866218339692,2003.0476025473465,2023.7558888470314,2044.8215501940642,2066.2171550383014,2087.9147411857484,2109.8588262100457,2132.019454509132,2154.4254545237914,2177.513930199741,2201.683294851598,2226.960624269406,2253.295773160229,2280.672983261565,2309.0382477625567,2338.3241180136984,2368.4298560972625,2399.3015073825386,2430.8606183904103,2463.0956257990865,2495.9161878917457,2529.2535670325874,2563.0887203310504,2597.4350949771683,2632.2955886598297,2667.7152878031043,2703.639576107306,2740.0041415981736,2776.6700645179903,2813.100235506369,2848.725598652967,2883.420895148402,2917.174562347606,2950.134596340046,2982.399710410959,3014.080162203196,3045.272831212354,3076.052575474929,3106.327980182648,3135.6140691666665,3163.469228049505,3189.925700062661,3214.951456529681,3238.5717611986297,3260.944792424832,3282.2556745802144,3302.6398921004566,3322.2374776940633,3341.1344741729677,3359.4695776794047,3377.346379509132,3394.7988271689496,3411.8256744727646,3428.3445140659237,3444.293747808219,3459.7783526712324,3474.910877046124,3489.8073096566295,3504.568394805936,3519.352206107306,3534.2507309557845,3549.2547977342674,3564.3292725684933,3579.4358874086756,3594.4301451063584,3609.236514252907,3623.9240390981736,3638.5882831050235,3653.241967515221,3667.4851743359973,3680.8617814954337,3693.331326803653,3704.9296624095496,3715.7188038314375,3725.7244820890414,3734.8660457077626,3743.112201666667,3750.604796792238,3757.468884828768,3763.607704783104,3768.927226039437,3773.487982187165,3777.312990570776,3780.4283665867574,3782.875724187065,3784.6806775785058,3785.7502940525114,3786.0420945205474,3785.6938397382546,3784.860501819341,3783.6801185616437,3782.2773569977167,3780.699248734873,3778.923065671302,3776.9318409931498,3774.7270862671235,3772.2968392365947,3769.512951985958,3766.302178390411,3762.7738164383554,3759.0612579558097,3755.27691743865,3751.526915684932,3747.837603310502,3744.1692385293304,3740.480799555325,3736.758728036529,3732.9751930821913,3728.9917366209424,3724.715519237905,3720.2466159931505,3715.708420102739,3711.2095060791726,3706.8417242287346,3702.6268249429218,3698.5154993493147,3694.4627050091076,3690.4413216141115,3686.4196510958905,3682.252711449771,3677.8466241469546,3673.2886437611655,3668.7026781621007,3664.1942797716893,3659.8574595561045,3655.704497733457,3651.6858339497717,3647.7513476369863,3643.878151493063,3640.050803420509,3636.1492030479453,3632.0763011073054,3627.919255715935,3623.792442311675,3619.8021211757987,3616.039042020548,3612.5180601500238,3609.180893507404,3605.97617119863,3602.873130878995,3599.8323738893264,3596.7025740922786,3593.3855736073056,3589.967491324201,3586.5690347101827,3583.292694966565,3580.2328559817356,3577.404495878995,3574.7531870992093,3572.222454004665,3569.782489554794,3567.3929290068495,3564.9067472257157,3562.2211597911214,3559.424121004566,3556.6364997031965,3553.965473762943,3551.5017687740788,3549.262300901826,3547.19181109589,3545.235652857936,3543.360124085292,3541.5260984360734,3539.5868017579905,3537.4431292678473,3535.1788012786633,3532.917005091324,3530.764968082192,3528.816183432331,3527.084064068793,3525.5142241438357,3524.0512201598176,3522.663181213788,3521.3085403547234,3519.842012100456,3518.16469130137,3516.36245283105,3514.556691552511,3512.8543344520544,3511.347717454338,3510.0517487214615,3508.9095602853886,3507.8665228424657,3506.8904727054796,3505.9415775561415,3504.8732624955087,3503.5881284931515,3502.1729691095893,3500.7501301243233,3499.4257573322907,3498.2930315525114,3497.3660544520553,3496.588861891983,3495.9054495895084,3495.284439452055,3494.6859884246574,3493.9654435113657,3493.024648028451,3491.9519955251144,3490.869614223744,3489.8843849053696,3489.0868659959265,3488.491202579909,3488.0413062557077,3487.6819420135603,3487.3809425905133,3487.098773584475,3486.6913174200913,3486.0622834683854,3485.2986610382827,3484.523081746576,3483.8421442694066,3483.3468837619457,3483.0504085725606,3482.8965700114154,3482.829981529681,3482.81864430172,3482.823491654721,3482.7010024315073,3482.3551662100454,3481.8743585346333,3481.3805508574114,3480.9800702739726,3480.763263207762,3480.7430124761704,3480.8630497299887,3481.05033097032,3481.165743493151,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994,3481.1806999999994};
    CO2={278.0584697739726,278.11378957876707,278.2213605617062,278.34384681846194,278.47112545319635,278.6010238207762,278.73313034098106,278.8695421046236,279.00982827853886,279.1540290787671,279.3024929856152,279.4578228119869,279.6187162009132,279.78191473972606,279.9422079595029,280.0965176891983,280.2422589817351,280.38166670319634,280.5185055613943,280.658229201038,280.8039932191781,280.9579931369863,281.1182885697033,281.28183982473735,281.4427201004566,281.59769528767123,281.74615669463157,281.8906576875016,282.03093192009135,282.1669711438356,282.2984254756406,282.42652746708836,282.5506873321918,282.6709293972603,282.7869747751141,282.89872807876714,283.0065246027398,283.11065236529686,283.2106883344811,283.3070302277367,283.3995426438356,283.4897062248858,283.5772794805126,283.6601155531228,283.73370056506855,283.79539739840186,283.84563329309213,283.8880542455773,283.9260691369863,283.96297574657535,284.00144228934306,284.04296654482624,284.0860805091324,284.1280744337899,284.1658206843139,284.19743873489784,284.2228497568493,284.2440404497717,284.26298989264416,284.2814429406642,284.30040649771695,284.32007237785393,284.3399863263218,284.3600296678893,284.3800388127854,284.3956198630137,284.37380123886516,284.273531458193,284.1253304794521,283.9747089041096,283.82510255258626,283.67477749083014,283.5310216894977,283.43427511415524,283.4031307077626,283.40315639269403,283.4313613013698,283.5033019406393,283.603045247274,283.7314982096963,283.90033961187214,284.07218321917804,284.22801106307855,284.40025959403147,284.57218321917804,284.7252910958905,284.8717838317489,285.0001854243082,285.12839897260267,285.2752910958904,285.42489744741374,285.57522250916986,285.72844748858444,285.90033961187214,286.07176673965114,286.2252225091699,286.3721347031964,286.5002425799087,286.6280281551763,286.7720661164758,286.8970861872146,287.0001940639269,287.103045247274,287.22834181700233,287.37529109589036,287.52844748858445,287.70299397098086,287.9034530715872,288.13174942922376,288.40369006849323,288.70290851049225,289.0317948885894,289.40388413242005,289.8039326484018,290.2309366656686,290.7038610050652,291.1978139269406,291.6727654109589,292.1246923422412,292.56935474212133,292.9663070776256,293.29431792237443,293.5685847555955,293.7971773710607,293.9972317351598,294.17218321917807,294.3248974474137,294.4720661164758,294.59708618721464,294.700194063927,294.7999316316091,294.9033047321406,295.0347117579908,295.23485730593603,295.5036900684932,295.80373858447484,296.12878710045663,296.4756792237443,296.8278743262969,297.20686905831275,297.6289811643835,298.0727168949772,298.49659581867405,298.90059335778625,299.3007762557078,299.6976198630137,300.07163000286954,300.42551918806294,300.7725228310502,301.0974743150685,301.4029085104923,301.7286384958954,302.0725228310502,302.39747431506856,302.7029085104923,303.0317948885894,303.40072773972594,303.77257134703194,304.13098794196173,304.53190614317435,304.97271689497717,305.4008247716895,305.8309366656686,306.30070461237113,306.7727654109589,307.2290296803653,307.6996752501435,308.16939182698303,308.5976683789954,309.00077625570776,309.3934992951069,309.7378936172867,309.9910159817352,310.169026826484,310.29368730818175,310.36564207650275,310.36553082191773,310.2966980593607,310.2031819840557,310.13120153080314,310.10626426940644,310.1313613013699,310.20617595503654,310.33149820969635,310.5098087899543,310.7631107305936,311.10598794196176,311.5037497504803,311.93529394977173,312.4354394977169,313.00272049741744,313.60404642937345,314.225897260274,314.8524957191781,315.514499251441,316.27743359345754,317.0661412671232,317.7815622146119,318.38774723345057,318.9504023535943,319.68393807077626,320.6440747716894,321.6133748580857,322.6665136268932,323.8816024543379,324.96027140410956,325.90609121503604,327.1737857280984,328.6208279109589,329.7164748858447,330.62427827681717,331.79499214013026,333.281772260274,334.863497716895,336.543468898932,338.30369748546553,339.6919614726028,340.8374937214612,342.21895745689545,343.7741194450684,345.2873047945206,346.8424200913243,348.6742503274945,350.6973614230107,352.4426033105022,353.83177140410953,354.9799645526113,355.889443237393,356.83699400684924,358.1755719178082,359.825744607256,361.4734327762806,363.2182559931507,365.30871489726036,367.28290914208895,368.8779827862614,370.5277405821918,372.5495296803653,374.7354295013349,376.8089162424833,378.81827511415526,380.8232037671233,382.7851963018065,384.82695844841186,387.02913331735164,389.328892762557,391.64350219277895,394.02284900406715,396.4793363538813,399.01952096347037,401.63444692477606,404.3341509571139,407.1015911335616,409.9326616974886,412.8262063979028,415.7846878935331,418.80037770890414,421.8697062214612,425.0001313072648,428.2037561658526,431.4813613755707,434.8318680045663,438.24786941343535,441.72435304856896,445.25476677511415,448.838822324201,452.47749502790253,456.1840626861011,459.9735486118721,463.8624894349314,467.8594472080869,471.9706449240837,476.19194949543385,480.5162265159816,484.93328019749475,489.44241888157484,494.04122146118726,498.73875220433797,503.5369671764229,508.4432305199273,513.4684858493151,518.623355716895,523.9108020958905,529.3350863219179,534.885322196347,540.5522021107307,546.3292020354194,552.2203151173491,558.219968747717,564.3210568732876,570.524954943459,576.854468109957,583.3169559634703,589.9176606963471,596.6554025735709,603.5294435374249,610.5224877157533,617.6082937648401,624.7645529061369,631.9962109541756,639.2929836837899,646.6572811689498,654.1024924960262,661.6521905241535,669.3127374760275,677.084370696347,684.9541508629886,692.9002803726731,700.8934221255707,708.9309695924658,717.0108202338498,725.1348422751049,733.305924365297,741.5251028436072,749.8072556414278,758.1852290739824,766.646207727169,775.1735134646119,783.7462901217032,792.3627586410629,801.0172330981736,809.7091474383561,818.4156419994324,827.1571870849084,835.9551558253426,844.8066158595889,853.7251463273197,862.7240416829695,871.7741534098174,880.8607998664384,889.9743595659232,899.1185119081734,908.2836371004564,917.4654359748857,926.659821541096,935.8730880753424,945.1342622853881,954.4635855901828,963.8319689305087,973.236958894372,982.6756918458904,992.1385294486304,1001.6202531363001,1011.1106307151235,1020.6012293607306,1030.092428002283,1039.5840217463258,1049.1199589892892,1058.6981046461187,1068.320967716895,1077.9912664971803,1087.694808941413,1097.4244977625572,1107.1674006392695,1116.9025056877388,1126.649732947264,1136.392541130137,1146.1315056050225,1155.9029413438507,1165.736610921944,1175.6140030936074,1185.5268122488587,1195.476943872483,1205.4674705411148,1215.4578682305935,1225.4461935273973,1235.4345882829305,1245.4109535704706,1255.3947839497719,1265.4179729109592,1275.478653572124,1285.5924449726779,1295.758870696347,1305.9554738470324,1316.160965322442,1326.3857725705518,1336.6196719977172,1346.8490014954339,1357.0602690926842,1367.273273198156,1377.508181757991,1387.7924382534245,1398.130835604711,1408.5180216918059,1418.9416297602738,1429.387088219178,1439.8156755246152,1450.1882218998114,1460.4516126255705,1470.5650237899542,1480.536804575754,1490.4393628448986,1500.2807559817354,1510.0392619520546,1519.7120161366245,1529.3070447373805,1538.8065959132418,1548.1997937671233,1557.4794871623374,1566.655978082036,1575.682655605023,1584.5646065410956,1593.3721789140902,1602.1268570608454,1610.8058868721462,1619.4012536415528,1627.906715131996,1636.3219084844177,1644.6347198287667,1652.8402303310497,1660.9179412903286,1668.845884812299,1676.6330314497718,1684.3341049771689,1691.9682221368867,1699.5387997441176,1707.0373418607307,1714.449399714612,1721.7641901974323,1728.9747319351188,1736.051486438356,1742.9972894748862,1749.8008187508422,1756.46658314217,1763.033251255708,1769.528679783105,1775.955463991504,1782.311606502826,1788.579951780822,1794.7402650228312,1800.7798239665517,1806.7096609911232,1812.4949322031964,1818.1234829680368,1823.6326981392695,1829.040277853881,1834.359209691781,1839.5992841438358,1844.7650931045234,1849.8503025676198,1854.830133515982,1859.6910669634701,1864.4231911137313,1869.0122494490295,1873.4493972831049,1877.7673001141557,1881.977979597338,1886.0972964043588,1890.1434501027397,1894.116271244292,1897.993340118709,1901.7585089035167,1905.4068358789955,1908.938416210046,1912.3179489491476,1915.5277472648897,1918.6087147716896,1921.6001192351596,1924.5093183928439,1927.3392691224087,1930.0857276484019,1932.735443938356,1935.2746073343812,1937.6951966308297,1939.9897810958907,1942.137963082192,1944.1389415689173,1946.0108347233454,1947.7641376255708,1949.4266189041093,1951.0014388369889,1952.5034151051414,1953.9295442351597,1955.2532668835613,1956.4396032173688,1957.4797954506012,1958.405597568493,1959.1665244634703,1959.7616929928643,1960.2755021952742,1960.71526966895,1961.0563143150684,1961.3096846149292,1961.4825887182485,1961.5603117351602,1961.5762562671227,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994,1961.5773999999994};
    
    
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00018433333333333333,0.001640836976320583,0.004384331511839709,0.007305666666666666,0.010225666666666668,0.013138003642987249,0.01606433151183971,0.018985666666666665,0.021905666666666667,0.02481800364298725,0.027559998178506375,0.0291763196347032,0.03062918378995434,0.03311064270030192,0.03565838298774859,0.03653468036529681,0.034346381278538805,0.03370401948124859,0.038736497679467026,0.04656581621004565,0.054696877853881276,0.06266962160341344,0.07082089696085037,0.08134435502283105,0.10062263698630136,0.15856969489981787,0.2767089367966664,0.4385683447488585,0.6595233561643835,0.9638101671781819,1.3314361150410459,1.7252232591324201,2.1413780764840182,2.6088571519824337,3.1197813591229377,3.6285011880365285,4.157993900650685,4.795674458427464,5.6097797695591,6.598152982534246,7.755199512990868,9.068855918777354,10.523862897186666,12.086411665068491,13.75177989178082,15.511774117833793,17.37460421673996,19.331188318721463,21.378563191666668,23.51334409226926,25.734780917264576,28.032385734246578,30.36150304885845,32.67879336897659,34.98117199197045,37.26813632100457,39.54078417979452,41.79947109696459,44.046893251822745,46.28212491723744,48.505803625913245,50.72077589276018,52.94905322534402,55.208823476826474,57.502834927968046,59.83039668542617,62.19356632321158,64.59068078013696,67.02140051118721,69.48449201879569,71.98161113058083,74.50881516369863,77.05363311952054,79.60256313735307,82.15586463585879,84.7125782520548,87.27361496757992,89.83926980605709,92.4127974078031,94.99282939885843,97.57931302865296,100.17028775139856,102.75885265775571,105.33379805821919,107.89270328995434,110.43432928145195,112.96187206931033,115.4746601849315,117.97379574315069,120.45983709480502,122.9355063810914,125.39919911187214,127.85233713584473,130.29572317855002,132.73119894003108,135.155157086758,137.56623106392698,139.96453318357786,142.3531805652681,144.73146340410958,147.10041427625566,149.45710996615267,151.78499188368957,154.06437961415529,156.29370427625574,158.47336999728648,160.60452705832213,162.68552303082194,164.71858459474888,166.70579931558623,168.65138777116866,170.55606780251145,172.41894369292234,174.23796471659557,176.01523109365408,177.75056450114155,179.44470217808217,181.09615075394865,182.7058874695243,184.27509080593606,185.80642436986304,187.30153010587742,188.75967117472615,190.17651397945204,191.55162718607303,192.88499647269626,194.1783791014765,195.4311948869863,196.64173878767124,197.80919581621,198.9357269634703,200.0238111506849,201.0746008458904,202.08880180391498,203.06830060605208,204.01250088013697,204.92153013013697,205.79566101862665,206.635832393898,207.4394871015982,208.20545975913242,208.93574355163187,209.63368803413425,210.30141865981736,210.94150913584474,211.55511454576194,212.14278024617929,212.70412824999997,213.23953013242007,213.74897256805028,214.23072567074317,214.68307447260278,215.10812468721463,215.50854486580204,215.88729503142073,216.24665755251135,216.58780821004572,216.91054528607435,217.2149885754017,217.50111847945206,217.76885066210045,218.01574979463905,218.2404092544882,218.44467034931506,218.63120668378994,218.80254438164653,218.96131056771026,219.1084512534247,219.24365084018265,219.36653293940412,219.47722683288418,219.5753905034247,219.6584254280822,219.72451311003195,219.77555024763578,219.81411058447486,219.84268952283105,219.86369535708138,219.87807888773486,219.88536750114156,219.88505113356166,219.8771583803116,219.8624154181139,219.83921828424658,219.80573172602735,219.7636898243194,219.7155782619083,219.6638467157534,219.6108199851598,219.5573501090214,219.5028073012326,219.4465539041096,219.3883080262557,219.32752887437934,219.2612672419218,219.18742615867583,219.1076106849315,219.02432211457315,218.93985581722688,218.85653265867577,218.77513606164382,218.69499112206503,218.61525757948132,218.53559115182648,218.45534669292238,218.37156685019465,218.28193362796614,218.1880504714612,218.09234540068496,217.99716508312747,217.90465142800733,217.8155957488585,217.72923871232877,217.64473446820497,217.56154811530618,217.4790271130137,217.39413815753423,217.3046101430434,217.21184986077114,217.11831229109592,217.0263045650685,216.93803243998434,216.85408968235836,216.77372007077625,216.69602679109593,216.62049903930563,216.5463173641615,216.47047584018267,216.39065178538814,216.30829856849314,216.2257759269406,216.14534899543378,216.06914537442924,215.99783061366244,215.93049712042753,215.86624474885846,215.80452778424663,215.74457852668613,215.6832535244404,215.61827862557075,215.55109391210047,215.4840631929411,215.41938863445054,215.35922377054797,215.30418213698627,215.25339881294758,215.2058704215167,215.1610679920091,215.11820653310505,215.0742004095928,215.02668374960703,214.97714353652972,214.92792550799086,214.88126634471146,214.8392077527884,214.80237881735164,214.76988798173514,214.74076688043013,214.7144136868715,214.69006048401823,214.66461800799087,214.63577161413028,214.6049370667371,214.57446676940648,214.54659319406392,214.52339405766398,214.5054169998846,214.49178291095893,214.481511586758,214.47401615692914,214.4685047469434,214.46189421004567,214.4518784349315,214.43991505483817,214.42832176177737,214.41931561757994,214.41496041324197,214.4158144015894,214.4209810503842,214.42867857420092,214.43349283219175,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992,214.43411999999992};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.003787671232876712,0.0338458904109589,0.09431804089627466,0.19713521471167997,0.3987260273972602,0.8163807077625571,1.7209830482571047,3.2209990580632284,5.2401946347031965,7.769219178082192,10.717201016168874,14.002699434837936,17.556018835616438,21.40025742009132,25.46959559098735,29.812994441949247,34.351222031963474,38.80289440639269,43.15455555232116,47.46128332229833,51.70968455878997,56.062148668150684,60.540729363242626,65.26133404743119,70.26999877648403,75.56679654577626,81.1187443054913,86.94482692664745,93.00982516963471,99.29868984600456,105.79600076596613,112.49463832945328,119.36012795662101,126.27429875342465,133.1287696202435,139.921913695586,146.6572486678082,153.34267079223744,159.98251073804803,166.5867203301114,173.1544139840183,179.6892704634703,186.1947309266225,192.69208701057337,199.19396663584476,205.70845523173514,212.23979807483718,218.79940362040577,225.38807590753427,232.00842351141554,238.6590700018901,245.34625397790816,252.06029856164386,258.76141352625564,265.4053302835479,271.9938158121335,278.5315207340183,285.02782842009134,291.4900266182786,297.9324208259943,304.3552352853882,310.7598578949772,317.14029123471073,323.4620689986432,329.680344076484,335.785431989726,341.77537750981236,347.66478379999126,353.4595506472603,359.1691870673515,364.8017737100518,370.36727367324147,375.86418702968035,381.3025382705479,386.6904259904434,392.0315793263124,397.3119118721461,402.5247997408676,407.67486846404427,412.773929205913,417.8253916974886,422.8362853390411,427.8090245566909,432.7556489479534,437.68037123059366,442.58347692579906,447.4614113342004,452.30701673239633,457.1094416541096,461.875415563927,466.61224311292636,471.332060724733,476.0384584577626,480.7289087431507,485.39554779591793,490.04048947676046,494.6605538732877,499.25419725,503.808395663922,508.3196014969091,512.793093553653,517.239238826484,521.6676164471891,526.0958641895446,530.5261935490867,534.9531479155252,539.3701515528857,543.7777791878696,548.1682777009132,552.5257207819635,556.839610518265,561.1172233333333,565.3512352648403,569.4290850216895,573.2435285698156,576.797009650716,580.0977777910958,583.1560862876713,585.9829982470682,588.5901854001204,590.9721952089042,593.129830359589,595.0826810447762,596.8546905675139,598.465458704338,599.9347643093607,601.2737731339795,602.4872829330944,603.5779888219178,604.5511819783103,605.4101152108192,606.1457192696184,606.752542543379,607.2458410662101,607.6438316952491,607.9636489467089,608.2209038892694,608.4229485285388,608.5693536694115,608.6596779614243,608.6953577431506,608.676244030822,608.58915540197,608.4256418327283,608.1982213253424,607.922744165525,607.6138455362801,607.2848043534447,606.9409263949772,606.5793735045662,606.1973604418744,605.7938649730519,605.3669725273973,604.901495402968,604.3873347250105,603.8347052507892,603.2585203687215,602.6721308162101,602.0880473124049,601.5095673483638,600.9329680707762,600.3540379543377,599.7715378354043,599.1856437570489,598.5845022808218,597.9571407899543,597.3132440502469,596.6659061978069,596.0281245696347,595.411461415525,594.8191323095479,594.2456763913093,593.6863690947489,593.1383803858448,592.5977335871945,592.0471152176591,591.474849946347,590.8899611563928,590.3060106360568,589.7348287589327,589.1881475570776,588.6688068276255,588.1716801050164,587.6908136406854,587.2233682442923,586.7649315833334,586.2986118371572,585.8117174521827,585.3133480981735,584.8168001335616,584.3344910811126,583.8772434304746,583.4480871358447,583.0416110582191,582.6521751499487,582.2760610426616,581.9089960319634,581.5339733801369,581.1387941396748,580.7317433702872,580.3263672591323,579.9349522534247,579.5687374096989,579.2300614156031,578.9136453607306,578.6136704109589,578.3267346531801,578.0480301504853,577.760755805936,577.4526650502283,577.1323659280822,576.8130373630137,576.5068892031964,576.2249848047945,575.9699403050379,575.7359781805056,575.5174241952055,575.3107912990868,575.1115541024278,574.902612742034,574.6719332773972,574.4281960981735,574.184710060153,573.9534979234754,573.7457706004566,573.5640147260275,573.4026679531339,573.2557709245483,573.1199622853882,572.990687586758,572.8511662686952,572.6891929810614,572.5136416552511,572.3377891095889,572.1738415392432,572.032603385171,571.9166122442923,571.8202760753425,571.7377789674127,571.6656045645476,571.5992811038813,571.5220557442923,571.4219823987324,571.3077419454986,571.1926843276256,571.0889676563926,571.0075164598896,570.9506888002408,570.9129218356164,570.8883631974887,570.8735719123998,570.8640590690171,570.8431720262557,570.7990044269405,570.7404117090226,570.6806645147623,570.6319100216896,570.6049850856165,570.6022449511129,570.6181046824269,570.6440844178082,570.6604820993151,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001,570.6626200000001};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0015781963470319637,0.014048261783566635,0.03753708486164133,0.06254851598173516,0.08754851598173514,0.1124829079022881,0.13753708486164135,0.16254851598173517,0.1859703196347032,0.1984346461187215,0.20315639269406394,0.2282049086757991,0.2719406392694064,0.29998290790228804,0.3281934775557053,0.3719406392694064,0.40004851598173524,0.4312101392319785,0.5001112545849241,0.5719891552511415,0.6250970319634703,0.6749658158045762,0.7282305624173465,0.8064583333333332,0.9347117579908676,1.1404313415425305,1.4599512812835294,1.8507762557077625,2.2507762557077626,2.6497265264366097,3.0490256280374033,3.441891290490867,3.8642192836986298,4.358239457133518,4.932477977917259,5.581569375388128,6.311749467694065,7.169232829272526,8.207956784621727,9.423008187271689,10.810199959611872,12.353628737039323,14.002779968637874,15.68600935091324,17.396291632077624,19.128633240491432,20.893789720488993,22.68541880913242,24.50313709851598,26.346135355483813,28.215727022011063,30.107719338584474,32.00518226563927,33.89128474912106,35.76582639957488,37.62802786621004,39.47842057431507,41.31699564222435,43.145709818555844,44.963589734817354,46.77094082545661,48.569630100409846,50.37558519538047,52.20179652625571,54.050403956621004,55.921043291780826,57.81552717020548,59.73266183481737,61.672395616780825,63.634041741561866,65.61919188189422,67.62484148732877,69.64053315616438,71.65510381058276,73.66879207568307,75.68066981301372,77.69125773070776,79.70060190933266,81.71105340545886,83.72149688116438,85.73198054372146,87.74109144807807,89.74369318827475,91.73134879885845,93.7025537078767,95.65657260401913,97.59563664792962,99.51896841141553,101.42713853915525,103.32031191820744,105.20047906291326,107.06634454680368,108.91787209132421,110.75461008843602,112.57803077491143,114.38607213584477,116.17818226369862,117.95435201663673,119.71673143579237,121.46464130593607,123.19866592579909,124.91683453517602,126.60805152417221,128.25875093264838,129.86762164497716,131.4347388308381,132.9611457039667,134.4457223652968,135.8895134303653,137.2934124723844,138.65983354156995,139.98875371803655,141.2790895913242,142.52917471144298,143.7403051479932,144.9122031392694,146.04529649086757,147.1389329572448,148.19395106501858,149.2107444429224,150.1906336872146,151.13435645479328,152.04144553761196,152.90942100342463,153.73811105136988,154.5275933696821,155.2789175895807,155.99181479566212,156.66563354908678,157.30013499885845,157.89638291894974,158.45717093264838,158.9940535399543,159.51820204935498,160.0318184088598,160.534302293379,161.0254176084475,161.5050006504853,161.97327103846345,162.4287825262557,162.87075463812786,163.29976368711482,163.7171374473139,164.1234903230594,164.51974200000004,164.9061661891234,165.28291922194774,165.64957819748858,166.0061212477169,166.3523388233463,166.68741984810484,167.01033964497717,167.3218373789954,167.62286853962374,167.91469526683008,168.19808452283104,168.47343713242012,168.74052163795943,168.9993964166573,169.24985709589043,169.49176267465756,169.72391619541756,169.9456967258278,170.1576867283105,170.3609573013699,170.5564863783155,170.74544739178955,170.9281247545662,171.104313706621,171.27377975562038,171.43662494448188,171.59256869178083,171.74040281735165,171.87924427812086,172.00992941279603,172.13344836415524,172.25085311872147,172.36313907268504,172.47079871681078,172.5735422260274,172.67112886415524,172.76353803981712,172.8511869472484,172.9333212694064,173.00911517694067,173.07926720273474,173.14492821152092,173.2071269349315,173.26688126484018,173.3245914082828,173.38007097733737,173.43301549200916,173.48330387100455,173.53070512494696,173.573988555986,173.61215635844746,173.64590977054797,173.67633273245875,173.7045133420197,173.7314635913242,173.75756298630134,173.78256084565336,173.8061536770966,173.8281888242009,173.84840655365295,173.8654836016356,173.87844494812484,173.88795778196348,173.89509954908678,173.90093109363227,173.90648745951856,173.91213047602744,173.91757317922375,173.92246597441803,173.9266537671607,173.92984007077624,173.93068461643836,173.92816549446692,173.92295255909565,173.91611313584474,173.9087034714612,173.90174008370138,173.89557426291574,173.88988824429225,173.88433317922374,173.87870149958826,173.87268425441653,173.864935163242,173.85440999771689,173.84175909018268,173.8280473127854,173.8143147111872,173.80155506849314,173.79010505321006,173.7796294293048,173.76974408675798,173.7602388047945,173.75080240117154,173.74005119834,173.72694201369862,173.71211203538815,173.6966326362253,173.68151872469556,173.66778205136987,173.65572693607308,173.64501673670688,173.63524754266163,173.6261996495434,173.61754936872148,173.60792185515388,173.5962434034827,173.58316934360732,173.5697557420091,173.55703261741772,173.54595863556094,173.5368570410959,173.52936331050228,173.5230767011503,173.51775723500387,173.51307492009133,173.50764444863012,173.50041141858173,173.49201403388793,173.4834980525114,173.47588346689497,173.4701468049692,173.46656800144726,173.46479246803653,173.4644114006849,173.46517240974245,173.46674220706078,173.46774178995432,173.46711195890416,173.4654819819098,173.46391391868465,173.46341401255708,173.46492979223743,173.4687559353432,173.47452202640542,173.4812382808219,173.48514851712332,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005,173.48565000000005};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0118067985883425e-05,9.132367434758341e-05,0.0006337253871550228,0.0038871157650684934,0.00952665405318462,0.014865460074914537,0.02382606998710046,0.03812341954908676,0.06099061300361678,0.09885349630036055,0.1514549462384703,0.20968080459018268,0.27751644633813655,0.3707250192772788,0.4908671540376712,0.6355100353470319,0.8097080249669948,1.0241045716620507,1.277856164417808,1.5700511146575342,1.8936551053639246,2.21438699889338,2.4945690419863014,2.730727915570776,2.9238002562194016,3.07624603829263,3.188583056312785,3.2619833850799083,3.297599020524802,3.2965198718687465,3.261892618550229,3.2094973733333334,3.1547281456816254,3.0997510336214966,3.0446208919178086,2.989353217397261,2.933961516215223,2.8783838531854307,2.822648538869863,2.766748763447488,2.7108448267771412,2.6559612440260936,2.6031960365867577,2.5526623260045667,2.5043210518417673,2.458080161753344,2.413922131666667,2.371786451883562,2.331612544609189,2.293299755979895,2.2566823014041097,2.22078530609589,2.1846502004533765,2.148096953150716,2.1111660013242006,2.073873641552512,2.0362431804681,1.9982535164812736,1.9599340679908674,1.9212793900114153,1.8823512457038951,1.843506132053734,1.8051482860616437,1.7672905204452054,1.7299045906360255,1.6929442889612185,1.6564256656735161,1.620338999908676,1.5846834102548844,1.5494110938592895,1.5145581625114157,1.4803359709931507,1.4469586869049582,1.4143970127743157,1.3826294296004569,1.3516192813242007,1.3213558395044536,1.2917975777001458,1.2629505051369863,1.234800639714612,1.2073355388873293,1.1805131930785113,1.1543361418378995,1.1287854584360733,1.1038464810589612,1.0794686760426802,1.0556452093949769,1.0323670765525115,1.0096319816153903,0.987412206983326,0.9657162215102741,0.9445384961986303,0.9238743819534521,0.9036912160423997,0.8839891970513699,0.8647538937979452,0.8459681362984068,0.8275975591537756,0.8096487241769408,0.7921169480867579,0.775001112779749,0.7582815560580539,0.7419606411780822,0.7260247940924658,0.710464470303235,0.6952544940246682,0.6803937526780821,0.665865271834475,0.651653340446347,0.6377533502842466,0.6241645979063927,0.6109000670707762,0.5979761636335367,0.5853757140975592,0.5730967442614154,0.5611290428093607,0.5494661302961987,0.5380884485140667,0.5269903206221462,0.5161603923367579,0.5055971076015794,0.4952885071480837,0.48523883759360736,0.4754451330547946,0.46590401820499916,0.4565994123316366,0.4475303892922375,0.4386904527899543,0.43007471753301146,0.4216652742700988,0.41345929967465755,0.4054541788607306,0.397650045835997,0.3900381994153348,0.382621973196347,0.3753973749885844,0.3683600897228834,0.36149823078388166,0.3548115464315069,0.34829482432077624,0.34194132373617037,0.33573858463019307,0.3296890160913242,0.3237916239018264,0.3180464813647666,0.31244722417858123,0.3069947272888128,0.30168440597831053,0.29651291521736906,0.2914717626846196,0.28656034192808216,0.2817721259737443,0.2771026334905807,0.27254633930143846,0.2681058422100457,0.26378042324429224,0.25957018624615114,0.2554691426019974,0.25147653023972605,0.2475887884589041,0.2438042563200277,0.24012065332974028,0.2365394396803653,0.23305656195433788,0.22967156219265414,0.22638101737253288,0.223186651293379,0.22008782905821914,0.2170833093053185,0.214167415572264,0.21133912856278536,0.20859581746347033,0.20593527761819128,0.20335062535495108,0.2008398002568493,0.19840196595091328,0.19603749780730217,0.1937440906379501,0.19152303383904112,0.18937294376141553,0.18729183224902687,0.18527545030937012,0.1833230951278539,0.18143254991780822,0.17960041715154576,0.17782188375264799,0.17609767392351597,0.17442790556050228,0.17281298478312998,0.17125148978143637,0.16974351250684927,0.1682871141678082,0.1668806335637336,0.16552116778191042,0.1642078902888128,0.162937598956621,0.16170785956299125,0.16051735478945842,0.1593672530468037,0.15825784934931508,0.1571896013142139,0.15616089362493138,0.15517088535616438,0.15421798347831053,0.1533010512721948,0.15241786798632942,0.1515662706015982,0.15074396752739724,0.14995084417009133,0.14918741912557076,0.148454183696347,0.14775155543949772,0.14707932590968634,0.1464356379835036,0.1458196252910959,0.14523023044520547,0.1446664110570714,0.1441252153216215,0.1436050270057078,0.1431060013356164,0.14262891655806323,0.1421740042808344,0.14174216363470318,0.14133314672945205,0.14094596584290867,0.14057920045311526,0.1402322437089041,0.13990413753652967,0.13959272706924794,0.1392959549022912,0.13901433826484016,0.13874869542922375,0.13849982724883972,0.13826823643061795,0.13805397795547944,0.13785614496803653,0.13767383612206502,0.13750620224386492,0.13735254242922373,0.1372108044280822,0.13707937765283076,0.13695857256026212,0.13684939588356163,0.13675272080593606,0.13666935397662006,0.13659923607780647,0.13654164084360734,0.13649574159817354,0.13646094977583154,0.13643653102494263,0.13642056681621004,0.13641153519748858,0.13640995558605937,0.13641682776818373,0.13643310714840184,0.13645967757191785,0.13649660209824213,0.13654323016821368,0.13659453972716895,0.13662398447945204,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996,0.13662774999999996};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004012573428995434,0.03210378527911708,0.06274416958629764,0.07216825052385846,0.07844375005913241,0.08524604932356278,0.09267590266989671,0.10073836004805936,0.10949821518378995,0.11899341907568554,0.12936461553921202,0.14061885578767122,0.152846581390411,0.16610076553594955,0.1805777326972079,0.19628732274200913,0.21335578634246577,0.23185706629627345,0.25206520161042495,0.27399392491324204,0.29781948420319637,0.32364509076311854,0.35185326763784713,0.38246317778995426,0.4157208447134703,0.45177033687663126,0.49114562052800864,0.5338734451392695,0.5802972189063927,0.6306180591881689,0.6855813045537466,0.7452243030536528,0.8100264187454339,0.8802683667602365,0.9569905620171419,1.0402451375205477,1.1307012282534246,1.228750684017142,1.3358458639845798,1.4520594348173514,1.578325494372146,1.7151909852396638,1.8646830994349626,2.0269035416552508,2.203156027340183,2.394204102656761,2.6028775067423964,2.8316298713584476,3.095767231484018,3.3944735821712584,3.7155943518652848,4.054698686449772,4.412171003789954,4.787139462431194,5.182478709092622,5.595674893687214,6.027205148710046,6.476037305191007,6.945594978797192,7.432883013550229,7.938471255947488,8.461166997905408,9.004943210921725,9.566323058470319,10.145969388630137,10.755139781489385,11.473544944757592,12.28854351678082,13.116951767351596,13.943186505552433,14.77338998209821,15.602177643036528,16.430586516780824,17.256820755325375,18.086862997508543,18.915592743264842,19.74974129098173,20.577492076652444,21.38694935550939,22.17015625194064,22.92818396757991,23.6565582563353,24.339106110530977,24.949990424543383,25.487357002397264,25.950522425218335,26.342682890964266,26.662474916666667,26.910175832077623,27.086068675948173,27.190515953143322,27.22787173002283,27.227714566894978,27.21959483033473,27.207771319153135,27.192286292808223,27.17317256472603,27.15045618620344,27.124114782905096,27.094171588584473,27.0606332130137,27.023615117306687,26.98378035437345,26.941874584246577,26.89803562796803,26.852311141392192,26.804689216357573,26.755234974429218,26.703961930821915,26.650882131702726,26.59594524902999,26.539247504337897,26.48118230022831,26.422128306357763,26.362066195144347,26.301053983219177,26.23911310319635,26.17627808758141,26.112508937057413,26.047854636073065,25.98230323527397,25.915888858216686,25.848736745600657,25.781067749657538,25.71286106643835,25.644096828414686,25.57471751019943,25.50478069417808,25.434297885273974,25.363297362424206,25.291711141690993,25.219596556278542,25.147104968721465,25.074405778168273,25.001434491874395,24.928193801826485,24.854649429680364,24.780823723363152,24.70666208377935,24.632226256392695,24.55753021917808,24.482605554677246,24.407478447854132,24.332297325114155,24.257070494063925,24.18180389749482,24.10639195092416,24.030861114041098,23.95522457796804,23.87951852082678,23.803691076486828,23.72781338253424,23.651885055136987,23.575913819586674,23.49982144280978,23.4236586130137,23.34741768310502,23.27108263879781,23.19456171606969,23.117922124200913,23.04118570582192,22.964410060890287,22.88768012881828,22.811186964383563,22.73493428116438,22.65892672949011,22.58308555591704,22.507452532762557,22.43199040776256,22.356663552625566,22.281483807990867,22.20647017305936,22.131642647031963,22.057044998255858,21.982611024287934,21.908380163127855,21.834341017808217,21.76050252347294,21.68678862267011,21.613216269406394,21.53975881210046,21.466446940525113,21.393232296575345,21.320183597374427,21.247319204452054,21.17466130017716,21.10213441634884,21.0297799173516,20.957594164269413,20.885585080377773,20.813656127704483,20.741834374429228,20.670132907534242,20.598588543546175,20.527155921924983,20.455904284703195,20.384838267465753,20.313968015865708,20.243220296943075,20.17264012511416,20.102221627853883,20.031950984912168,19.961741314549492,19.891655110159817,19.821713248630136,19.751950625138484,19.682323524500337,19.612887333219177,19.543634194292235,19.474572203283678,19.405635022584338,19.336864054680362,19.268230579680367,19.1997282127149,19.131307931697418,19.06303678196347,18.994935150228304,18.927036990724726,18.859287313077637,18.791726585159818,18.72434694737443,18.65719730041233,18.590476218672496,18.524465782534246,18.459181210958906,18.394647774044966,18.330825671416587,18.267776413013696,18.20551753504566,18.144068237071135,18.08336445243157,18.023438542237447,17.964285430593605,17.905910126347404,17.848230204241517,17.791263935045663,17.735020485958902,17.67952908271016,17.624759050764467,17.570763928424658,17.517548185159818,17.465115962449786,17.4134107588305,17.36246187191781,17.31226115456621,17.262790863321857,17.213984001909136,17.165884225799086,17.118508649429224,17.071883968205576,17.025984595929398,16.98084747739726,16.936463630821915,16.892833058678917,16.84991101133537,16.807718753310507,16.76622869954338,16.725426732350225,16.68528598361061,16.645850053538812,16.607135853424655,16.569168222715025,16.531916096315218,16.495397969178082,16.459603770205483,16.424535178351675,16.39015211148757,16.356452223515983,16.323412326826485,16.291037044178083,16.259343372488583,16.22834706347032,16.19806386678082,16.168507015255006,16.139642584715673,16.111481045776255,16.084015867579907,16.057244358624022,16.031115723796383,16.00562679280822,15.980785526141553,15.956613641336054,15.933104211008184,15.910290273401827,15.888174467579908,15.866752874570203,15.845997826844885,15.825917342123288,15.806503062557077,15.787732503710979,15.769567600301299,15.752029815639267,15.735133552968037,15.718899213681164,15.703326607104136,15.688430074771686,15.67420129372146,15.660633553629888,15.647709447134266,15.635429737671231,15.623768123287674,15.612705720164309,15.602240962542107,15.592397168721464,15.583189534589044,15.574633461144797,15.566726626581021,15.559465227968035,15.552840845547948,15.546847799923897,15.541474072754946,15.536696124657533,15.532494042123284,15.528875855820047,15.525855307331199,15.523448727168953,15.52167159760274,15.520527019215512,15.52000627763399,15.52003803630137,15.520200737328771,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006,15.520226000000006};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0471304628219178,0.420016317260274,1.1102177293812787,1.8293524811641337,2.5370508387900785,3.2303314559589045,3.9376214276027404,4.835891733078949,6.091052641622626,7.678000616940639,9.555622500696346,11.668031373144201,13.902282128724707,16.131335102968038,18.344956667465755,20.540528817856252,22.73466146826328,24.921763137328767,27.103596702054798,29.281293384445565,31.458041534166735,33.627840737671235,35.7610523033105,37.832881736608265,39.85010162513755,41.820091256392686,43.75066406392694,45.64746636369051,47.51674289601891,49.3611759497717,51.18437396769406,52.97398991767472,54.630960748739,56.06688279657535,57.29631279999999,58.346795569488734,59.24324954363724,60.006137354908674,60.652649356621,61.19662174699266,61.65058460469721,62.02308419543379,62.3097834599315,62.50448715414328,62.61423384258177,62.65014499246575,62.622302046232875,62.53951052853507,62.409344082128165,62.23736313984018,62.02725522294521,61.78396746637535,61.52079206647078,61.24913009737443,60.9674129553653,60.67377462652582,60.36955154045557,60.056782736187216,59.737085617351596,59.41207033366893,59.08164330321288,58.74522912591325,58.402270316666666,58.05240823041271,57.69436737485466,57.32554460559361,56.94435742853881,56.55270082612784,56.15223512012438,55.74502773732877,55.332750879908694,54.91707481681888,54.505057825437596,54.10376678938356,53.71261668070776,53.329762509000794,52.95123353204706,52.57485677191781,52.201403821461184,51.8320275149874,51.467270809732504,51.10822296404109,50.755183294178075,50.40764068562829,50.06426564359952,49.724563139041095,49.38762056746575,49.050883506062085,48.71239978988945,48.373690007762555,48.03627920376712,47.70664128081381,47.420679074329406,47.20947377579909,47.06883168527397,46.989941082065144,46.96527362863113,46.987961652168956,47.05013902671232,47.14544138915525,47.27091455833334,47.421432628881284,47.574397861986306,47.70962078093794,47.826278238102596,47.92554679018266,48.00858274257991,48.076702444528024,48.13090794105191,48.170201212442926,48.19436331187214,48.20601163963557,48.20799017646842,48.20278694714611,48.19263289737443,48.17847227575043,48.160112207449096,48.137423128424665,48.11056231541097,48.079457635787996,48.0421700598607,47.99763855913242,47.94772771700914,47.894660253245625,47.840296286986934,47.78635914531964,47.73328293356164,47.680433145468726,47.62717106370269,47.5732919987443,47.518364889041095,47.46019556887679,47.397344835745564,47.33146096004566,47.26454518630137,47.198338051022404,47.13429768184057,47.07273902248858,47.01284830662101,46.953886348913976,46.89542019481748,46.83693598493151,46.7761242762557,46.71151504286996,46.64454726332155,46.57721343869863,46.51119607968037,46.447972458104395,46.3877090294795,46.32957884178083,46.27276388710046,46.21688455364299,46.16167067646655,46.10518181552511,46.045896099315065,45.98524096441725,45.92506324811831,45.86704820810502,45.81261980890412,45.7619766922206,45.714165473515045,45.66834601952055,45.62401938173517,45.58055579246763,45.53556254272588,45.48750452888127,45.43779738299088,45.38838420604336,45.3408975278704,45.29681543253424,45.25634442328768,45.2185845114985,45.18262342779929,45.14798041050228,45.114013819748855,45.07839417005952,45.03952670208474,44.998853053995425,44.95831722237443,44.919621042080244,44.884188250695225,44.852251238812784,44.82290054805936,44.79525069281258,44.76876361784439,44.74281679942922,44.71508865136986,44.684040444040846,44.65105301831007,44.618101670205476,44.58688846894977,44.55887485712254,44.53424352736172,44.512096301369866,44.491536260844754,44.472050973103656,44.45298540821107,44.43204211381278,44.40768713105023,44.381333511187215,44.35492820205479,44.330166324315066,44.30849219166666,44.29010649522045,44.27407583284583,44.25951622773974,44.24591301746576,44.23263558387916,44.2173720176504,44.1986130423516,44.177781357305925,44.156841397055665,44.13747545592047,44.12113705844749,44.10801411518265,44.09718822815018,44.08775568776169,44.079210982191775,44.07092509611872,44.06061594441388,44.04676719824369,44.03082395205479,44.014745834246575,44.0002239772357,43.98867140990561,43.980276967237444,43.974119179908676,43.969304304437706,43.96531803796005,43.96153737671233,43.955688075228316,43.946281602986126,43.93474387905564,43.923040341095884,43.91285781347032,43.90561478977219,43.90148426183877,43.89954368995435,43.898896756963474,43.89903396528995,43.89933679750511,43.89754333721461,43.89216910719178,43.88466228524902,43.87697588985358,43.87079286894976,43.867519758789946,43.867325340490794,43.86928547028813,43.872236791438354,43.87403635719179,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005,43.874269000000005};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.000570334290022831,0.009472775622119544,0.07342896765536717,0.31235040351917803,0.7291767597363012,1.2236394509526536,1.7732774257257276,2.3646837189726027,2.9902240092351597,3.641544229956084,4.318868890684057,5.013550819851598,5.72206281076484,6.458724411988484,7.354890370118771,8.50712921458904,9.887936144086757,11.45125078489832,13.173615591973887,15.02225618253425,16.974887164155252,19.012999513209575,21.12371789577657,23.272191458675803,25.310727857990866,27.120047428682913,28.725499176136875,30.165701424429226,31.47309153881278,32.67299245208599,33.78634610833084,34.82877312899544,35.814649088926934,36.75261979419617,37.63991175274284,38.475303502511416,39.269576203196344,40.032915688207076,40.77437768041832,41.50033862762557,42.215184855251145,42.92119919814482,43.62100433978997,44.306176320662104,44.91092021757991,45.378271794710194,45.721074828699436,45.96258257020548,46.12233144760274,46.216269334894086,46.25751355021989,46.25534546141552,46.21615660148402,46.155198601133456,46.144436786144475,46.2427905119863,46.43720261666667,46.70792678813347,47.04281340089454,47.43181473424658,47.86685806495435,48.34128835562293,48.848801713892634,49.382426980365295,49.93808849611872,50.51226175891471,51.10058799502428,51.69556383184931,52.29239718356164,52.89119195207601,53.49331546071064,54.09909741872146,54.709342575,55.318219807556716,55.891189645644324,56.39882725810502,56.84637297762558,57.242535888792816,57.59175596269338,57.89841268378995,58.17111646678082,58.41769290994148,58.64485269904714,58.85302988812785,59.01200675399544,59.09516668649163,59.109488086092064,59.06608439965754,58.973732031849316,58.836499123358784,58.6587835892797,58.44945774463471,58.21652098436072,57.963419423119866,57.67302928649287,57.32922836917808,56.93607784543379,56.50049781856925,56.02827840858067,55.52458237168949,54.99039948664383,54.427724875114166,53.84307285365296,53.249261216438356,52.696133870776265,52.224987543150064,51.8284167664658,51.49267722796804,51.20620917842465,50.95992764094057,50.74572749484805,50.55433482614155,50.37894617191781,50.21836699634952,50.072247045324,49.9404196946347,49.822675471803656,49.71721978904796,49.62089494524602,49.531242403652975,49.446612449086764,49.36530744840494,49.28300984723719,49.19719476621005,49.11008359041096,49.02438518754772,48.942169854007595,48.86525656598173,48.79347165319635,48.725097069358355,48.65861634366595,48.593302562557085,48.52818501963471,48.459671140402214,48.385596065909375,48.308615667694056,48.2317715956621,48.157518058930314,48.08778920444082,48.02263965502283,47.96045837591324,47.899883864841435,47.84016167454556,47.780421990639276,47.717126548401815,47.64822806762669,47.57627000987069,47.50440174246575,47.43511940673516,47.37045504088879,47.31037554176086,47.253309402853866,47.197853151141544,47.14335511593993,47.08931885885951,47.03268173093608,46.97133285410959,46.90778763221736,46.84504678888609,46.78562306472603,46.73155118595889,46.6828158136531,46.63765235731187,46.59462265776256,46.55294740753424,46.51168959698268,46.46729943784184,46.417705137442915,46.36544551883563,46.313661048104905,46.26483475193471,46.22102427077625,46.18226077203196,46.146917007062655,46.11349935168614,46.08124152659818,46.04919871232877,46.013896428638624,45.97320776141894,45.92969904029679,45.886520793949764,45.846230537477226,45.81083201978036,45.78037863995434,45.75322772020547,45.727900588221424,45.70357392076877,45.679321875684934,45.65168802956621,45.61861028287422,45.58259101660522,45.54681376164384,45.513840241324196,45.485703766679144,45.462403764062934,45.44230309623288,45.42390927488585,45.40642069520174,45.38888492630625,45.36787549474886,45.34134274863013,45.311824382990864,45.282468642351596,45.25582331997717,45.23389719634702,45.216700585689416,45.20256228234805,45.19000437454338,45.178225458789946,45.16629823950645,45.15079380475273,45.12969278995434,45.10554784589041,45.081528647318294,45.06016527307528,45.04347251849314,45.03144070570776,45.02240619346134,45.014875073488845,45.00805700136987,45.001027772716895,44.990394163218305,44.974137285517884,44.95483784703196,44.93565526837899,44.9191191924458,44.90719192536462,44.89986070593607,44.89545995856164,44.892503737374305,44.89019753024521,44.8876248425799,44.881407194863016,44.86956387792,44.85464893459061,44.83982641084475,44.827620043379,44.819993129001055,44.81691200797216,44.816708110730595,44.81789603812785,44.81968321240175,44.82116513582977,44.81898197305936,44.811159559360725,44.80027928456721,44.789490802273434,44.78130533116438,44.77766548013699,44.77852921399182,44.78223205827563,44.786923535045666,44.78962712054794,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985,44.789971999999985};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0009349796745205481,0.009232196884018265,0.030829078714884977,0.06605002662250044,0.11387456348413243,0.17355352111872147,0.24418825698141702,0.32571396771876643,0.41700484971461194,0.5175369066392694,0.6256606063265339,0.7359830139314819,0.8419769909474885,0.9432456142762558,1.0398672928615789,1.1327506509078773,1.2218280470433789,1.3073507007305938,1.3895388137995608,1.4686806679506015,1.5449097368150684,1.6184922499999999,1.689700770498353,1.758791091719721,1.8258836818607307,1.8911386258447491,1.954675064988148,2.016657413369669,2.077144028401826,2.1362327287557075,2.1940209602532,2.2507904623808854,2.3067465301027394,2.3620204572716896,2.4167009342938597,2.4709314093978154,2.52476424380137,2.5782593400000007,2.6314377789394787,2.6843789093398644,2.7371179461529684,2.789942260958904,2.8430585938339945,2.8965103922574365,2.950288567579909,3.0044266215296798,3.0589430208109385,3.1139195997753077,3.1693187369634708,3.225113394589041,3.2813304225142854,3.3384418551819617,3.396781238721461,3.456250163904109,3.516699539561906,3.578148793088929,3.6405333344748865,3.703834286358448,3.768022777933728,3.833110590271009,3.8989809426826487,3.965595908013699,4.032902905696097,4.100880271420795,4.1693225755022825,4.238108295901827,4.307217093214375,4.376724660279836,4.446597191495433,4.5168535137671215,4.587518504430347,4.659051998215435,4.731783155547945,4.805688895970319,4.880650293430459,4.956550726428532,5.033193428721462,5.110574941894977,5.188693798888078,5.267638865808132,5.347454138869863,5.428665060410959,5.511704858444869,5.596600365708885,5.683178006940639,5.771312632009132,5.860755352478605,5.951409222853538,6.043201413550228,6.136149155136985,6.230251316240424,6.325623801414465,6.422149430787672,6.519701180707762,6.618135067229896,6.71744538668485,6.817455474223743,6.9179351440981725,7.018718558356164,7.1198319628995455,7.220936808561645,7.319296500456621,7.412291296648452,7.499894068158763,7.582277096484019,7.659662494246575,7.732268042558013,7.800356039867506,7.863922653824201,7.923057503116438,7.9780597318893625,8.02931263737602,8.077099161689498,8.121724485593608,8.163384491005566,8.20222345022435,8.23831821115297,8.271790276689497,8.302729429311823,8.331094799297977,8.356853905719177,8.380235909383563,8.401502713459655,8.420920414573228,8.438711530410961,8.45500789724886,8.469841998469384,8.483257294927014,8.495298286164383,8.505996679132418,8.515219152681276,8.52289792576244,8.529207013127854,8.534368179200914,8.5385873759871,8.542062693359844,8.544880797534246,8.547031658196348,8.548503028352918,8.549309154788846,8.549442595331051,8.548732766997716,8.547068918939665,8.544597131648981,8.541515454452053,8.538006425525113,8.534242021884685,8.530282964088721,8.52609635952055,8.521643864098174,8.51692340443515,8.511956274088567,8.506607882123289,8.500750191792237,8.49451225828343,8.488068017623855,8.481588903527397,8.475230314828767,8.469042920196248,8.462969431211013,8.456958658812786,8.450983083892694,8.444999842201016,8.438797837265017,8.432233926335616,8.425424779566208,8.418544868289604,8.41174868028021,8.405189711050228,8.39891048502283,8.392852756269557,8.386947448968298,8.381163258184932,8.375448858687216,8.369594492792187,8.363441355819548,8.357104694463471,8.350753386986304,8.344546602139443,8.338624346903273,8.333029544646118,8.327698181210048,8.322562932509669,8.317579446617946,8.312696178150686,8.30770004644977,8.302437111822679,8.297010286782724,8.291590452203197,8.286333804646118,8.281384837209373,8.276775757176905,8.272443443458904,8.26831701237443,8.26435530365297,8.2604985100742,8.25653540737443,8.252310271621006,8.247929478892695,8.243558551643835,8.239351977865295,8.235450929931508,8.231891162176623,8.228602077202353,8.225513982922374,8.222584073710046,8.219756020195,8.216813606482804,8.213603386004564,8.210232447545662,8.206867450073295,8.203660053139112,8.200753010993152,8.198179967317353,8.195873146786623,8.193758516925106,8.19179457747717,8.189924434075342,8.187935860350201,8.185672647621983,8.183244307111872,8.180816912134704,8.178544186212228,8.176563655965579,8.174909558687213,8.173513387294518,8.172302948112444,8.171234494502146,8.170251963093607,8.169143453835616,8.167756208050877,8.166196802827619,8.16463207336758,8.163215400399544,8.162085740737082,8.16127475039948,8.160714195342466,8.160331648858447,8.160084080078848,8.15991519175328,8.159614246678082,8.159028778196344,8.158267907999539,8.15749725261506,8.15686994510274,8.156523779634703,8.156490602227526,8.156701817217233,8.157049120468036,8.157269093561643,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998,8.157297799999998};
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0025567004294520545,0.020424038495776255,0.03919246471164384,0.0437726287313927,0.04607020052273811,0.04850041875581131,0.051054239278424667,0.05374130439817352,0.05656211977550965,0.05954579088964244,0.06268121238652968,0.06598022325673515,0.06944344501024341,0.07310661007609975,0.07695608493847032,0.08100640565787671,0.08525833260341655,0.0897557388055406,0.0944818841597032,0.09945461539646121,0.10467486855081405,0.11019649891825738,0.1159989651826484,0.12210417499657533,0.12851327545778748,0.1352923936643711,0.14241630091780824,0.1499118964200913,0.15778058645778126,0.1661035697654016,0.17484985752968038,0.18405247800114152,0.19371317044438205,0.20393160802095966,0.21466975495890406,0.22596816311872148,0.23782895747501062,0.25037451593601073,0.2635581431426941,0.2774296243573059,0.29199156412634425,0.30739422045166803,0.32358025796232875,0.34050048387557075,0.3574037363615852,0.3737374147547097,0.38939200101484023,0.40448088582648395,0.4190632307339559,0.4333349968162412,0.44729203873401824,0.4610419350319635,0.4746448630610574,0.48829118955166306,0.5019817911780823,0.5158231427305936,0.5298733549147828,0.5443277867189784,0.5591830596289954,0.574546325173516,0.590470517547415,0.6071665970556305,0.6246176428047945,0.642933264847032,0.6621581346952928,0.6825294255558925,0.7040073444737441,0.7267057792648401,0.7506580226220775,0.776138068488048,0.8030739708869864,0.8315856696700914,0.8616919838186616,0.8937143408315369,0.927539324530822,0.9632947423755707,1.0009818495691667,1.0409800139014898,1.0831252141780823,1.1275547821917808,1.1742493322780523,1.223656964985403,1.2755534023287671,1.3300876268264838,1.3872163170773135,1.447466875645133,1.5105457288812785,1.5766149724086758,1.6456045363212066,1.7181316831978444,1.7938240439497717,1.8730565105136987,1.9574584246885998,2.0509363639456546,2.150194063926941,2.2501940639269407,2.3499316316091523,2.4501483394465655,2.55019406392694,2.650194063926941,2.7499316316091527,2.850147960679442,2.950348928242009,3.051750425799087,3.1551652949209648,3.2614352244402034,3.3697845570091327,3.4799910308904107,3.589923733514921,3.6985345247322656,3.8048318273630133,3.908943317123288,4.0108466339497095,4.112652498864187,4.2150541268949775,4.318371669121005,4.422328403443122,4.5275915605460115,4.633804363242009,4.740967269623288,4.84905467864255,4.9581660054754915,5.068203872134704,5.179012904121006,5.290411152431569,5.402478179278077,5.515137016392694,5.628388133105023,5.742204968668937,5.856691737779088,5.971769758504567,6.087439562888126,6.2036232963835864,6.320071198425843,6.436346920102739,6.552399962614154,6.6682038114446565,6.783864074928261,6.899301177648401,7.014515670194064,7.1294814673622655,7.2443032511573655,7.358938314292238,7.473641029143837,7.588639028001974,7.704073901035414,7.819866302054796,7.9360167181621,8.052498235789479,8.16941741155853,8.28669371644977,8.404327795091325,8.522233783013446,8.640108932425363,8.757461238584476,8.87423256724886,8.990396589163671,9.106058851758458,9.221139865799087,9.335640319360728,9.449534490794468,9.562925757783018,9.675788282351599,9.788486568173516,9.901358764062744,10.014560060246213,10.128013445547944,10.241719108904112,10.355650043775109,10.469911019956895,10.58442359931507,10.699188262671234,10.814158158141204,10.929300485394366,11.044396669520546,11.159428460502282,11.274368537105447,11.389322674894578,11.50421071084475,11.619033877283103,11.73376652405931,11.848511990191694,11.96317601655251,12.077647799543378,12.191787567065274,12.30568466710738,12.419259914155253,12.532514909703195,12.645422722831674,12.758086041125523,12.870428773744294,12.982450894977168,13.094132480603589,13.205618982152172,13.31687500605023,13.427908923287669,13.53869434907241,13.649332124832199,13.759747427511414,13.869939596118721,13.97992088961187,14.08969205742009,14.199265713812785,14.308729040525114,14.418130960724357,14.52758480512607,14.637014317465756,14.746421075684934,14.855779010897768,14.965188970098497,15.074575226940643,15.183938235730592,15.293252935386256,15.402619010185086,15.511961262100456,15.621280270890411,15.730550985559674,15.839873175157509,15.949172171575341,16.05844730605023,16.167674160277716,16.27695308944719,16.38620820673516,16.495439466095892,16.6046230847662,16.713858129533772,16.82306936678082,16.932257375570774,17.041397134939615,17.150588169620356,17.259755526826485,17.368900285045665,17.47799630965766,17.587144083910044,17.6962675619863,17.80536844509132,17.91442110960152,18.023524374679365,18.13260447146119,18.241661605136986,18.35067115863463,18.45973128896905,18.568767631506848,18.67778138972603,18.7867464590376,18.89576332814457,19.004756416095887,19.113725675456624,19.222647383526084,19.331620493116997,19.44057045045662,19.549496584931507,19.658305685065624,19.766613787477855,19.87386193732877,19.979981704223746,20.084949398444863,20.188860855355003,20.291643630136985,20.393299271347036,20.493804488766,20.59325104720694,20.69157019646119,20.78876308744292,20.884808451121597,20.979792237236758,21.073649761187216,21.166381652168955,21.257967787111067,21.348491174761705,21.437888450000003,21.526161340182643,21.613290746045735,21.6993544869442,21.78429401152968,21.86810990171233,21.950783828384733,22.032389797304564,22.112873446575346,22.19223358732877,22.270454032987747,22.347604730274217,22.42363325627854,22.49854002077626,22.572308360995084,22.645005661421763,22.716580939497714,22.78703570319635,22.856354436492254,22.924599841429938,22.991724370547946,23.057728509703196,23.12259938516419,23.18639414541289,23.24906992488584,23.310625939155255,23.371049707469993,23.430396196890985,23.488624478424658,23.545733742465753,23.60173237968036,23.656619393150688,23.71039528093607,23.763060168721466,23.814596969325297,23.865052170406027,23.914389956963472,23.96261184394977,24.009707910015095,24.055719468011578,24.10061550570776,24.144396392694066,24.187053098653845,24.228623513112257,24.26907905365297,24.308420065525112,24.346639285011975,24.383770556390825,24.419787599999996,24.454690736757993,24.48847434454488,24.52116759875833,24.55274739531963,24.583215155821918,24.612564527482096,24.640821764189553,24.667966938470318,24.694000698972605,24.718917708138708,24.74274080291283,24.765452480821917,24.787053491095886,24.80754063628515,24.826930965610888,24.845211146461182,24.862381906164387,24.87843993806547,24.893400000689923,24.907250685616432,24.919992570205476,24.931623862791003,24.942154285540642,24.951577223173516,24.959892107762556,24.96709816001011,24.9732021920896,24.978198759931505,24.98208789429224,24.98487108017442,24.98654934841025,24.987189357876712,24.98726786883562,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269,24.987269};
    C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0005037175364155252,0.004503905405422374,0.01194458859537671,0.01941961412027285,0.026405789048139835,0.033349295995890406,0.04059860662283105,0.048121155375005616,0.05581717258441501,0.0636045938842466,0.07148744859931508,0.07941079645346334,0.08717559524689845,0.09447403605856164,0.1012796658997717,0.10757756257644657,0.11340782442630436,0.11874860013812787,0.12360008683105023,0.1279617564510879,0.13183730355909562,0.13524678931392695,0.13834841296004569,0.1412999334366719,0.14412668851931285,0.14682677964726026,0.14940025556735162,0.15184667952567557,0.15416820743705553,0.1563632843847032,0.15843196892009134,0.16038185343224295,0.16227027957948448,0.1641516291757991,0.16603390826484019,0.16791668430779497,0.1698016741761983,0.17168757553995437,0.17357440462899543,0.17546172787396133,0.17735126003999177,0.179241142423516,0.18112747185730593,0.18300588338247623,0.18487753610369415,0.18674113314155252,0.18859668939840182,0.1904437890968261,0.19228411588691144,0.19411640065867575,0.19594066565068494,0.19775681733614667,0.19956877018272012,0.20137754634589036,0.2031834871986301,0.20498617613578238,0.2067872610341374,0.2085855035114155,0.21038090686986302,0.21217306814319312,0.21396362062758564,0.21575137688470322,0.21753665116780826,0.21931933488907604,0.22110109480702458,0.2228807070673516,0.22465818736073062,0.22643312497188536,0.228207141858619,0.22997901200342466,0.23174874605136983,0.23351567231558626,0.23527942272036953,0.23703683531849315,0.23878763794292238,0.24053142380070866,0.24226979608902552,0.24400155581506852,0.24572671093721463,0.24744487302672355,0.2491576094394603,0.2508634578002283,0.2525604749600457,0.2542463219328543,0.25592224473580544,0.25758709104223737,0.2592408722340182,0.2608832327815642,0.2625156556066072,0.26413701953310503,0.2657473457054795,0.2673459970591611,0.26893255013264156,0.270504022390411,0.27206016324771687,0.27360062597324525,0.27512680911670656,0.27663767081506846,0.2781332154189498,0.27961362875799084,0.2810789183424658,0.2825299896004566,0.28397327123059357,0.28541468849241464,0.2868564718046479,0.2882976423093608,0.2897382014200913,0.291177813047259,0.29261780218658456,0.29405717249885843,0.29549592536415525,0.2969337438429585,0.29837193382649024,0.299809505186073,0.30124646554566215,0.30268248589550745,0.30411887546639593,0.30555464787328773,0.30698981572716894,0.30842403919350253,0.309858637097191,0.3112926180547945,0.31272598841438354,0.3141584212346483,0.3155912287279861,0.31702341948515983,0.3184549998447489,0.3198856432757941,0.3213166603587812,0.32274706091552513,0.3241768525239726,0.3256057140600906,0.32703494198957633,0.3284635535947489,0.3298915626974886,0.3313186361012364,0.33274607486922986,0.3341729037682648,0.3355991253767124,0.33702441813097916,0.33845007649091435,0.3398751251906393,0.3412995655502283,0.34272307141757125,0.34414694811259894,0.3455702166130137,0.3469928782214613,0.3484146121904646,0.3498367097342834,0.35125819803538816,0.35267907964383566,0.354098147462466,0.3555104557217013,0.35690878692694067,0.3582922599223744,0.3596605783788332,0.36101497303852886,0.3623545263869863,0.3636792481175799,0.3649888490966826,0.36628451777564436,0.36756536579109594,0.36883140750570775,0.3700823684778614,0.3713193824489857,0.3725415951392695,0.373749028086758,0.3749414252769232,0.3761198508142389,0.3772835131666667,0.37843241485730594,0.37956630700075483,0.3806862253509214,0.38179140239497716,0.3828818453184932,0.38395732362877083,0.3850188010817988,0.38606556281621,0.38709762196917813,0.38811474518155675,0.3891178654818224,0.39010629067579905,0.39108003231849314,0.3920388816499301,0.39298370358286855,0.39391386722260274,0.3948293626118722,0.3957300105293748,0.3966166178553441,0.3974885874680365,0.398345919086758,0.3991884305858473,0.40001689206404545,0.4008307376575342,0.4016299780034247,0.4024144380487997,0.40318482745783113,0.4039406252853881,0.40468183687214604,0.405408550956621,0.40612078127853884,0.40681852285730596,0.40750177818264843,0.4081703439806872,0.40882480679611116,0.4094647228710045,0.41009010442579913,0.4107008237064713,0.411297431989464,0.4118795203230594,0.41244709436758,0.4130000508387354,0.4135388758701843,0.41406320147374437,0.41457304924200905,0.4150683004048768,0.41554941218484726,0.41601605755707755,0.41646824032077623,0.416905876120649,0.41732934718687775,0.4177383760901827,0.4181329675890411,0.41851304551574464,0.4188789521160235,0.41923044331050224,0.4195675160502283,0.4198901135741697,0.42019852573253674,0.4204925429805937,0.42077217444748866,0.4210373702959241,0.42128835928527586,0.4215249725947488,0.42174723029109584,0.42195508069700205,0.4221487227651303,0.4223280096472603,0.42249296108219175,0.42264355475681814,0.42277990994600706,0.42290194663584474,0.42300966806278534,0.42310306374140394,0.42318221454717175,0.42324707231963465,0.4232976287420091,0.42333390888702377,0.4233559190936728,0.4233645146723744,0.4233657035513699,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001,0.4233657400000001};
    CF4={35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.0,35.00410570936072,35.03729846081668,35.104715555322265,35.183408305136986,35.26674528847032,35.35423082394453,35.44676726902088,35.54401009600456,35.64632610753424,35.75373506786311,35.86734521504106,35.986734124429226,36.112351972146115,36.24422209309766,36.38370582748086,36.53028338755708,36.68450860582191,36.84641079221685,37.01766029709933,37.197618816780825,37.38696705833333,37.58574064074843,37.79598969908925,38.0169323650685,38.2494029293379,38.493444158438756,38.75157482660254,39.022833999429224,39.308246374429224,39.607865238671806,39.924782433517976,40.25781786004566,40.608229254223744,40.976082716956725,41.365173605962276,41.77405355376712,42.20426707659818,42.65589467345859,43.13359605733462,43.63559337922374,44.16378285308219,44.7431718983145,45.521996656436365,46.44553082191781,47.35174657534247,48.24938468448237,49.15133505501908,50.051746575342456,50.945433789954336,51.79941886867778,52.657573670683924,53.551746575342456,54.445433789954336,55.29941886867778,56.157573670683924,57.04543378995433,57.901649543379,58.7494188686778,59.60126088529581,60.451649543379,61.30164954337899,62.14941886867779,62.99494809990768,63.80155251141553,64.60786529680365,65.4494188686778,66.29494809990767,67.10155251141553,67.90155251141553,68.69945305287322,69.50118671557252,70.30155251141552,71.10155251141553,71.89322582154357,72.65111254584927,73.40776826484019,74.20155251141551,74.99322582154352,75.75111254584922,76.50145547945205,77.25038520981735,77.99586169044402,78.77244127778029,79.5479000541096,80.31712968892693,81.07530151687129,81.82479062889314,82.56011159372146,83.28211526244293,83.99056973210944,84.69970733154803,85.41389591655252,86.13529866940638,86.8619804949516,87.59860642846552,88.34268386815069,89.09421671974884,89.85302523930308,90.61980883424845,91.39383296472603,92.17365457842465,92.95764240369476,93.74630865757884,94.53911056769407,95.33605243892696,96.13694899089255,96.9425332479318,97.75225117682648,98.56610767260274,99.38353383651844,100.20262479512876,101.0201682454338,101.8357884589041,102.64929537144747,103.46144046681387,104.27165410273973,105.07994556506848,105.88613122758689,106.69093965170173,107.49408846575345,108.2973880365297,109.10246934212267,109.91032390036992,110.72040123401825,111.5327006369863,112.34704002834546,113.16416545485565,113.98351507534248,114.80509197260277,115.62825856974075,116.45067604270842,117.26868196232876,118.08183576598174,118.88995535648877,119.69377214040783,120.49272843378996,121.28683973173513,122.07591707929738,122.86068074493475,123.64091710273975,124.41890353196347,125.19673503749033,125.97543692120166,126.75448998744294,127.53388214954337,128.31344431020906,129.0938840871011,129.87466985388127,130.65579951027397,131.43696281106995,132.21796244705504,132.9973499611872,133.7749912876712,134.55070964755967,135.3252159805468,136.0979665159817,136.86897658561642,137.6380672077813,138.4059420208661,139.17195815867578,139.93540523630136,140.69537837238943,141.45245579865636,142.2061219543379,142.9563771130137,143.70306228159544,144.4468379157372,145.18720383105023,145.92416523515982,146.65762094038354,147.38874187426703,148.11752420547947,148.84403720433792,149.5681212902101,150.2904298369202,151.0104711894977,151.7282429394977,152.44382593835618,153.15722643150687,153.8685743070776,154.57882131164382,155.28867777858872,155.9989205777129,156.70906135159817,157.419111359589,158.12890660156074,158.83908189034545,159.5491613995434,160.25914890981733,160.9688679382314,161.6789719541196,162.38898020662103,163.0988914714612,163.80854800664972,164.5185920087831,165.2285390057078,165.93838152739727,166.64796808647105,167.35794082369878,168.06781031849314,168.77758158333333,169.4870969208461,170.1969921454419,170.90679037442922,171.61649163926938,172.32593824611374,173.03577095124697,173.7455004303653,174.4551316952055,175.16450708048885,175.8742622729901,176.58391923744293,177.29347175913242,178.00276841715944,178.71245108790575,179.42203179908674,180.13152055821914,180.84074849698084,181.55036240053835,182.25987934931504,182.96929187100457,183.6784473313559,184.38798247342302,185.09741941324197,185.80675193493153,186.5158299134728,187.22530003036968,187.9346619748858,188.64393073401826,189.35248914174588,190.05782296523566,190.75628526255704,191.4474135616438,192.13106846517954,192.80786811885866,193.47733967694066,194.13948796803652,194.79418025436658,195.44199577019864,196.08249407534245,196.7156786118721,197.34140454584926,197.96024216356952,198.57176597602742,199.1759717694064,199.77272883733193,200.36258730808197,200.94513038242007,201.52036741666666,202.08817935826656,202.64906495031127,203.2026435239726,203.74891930936073,204.2877723928999,204.8196813436822,205.34428667351597,205.86159245890414,206.3714879184258,206.87443646997346,207.3700798150685,207.85842684931507,208.33937968480677,208.8133641030921,209.28005169977166,209.73943999086757,210.19144270803702,210.636459238494,211.074177347032,211.50461187557082,211.92766697671357,212.3437268625022,212.75249922374428,213.1539850091324,213.5480999885408,213.9352032376519,214.31502235730593,214.68755939155253,215.05286267123287,215.4109209623288,215.76174549086758,216.10533252511416,216.44157600079222,216.77077597884076,217.09269861643835,217.40734689954343,217.71466649892088,218.01491360284888,218.30789174200905,218.59359752739724,218.87197201304363,219.14326996888803,219.40730611643835,219.66408064497713,219.91353624751102,220.15590381898906,220.39100049086755,220.61884376255705,220.8393779910859,221.05280143388666,221.25896235958905,221.45786688812782,221.6494722369563,221.83395779081516,222.01118672602738,222.18116999771686,222.3438652145745,222.49942413863315,222.647728586758,222.78878436415528,222.92256694674631,223.04919049556167,223.16856170433792,223.2806887305936,223.38555867891804,223.48324935020707,223.57370480593605,223.65692058333332,223.73288414742868,223.80166318208703,223.86319791552512,223.91749369292233,223.96454587960056,224.00439078787394,224.03700227397258,224.0623867945205,224.08053884581557,224.09146837543975,224.09561996118717,224.09611497260275,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612,224.09612};
    SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0006312785388127854,0.005619304713426654,0.015014833944656534,0.025019406392694066,0.035019406392694075,0.044993163160915235,0.05501483394465653,0.06501940639269406,0.07501940639269407,0.08499316316091525,0.09564611248346933,0.11066038812785388,0.13067009132420093,0.15498290790228808,0.17940580632282854,0.20003881278538813,0.22003881278538814,0.2412317725877685,0.27004450183396966,0.29942694063926945,0.32567979452054796,0.3556022126157148,0.39005191880629786,0.4250679223744292,0.460699200913242,0.4999726526436609,0.5413218928562517,0.5919908675799087,0.6570199771689497,0.7374361978191981,0.8370421750630036,0.9514857305936073,1.0765051369863012,1.2111531489382936,1.3558463707363326,1.5071849315068493,1.672845319634703,1.8548735184769318,2.0402744279761458,2.227252853881279,2.426650684931507,2.635479149512189,2.8509502083489284,3.071689497716895,3.2985525114155254,3.514230284826709,3.7278366269930387,3.9516586757990866,4.152231735159817,4.3342394172468,4.5422053484542255,4.764805365296803,4.986689497716896,5.21484275270105,5.445341180727099,5.676077625570777,5.914243721461187,6.176166433987387,6.449806194964071,6.716615103070776,6.9869865565525116,7.262325140087831,7.543931952262022,7.829225074805937,8.118441674143837,8.410798550557177,8.708172509228485,9.009559889737442,9.314960906050226,9.624300653272888,9.937863701483833,10.255650025159818,10.579179158789954,10.90988932987998,11.248304641445218,11.594190275570776,11.947546026255708,12.308281834235345,12.676730162023729,13.05263616541096,13.43599967351598,13.826564709565337,14.223583161031577,14.62567053892694,15.03266820479452,15.44447586727612,15.861472484885034,16.28337071073059,16.7101697576484,17.1417665465323,17.57855758083221,18.020099782305937,18.46540336780822,18.913372157736983,19.3642732394815,19.817795579680364,20.27394131803653,20.732602462857127,21.194198248670062,21.658411537899543,22.125243404337894,22.594929394140035,23.070326358409435,23.55353434931507,24.044900788013695,24.54430433511614,25.052204186738653,25.568249863242006,26.092440185045664,26.624645797389395,27.16535692662437,27.713535641666667,28.264534575228307,28.813575950549566,29.360490373250556,29.90490267111872,30.446816743378992,30.986111442156346,31.52327662799736,32.057943832077626,32.59011690194064,33.12016227048931,33.65197143191793,34.18858837876712,34.73050397237443,35.27758787382352,35.83034215861467,36.38838538493151,36.95171798413242,37.52020471262757,38.09436765922724,38.673757960502286,39.25801631666666,39.846641870966515,40.44012116074961,41.038044991894985,41.64041601015982,42.2470897857231,42.858622966824804,43.474592823858444,44.0950018469178,44.71962513062106,45.34849911831287,45.98065203527398,46.616010167694064,47.2544233959347,47.89647593549418,48.54172582111872,49.19017420810504,49.84189247020547,50.49687985799087,51.15491906929223,51.81448991997718,52.473847343756404,53.13337554235565,53.79262041381278,54.45158482899544,55.11011915768271,55.768823417953875,56.427245071461186,57.085386486643834,57.74309809615365,58.400979167755196,59.05857785399544,59.71589714349316,60.37278715802892,61.02984679084855,61.686623760616435,62.34312267385844,62.99919209421926,63.655430663713595,64.31138729098173,64.96706545479454,65.6223151538139,66.27773428498483,66.93287107111873,67.58773023413241,68.2421619620387,68.89676215602778,69.5510807247717,70.20512188778538,70.8587358948081,71.51251802615964,72.16601937762557,72.81924354063925,73.47204095098185,74.1250066446977,74.77769115536529,75.43009919269406,76.08208100601529,76.73423138721056,77.386100806621,78.03769384394978,78.68886093536382,79.34019637949511,79.99125220650684,80.64203074497718,81.29238473788708,81.9429061210969,82.59314810673514,83.24311426894977,83.89224952492764,84.53829120238477,85.17794106917809,85.81079394257993,86.4367139610107,87.05626682745931,87.66902967579908,88.27500741712329,88.87406971848442,89.46675817087514,90.05266738093609,90.63180373961187,91.20404143832809,91.76989873399766,92.32898868344749,92.88131628630136,93.42676311940141,93.96582301637255,94.49812633504565,95.02367968013698,95.54236951261508,96.05466464425105,96.56021558401825,97.05902717328767,97.55099311728797,98.03655799047085,98.51538993150687,98.9874936392694,99.45276943410123,99.91163693196597,100.3637853752283,100.80921233105022,101.24783021260323,101.6800345918045,102.10552829680366,102.52431486757989,102.93631057892308,103.34188135101492,103.74075956050228,104.132937380137,104.51834215648002,104.89731557606608,105.26960330593609,105.63520861187213,105.9940549452741,106.3464697646749,106.69220577054797,107.03126981963472,107.36369762328768,107.689502913242,108.00868695433788,108.32124350114155,108.62707541564362,108.92645182469373,109.219180619863,109.50526465296805,109.7846380904072,110.05755592219664,110.32383175570776,110.58346828652968,110.83641822866609,111.0829024991953,111.32276285958905,111.5559906392694,111.78254957816203,112.00263654203474,112.21610519634703,112.42295296803651,112.62315089344885,112.81687180640081,113.00398750114158,113.18449526484018,113.35837091767722,113.52575704343514,113.68654978196345,113.84074753767123,113.98833215314268,114.12942099516867,114.26392328767122,114.39184728082192,114.51316461124834,114.62798616842889,114.73623426369863,114.83791075456622,114.93300452144622,115.02159131435735,115.10361646461187,115.17908169863016,115.24797689973052,115.31036517498501,115.3661986415525,115.4154838675799,115.4582167415101,115.49443151510843,115.52411078652968,115.54725475570778,115.56385779452677,115.57393656993104,115.57788130251144,115.57843240410959,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999,115.57844999999999};
    CCl4={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0032744417808219174,0.02914484265601218,0.07786380783866059,0.12975507020547944,0.18165071917808218,0.23340828957382034,0.28537691400304416,0.3372569349315069,0.3891444063926941,0.44086455098934546,0.4928332267884323,0.5447444063926942,0.5966006221461188,0.6483207782206751,0.7003269881727675,0.7522444063926942,0.8041006221461188,0.8558207782206751,0.9078206753873793,0.9596753710045661,1.0113628595890412,1.0629957555143845,1.1150771365122139,1.167100913242009,1.2191009132420092,1.2712758100032437,1.326085867829428,1.384492294520548,1.4459981164383562,1.5102672639543877,1.5774781545524863,1.6475777397260274,1.7210214041095888,1.7973213320607828,1.8770598248371886,1.960166095890411,2.0471738584474886,2.1379359632707042,2.2331459453052873,2.332260273972603,2.435769006849315,2.543486612957557,2.6563612882700802,2.774423401826484,2.8978709474885846,3.026097142064027,3.160519436958854,3.3010301940639266,3.4476049657534245,3.6006807077625567,3.7606311643835624,3.926638755707762,4.095201712328767,4.262822868790079,4.430748468572997,4.599208847031964,4.779025171232877,5.001140343276693,5.262394582927863,5.5285162100456615,5.7944530821917795,6.0606262005015346,6.350428823265215,6.7371698630136985,7.173995719178083,7.464374137285724,7.633240328617411,7.907885502283105,8.351278652968036,8.861145509893456,9.380895395738206,9.90063441780822,10.42031569634703,10.934647902787134,11.451395226688625,11.976690639269405,12.541777968036529,13.14458295281583,13.755904870624049,14.366815068493151,14.981193493150684,15.593956811263318,16.207798706240485,16.85015125570776,17.623548515981735,18.51437784764329,19.42634988896375,20.336765981735162,21.246765981735162,22.154377847643286,23.07203139581306,24.029428652968036,25.039494863013697,26.069292387154732,27.105904034733143,28.136998858447495,29.17015525114155,30.238583130598595,31.44757687077376,32.832612442922375,34.6084897260274,36.30594948786086,37.53864255059012,38.75126712328767,40.10029566210045,41.5864175586995,43.218831174988146,44.97982876712329,46.869449771689496,48.87732228584974,51.00767161963221,53.24886643835617,55.60030194063928,58.030804488858955,60.536283828629884,63.08744292237444,65.61793493150685,68.05711937645033,70.41713038026798,72.68366381278538,74.8641301369863,76.95860069366469,78.98289600019962,80.92492694063928,82.7947910958904,84.59005124510317,86.324359651421,87.990024543379,89.59116095890413,91.13147103076578,92.60700192753949,93.905225456621,94.90247488584477,95.91163761010056,97.29229991641091,98.77672203196346,99.88663013698631,101.11222599932631,102.40781308481174,103.45194063926941,104.4708789954338,105.47466913691143,105.62396680140728,104.9362271689498,104.3173687214612,103.55677417845646,102.78626188337451,101.92309931506848,100.9364703196347,100.15052755944805,99.34547822940839,98.39243607305936,97.37734874429223,96.34067006013424,95.38234305212467,94.42684360730595,93.41601484018265,92.27524433278438,90.91485590415574,89.23252846723744,87.23384761392695,85.04268296252964,82.67251796439727,80.14909888002283,77.47908472408675,74.67931977233637,71.75320972958524,68.8195609545662,65.98363436038814,63.25714527792811,60.63281428526118,58.104881143150685,55.6676877347032,53.32080664033611,51.06141288856764,48.889863144406384,46.8047664194064,44.80366218944594,42.880902229675364,41.03427715365296,39.26072602568493,37.55732236226514,35.91758478247997,34.33896299760274,32.820745776484024,31.362538601271925,29.96212146566765,28.61940710296804,27.332423685958904,26.098818112197147,24.915147213496827,23.780191275114152,22.691861360045664,21.647274461871522,20.64312819780142,19.679496052853885,18.75579330650685,17.871455393648475,17.02489730760629,16.21533399543379,15.441014739840183,14.70051353090176,13.991834299169412,13.314051900114153,12.665148505707764,12.043668668762633,11.44854887033461,10.879709122488585,10.336560065433792,9.818571185944307,9.32433943129295,8.85303437436073,8.403576407385843,7.975095358481795,7.566256526127393,7.176055666232877,6.803457888276255,6.448113781277043,6.109322875596695,5.7868698733105015,5.480280131575342,5.188959632962484,4.911884046151813,4.648525398618722,4.398238900296803,4.160430560189385,3.934080704743525,3.7186761509360733,3.5138947253310504,3.3194763078025424,3.1349255650100436,2.960024943732877,2.7943306311757987,2.6373719730099556,2.488553020284546,2.3475628592922377,2.213994088607306,2.0873757309303964,1.967184383645888,1.8532801537557075,1.7454572287899541,1.6435194233520474,1.547160920072704,1.4561785198059363,1.3702678111643838,1.2891603560017593,1.212530753947713,1.1401824062785388,1.0718223981621005,1.007193362152968,0.9461491986826484,0.8885570205445207,0.8342788895136986,0.7831904926655936,0.7350827207218665,0.6898083294246575,0.647198780869863,0.6071093934143585,0.5693589471774678,0.5338064568630136,0.5003082522831049,0.46878000606836207,0.4391122009869282,0.4112406620570776,0.38508080657534255,0.36054200172495454,0.3375013943360219,0.3158798966700913,0.29559155563584477,0.2765577791135876,0.25867127917337873,0.2418655362488584,0.2260885824760274,0.21129594904287993,0.19742726153851028,0.18444480449086761,0.17229648524200913,0.16092957601752253,0.1502833512181644,0.14031897398515983,0.13099257511757992,0.12225811681815629,0.11406666476482143,0.1063956237196347,0.09921935001723743,0.09251345398111822,0.08624704658154024,0.08039720638025115,0.07493552529646119,0.0698365534353376,0.0650721248453739,0.060622984761073063,0.05646500845559362,0.052577841615795214,0.048943462110204415,0.04555107319897259,0.042387471092579905,0.039440282584370705,0.036693248210348514,0.03413406219760274,0.03174952762705479,0.02952813597917384,0.02745680128866838,0.025525135803538813,0.023722776952397263,0.022042652398690646,0.02047668589659562,0.019019398874315068,0.01766439276232877,0.01640515915194438,0.015233738210451755,0.014144535682762556,0.013131764241666668,0.012190173364329293,0.011313312083152742,0.010496812731552509,0.00973706482547945,0.009030951508238454,0.008374698867742067,0.007765676534018266,0.007200668492922374,0.006676503401865909,0.006189713135571275,0.0057379023479109574,0.0053185188187100454,0.004928998965783803,0.00456669611458798,0.004230155713538813,0.0039178452708219175,0.0036283253629005416,0.0033599111424960394,0.0031112980540981727,0.00288098185520548,0.002667609647610787,0.00246974797949753,0.0022863657401826485,0.0021162673311986304,0.00195842862296629,0.0018119340228165781,0.0016761821432876715,0.0015504916069178079,0.0014342269199559598,0.0013266170028681352,0.0012270603691324202,0.0011349326881164384,0.0010496871904709995,0.0009707302251544432,0.0008975854761404111,0.0008297852788664383,0.0007669705369748857,0.0007088266078835616,0.0006550495194315068,0.000605347329010274,0.0005594366769018764,0.0005169815497592197,0.00047773708690525117,0.0004414564252659817,0.000407916795001048,0.0003768586140001217,0.00034809953396803655,0.00032148576297146117,0.0002968836017493512,0.000274139354332198,0.00025314117777168953,0.00023375951423401826,0.0002158687337300634,0.0001993353451431931,0.00018406419460502283,0.00016995660747831054,0.00015691553185845995,0.00014484252509077526,0.00013367961066666667,0.0001233671501849315,0.00011384946613644357,0.00010506371959191555,9.696050957853881e-05,8.948486456381278e-05,8.258749293565261e-05,7.621721647243775e-05,7.033647413984017e-05,6.490312706038813e-05,5.9880981286748015e-05,5.523758815780217e-05,5.095077411518265e-05,4.69961592336758e-05,4.3351109388562016e-05,3.9989118792997235e-05,3.688932998424658e-05,3.403045443493151e-05,3.139383773870424e-05,2.895962553890823e-05,2.6711832607305935e-05,2.4634896798401824e-05,2.271727843517167e-05,2.0946694863120055e-05,1.931412336232877e-05,1.7809788535730596e-05,1.642411321331437e-05,1.5146258231119783e-05,1.4033247237785387e-05,1.3462233067465757e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05,1.3391275000000005e-05};
    CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00044473573059360724,0.003948836600481574,0.010478577847019487,0.017294597888127854,0.023959627283105026,0.030901503218803805,0.04081632944082641,0.05401842237442922,0.07177848173515981,0.10444801170559175,0.1723769436335055,0.299108698630137,0.5106528652968036,0.817678878097163,1.174994881727674,1.5983112442922376,2.1709422374429224,2.906917800733588,3.823745894153754,4.947110616438356,6.239684189497718,7.548749062429821,8.847579407141252,10.356759589041097,12.307005079908677,14.788031239863264,17.877847393767,21.575408675799086,25.84895890410959,30.643954200663718,36.053253493275434,42.17608961187215,49.19173401826483,57.16974226800908,66.100670247274,76.02270547945206,87.22777111872146,99.57884009531652,112.27597150485315,124.67356164383561,136.7359132420091,148.60491048481674,159.23265320508023,168.58669520547946,177.69760273972602,185.7945647129276,193.90698704992886,202.88659817351598,212.3010216894977,222.96704705941065,234.65281208673306,244.6479566210046,252.7084189497717,259.8211247099333,264.70460887791,267.6228652968037,269.282448630137,269.4315004553734,268.9239329914913,268.1354166666667,266.884446347032,265.20119644683984,263.4726552012376,261.8654280821918,260.05231735159816,257.9826060770517,256.0408687651271,253.9888984018265,251.22512557077627,247.9522903410934,244.5666925349327,240.99631652397258,237.26682538470322,233.52331635141726,229.7654200508895,226.02478138242006,222.3029126952055,218.6154614511565,214.94085907548285,211.2907124714612,207.66445750456623,204.06326933267212,200.4832680599159,196.92053604109591,193.37172431849316,189.84314069620356,186.33746402001148,182.86226439840183,179.42232722831048,176.01990111626992,172.65076224884908,169.31650261301368,166.01709255593607,162.75231686597672,159.5134357463383,156.29962504452055,153.1151287842466,149.9650306428687,146.85026407450655,143.77650494863013,140.74458299543377,137.75387721269684,134.8007441133724,131.88699484474887,129.0118805696347,126.17157560548442,123.36091910126446,120.58497521118721,117.84703972374427,115.15049029453927,112.49548832337751,109.88427760045664,107.3155802888128,104.7890457291838,102.30214372744155,99.8558209803653,97.44628542762557,95.07181264610688,92.73252016330689,90.4324247640411,88.17351234166667,85.95804154694963,83.78413716212758,81.6520889923516,79.56088927819634,77.510396489809,75.49789180040203,73.52170187773972,71.5798919122146,69.6743735365434,67.80510857656512,65.97472950707764,64.18439216757992,62.434336129140775,60.721846897942704,59.04709657305937,57.40938869977168,55.80815751933715,54.239431926391376,52.70259631369864,51.198537736301375,49.728623475879566,48.29232729303465,46.89120308789955,45.52481764805936,44.19232288626207,42.89157268494835,41.62273041358447,40.384916210388134,39.17635411106557,37.99452435620836,36.84070468527398,35.71549948321918,34.61960695461112,33.55243914745303,32.51438720045662,31.504501531849314,30.522113040586245,29.565667510894652,28.63503812659817,27.72861357180365,26.84511450490868,25.984738854109583,25.147812455251138,24.334558140296803,23.545350733419415,22.779079017616397,22.03546743824201,21.31374597625571,20.61343609771315,19.933238066603042,19.27234811084475,18.62980748847032,18.005779168197474,17.399841922827306,16.8124333423516,16.243506258219174,15.692783808315866,15.159108606076742,14.642209340296802,14.141539730022833,13.656643410197246,13.186141375978742,12.729614926027397,12.286992103424657,11.858375224250194,11.44334856329971,11.042104266210046,10.654305351826483,10.27950185680596,9.916862977267167,9.566213464063926,9.227114815993149,8.898933232849203,8.580820971147636,8.27290965278539,7.975159079246574,7.687547961491629,7.409729567524734,7.1416404172374435,6.882875964611873,6.633103470726226,6.391787777714961,6.158760256312785,5.933506328744291,5.715656001741834,5.50492614928394,5.30143246270548,5.105104039737443,4.915886726586321,4.7334140296253775,4.557522362785389,4.387934198424658,4.2244447872106825,4.06666835396858,3.9143438759817357,3.7671803355365285,3.6251348750260743,3.48804612601595,3.355953757625571,3.228786042819635,3.106412694943671,2.9885249178723146,2.875010312328767,2.765687893527397,2.6604095646339543,2.5588276955922975,2.4608134202283103,2.3663103398515983,2.275290666977818,2.1876172924337838,2.1033003601712337,2.0222424382077624,1.9443098489980535,1.8693010435034434,1.7971389082077627,1.7276956317922376,1.6608224192035335,1.5963161189543564,1.5341812493150682,1.474381818196347,1.4168870991059712,1.36161180062723,1.3085155128881276,1.257494234543379,1.2084713176127206,1.1613158465699778,1.1159734844634706,1.0723399229908674,1.0303248451049856,0.989851470468542,0.9509221904315069,0.9135202240342465,0.8776191372100519,0.8431343880179903,0.8100333873858448,0.7782463037671232,0.7477049774871373,0.7183385710876499,0.6901031301872146,0.6629177359257991,0.6367516809908675,0.6116009110696347,0.5874452186038811,0.5642594926472603,0.5420135872782268,0.5206429950571025,0.5001322024440639,0.48044273517237435,0.46153819890441533,0.4433494839100669,0.42584477356392697,0.4090054114292237,0.39282380966626745,0.37728617090512323,0.3623859199794521,0.3480848311484018,0.33436752370597844,0.3211942980345491,0.3085473974349315,0.296400544510274,0.2847246349441325,0.2734935452064557,0.2626892641609589,0.2523027944942922,0.2423416932524578,0.23278826545121892,0.2236323477591324,0.21485305636643837,0.20643218132403873,0.19834481755736463,0.19057939915296807,0.1831137629714612,0.17593068724955088,0.16901590831257018,0.16236831214155253,0.15598134525684934,0.14985171192530006,0.14397914001453763,0.13835386271004566,0.13294712468378994,0.12774902650226438,0.12275991087468187,0.11796863078538812,0.11334988028082194,0.10891263311865283,0.10465154318909226,0.10056490392305935,0.09664770909965754,0.09289366137817263,0.08929075899225303,0.08603686900810503,0.08433776362260272,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998,0.08412566099999998};
    CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0038021906392694065,0.03868118321917808,0.13397297538176509,0.2805023950145969,0.45708260844748866,0.6559056792237443,0.8673190194500586,1.012806352147117,1.0786760273972602,1.140318778538813,1.2113837216483268,1.2944530878059737,1.391645205479452,1.5042384132420092,1.632903039149637,1.7821241653566882,1.9539260844748856,2.150415525114155,2.3745813721086906,2.6338066883748783,2.9316316210045663,3.2736007990867577,3.6654555842503185,4.117500404221873,4.635096803652968,5.228633105022831,5.907427968972229,6.689800484691968,7.586901655251142,8.615930422374431,9.792117321655814,11.147440882551088,12.701415525114156,14.480639840182649,16.510975509643938,18.85138324974424,21.518689497716895,24.478499429223742,27.630865518252364,31.12447620206103,35.448095319634696,39.93541438356164,44.51991646705093,50.683826583826125,57.8301803652968,64.40304851598174,70.27671996095016,75.79353185742445,79.96995262557077,82.2234703196347,83.3676973918956,83.77238560770517,83.67085159817351,83.42367123287673,83.0072020017716,82.5212023666941,82.06534874429222,81.57008961187215,80.91239567894303,80.11879845048281,79.30590296803653,78.47144520547944,77.59685050652493,76.71539324650922,75.8145923227169,74.89629088173517,73.97729800118522,73.05331623114255,72.13459826621005,71.22300387671234,70.32272188729571,69.42857649563278,68.54344107773973,67.66703446347036,66.79936057962861,65.93926522031465,65.08593444246576,64.23846218299086,63.397708110511026,62.56366598454724,61.737566141210046,60.92003254714612,60.11130111812324,59.310240464792145,58.517076344292235,57.7316170283105,56.95367709918096,56.181288350821234,55.41421505239725,54.65305417751142,53.898622692036575,53.15080958714848,52.410681852968025,51.67828836723745,50.953444960676315,50.23521526996782,49.523951758789956,48.81941122796803,48.12075338991815,47.42671673304171,46.73830264383562,46.05609393219179,45.38075739460913,44.71217589998378,44.0508684305936,43.39654157636986,42.749129217644786,42.10797048864092,41.473315350342475,40.844307256735156,40.22055333244629,39.6019526927399,38.98945418447488,38.38351507146119,37.78470235938318,37.19253731619227,36.60718854623287,36.02846032945205,35.45638039355616,34.89026191612053,34.32977657408676,33.77447090799087,33.22486476668163,32.68091976509469,32.143410980365296,31.612709421004567,31.08898811036131,30.57157090740169,30.060636999543373,29.556086829452056,29.057873434083138,28.56492873989664,28.077192739954338,27.59498081997717,27.11877830204918,26.64848340852328,26.1847035619863,25.727440026369862,25.276581494243583,24.83155115830526,24.39255457123288,23.959439553196347,23.5317674434944,23.108798704054696,22.691073909132417,22.27890085068493,21.872646177932477,21.4722114120097,21.077901853652968,20.68954353196347,20.307065570260374,19.930028899182826,19.55855767134703,19.19220030171233,18.8306054043379,18.47396778630137,18.122544840068493,17.77656646347032,17.436343002335505,17.101573398778914,16.772328813013697,16.44846018847032,16.12993971715323,15.816353038009021,15.507530836415526,15.203199305479451,14.90356388131971,14.608548538884834,14.318516164383562,14.033605956392696,13.75386507622951,13.4788935174199,13.208740928310503,12.943305819063928,12.682523614234471,12.425832446856676,12.173170545776257,11.924633879908676,11.680420597904037,11.44043109347818,11.20493152420091,10.973897981621002,10.747246116428377,10.524644527379794,10.30615248173516,10.091658918972604,9.880933813274197,9.673584105570027,9.469819184486301,9.269746552579909,9.073496967171446,8.88096873499295,8.692267160445205,8.507274303984017,8.325916019878733,8.147945079177054,7.973386733047948,7.802011546769406,7.6336834738032415,7.468296394135694,7.306045104098172,7.146994379143835,6.991230680219952,6.838587053352952,6.689068422146118,6.542575978687214,6.399065207843776,6.258324189519986,6.120263394726027,5.984739733093607,5.851812768548668,5.721425337802636,5.593716369988585,5.4687241312557076,5.346449792763618,5.22670116268165,5.109478048641552,4.994715450262557,4.882366767083864,4.772180145941282,4.664113479863013,4.5581846517579905,4.454460265809067,4.352882443887331,4.253547336712328,4.1564301146575335,4.061481092344301,3.968545588163598,3.8776319345205477,3.7886794325342468,3.7015842126288767,3.6161722629424298,3.532512505890411,3.450635810011416,3.370583362248796,3.2923010692721513,3.2158202898630144,3.141082398915526,3.068044788422412,2.996595330195842,2.9267332263242007,2.85836013010274,2.7914128135120517,2.725836730715154,2.6616989312328765,2.5990152983561643,2.5378097804180695,2.478008017312673,2.4196034311529675,2.3625479513812784,2.3068148772972648,2.252313684097268,2.199004121780822,2.1468242182990864,2.0957700672945205,2.045856703915525,1.9970948950799088,1.9494909815981736,1.9030432859604638,1.8576718375284142,1.8133694883105023,1.7701047417009133,1.7278537579025375,1.6865176808614046,1.6460762611529682,1.606529911130137,1.5678974665148964,1.5301516139781233,1.4933221967351598,1.457394494041096,1.4223451196802408,1.3881124348742109,1.3546949201712328,1.3220662957990867,1.2901856932993987,1.2589865880627602,1.2284902485958904,1.1987038082420092,1.1696381041154527,1.1412691951814944,1.1136045860958903,1.0866198858105023,1.0602966101328692,1.034591540791882,1.0095017428447488,0.9849899815924656,0.9610318693993376,0.9376053529599707,0.9147315740707761,0.8924133719166668,0.8706563175707762,0.8494314200239726,0.8287341745091324,0.8085456233082192,0.7888543869518178,0.7696268136651104,0.7508475700239726,0.732493668150685,0.7145680885482696,0.6970584097254534,0.6799785301141553,0.6633286642785388,0.6471045331270867,0.6312768450908376,0.6167701243196347,0.609120124041096,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243,0.60816243};
    CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00026216997716894974,0.0023328254350999324,0.006227071957107568,0.01062417151826484,0.016821602054794518,0.025049676092272374,0.035634821200439155,0.0500618852739726,0.06885242294520548,0.09398218519974051,0.12931304838186491,0.18115166095890414,0.280890747716895,0.45627156364623095,0.6851843066472041,0.9339441952054796,1.1966765753424657,1.468816767722135,1.733124036230257,1.985553310502283,2.239683276255707,2.4947004322928366,2.749936370611572,3.0015461757990867,3.2497287671232873,3.495082724505327,3.73834687975647,3.9711926940639266,4.19913801369863,4.4338976217656,4.678435121765601,4.931189440639268,5.193271004566209,5.464559484242833,5.747307130024701,6.040583675799087,6.345543835616438,6.661215877248796,6.990127877585647,7.331429337899544,7.686330251141553,8.053429756780696,8.436022878458969,8.833227397260275,9.245694349315068,9.672200439154627,10.116867360331364,10.577030936073058,11.044649543378995,11.5046855054021,11.96757619707064,12.44407819634703,12.94475799086758,13.470883093794447,14.010801033011452,14.549154109589042,15.070337328767126,15.54906732352721,15.98180737704918,16.3443453196347,16.621064497716898,16.821767862489708,16.958256194325923,17.03884246575343,17.0712705479452,17.072509107468125,17.053076496494246,17.019300799086757,16.979922374429226,16.940027347356338,16.89930938568256,16.854912671232874,16.809281392694064,16.759411461062456,16.70508961604411,16.650736899315064,16.593435631621002,16.53522896584637,16.47636120583252,16.417386852397257,16.358360212328765,16.299534641168872,16.240561834516992,16.18164232123288,16.122756801826487,16.063907496098135,16.00502887744685,15.946067871575343,15.886961249885843,15.827769175940688,15.768491374020634,15.709216984817353,15.649995691780823,15.590848951109116,15.531697874543687,15.472563122716897,15.413433624885842,15.354298870694537,15.295010267408365,15.235548156849319,15.175959256050227,15.116307442965415,15.056585651816192,14.996882575456619,14.93720481050228,14.877541940921851,14.817821024666886,14.758072867694063,14.698280160502284,14.638371796562241,14.578239669868628,14.517968547374428,14.45761024155251,14.397225759912793,14.336807780903323,14.27640663413242,14.21600039657534,14.155585928899368,14.095104842868414,14.034584735730595,13.973943223972604,13.91314392257654,13.852176297499811,13.791133656621007,13.730065426826487,13.669033356514959,13.607992470647753,13.546966384132423,13.485938143150685,13.42491736354892,13.363833265548507,13.302653021004568,13.241327772488587,13.179916582872968,13.118417272596188,13.056920510616441,12.995475968493151,12.934110977121541,12.872752009220688,12.811426870776257,12.750131227968035,12.688864529974175,12.627499277255033,12.56603087659817,12.50450242340183,12.442980294599769,12.38145665998453,12.3200194533105,12.25867638333333,12.197422470768148,12.136187769534892,12.075008251826484,12.013869101712329,11.952715917291089,11.891446692959176,11.830143360159818,11.76885734589041,11.707651897833543,11.646519919068291,11.585520099086759,11.524635514954335,11.463867525871448,11.403155289396038,11.342528681506849,11.28192205456621,11.22128545810502,11.160657070662099,11.100089266210047,11.039632546689498,10.979353681380843,10.919212384482684,10.859235528538813,10.799408166095887,10.739740000588867,10.68016499829079,10.620661661643837,10.561186773858447,10.501790335703147,10.442468021184844,10.383305252739726,10.324344841324201,10.265614027745963,10.20704370160909,10.148660252739726,10.090456614954338,10.032433618463521,9.974479476069723,9.916590996746574,9.858801554988586,9.801170849585612,9.743689348649818,9.686437567739725,9.629427141643834,9.572655838400452,9.516057229426822,9.459663148573059,9.403461114041097,9.347406212370124,9.291406261382308,9.235530542922374,9.179822858550232,9.124336574487673,9.069060170299206,9.014042866997718,8.959269341803655,8.904737080499665,8.850389065686052,8.796250271015984,8.742265435022832,8.688406854727527,8.6346538702823,8.581085142705481,8.527739302511415,8.474665207942275,8.421825260990875,8.369241198607305,8.316897825171234,8.2647990642414,8.21288557243101,8.161140938504568,8.109527030319637,8.058082350687178,8.006800250677445,7.955753734121006,7.904977955764839,7.854495138262469,7.804246164156811,7.754251492283106,7.704503350525113,7.655001626443846,7.6056522418589205,7.5564528942123275,7.507427730513698,7.458625562974525,7.4100375411243675,7.36173031520548,7.31371359915525,7.265985074113332,7.218487558562486,7.171245767431507,7.12424827770548,7.0774590981682755,7.030801218718,6.984328997534248,6.938077371312784,6.892089883456595,6.846355861836713,6.800915598390412,6.75575609245434,6.7108737925572655,6.666219993764596,6.621814189805936,6.577612623744293,6.533592420095879,6.489734126905801,6.4461005124315065,6.402722196358447,6.359637527720075,6.316815258883992,6.274272510228311,6.231995753013699,6.189986393418233,6.148195736555537,6.106611365856164,6.0652024952054795,6.023983203150684,5.982983424235158,5.942231647831051,5.901753963299086,5.861570811809517,5.821633870683777,5.781957784349313,5.742534561666666,5.703362798456658,5.664368545121641,5.625549859383562,5.586923831084474,5.548527079467587,5.510350982347387,5.472445842602741,5.434817536906394,5.397462932494011,5.360336125925593,5.3234550902168944,5.286809993573059,5.25037315955099,5.214084734665144,5.177985871278539,5.142102199543378,5.106465573025239,5.07106578907556,5.0359324412442925,5.001054441883563,4.96642806593545,4.932014881026306,4.897829226141552,4.863837628458904,4.830022943133718,4.79636917039268,4.762923236929223,4.729707066347032,4.696748181190707,4.664021330211593,4.631538825981735,4.599289468858448,4.567273782360144,4.535454120394522,4.503821341484018,4.472352303504565,4.441067712350411,4.409961085931145,4.379074016095891,4.348424801678083,4.318024246661801,4.287835196435549,4.259719289063927,4.244766012089041,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898,4.2428898};
    CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0005681506849315068,0.005581906392694065,0.018535273972602736,0.03948199965067245,0.06855306410160443,0.10564497716894973,0.15128772831050227,0.20627011596426878,0.272112230830651,0.3497917237442922,0.4406325913242009,0.5466693327843901,0.6712090550689922,0.8156833333333334,0.9832961187214613,1.1779147238441001,1.4054400410459866,1.6647281392694069,1.9534697488584476,2.2688957500561417,2.6142312916385952,2.983170947488585,3.3648144977168957,3.755661641652319,4.167390840132744,4.603881278538812,5.066609931506849,5.544297172318287,6.023262886443597,6.494340867579909,6.9553724315068495,7.392783421600917,7.781105806322828,8.094015068493151,8.336021689497716,8.522142644159992,8.666735070614068,8.779123116438356,8.866643721461186,8.934086023779225,8.986625195872945,9.027316038812787,9.057986015981733,9.080113146567859,9.095315168451231,9.104889208584474,9.110272334954336,9.112794071291765,9.113234464308457,9.11210808655251,9.109804286027398,9.106624533726762,9.102760508847748,9.098389872968037,9.093642422557076,9.088612685021397,9.083352516912443,9.077898229954338,9.072295418538813,9.066585159735011,9.060774641396998,9.054889210787671,9.048952586974888,9.042983449470645,9.036976038371572,9.030934718504566,9.024872371575343,9.018787822198457,9.012651220442617,9.006460440331049,9.000234066712329,8.993980907199079,8.987699986265627,8.98140047293379,8.975083050296803,8.968746376229072,8.96238248677131,8.955994519337898,8.94958044099315,8.943132374318935,8.936638307672295,8.930107147636987,8.92354406065069,8.91695547645208,8.910340452820819,8.903704317260273,8.897044387226027,8.89036024937539,8.883645169543348,8.876901928664385,8.87012107305936,8.863298251754122,8.856431796357388,8.849531991769407,8.842604051769408,8.83565478718991,8.828679006417959,8.821679008401828,8.814652830148402,8.807601194189,8.800515744559627,8.793392296232875,8.786224945068492,8.779020097369001,8.771777126152033,8.764506524885844,8.757213817545663,8.749902163345496,8.742562575509302,8.735198274520549,8.727808333253426,8.720392649740626,8.712935371806365,8.705435684805936,8.69789827737443,8.690331007450842,8.682732736449367,8.675114002214611,8.66747573097032,8.659817184782854,8.652129155547508,8.644416040753425,8.636675913242009,8.628901450276404,8.621079230047066,8.61321945925799,8.605328309326485,8.5974136255651,8.589474446117348,8.581518109143838,8.573542375673517,8.565547155518253,8.557524372693472,8.54947776956621,8.541398335194065,8.533278917819635,8.525124495011413,8.516941804326484,8.508737296027396,8.500520029659407,8.492284328005557,8.484033856449772,8.475766595821916,8.46748366942205,8.459175682027972,8.450839501586758,8.442468768127855,8.434070316907826,8.425643166101255,8.417199385993152,8.408745019497719,8.400283869117636,8.391806060878809,8.383315323207762,8.374810647694064,8.366292065011164,8.357742852550933,8.349162509474887,8.34055559324201,8.331930820769394,8.323286637727719,8.314635275753423,8.305978418299086,8.297315798638808,8.288637293591089,8.279947756815067,8.271245243173517,8.26252273788894,8.253765654992856,8.244984643778539,8.236186345102738,8.227379224503457,8.218561444747484,8.209740972933789,8.200915390650685,8.192084465142662,8.183238870623518,8.174382764840182,8.165507044988583,8.156606988634502,8.147678934756502,8.138735847248858,8.129784216632421,8.120832312022857,8.111873884875616,8.102912772876714,8.093946528047946,8.08497591137423,8.075990735093258,8.06698810785388,8.057961228778536,8.04891681167359,8.03985348190424,8.030784259486303,8.021715509178081,8.012651351849378,8.003581373969858,7.9945095112671245,7.9854344272831055,7.976356223526898,7.96725763922858,7.958138276472602,7.949002402283104,7.939859157327519,7.930706961710144,7.921558596598174,7.912416130034248,7.903279421816753,7.894137676758084,7.884995879417808,7.875852044577626,7.8666991738721705,7.857522236176986,7.848331907123288,7.839135049851598,7.829940561271427,7.820746436254679,7.811561213036529,7.802382496506849,7.79320994968467,7.784033757961299,7.774858231278539,7.76567440239726,7.756477597067893,7.747263706347127,7.73804607780822,7.728831275627854,7.719627856095702,7.710429464602982,7.701240103904109,7.692057224828768,7.682881465173541,7.673702447843649,7.664517527180365,7.655320063744292,7.6461132455365295,7.636903859292237,7.6276985302968034,7.61850354630137,7.6093239161821,7.600149055773012,7.590982660616439,7.581823243504563,7.572670791061207,7.563508183860535,7.554335093219176,7.545155673413241,7.535978803724642,7.5268026574113875,7.5176397571347024,7.508491958242009,7.499358938499264,7.490229864183072,7.481109523767124,7.47199578204338,7.462882174868753,7.453753715963239,7.444620885148402,7.435490445753424,7.426370784674064,7.417259634746395,7.40816521458904,7.39908505436073,7.390018600146406,7.3809562783469636,7.371902133436074,7.362847635627854,7.353788361427877,7.34472023513577,7.335656091792237,7.326602196198629,7.317566499201537,7.308542642358398,7.299534470867581,7.29053929908676,7.28155775315237,7.272579651592559,7.26360268520548,7.254620503367581,7.245639306204494,7.236657393155238,7.22768709094749,7.218734202157535,7.209802543176823,7.200881561372795,7.1925298826141555,7.188075860239724,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999,7.187516599999999};
    CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00030208299180327873,0.0027323010554682237,0.007255870319634704,0.01234157448630137,0.01978005587182174,0.03204669518052749,0.05176139326484019,0.08339991210045662,0.13158013872046312,0.20142883817401505,0.2971478824200913,0.4231224029680365,0.5813258916585572,0.7776257756319086,1.0304688356164384,1.3756340696347034,1.9086264983656462,2.7380600955660355,3.812515410958905,5.01953493150685,6.336519105721487,7.832975378646105,9.48092591324201,11.271417066210043,13.269146065698534,15.52936332559822,18.10859589041096,21.047298515981733,24.244567672854757,27.749573184120568,31.771060502283103,36.40478881278539,41.69099625720488,47.87606009057564,55.074006278538825,63.29848002283106,72.52628977655515,82.94763621902837,94.62808276255709,107.64380878995433,121.93341545649626,137.48081224892084,154.29082762557078,172.70665525114157,192.63604161988175,213.07947919005915,232.84363584474886,251.88636986301367,270.2693303827632,287.3813079821344,304.35223744292244,321.6076084474886,338.18857125034305,355.1070614067919,372.50871004566216,390.02926940639264,408.7554299535893,428.47937121041997,448.0485388127854,465.8375342465754,481.0343257042692,494.07854205654115,504.55504566210044,512.8825342465753,519.4272728435262,524.8814006786935,529.0506392694064,532.3179280821918,534.8922115240663,537.015238416049,538.7651141552511,539.8258789954338,540.0187954749607,539.8555879931132,539.2222716894977,537.3826826484018,534.6894598522844,531.7495340190633,528.4857559474885,524.9084954805936,521.1721175625858,517.2771905411956,513.2665014257992,509.15319707762563,504.9653922742409,500.6879484990424,496.3428944086758,491.9375184018265,487.48037764435344,482.97306456626,478.4174056152968,473.8146334783105,469.17627080773883,464.5085858521845,459.82428208333334,455.13227512671233,450.43856504616116,445.7405019318094,441.04309193036516,436.3486109863013,431.6590469605135,426.9649059280448,422.26711155479455,417.5719427420092,412.8869259507823,408.2136013019968,403.5607527351597,398.93049866210043,394.3232782672979,389.7346109175431,385.16811862100457,380.62348534703193,376.0963032759937,371.57933420045475,367.0801265410959,362.60346089611875,358.15464503473936,353.7337719503487,349.345065413242,344.9873025091324,340.6606867721636,336.36139633473374,332.0916669132419,327.8461673892694,323.6226947814332,319.42101180928904,315.2479796997717,311.10713645205476,307.00281781786316,302.9321411104842,298.89664164041096,294.8953010639269,290.928652070402,286.9922166968336,283.08398206392695,279.2010087853882,275.347169731205,271.522433908604,267.73252538356166,263.980321510274,260.26732715989846,256.58900743022184,252.94688470205483,249.34045905251142,245.76962258512992,242.22693092095219,238.71211147488586,235.22760593949772,231.77712513251993,228.36011331695548,224.98122784817352,221.6406875216895,218.33791108468697,215.06886602890998,211.83527335958902,208.63620491780821,205.46858044189935,202.32708580414575,199.21589610273975,196.13745618607308,193.09471548715598,190.08712519755719,187.1171886803653,184.18379864611873,181.28663760464232,178.42256725076106,175.5927396347032,172.7938793196347,170.02345558333334,167.2831300194064,164.57504026712328,161.90112149315067,159.26401655558053,156.6616074774029,154.09466321004564,151.56220099657534,149.0642029844612,146.59762537035263,144.16131695776252,141.75327980136987,139.37530488004964,137.0269566796417,134.7113077020548,132.42967307762555,130.18266049256434,127.96723914623409,125.78400824086759,123.63237200342463,121.51199677604986,119.4184586911352,117.35141232990871,115.31182416210045,113.3014984926579,111.31979286814446,109.36906757534246,107.4493330022831,105.5601091784939,103.69881078896252,101.86612730479452,100.06129717465753,98.28256733664257,96.52676194366218,94.79580755582195,93.09077574908677,91.41295566705965,89.76165279492288,88.13794931221462,86.5409955691781,84.9703321853825,83.424002703158,81.90239482305937,80.40366279121007,78.92676370029507,77.4709036829079,76.03794380696347,74.62861072568492,73.24383907792499,71.88230675731621,70.54422208767123,69.22886025787672,67.93598022527198,66.6638192656586,65.41170717351598,64.17847770068492,62.96480346365495,61.77029186350805,60.596355865753424,59.443493824429225,58.31187012210182,57.19985043431176,56.107576729452056,55.034581598858445,53.980567575228314,52.943293689840175,51.922482389840184,50.91841754383561,49.931852259064435,48.962358538494016,48.01098419543379,47.07762415673516,46.1619332727824,45.262545153168276,44.379661043949774,43.51281186358447,42.66109770848055,41.822917740440275,40.9990517533105,40.18990751598174,39.396003156803154,38.6169132494626,37.85306607283105,37.103987775799084,36.369363112608234,35.64816918502101,34.940499386758,34.24545272739726,33.56247975695723,32.89110901688405,32.23211723972603,31.58576217317352,30.95238966651695,30.33132548695262,29.722596845205477,29.12579803847032,28.540740435098684,27.96655932295238,27.402911912328765,26.84921932260274,26.30551644109589,25.772038617694065,25.24898064486301,24.73649280616438,24.234639782274126,23.742637726628118,23.2604866173516,22.7879187826484,22.324748300865835,21.86995950379831,21.423393124657533,20.98511664794521,20.555404028723462,20.134016961224955,19.721354842237442,19.317322373173514,18.921725553556907,18.53393217574513,18.153987056849314,17.781651787328766,17.416517916578087,17.057876656865535,16.70602360296804,16.361094710730598,16.02327000446952,15.69232762377486,15.36841163150685,15.051291759018264,14.740804248766127,14.436489831002818,14.138362998059362,13.846029445091325,13.559242894579185,13.277780739942799,13.001939627739725,12.731800337671233,12.467476037145369,12.208660340603712,11.955343149543381,11.707335701027397,11.464540777567558,11.22658341904802,10.993312477739728,10.764477357077626,10.540151461623251,10.320213561465117,10.104875128561645,9.89417558673516,9.688099286507724,9.486310031753812,9.30074077103881,9.202707238013698,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287,9.1904287};
    CH3Br={5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.799999999999998,5.801704452054794,5.8152937785388135,5.841116495433791,5.86904312916386,5.897605404596153,5.926556278538812,5.955556278538814,5.984480173166653,6.013543018439504,6.042556278538814,6.071619406392695,6.1010421036379965,6.130981373980089,6.160557248858447,6.19012037671233,6.220041761796042,6.250545243531202,6.281059189497717,6.311559189497717,6.341979147640791,6.372608371385083,6.403560159817353,6.434623287671233,6.4659784639568825,6.497546726925669,6.529124257990866,6.5610621004566205,6.592978122114929,6.6250474686229,6.657062100456621,6.689125228310502,6.721540052586271,6.754485824163485,6.787063070776255,6.819689326484018,6.852977096589065,6.886486565860718,6.919627168949773,6.953128139269406,6.986976754747112,7.02086105185019,7.053373687214612,7.084560159817353,7.115478805798838,7.146672240936198,7.1787514840182665,7.2121281392694065,7.246039027060409,7.2807405606707105,7.31669611872146,7.353698059360728,7.391598564638072,7.430684108091923,7.47076700913242,7.512206792237443,7.5546577603737814,7.598754652918134,7.644214554794522,7.690716495433791,7.738154341954238,7.787325197744342,7.838288356164384,7.890791267123288,7.944712170322131,8.000772453651722,8.058300970319634,8.117367009132423,8.178207384534772,8.241345965266861,8.306378652968034,8.373382534246574,8.442201915063503,8.513420960276468,8.586958276255709,8.662899999999999,8.740695761908327,8.820934310826658,8.903475742009133,8.988480593607305,9.075751539224491,9.165949144771313,9.258495148401826,9.353436872146117,9.419108887578911,9.290565105297302,9.116756335616438,9.158933219178081,9.224993445430048,9.056463408563515,8.695239668949773,8.371697488584475,8.200270930022207,8.082030716495746,7.9289736872146115,7.75161803652968,7.6069971358260355,7.528630605854107,7.389128416700916,7.231388682077625,7.165396377522394,7.14012454346483,7.127427399634704,7.120078382990869,7.092165481377911,6.9137532065694485,6.700031673390412,6.623859710308218,6.603193961131258,6.5942424997964855,6.583967095502284,6.571072939372146,6.559868649819972,6.5513576719908855,6.545536269452054,6.542410820319636,6.540235211201686,6.537149370305005,6.532918038025115,6.527889003299087,6.521654484813734,6.511810758247091,6.499494869543379,6.488855933276256,6.480919911393317,6.475730067752232,6.473306201107307,6.471901634863014,6.469647548970482,6.466287520333046,6.462180847191781,6.456748794920091,6.446833417108192,6.433259504528376,6.420737822522831,6.410632148869861,6.4030839946340805,6.398126159365347,6.394039344406393,6.388986104680366,6.382767421196633,6.375401212239658,6.366266842111872,6.352553102100458,6.33506992581493,6.318460453555123,6.304138655376712,6.292265107123288,6.282891655837388,6.274337571522506,6.264831896506849,6.254194354897259,6.2427603227142745,6.230100514287652,6.213276604098173,6.192950985353882,6.173663930890473,6.1567916639356115,6.142484312431507,6.130771444349315,6.1200350415863225,6.108546203375377,6.09610271502283,6.083068164531963,6.06913026110712,6.051417655110973,6.030550964680365,6.010919489577624,5.993888530338224,5.9795387900439465,5.967780969098173,5.956964775399544,5.945429224100482,5.932982185686117,5.920017261518265,5.906228586084475,5.888849096366557,5.868435934449124,5.8492688177168946,5.832693360388127,5.818888609770629,5.807848330463327,5.797885477728311,5.787211066118722,5.775587831736594,5.763392530661757,5.750365039840183,5.733831492317353,5.714328756152967,5.696029320342466,5.680360491815068,5.667512342191782,5.657392953691271,5.648339948485977,5.6386559380821915,5.628091968904109,5.617021291028769,5.60517582579578,5.5899747325342455,5.5719211355251135,5.555065293952141,5.54073976688771,5.529035739326485,5.519912690433791,5.511861998433453,5.503209063990849,5.493705579954338,5.483709974737443,5.472983868321357,5.459001076657121,5.442237196175799,5.426634724337899,5.4135372658629635,5.403016190859501,5.3950228307420085,5.388079552397261,5.380554027972965,5.372168007300291,5.363275519315068,5.353656055216895,5.340867970198743,5.325335825570402,5.31092267910959,5.298961288002283,5.289537502569492,5.282592177056541,5.276677144417808,5.270172717191781,5.262807461482771,5.254921687943022,5.246303967237442,5.234568595159817,5.220139666550016,5.206770037056135,5.195807430936074,5.187349384874429,5.18133288209584,5.176322583376625,5.170726814737443,5.164259095559362,5.157255847036268,5.149515687436185,5.13873650739726,5.12533394413242,5.1130112212529015,5.103104754427165,5.095720448926941,5.090793889509133,5.086925910732215,5.082532136024527,5.077315302762558,5.071597907545661,5.065189562320282,5.055808858672367,5.043839632100457,5.032906888127854,5.0243568352483345,5.018289406870087,5.0146414217465765,5.01202904152968,5.008887374648304,5.004905968568319,5.00040197772831,4.995188956952054,4.987042881276355,4.976326777533281,4.966615141164383,4.959243170079908,4.9543225642792,4.951780929746019,4.950247519520548,4.948169086632421,4.945239161138683,4.94176508585685,4.9375719677511425,4.930478282031965,4.920855559637511,4.91220745173722,4.905862215627855,4.9019328633675805,4.900342609144272,4.89972889466686,4.898555914372147,4.896519478995433,4.89393201748141,4.890620605264274,4.884434977591325,4.8757494486757995,4.868030618287672,4.862571938173516,4.859479512716895,4.858671755993152,4.8588007820257255,4.858354220485659,4.857038853230594,4.8551647432990865,4.852565818372695,4.847113676629957,4.839187950525114,4.832226089349315,4.827509014845172,4.825131649386587,4.825007101152968,4.825793626552513,4.82599523902232,4.825327441122963,4.8241016500913245,4.82215178857306,4.817380053606931,4.810163722487929,4.803918228447489,4.799899292134703,4.798185383473,4.798683181936771,4.800065415856164,4.800855323687215,4.80077616672967,4.8001369807666485,4.798775630513698,4.7946127392694065,4.788036622724069,4.782420967829335,4.779010083424658,4.777884275936073,4.778944694494223,4.780873067271285,4.782201569166667,4.78265696347032,4.782551353204332,4.781728814271964,4.778127812237442,4.772130513447489,4.767101857489582,4.7642698745565415,4.763698148573059,4.76528485752283,4.767720695209721,4.769555220207195,4.7705038084360725,4.770809300616438,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413,4.7708413};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0031563926940639275,0.033451942510666965,0.12905907440676698,0.3092744863013699,0.573768607305936,0.88913607368316,1.261343549916411,1.7099832191780824,2.2055859018264843,2.80578207076378,3.5222441244354616,4.303982591324201,5.308832248858448,6.80617667240562,8.957388147815454,11.639563242009132,14.650297374429224,17.714710073733066,21.040939198293284,25.22833847031964,30.565954908675803,36.69394074843426,42.83581758240388,49.55201769406393,58.14675456621004,68.79613372695063,78.42065259999501,85.82900856164383,91.91636244292238,96.35516020098811,100.82284826708586,105.57703767123286,109.43712328767123,112.34752800858348,116.46397572173565,121.37590182648403,124.54371575342468,127.84159620854854,130.47518077700425,129.98157534246573,125.28423515981736,115.6939338960002,103.93801878259352,91.12373002283107,77.93923972602738,65.79206931968463,55.0324387990618,45.94420490867579,38.28740239726027,31.915742810714377,26.581392007884826,22.173147260273968,18.594535958904107,15.677998172268383,13.279710543089555,11.311191252831051,9.68107345150685,8.285289923157048,7.074757810053897,6.078079132831051,5.264270068744293,4.583193760817301,3.8966490011220585,3.2072895376712327,2.625341024018265,2.1491329119355864,1.7590466564323677,1.4400301143150687,1.17914870713242,0.9658555601790865,0.7913215201007873,0.6485658438344749,0.5317859946917808,0.43623665976214543,0.35795956249813793,0.2938413852123288,0.24130146041780828,0.198237962593782,0.16290336580053397,0.13392378758561643,0.11015425636484018,0.09065659356157708,0.07464570135076788,0.06150140934349316,0.050705359948630145,0.041833314477139005,0.034531747038931616,0.028522377938013693,0.02357297900079909,0.019493175236833468,0.016124964576930034,0.013345038541666666,0.011050091617442923,0.009155154529309142,0.00758871075742399,0.006293925063390409,0.0052230212146575335,0.004336834484221811,0.0036023433443088306,0.002993430136084475,0.0024882178281849317,0.002068826871012676,0.001720336533336109,0.0014309000408219178,0.0011904847828264839,0.000990789183035488,0.0008247374431440102,0.0006866875197180365,0.0005718792280856163,0.000476381800270604,0.00039685427062081745,0.00033062784698972597,0.00027545550564954337,0.0002295010619237967,0.0001911984930869638,0.0001592958875182648,0.00013272728537100457,0.00011060291731944132,9.21614491067963e-05,7.679696633573059e-05,6.399543545034245e-05,5.332989556034633e-05,4.4434016711028464e-05,3.70170443857306e-05,3.083492490924658e-05,2.568443935669836e-05,2.1391147011722117e-05,1.7815396816095893e-05,1.4837662219863012e-05,1.2358180076440351e-05,1.029181849853089e-05,8.570767119121004e-06,7.137337922454338e-06,5.943325328609614e-06,4.947778911131321e-06,4.118459812796803e-06,3.427885534851598e-06,2.8531034570479954e-06,2.3744346246484887e-06,1.976061013949771e-06,1.644486226849315e-06,1.368525913351174e-06,1.1386656196727736e-06,9.47317174510274e-07,7.879962822728309e-07,6.553060812808221e-07,5.448338084794521e-07,4.528990475650685e-07,3.7642170818949766e-07,3.128433765377086e-07,2.5995421736707464e-07,2.159828502568493e-07,1.7942715967237444e-07,1.4904313250748557e-07,1.2377052351823677e-07,1.027588474917808e-07,8.528930161404111e-08,7.077303630247584e-08,5.8707286383927506e-08,4.868893064052512e-08,4.037436531894977e-08,3.347651333914589e-08,2.7749832414452804e-08,2.2998710507077627e-08,1.9057658079452056e-08,1.5789470592994738e-08,1.3076848248813847e-08,1.0826672649155252e-08,8.961048090878996e-09,7.415328232681463e-09,6.1342697281571715e-09,5.073674288710046e-09,4.195872602077626e-09,3.469530901923485e-09,2.868095466279911e-09,2.3704611136872145e-09,1.9587890827168946e-09,1.6182495168803806e-09,1.336325937731305e-09,1.1031789442146117e-09,9.104844330011416e-10,7.513256473765251e-10,6.198221228769555e-10,5.112630933378996e-10,4.216565606552512e-10,3.477107756790616e-10,2.8664922914183943e-10,2.3626418912557075e-10,1.9468669067351598e-10,1.6038144244384559e-10,1.3206714979156996e-10,1.0872448252557078e-10,8.949075663207762e-11,7.36520651030822e-11,6.060225762026255e-11,4.985751123344749e-11,4.1011668369292234e-11,3.3731115281525564e-11,2.77348976238912e-11,2.279890965776256e-11,1.8735748271461186e-11,1.539305907434002e-11,1.2642428575956909e-11,1.0381445792762559e-11,8.523841194486301e-12,6.9982465001187085e-12,5.744407770410367e-12,4.714584556369864e-12,3.868877809543379e-12,3.1745392824859643e-12,2.6039551062282917e-12,2.135320889885845e-12,1.7505975607648407e-12,1.4349691096426255e-12,1.175941652932243e-12,9.635790625719177e-13,7.895200373184932e-13,6.468796465010542e-13,5.298966245095503e-13,4.3401999981621005e-13,3.5545046069178084e-13,2.9106284007590384e-13,2.3825110332232953e-13,1.9498270044292236e-13,1.5958799780136985e-13,1.3065086936961349e-13,1.0694775436680078e-13,8.754118461244292e-14,7.165295768595889e-14,5.864684853789768e-14,4.799211297884948e-14,3.9269202550799084e-14,3.212686672214612e-14,2.6278862015512012e-14,2.148857796461749e-14,1.7568863505821917e-14,1.4362938689041096e-14,1.1742114820399793e-14,9.59827660402441e-15,7.845603640616437e-15,6.4127262358105036e-15,5.241475569985528e-15,4.283345194318281e-15,3.4998627751369864e-15,2.8591334570890415e-15,2.3352497852397264e-15,1.9070907636643838e-15,1.557298080844749e-15,1.27162187466895e-15,1.0384063415475833e-15,8.478583083355539e-16,6.922543481666666e-16,5.651908316849315e-16,4.6144685928963e-16,3.7665729571918115e-16,3.073895741518264e-16,2.5082244311872146e-16,2.0465303961248345e-16,1.6695420432698304e-16,1.361996690810502e-16,1.1111431302945204e-16,9.065442743050501e-17,7.395265971228791e-17,6.032647040776254e-17,4.9209718773287677e-17,4.013933835089204e-17,3.273155534887841e-17,2.6687012676484024e-17,2.1757032454794522e-17,1.7738024652022362e-17,1.4460034783961503e-17,1.1788286550776254e-17,9.61055358101598e-18,7.835557375255257e-18,6.3876223236316345e-18,5.207137443984019e-18,4.244496933276256e-18,3.459461632482783e-18,2.8189414963968114e-18,2.2968443020547945e-18,1.871431501152968e-18,1.5249399654715299e-18,1.242530271427346e-18,1.0124623160342465e-18,8.250212265730594e-19,6.72321116641565e-19,5.478185149001359e-19,4.463393652054794e-19,3.636129358938356e-19,2.9620100917518154e-19,2.4124579097922753e-19,1.9648574696689499e-19,1.6004025761643835e-19,1.3037081120546076e-19,1.0619565181064077e-19,8.740057239771689e-20,7.835268550856162e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20,7.724799099999999e-20};
    CH3Cl={480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.0,480.10100456621007,480.9924972240937,483.26711611398053,486.43787100456626,489.9257305936073,493.5599590163933,497.3118755146343,501.0947488584475,504.7945547945206,508.3788570439404,511.8235537839659,515.0246461187214,517.9741609589042,520.6670178967987,523.115757604112,525.2726084474886,527.1721232876712,528.8239629962324,530.2768997804227,531.5271746575344,532.5830993150686,533.4807029904932,534.238486975073,534.8823230593607,535.3946575342466,535.8434651109114,536.2379677870099,536.5442694063927,536.7941723744292,536.9998632632183,537.193983893505,537.3439783105024,537.4501940639269,537.5499316316092,537.6501483394464,537.7438812785389,537.8000970319634,537.8499658158047,537.893761384335,537.9063127853882,537.9500970319635,537.993738584475,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0,538.0009797442923,538.0082283173516,538.0183631289955,538.0240139425293,538.0266394722283,538.0278564394977,538.0284244143835,538.0286835355254,538.0288024066326,538.0288574623288,538.0288874783105,538.0288987431508,538.0289012488586,538.0289087431507,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891,538.02891};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.07190262557077624,0.66851649543379,1.9543688103525714,3.622749356239239,5.516404109589041,7.377441552511416,9.209731327195149,11.046334793023428,12.681099315068494,14.170256278538814,15.521085201611895,16.54972766175113,17.181625570776255,17.68039098173516,18.22460575891409,18.809327307757567,19.386412960502287,19.947213839611877,20.503192395578505,21.052426235544075,21.582885115525112,22.088148370662097,22.561175245838637,23.000300667289526,23.403267187100454,23.773220105821917,24.11348789951842,24.42724563437414,24.71617497054795,24.98261001552511,25.22960641389513,25.45985246498428,25.675341111643835,25.878034591666665,26.069223865878186,26.249907018140707,26.4207261357306,26.582452796461194,26.734908718644732,26.872234589677372,26.983582435159814,27.059198441095887,27.090839488201464,27.071570045905066,26.99569932922374,26.858106233447486,26.654317806338423,26.380431019225806,26.034692417009136,25.62149086506849,25.150490395974003,24.63107950476957,24.073345144634704,23.48587910719178,22.876278233377004,22.250418494311575,21.61393195559361,20.970995825913246,20.325349566985427,19.67908779219596,19.03474808333333,18.39397198721461,17.75862751598486,17.130399730684683,16.511733693493152,15.904312075684933,15.309668372030716,14.728191830648504,14.160804473287671,13.60791077283105,13.069947975673701,12.546557638279436,12.037782718835617,11.543481337671233,11.064104100775383,10.599537916511029,10.150305377328769,9.716489141621006,9.298048381566796,8.894317397071232,8.505252274760274,8.130550867077625,7.769959725817988,7.422586128380679,7.088195435445205,6.766686539566209,6.457997524656784,6.161654074610561,5.877643026609589,5.605629294041097,5.345233350324875,5.095804928890449,4.8571289874999986,4.6287913461415515,4.410285793597824,4.200976720651217,4.000790817785388,3.80951938729452,3.6269494431082667,3.452643604389238,3.2863645170547944,3.127732041187215,2.976433692291714,2.831994365819859,2.6941870896803657,2.5626370341210047,2.4370090002397258,2.3171295362785385,2.202820243789954,2.09390330510274,1.9902206895250396,1.891457037188225,1.7974393170319634,1.707934333892694,1.6227500410998201,1.5415859110371286,1.4642600843150684,1.3905777767237444,1.320426720973314,1.2536185514036418,1.1900762851369866,1.1296953139155252,1.0723346623220302,1.017783318715379,0.9659485974851597,0.9166998410022832,0.8699038880293123,0.8253655362776092,0.7830014087648401,0.7427304001392695,0.7044730193956821,0.6681279716653316,0.6336551574554794,0.6009600789737444,0.5699332040776258,0.5404614480530823,0.5125052089726027,0.4859753039337898,0.46077838067182547,0.43682783612346854,0.4141044144611872,0.3925571978664384,0.37212340090444646,0.352738175244311,0.33436710413242016,0.3169570066038813,0.3004479747999164,0.28478556164214824,0.2699433628310502,0.25586137785388136,0.24249129858891635,0.22980357331770404,0.21777725990182648,0.2063810173755708,0.19558751308660827,0.18535933105624489,0.17568631269748858,0.1665196078047945,0.1578177979705255,0.14956733085966387,0.1417488303299087,0.13432333677054795,0.12727940535610824,0.12060347805155702,0.1142895446803653,0.10830921354680366,0.10263545093559585,0.0972538910120359,0.09216268203401827,0.08735428886632418,0.082804454917986,0.07848407847602458,0.07438953028299088,0.07050378978812784,0.06681288740498477,0.06331809046046424,0.06002241818173517,0.056891772266552516,0.053912889389391046,0.05110393547221629,0.048452614086529684,0.04592785646164383,0.043533975302649276,0.04127596563560084,0.03914284434703196,0.03710559072591324,0.03515937802437869,0.033330853730762035,0.031612752275456624,0.029978572759474884,0.028434932594072034,0.026974327526127204,0.025589118009360725,0.024270763200000003,0.023015156223475438,0.021830641211658494,0.020696571539155252,0.01960859129714612,0.01858098431670472,0.017609998609684173,0.016690299670662097,0.015816483703196344,0.014986978633471192,0.014214570054778927,0.013493390195662097,0.01279976142625571,0.012131135572716894,0.011503530229223744,0.010916184653424657,0.010365317432305936,0.009844450334392234,0.009334879063368483,0.008850716493276255,0.008392337624509133,0.007957116369416248,0.007542006059800353,0.007148009265616436,0.006788214774223745,0.006444378543219117,0.006114775275390873,0.005813405296004566,0.005522358102671233,0.005240540485184021,0.004981776050242128,0.0047287597453424665,0.004480844176803654,0.004255451363488536,0.004049967462760187,0.0038444856624885843,0.003639143314908676,0.003452168632994111,0.003284641399925768,0.003131659080844748,0.002973597889714612,0.0028109671554901188,0.0026621698857977774,0.0025288651085045664,0.0024093395564041098,0.0022991026713195845,0.002179069647868634,0.0020504076968036527,0.0019321640510730597,0.0018263598940780872,0.0017316268114602826,0.001646844278847032,0.0015709499673744293,0.0015030141491662926,0.0014421371981043678,0.0013845503218949775,0.001311801531872146,0.0012255167807839285,0.0011451615430927652,0.0010732348656050227,0.00100888580013242,0.0009513369682190095,0.0008998172784035293,0.0008561439830034245,0.000834069679366438,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996,0.0008313377099999996};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.002241803278688524,0.020173048132345234,0.05281541095890411,0.08587465753424657,0.11729164701699228,0.14729199041844449,0.17536495433789956,0.20186204337899546,0.2267960909623974,0.2504086040621803,0.27525313926940637,0.3140876712328767,0.3603444600394241,0.40513695947800493,0.45465302511415523,0.5076657534246575,0.616829281445717,0.7932291663547671,0.9979615296803653,1.2732386986301372,1.730691433365771,2.455696920303416,3.411786586757991,4.499031221461188,5.655829415250643,6.814796764977419,7.926782305936073,8.946060388127853,9.95102169448811,11.028125339970556,12.029986872146118,12.956623287671235,13.731425970631534,14.350251341168251,14.920312785388129,15.344992579908675,15.622331349651922,15.936557668553034,16.73441843356164,17.964158319977173,19.132138882243556,20.161969588159042,21.042778005365296,21.773346948858446,22.351055754977295,22.779752886706845,23.0661492576484,23.22657787853881,23.277023988365524,23.23169475324126,23.10306629109589,22.902573172031964,22.641044455037804,22.327679843291037,21.971109869863014,21.578817721803656,21.157407771809268,20.71206747195617,20.248064815296807,19.769828602739725,19.28130952613719,18.78511367445012,18.28405450022831,17.78029782979452,17.275795154506326,16.77163438910753,16.26948859394977,15.770351625570777,15.275058977885694,14.783766999627593,14.297360450684934,13.816597518378996,13.342448000759164,12.875432159062555,12.416972939155253,11.967998423515985,11.529366733372008,11.101301407544852,10.68448386917808,10.279115712808219,9.885395192560635,9.502949041493094,9.131886302762558,8.771962315662101,8.423105427247547,8.085044833927501,7.758020141027398,7.441993200285388,7.136927737970843,6.842385679397037,6.558333509292237,6.284516198904108,6.020742812511727,5.766487776824175,5.521559397123287,5.285635822819635,5.058575931655376,4.84001130150136,4.6299053080936075,4.428068453732876,4.234278074628965,4.048084797604113,3.8693738233447497,3.6978842872831046,3.533393274291363,3.375476597721075,3.223963804018266,3.0786656219863016,2.9394380933274693,2.805985582826496,2.678209058082192,2.555907031221461,2.4389278377583152,2.326958828594175,2.2198393986415526,2.117378506917808,2.0194039794349004,1.9256203110059384,1.8359208791552515,1.7501863819634706,1.668315848231342,1.590080600577794,1.5153791210730596,1.4440540356506852,1.3759722695811192,1.3109368455540584,1.2488385195776257,1.1895122419634705,1.132824984406393,1.078691665194064,1.0270318353538812,0.9777456604474885,0.9307504854235034,0.885918460865275,0.8431713962682649,0.8024064068447488,0.7635543709214637,0.7264895763528583,0.6911354033824201,0.6573998136929223,0.6252234500690858,0.594535958250181,0.5652983555388128,0.5374522017876712,0.5109591962093719,0.48572826214551057,0.4616906568299087,0.4387874975502282,0.41698815696467423,0.3962159885800179,0.37642958338926946,0.35758627128538817,0.33965392668740174,0.32259645562475675,0.3063691888652968,0.2909328562077626,0.27626807230335976,0.2623050209592472,0.24901784072031966,0.2363940603333333,0.2243988136347406,0.212966281011481,0.20207925902853882,0.1917362600627854,0.1819191418483419,0.17259628182649336,0.16374641590525116,0.1553234450753425,0.14730683790698526,0.13969078640257815,0.13246336794063926,0.12560249827625572,0.11908937043309753,0.11290268350249831,0.1070322594109589,0.10146401760273971,0.09618534816050663,0.0911775730084266,0.08642972381073061,0.08192449960102742,0.07762861562980637,0.07352747027835979,0.06963404427922376,0.06594042406187214,0.0624380600985796,0.05911545365844468,0.05596664258972603,0.052983616572374416,0.050158672520601584,0.04748097802218293,0.04494440615285388,0.04254153364691781,0.04026571564978666,0.03810762791538008,0.036062034502968035,0.03412360152682649,0.0322878009843127,0.030548311240983294,0.028901742018378997,0.027343373112671234,0.02586870345816865,0.024471922350339657,0.02314977289954338,0.02189822656438356,0.02071334929677995,0.019590318623759886,0.01852688226883562,0.01752026478150685,0.01656796368161913,0.015666564757217043,0.014814031358675797,0.014007667855251142,0.013245070018952268,0.012523211030940437,0.011840333305936071,0.011194109349885843,0.010582534281866158,0.010003385219395911,0.009455507677751144,0.008937397527031965,0.008447698020131435,0.007984506347807063,0.0075466450930022815,0.007132695150993151,0.00674141612468548,0.006371220570733839,0.0060210791945205485,0.005689817798778539,0.005376454700365296,0.005080129083961187,0.004800009341689498,0.004535293149452055,0.004285243703851211,0.004048822314405146,0.0038254122362328773,0.0036142893709474877,0.0034148052120476827,0.0032260845610206598,0.0030476152307876716,0.0028788800637785388,0.002719436962541795,0.0025686923470708578,0.002426310148116438,0.0022918423388356163,0.0021648632656908573,0.002044838480937882,0.0019314564111301373,0.0018243421184817353,0.0017231325682661501,0.001627391634913822,0.0015369039261643837,0.001451411447420091,0.001370681026019288,0.0012944035857677721,0.00122238867956621,0.0011543918911187214,0.0010901950334635201,0.0010295291881507723,0.0009722335530776256,0.0009181011184657534,0.0008669530453527834,0.0008185930304461381,0.0007729148600445205,0.000729783805630137,0.0006890780497870724,0.0006506313371873082,0.0006143385303447489,0.0005800752136803653,0.0005477324088351735,0.0005171732004207432,0.0004883074898664384,0.0004610337219931508,0.00043527483123144206,0.0004109335393787678,0.0003879541716175798,0.0003662668792671233,0.00034580500270783117,0.00032648031008488033,0.0003092832457488584,0.000300357392359589,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994,0.00029924471999999994};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0006748367579908675,0.006676638698630136,0.02239337356214288,0.04824538570751303,0.08366848515981734,0.12830214783105023,0.1816158250056142,0.24366456752002394,0.3137207363013699,0.39154168378995435,0.476575948611423,0.5691519172467999,0.6684195833333334,0.7747120662100456,0.8808015555056516,0.9295352496444346,0.9251894406392694,0.9356176940639269,0.9764518202460265,1.0629992040322378,1.1943614155251139,1.3649115867579908,1.602303016692866,1.9107527153978594,2.257295034246575,2.6594571917808216,3.158102263143449,3.7837714711680017,4.5368888127853895,5.438664269406394,6.525967219040847,7.848870985228435,9.439167751141552,11.226874315068494,13.12926566047858,15.175156267934225,17.43223344748858,19.947514269406394,22.548182573545926,25.2693847406243,28.27055194063927,31.540985159817353,35.00504223120493,38.663728884397536,42.43853652968036,46.18986415525114,50.03972666367243,54.1919677183921,58.48469805936073,62.88123573059361,67.46916951119097,72.54151455947301,78.2622305936073,84.32187842465754,90.45324184694464,96.61699094867379,102.02869121004566,106.53163926940637,110.64041198817274,115.9463893255483,121.74720319634702,126.4784817351598,131.73993291039747,137.2632612845273,142.07877283105023,147.4606735159817,152.82169511190952,157.49455198742416,162.34138127853882,167.80526826484018,173.945579010405,180.5237492345236,187.23097378538816,194.02760381735163,201.0494296469047,208.34551092540605,215.83761222945205,223.5079793538813,231.31381395337107,239.27930867382167,247.3164696484018,255.3386175719178,263.2701654118385,271.0591498791077,278.64853220319634,286.0038035273973,293.10730488048006,299.95369279255243,306.532018479452,312.8411779988584,318.8788265389625,324.6488605390748,330.14897507990867,335.3838409417808,340.33315520911617,344.81072900151275,348.490161880137,351.0968440582192,352.4214199506014,352.30805291440856,350.64604742579905,347.3568300399543,342.3903919450558,335.7136191481398,327.3506508641553,317.50913343949776,306.5462244645807,294.77641917660065,282.4862294828767,269.9046428378995,257.22067198129224,244.5727960388939,232.08620047602741,219.84968947031962,207.93406373537195,196.37716440904697,185.22045912671237,174.48561199315068,164.19019505923598,154.33935830001,144.9476100136986,136.01658263356168,127.5449236499925,119.51694323423347,111.92578542351599,104.75746962123287,97.99814310075355,91.62539412688949,85.6245652880137,79.97765721289954,74.67082006156896,69.68475675603337,65.00791167226028,60.62530408538813,56.522119068405196,52.67910216602758,49.08385339863014,45.72204471027397,42.58041787879145,39.642182257034584,36.89638288310503,34.3321230423516,31.93952209199915,29.70655117852134,27.625177013926944,25.685911618949774,23.87978410422374,22.19651836586758,20.62914989828767,19.16996323002283,17.811531994952215,16.54571439373487,15.367488062328768,14.271370437785388,13.252318821913441,12.304490087806286,11.423613335730593,10.60493497372146,9.844192239807994,9.136699275394584,8.47919703737443,7.867980802260274,7.299606873664384,6.771248463127854,6.280288139737443,5.824284571244292,5.401049070081719,5.007954101986613,4.643088970057078,4.3044149828424665,3.990119089012838,3.6981962469739504,3.4271538545319635,3.1754618659589045,2.941871605843002,2.7249733564410072,2.5237731619977164,2.3372218818264843,2.1643350250482203,2.0039669991283344,1.855299281518265,1.7174832955593609,1.5897726136929535,1.4712858946675773,1.361383737591324,1.2594995907648403,1.1651294625627544,1.077656836306167,0.9966586841152968,0.9216885205833333,0.8522888037518525,0.7879871054624318,0.7284728900559361,0.6733950723481734,0.6224181654783479,0.5751871928082847,0.5314699943938355,0.491019055477169,0.45358751359682614,0.4189312149907927,0.38689380863584466,0.357281150563927,0.32991452370110036,0.30460278398035034,0.28120719920433795,0.25957674950684934,0.23957826067967292,0.221078737039028,0.2039843874440639,0.18819503394292236,0.17361940514044216,0.16015506304200663,0.1477251403196347,0.13625001259018263,0.12565868819329043,0.1158747820717057,0.10684002014200912,0.09849553845673516,0.09079258639383936,0.08367885382032618,0.07711621356392695,0.07106436573595891,0.06548564479937495,0.06033853775507055,0.055592586476940646,0.051216681013470315,0.04718274355924907,0.04345975217129432,0.04002524793184931,0.036857887805136984,0.03393869578609677,0.031246978218591705,0.028767538834703194,0.02648404910810502,0.024381349337437935,0.022443366685950174,0.020658365975342464,0.019014264178652967,0.017499759614124682,0.016103122648776422,0.014816389241324201,0.013631414476598172,0.01254077728098473,0.011536463678509806,0.010612383893858447,0.009762094353276256,0.008979800753630198,0.008259439287959584,0.007596516418641553,0.006986263889657534,0.006424470150568469,0.005906985869439452,0.005430815742636986,0.004992829382705479,0.004590179737067707,0.0042197505078679165,0.003879161969360731,0.0035659890949086754,0.0032780725509430598,0.003013136848596701,0.0027694247439155255,0.002545183107317352,0.0023388853487785392,0.0021491687162785386,0.0019747624390867584,0.0018144835470205484,0.001667252247180428,0.001531879971852278,0.0014074806126255703,0.0012931621327511415,0.00118812172036617,0.0010914906954010717,0.0010026304504269408,0.0009209379876187216,0.0008458776702071013,0.0007768759329611716,0.0007135050028367578,0.000655312900956621,0.0006018818106725865,0.0005527751594626998,0.0005076700911700913,0.00046623841865296804,0.00042817494412477236,0.0003931665923616165,0.0003609969487374429,0.00033144709326484025,0.00030431794196717567,0.0002793974848871921,0.00025652312942123283,0.00023552509539155248,0.0002162509977096028,0.00019854316457028654,0.0001822836707579909,0.00016734894659018265,0.00015362993647995108,0.0001410198752993893,0.00012944078214269404,0.00011881198307191783,0.00010906023212381166,0.00010010635385445581,9.188950965627854e-05,8.434822609189497e-05,7.74278366123394e-05,7.107127323697632e-05,6.52342731022831e-05,5.9872951150684925e-05,5.4950611707072644e-05,5.0429028945596294e-05,4.627957991655251e-05,4.2472777488698635e-05,3.898129146447152e-05,3.577589472883542e-05,3.2995820769178085e-05,3.157290872945206e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05,3.1396202e-05};
    Halon1202={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.227231329690345e-05,0.0005007416972328268,0.0009378424657534249,0.0010631278538812785,0.001499658158045762,0.002000741697232827,0.0025640981735159814,0.0035019406392694068,0.004499316316091523,0.0055014833944656534,0.006501940639269407,0.007501940639269406,0.008499316316091524,0.009564611248346932,0.011002910958904108,0.012502910958904113,0.014061246787434192,0.016002966788931306,0.017940753424657535,0.01950291095890411,0.021061246787434193,0.022939838935050028,0.024502910958904108,0.026066038812785384,0.027936360318886144,0.02950222509169848,0.031129166666666666,0.033631107305936075,0.03712215173291414,0.04156980312897672,0.04650970319634703,0.05113093607305935,0.052938181812510914,0.05068065224442947,0.04586404109589041,0.040051484018264846,0.03456603257479352,0.029618838735434288,0.02568162100456621,0.02286889269406393,0.01937784826708586,0.015143809660520995,0.011821011660456624,0.009460986358173516,0.007293776230266737,0.005236540737583528,0.003708575863824202,0.0026269417725456614,0.00186272457752726,0.0013193775154078649,0.0009345287029178082,0.0006619663742054794,0.0004689448564531589,0.00033215608668657834,0.00023526958235616438,0.0001666514365582192,0.0001180578590933453,8.362099694748671e-05,5.922961379315069e-05,4.1954850818150686e-05,2.9721315527636796e-05,2.1051762512862112e-05,1.491118045753425e-05,1.0562222551780822e-05,7.482404143693578e-06,5.299825807294241e-06,3.753921240456621e-06,2.659061853881279e-06,1.8837110886027519e-06,1.3342423664846109e-06,9.450576202123288e-07,6.694244540799086e-07,4.742282486272302e-07,3.3589833497836046e-07,2.379202542796804e-07,1.685290196472603e-07,1.1938796447698184e-07,8.45631169167958e-08,5.989692777819635e-08,4.242753798721462e-08,3.005617257682087e-08,2.1288943436205932e-08,1.507917825456621e-08,1.068122203303653e-08,7.566704957708725e-09,5.359536598470289e-09,3.796214974942924e-09,2.6890202825684933e-09,1.9049339962830304e-09,1.3492746559085446e-09,9.557051530719177e-10,6.769665538013698e-10,4.7957116511103e-10,3.396827507716427e-10,2.4060079672716894e-10,1.704277618070776e-10,1.207330578603844e-10,8.551585241506195e-11,6.057175947454338e-11,4.290554968527397e-11,3.039480191643462e-11,2.152879668526742e-11,1.524906876461187e-11,1.0801562605228308e-11,7.65195564760486e-12,5.419920104164669e-12,3.838985282317352e-12,2.719316303595891e-12,1.9263960391858176e-12,1.3644763131322578e-12,9.664726556803653e-13,6.845936349132419e-13,4.849742786897099e-13,3.4350980923496016e-13,2.4331153731164377e-13,1.7234789560730592e-13,1.2209330256153466e-13,8.647932098100186e-14,6.125419403173517e-14,4.338894743025113e-14,3.073724631541158e-14,2.177135189631958e-14,1.5420873243835615e-14,1.0923259447990868e-14,7.738166830353257e-15,5.48098388946238e-15,3.8822373768949774e-15,2.749953580605023e-15,1.9480998558148064e-15,1.3798492525309339e-15,9.773614647351598e-16,6.923066427054795e-16,4.903901982602739e-16,3.4736420115182643e-16,2.4605281612100454e-16,1.7428965738013693e-16,1.234688697697526e-16,8.745364378413896e-17,6.194431735114155e-17,4.3877790742351596e-17,3.1083549039945604e-17,2.2016639580749558e-17,1.559461282431507e-17,1.1046326292054797e-17,7.825349171463496e-18,5.542735619721505e-18,3.925976822716894e-18,2.780936139771689e-18,1.9700482099247076e-18,1.3953954073037401e-18,9.88372956902968e-19,7.001065437408676e-19,4.959638069856963e-19,3.512937473890667e-19,2.4882498327397256e-19,1.762533071894977e-19,1.248599423162443e-19,8.843894549991733e-20,6.26422162107306e-20,4.4372142014611874e-20,3.143375323374441e-20,2.2264690998350674e-20,1.5770310137671235e-20,1.1170780740981736e-20,7.913514002233201e-21,5.605183160118148e-21,3.970209021689498e-21,2.8122676948515984e-21,1.9922438899733015e-21,1.4111167244783917e-21,9.99508520091324e-22,7.079943320684932e-22,5.015516135141602e-22,3.552516186748946e-22,2.51628381380137e-22,1.782390726244292e-22,1.2626668276032075e-22,8.943534691409442e-23,6.334797776164384e-23,4.487206326609589e-23,3.1787903414371713e-23,2.2515537660510082e-23,1.5947987191095892e-23,1.1296636638698631e-23,8.002671925649377e-24,5.668334238362434e-24,4.0149395379337906e-24,2.8439521845890408e-24,2.0146895721697602e-24,1.4270151234255056e-24,1.0107695259703195e-24,7.159709879828766e-25,5.07202368268926e-25,3.5925407582992426e-25,2.5446336428995434e-25,1.8024720626255707e-25,1.276892655522681e-25,9.044297406675462e-26,6.406169128230594e-26,4.5377616642351595e-26,3.21460432250761e-26,2.276921020350076e-26,1.6127666365639268e-26,1.1423910889292238e-26,8.09283444723289e-27,5.7321968074149754e-27,4.060174060627854e-27,2.8759937476484016e-27,2.0373881952458394e-27,1.443092648675082e-27,1.0221574337214612e-27,7.240375093424657e-28,5.129167890191505e-28,3.6330163403180123e-28,2.573302908732877e-28,1.8227797192237446e-28,1.291278886432461e-28,9.146195514836907e-29,6.478344530011414e-29,4.588886591187215e-29,3.2508218184561595e-29,2.3025740139620914e-29,1.6309369168835616e-29,1.1552618759817348e-29,8.18401275861217e-30,5.796778882588423e-30,4.105918254052511e-30,2.9083962728881277e-30,2.0603425227281855e-30,1.4593513732988687e-30,1.033673593936073e-30,7.321949088618723e-31,5.1864475278767125e-31,3.67378102772831e-31,2.6022951498059356e-31,1.8433161968378996e-31,1.3058271161267685e-31,9.249241468217307e-32,6.551333084292239e-32,4.640587447077625e-32,3.28744739349365e-32,2.3285160854460777e-32,1.6493119857648402e-32,1.1682777405730594e-32,8.27621839021702e-33,5.862088554218254e-33,4.15217775757991e-33,2.9411638864041096e-33,2.0835554684396285e-33,1.4757932131940078e-33,1.0453195718082189e-33,7.404442294977169e-34,5.245394984923585e-34,3.715340605673922e-34,2.6316140299200914e-34,1.8640839963356166e-34,1.3205393064528907e-34,9.353448585408464e-35,6.625144056461187e-35,4.6928708713698617e-35,3.3244855746733783e-35,2.354750448383892e-35,1.6678939940410957e-35,1.1814401394611873e-35,8.369462732808032e-36,5.9281340752650845e-36,4.198958497945205e-36,2.9743006146803647e-36,2.1070299708838605e-36,1.4924203315324872e-36,1.0570966692945204e-36,7.487864689132419e-37,5.304492465470093e-37,3.7571996551891047e-37,2.6612632750114157e-37,1.8850858185159815e-37,1.335417230787016e-37,9.45882970770258e-38,6.699786524474886e-38,4.745743365970319e-38,3.361941088842789e-38,2.381280404050796e-38,1.711774434006849e-38,1.4132573307534242e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38,1.3776113999999995e-38};
    Halon1211={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.312785388127853e-05,0.0005640981735159817,0.0015650684931506848,0.0031235191007310923,0.00569309204780797,0.009823401826484017,0.016328253424657536,0.025429753037902042,0.03814982096963345,0.05572836757990867,0.07886529680365297,0.1084139160241535,0.14581744267285476,0.1927275114155251,0.24874497716894975,0.31395009606507474,0.3912555455747686,0.4812528538812786,0.5838402397260274,0.6992892039074782,0.8305924414252565,0.9809465182648403,1.155873801369863,1.358596071312723,1.5965904346632733,1.8717489726027396,2.1636215182648404,2.4458149412381167,2.7055687850887047,2.9145439497716894,3.088502111872146,3.2453358537939465,3.394239464655538,3.5548041666666665,3.7055764269406395,3.8342299981909824,3.9500179061556504,4.042396860730594,4.110992751141553,4.1669697956433875,4.204783024552737,4.22590656392694,4.239386815068493,4.240194898882152,4.222665984189061,4.183640206244292,4.125439763025114,4.055736987743282,3.9766549230975374,3.890247609063927,3.797795465319634,3.7008000409270907,3.59968171268976,3.4956495325342463,3.3894979449429226,3.2819763506377106,3.1736051098802616,3.0649188089269406,2.956366147705479,2.848477599750917,2.74160278494367,2.636200542773972,2.5325841652853884,2.431008370082965,2.3315534879876547,2.2344344536872147,2.139767352865297,2.047654649052387,1.958038871529462,1.8710167332648402,1.7866661965525115,1.7050624497675724,1.6261890352039823,1.550133332591324,1.4768727221461184,1.4063772865772763,1.3385426517242742,1.2733563937100456,1.210756902191781,1.1506808457527382,1.0930073277756256,1.0377403453995433,0.9848418511118723,0.9342687295209037,0.885921976265177,0.8397681152614155,0.7957310081986301,0.7537374934506825,0.7136765199838996,0.6755028179200914,0.6391314375456622,0.6044963146124647,0.5715107969419617,0.5401424324486301,0.5103362446232876,0.4820423930919356,0.45516539537264517,0.4296616196815068,0.4054737632762557,0.3825438478122738,0.3608009701069816,0.340193080334475,0.3206597703744293,0.30216132140548196,0.2846413720121049,0.26807021087557076,0.2523969347488585,0.2375850080262245,0.223592097504797,0.21037711660045663,0.19789138812671236,0.18610390936122959,0.17496900512644412,0.16445068909474886,0.15451712254908678,0.14516176654111462,0.1363465342702953,0.1280444025262557,0.12022195384817351,0.11284987874210269,0.10590414025592858,0.09936499805605022,0.09321772969805937,0.08743682342744342,0.0819915423951721,0.0768650908780822,0.07204051731883561,0.06751304020795469,0.06326261801974263,0.05927368680468036,0.05552802088173516,0.052009401415103435,0.04869935579920496,0.04558562531061644,0.04265566845148402,0.03990861433504566,0.03733510669737442,0.034924386093264835,0.032666190883447487,0.030551438511875268,0.028568618896438105,0.02670960191678082,0.024965586071004565,0.023330940686883992,0.02180718532459266,0.020376312612328768,0.01903146539121005,0.017777972569810615,0.01659832094471424,0.015488517163356167,0.01445673486027397,0.013499834198842228,0.01260944695687801,0.01176858248892694,0.010973691094178083,0.010234323158706678,0.009547733567825156,0.008910408728630135,0.008319048002465754,0.0077686015114606264,0.007243155562439087,0.006741434475605022,0.006274507417134704,0.005842007350793473,0.005441027152256156,0.005069516002363015,0.0047253045571004565,0.004406323054244829,0.004110386880362241,0.003836112382431507,0.0035820419423173515,0.003346838422710283,0.003129005479183634,0.002927425653310502,0.002738754616221461,0.002549353873322916,0.0023591085180097375,0.0021809237130136984,0.0020159777178538813,0.0018632812436469174,0.0017218522430744565,0.001591004956666667,0.001469999489098174,0.0013581601170232303,0.0012547197851102878,0.0011591038712442923,0.0010707158149497718,0.0009890249670869078,0.0009134571853472942,0.0008435747521506851,0.0007789354491929225,0.0007191780944150386,0.0006639120461526873,0.0006128544230650685,0.0005657035017534246,0.0005221756360551752,0.0004819551876527777,0.00044481230776369864,0.00041051165558333335,0.00037884088838435395,0.00034956281153648914,0.0003225075211586757,0.0002975148384429224,0.00027444246982276,0.0002531333256707089,0.00023347285765068493,0.00021533641846461184,0.00019860776555261748,0.00018316298331439793,0.00016891249055479452,0.00015576351849771694,0.00014362881155934826,0.00013241755893833435,0.00012206951250913244,0.00011252258664611876,0.00010372000529532836,9.559973935115684e-05,8.811479183584475e-05,8.121490852716896e-05,7.485492945367231e-05,6.89873528479505e-05,6.357727284280822e-05,5.8587208151369865e-05,5.398418393253861e-05,4.973583125562978e-05,4.5819077937100454e-05,4.2209511875570774e-05,3.888486507560009e-05,3.582040232325336e-05,3.299730526335617e-05,3.039629800353881e-05,2.8000253387499693e-05,2.579097847946578e-05,2.375445733493151e-05,2.1876679516894977e-05,2.0145572011187217e-05,1.8550355522260273e-05,1.7080925283904105e-05,1.572782702465753e-05,1.4482384553987947e-05,1.3334916854724344e-05,1.2278272577054794e-05,1.1305219202283104e-05,1.0409249310229682e-05,9.583225581172495e-06,8.821963838447489e-06,8.12059829336758e-06,7.474810675337975e-06,6.879910323530952e-06,6.332426854235161e-06,5.828640351883562e-06,5.365094976289206e-06,4.938154189056908e-06,4.545157139885845e-06,4.183380139326484e-06,3.850275006852684e-06,3.543216628596078e-06,3.260432312557078e-06,3.0001135058904112e-06,2.7606089557143747e-06,2.5401371423517545e-06,2.3373365943264842e-06,2.1507690938584474e-06,1.979144179720413e-06,1.8211182547675723e-06,1.6756952876598175e-06,1.5418181839611872e-06,1.4185574300406716e-06,1.305005020185331e-06,1.2005064909931506e-06,1.1043755677739725e-06,1.0159871233467137e-06,9.346550647702768e-07,8.598542723333334e-07,7.91051091219178e-07,7.277717174698579e-07,6.695172678587812e-07,6.159018126609589e-07,5.665417170878996e-07,5.21120211205941e-07,4.793038057114243e-07,4.4084479625e-07,4.054849590593607e-07,3.7298335434211013e-07,3.4307901967146675e-07,3.1709001729223743e-07,3.0377335375684926e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07,3.021190999999999e-07};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.312785388127853e-05,0.000499658158045762,0.0010007416972328267,0.001564098173515982,0.0025019406392694063,0.0036861332559822344,0.006382475609451804,0.011952568493150685,0.021022488584474888,0.03405156292886194,0.05203600506524939,0.07781204337899544,0.11314206621004565,0.15721536417396512,0.21146891608653343,0.2765149543378996,0.3531044520547945,0.4443678846345785,0.5515525588242632,0.6741356164383562,0.8153618721461187,0.9763804775806572,1.1582312223968858,1.3574582191780822,1.560568093607306,1.7489462606357762,1.9063606881752626,2.019628310502283,2.1191034817351597,2.2468423587718642,2.383156874267036,2.4839044520547944,2.5560026255707764,2.6197712487835916,2.6785186278913096,2.732536643835616,2.7820910388127853,2.8275329861890857,2.8695572797365076,2.9076318493150684,2.942125057077625,2.9729806272924617,2.9997308535683813,3.0203552083789957,3.035122594212328,3.046032952608915,3.053576788061981,3.0579268481506854,3.059322695490868,3.0579996196702592,3.054129029571356,3.0478494922831056,3.0392968932876716,3.028617810102053,3.0159289985690045,3.0012874351027405,2.984755152260275,2.9665041143335955,2.946687528026143,2.9254689752853884,2.902990667305936,2.879352274075654,2.8546071397065957,2.828851269143836,2.802155876586758,2.774584755118397,2.746109888797378,2.7167766608904107,2.6866849567123285,2.655956849604823,2.6246724694711125,2.592945224908676,2.5608314681506847,2.5283687596186093,2.495557923442155,2.46244866359589,2.4290755730707767,2.3954435305791977,2.361514962038139,2.327378822876712,2.2931162050228306,2.2587986564490854,2.2244563685176346,2.1901577992009127,2.155909799223744,2.1217198440006735,2.0875891660651056,2.0535562436529675,2.0195899603995433,1.9856857155070238,1.9518545424112645,1.9181868184931508,1.8847227547831051,1.8515176916972946,1.8185649457699242,1.785878998515982,1.7534664443493149,1.7213469720582255,1.6894845520864834,1.6578624395547947,1.6264828225228307,1.5953839287619458,1.5645699573396838,1.5341023410273973,1.5040066813584476,1.4742953569868629,1.4449432794273525,1.4159616642351598,1.3873462621118724,1.3591076546283405,1.331187068601879,1.303593397739726,1.2763453588470322,1.2494589483139955,1.2229433573634192,1.1968494253538813,1.1711776783675798,1.145919119070851,1.1210389420868887,1.0965467250799084,1.0724341623630138,1.0486881934218504,1.0252678191474849,1.0022020238150684,0.9795068042283104,0.9572035160243781,0.9352996008423191,0.9138114814988585,0.8927240264554794,0.8720158053351299,0.8516606426367055,0.8316797767454337,0.8120626219965753,0.7927872962499999,0.7738476035216895,0.7552530938253424,0.7370162253938356,0.7191655215098249,0.701682123504351,0.684554373622146,0.6677836878424657,0.6513679168418857,0.63528276810943,0.6195140109406393,0.6040328735182648,0.5888624067523018,0.5740110616190396,0.5594822468401827,0.5452777984611873,0.5313971409908427,0.5178199962796367,0.5045579164680366,0.4915908610011415,0.47891292735050023,0.4665062669039006,0.4543531031552512,0.44245601998515977,0.4308368204674564,0.41948823226068566,0.4084056735114155,0.3975854938413242,0.38703566524791655,0.3767404724798013,0.36669748183789946,0.3568845342408676,0.3472889470900517,0.3379053832409238,0.32874364355593605,0.31980636347488584,0.3110946152248671,0.3025871552028782,0.29428662598858446,0.2862003257557078,0.2783250799800135,0.27064792323728387,0.2631677504383562,0.2558726047545662,0.24875467348212818,0.24180770505063068,0.23503563459246576,0.2284248694155251,0.22197747529960454,0.2156995018350956,0.20959165328995433,0.20364796209817349,0.197864740877411,0.1922317106433459,0.18674358357420093,0.18139308615182648,0.17618104009862265,0.17110374008411933,0.16616504389611872,0.16136482620547946,0.15670149534046335,0.15216616101504607,0.14775727578995432,0.14347092121689495,0.1393039115829029,0.13524557131231754,0.13129307102283105,0.1274458896894977,0.12370282263540187,0.12004620199779799,0.1164787202089041,0.11301316487100459,0.10964898290652991,0.10637950317261462,0.10320385414383564,0.10011881701803653,0.09711972643141888,0.09419961283937232,0.0913598922328767,0.08860065316757991,0.08592228786327256,0.08332200980053865,0.08079987688527397,0.07835298896598174,0.07597900932142876,0.07367342591078799,0.07143536051404108,0.06926086540445205,0.06714716313777604,0.06509182301919025,0.06309621490079909,0.06116009370536529,0.05928343581395502,0.057463228069141586,0.05569854128458904,0.05398723016347032,0.05232781483709422,0.05071697327887036,0.04915291674440639,0.0476332601739726,0.046157345240525116,0.04472506063721462,0.04333616000079909,0.04199026767671232,0.0406867737231679,0.039422906560463926,0.038197949932077625,0.03701053844543379,0.03585953589613868,0.034741816434338595,0.03365641431312785,0.032602938295776256,0.031581479271375106,0.030590914891344783,0.029631615652511416,0.028702792111415524,0.027803440808965865,0.026931607269200544,0.026086890462214612,0.025268279793378996,0.024474420813401704,0.02370335567316759,0.022955316298744293,0.02223018420011415,0.021527918672266503,0.020847648172613656,0.020189258555479452,0.019551881429452054,0.018934801955076477,0.01833674901259388,0.017757402015296807,0.01719566937579909,0.016650764805535595,0.016121977759972678,0.015609571912328764,0.015113396133447485,0.014633356651931282,0.01416860278163317,0.013718831035958905,0.013283431162328767,0.012861967112398632,0.01245354111033916,0.012057658260958906,0.011673675359931508,0.011301498602653018,0.010940720281041183,0.01059147223025114,0.010253605160068494,0.009926878133756332,0.009610555694441731,0.00932262226611872,0.009171340419965751,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999,0.009152420199999999};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.312785388127853e-05,0.0005640981735159817,0.001561588629388427,0.0030653529455797594,0.005067009132420092,0.007631107305936072,0.011122151732914141,0.015696058836739277,0.021637899543378993,0.0286398401826484,0.036743619781919805,0.046641089652419095,0.057647602739726043,0.06971267123287671,0.08311531489382938,0.09764776492751454,0.11315633561643834,0.12972140410958904,0.14761223831624123,0.16659131234872868,0.18622722602739725,0.20716700913242006,0.22898495895401358,0.2513482739476508,0.2757369292237443,0.3013610730593607,0.32592097743094545,0.3498462179055318,0.37229115296803655,0.3929135273972602,0.4118016727175187,0.4251950825910123,0.42912300228310496,0.4263669520547946,0.4219408042642912,0.4167400716121466,0.40986015981735163,0.4019213470319634,0.39338126668662826,0.3838596520448137,0.3734796232876712,0.36291649543379,0.3519452482096963,0.3404888333175263,0.32896870763584474,0.317135328892694,0.3053313489997505,0.2935863981713576,0.2820328635285388,0.27069728498630136,0.2596374120006799,0.24880471779085886,0.2382551901609589,0.2280050000639269,0.21806311955025326,0.2084197027403405,0.19908883566210048,0.1900723164874429,0.18136686823436762,0.17297250453599944,0.16489590679680363,0.1571360695365297,0.14968940452779647,0.1425370307975023,0.13568480168264843,0.12912050644634707,0.12283183371478652,0.11680407365327372,0.11102907922260273,0.10550687374429225,0.10023846371012989,0.09520914689041564,0.09040562617625571,0.08582537844497717,0.08146567833840607,0.07730450580956222,0.07333463900958904,0.06955447868002283,0.06595460813953265,0.06252186397637392,0.05925179310136986,0.05613927484874429,0.05318517746901527,0.05037336401840801,0.047698775737100456,0.04516227501757991,0.042757110233832996,0.040466388754327606,0.0382856682413242,0.036216416562214616,0.03425411329296604,0.03239254354225678,0.03062870616061644,0.028958338874315065,0.027377599075680558,0.02588066700378802,0.024462598935502285,0.02311096993105023,0.021822581293599198,0.020601176318336262,0.01944482565194064,0.0183498051716895,0.017313608947728747,0.016332791702332386,0.015405497181963471,0.014529258627283105,0.013701614993539312,0.012919162458128727,0.012179916863470322,0.011481545910388127,0.010821933822273372,0.010198111673750091,0.009608382952203195,0.009051172193881279,0.00852510124042724,0.008028258422936597,0.007559559283116438,0.0071174954805365296,0.006700613987021795,0.006307130417987344,0.005936001312226029,0.005585964423961187,0.00525574505481155,0.0049438719346901906,0.004649667929771689,0.004372297201986301,0.004110993115003118,0.003864743175753175,0.003632889324566209,0.0034145847544634696,0.003209076165647753,0.003015457829541103,0.0028331656872260277,0.0026614659129337898,0.0024996834494063927,0.0023473207390639268,0.0022039159587100457,0.002069017862808219,0.001942228385796093,0.0018229830027516093,0.001710902387351598,0.0016055539425114153,0.0015065584298496644,0.001413452322733488,0.0013259054306621004,0.0012435648310159817,0.00116617299868185,0.0010934115507269134,0.0010250844557831047,0.0009609537473584477,0.0009007863480108605,0.0008442848761420078,0.0007912582605057077,0.0007414947845171232,0.0006948025102043878,0.0006509344740389001,0.0006097353009920092,0.0005710603986506849,0.000534783100156137,0.0005007427390997236,0.00046883777640296806,0.0004389404623687215,0.00041092806243340314,0.00038465714352672046,0.0003600359696598173,0.00033696062481278536,0.0003153286955451756,0.0002950261976167284,0.00027599223117123284,0.0002581577448630137,0.00024145899956310357,0.00022581753079764578,0.00021117882349429222,0.00019747759076027394,0.00018465530454677247,0.00017264517416746823,0.00016140275662557076,0.0001508742908961187,0.00014101334216136437,0.00013177343800841506,0.00012312599309931507,0.0001150372013744292,0.00010747603664143399,0.00010040326330361679,9.379107915057077e-05,8.760897594748859e-05,8.183005680394303e-05,7.64231079516777e-05,7.136519949680363e-05,6.663235605810503e-05,6.220639753132034e-05,5.806616292692817e-05,5.419772894189498e-05,5.058499506837899e-05,4.721236495510455e-05,4.4060863084988896e-05,4.111762659668949e-05,3.836886616232877e-05,3.580211127698181e-05,3.340212074111086e-05,3.115879474315069e-05,2.906275829394977e-05,2.7105810398963246e-05,2.5278056857489333e-05,2.3572876365525112e-05,2.1982347822031963e-05,2.0498899553825135e-05,1.9113961325529605e-05,1.782179064863014e-05,1.6616108373515983e-05,1.5490813788822142e-05,1.4439276896677335e-05,1.345768245890411e-05,1.2541883323173516e-05,1.1688058343738925e-05,1.0891683726742894e-05,1.0149503789543378e-05,9.457755567625572e-06,8.813053274344697e-06,8.211645721213382e-06,7.650949043972605e-06,7.127960661210044e-06,6.640069187170634e-06,6.184692242808313e-06,5.760166510216895e-06,5.364597003618722e-06,4.996243095035181e-06,4.652988061482802e-06,4.3332888881735156e-06,4.035488807557078e-06,3.758124564450308e-06,3.499546962827994e-06,3.2585232098972603e-06,3.0337831144863015e-06,2.8242757927511413e-06,2.6290696833333335e-06,2.4472739440410957e-06,2.278039053630137e-06,2.120569101331125e-06,1.9738984959681676e-06,1.8373547103767128e-06,1.710230364155251e-06,1.5918873084357613e-06,1.4815688182557327e-06,1.3787603535502283e-06,1.2829849710958903e-06,1.193824615525426e-06,1.1107889120410708e-06,1.0335397651187215e-06,9.616840141038813e-07,8.948479996063392e-07,8.326170455653742e-07,7.747069866347032e-07,7.208126316849316e-07,6.706401861156088e-07,6.238748564623038e-07,5.80328680925799e-07,5.39800817283105e-07,5.021064091646456e-07,4.6703117141655437e-07,4.3441831903767125e-07,4.0409043409360725e-07,3.75888102701718e-07,3.496372811312598e-07,3.2521614582077624e-07,3.0248588297260277e-07,2.8132563339115953e-07,2.616164779767666e-07,2.432799522328767e-07,2.2622816115525111e-07,2.1038042958645232e-07,1.9564063005568657e-07,1.8193793939497717e-07,1.6919723302397265e-07,1.5735213689830825e-07,1.4632884919247322e-07,1.360718333710046e-07,1.265242863481735e-07,1.1764179180390874e-07,1.0937489618166904e-07,1.0168927620182648e-07,9.454686969634702e-08,8.791125226326884e-08,8.174005271337456e-08,7.63241153152968e-08,7.353414546849314e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08,7.318706099999999e-08};
    N2O={272.96107456621,272.9726693013698,272.9941257165394,273.01677058294024,273.03903277739727,273.0609621563927,273.0825153713103,273.10385496731294,273.12487171461186,273.14564631849316,273.1661722663061,273.1866024701574,273.20678641666666,273.22678616780826,273.24662643795693,273.2664805481449,273.2862269452055,273.3058792956621,273.32541536802285,273.3450366053722,273.36467567009134,273.3843594737443,273.4040140041046,273.4238206748883,273.4436899851598,273.4637077899543,273.48382240089705,273.5041690512639,273.5246361997717,273.5453029200914,273.56616807893556,273.58739298222173,273.6088356769406,273.63054125114155,273.6525594280822,273.6749426712328,273.697710902968,273.7208541461187,273.74432746710704,273.768343619757,273.7927792557078,273.81768894406395,273.8430161590251,273.86897407288467,273.8954107123288,273.9223855673516,273.94986340039173,273.9780587438681,274.0068153150685,274.03618780022833,274.0661241729919,274.0968826418145,274.1282830639269,274.16039195547944,274.1931284790715,274.22675319710805,274.2610637614155,274.2961303059361,274.33190511195943,274.36865666319835,274.4061587899543,274.44448673287667,274.4835940374716,274.5237831142551,274.56480193379,274.60669492351593,274.64938155345334,274.69323864393544,274.7380005547945,274.7837237191781,274.8303126097512,274.8781333412431,274.92692350684933,274.9767818538812,275.0276008607617,275.0803156546648,275.13766897716897,275.20297787214605,275.2722146756993,275.33459150004995,275.37732723173514,275.39653468607304,275.40087332013997,275.4007942936972,275.40350199429224,275.43144604794526,275.5030698530703,275.60014833944655,275.700194063927,275.800194063927,275.89993163160915,276.0001483394466,276.1001940639269,276.200194063927,276.2999316316091,276.4001483394465,276.5001940639269,276.6001940639269,276.6999316316091,276.80014833944654,276.9001940639269,277.0001940639269,277.0999316316092,277.20014833944657,277.29703767123283,277.37198915525113,277.4280794314694,277.50326764727896,277.6001940639269,277.69703767123286,277.771835108042,277.82823056241733,277.9033019406392,278.0001940639269,278.0999316316092,278.20014833944657,278.300194063927,278.4001940639269,278.4999316316092,278.60014833944655,278.700194063927,278.79703767123283,278.871835108042,278.9282305624173,279.0033019406393,279.1001940639269,279.1999316316091,279.2969919467525,279.37198915525113,279.4250970319635,279.4749658158046,279.5282305624174,279.6001455479452,279.6719891552512,279.72825342465757,279.80330194063924,279.9001940639269,280.0001940639269,280.0999316316092,280.20014833944657,280.300194063927,280.403350456621,280.5280281551763,280.6752225091698,280.8252910958904,280.9752910958905,281.1280110630786,281.3002595940315,281.47218321917813,281.6284474885845,281.8029939709809,282.0034530715872,282.22859303652973,282.47232876712326,282.69984617112056,282.92849015644885,283.17232876712336,283.3972802511415,283.59986326321837,283.8002966788932,284.0035445205479,284.2254366438356,284.44361893979084,284.62525959403155,284.8003396118722,284.97218321917813,285.1280110630786,285.30341598672555,285.5003881278539,285.70038812785384,285.8998632632183,286.097140286199,286.27218321917803,286.42529109589043,286.5748974474137,286.7283789018639,286.9034960045662,287.10038812785393,287.30297687888316,287.52849015644887,287.7754851598174,288.0254851598174,288.2748290790228,288.52537084861643,288.77232876712327,288.99728025114155,289.20297687888313,289.42849015644885,289.67232876712336,289.90043664383563,290.1279597867854,290.37221445592235,290.6004366438356,290.83174942922375,291.10292560259006,291.3972886256456,291.67237728310505,291.93179794520546,292.23413574182206,292.60371266561873,293.00077625570776,293.40077625570774,293.80284014210145,294.231943228036,294.704078196347,295.2009703196347,295.7027717737106,296.2320915674826,296.80427226027393,297.40116438356154,298.00581702098464,298.6585395488684,299.3629560502283,300.0756954908676,300.7376823084314,301.40807294395785,302.2266755136987,303.0777394406393,303.79019366157644,304.4106888427278,305.08820776255703,305.7492094748858,306.3172759921526,307.244360434289,308.46775142694065,309.44270747716894,310.0949461021908,310.6013330276717,311.08473458904103,311.6246666666667,312.301999226489,313.04356602602485,313.76895804794515,314.5280019977169,315.2405021661426,315.8565604180702,316.50388784246576,317.24836386986306,318.00700828405326,318.7157618397086,319.445162673516,320.19307019292233,320.89654339114696,321.60690800533973,322.32922489041096,323.0642038904109,323.81086535990715,324.5792501236994,325.3685783344749,326.1802685182648,327.0119447160903,327.8688119435119,328.7478538413243,329.64887247716894,330.57144644904184,331.5162319527753,332.48215204452055,333.4673830159818,334.4698748422474,335.49012248506307,336.5272393972603,337.5810484885845,338.6511417990368,339.73834033210437,340.84175025342466,341.96122858333337,343.09638652247554,344.248353875234,345.4164310913242,346.60051071803656,347.8001630615129,349.0163441730013,350.24808653881274,351.4952391347031,352.7573708020186,354.0354940684869,355.3279644063927,356.63028451027395,357.93763529161987,359.25044493641934,360.5676770114156,361.8892434406393,363.2147597476171,364.54538874697147,365.88018675342465,367.2191083458904,368.561615903991,369.90760369642504,371.2548196906393,372.603051262557,373.9519370832086,375.3026832977269,376.65434240525116,378.0069090605023,379.3600559982783,380.7150132178776,382.07069296461185,383.4261144292238,384.7799899586608,386.1333923971199,387.48539364726025,388.8359933972603,390.1848781510778,391.5332969341923,392.88032137328764,394.22597234817346,395.5700770127255,396.9147839417902,398.26007751369866,399.6061142968036,400.9525761906705,402.3007032052487,403.6495634121004,404.99916020319637,406.3491671608029,407.70080501199885,409.0532842579909,410.4076537397261,411.7646518585411,413.1256437219103,414.48969850342456,415.85679470547944,417.22659853311126,418.6003271287209,419.9770059303653,421.3566184657534,422.73848315245647,424.1215426954518,425.5025455878995,426.88114239041096,428.25698413430405,429.6313122076346,431.0031891369863,432.3726347054794,433.73982775228313,435.1047820399544,436.4668906335617,437.82178946803657,439.16464004081513,440.49605742901804,441.8151511952055,443.12197087899557,444.4163077728186,445.69944387611986,446.97059945776255,448.22988381735155,449.47713378992324,450.71357885639515,451.9384701244292,453.1519216426941,454.3537666458692,455.5451910663441,456.725476966895,457.8947369086757,459.05280515222574,460.2008218094887,461.33810877625575,462.4647584143836,463.58061437059905,464.68679486886805,465.78261936301357,466.868189946347,467.9433643602253,469.0091990775975,470.06505625342476,471.1110265490867,472.1469751873019,473.1739269516368,474.19125200114155,475.199050760274,476.19719065880685,477.186654808163,478.16684413242007,479.1378513710046,480.0995433340508,481.05286893704306,481.99725520091323,482.93279842123275,483.8593545154951,484.77785187243626,485.6877389783105,486.5890882111872,487.4817904896075,488.3667199133201,489.2433455194064,490.11174950114156,490.9714850156635,491.8211535425369,492.6579766312786,493.4816995159817,494.292236299174,495.0903932238971,495.87572648173517,496.64835155251143,497.4082213917584,498.1561351850064,498.8916849566211,499.61499840296807,500.3260318952891,501.0255267368472,501.71311697374426,502.3889113253426,503.05288038048,503.70572168068026,504.34708885730583,504.97710035958903,505.595724413454,506.20361507571374,506.80045438698625,507.3863468184931,507.96127531947883,508.5258544788938,509.07978862214617,509.6231794851598,510.15601066467667,510.67885245171175,511.19144910502285,511.6938896643837,512.1861642538053,512.6688040260655,513.1415671404108,513.6045474041097,514.0577436643897,514.501645519132,514.9360415034247,515.3610114874429,515.7765601988922,516.1831419719197,516.5805660045662,516.9689207054795,517.3481951711767,517.7188259276985,518.080634423516,518.4337013664382,518.7781494942923,519.1140650525116,519.4415218036529,519.760599739726,520.071279379719,520.3738978066317,520.6683369280822,520.9546721187214,521.232916236894,521.503393295843,521.7659885878994,522.0207747956622,522.2677779893642,522.5072877191157,522.7392080639269,522.9636052968036,523.1805159395913,523.3901898640337,523.5925566449772,523.7876811563926,523.9755938923323,524.1565285090701,524.3304231141552,524.4973474098173,524.6573368772052,524.8105861974949,524.9570574954338,525.0968190856164,525.2298999558162,525.3564817077813,525.4765373230593,525.5901224760273,525.6972881577839,525.7981750854823,525.8927788812784,525.9811600878996,526.0633577787571,526.1395050908501,526.2095959417808,526.2736882214612,526.3318326143112,526.3841355342341,526.430612283105,526.4713143869863,526.5062951895478,526.5356339270279,526.5593654315068,526.5775298732875,526.5901955500786,526.5974103056741,526.5996163116439,526.5995065582191,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999,526.5994499999999};
    
    return;
}

void setEm_RCP85()
{
    Aero_BC_em={0.0,0.106998,0.1333826,0.15984677,0.18639296,0.21302373,0.23974168,0.26654951,0.29345,0.32044601,0.34754051,0.37473653,0.40203721,0.4294458,0.45696563,0.48460014,0.51235288,0.5402275,0.56822778,0.59635759,0.62462095,0.65302198,0.68156496,0.71025425,0.73909439,0.76809005,0.79724604,0.8265673,0.85605896,0.88572629,0.91557471,0.94560984,0.97583743,1.0062635,1.036894,1.0677355,1.0987944,1.1300774,1.1615915,1.1933438,1.2253417,1.2575928,1.2901048000000002,1.322886,1.3559444999999999,1.3892891,1.4229284,1.4568716999999998,1.4911284,1.5257081000000001,1.5606208000000001,1.5958768,1.6314868,1.6674616000000002,1.7038127,1.7405515999999999,1.7776901999999999,1.8152409999999999,1.8532168000000002,1.8916306,1.930496,1.969827,2.0096380000000003,2.0499438000000003,2.0907597,2.1321015,2.1739855,2.2164284,2.2594475,2.3030607000000005,2.3472862,2.3921432,2.437651,2.4838298,2.5307004,2.5782841,2.6266031,2.67568,2.7255382999999997,2.7762021,2.8276963999999998,2.8800468999999995,2.9332801,2.9874231,3.0425042999999996,3.0985525000000003,3.1187417,3.1389308999999996,3.15912,3.1793092,3.1994982999999997,3.2196875,3.2398767000000004,3.2600658,3.2802550000000004,3.3004441,3.3244138,3.3483834999999997,3.3723532,3.3963229,3.4202926,3.4442623,3.4682318999999997,3.4922016000000005,3.5161712999999994,3.540141,3.562453,3.5847651,3.6070771,3.6293891000000005,3.6517012,3.6740132000000005,3.6963253,3.7186373,3.7409492999999996,3.7632614,3.7925706,3.8218797999999996,3.8511889999999998,3.8804982000000003,3.9098074,3.9391165999999997,3.9684258000000003,3.997735,4.0270443,4.0563535,4.0882845,4.1202154,4.1521464,4.1840774,4.216008400000001,4.2479394,4.2798704,4.3118014,4.3437324,4.3756633,4.4173849,4.4591064000000005,4.500828,4.542549500000001,4.5842711,4.6259926,4.6677142,4.7094357,4.7511573,4.7928788,4.794951599999999,4.797024400000001,4.7990972,4.80117,4.8032428,4.805315599999999,4.8073885,4.8094613,4.811534099999999,4.8136069,4.798714299999999,4.7838218,4.7689293,4.7540366999999994,4.7391442,4.7242517,4.7093590999999995,4.6944666,4.679574099999999,4.6646815,4.667096400000001,4.6695113,4.671926200000001,4.674341,4.6767559,4.6791708,4.6815857,4.6840005,4.6864154000000005,4.6888303,4.693243,4.6976558,4.7020686,4.706481299999999,4.7108941,4.715306900000001,4.7197195999999995,4.7241324,4.7285452,4.732957900000001,4.7733276,4.813697299999999,4.854067,4.8944367,4.9348064,4.9751761,5.0155458,5.0559155,5.0962852,5.136654900000001,5.179599700000001,5.2225445,5.2654893,5.3084340999999995,5.3513789,5.3943237,5.4372685,5.4802133,5.5231581,5.566102900000001,5.7038725,5.8416421,5.9794117,6.1171812999999995,6.254950900000001,6.3927205,6.5304901,6.668259700000001,6.8060293000000005,6.9437989,7.021004799999999,7.0982107,7.175416499999999,7.2526224,7.329828200000001,7.4070341,7.48424,7.5614457999999996,7.6386517000000005,7.715857499999999,7.7247518,7.733646,7.742540299999999,7.7514345,7.7603288,7.769222999999999,7.7781173,7.7870115,7.795905800000001,7.8048,7.8945,7.9842,8.0734,8.1623,8.2512,8.2076,8.1641,8.1208667,8.0776333,8.0344,7.99705,7.9597,7.92235,7.885,7.84765,7.8103,7.77295,7.7356,7.69825,7.6609,7.599139999999999,7.537380000000001,7.475619999999999,7.413860000000001,7.3521,7.29034,7.22858,7.1668199999999995,7.105060000000001,7.0433,6.952310000000001,6.86132,6.77033,6.67934,6.58835,6.49736,6.40637,6.31538,6.2243900000000005,6.1334,6.0841199999999995,6.03484,5.9855599999999995,5.93628,5.887,5.83772,5.7884400000000005,5.73916,5.6898800000000005,5.6406,5.59518,5.54976,5.50434,5.45892,5.4135,5.36808,5.32266,5.27724,5.23182,5.1864,5.1532800000000005,5.12016,5.08704,5.05392,5.0208,4.98768,4.95456,4.9214400000000005,4.888319999999999,4.8552,4.83481,4.81442,4.79403,4.77364,4.75325,4.73286,4.71247,4.692080000000001,4.67169,4.6513,4.62775,4.6042,4.58065,4.5571,4.53355,4.51,4.48645,4.4629,4.43935,4.4158,4.39918,4.38256,4.36594,4.34932,4.3327,4.31608,4.29946,4.28284,4.26622,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496,4.2496};
    CH4_em={0.0,1.9632618999999998,2.4364481,2.911105,3.3872782,3.8650146,4.3443625,4.8253718,5.308093799999999,5.7925816,6.278889599999999,6.7670743,7.2571937,7.7493076,8.2434776,8.7397674,9.2382426,9.738970599999998,10.242021000000001,10.747466000000001,11.25538,11.765839,12.278921,12.794707,13.313282000000001,13.834732,14.359145000000002,14.886613,15.417231,15.951096,16.488308,17.028971,17.573192000000002,18.121081,18.672751,19.228319,19.787906,20.351635,20.919635999999997,21.49204,22.068984,22.650607,23.237054999999998,23.828476000000002,24.425025,25.02686,25.634145,26.247048,26.865743,27.490408000000002,28.121229999999997,28.758398,29.402108000000002,30.052563,30.709971000000003,31.374547999999997,32.046514,32.7261,33.413539,34.109076,34.81296,35.52545,36.246813,36.977321,37.717259000000006,38.466916999999995,39.226597,39.996609,40.777271,41.568914,42.371876,43.186509,44.013172999999995,44.85224,45.704093,46.569129,47.447755,48.34039,49.247469,50.169439000000004,51.106759000000004,52.059903999999996,53.029365000000006,54.015643999999995,55.019264,56.040758999999994,56.46131999999999,56.88188,57.302441,57.723001000000004,58.143562,58.564122,58.984683,59.405243000000006,59.825804000000005,60.246364,59.614468,58.982572999999995,58.350677000000005,57.71878100000001,57.086884999999995,56.45499,55.823094,55.191198,54.559303,53.927406999999995,56.683868999999994,59.44033100000001,62.19679300000001,64.953255,67.709717,70.46618000000001,73.22264200000001,75.979104,78.735566,81.492028,84.359461,87.226893,90.094326,92.96175799999999,95.82919100000001,98.696624,101.56406,104.43149,107.29892,110.16635,111.52362,112.88089,114.23816000000001,115.59543000000001,116.9527,118.30996999999999,119.66723999999999,121.02451,122.38178,123.73905,124.8415,125.94396,127.04642,128.14887,129.25133,130.35378,131.45623999999998,132.5587,133.66115,134.76361,135.96943000000002,137.17525,138.38107,139.5869,140.79272,141.99854,143.20436,144.41019,145.61601000000002,146.82183,147.86155,148.90128,149.941,150.98072,152.02045,153.06017,154.09989,155.13962,156.17934,157.21906,158.34545,159.47183,160.59821000000002,161.7246,162.85098,163.97736,165.10375,166.23013,167.35651000000001,168.4829,170.03046,171.57803,173.12559,174.67315,176.22072,177.76828,179.31583999999998,180.86341000000002,182.41097,183.95853,189.11003,194.26153,199.41303,204.56453,209.71603,214.86753,220.01902,225.17052,230.32202,235.47352,238.52217000000002,241.57082999999997,244.61947999999998,247.66813,250.71679,253.76543999999998,256.81408999999996,259.86274,262.9114,265.96005,270.02505,274.09004,278.15504,282.22003,286.28503,290.35002000000003,294.41502,298.48002,302.54501,306.61001,310.01251,313.415,316.8175,320.22,323.6225,327.025,330.42749,333.82999,337.23249,340.63499,336.59218,332.54937,328.50656000000004,324.46375,320.42094,316.37814,312.33533,308.29252,304.24971,300.2069,303.4092,306.5788,309.7164,312.824,315.9027,322.1577,328.4342,334.75397000000004,341.07372999999995,347.3935,354.56076,361.72802,368.89527999999996,376.06254,383.2298,390.39706,397.56432,404.73158,411.89884,419.0661,425.58022,432.09434000000005,438.60846,445.12257999999997,451.6367,458.15082,464.66494000000006,471.17905999999994,477.69318,484.2073,493.52545,502.8436,512.16175,521.4799,530.79805,540.1162,549.43435,558.7525,568.07065,577.3888,587.33132,597.2738400000001,607.21636,617.15888,627.1014,637.0439200000001,646.98644,656.92896,666.87148,676.814,683.65001,690.48602,697.3220299999999,704.15804,710.99405,717.83006,724.66607,731.50208,738.3380900000001,745.1741,748.66794,752.16178,755.65562,759.14946,762.6433,766.13714,769.63098,773.12482,776.61866,780.1125,784.24064,788.36878,792.49692,796.62506,800.7532,804.88134,809.0094799999999,813.13762,817.26576,821.3939,826.3294099999999,831.2649200000001,836.20043,841.13594,846.07145,851.0069599999999,855.94247,860.8779800000001,865.81349,870.749,872.4331900000001,874.11738,875.80157,877.4857599999999,879.16995,880.85414,882.5383300000001,884.2225199999999,885.90671,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.5909,887.7612,887.93151,888.10181,888.27211,888.44242,888.61272,888.78302,888.95332,889.12363,889.29393,889.46423,889.63454,889.80484,889.97514,890.14545,890.31575,890.48605,890.65636,890.82666,890.99696,891.1672599999999,891.3375699999999,891.5078699999999,891.6781699999999,891.8484800000001,892.0187800000001,892.1890800000001,892.3593900000001,892.5296900000001,892.6999900000001,892.8702900000001,893.0406,893.2109,893.3812,893.55151,893.72181,893.89211,894.06242,894.23272,894.40302,894.57333,894.74363,894.91393,895.08423,895.25454,895.42484,895.59514,895.76545,895.93575,896.10605,896.27636,896.44666,896.61696,896.7872699999999,896.9575699999999,897.1278699999999,897.2981699999999,897.4684800000001,897.6387800000001,897.8090800000001,897.9793900000001,898.1496900000001,898.3199900000001,898.4903,898.6606,898.8309,899.00121,899.17151,899.34181,899.51211,899.68242,899.85272,900.02302,900.1933300000001,900.3636300000001,900.53393,900.70424,900.87454,901.04484,901.21514,901.38545,901.55575,901.72605,901.89636,902.06666,902.23696,902.4072699999999,902.5775699999999,902.7478699999999,902.9181800000001,903.0884800000001,903.2587800000001,903.4290800000001,903.5993900000001,903.7696900000001,903.9399900000001,904.1103,904.2806,904.7895,904.8603,904.9552,905.0501,905.145,905.2399,905.3348,905.44156,905.5483199999999,905.6550800000001,905.76184,905.8686,905.9807,906.0928,906.2049,906.317,906.4291,906.5412,906.6533,906.7654,906.8775,906.9896,907.1017,907.2138,907.3259,907.438,907.5501,907.6505400000001,907.75098,907.85142,907.95186,908.0523,908.15274,908.25318,908.35362,908.4540599999999,908.5545,908.65494,908.7553800000001,908.8558199999999,908.9562599999999,909.0567,909.15714,909.2575800000001,909.3580199999999,909.45846,909.5589,909.65934,909.7597800000001,909.8602199999999,909.96066,910.0611,910.14458,910.2280699999999,910.31155,910.39504,910.4785199999999,910.562,910.64549,910.7289699999999,910.81246,910.89594,910.9794199999999,911.06291,911.14639,911.2298800000001,911.31336,911.39684,911.4803300000001,911.56381,911.6473,911.7307800000001,911.81426,911.89775,911.9812300000001,912.06472,912.1482,912.2316800000001,912.31517,912.39865,912.4821400000001,912.56562,912.6491,912.7325900000001,912.81607,912.89956,912.9830400000001,913.06652,913.15001,913.2334900000001,913.3169800000001,913.40046,913.4839400000001,913.5674300000001,913.65091,913.7344,913.8178800000001,913.90136,913.98485,914.0683300000001,914.1518199999999,914.2353,914.3042,914.37309,914.44199,914.51088,914.57978,914.6486800000001,914.7175699999999,914.7864699999999,914.85536,914.92426,914.99316,915.06205,915.13095,915.19984,915.2687400000001,915.3376400000001,915.4065300000001,915.4754300000001,915.54432,915.61322,915.6821199999999,915.75101,915.8199099999999,915.8888,915.9577,916.0266,916.09549,916.16439,916.23328,916.30218,916.3710800000001,916.4399699999999,916.5088699999999,916.57776,916.64666,916.71556,916.78445,916.85335,916.92224,916.9911400000001,917.0600400000001,917.1289300000001,917.1978300000001,917.26672,917.33562,917.4045199999999,917.47341,917.5423099999999,917.6112,917.6801,917.7393,917.79849,917.85769,917.9168800000001,917.97608,918.0352800000001,918.0944699999999,918.1536699999999,918.21286,918.27206,918.3312599999999,918.39045,918.44965,918.5088400000001,918.56804,918.62724,918.6864300000001,918.7456300000001,918.80482,918.86402,918.9232199999999,918.98241,919.04161,919.1008,919.16,919.2192,919.2783900000001,919.3375900000001,919.39678,919.4559800000001,919.5151800000001,919.5743699999999,919.63357,919.6927599999999,919.7519599999999,919.81116,919.87035,919.92955,919.98874,920.04794,920.1071400000001,920.1663300000001,920.22553,920.2847199999999,920.3439199999999,920.40312,920.46231,920.5215099999999,920.5807,920.6399,920.691,920.7420900000001,920.79319,920.84428,920.89538,920.9464800000001,920.9975699999999,921.0486699999999,921.09976,921.15086,921.20196,921.25305,921.30415,921.35524,921.40634,921.45744,921.5085300000001,921.5596300000001,921.6107199999999,921.6618199999999,921.7129199999999,921.76401,921.81511,921.8662,921.9173,921.9684,922.01949,922.07059,922.1216800000001,922.1727800000001,922.2238800000001,922.2749699999999,922.32607,922.37716,922.4282599999999,922.4793599999999,922.53045,922.58155,922.63264,922.6837400000001,922.7348400000001,922.7859300000001,922.83703,922.88812,922.93922,922.9903199999999,923.0414099999999,923.09251,923.1436,923.1947};
    //CO_em={0.0,9.0502213,12.960844,16.876539,20.797465,24.723782,28.655658000000003,32.593264000000005,36.536778000000005,40.486382,44.442265,48.40462,52.373649,56.349557,60.332558,64.32287,68.32072,72.32634,76.339972,80.361863,84.392268,88.431451,92.479683,96.537244,100.60441999999999,104.68151999999999,108.76883000000001,112.86668,116.9754,121.09532,125.22678,129.37015,133.52578,137.69406999999998,141.8754,146.07018,150.27882,154.50173999999998,158.7394,162.99225,167.26075,171.5454,175.84668,180.16513,184.50125,188.85561,193.22877,197.62131000000002,202.03382,206.46693,210.92127000000002,215.39751,219.8963,224.41836,228.96441000000002,233.53517999999997,238.13144,242.75397999999998,247.40361000000001,252.08117000000001,256.78752000000003,261.52355,266.29019,271.08837,275.91908,280.78331000000003,285.68212,290.61656,295.58772999999997,300.59677999999997,305.64487,310.73322,315.86307,321.03569,326.25242000000003,331.51462000000004,336.82369,342.18109,347.5883,353.04688,358.5584,364.1245,369.74689,375.42728,381.16749,386.96935,387.46072000000004,387.95209,388.44346,388.93483,389.42621,389.91758,390.40895,390.90032,391.39169,391.88307000000003,392.8961,393.90914,394.92217999999997,395.93522,396.94826,397.9613,398.97434,399.98738,401.00042,402.01346,403.03247999999996,404.0515,405.07052000000004,406.08954,407.10856,408.12757999999997,409.1466,410.16562000000005,411.18464,412.20366,413.25581,414.30795,415.3601,416.41225,417.46439,418.51653999999996,419.56869000000006,420.62082999999996,421.67298,422.72513,424.29312000000004,425.86110999999994,427.42911,428.9971,430.56509000000005,432.13309000000004,433.70108,435.26907,436.83707000000004,438.40505999999993,439.89155999999997,441.37805999999995,442.86456,444.35105999999996,445.83755999999994,447.32406,448.81055999999995,450.29706,451.78355999999997,453.27005999999994,451.75965,450.24925,448.73884000000004,447.22844000000003,445.71803,444.20762,442.69722,441.18681,439.67641,438.166,440.99557000000004,443.82514000000003,446.65470999999997,449.48427000000004,452.31384,455.14340999999996,457.97298,460.80254,463.63210999999995,466.46168,468.03074000000004,469.5998,471.16885999999994,472.73790999999994,474.30697000000004,475.87602999999996,477.44509000000005,479.01415,480.58320999999995,482.15227000000004,488.55777,494.96327,501.36877999999996,507.77428,514.17979,520.58529,526.9907900000001,533.3963,539.8018,546.20731,558.44614,570.68497,582.9238,595.16263,607.40145,619.64028,631.87911,644.1179400000001,656.35677,668.5956,682.67558,696.75555,710.83553,724.9155099999999,738.9954799999999,753.0754599999999,767.15544,781.23541,795.3153900000001,809.3953700000001,825.18291,840.97046,856.758,872.54555,888.3331,904.1206400000001,919.90819,935.69573,951.48328,967.27082,980.4447,993.6185800000001,1006.7925,1019.9663,1033.1402,1046.3141,1059.488,1072.6618,1085.8357,1099.0096,1095.9087,1092.8078,1089.707,1086.6061,1083.5052,1080.4043,1077.3034,1074.2026,1071.1017,1068.0008,1066.7448,1065.4691,1064.1741,1062.8596,1061.5255,1058.9366,1056.3789,1053.8833,1051.3876,1048.892,1050.5457,1052.1995,1053.8532,1055.507,1057.1607,1058.8144,1060.4682,1062.1219,1063.7757,1065.4294,1060.7002,1055.971,1051.2418,1046.5126,1041.7833,1037.0541,1032.3249,1027.5957,1022.8665,1018.1373,1011.8253,1005.5133,999.2013599999999,992.8893800000001,986.5774,980.26542,973.95344,967.6414599999999,961.3294800000001,955.0175,950.1349,945.2523,940.3697,935.4871,930.6045,925.7219,920.8393,915.9567,911.0741,906.1915,899.68938,893.1872599999999,886.68514,880.1830199999999,873.6809,867.1787800000001,860.67666,854.1745400000001,847.6724199999999,841.1703,836.60001,832.02972,827.45943,822.88914,818.31885,813.74856,809.17827,804.60798,800.03769,795.4674,791.64666,787.82592,784.00518,780.18444,776.3637,772.54296,768.72222,764.90148,761.08074,757.26,753.3432799999999,749.42656,745.50984,741.59312,737.6764,733.75968,729.84296,725.92624,722.0095200000001,718.0928,715.3118400000001,712.53088,709.74992,706.9689599999999,704.188,701.40704,698.62608,695.8451200000001,693.06416,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832,690.2832};
    
    //CO2_em in MtCO2 per year
    /* CO2_em={11.0,30.573753099999998,50.14750766666666,69.72125966666665,89.29501166666667,108.86876733333334,132.1091856333333,151.68293763333332,171.25669329999997,190.83044529999998,210.4041973,229.9779493,249.55170496666662,269.1254569666666,288.6992089666666,308.2729646333333,331.5133833,351.08713529999994,370.6608909666666,390.2346429666667,409.80840963333327,429.38213963333334,448.9559063,468.5296729666666,488.1034029666667,507.6771696333333,530.9175663,550.4913329666667,570.0650996333334,589.6388296333333,609.2125963,628.7863629666667,652.0267596333333,671.6005263,691.1742562999999,714.4146896333334,733.9884563,760.8955196333333,776.8026196333334,796.3763863,815.9501163,839.1905492666667,858.7643162999999,878.3380463,897.9118129666666,917.4855429666667,940.7259766666667,960.2997433333333,979.8734733333334,999.44724,1022.6876733333332,1045.9280700000002,1069.1685033333333,1088.7422333333332,1108.316,1127.8897666666664,1147.4634966666665,1170.70393,1193.9443633333333,1213.5180933333334,1236.7585266666665,1256.3322933333332,1279.57269,1299.1464566666666,1318.7201866666667,1360.2939533333333,1376.2010533333332,1395.7747833333333,1419.0152166666667,1438.5889833333333,1461.8293800000001,1496.069813333333,1515.6435433333331,1538.8839766666667,1562.12441,1589.0314696666665,1612.271903,1639.1790029999997,1662.4193996666665,1689.3264996666667,1723.5669329999998,1743.140663,1773.7144296666668,1796.9548263333334,1827.528593,1861.7690263333334,1836.2141929999998,2037.2836696666668,2039.9664596666667,2070.995956333333,2070.4905796666667,2108.0945563333335,2131.183996333333,2153.1875896666666,2189.930926333333,2236.5452596666664,2285.1531926666667,2092.627636,2118.4134400000003,2149.173583333333,2177.2496533333333,2188.6779933333332,2213.2228066666667,2226.5272333333332,2246.8103166666665,2261.029833333333,2360.10588,2714.5558,2791.43205,2778.2756466666665,2854.2303899999997,2888.8860366666668,2922.841276666666,2951.852566666666,3026.27424,3143.224956666666,3270.2007066666665,3155.76811,3228.564606666667,3252.80175,3271.5323666666663,3293.195106666666,3340.9315133333334,3453.023016666667,3447.4006966666666,3548.4317366666664,3601.5779799999996,3656.36766,3646.145433333333,3752.3463266666663,3851.5344999999998,3906.020763333333,3995.068403333333,4092.003556666666,4250.416316666666,4353.089656666667,4601.45829,4652.90331,4926.793483333333,5031.741843333333,5253.655733333333,5512.957376666667,5821.796676666667,5725.180156666666,5875.38622,6016.932826666666,5921.2781466666665,5965.110909999999,6108.592453333333,5737.56887,5660.41531,5900.093723333333,6109.386396666667,6051.11562,5594.065913333334,6062.039023333333,5721.527533333334,5840.783263333333,6318.723326666666,6306.15546,6354.65798,6396.43862,6817.00371,6837.128503333332,7220.495369999999,7145.892416666666,6758.916303333333,6083.82852,6239.15776,6489.496016666666,6679.624416666666,7081.433076666666,7291.896406666667,7054.2348066666655,7228.627119999999,7574.71869,7642.670126666666,7740.515566666667,7900.807199999999,7888.46168,7073.540429999999,7627.212706666666,8294.659779999998,8595.144946666665,8437.463503333332,9248.560383333333,10473.907033333333,10654.005266666667,10800.229366666666,11062.852533333335,11858.680166666665,12549.857099999997,12986.863266666667,13381.799566666667,13440.517566666666,13820.705433333333,14073.846599999999,14430.429566666666,15005.080566666666,15618.488966666664,16167.271266666667,16861.88826666667,17264.959799999997,17685.076933333334,18474.088966666666,19334.7473,19440.2681,19968.894366666667,20783.0282,20836.702699999998,20704.154533333334,21903.22823333333,22450.953799999996,22716.35666666667,23656.279899999998,23309.768533333332,22780.494366666666,23163.820166666665,23230.24036666667,24016.9721,24637.597966666664,25289.741766666666,25839.031533333335,26695.990933333334,27179.6932,27366.105433333334,27925.259633333335,27212.278133333333,27214.368866666664,27615.85053333333,28039.038133333335,28457.37583333333,28736.1789,28610.4247,28423.227066666666,28907.266666666666,29435.63333333333,29995.899999999998,31209.566666666666,32687.6,33610.5,34197.166666666664,34786.4,35375.63333333333,35964.86666666667,36554.1,37461.49,38368.880000000005,39276.270000000004,40183.66,41091.05,41998.439999999995,42905.83,43813.22,44720.61,45628.0,46401.70333333334,47175.40666666666,47949.11,48722.81333333333,49496.51666666666,50270.22,51043.92333333333,51817.626666666656,52591.329999999994,53365.03333333333,54420.11666666667,55475.2,56530.283333333326,57585.36666666667,58640.45,59695.533333333326,60750.61666666667,61805.7,62860.783333333326,63915.86666666666,65143.83333333332,66371.79999999999,67599.76666666668,68827.73333333334,70055.7,71283.66666666666,72511.63333333333,73739.6,74967.56666666667,76195.53333333333,77411.58333333333,78627.63333333333,79843.68333333333,81059.73333333332,82275.78333333333,83491.83333333333,84707.88333333333,85923.93333333333,87139.98333333332,88356.03333333333,89190.97,90025.90666666668,90860.84333333334,91695.77999999998,92530.71666666666,93365.65333333332,94200.59000000001,95035.52666666666,95870.46333333333,96705.4,97197.06333333332,97688.72666666665,98180.39,98672.05333333333,99163.71666666666,99655.38,100147.04333333332,100638.70666666667,101130.36999999998,101622.03333333333,101921.08666666664,102220.14,102519.19333333333,102818.24666666667,103117.3,103416.35333333333,103715.40666666666,104014.45999999999,104313.51333333334,104612.56666666667,104717.54333333332,104822.52,104927.49666666667,105032.47333333333,105137.45,105242.42666666665,105347.40333333334,105452.38,105557.35666666667,105662.33333333331,105651.03999999998,105639.74666666666,105628.45333333332,105617.15999999999,105605.86666666665,105594.57333333332,105583.27999999998,105571.98666666665,105560.69333333331,105549.39999999998,105538.10666666666,105526.81333333332,105515.51999999999,105504.22666666665,105492.93333333332,105481.63999999998,105470.34666666665,105459.05333333332,105447.75999999998,105436.46666666665,105425.17333333332,105413.87999999999,105402.58666666666,105391.29333333332,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,105379.99999999999,104390.75166666666,103401.50333333333,102412.255,101423.00666666667,100433.762,99444.51366666665,98455.26533333333,97466.01699999999,96476.76866666667,95487.52033333333,94498.272,93509.02366666666,92519.77533333334,91530.527,90541.28233333332,89552.034,88562.78566666666,87573.53733333333,86584.289,85595.04066666667,84605.79233333333,83616.544,82627.29566666667,81638.04733333332,80648.80266666667,79659.55433333333,78670.306,77681.05766666666,76691.80933333334,75702.56099999999,74713.31266666666,73724.06433333333,72734.81599999999,71745.56766666667,70756.32299999999,69767.07466666667,68777.82633333335,67788.578,66799.32966666666,65810.08133333334,64820.83299999999,63831.58466666666,62842.33633333334,61853.087999999996,60863.84333333332,59874.595,58885.34666666666,57896.098333333335,56906.85,55917.60166666666,54928.35333333333,53939.104999999996,52949.85666666667,51960.612,50971.363666666664,49982.11533333333,48992.867,48003.61866666667,47014.37033333333,46025.121999999996,45035.87366666667,44046.62533333334,43057.377,42068.13233333333,41078.884000000005,40089.63566666666,39100.38733333333,38111.139,37121.890666666666,36132.6427,35143.39473333333,34154.14676666667,33164.8988,32175.651199999997,31186.403233333327,30197.155266666665,29207.9073,28218.65933333333,27229.411366666667,26240.163399999998,25250.915433333335,24261.667466666666,23272.419499999996,22283.171533333327,21293.923566666665,20304.6756,19315.427633333336,18326.179666666667,17336.9317,16347.683733333333,15358.435766666664,14369.187799999998,13379.939833333334,12390.691866666668,11401.4439,10412.195933333333,9422.947966666667,8433.699999999999,7656.0,7501.2666666666655,7516.8133333333335,7532.36,7547.906666666667,7563.453333333333,7579.0,7621.24,7663.4800000000005,7705.719999999998,7747.96,7790.2,7779.664566666668,7769.128766666667,7758.593333333333,7748.057900000001,7737.522099999999,7726.986666666666,7716.451233333334,7705.915433333333,7695.380000000001,7684.844566666667,7674.308766666667,7663.7733333333335,7653.2379,7642.7021,7632.166666666667,7619.348,7606.529333333334,7593.710666666667,7580.891999999999,7568.073333333334,7555.254666666667,7542.435999999999,7529.617333333334,7516.798666666667,7503.9800000000005,7491.1613333333335,7478.342666666666,7465.524,7452.705333333333,7439.886666666665,7427.068,7414.249333333333,7401.430666666667,7388.611999999998,7375.793333333333,7362.974666666667,7350.156,7337.337333333333,7324.518666666666,7311.7,7303.956,7296.211999999999,7288.467999999999,7280.723999999999,7272.98,7265.236,7257.492,7249.7480000000005,7242.003999999999,7234.259999999999,7226.516,7218.772,7211.027999999999,7203.284,7195.54,7187.796,7180.051999999999,7172.307999999999,7164.564,7156.82,7149.076,7141.332,7133.588000000001,7125.843999999999,7118.099999999999,7110.356,7102.611999999999,7094.8679999999995,7087.124,7079.38,7071.635999999999,7063.891999999999,7056.148,7048.4039999999995,7040.66,7032.916,7025.1720000000005,7017.427999999999,7009.683999999999,7001.9400000000005,6994.196000000001,6986.451999999999,6978.708,6970.964,6963.219999999998,6955.475999999999,6947.732,6939.988,6932.244,6924.5,6915.311333333333,6906.122666666666,6896.933999999999,6887.745333333332,6878.556666666667,6869.3679999999995,6860.1793333333335,6850.990666666667,6841.802,6832.613333333334,6823.424666666667,6814.236,6805.047333333333,6795.858666666666,6786.669999999999,6777.481333333334,6768.292666666666,6759.103999999999,6749.915333333333,6740.7266666666665,6731.5380000000005,6722.349333333334,6713.160666666667,6703.972,6694.783333333333,6685.594666666666,6676.406,6667.217333333333,6658.028666666666,6648.84,6639.651333333332,6630.462666666667,6621.274,6612.085333333333,6602.8966666666665,6593.708,6584.519333333333,6575.330666666667,6566.142,6556.953333333333,6547.764666666667,6538.575999999999,6529.387333333332,6520.198666666667,6511.01,6501.821333333333,6492.632666666666,6483.4439999999995,6474.2553333333335,6465.066666666667,6454.352666666666,6443.638666666667,6432.924666666667,6422.210666666666,6411.496666666667,6400.782666666666,6390.068666666666,6379.354666666667,6368.640666666666,6357.926666666666,6347.212666666667,6336.498666666666,6325.784666666666,6315.0706666666665,6304.356666666667,6293.642666666667,6282.928666666666,6272.214666666667,6261.500666666666,6250.786666666666,6240.072666666667,6229.358666666667,6218.644666666665,6207.930666666667,6197.216666666666,6186.502666666666,6175.788666666666,6165.074666666666,6154.3606666666665,6143.646666666667,6132.932666666667,6122.218666666666,6111.504666666667,6100.790666666667,6090.076666666667,6079.362666666667,6068.648666666667,6057.934666666666,6047.220666666666,6036.506666666666,6025.792666666666,6015.078666666665,6004.364666666667,5993.6506666666655,5982.9366666666665,5972.222666666666,5961.508666666667,5950.794666666666,5940.080666666666,5929.366666666667,5919.65,5909.9333333333325,5900.216666666667,5890.5,5880.783333333333,5871.066666666667,5861.349999999999,5851.633333333333,5841.916666666667,5832.2,5822.483333333333,5812.766666666666,5803.049999999999,5793.333333333333,5783.616666666667,5773.9,5764.1833333333325,5754.466666666666,5744.75,5735.033333333333,5725.316666666667,5715.599999999999,5705.883333333333,5696.166666666667,5686.45,5676.733333333334,5667.016666666666,5657.299999999999,5647.583333333333,5637.866666666667,5628.15,5618.433333333333,5608.716666666666,5598.999999999999,5589.283333333334,5579.566666666667,5569.849999999999,5560.133333333333,5550.416666666666,5540.7,5530.983333333334,5521.266666666666,5511.549999999999,5501.833333333333,5492.116666666666,5482.4,5472.683333333333,5462.966666666666,5453.25,5443.533333333333};
    convert I_em from MtCO2 to PgC
    for (int i = 0; i<CO2_em.size(); i++)
    {
        CO2_em[i] = (12.0/48.0)*CO2_em[i]/1000.0;
    }*/
    
    HFC125_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.05544628,0.057318506,0.059192895,0.061069449000000005,0.062948171,0.064829061,0.066712124,0.068597361,0.070484772,0.072374362,0.018814426999999998,0.066288365,0.07359413299999999,0.073496743,0.018263078000000002,-0.080681159,0.075292049,0.17780496,0.18118326,0.18829422,0.18594167,0.19092079,0.28889991,0.3768163,1.8251047999999999,2.9802177000000003,3.4188812000000004,5.354049,7.2031812,8.1531677,8.5381,9.0301,9.8852,12.0788,12.5073,13.7591,17.9373,22.1104,26.273033,30.435667,34.5983,37.80811,41.017920000000004,44.22773,47.437540000000006,50.64735,53.85716,57.06697,60.27678,63.48659,66.6964,67.92232,69.14824,70.37416,71.60008,72.826,74.05192,75.27784,76.50376,77.72968,78.9556,81.08502,83.21444,85.34385999999999,87.47328,89.6027,91.73212,93.86154,95.99096,98.12038000000001,100.2498,101.83830999999999,103.42681999999999,105.01533,106.60383999999999,108.19235,109.78086,111.36936999999999,112.95788,114.54638999999999,116.1349,117.32942,118.52394,119.71846000000001,120.91298,122.1075,123.30202,124.49654,125.69106000000001,126.88558,128.0801,129.34351999999998,130.60693999999998,131.87036,133.13378,134.3972,135.66062,136.92404,138.18746000000002,139.45088,140.7143,141.11548,141.51666,141.91783999999998,142.31902,142.7202,143.12138000000002,143.52256,143.92373999999998,144.32492,144.7261,145.0082,145.2903,145.5724,145.8545,146.1366,146.4187,146.7008,146.9829,147.265,147.5471,147.62282,147.69853999999998,147.77426,147.84998000000002,147.9257,148.00142,148.07713999999999,148.15286,148.22858,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.3043,148.35837,148.41245,148.46652,148.5206,148.57467,148.62875,148.68282,148.7369,148.79097,148.84503999999998,148.89911999999998,148.95318999999998,149.00727,149.06134,149.11542,149.16949,149.22357,149.27764,149.33172,149.38579,149.43986,149.49393999999998,149.54801,149.60209,149.65616,149.71024,149.76431000000002,149.81839,149.87246000000002,149.92653,149.98061,150.03468,150.08876,150.14283,150.19691,150.25098,150.30506,150.35913,150.41321000000002,150.46728000000002,150.52135,150.57543,150.6295,150.68358,150.73765,150.79173,150.8458,150.89988,150.95395,151.00802,151.0621,151.11616999999998,151.17025,151.22432,151.2784,151.33247,151.38655,151.44062,151.49469,151.54877,151.60284,151.65691999999999,151.71098999999998,151.76507,151.81914,151.87322,151.92729,151.98137,152.03544,152.08951000000002,152.14359,152.19766,152.25173999999998,152.30581,152.35988999999998,152.41396,152.46804,152.52211,152.57618,152.63026000000002,152.68433000000002,152.73841000000002,152.79248,152.84656,152.90063,152.95471,153.00878,153.06286,153.11693,153.171,153.22508,153.27915,153.33323000000001,153.3873,153.44138,153.49545,153.54953,153.6036,153.9761,153.9867,154.00076,154.01482,154.02888000000002,154.04294,154.057,154.07282,154.08864,154.10446000000002,154.12028,154.1361,154.15268999999998,154.16929,154.18588,154.20247,154.21907,154.23566,154.25225,154.26885,154.28544,154.30203,154.31863,154.33522,154.35181,154.36841,154.385,154.39988,154.41477,154.42965,154.44454,154.45942,154.4743,154.48918999999998,154.50406999999998,154.51896000000002,154.53384,154.54872,154.56361,154.57849,154.59338,154.60826,154.62313999999998,154.63803000000001,154.65291000000002,154.6678,154.68268,154.69756,154.71245,154.72733,154.74222,154.7571,154.76946,154.78181999999998,154.79419,154.80655,154.81891000000002,154.83127,154.84363000000002,154.856,154.86836,154.88072,154.89308,154.90544,154.91781,154.93017,154.94253,154.95488999999998,154.96725,154.97961999999998,154.99198,155.00433999999998,155.0167,155.02906000000002,155.04143,155.05379,155.06615,155.07851000000002,155.09087,155.10324,155.1156,155.12796,155.14032,155.15268,155.16505,155.17741,155.18976999999998,155.20213,155.21448999999998,155.22686000000002,155.23922,155.25158000000002,155.26394,155.2763,155.28867,155.30103,155.31339,155.32575,155.33811,155.35048,155.36283999999998,155.3752,155.3854,155.39561,155.40581,155.41602,155.42622,155.43642,155.44663,155.45683,155.46704,155.47724,155.48744,155.49765,155.50785,155.51806000000002,155.52826000000002,155.53846000000001,155.54867,155.55886999999998,155.56908,155.57928,155.58948,155.59968999999998,155.60988999999998,155.6201,155.6303,155.6405,155.65071,155.66091,155.67112,155.68132,155.69152,155.70173,155.71193,155.72214,155.73234,155.74254,155.75275,155.76295,155.77316000000002,155.78336000000002,155.79356,155.80377,155.81396999999998,155.82418,155.83438,155.84458,155.85478999999998,155.86498999999998,155.8752,155.8854,155.89417,155.90294,155.91171,155.92048,155.92925,155.93802,155.94679,155.95556000000002,155.96433000000002,155.9731,155.98187,155.99063999999998,155.99941,156.00818,156.01695,156.02572,156.03448999999998,156.04326,156.05203,156.0608,156.06957,156.07834,156.08711,156.09588,156.10465,156.11342,156.12219,156.13096000000002,156.13973000000001,156.1485,156.15726999999998,156.16603999999998,156.17481,156.18358,156.19235,156.20112,156.20989,156.21866,156.22743,156.2362,156.24497,156.25374,156.26251000000002,156.27128000000002,156.28005,156.28882,156.29758999999999,156.30636,156.31513,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239,156.3239};
    HFC134a_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.94505787,1.0101542,2.1776447999999995,4.2079892,8.4161579,21.399077,29.726101,40.584859,50.643567,59.652126,67.04399699999999,75.0393,84.0409,94.7161,101.4157,113.9297,120.9334,121.0746,129.6223,137.2526,144.8829,152.5132,163.76989,175.02658,186.28327,197.53996,208.79665,220.05334,231.31002999999998,242.56672000000003,253.82341,265.0801,271.95968999999997,278.83928,285.71887000000004,292.59846,299.47805,306.35764,313.23722999999995,320.11682,326.99641,333.876,341.18467999999996,348.49336,355.80204,363.11072,370.4194,377.72808,385.03676,392.34544,399.65412000000003,406.9628,412.75678999999997,418.55078,424.34477000000004,430.13876,435.93275,441.72674000000006,447.52072999999996,453.31472,459.10871,464.9027,469.21826,473.53382,477.84938,482.16494000000006,486.4805,490.79605999999995,495.11162,499.42717999999996,503.74274,508.0583,512.72379,517.38928,522.05477,526.7202599999999,531.38575,536.05124,540.71673,545.3822200000001,550.0477099999999,554.7132,559.74698,564.78076,569.8145400000001,574.8483200000001,579.8821,584.91588,589.94966,594.9834400000001,600.0172200000001,605.051,609.85911,614.66722,619.47533,624.28344,629.09155,633.8996599999999,638.70777,643.5158799999999,648.32399,653.1321,658.16476,663.19742,668.2300799999999,673.26274,678.2954,683.3280599999999,688.36072,693.39338,698.4260400000001,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.4587,703.6218200000001,703.78494,703.9480599999999,704.11118,704.2743,704.43742,704.60054,704.76366,704.92678,705.0899,705.25302,705.41614,705.5792700000001,705.74239,705.9055099999999,706.06863,706.23175,706.39487,706.55799,706.72111,706.88423,707.04735,707.21047,707.37359,707.53671,707.69983,707.86295,708.02607,708.18919,708.35231,708.51543,708.67855,708.84167,709.0047900000001,709.16791,709.3310299999999,709.49416,709.65728,709.8204,709.98352,710.14664,710.30976,710.47288,710.636,710.79912,710.9622400000001,711.12536,711.2884799999999,711.4516,711.61472,711.7778400000001,711.94096,712.10408,712.2672,712.43032,712.59344,712.7565599999999,712.91968,713.0828,713.2459200000001,713.40904,713.57217,713.7352900000001,713.89841,714.06153,714.22465,714.38777,714.55089,714.7140099999999,714.87713,715.04025,715.2033700000001,715.36649,715.5296099999999,715.69273,715.85585,716.01897,716.18209,716.34521,716.50833,716.67145,716.83457,716.99769,717.16081,717.32393,717.4870599999999,717.65018,717.8133,717.97642,718.13954,718.30266,718.46578,718.6289,718.79202,718.95514,719.11826,719.28138,719.4445,720.2033,720.2524,720.3181599999999,720.38392,720.44968,720.51544,720.5812,720.65512,720.72904,720.80296,720.87688,720.9508,721.02846,721.10612,721.18378,721.26144,721.3391,721.41676,721.49442,721.57208,721.6497400000001,721.7274,721.8050599999999,721.8827200000001,721.96038,722.03804,722.1157,722.18528,722.25487,722.32445,722.39404,722.46362,722.5332,722.60279,722.67237,722.74196,722.81154,722.88112,722.95071,723.02029,723.08988,723.15946,723.22904,723.29863,723.36821,723.4378,723.50738,723.57696,723.64655,723.71613,723.78572,723.8553,723.91314,723.97097,724.0288099999999,724.08664,724.1444799999999,724.20232,724.26015,724.31799,724.37582,724.4336599999999,724.4915,724.5493299999999,724.60717,724.665,724.72284,724.78068,724.8385099999999,724.89635,724.95418,725.01202,725.06986,725.12769,725.18553,725.2433599999999,725.3012,725.35904,725.41687,725.47471,725.53254,725.59038,725.64822,725.70605,725.7638900000001,725.82172,725.87956,725.9374,725.99523,726.05307,726.1109,726.1687400000001,726.22658,726.28441,726.34225,726.40008,726.4579200000001,726.51576,726.5735900000001,726.63143,726.68926,726.7471,726.7948299999999,726.8425599999999,726.89028,726.93801,726.9857400000001,727.03347,727.0812,727.12892,727.17665,727.22438,727.27211,727.31984,727.3675599999999,727.41529,727.46302,727.51075,727.55848,727.6062,727.65393,727.70166,727.7493900000001,727.7971200000001,727.8448400000001,727.89257,727.9403,727.98803,728.03576,728.08348,728.13121,728.17894,728.22667,728.2744,728.32212,728.36985,728.4175799999999,728.4653099999999,728.51304,728.56076,728.6084900000001,728.65622,728.70395,728.75168,728.7994,728.84713,728.89486,728.94259,728.99032,729.03804,729.08577,729.1335,729.1745099999999,729.21552,729.25653,729.29754,729.33855,729.37956,729.42057,729.46158,729.50259,729.5436,729.58461,729.62562,729.6666299999999,729.7076400000001,729.74865,729.7896599999999,729.83067,729.87168,729.91269,729.9537,729.9947099999999,730.03572,730.07673,730.11774,730.15875,730.19976,730.24077,730.28178,730.32279,730.3638,730.40481,730.44582,730.4868299999999,730.5278400000001,730.56885,730.6098599999999,730.65087,730.69188,730.73289,730.7739,730.8149099999999,730.85592,730.89693,730.93794,730.97895,731.01996,731.06097,731.10198,731.14299,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184,731.184};
    HFC143a_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.35640391,0.36316592,0.36993573,0.37671337,0.38349883,0.39029213,0.39709328,0.40390227,0.05429956,0.054330947000000004,0.76720931,0.78079292,0.081528294,0.79436576,0.80794309,0.10867413,0.82150728,1.5479208999999998,0.86222749,0.87579234,0.88920979,0.90261206,1.6286536,2.3685965,3.8347584,6.0409628,6.149987599999999,6.2587493,6.3676829,6.477524900000001,6.234,7.4947,8.7389,9.9776,11.2136,12.4483,15.3186,18.1628,20.954333,23.745867,26.5374,27.390320000000003,28.243240000000004,29.096159999999998,29.94908,30.802,31.65492,32.50784,33.36076,34.21368,35.0666,35.3783,35.69,36.0017,36.3134,36.6251,36.9368,37.2485,37.5602,37.8719,38.1836,38.94891,39.714220000000005,40.47953,41.24484,42.01015,42.775459999999995,43.54077,44.30608,45.07139,45.8367,46.27373,46.71076,47.14779,47.58482,48.02185,48.45888,48.89591,49.33294,49.76997,50.207,50.428709999999995,50.650420000000004,50.87213,51.09384,51.31555,51.537259999999996,51.75897,51.98068,52.20239,52.4241,52.64359,52.863080000000004,53.08257,53.30206,53.52155,53.741040000000005,53.960530000000006,54.18001999999999,54.39951,54.619,54.42783000000001,54.23666,54.04549,53.854319999999994,53.66315,53.47198,53.280809999999995,53.08964,52.898469999999996,52.7073,52.45431,52.20132,51.94833,51.69534,51.44235,51.18936,50.936370000000004,50.68338,50.43039,50.1774,49.84386,49.51032,49.17678,48.84324,48.5097,48.176159999999996,47.842620000000004,47.50908,47.175540000000005,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.842,46.859673,46.877347,46.89502,46.912694,46.930367,46.948040999999996,46.965714,46.983388,47.001061,47.018735,47.036408,47.054082,47.071754999999996,47.089428999999996,47.107102000000005,47.124776000000004,47.142449,47.160121999999994,47.177796,47.195469,47.213143,47.230816,47.248490000000004,47.266163,47.283837,47.30151,47.319184,47.336857,47.354531,47.372203999999996,47.389878,47.407551,47.425224,47.442898,47.460571,47.478245,47.495917999999996,47.513591999999996,47.531265000000005,47.548939000000004,47.566612,47.584286,47.601959,47.619633,47.637306,47.65498,47.672653000000004,47.690327,47.708,47.725673,47.743347,47.76102,47.778694,47.796367,47.814040999999996,47.831714,47.849388,47.867061,47.884735,47.902408,47.920082,47.937754999999996,47.955428999999995,47.973102000000004,47.990776000000004,48.008449,48.026121999999994,48.043796,48.061469,48.079143,48.096816,48.11449,48.132163,48.149837,48.16751,48.185184,48.202857,48.220531,48.238203999999996,48.255878,48.273551,48.291224,48.308898,48.326571,48.344245,48.361918,48.379591999999995,48.397265000000004,48.414939000000004,48.432612,48.450286,48.467959,48.485633,48.503306,48.52098,48.538653000000004,48.556327,48.574,48.7474,48.7506,48.75506,48.75952,48.76398,48.768440000000005,48.7729,48.77792,48.78294,48.78796,48.79298,48.798,48.803253000000005,48.808507,48.813759999999995,48.819013,48.824267,48.82952,48.834773,48.840027,48.845279999999995,48.850533,48.855787,48.86104,48.866293,48.871547,48.8768,48.881508000000004,48.886216,48.890924,48.895632,48.90034,48.905048,48.909756,48.914464,48.919171999999996,48.92388,48.928588,48.933296,48.938004,48.942712,48.94742,48.952128,48.956835999999996,48.961544,48.966252000000004,48.97096,48.975668,48.980376,48.985084,48.989792,48.9945,48.998416,49.002332,49.006248,49.010164,49.01408,49.017996000000004,49.021912,49.025828000000004,49.029744,49.03366,49.037576,49.041492,49.045408,49.049324,49.05324,49.057156,49.061071999999996,49.064988,49.068903999999996,49.07282,49.076736,49.080652,49.084568,49.088484,49.0924,49.096315999999995,49.100232,49.104147999999995,49.108064,49.111979999999996,49.115896,49.119811999999996,49.123728,49.127644000000004,49.13156,49.135476000000004,49.139392,49.143308000000005,49.147224,49.151140000000005,49.155056,49.158972,49.162888,49.166804,49.17072,49.174636,49.178552,49.182468,49.186384000000004,49.1903,49.193529999999996,49.19676,49.19999,49.20322,49.20645,49.20968,49.21291,49.21614,49.21937,49.2226,49.22583,49.22906,49.23229,49.23552,49.23875,49.24198,49.24521,49.24844,49.251670000000004,49.2549,49.25813,49.261359999999996,49.264590000000005,49.26782,49.27105,49.27428,49.27751,49.28074,49.283970000000004,49.2872,49.29043,49.293659999999996,49.296890000000005,49.30012,49.30335,49.30658,49.30981,49.31304,49.31627,49.3195,49.32273,49.325959999999995,49.329190000000004,49.33242,49.33565,49.338879999999996,49.34211,49.34534,49.34857,49.3518,49.354576,49.357352,49.360128,49.362904,49.36568,49.368456,49.371232,49.374008,49.376784,49.37956,49.382335999999995,49.385112,49.387888000000004,49.390664,49.393440000000005,49.396215999999995,49.398992,49.401768,49.404544,49.40732,49.410096,49.412872,49.415648,49.418424,49.4212,49.423976,49.426752,49.429528000000005,49.432303999999995,49.43508,49.437856,49.440632,49.443408000000005,49.446184,49.44896,49.451736,49.454512,49.457288,49.460064,49.46284,49.465616,49.468392,49.471168,49.473944,49.47672,49.479496000000005,49.482271999999995,49.485048,49.487823999999996,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906,49.4906};
    HFC227ea_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0047100239000000006,0.004710028,0.18499007,0.1819901,0.099994794,0.43697783,0.40797848,0.92795208,1.3539299999999999,1.9509,1.6449,2.508,3.341,4.269,4.8901,6.2176,7.5465,8.8781,10.2097,11.5413,10.50312,9.464939999999999,8.42676,7.38858,6.3504,5.31222,4.27404,3.2358599999999997,2.19768,1.1595,1.1041100000000001,1.04872,0.99333,0.93794,0.88255,0.82716,0.77177,0.71638,0.66099,0.6056,0.6214,0.6372,0.653,0.6688,0.6846,0.7004,0.7162,0.732,0.7478,0.7636,0.71926,0.67492,0.63058,0.58624,0.5419,0.49756,0.45322,0.40888,0.36454,0.3202,0.30297,0.28574,0.26851,0.25128,0.23405,0.21682,0.19959,0.18236,0.16513,0.1479,0.146,0.1441,0.1422,0.1403,0.1384,0.1365,0.1346,0.1327,0.1308,0.1289,0.12734,0.12578,0.12422,0.12266,0.1211,0.11954,0.11798,0.11642,0.11486,0.1133,0.11214,0.11098,0.10982,0.10866,0.1075,0.10634,0.10518,0.10402,0.10286,0.1017,0.10064,0.09958,0.09852,0.09746,0.0964,0.09534,0.09428,0.09322,0.09216,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.0911,0.091385714,0.091671429,0.091957143,0.092242857,0.09252857099999999,0.092814286,0.0931,0.09338571400000001,0.093671429,0.093957143,0.094242857,0.09452857099999999,0.094814286,0.0951,0.09538571400000001,0.095671429,0.09595714300000001,0.09624285699999999,0.096528571,0.096814286,0.0971,0.097385714,0.097671429,0.09795714300000001,0.09824285699999999,0.098528571,0.098814286,0.0991,0.099385714,0.099671429,0.09995714300000001,0.10024286,0.10052857,0.10081429,0.1011,0.10138571,0.10167143,0.10195714,0.10224286,0.10252857,0.10281429,0.1031,0.10338571,0.10367143,0.10395714,0.10424286,0.10452857,0.10481429,0.1051,0.10538571,0.10567143,0.10595714,0.10624286,0.10652857,0.10681429,0.1071,0.10738571,0.10767143,0.10795714,0.10824286,0.10852857,0.10881429,0.1091,0.10938571,0.10967143,0.10995714,0.11024286,0.11052857,0.11081429,0.1111,0.11138571,0.11167143,0.11195714,0.11224286,0.11252857,0.11281429,0.1131,0.11338571,0.11367143,0.11395714,0.11424286,0.11452857,0.11481429,0.1151,0.11538571,0.11567143,0.11595714,0.11624286,0.11652857,0.11681429,0.1171,0.11738571,0.11767143,0.11795714,0.11824286,0.11852857,0.11881429,0.1191,0.1179,0.1179,0.1179,0.1179,0.1179,0.1179,0.1179,0.11794,0.11798,0.11802,0.11806,0.1181,0.11810667,0.11811333,0.11812,0.11812667,0.11813333,0.11814,0.11814667,0.11815333,0.11816,0.11816667,0.11817333,0.11818,0.11818667,0.11819333,0.1182,0.118216,0.118232,0.118248,0.118264,0.11828,0.118296,0.118312,0.118328,0.118344,0.11836,0.118376,0.118392,0.118408,0.118424,0.11844,0.118456,0.118472,0.118488,0.118504,0.11852,0.118536,0.118552,0.118568,0.118584,0.1186,0.118608,0.118616,0.118624,0.118632,0.11864,0.118648,0.118656,0.118664,0.118672,0.11868,0.118688,0.118696,0.118704,0.118712,0.11872,0.118728,0.118736,0.118744,0.118752,0.11876,0.118768,0.118776,0.118784,0.118792,0.1188,0.118808,0.118816,0.118824,0.118832,0.11884,0.118848,0.118856,0.118864,0.118872,0.11888,0.118888,0.118896,0.118904,0.118912,0.11892,0.118928,0.118936,0.118944,0.118952,0.11896,0.118968,0.118976,0.118984,0.118992,0.119,0.119008,0.119016,0.119024,0.119032,0.11904,0.119048,0.119056,0.119064,0.119072,0.11908,0.119088,0.119096,0.119104,0.119112,0.11912,0.119128,0.119136,0.119144,0.119152,0.11916,0.119168,0.119176,0.119184,0.119192,0.1192,0.119208,0.119216,0.119224,0.119232,0.11924,0.119248,0.119256,0.119264,0.119272,0.11928,0.119288,0.119296,0.119304,0.119312,0.11932,0.119328,0.119336,0.119344,0.119352,0.11936,0.119368,0.119376,0.119384,0.119392,0.1194,0.119406,0.119412,0.119418,0.119424,0.11943,0.119436,0.119442,0.119448,0.119454,0.11946,0.119466,0.119472,0.119478,0.119484,0.11949,0.119496,0.119502,0.119508,0.119514,0.11952,0.119526,0.119532,0.119538,0.119544,0.11955,0.119556,0.119562,0.119568,0.119574,0.11958,0.119586,0.119592,0.119598,0.119604,0.11961,0.119616,0.119622,0.119628,0.119634,0.11964,0.119646,0.119652,0.119658,0.119664,0.11967,0.119676,0.119682,0.119688,0.119694,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197,0.1197};
    HFC23_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.74681988,0.067690547,0.073576745,0.07997479099999999,0.08692919699999999,0.09448834,0.10270482,0.11163575,0.12134333,0.13189502,0.14336429,0.15583315,0.16938647,0.18411857,0.20013198,0.21753811,0.23645812,0.25702368,0.27937786,0.30367628,0.33008802,0.35878218,0.38997068,0.42387036,0.4607169,0.5007665,0.54429755,0.5916127,0.64304094,0.69893975,0.75969781,0.82576341,0.8975743,0.97563006,1.0604738,1.1526958,1.2529377,1.361897,1.4803316999999998,1.6090657,1.7489948,1.901128,2.066494,2.2462442000000005,2.4416297,2.6540105,2.8848647,3.5660803999999997,3.7964008000000002,4.0275411,4.2595023,4.4921574,4.7256142,4.959872900000001,5.1949332,5.4307947,5.6674573,5.9049208,6.1431847,6.3822491999999995,6.621823299999999,6.8621776,7.102985,7.3453102,7.588207000000001,10.211528,10.248182,10.284399,10.320704,10.357655000000001,10.3949,10.4328,10.4708,10.5083,10.5454,10.8116,10.5529,10.2947,10.037233,9.779766699999998,9.5223,8.685310000000001,7.848319999999999,7.01133,6.17434,5.33735,4.50036,3.6633699999999996,2.82638,1.9893900000000002,1.1524,1.1063,1.0602,1.0141,0.968,0.9219,0.8758,0.8297,0.7836,0.7375,0.6914,0.66362,0.63584,0.60806,0.58028,0.5525,0.52472,0.49694,0.46916,0.44138,0.4136,0.39687,0.38014,0.36341,0.34668,0.32995,0.31322,0.29649,0.27976,0.26303,0.2463,0.23542,0.22454,0.21366,0.20278,0.1919,0.18102,0.17014,0.15926,0.14838,0.1375,0.13105,0.1246,0.11815,0.1117,0.10525,0.0988,0.09235,0.0859,0.07945,0.073,0.06942,0.06584,0.06226,0.05868,0.0551,0.05152,0.04794,0.04436,0.04078,0.0372,0.03348,0.02976,0.02604,0.02232,0.0186,0.01488,0.01116,0.00744,0.00372,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0071469388,0.014293878000000001,0.021440816,0.028587755,0.035734694,0.042881632999999995,0.050028570999999994,0.05717551,0.064322449,0.071469388,0.078616327,0.085763265,0.09291020400000001,0.10005714,0.10720408,0.11435102,0.12149796,0.1286449,0.13579184,0.14293878,0.15008571,0.15723265,0.16437959,0.17152653,0.17867347,0.18582041,0.19296735,0.20011429,0.20726122,0.21440816,0.2215551,0.22870204,0.23584898,0.24299592,0.25014286,0.2572898,0.26443673,0.27158367,0.27873061,0.28587755,0.29302449,0.30017143,0.30731837,0.31446531,0.32161224,0.32875918,0.33590612,0.34305306,0.3502,0.35734694,0.36449388,0.37164082,0.37878776,0.38593469,0.39308163,0.40022857,0.40737551,0.41452245,0.42166939,0.42881633,0.43596327,0.4431102,0.45025714,0.45740408,0.46455102,0.47169796,0.4788449,0.48599184,0.49313878,0.50028571,0.50743265,0.51457959,0.52172653,0.52887347,0.53602041,0.54316735,0.55031429,0.55746122,0.56460816,0.5717551,0.57890204,0.58604898,0.59319592,0.60034286,0.6074898,0.61463673,0.62178367,0.62893061,0.63607755,0.64322449,0.65037143,0.65751837,0.66466531,0.67181224,0.67895918,0.68610612,0.69325306,0.7004,0.7033,0.7033,0.70338,0.70346,0.70354,0.70362,0.7037,0.70376,0.70382,0.70388,0.70394,0.704,0.70407333,0.70414667,0.70422,0.70429333,0.70436667,0.70444,0.70451333,0.70458667,0.70466,0.70473333,0.70480667,0.70488,0.70495333,0.70502667,0.7051,0.705172,0.705244,0.705316,0.705388,0.70546,0.705532,0.705604,0.705676,0.705748,0.70582,0.705892,0.705964,0.706036,0.706108,0.70618,0.706252,0.706324,0.706396,0.706468,0.70654,0.706612,0.706684,0.706756,0.706828,0.7069,0.706956,0.707012,0.707068,0.707124,0.70718,0.707236,0.707292,0.707348,0.707404,0.70746,0.707516,0.707572,0.707628,0.707684,0.70774,0.707796,0.707852,0.707908,0.707964,0.70802,0.708076,0.708132,0.708188,0.708244,0.7083,0.708356,0.708412,0.708468,0.708524,0.70858,0.708636,0.708692,0.708748,0.708804,0.70886,0.708916,0.708972,0.709028,0.709084,0.70914,0.709196,0.709252,0.709308,0.709364,0.70942,0.709476,0.709532,0.709588,0.709644,0.7097,0.709744,0.709788,0.709832,0.709876,0.70992,0.709964,0.710008,0.710052,0.710096,0.71014,0.710184,0.710228,0.710272,0.710316,0.71036,0.710404,0.710448,0.710492,0.710536,0.71058,0.710624,0.710668,0.710712,0.710756,0.7108,0.710844,0.710888,0.710932,0.710976,0.71102,0.711064,0.711108,0.711152,0.711196,0.71124,0.711284,0.711328,0.711372,0.711416,0.71146,0.711504,0.711548,0.711592,0.711636,0.71168,0.711724,0.711768,0.711812,0.711856,0.7119,0.711942,0.711984,0.712026,0.712068,0.71211,0.712152,0.712194,0.712236,0.712278,0.71232,0.712362,0.712404,0.712446,0.712488,0.71253,0.712572,0.712614,0.712656,0.712698,0.71274,0.712782,0.712824,0.712866,0.712908,0.71295,0.712992,0.713034,0.713076,0.713118,0.71316,0.713202,0.713244,0.713286,0.713328,0.71337,0.713412,0.713454,0.713496,0.713538,0.71358,0.713622,0.713664,0.713706,0.713748,0.71379,0.713832,0.713874,0.713916,0.713958,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714,0.714};
    HFC245fa_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,17.9257,19.7183,21.5109,23.3035,25.096,26.8885,38.6318,50.375,62.118267,73.861533,85.6048,91.86659,98.12838,104.39017,110.65196,116.91375,123.17553999999998,129.43733,135.69912,141.96091,148.2227,152.77696,157.33122,161.88548,166.43974,170.994,175.54826,180.10252,184.65678,189.21104,193.7653,192.50583999999998,191.24638000000002,189.98692,188.72746,187.468,186.20854,184.94908,183.68962,182.43016,181.1707,179.22468999999998,177.27868,175.33267,173.38666,171.44065,169.49464,167.54863,165.60262,163.65661,161.7106,160.45046000000002,159.19031999999999,157.93018,156.67004,155.4099,154.14976000000001,152.88962,151.62948,150.36934,149.1092,147.84735,146.5855,145.32365,144.0618,142.79995,141.5381,140.27625,139.0144,137.75255,136.4907,135.66527,134.83983999999998,134.01441,133.18898000000002,132.36355,131.53812,130.71268999999998,129.88726,129.06183000000001,128.2364,127.43725,126.6381,125.83895,125.0398,124.24065,123.4415,122.64235,121.8432,121.04405,120.2449,121.40096000000001,122.55702,123.71308,124.86913999999999,126.0252,127.18126000000001,128.33732,129.49338,130.64944,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.8055,131.82622,131.84693000000001,131.86765,131.88837,131.90908000000002,131.9298,131.95051,131.97123,131.99195,132.01266,132.03338,132.0541,132.07481,132.09553,132.11624,132.13696000000002,132.15768,132.17838999999998,132.19911000000002,132.21983,132.24053999999998,132.26126000000002,132.28198,132.30268999999998,132.32341,132.34412,132.36484,132.38556,132.40627,132.42699,132.44771,132.46842,132.48914,132.50986,132.53056999999998,132.55129,132.572,132.59271999999999,132.61344,132.63415,132.65487,132.67559,132.6963,132.71702,132.73773,132.75845,132.77917,132.79988,132.8206,132.84132,132.86203,132.88275,132.90347,132.92418,132.9449,132.96561,132.98633,133.00705,133.02776,133.04848,133.0692,133.08991,133.11063000000001,133.13134,133.15206,133.17278000000002,133.19349,133.21421,133.23493,133.25564,133.27636,133.29708,133.31779,133.33851,133.35922,133.37994,133.40066000000002,133.42137,133.44208999999998,133.46281000000002,133.48352,133.50423999999998,133.52496000000002,133.54567,133.56638999999998,133.5871,133.60782,133.62854,133.64925,133.66997,133.69069,133.7114,133.73212,133.75283000000002,133.77355,133.79426999999998,133.81498,133.8357,133.8876,133.8969,133.90908000000002,133.92126000000002,133.93344,133.94562,133.9578,133.97158000000002,133.98536000000001,133.99913999999998,134.01292,134.0267,134.04113,134.05557,134.07,134.08443,134.09887,134.1133,134.12773,134.14217,134.1566,134.17103,134.18547,134.1999,134.21433000000002,134.22877,134.2432,134.25614,134.26907,134.28201,134.29494,134.30788,134.32082,134.33375,134.34669,134.35962,134.37256000000002,134.3855,134.39843,134.41137,134.4243,134.43724,134.45018000000002,134.46311,134.47605,134.48898,134.50191999999998,134.51486,134.52778999999998,134.54073,134.55366,134.5666,134.57735,134.58811,134.59886,134.60962,134.62037,134.63111999999998,134.64188000000001,134.65263000000002,134.66339,134.67414,134.68489,134.69565,134.7064,134.71716,134.72791,134.73866,134.74942,134.76017,134.77093,134.78168,134.79243,134.80319,134.81394,134.8247,134.83545,134.8462,134.85696000000002,134.86771000000002,134.87847,134.88922,134.89997,134.91073,134.92148,134.93223999999998,134.94298999999998,134.95373999999998,134.9645,134.97525,134.98601000000002,134.99676000000002,135.00751,135.01827,135.02902,135.03978,135.05053,135.06128,135.07204,135.08279,135.09355,135.1043,135.11317,135.12204,135.13092,135.13978999999998,135.14866,135.15753,135.1664,135.17528000000001,135.18415,135.19302,135.20189,135.21076000000002,135.21964,135.22851,135.23738,135.24625,135.25512,135.264,135.27286999999998,135.28173999999999,135.29061000000002,135.29948000000002,135.30836000000002,135.31723,135.3261,135.33497,135.34384,135.35272,135.36158999999998,135.37046,135.37933,135.3882,135.39708000000002,135.40595,135.41482,135.42369,135.43256,135.44144,135.45031,135.45918,135.46805,135.47692,135.4858,135.49466999999999,135.50354,135.51241000000002,135.52128000000002,135.53016000000002,135.53903,135.5479,135.55552,135.56314,135.57076999999998,135.57838999999998,135.58601000000002,135.59363000000002,135.60125,135.60888,135.6165,135.62412,135.63173999999998,135.63936,135.64699,135.65461000000002,135.66223,135.66985,135.67747,135.6851,135.69272,135.70033999999998,135.70796,135.71558000000002,135.72321000000002,135.73083,135.73845,135.74607,135.75368999999998,135.76131999999998,135.76894,135.77656000000002,135.78418,135.7918,135.79943,135.80705,135.81467,135.82228999999998,135.82991,135.83754,135.84516000000002,135.85278,135.8604,135.86802,135.87565,135.88326999999998,135.89088999999998,135.89851000000002,135.90613000000002,135.91376,135.92138,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929,135.929};
    HFC32_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.087305408,0.78573737,4.0,5.3987,6.7975,8.196,9.5947,10.9935,12.3831,13.7731,15.162767,16.552432999999997,17.9421,22.21208,26.482059999999997,30.75204,35.02202,39.292,43.56198,47.831959999999995,52.10194,56.371919999999996,60.6419,61.78125,62.9206,64.05995,65.1993,66.33865,67.478,68.61735,69.7567,70.89605,72.0354,72.90303,73.77065999999999,74.63829,75.50591999999999,76.37355,77.24118,78.10880999999999,78.97644,79.84407,80.7117,80.10127,79.49084,78.88041,78.26998,77.65955,77.04912,76.43869000000001,75.82826,75.21783,74.6074,75.55521999999999,76.50304,77.45085999999999,78.39868,79.3465,80.29432,81.24214,82.18996,83.13778,84.0856,85.06506,86.04451999999999,87.02398000000001,88.00344,88.9829,89.96236,90.94181999999999,91.92128000000001,92.90074,93.8802,94.1193,94.3584,94.5975,94.8366,95.0757,95.3148,95.5539,95.793,96.0321,96.2712,95.76444000000001,95.25768000000001,94.75092,94.24416,93.7374,93.23064000000001,92.72388000000001,92.21712,91.71036,91.2036,90.20593000000001,89.20826,88.21059,87.21292,86.21525,85.21758,84.21991,83.22224,82.22457,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.2269,81.237246,81.247592,81.257938,81.268284,81.27863,81.288976,81.29932099999999,81.309667,81.320013,81.330359,81.340705,81.351051,81.361397,81.37174300000001,81.38208900000001,81.39243499999999,81.402781,81.413127,81.423472,81.433818,81.444164,81.45451,81.46485600000001,81.475202,81.485548,81.49589399999999,81.50624,81.516586,81.52693199999999,81.537278,81.547623,81.557969,81.568315,81.578661,81.589007,81.59935300000001,81.60969899999999,81.62004499999999,81.630391,81.640737,81.651083,81.661429,81.671774,81.68212,81.69246600000001,81.702812,81.71315799999999,81.723504,81.73385,81.744196,81.754542,81.764888,81.775234,81.78558000000001,81.795926,81.806271,81.81661700000001,81.826963,81.83730899999999,81.847655,81.858001,81.868347,81.878693,81.889039,81.899385,81.90973100000001,81.920077,81.930422,81.940768,81.951114,81.96146,81.971806,81.982152,81.992498,82.002844,82.01319000000001,82.023536,82.03388199999999,82.044228,82.054573,82.06491899999999,82.075265,82.085611,82.095957,82.106303,82.116649,82.126995,82.137341,82.147687,82.15803299999999,82.168379,82.178724,82.18907,82.199416,82.209762,82.220108,82.23045400000001,82.2408,82.2473,82.2527,82.26021999999999,82.26774,82.27526,82.28278,82.2903,82.29874000000001,82.30718,82.31562,82.32406,82.3325,82.341367,82.350233,82.3591,82.36796700000001,82.37683299999999,82.3857,82.39456700000001,82.40343299999999,82.4123,82.42116700000001,82.430033,82.4389,82.447767,82.456633,82.4655,82.473444,82.481388,82.48933199999999,82.497276,82.50522,82.513164,82.521108,82.52905200000001,82.536996,82.54494,82.55288399999999,82.560828,82.568772,82.576716,82.58466,82.59260400000001,82.600548,82.608492,82.616436,82.62438,82.632324,82.640268,82.648212,82.65615600000001,82.6641,82.67070600000001,82.677312,82.683918,82.690524,82.69713,82.70373599999999,82.710342,82.716948,82.72355400000001,82.73016,82.736766,82.743372,82.749978,82.756584,82.76319000000001,82.769796,82.776402,82.783008,82.789614,82.79621999999999,82.802826,82.809432,82.816038,82.822644,82.82925,82.835856,82.842462,82.849068,82.855674,82.86228,82.868886,82.87549200000001,82.882098,82.888704,82.89531,82.901916,82.90852199999999,82.915128,82.921734,82.92834,82.934946,82.941552,82.94815799999999,82.954764,82.96137,82.96797600000001,82.974582,82.981188,82.987794,82.9944,82.999852,83.00530400000001,83.010756,83.01620799999999,83.02166,83.027112,83.03256400000001,83.038016,83.043468,83.04892,83.054372,83.059824,83.065276,83.070728,83.07618000000001,83.081632,83.08708399999999,83.092536,83.097988,83.10344,83.108892,83.11434399999999,83.119796,83.125248,83.1307,83.136152,83.141604,83.147056,83.152508,83.15796,83.163412,83.168864,83.174316,83.17976800000001,83.18522,83.19067199999999,83.196124,83.201576,83.20702800000001,83.21248,83.21793199999999,83.223384,83.228836,83.234288,83.23974,83.245192,83.250644,83.256096,83.261548,83.267,83.271682,83.276364,83.28104599999999,83.285728,83.29041,83.29509200000001,83.299774,83.304456,83.309138,83.31381999999999,83.318502,83.323184,83.327866,83.332548,83.33723,83.341912,83.346594,83.351276,83.355958,83.36064,83.36532199999999,83.37000400000001,83.374686,83.379368,83.38405,83.38873199999999,83.393414,83.398096,83.402778,83.40746,83.412142,83.416824,83.42150600000001,83.426188,83.43087,83.435552,83.440234,83.444916,83.449598,83.45428000000001,83.458962,83.46364399999999,83.468326,83.473008,83.47769,83.482372,83.487054,83.491736,83.496418,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011,83.5011};
    HFC4310mee_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.6471,1.294,1.9411,2.5882,3.2351,3.8842,4.5338,5.1847667,5.8357333,6.4867,6.56469,6.64268,6.72067,6.798660000000001,6.87665,6.9546399999999995,7.03263,7.11062,7.188610000000001,7.2666,7.35248,7.43836,7.52424,7.610119999999999,7.696,7.78188,7.8677600000000005,7.953639999999999,8.03952,8.1254,8.22403,8.32266,8.421289999999999,8.519919999999999,8.61855,8.71718,8.81581,8.914439999999999,9.013069999999999,9.1117,9.23927,9.36684,9.49441,9.62198,9.74955,9.87712,10.00469,10.13226,10.259830000000001,10.3874,10.56431,10.74122,10.91813,11.09504,11.27195,11.44886,11.62577,11.80268,11.97959,12.1565,12.33644,12.51638,12.69632,12.87626,13.0562,13.236139999999999,13.41608,13.596020000000001,13.775960000000001,13.9559,14.18108,14.406260000000001,14.63144,14.856620000000001,15.0818,15.30698,15.532160000000001,15.75734,15.982520000000001,16.2077,16.48786,16.76802,17.04818,17.32834,17.6085,17.88866,18.16882,18.44898,18.72914,19.0093,19.2916,19.5739,19.8562,20.1385,20.4208,20.7031,20.9854,21.2677,21.55,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.8323,21.837794,21.843288,21.848782,21.854276000000002,21.859769,21.865263,21.870757,21.876251,21.881745000000002,21.887239,21.892733,21.898227,21.90372,21.909214000000002,21.914707999999997,21.920202,21.925696,21.93119,21.936684,21.942178,21.947671,21.953165,21.958659,21.964153,21.969647,21.975141,21.980635,21.986129000000002,21.991622,21.997116000000002,22.00261,22.008104,22.013598,22.019092,22.024586,22.030079999999998,22.035573,22.041067,22.046560999999997,22.052055,22.057548999999998,22.063043,22.068537,22.074031,22.079524,22.085017999999998,22.090512,22.096006,22.1015,22.106994,22.112488,22.117982,22.123476,22.128969,22.134463,22.139957,22.145451,22.150945,22.156439000000002,22.161932999999998,22.167427,22.17292,22.178414,22.183908,22.189401999999998,22.194896,22.20039,22.205884,22.211378,22.216870999999998,22.222365,22.227859,22.233353,22.238847,22.244341,22.249835,22.255329,22.260822,22.266316,22.271810000000002,22.277304,22.282798,22.288292000000002,22.293785999999997,22.29928,22.304773,22.310267,22.315761,22.321254999999997,22.326749,22.332243,22.337737,22.343231,22.348724,22.354218,22.359712,22.365206,22.3707,22.3987,22.4002,22.402260000000002,22.404320000000002,22.40638,22.40844,22.4105,22.412760000000002,22.415020000000002,22.417279999999998,22.419539999999998,22.4218,22.424220000000002,22.42664,22.42906,22.43148,22.4339,22.436320000000002,22.43874,22.44116,22.443579999999997,22.446,22.448420000000002,22.45084,22.45326,22.455679999999997,22.4581,22.460264000000002,22.462428,22.464592,22.466756,22.46892,22.471084,22.473248,22.475412,22.477576000000003,22.47974,22.481904,22.484068,22.486232,22.488395999999998,22.490560000000002,22.492724,22.494888,22.497052,22.499216,22.501379999999997,22.503544,22.505708,22.507872,22.510036,22.5122,22.514001999999998,22.515804,22.517606,22.519408,22.52121,22.523011999999998,22.524814000000003,22.526616,22.528418,22.53022,22.532022,22.533824,22.535626,22.537428,22.53923,22.541032,22.542834,22.544635999999997,22.546438000000002,22.54824,22.550042,22.551844,22.553646,22.555448000000002,22.55725,22.559051999999998,22.560854,22.562656,22.564458,22.56626,22.568062,22.569864000000003,22.571666,22.573468,22.57527,22.577072,22.578874,22.580676,22.582478,22.58428,22.586082,22.587884,22.589686,22.591488000000002,22.59329,22.595092,22.596894,22.598696,22.600498,22.6023,22.603782,22.605264000000002,22.606745999999998,22.608228,22.60971,22.611192000000003,22.612674,22.614156,22.615638,22.61712,22.618602,22.620084,22.621566,22.623048,22.62453,22.626012,22.627494,22.628976,22.630457999999997,22.63194,22.633422,22.634904000000002,22.636385999999998,22.637868,22.63935,22.640832,22.642314000000002,22.643796,22.645278,22.64676,22.648242,22.649724,22.651206,22.652688,22.65417,22.655652,22.657134,22.658616000000002,22.660098,22.661579999999997,22.663062,22.664544,22.666026000000002,22.667507999999998,22.66899,22.670472,22.671954,22.673436,22.674917999999998,22.6764,22.677674,22.678948000000002,22.680222,22.681496,22.68277,22.684044,22.685318,22.686592,22.687866,22.68914,22.690414,22.691688,22.692961999999998,22.694236,22.695510000000002,22.696784,22.698058,22.699332000000002,22.700606,22.70188,22.703154,22.704428,22.705702,22.706976,22.70825,22.709524,22.710798,22.712072,22.713345999999998,22.71462,22.715894,22.717168,22.718442,22.719716000000002,22.72099,22.722264000000003,22.723538,22.724812,22.726086,22.72736,22.728634,22.729908,22.731182,22.732456,22.733729999999998,22.735004,22.736278,22.737551999999997,22.738826,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401,22.7401};
    C2F6_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.95911885,0.050575847,0.053237732,0.056039719,0.058989177000000004,0.062093873,0.065361969,0.068802075,0.072423235,0.07623498599999999,0.08024735200000001,0.084470898,0.08891673300000001,0.09359656300000001,0.09852269699999999,0.1037081,0.10916642,0.11491202,0.12096002,0.12732636,0.13402771,0.14108183,0.14850719,0.15632334,0.16455089,0.17321146,0.18232786,0.19192405,0.20202532,0.21265824,0.22385079,0.23563239,0.24803412,0.26108852,0.27483004,0.28929476,0.30452082,0.32054821,0.33741917,0.35517808,0.37387169,0.39354912,0.41426223,0.39468287,0.37832187,0.3640764,0.35194679,0.34193311,0.33403572,0.32825472,0.32459037,0.32304286,0.32361242,0.32629927,0.3311036,0.33802563,0.34706557,0.35822365,0.37150001,0.38689499,0.40440867,0.42404135,0.4457932,0.46966444,0.49565531,0.52376596,0.55399667,0.58634761,0.62081899,0.65741104,0.69612398,0.73695798,0.7799133,0.82499011,0.87218868,0.9215092,0.97295172,1.0265167,1.0822044,1.1400146,1.1999481,1.2620042999999999,1.3261846000000002,1.392488,1.4609153,1.5314669,1.6041426,1.678943,1.7558675,1.8349176,1.9160924,2.0735678,2.3729101000000004,2.3731468999999996,2.3733837,2.3736205000000004,2.3738572999999996,2.3740941,2.3743309,2.3745677000000005,2.3748044999999998,2.3749,2.4345,2.4915,2.5463,2.599,2.6494,2.6001,2.5502,2.4998332999999997,2.4494667000000003,2.3991,2.42213,2.44516,2.4681900000000003,2.49122,2.51425,2.53728,2.56031,2.58334,2.60637,2.6294,2.64399,2.6585799999999997,2.6731700000000003,2.68776,2.70235,2.71694,2.73153,2.74612,2.76071,2.7753,2.77061,2.76592,2.76123,2.75654,2.75185,2.74716,2.74247,2.73778,2.7330900000000002,2.7284,2.73746,2.7465200000000003,2.75558,2.76464,2.7737,2.7827599999999997,2.79182,2.80088,2.80994,2.819,2.80583,2.7926599999999997,2.77949,2.76632,2.75315,2.73998,2.72681,2.7136400000000003,2.70047,2.6873,2.6938400000000002,2.70038,2.70692,2.71346,2.72,2.72654,2.7330799999999997,2.73962,2.7461599999999997,2.7527,2.7517400000000003,2.75078,2.74982,2.7488599999999996,2.7479,2.74694,2.74598,2.7450200000000002,2.7440599999999997,2.7431,2.7360700000000002,2.7290400000000004,2.72201,2.7149799999999997,2.70795,2.70092,2.69389,2.68686,2.67983,2.6728,2.66808,2.66336,2.65864,2.6539200000000003,2.6492,2.6444799999999997,2.63976,2.63504,2.63032,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.6256,2.5994162999999997,2.5732327,2.5470490000000003,2.5208652999999996,2.4946816000000003,2.468498,2.4423142999999996,2.4161306000000002,2.3899468999999995,2.3637633,2.3375796,2.3113959,2.2852122,2.2590286,2.2328449,2.2066612,2.1804776,2.1542939,2.1281102,2.1019265,2.0757429,2.0495592,2.0233755,1.9971918000000002,1.9710081999999998,1.9448245,1.9186408,1.8924571,1.8662735000000001,1.8400898,1.8139061,1.7877223999999998,1.7615387999999998,1.7353551,1.7091714,1.6829878,1.6568041,1.6306204,1.6044367,1.5782531000000002,1.5520694,1.5258857,1.499702,1.4735184,1.4473347,1.421151,1.3949673,1.3687837,1.3426,1.3164163,1.2902327,1.264049,1.2378653,1.2116816000000001,1.185498,1.1593143,1.1331306,1.1069468999999998,1.0807632999999999,1.0545796,1.0283959,1.0022122,0.97602857,0.9498449,0.92366122,0.89747755,0.87129388,0.8451102,0.81892653,0.79274286,0.76655918,0.74037551,0.71419184,0.68800816,0.66182449,0.63564082,0.60945714,0.58327347,0.5570898,0.53090612,0.50472245,0.47853878,0.4523551,0.42617143,0.39998776,0.37380408,0.34762041,0.32143673,0.29525306,0.26906939,0.24288571,0.21670204,0.19051837,0.16433469,0.13815102,0.11196735,0.085783673,0.0596,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592,0.0592};
    C6F14_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.4624,0.4651,0.4058,0.3939,0.4062,0.4358,0.4427,0.4492,0.45503333,0.46086667,0.4667,0.43848,0.41026,0.38204,0.35382,0.3256,0.29738,0.26916,0.24094,0.21272,0.1845,0.17723,0.16996,0.16269,0.15542,0.14815,0.14088,0.13361,0.12634,0.11907,0.1118,0.1119,0.112,0.1121,0.1122,0.1123,0.1124,0.1125,0.1126,0.1127,0.1128,0.11238,0.11196,0.11154,0.11112,0.1107,0.11028,0.10986,0.10944,0.10902,0.1086,0.10848,0.10836,0.10824,0.10812,0.108,0.10788,0.10776,0.10764,0.10752,0.1074,0.10732,0.10724,0.10716,0.10708,0.107,0.10692,0.10684,0.10676,0.10668,0.1066,0.10626,0.10592,0.10558,0.10524,0.1049,0.10456,0.10422,0.10388,0.10354,0.1032,0.1026,0.102,0.1014,0.1008,0.1002,0.0996,0.099,0.0984,0.0978,0.0972,0.09635,0.0955,0.09465,0.0938,0.09295,0.0921,0.09125,0.0904,0.08955,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.0887,0.08787346900000001,0.087046939,0.08622040800000001,0.085393878,0.08456734699999999,0.083740816,0.08291428599999999,0.082087755,0.081261224,0.080434694,0.079608163,0.078781633,0.077955102,0.07712857099999999,0.076302041,0.07547551,0.07464898,0.073822449,0.07299591799999999,0.072169388,0.071342857,0.070516327,0.069689796,0.068863265,0.068036735,0.06721020400000001,0.066383673,0.065557143,0.064730612,0.063904082,0.063077551,0.06225102,0.06142449,0.06059795900000001,0.059771429,0.058944897999999996,0.058118367000000004,0.057291837000000005,0.05646530599999999,0.055638775999999994,0.054812245,0.053985714000000004,0.053159184000000005,0.052332653,0.051506122,0.050679592,0.049853061,0.049026531,0.0482,0.047373469,0.046546939,0.045720408,0.044893878,0.044067347,0.043240815999999994,0.042414285999999995,0.041587755,0.040761224,0.039934694,0.039108163,0.038281632999999995,0.037455102000000004,0.036628571,0.035802041,0.03497551,0.03414898,0.033322449,0.032495918,0.031669388,0.030842857,0.030016327000000002,0.029189796,0.028363265,0.027536735,0.026710203999999998,0.025883673,0.025057142999999997,0.024230612000000002,0.023404082000000003,0.022577551,0.02175102,0.02092449,0.020097959,0.019271429,0.018444898,0.017618367,0.016791837,0.015965306000000002,0.015138776000000001,0.014312245,0.013485714,0.012659183999999999,0.011832653,0.011006122,0.010179592,0.0093530612,0.0085265306,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077,0.0077};
    CF4_em={0.010762744,0.010752073000000001,0.010747949,0.01074382,0.010739687,0.010735548000000001,0.010731403,0.010727253999999999,0.010723098,0.010718937,0.010714768999999999,0.010710595,0.010706413,0.010702225,0.01069803,0.010693826000000002,0.010689617,0.010685398,0.010681171000000001,0.010676935,0.010672691000000002,0.010668437,0.010664172,0.010659898999999999,0.010655613999999999,0.010651319,0.010647011999999999,0.010642695,0.010638363999999999,0.010634021,0.010629666000000001,0.010625296999999999,0.010620913999999999,0.010616516999999999,0.010612106000000001,0.010607681,0.010603238000000001,0.01059878,0.010594305,0.010589813,0.010585303,0.010580775,0.010576228,0.010571661000000001,0.010567074,0.010562466999999999,0.010557838,0.010553187,0.010548513,0.010543815,0.010539093999999999,0.010534347,0.010529574,0.010524775,0.010519947,0.010515091,0.010510206000000001,0.010505291000000002,0.010500343,0.010495363999999998,0.010490352,0.010485305,0.010480223,0.010475104,0.010469948,0.010464751,0.010459517,0.010454239,0.01044892,0.010443556,0.010438147,0.010432691,0.010427186,0.010421632,0.010416028,0.010410369000000001,0.010404655,0.010398886,0.010393056999999999,0.01038717,0.01038122,0.010375207,0.010369128,0.010362983000000001,0.010356769,0.010350482,0.010350913,0.010351344,0.010351774000000001,0.010352205,0.010352638,0.01035307,0.0103535,0.010353931,0.010354361999999999,0.010354793000000001,0.01035496,0.010355129,0.010355298,0.010355467,0.010355635,0.010355804,0.010355975,0.010356145,0.010356315999999999,0.010356485,0.010356891,0.010357297,0.010357705,0.010358112,0.010358519,0.010358926999999999,0.010359338000000001,0.010359748,0.01036016,0.010360569,0.010361285999999999,0.010362003,0.01036272,0.010363441,0.010364164,0.010364884,0.010365604,0.010366324,0.010367045,0.010367767,0.010368724000000001,0.01036968,0.010370641,0.010371601999999999,0.01037256,0.010373516,0.010374477,0.010375435,0.010376393000000001,0.010377345,0.010379723,0.0103821,0.010384475,0.01038685,0.010389227,0.010391604,0.010393983,0.010396358,0.010398735,0.010401115,0.010406394,0.010411672,0.010416950999999999,0.010422233000000001,0.010427518,0.010432805,0.010438096,0.010443388,0.010448681999999999,0.010453981999999999,0.0104523,0.98417991,1.1648849,1.2256653,1.2896433999999999,1.3569897,1.4278826999999998,1.5025036,1.5810544,1.6637375,1.7507764,1.8423953000000002,1.9388368999999999,2.0403528000000004,2.1472124,2.2596977000000003,2.3781004,2.5027381,2.6339327999999997,2.7720335,2.9174066,3.0704314,3.2315097,3.4010636,3.5795440000000003,3.7674167,3.9651774,4.1733472,4.392470200000001,4.623130000000001,4.865916,5.121479,5.3904959,5.6736692,5.971749099999999,6.2855162,6.615796899999999,6.9634615,7.329426600000001,7.7146508,8.1201607,8.5470132,14.984956,13.488098999999998,13.488369,13.488639000000001,13.488909,13.48918,13.489448999999999,11.992564,13.489967000000002,13.490244,13.490523000000001,11.993644999999999,13.49105,13.491328,11.994452,13.491857000000001,11.994981,13.492386999999999,11.995499,13.492892999999999,11.996004,11.996242,11.99648,13.493874,11.996986,11.997224000000001,11.997461999999999,11.997683,11.997905000000001,11.998111,11.998353999999999,11.998586999999999,10.501674000000001,11.999071,11.999322,11.999575,10.502692,12.0001,11.925,11.8481,11.7693,11.6885,11.6059,11.4149,11.2221,11.0262,10.8303,10.6344,10.74841,10.86242,10.97643,11.09044,11.20445,11.31846,11.43247,11.54648,11.66049,11.7745,11.83853,11.902560000000001,11.96659,12.030619999999999,12.09465,12.15868,12.222710000000001,12.28674,12.350769999999999,12.4148,12.38727,12.359739999999999,12.33221,12.304680000000001,12.27715,12.24962,12.22209,12.194560000000001,12.16703,12.1395,12.174619999999999,12.20974,12.244860000000001,12.27998,12.3151,12.35022,12.38534,12.42046,12.45558,12.4907,12.41897,12.34724,12.27551,12.20378,12.13205,12.060319999999999,11.98859,11.91686,11.845130000000001,11.7734,11.78015,11.7869,11.79365,11.8004,11.80715,11.8139,11.82065,11.8274,11.83415,11.8409,11.8161,11.7913,11.7665,11.7417,11.7169,11.6921,11.6673,11.6425,11.6177,11.5929,11.54293,11.49296,11.44299,11.39302,11.34305,11.29308,11.24311,11.19314,11.14317,11.0932,11.06043,11.027660000000001,10.99489,10.96212,10.92935,10.89658,10.86381,10.83104,10.79827,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.7655,10.656371,10.547243,10.438114,10.328986,10.219857000000001,10.110729,10.0016,9.892471400000002,9.783342900000001,9.674214300000001,9.5650857,9.4559571,9.346828599999998,9.2377,9.1285714,9.0194429,8.910314300000001,8.8011857,8.6920571,8.582928599999999,8.4738,8.3646714,8.2555429,8.1464143,8.0372857,7.9281571,7.819028599999999,7.7099,7.600771400000001,7.4916429,7.3825142999999995,7.2733857,7.1642570999999995,7.055128599999999,6.946,6.836871400000001,6.7277429,6.6186143,6.5094857,6.4003571,6.291228599999999,6.1821,6.072971400000001,5.9638429,5.8547142999999995,5.7455857,5.636457099999999,5.5273286,5.4182,5.3090714000000006,5.199942900000001,5.0908143,4.981685700000001,4.8725571,4.763428599999999,4.6543,4.545171400000001,4.4360429,4.326914299999999,4.2177857,4.1086571,3.9995286,3.8904,3.7812714,3.6721428999999994,3.5630143,3.4538857000000003,3.3447571000000003,3.2356286,3.1265,3.0173714,2.9082429,2.7991143,2.6899857000000003,2.5808571,2.4717286,2.3626,2.2534714,2.1443429,2.0352143,1.9260857,1.8169571,1.7078286,1.5987,1.4895714,1.3804428999999998,1.2713143,1.1621857,1.0530571000000002,0.94392857,0.8348,0.72567143,0.61654286,0.50741429,0.39828571,0.28915714,0.18002857,0.0709,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.0705,0.070513333,0.070526667,0.07054,0.070553333,0.070566667,0.07058,0.070593333,0.070606667,0.07062,0.07063333299999999,0.070646667,0.07066,0.070673333,0.07068666700000001,0.0707,0.070708,0.070716,0.070724,0.070732,0.07074,0.070748,0.070756,0.070764,0.070772,0.07078,0.070788,0.070796,0.070804,0.070812,0.07082,0.070828,0.070836,0.070844,0.070852,0.07086,0.070868,0.070876,0.070884,0.070892,0.0709,0.070904,0.070908,0.070912,0.070916,0.07092,0.070924,0.070928,0.070932,0.070936,0.07094,0.070944,0.070948,0.070952,0.070956,0.07096,0.070964,0.070968,0.070972,0.070976,0.07098,0.070984,0.070988,0.070992,0.070996,0.071,0.071004,0.071008,0.071012,0.071016,0.07102,0.071024,0.071028,0.071032,0.071036,0.07104,0.071044,0.071048,0.071052,0.071056,0.07106,0.071064,0.071068,0.071072,0.071076,0.07108,0.071084,0.071088,0.071092,0.071096,0.0711,0.071106,0.071112,0.071118,0.071124,0.07113,0.071136,0.071142,0.071148,0.071154,0.07116,0.071166,0.071172,0.071178,0.071184,0.07119,0.071196,0.071202,0.071208,0.071214,0.07122,0.071226,0.071232,0.071238,0.071244,0.07125,0.071256,0.071262,0.071268,0.071274,0.07128,0.071286,0.071292,0.071298,0.071304,0.07131,0.071316,0.071322,0.071328,0.071334,0.07134,0.071346,0.071352,0.071358,0.071364,0.07137,0.071376,0.071382,0.071388,0.071394,0.0714,0.071404,0.071408,0.071412,0.071416,0.07142,0.071424,0.071428,0.071432,0.071436,0.07144,0.071444,0.071448,0.071452,0.071456,0.07146,0.071464,0.071468,0.071472,0.071476,0.07148,0.071484,0.071488,0.071492,0.071496,0.0715,0.071504,0.071508,0.071512,0.071516,0.07152,0.071524,0.071528,0.071532,0.071536,0.07154,0.071544,0.071548,0.071552,0.071556,0.07156,0.071564,0.071568,0.071572,0.071576,0.07158,0.071584,0.071588,0.071592,0.071596,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716,0.0716};
    SF6_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.26190788,0.26198971,0.26207156,0.26215339,0.26223522,0.26231705,0.26239889,0.26248072,0.26256255,0.26264438,0.52463411,0.52479777,0.78686933,0.52520694,0.52537061,0.52553427,0.52569795,1.0496773000000001,0.52618894,0.7882605,0.78850599,1.0506594,0.78907883,1.0512322,1.0515595,1.0518869,1.5760299999999998,1.8384289,2.3628175,2.8873697999999997,3.1501778,3.4130677000000005,3.6760394,3.939093,3.9403205000000003,4.7272717,4.9906525,4.730299400000001,4.993680400000001,5.519051,5.5207695,5.7843959,5.7861962,6.3118123,5.0042369,6.0534232,6.0553054,4.4857403,4.7490393,6.3219597,5.5382,5.699,5.8596,6.0201,6.1805,6.3407,6.4709,6.6013,6.7489333,6.8965667,7.0442,7.1479,7.2516,7.3553,7.459,7.5627,7.6664,7.7701,7.8738,7.9775,8.0812,8.27191,8.46262,8.65333,8.84404,9.03475,9.22546,9.41617,9.60688,9.79759,9.9883,10.11551,10.24272,10.36993,10.49714,10.62435,10.751560000000001,10.87877,11.005980000000001,11.133189999999999,11.2604,11.3309,11.4014,11.4719,11.5424,11.6129,11.6834,11.7539,11.8244,11.8949,11.9654,12.17483,12.384260000000001,12.593689999999999,12.80312,13.01255,13.221979999999999,13.431410000000001,13.640839999999999,13.850270000000002,14.0597,14.00293,13.94616,13.889389999999999,13.83262,13.77585,13.719079999999998,13.66231,13.60554,13.548770000000001,13.492,13.630379999999999,13.76876,13.90714,14.045520000000002,14.1839,14.32228,14.46066,14.599039999999999,14.737420000000002,14.8758,14.99349,15.11118,15.22887,15.34656,15.46425,15.58194,15.699629999999999,15.81732,15.93501,16.0527,16.13966,16.22662,16.313579999999998,16.40054,16.4875,16.574460000000002,16.66142,16.748379999999997,16.83534,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.9223,16.758923,16.595547,16.432170000000003,16.268794,16.105417000000003,15.942041,15.778664000000001,15.615288,15.451910999999999,15.288535000000001,15.125157999999999,14.961782000000001,14.798404999999999,14.635029000000001,14.471651999999999,14.308276000000001,14.144898999999999,13.981522,13.818145999999999,13.654769,13.491392999999999,13.328016,13.164639999999999,13.001263,12.837887,12.67451,12.511134,12.347757000000001,12.184381,12.021004,11.857628,11.694251,11.530874,11.367498,11.204121,11.040745,10.877367999999999,10.713992,10.550614999999999,10.387239,10.223861999999999,10.060486000000001,9.8971092,9.7337327,9.5703561,9.4069796,9.2436031,9.0802265,8.91685,8.7534735,8.590096899999999,8.4267204,8.2633439,8.0999673,7.936590799999999,7.773214299999999,7.609837799999999,7.446461200000001,7.283084700000001,7.1197082,6.9563315999999995,6.7929550999999995,6.629578599999999,6.466202,6.3028255,6.139449,5.9760724000000005,5.8126959000000005,5.6493194,5.4859429,5.3225663,5.1591898,4.9958133,4.8324367,4.6690602,4.5056837,4.342307099999999,4.1789306,4.0155541,3.8521775999999996,3.688801,3.5254245,3.362048,3.1986714,3.0352949000000002,2.8719183999999998,2.7085418,2.5451653,2.3817888,2.2184122000000004,2.0550357,1.8916592,1.7282827,1.5649061000000002,1.4015296,1.2381531000000001,1.0747765,0.9114,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044,0.9044};
    CCl4={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.395,1.447,1.502,1.554,1.607,1.657,1.712,1.765,1.815,1.87,1.923,1.973,2.028,2.081,2.134,2.184,2.239,2.291,2.341,2.386,2.452,2.505,2.557,2.61,2.663,2.85,2.989,3.13,3.275,3.396,3.573,3.726,3.883,4.043,4.233,4.427,4.625,4.827,5.033,5.27,5.485,5.731,6.01,6.267,6.529,6.824,7.151,7.432,7.798,8.119,8.473,8.592,8.762,8.906,9.102,9.623,12.093,12.363,12.633,12.903,13.146,14.007,19.895,19.025,11.082,11.216,18.614,22.143,22.696,23.196,23.802,24.304,24.563,25.35,25.878,28.827,29.446,30.065,30.685,31.573,31.933,32.553,33.979,41.893,42.817,43.74,44.664,45.588,46.512,47.436,50.781,52.603,53.918,54.705,55.75,56.796,59.187,67.278,68.369,74.34,65.0,65.0,70.0,75.0,80.0,85.0,90.0,95.0,100.0,105.0,110.0,115.0,119.0,123.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,127.0,121.849,110.093,123.807,135.729,134.867,109.714,149.931,115.608,135.667,118.146,143.171,70.607,91.022,85.436,77.289,85.021,70.403,74.423,84.361,69.242,74.132,65.195,69.565,69.381,67.383,65.0,58.5,52.0,45.5,39.0,32.5,26.0,19.5,13.0,6.5,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CFC11_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.161,0.161,0.161,0.161,0.161,0.322,0.322,0.483,0.966,2.093,3.703,6.118,8.855,8.158,11.742,15.985,19.855,24.604,30.685,34.375,32.235,33.015,43.342,55.722,69.881,85.539,101.538,115.75,129.623,147.119,167.586,194.513,221.119,243.137,274.26,314.04,345.881,335.741,343.24,330.711,359.009,274.357,304.998,289.529,252.419,299.092,310.901,315.327,388.346,387.277,303.816,301.477,291.464,190.405,203.23,144.94,127.137,119.235,115.437,95.388,92.401,94.931,99.227,81.839,81.408,90.865,78.182,49.49,48.471,47.083,45.74,44.442,42.976,41.557,40.186,38.86,37.578,36.338,35.138,33.979,32.858,31.773,30.725,29.711,28.73,27.782,26.865,25.979,25.122,24.293,23.491,22.716,21.966,21.241,20.54,19.862,19.207,18.573,17.96,17.368,16.794,16.24,15.704,15.186,14.685,14.2,13.732,13.279,12.84,12.417,12.007,11.611,11.227,10.857,10.499,10.152,9.817,9.493,9.18,8.877,8.584,8.301,8.027,7.762,7.506,7.258,7.019,6.787,6.563,6.346,6.137,5.935,5.739,5.549,5.366,5.189,5.018,4.852,4.692,4.537,4.388,4.243,4.103,3.967,3.836,3.71,3.587,3.469,3.355,3.244,3.137,3.033,2.933,2.836,2.743,2.652,2.565,2.48,2.398,2.319,2.243,2.169,2.097,2.028,1.961,1.896,1.834,1.773,1.715,1.658,1.603,1.55,1.499,1.45,1.402,1.356,1.311,1.268,1.226,1.185,1.146,1.108,1.072,1.036,1.002,0.969,0.937,0.906,0.876,0.847,0.819,0.792,0.766,0.741,0.717,0.693,0.67,0.648,0.627,0.606,0.586,0.567,0.548,0.53,0.512,0.495,0.479,0.463,0.448,0.433,0.419,0.405,0.392,0.379,0.366,0.354,0.342,0.331,0.32,0.31,0.299,0.29,0.28,0.271,0.262,0.253,0.245,0.237,0.229,0.221,0.214,0.207,0.2,0.194,0.187,0.181,0.175,0.169,0.164,0.158,0.153,0.148,0.143,0.138,0.134,0.129,0.125,0.121,0.117,0.113,0.109,0.106,0.102,0.099,0.096,0.093,0.089,0.087,0.084,0.081,0.078,0.076,0.073,0.071,0.068,0.066,0.064,0.062,0.06,0.058,0.056,0.054,0.052,0.051,0.049,0.047,0.046,0.044,0.043,0.041,0.04,0.039,0.037,0.036,0.035,0.034,0.033,0.032,0.031,0.03,0.029,0.028,0.027,0.026,0.025,0.024,0.023,0.023,0.022,0.021,0.02,0.02,0.019,0.018,0.018,0.017,0.017,0.016,0.016,0.015,0.015,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.092,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.093,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.094,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.095,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096,0.096};
    CFC113_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.868,4.203,5.137,6.071,6.538,7.939,1.889,2.139,2.437,2.785,3.233,3.73,4.227,4.824,5.57,6.366,7.212,8.248,9.476,10.853,12.426,14.246,16.313,18.678,21.388,24.494,28.094,32.236,36.92,42.295,48.505,55.552,63.634,72.896,83.489,95.641,104.421,108.943,120.93,177.397,128.622,169.103,250.222,245.07,204.109,203.131,198.928,121.343,67.857,61.065,22.978,27.962,18.663,14.831,14.362,17.777,12.051,6.019,2.604,5.237,0.854,1.119,0.911,0.806,0.754,0.377,0.189,0.094,0.047,0.024,0.012,0.006,0.003,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.483,0.484,0.484,0.484,0.484,0.484,0.484,0.484,0.484,0.484,0.484,0.485,0.485,0.485,0.485,0.485,0.485,0.485,0.485,0.486,0.486,0.486,0.486,0.486,0.486,0.486,0.486,0.487,0.487,0.487,0.487,0.487,0.487,0.487,0.487,0.487,0.488,0.488,0.488,0.488,0.488,0.488,0.488,0.488,0.488,0.489,0.489,0.489,0.489,0.489,0.489,0.489,0.489,0.489,0.489,0.49,0.49,0.49,0.49,0.49,0.49,0.49,0.49,0.49,0.49,0.491,0.491,0.491,0.491,0.491,0.491,0.491,0.491,0.491,0.491,0.491,0.492,0.492,0.492,0.492,0.492,0.492,0.492,0.492,0.492,0.492,0.492,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.493,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.494,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.495,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.496,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.497,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.498,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.499,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.5,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.501,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.502,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503,0.503};
    CFC114_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.117,0.117,0.117,0.234,0.234,0.351,0.468,0.585,0.819,1.17,1.521,3.861,6.318,6.903,7.254,7.722,8.073,7.102,7.288,7.43,7.431,7.388,7.302,7.25,7.221,7.176,6.6,6.88,7.168,7.421,7.692,7.975,8.305,8.623,8.974,9.344,9.687,10.052,10.471,10.883,11.29,11.734,12.2,12.68,13.168,13.661,14.194,14.121,13.905,14.252,14.781,15.705,16.379,16.667,16.593,15.725,14.022,13.243,10.324,8.322,6.105,4.784,2.943,1.886,1.199,0.784,0.567,0.45,0.423,0.37,0.378,0.227,0.136,0.082,0.049,0.029,0.018,0.011,0.006,0.004,0.002,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.877,0.878,0.878,0.878,0.878,0.878,0.878,0.879,0.879,0.879,0.879,0.879,0.88,0.88,0.88,0.88,0.881,0.881,0.881,0.881,0.882,0.882,0.882,0.882,0.882,0.883,0.883,0.883,0.883,0.883,0.884,0.884,0.884,0.884,0.884,0.885,0.885,0.885,0.885,0.885,0.886,0.886,0.886,0.886,0.886,0.887,0.887,0.887,0.887,0.887,0.888,0.888,0.888,0.888,0.888,0.888,0.889,0.889,0.889,0.889,0.889,0.89,0.89,0.89,0.89,0.89,0.89,0.891,0.891,0.891,0.891,0.891,0.891,0.892,0.892,0.892,0.892,0.892,0.892,0.893,0.893,0.893,0.893,0.893,0.893,0.894,0.894,0.894,0.894,0.894,0.894,0.894,0.895,0.895,0.895,0.895,0.895,0.895,0.896,0.896,0.896,0.896,0.896,0.896,0.896,0.897,0.897,0.897,0.897,0.897,0.897,0.897,0.898,0.898,0.898,0.898,0.898,0.898,0.898,0.899,0.899,0.899,0.899,0.899,0.899,0.899,0.899,0.9,0.9,0.9,0.9,0.9,0.9,0.9,0.901,0.901,0.901,0.901,0.901,0.901,0.901,0.901,0.902,0.902,0.902,0.902,0.902,0.902,0.902,0.902,0.903,0.903,0.903,0.903,0.903,0.903,0.903,0.903,0.904,0.904,0.904,0.904,0.904,0.904,0.904,0.904,0.905,0.905,0.905,0.905,0.905,0.905,0.905,0.905,0.906,0.906,0.906,0.906,0.906,0.906,0.906,0.906,0.906,0.907,0.907,0.907,0.907,0.907,0.907,0.907,0.907,0.907,0.908,0.908,0.908,0.908,0.908,0.908,0.908,0.908,0.908,0.909,0.909,0.909,0.909,0.909,0.909,0.909,0.909,0.909,0.91,0.91,0.91,0.91,0.91,0.91,0.91,0.91,0.91,0.91,0.911,0.911,0.911,0.911,0.911,0.911,0.911,0.911,0.911,0.912,0.912,0.912,0.912,0.912,0.912,0.912,0.912,0.912,0.912,0.913,0.913,0.913,0.913,0.913,0.913,0.913,0.913,0.913,0.913,0.913,0.914,0.914};
    CFC115_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.225,0.444,0.633,0.825,1.043,1.283,1.537,1.803,2.127,2.495,2.921,3.391,3.943,4.582,5.337,6.228,7.006,7.743,8.399,9.207,9.71,9.792,10.152,10.807,11.493,12.26,12.363,12.135,12.018,11.681,11.011,9.083,7.019,5.429,4.223,3.32,2.609,2.069,1.609,1.288,1.046,0.785,0.588,0.441,0.331,0.248,0.186,0.14,0.105,0.079,0.059,0.044,0.033,0.025,0.019,0.014,0.01,0.008,0.006,0.004,0.003,0.002,0.002,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.238,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.239,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.24,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.241,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.242,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.243,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.244,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.245,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.246,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247,0.247};
    CFC12_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.097,0.097,0.097,0.194,0.291,0.485,0.776,1.164,1.649,2.231,2.91,3.589,4.365,5.917,7.76,13.483,20.661,24.056,25.802,28.615,33.854,35.2,39.582,44.802,50.343,58.664,66.689,69.93,78.149,93.09,104.6,120.668,141.744,164.921,185.933,208.571,235.269,263.953,294.486,321.743,346.609,378.471,419.239,454.701,442.834,432.28,419.447,424.498,357.266,432.044,386.347,400.317,408.416,432.125,407.669,502.712,453.238,507.99,385.52,405.617,309.884,303.369,228.999,232.722,194.71,178.907,160.981,152.715,145.169,140.712,117.202,100.258,107.745,87.647,51.552,49.808,46.366,43.216,40.334,36.906,33.769,30.898,28.272,25.869,23.67,21.658,19.817,18.133,16.591,15.181,13.891,12.71,11.63,10.641,9.737,8.909,8.152,7.459,6.825,6.245,5.714,5.228,4.784,4.377,4.005,3.665,3.353,3.068,2.807,2.569,2.35,2.151,1.968,1.801,1.648,1.507,1.379,1.262,1.155,1.057,0.967,0.885,0.809,0.741,0.678,0.62,0.567,0.519,0.475,0.435,0.398,0.364,0.333,0.305,0.279,0.255,0.233,0.214,0.195,0.179,0.164,0.15,0.137,0.125,0.115,0.105,0.096,0.088,0.08,0.074,0.067,0.062,0.056,0.052,0.047,0.043,0.039,0.036,0.033,0.03,0.028,0.025,0.023,0.021,0.019,0.018,0.016,0.015,0.014,0.012,0.011,0.01,0.01,0.009,0.008,0.007,0.007,0.006,0.006,0.005,0.005,0.004,0.004,0.004,0.003,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.013,4.013,4.014,4.015,4.016,4.017,4.018,4.018,4.019,4.02,4.021,4.022,4.023,4.024,4.025,4.026,4.028,4.029,4.03,4.031,4.032,4.033,4.034,4.035,4.036,4.037,4.037,4.038,4.039,4.04,4.041,4.042,4.043,4.044,4.045,4.046,4.047,4.048,4.049,4.05,4.051,4.051,4.052,4.053,4.054,4.055,4.056,4.057,4.058,4.058,4.059,4.06,4.061,4.062,4.063,4.063,4.064,4.065,4.066,4.067,4.068,4.068,4.069,4.07,4.071,4.071,4.072,4.073,4.074,4.075,4.075,4.076,4.077,4.078,4.078,4.079,4.08,4.081,4.081,4.082,4.083,4.084,4.084,4.085,4.086,4.087,4.087,4.088,4.089,4.089,4.09,4.091,4.091,4.092,4.093,4.094,4.094,4.095,4.096,4.096,4.097,4.098,4.098,4.099,4.1,4.1,4.101,4.102,4.102,4.103,4.104,4.104,4.105,4.106,4.106,4.107,4.108,4.108,4.109,4.109,4.11,4.111,4.111,4.112,4.113,4.113,4.114,4.114,4.115,4.116,4.116,4.117,4.118,4.118,4.119,4.119,4.12,4.121,4.121,4.122,4.122,4.123,4.123,4.124,4.125,4.125,4.126,4.126,4.127,4.128,4.128,4.129,4.129,4.13,4.13,4.131,4.132,4.132,4.133,4.133,4.134,4.134,4.135,4.135,4.136,4.137,4.137,4.138,4.138,4.139,4.139,4.14,4.14,4.141,4.141,4.142,4.142,4.143,4.144,4.144,4.145,4.145,4.146,4.146,4.147,4.147,4.148,4.148,4.149,4.149,4.15,4.15,4.151,4.151,4.152,4.152,4.153,4.153,4.154,4.154,4.155,4.155,4.156,4.156,4.157,4.157,4.158,4.158,4.159,4.159,4.16,4.16,4.161,4.161,4.162,4.162,4.163,4.163,4.164,4.164,4.165,4.165,4.166,4.166,4.166,4.167,4.167,4.168,4.168,4.169,4.169,4.17,4.17,4.171,4.171,4.172,4.172,4.173,4.173,4.173,4.174,4.174,4.175,4.175,4.176,4.176,4.177,4.177,4.177,4.178,4.178,4.178};
    CH3Br_em={157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.267,157.927,158.604,159.3,160.014,160.748,161.502,162.277,163.073,163.892,164.735,165.601,166.493,167.41,168.355,169.328,170.329,171.36,172.423,173.518,174.646,175.809,177.007,178.243,179.517,180.83,182.185,183.581,185.022,186.506,188.038,189.616,191.243,192.92,194.648,196.427,198.259,200.146,202.087,204.082,206.133,208.24,210.402,212.619,200.199,201.834,207.696,206.946,195.938,186.206,181.525,181.887,177.539,174.26,168.841,167.857,167.857,167.857,167.857,167.857,167.857,167.857,167.857,167.857,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.925,155.92,155.937,155.96,155.983,156.006,156.029,156.051,156.074,156.097,156.125,156.152,156.18,156.207,156.235,156.263,156.29,156.318,156.345,156.372,156.399,156.426,156.453,156.48,156.506,156.532,156.559,156.585,156.611,156.636,156.662,156.687,156.713,156.738,156.763,156.788,156.812,156.837,156.861,156.886,156.91,156.934,156.958,156.981,157.005,157.028,157.052,157.075,157.098,157.121,157.144,157.167,157.189,157.212,157.234,157.256,157.278,157.3,157.322,157.344,157.366,157.387,157.409,157.43,157.452,157.473,157.494,157.515,157.536,157.556,157.577,157.598,157.618,157.639,157.659,157.679,157.699,157.719,157.739,157.759,157.779,157.799,157.818,157.838,157.857,157.877,157.896,157.915,157.934,157.953,157.972,157.991,158.01,158.029,158.047,158.066,158.085,158.103,158.121,158.14,158.158,158.176,158.194,158.212,158.23,158.248,158.266,158.284,158.301,158.319,158.337,158.354,158.372,158.389,158.406,158.424,158.441,158.458,158.475,158.492,158.509,158.526,158.543,158.56,158.576,158.593,158.61,158.626,158.643,158.659,158.676,158.692,158.708,158.724,158.741,158.757,158.773,158.789,158.805,158.821,158.837,158.853,158.868,158.884,158.9,158.915,158.931,158.947,158.962,158.977,158.993,159.008,159.024,159.039,159.054,159.069,159.084,159.099,159.114,159.129,159.144,159.159,159.174,159.189,159.204,159.218,159.233,159.248,159.262,159.277,159.292,159.306,159.32,159.335,159.349,159.364,159.378,159.392,159.406,159.421,159.435,159.449,159.463,159.477,159.491,159.505,159.519,159.532,159.546,159.56,159.574,159.588,159.601,159.615,159.629,159.642,159.656,159.669,159.683,159.696,159.709,159.723,159.736,159.749,159.763,159.776,159.789,159.802,159.815,159.829,159.842,159.855,159.868,159.881,159.894,159.907,159.919,159.932,159.945,159.958,159.971,159.983,159.996,160.009,160.021,160.034,160.046,160.059,160.071,160.084,160.096,160.109,160.121,160.134,160.146,160.158,160.17,160.183,160.195,160.207,160.219,160.231,160.244,160.256,160.268,160.28,160.292,160.304,160.316,160.328,160.339,160.351,160.351};
    CH3CCl3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.214,3.512,6.224,9.469,10.772,14.717,18.348,20.077,28.22,31.46,36.197,48.096,69.567,94.137,114.767,134.875,141.326,170.133,214.168,266.209,305.489,308.992,382.3,462.112,587.319,489.712,550.707,505.097,505.343,553.718,569.476,546.714,539.076,647.608,635.816,564.767,694.142,573.576,554.986,372.232,244.236,201.637,89.184,62.53,29.412,24.668,18.584,13.253,13.487,8.444,10.874,10.874,10.874,10.874,10.874,10.874,7.266,7.266,7.266,7.266,7.266,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl_em={3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3100.211,3117.785,3137.148,3158.216,3180.749,3204.498,3229.071,3254.039,3278.967,3303.389,3326.864,3349.069,3369.713,3388.628,3405.698,3420.923,3434.335,3446.065,3456.224,3464.95,3472.409,3478.741,3484.114,3488.632,3492.425,3495.619,3498.281,3500.505,3502.36,3503.915,3505.193,3506.255,3507.154,3507.882,3508.496,3508.999,3509.425,3509.774,3510.061,3510.299,3510.501,3510.656,3510.801,3510.907,3511.005,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082,3511.082};
    HCFC141b_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,23.101,33.844,41.961,51.431,46.639,58.131,55.817,55.602,57.19,57.77,48.801,43.847,46.641,48.747,50.583,52.161,53.496,54.598,55.479,56.152,56.625,56.909,57.013,57.113,57.207,57.297,57.382,57.463,57.54,57.613,57.682,57.748,57.811,57.87,57.927,57.98,58.031,58.08,57.831,57.299,56.499,55.444,54.147,52.62,50.874,48.92,46.769,44.431,42.209,40.099,38.094,36.189,34.38,32.661,31.028,29.476,28.002,26.602,25.272,24.008,22.808,21.668,20.584,19.555,18.577,17.648,16.766,15.928,15.131,14.375,13.656,12.973,12.325,11.708,11.123,10.567,10.038,9.537,9.06,8.607,8.176,7.768,7.379,7.01,6.66,6.327,6.01,5.71,5.424,5.153,4.895,4.651,4.418,4.197,3.987,3.788,3.599,3.419,3.248,3.085,2.931,2.785,2.645,2.513,2.387,2.268,2.155,2.047,1.945,1.847,1.755,1.667,1.584,1.505,1.429,1.358,1.29,1.226,1.164,1.106,1.051,0.998,0.948,0.901,0.856,0.813,0.772,0.734,0.697,0.662,0.629,0.598,0.568,0.539,0.512,0.487,0.462,0.439,0.417,0.397,0.377,0.358,0.34,0.323,0.307,0.291,0.277,0.263,0.25,0.237,0.226,0.214,0.204,0.193,0.184,0.175,0.166,0.157,0.15,0.142,0.135,0.128,0.122,0.116,0.11,0.104,0.099,0.094,0.09,0.085,0.081,0.077,0.073,0.069,0.066,0.063,0.059,0.056,0.054,0.051,0.048,0.046,0.044,0.042,0.039,0.037,0.036,0.034,0.032,0.031,0.029,0.028,0.026,0.025,0.024,0.022,0.021,0.02,0.019,0.018,0.017,0.016,0.016,0.015,0.014,0.013,0.013,0.012,0.012,0.011,0.01,0.01,0.009,0.009,0.008,0.008,0.008,0.007,0.007,0.007,0.006,0.006,0.006,0.005,0.005,0.005,0.005,0.004,0.004,0.004,0.004,0.004,0.003,0.003,0.003,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002};
    HCFC142b_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.613,0.613,0.613,0.613,0.613,0.613,0.613,0.613,0.613,0.613,1.25,0.961,1.165,1.331,1.011,3.575,3.773,4.458,6.174,11.322,16.556,20.911,22.5,25.599,24.275,26.411,22.493,27.683,28.047,26.296,28.001,22.43,23.232,23.348,26.458,34.767,39.869,39.099,38.069,36.801,35.314,33.625,31.75,29.705,27.502,25.476,23.611,21.896,20.318,18.867,17.531,16.302,15.172,14.132,13.175,12.295,11.485,10.74,10.055,9.424,8.826,8.259,7.72,7.207,6.717,6.249,5.801,5.372,4.96,4.563,4.198,3.862,3.553,3.269,3.007,2.767,2.545,2.342,2.154,1.982,1.824,1.678,1.543,1.42,1.306,1.202,1.106,1.017,0.936,0.861,0.792,0.729,0.67,0.617,0.567,0.522,0.48,0.442,0.407,0.374,0.344,0.317,0.291,0.268,0.247,0.227,0.209,0.192,0.177,0.162,0.149,0.138,0.127,0.116,0.107,0.099,0.091,0.083,0.077,0.071,0.065,0.06,0.055,0.051,0.047,0.043,0.039,0.036,0.033,0.031,0.028,0.026,0.024,0.022,0.02,0.019,0.017,0.016,0.014,0.013,0.012,0.011,0.01,0.01,0.009,0.008,0.007,0.007,0.006,0.006,0.005,0.005,0.005,0.004,0.004,0.004,0.003,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.165,0.33,0.496,0.661,0.826,0.991,1.157,1.322,1.487,1.652,1.817,1.983,2.148,2.313,2.478,2.644,2.809,2.974,3.48,4.251,6.008,7.06,7.659,9.426,11.573,14.396,16.782,20.514,24.512,29.817,36.216,39.381,43.652,47.746,54.79,61.912,62.543,70.487,78.51,85.789,92.012,99.321,104.973,106.406,116.821,125.343,130.447,138.367,146.048,162.883,180.113,186.15,195.69,204.801,185.994,188.092,179.101,243.238,211.181,208.614,249.912,230.91,229.638,270.443,243.015,252.962,263.062,283.408,297.615,311.265,324.431,337.175,349.552,361.61,373.391,384.93,396.259,407.405,417.103,425.539,432.879,439.265,444.821,449.654,453.859,457.517,460.7,463.469,465.878,467.974,469.797,471.384,472.764,467.698,457.026,441.474,421.679,398.19,371.49,341.994,310.067,276.024,240.141,208.923,181.763,158.134,137.576,119.691,104.131,90.594,78.817,68.571,59.657,51.901,45.154,39.284,34.177,29.734,25.869,22.506,19.58,17.035,14.82,12.893,11.217,9.759,8.49,7.387,6.426,5.591,4.864,4.232,3.682,3.203,2.787,2.424,2.109,1.835,1.596,1.389,1.208,1.051,0.915,0.796,0.692,0.602,0.524,0.456,0.397,0.345,0.3,0.261,0.227,0.198,0.172,0.15,0.13,0.113,0.099,0.086,0.075,0.065,0.056,0.049,0.042,0.037,0.032,0.028,0.024,0.021,0.018,0.016,0.014,0.012,0.01,0.009,0.008,0.007,0.006,0.005,0.005,0.004,0.003,0.003,0.003,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1202={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001,0.002,0.005,0.008,0.013,0.019,0.026,0.035,0.044,0.055,0.067,0.08,0.095,0.11,0.127,0.145,0.161,0.185,0.206,0.229,0.249,0.269,0.289,0.309,0.329,0.349,0.369,0.389,0.409,0.429,0.509,0.589,0.669,0.729,0.789,0.607,0.467,0.328,0.282,0.235,0.189,0.189,0.189,0.049,0.049,0.049,0.049,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.005,0.014,0.032,0.058,0.1,0.158,0.229,0.329,0.461,0.63,0.839,1.086,1.365,1.767,2.035,2.454,2.928,3.453,3.946,4.522,5.168,6.032,7.083,8.22,9.656,11.362,11.605,11.702,11.426,9.343,10.23,9.105,10.035,10.743,9.909,9.837,9.806,8.834,8.669,8.524,7.77,7.653,7.518,6.992,6.502,6.047,5.624,5.23,4.864,4.524,4.207,3.913,3.639,3.384,3.147,2.927,2.722,2.531,2.354,2.189,2.036,1.894,1.761,1.638,1.523,1.417,1.317,1.225,1.139,1.06,0.985,0.916,0.852,0.793,0.737,0.686,0.638,0.593,0.551,0.513,0.477,0.444,0.413,0.384,0.357,0.332,0.309,0.287,0.267,0.248,0.231,0.215,0.2,0.186,0.173,0.161,0.149,0.139,0.129,0.12,0.112,0.104,0.097,0.09,0.084,0.078,0.072,0.067,0.063,0.058,0.054,0.05,0.047,0.043,0.04,0.038,0.035,0.033,0.03,0.028,0.026,0.024,0.023,0.021,0.02,0.018,0.017,0.016,0.015,0.014,0.013,0.012,0.011,0.01,0.009,0.009,0.008,0.008,0.007,0.007,0.006,0.006,0.005,0.005,0.005,0.004,0.004,0.004,0.003,0.003,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001,0.003,0.005,0.008,0.013,0.016,0.024,0.043,0.1,0.17,0.277,0.372,0.524,0.783,1.006,1.253,1.548,1.805,2.139,2.645,2.98,3.475,3.997,4.579,5.109,5.696,5.482,5.119,4.094,2.74,3.344,4.75,3.991,2.691,2.594,2.491,2.39,2.295,2.209,2.131,2.057,1.987,1.92,1.834,1.752,1.675,1.601,1.521,1.445,1.373,1.304,1.239,1.177,1.118,1.062,1.009,0.959,0.911,0.865,0.822,0.781,0.742,0.705,0.669,0.636,0.604,0.574,0.545,0.518,0.492,0.467,0.444,0.422,0.401,0.381,0.362,0.344,0.326,0.31,0.295,0.28,0.266,0.253,0.24,0.228,0.217,0.206,0.195,0.186,0.176,0.168,0.159,0.151,0.144,0.136,0.13,0.123,0.117,0.111,0.106,0.1,0.095,0.091,0.086,0.082,0.078,0.074,0.07,0.067,0.063,0.06,0.057,0.054,0.052,0.049,0.046,0.044,0.042,0.04,0.038,0.036,0.034,0.032,0.031,0.029,0.028,0.026,0.025,0.024,0.023,0.022,0.02,0.019,0.018,0.018,0.017,0.016,0.015,0.014,0.014,0.013,0.012,0.012,0.011,0.011,0.01,0.009,0.009,0.009,0.008,0.008,0.007,0.007,0.007,0.006,0.006,0.006,0.005,0.005,0.005,0.005,0.004,0.004,0.004,0.004,0.004,0.003,0.003,0.003,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008,0.008};
    Halon2402_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.007,0.014,0.028,0.048,0.075,0.109,0.15,0.197,0.252,0.313,0.391,0.468,0.544,0.621,0.697,0.774,0.85,0.927,1.003,1.105,1.183,1.262,1.355,1.434,1.504,1.728,1.73,1.73,1.735,1.715,1.7,1.68,1.3,0.85,0.7,0.71,0.631,0.562,0.5,0.445,0.396,0.353,0.314,0.279,0.249,0.221,0.197,0.175,0.156,0.139,0.124,0.11,0.098,0.087,0.078,0.069,0.061,0.055,0.049,0.043,0.039,0.034,0.031,0.027,0.024,0.022,0.019,0.017,0.015,0.013,0.012,0.011,0.01,0.008,0.008,0.007,0.006,0.005,0.005,0.004,0.004,0.003,0.003,0.003,0.002,0.002,0.002,0.002,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.001,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O_em={ 0.0,8.1574185,15.897848999999999,23.63869042857143,31.379956142857143,39.121658714285715,46.86381385714286,54.60643257142856,62.34953214285714,70.09312357142858,77.83722571428571,85.58185428571427,93.32702185714285,101.07274885714286,108.81905099999999,116.56594714285714,124.31345457142858,132.06159214285714,139.8103787142857,147.55983628571428,155.30998528571428,163.06084142857142,170.81244714285714,178.56479142857143,186.31792142857142,194.07185285714283,201.82661714285715,209.58224571428568,217.3387542857143,225.09615857142856,232.8545057142857,240.61381142857144,248.37412285714285,256.1354557142857,263.8978571428571,271.66134285714287,279.4259442857143,287.1917085714286,294.95868285714283,302.72686714285715,310.49634,318.2671171428571,326.0392457142857,333.81275714285715,341.5877142857143,349.36414857142853,357.1421071428571,364.9216214285714,372.7027857142857,380.4856,388.27014285714284,396.0564614285714,403.8446185714285,411.6346457142857,419.4266371428571,427.2206242857143,435.01668571428564,442.8148685714285,450.6152514285714,458.4179128571428,466.2228999999999,474.0302914285714,481.84018142857144,489.65261714285714,497.4676928571428,505.2855028571429,513.1060942857142,520.9295928571429,528.7560771428572,536.5856257142857,544.4183328571429,552.2543085714285,560.0936628571428,567.9364899999999,575.7828842857142,583.6329714285714,591.4868614285714,599.3446642857143,607.2065214285714,615.0725428571428,622.9428542857142,630.8175971428572,638.6969128571428,646.5809271428571,654.4697971428571,662.3636642857143,671.6300799999999,730.1809742857142,730.3594099999999,729.8287385714285,728.0099985714286,734.31776,740.5584528571428,746.4775842857142,752.3469957142856,758.3348457142857,793.5631942857142,740.32013,745.5632642857142,750.91973,756.5637514285714,760.8928485714285,761.7081528571427,763.6407899999999,765.06815,766.45415,919.3112971428571,1047.7339871428571,1094.2969085714285,1113.7504714285715,1131.9682314285712,1171.09674,1188.521667142857,1203.786414285714,1217.7175685714285,1232.1905985714284,1275.3376114285713,1233.9805342857142,1245.4452528571428,1255.179357142857,1264.267447142857,1298.3042442857143,1307.7373099999998,1315.3770457142857,1322.2626528571427,1328.6828971428572,1337.2569414285713,1347.3742385714286,1358.9058057142856,1371.7705099999998,1385.8144928571428,1400.7997457142858,1416.4881814285714,1432.6417442857141,1449.0223785714286,1465.3920285714285,1484.476557142857,1508.46245,1536.3025542857142,1567.0742057142857,1599.9174714285714,1633.8791857142855,1668.0063714285716,1701.3458,1732.944557142857,1761.8495714285714,1789.813457142857,1819.0222285714287,1849.1729142857143,1879.8388714285713,1910.6124714285716,1941.219814285714,1971.3870000000002,2000.8399714285713,2029.3049857142853,2056.5079857142855,2083.3880571428567,2110.860714285714,2138.617642857143,2167.9733428571426,2199.838771428571,2233.2999857142854,2267.4431999999997,2301.3543142857143,2334.1195428571427,2364.8251,2392.6942285714285,2417.669885714285,2439.9172285714285,2459.7771,2478.333471428571,2496.866585714286,2516.6566857142857,2538.9838571428572,2565.1285,2596.3705428571425,2671.749771428571,2818.9249,3022.1057428571426,3279.0680999999995,3583.488857142857,3913.428357142857,4246.947728571428,4562.1077857142855,4836.970600000001,5049.599499999999,5214.946157142857,5360.309585714285,5482.277585714285,5585.405414285714,5679.317285714285,5768.211585714285,5856.292828571428,5947.770871428572,6046.859185714286,6157.772814285715,6323.436742857143,6574.303528571428,6895.918385714285,7287.451757142857,7694.999871428571,8164.487571428571,8576.036857142857,8831.026285714284,9090.448714285712,9329.375314285715,8807.81927142857,9299.919985714287,9499.135328571429,9335.228885714287,9650.094614285714,9906.692399999998,10268.350714285714,10401.871700000002,11012.214714285712,11096.473614285713,10751.324885714284,11186.977685714284,11340.838299999998,11075.635057142856,11026.595328571428,11110.77267142857,11725.485828571429,11318.226385714286,11520.205242857142,11920.356171428572,11632.28487142857,12255.465042857142,11492.019628571428,11797.160728571427,11972.876928571428,12024.671685714284,12429.611228571428,12407.569899999997,11828.119128571429,11717.514285714286,11790.42857142857,11862.242857142857,11933.742857142855,12004.771428571428,12075.014285714286,12222.571428571428,12369.814285714285,12517.004814285712,12664.195185714285,12811.385714285712,13031.794285714286,13252.202857142856,13472.611428571428,13693.019999999999,13913.428571428569,14133.837142857143,14354.245714285713,14574.654285714285,14795.062857142855,15015.471428571429,15207.767142857141,15400.062857142855,15592.358571428573,15784.654285714287,15976.949999999999,16169.245714285713,16361.541428571427,16553.83714285714,16746.132857142857,16938.42857142857,17134.715714285714,17331.002857142856,17527.289999999997,17723.577142857142,17919.864285714284,18116.15142857143,18312.438571428567,18508.725714285712,18705.012857142854,18901.3,19021.954285714284,19142.608571428573,19263.262857142858,19383.917142857143,19504.571428571428,19625.225714285712,19745.88,19866.534285714282,19987.18857142857,20107.842857142856,20206.167142857143,20304.491428571426,20402.815714285713,20501.14,20599.464285714286,20697.788571428573,20796.112857142853,20894.43714285714,20992.761428571426,21091.085714285713,21172.58,21254.074285714287,21335.56857142857,21417.062857142857,21498.557142857142,21580.051428571427,21661.545714285712,21743.039999999997,21824.534285714282,21906.02857142857,22003.205714285712,22100.382857142853,22197.56,22294.737142857142,22391.914285714283,22489.091428571428,22586.268571428565,22683.445714285717,22780.622857142855,22877.8,22993.158571428572,23108.517142857145,23223.87571428571,23339.234285714283,23454.592857142856,23569.95142857143,23685.31,23800.668571428567,23916.02714285714,24031.385714285712,24107.269999999997,24183.154285714285,24259.038571428573,24334.922857142858,24410.807142857142,24486.691428571427,24562.57571428571,24638.46,24714.344285714287,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24790.22857142857,24751.142428571427,24712.054714285714,24672.96857142857,24633.880857142853,24594.794714285712,24555.707,24516.62085714285,24477.53314285714,24438.447,24399.359285714283,24360.273142857142,24321.185428571425,24282.099285714285,24243.011571428568,24203.92542857143,24164.83771428571,24125.751571428573,24086.66542857143,24047.577714285715,24008.49157142857,23969.403857142857,23930.317714285713,23891.23,23852.143857142855,23813.056142857142,23773.969999999998,23734.882285714284,23695.796142857143,23656.708428571426,23617.622285714282,23578.53457142857,23539.448428571424,23500.362285714284,23461.274571428567,23422.18842857143,23383.10071428571,23344.01457142857,23304.926857142855,23265.840714285714,23226.752999999997,23187.666857142856,23148.579142857143,23109.493,23070.40528571429,23031.319142857144,22992.231428571427,22953.145285714287,22914.05757142857,22874.97142857143,22835.885285714285,22796.797571428568,22757.711428571427,22718.62371428571,22679.537571428566,22640.449857142856,22601.363714285708,22562.275999999998,22523.189857142857,22484.10214285714,22445.016,22405.928285714283,22366.842142857146,22327.754428571425,22288.668285714288,22249.580571428567,22210.49442857143,22171.408285714286,22132.320571428572,22093.234428571428,22054.146714285715,22015.06057142857,21975.972857142857,21936.886714285713,21897.799,21858.712857142855,21819.62514285714,21780.538999999997,21741.451285714284,21702.36514285714,21663.277428571426,21624.19128571428,21585.105142857145,21546.017428571424,21506.931285714287,21467.843571428566,21428.75742857143,21389.669714285712,21350.58357142857,21311.495857142854,21272.409714285714,21233.322000000004,21194.235857142856,21155.148142857142,21116.062,21076.974285714285,21037.888142857144,20998.800428571427,20959.714285714283,20967.571428571428,20968.514285714286,20968.639999999996,20968.765714285717,20968.891428571427,20969.01714285714,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855,20969.142857142855};
    Aero_NH3_em={1.0125159807142856,1.0372799778571429,1.0614889614285714,1.0851518442857142,1.1082774907142856,1.1308748135714284,1.1566465707142857,1.1782138757142857,1.1992794985714286,1.2198523642857142,1.239941264285714,1.259555257142857,1.2787030857142856,1.297393614285714,1.3156358285714285,1.3334385928571426,1.3545046285714284,1.371455207142857,1.3879929285714285,1.4041266571428572,1.4198654999999998,1.4352181999999998,1.4501935,1.4648006285714283,1.4790482071428568,1.4929452214285712,1.5101943928571429,1.5234168714285714,1.5363155,1.5488990214285712,1.5611764214285713,1.573156564285714,1.5885422928571429,1.5999545142857143,1.6110963142857142,1.625670171428571,1.636297357142857,1.6540684285714284,1.6605228428571424,1.6704448928571427,1.680149707142857,1.6933400071428573,1.7026369428571426,1.7117433571428569,1.720667992857143,1.7294197142857142,1.7417014857142856,1.7501343357142856,1.7584209857142854,1.7665704214285711,1.7782853642857144,1.7898806999999999,1.8013655357142855,1.8090546357142854,1.8166509642857143,1.8241633857142854,1.8316007642857144,1.8426658214285712,1.853673564285714,1.860939,1.8718588285714286,1.8790542,1.889921692857143,1.8970825785714287,1.9042393357142857,1.9335644571428572,1.9370461785714284,1.944244464285714,1.9551681785714283,1.9624385928571426,1.973452164285714,1.9956057142857144,2.003050864285714,2.0142658857142854,2.025565907142857,2.0406535285714282,2.052150021428571,2.0674520857142857,2.0791806285714287,2.0947323499999997,2.1178102142857145,2.126259578571428,2.145946792857143,2.1584109499999995,2.1784368285714284,2.2023391928571425,2.242687842857143,2.422120657142857,2.4295566999999996,2.465368657142857,2.4680536857142856,2.5035702071428565,2.5238357857142852,2.543081485714285,2.5778933571428566,2.6252592428571426,2.7607911357142862,2.6177772999999998,2.6621137857142854,2.7077888999999997,2.751001807142857,2.777309185714285,2.81563265,2.838009264285714,2.8691210857142857,2.8929206000000005,3.473667921428572,3.934491778571428,4.132656407142857,4.161546207142857,4.271017342857142,4.417025364285713,4.487813607142856,4.548292442857142,4.6512119,4.798879364285714,4.943729928571428,4.88127205,4.976789585714286,5.019059964285713,5.057032257142857,5.192154085714285,5.286001857142857,5.433770471428571,5.462369571428571,5.590208478571427,5.686588035714285,5.7741273500000005,5.85497097142857,5.931263814285715,6.005150549999999,6.078776092857144,6.154284992857143,6.233822164285715,6.319532399999999,6.41356025,6.5189698428571425,6.635664885714285,6.761049721428571,6.892528814285714,7.0275066285714285,7.163387507142857,7.297576035714285,7.427476557142857,7.5504934142857145,7.6640313142857135,7.768465228571428,7.866945985714285,7.96104147142857,8.052319449999999,8.142347807142857,8.232694307142856,8.324926957142859,8.4206134,8.521321521428572,8.628619085714286,8.745225,8.871363907142856,9.004862357142857,9.14354702142857,9.285244449999999,9.427781314285713,9.568984164285714,9.706679549999997,9.838694142857142,9.962854614285714,10.076808285714286,10.181767257142855,10.280905792857144,10.377397671428568,10.474417157142856,10.575138149999999,10.68273467142857,10.800380864285714,10.931250628571428,11.078518228571427,11.250825978571426,11.453285292857144,11.683773478571426,11.940167599999997,12.220345571428572,12.522182999999998,12.843558285714284,13.182348857142856,13.536432142857143,13.903684357142854,14.309912714285714,14.776764285714284,15.295876285714284,15.858885928571429,16.45743164285714,17.08314821428571,17.727675285714284,18.382648857142854,19.03970614285714,19.690485571428567,20.3505385,21.03877014285714,21.75185092857143,22.48644764285714,23.2392295,24.006866928571423,24.786025499999997,25.57337564285714,26.36558535714286,27.159325071428572,27.980128785714285,28.84611,29.74280171428571,30.65573571428571,31.57044257142857,32.47245771428571,33.34731171428571,34.180536357142856,34.95766342857143,35.66422714285714,36.3458215,37.04590578571428,37.74680971428571,38.430861785714285,39.0803905,39.67772557142857,40.205195499999995,40.645127571428574,40.97985271428571,41.191698214285715,41.317314857142854,41.42356971428571,41.53811692857143,41.68861307142856,41.90271107142857,42.45207578571428,43.512316,44.96700357142857,46.69971278571428,48.59401428571428,49.04694285714285,49.499871428571424,49.953042857142854,50.405849999999994,50.858778571428566,51.25402857142857,51.64939999999999,52.04521707142856,52.44103292857143,52.83685,53.44282714285714,54.048804285714276,54.65478142857142,55.26075857142857,55.86673571428571,56.47271285714285,57.078689999999995,57.684667142857144,58.29064428571427,58.89662142857143,59.36495928571428,59.833297142857134,60.301635,60.76997285714285,61.23831071428571,61.70664857142857,62.17498642857143,62.64332428571428,63.111662142857135,63.57999999999999,64.00767142857143,64.43534285714286,64.86301428571429,65.2906857142857,65.71835714285714,66.14602857142856,66.5737,67.00137142857142,67.42904285714286,67.85671428571428,68.19211214285713,68.52750999999999,68.86290785714286,69.19830571428571,69.53370357142856,69.86910142857143,70.20449928571428,70.53989714285714,70.875295,71.21069285714286,71.46174642857143,71.7128,71.96385357142857,72.21490714285714,72.46596071428571,72.71701428571428,72.96806785714286,73.21912142857143,73.470175,73.72122857142857,73.93947214285714,74.1577157142857,74.37595928571429,74.59420285714285,74.81244642857142,75.03069,75.24893357142857,75.46717714285714,75.68542071428571,75.90366428571427,76.06572285714284,76.22778142857142,76.38983999999999,76.55189857142857,76.71395714285714,76.87601571428571,77.03807428571427,77.20013285714286,77.36219142857142,77.52425,77.70900357142857,77.89375714285714,78.0785107142857,78.26326428571429,78.44801785714284,78.63277142857142,78.817525,79.00227857142856,79.18703214285713,79.3717857142857,79.59180214285713,79.81181857142857,80.03183499999999,80.25185142857141,80.47186785714285,80.69188428571428,80.91190071428571,81.13191714285713,81.35193357142857,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195,81.57195};
    Aero_NOx_em={0.0,0.3597910371428571,0.5521257114285714,0.7446256571428571,0.9372960328571429,1.1301420628571428,1.3231692014285714,1.516383067142857,1.709789377142857,1.903394144285714,2.0972034799999997,2.291223692857143,2.4854613542857145,2.679923134285714,2.874615998571428,3.0695471100000002,3.2647237957142856,3.460153514285714,3.6558444142857143,3.851804414285714,4.048042057142857,4.244565228571428,4.441383457142856,4.638505614285714,4.8359412285714285,5.033699828571429,5.2317912714285715,5.4302264000000005,5.629015071428571,5.828169114285715,6.027699042857144,6.2276170142857135,6.427934528571428,6.628664400000001,6.829819114285716,7.031411814285714,7.2334563,7.435966371428571,7.638956485714285,7.842441428571427,8.046436314285714,8.250957571428572,8.456020642857142,8.661642614285714,8.867840900000001,9.074633242857143,9.282038042857142,9.490074357142857,9.698761571428571,9.908119728571428,10.118169528571428,10.328932657142856,10.540431128571427,10.752687285714286,10.965725114285716,11.179568271428572,11.394242385714286,11.609772428571427,11.826185014285713,12.043507742857143,12.261768542857142,12.480996328571429,12.701221328571428,12.922474099999999,13.144786842857144,13.368191757142856,13.592722685714286,13.818415114285711,14.045304199999999,14.2734274,14.502822828571428,14.733529585714287,14.965588414285715,15.199041042857141,15.43393084285714,15.670302171428572,15.908200371428572,16.147673414285713,16.38876927142857,16.63153887142857,16.87603347142857,17.122306299999998,17.370412885714288,17.620409742857145,17.872355028571427,18.126309199999998,18.210492814285715,18.294676757142856,18.378860371428573,18.463043985714286,18.5472276,18.631411214285713,18.715595157142857,18.79977877142857,18.883962385714288,18.968146,19.099320257142857,19.230494514285716,19.361668442857145,19.492842699999997,19.62401662857143,19.755190885714285,19.88636514285714,20.017539071428573,20.148713328571425,20.279887585714288,20.427831142857144,20.57577502857143,20.723718914285712,20.8716628,21.019606357142855,21.167550242857143,21.315494128571427,21.463438014285714,21.61138157142857,21.759325457142854,21.93525574285714,22.1111857,22.287115985714284,22.46304627142857,22.63897622857143,22.814906514285713,22.9908368,23.166766757142852,23.34269704285714,23.518627328571426,23.774979085714286,24.03133084285714,24.287682928571428,24.54403468571428,24.800386442857143,25.056738199999998,25.31309028571428,25.56944204285714,25.8257938,26.082145557142855,26.430738814285714,26.77933207142857,27.127925328571425,27.476518585714288,27.825111842857144,28.173705100000003,28.522298357142855,28.87089161428571,29.21948487142857,29.568078128571432,29.758578914285714,29.949079700000002,30.13958081428571,30.3300816,30.52058271428571,30.711083499999997,30.901584614285714,31.092085399999995,31.282586185714283,31.4730873,31.69302381428572,31.912960657142854,32.132897171428574,32.35283401428571,32.572770528571425,32.79270737142857,33.01264257142857,33.232581714285715,33.45251757142857,33.67245342857143,33.85096957142857,34.029489,34.20800514285714,34.38652128571428,34.56503742857143,34.74355357142857,34.922073000000005,35.100589142857146,35.27910528571429,35.45762142857142,36.54836357142857,37.63910571428571,38.72984457142857,39.82058671428571,40.911328857142855,42.002067714285715,43.09280985714285,44.183552,45.27429085714286,46.365033000000004,47.73646057142857,49.10788814285715,50.47931571428572,51.85074328571428,53.22217085714286,54.593598428571426,55.965026,57.33645357142857,58.70788114285715,60.079308714285716,62.294320428571424,64.50932885714286,66.72433728571428,68.93934899999999,71.15435742857142,73.36936585714287,75.58437757142858,77.799386,80.0143977142857,82.22940614285713,84.80321128571428,87.37701971428571,89.95082485714286,92.52463328571429,95.0984417142857,97.67224685714285,100.24605528571428,102.81986042857143,105.39366885714286,107.96747399999998,109.60236657142856,111.23725914285714,112.87214842857142,114.507041,116.14193357142858,117.77682614285713,119.41171542857144,121.04660799999999,122.68150057142857,124.31639314285712,124.42379328571428,124.53119671428571,124.63860014285714,124.74600028571429,124.85340371428572,124.96080714285715,125.06820728571428,125.17561071428571,125.28301085714286,125.39041428571429,125.80605714285714,126.2217,126.63734285714285,127.05331428571428,127.46862857142857,127.84089999999999,128.21711428571427,128.6008857142857,128.98465714285715,129.36842857142855,130.22369999999998,131.07897142857144,131.93424285714286,132.7895142857143,133.64478571428572,134.50005714285714,135.35532857142854,136.2106,137.06587142857143,137.92114285714285,137.71381428571428,137.5064857142857,137.29915714285715,137.09182857142855,136.8845,136.67717142857143,136.46984285714285,136.2625142857143,136.0551857142857,135.84785714285712,134.39468428571428,132.9415114285714,131.48833857142859,130.0351657142857,128.58199285714286,127.12882,125.67564714285712,124.22247428571428,122.76930142857142,121.31612857142856,120.19422142857142,119.0723142857143,117.95040714285715,116.82849999999999,115.70659285714285,114.58468571428573,113.46277857142857,112.34087142857142,111.21896428571428,110.09705714285715,109.48844428571428,108.87983142857144,108.27121857142856,107.66260571428572,107.05399285714286,106.44537999999999,105.83676714285714,105.22815428571427,104.61954142857141,104.01092857142856,103.52878285714284,103.04663714285714,102.56449142857143,102.08234571428572,101.6002,101.11805428571427,100.63590857142857,100.15376285714285,99.67161714285714,99.18947142857142,98.78710285714286,98.38473428571427,97.98236571428572,97.57999714285714,97.17762857142857,96.77526,96.37289142857142,95.97052285714285,95.56815428571427,95.1657857142857,94.58306428571429,94.00034285714285,93.41762142857144,92.8349,92.25217857142857,91.66945714285714,91.08673571428571,90.50401428571428,89.92129285714284,89.33857142857143,89.02695428571427,88.71533714285715,88.40371999999999,88.09210285714286,87.78048571428572,87.46886857142856,87.15725142857143,86.84563428571427,86.53401714285715,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224,86.2224};
    Aero_OC_em={ 0.0,0.56591996,0.78146771,0.99736131,1.2136114,1.4302291,1.6472256999999997,1.864613,2.082403,2.3006082,2.5192414,2.7383159,2.9578452,3.1778436,3.3983254,3.6193057,3.8407998999999995,4.062823799999999,4.2853938,4.508526799999999,4.7322403,4.956552200000001,5.1814809,5.4070456,5.633266000000001,5.8601623,6.087755400000001,6.3160669,6.5451189,6.7749345000000005,7.0055372,7.236951299999999,7.469202,7.7023151,7.9363173,8.1712361,8.4070999,8.643937800000002,8.881780000000001,9.1206576,9.360602499999999,9.601647900000001,9.8438276,10.087177,10.331732,10.57753,10.824608999999999,11.073008999999999,11.322772,11.573938,11.826552000000001,12.080658,12.336302,12.593532000000002,12.852397,13.112948000000001,13.375236,13.639316,13.905242999999999,14.173074,14.442867000000001,14.714684,14.988586999999999,15.264641000000001,15.542912,15.823469000000001,16.106382,16.391724,16.679571,16.97,17.26309,17.558925,17.857588,18.159167999999998,18.463755,18.771441,19.082323000000002,19.396499,19.714071,20.035144,20.359827,20.688231,21.020471,21.356666,21.696939,22.041414000000003,22.105064000000002,22.168714,22.232363,22.296013000000002,22.359663,22.423312,22.486962,22.550611,22.614261,22.677910999999998,22.734528,22.791144,22.847761,22.904378,22.960995,23.017612,23.074229000000003,23.130846,23.187463,23.244079,23.283844000000002,23.323608,23.363373,23.403138000000002,23.442902,23.482667000000003,23.522431,23.562196,23.601960000000002,23.641725,23.675442,23.709158,23.742875,23.776592,23.810309,23.844026,23.877742,23.911459,23.945176,23.978893,24.011375,24.043857,24.076339,24.108821,24.141303,24.173785000000002,24.206267,24.238749,24.271232,24.303714000000003,24.336515,24.369316,24.402117,24.434918,24.467719,24.50052,24.533321,24.566122,24.598923000000003,24.631724,24.427454,24.223184,24.018914000000002,23.814645000000002,23.610375,23.406105,23.201836,22.997566,22.793295999999998,22.589026999999998,22.605247,22.621467000000003,22.637688,22.653907999999998,22.670128,22.686349,22.702569,22.718789,22.73501,22.75123,22.748587,22.745943,22.7433,22.740656,22.738013,22.735369,22.732726,22.730082,22.727439,22.724795,22.68764,22.650484,22.613328,22.576173,22.539017,22.501860999999998,22.464705,22.42755,22.390394,22.353238,22.541288,22.729338000000002,22.917388,23.105438,23.293487,23.481537,23.669587,23.857637,24.045686,24.233735999999997,24.502237,24.770737,25.039238,25.307738,25.576239,25.844739,26.11324,26.381740999999998,26.650240999999998,26.918741999999998,27.221794,27.524846000000004,27.827897999999998,28.13095,28.434002000000003,28.737054999999998,29.040107,29.343159000000004,29.646210999999997,29.949263000000002,30.456334000000002,30.963403999999997,31.470475,31.977546000000004,32.484615999999995,32.991687,33.498757,34.005828,34.512898,35.019969,35.072322,35.124675,35.177028,35.229381,35.281735,35.334088,35.386441,35.438794,35.491147,35.5435,35.7143,35.8845,36.0543,36.2232,36.3917,36.1912,35.9908,35.7901,35.5894,35.3887,35.29844,35.20818,35.11792,35.02766,34.9374,34.84714,34.756879999999995,34.66662,34.57636,34.4861,34.34997,34.213840000000005,34.077709999999996,33.94158,33.80545,33.66932,33.533190000000005,33.397059999999996,33.26093,33.1248,32.96601,32.80722,32.64843,32.48964,32.33085,32.172059999999995,32.01327,31.85448,31.695690000000003,31.5369,31.38737,31.237840000000002,31.088309999999996,30.938779999999998,30.78925,30.63972,30.490190000000002,30.340659999999996,30.191129999999998,30.0416,29.87913,29.716659999999997,29.554190000000002,29.39172,29.22925,29.066779999999998,28.90431,28.741840000000003,28.57937,28.4169,28.304809999999996,28.19272,28.08063,27.96854,27.85645,27.744359999999997,27.632270000000002,27.52018,27.40809,27.296,27.203640000000004,27.111279999999997,27.01892,26.92656,26.8342,26.741840000000003,26.64948,26.55712,26.46476,26.3724,26.23123,26.09006,25.94889,25.80772,25.66655,25.52538,25.38421,25.24304,25.10187,24.9607,24.85535,24.75,24.64465,24.5393,24.43395,24.3286,24.22325,24.1179,24.01255,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072,23.9072};
    Aero_SOx_em={0.0,0.19776529399999998,0.232613,0.2676215,0.30279578,0.33814098,0.37366238,0.40936542,0.44525572,0.48133908,0.51762146,0.55410902,0.59080812,0.62772528,0.66486724,0.70224098,0.73985366,0.77771266,0.8158256,0.85420032,0.89284496,0.93176782,0.97097754,1.01048296,1.05029326,1.09041784,1.13086644,1.17164906,1.21277606,1.25425808,1.29610608,1.33833138,1.38094568,1.423961,1.46738972,1.51124466,1.55553898,1.60028626,1.64550052,1.69119622,1.73738822,1.7840919,1.83132306,1.87909802,1.9274336,1.97634716,2.0258566000000005,2.0759802,2.126737,2.1781467999999995,2.2302296000000004,2.2830062,2.3364982000000003,2.3907276,2.4457172000000003,2.5014906000000003,2.558072,2.6154864,2.6737596000000003,2.732918,2.792989,2.854001,2.9159832000000003,2.9789652,3.0429782000000003,3.108054,3.1742256,3.2415266,3.3099924,3.3796584000000003,3.4505623999999995,3.5227421999999997,3.5962373999999997,3.6710886,3.7473379999999996,3.8250286,3.904205,3.9849134,4.0672008,4.151116200000001,4.2367099999999995,4.324034200000001,4.413142,4.5040888,4.5969316,4.6917288,4.802564,4.9133992,5.0242344,5.1350696,5.2459048,5.3567402,5.4675754,5.5784106,5.6892458,5.800081,5.985356200000001,6.1706314,6.3559064,6.5411816,6.7264568,6.911732000000001,7.0970070000000005,7.2822822,7.4675574000000005,7.6528326,7.986336200000001,8.3198398,8.6533434,8.986847000000001,9.3203506,9.653854199999998,9.987357800000002,10.3208614,10.654364999999999,10.9878686,11.524642800000002,12.061417,12.598191,13.1349652,13.6717392,14.2085134,14.7452876,15.2820616,15.8188358,16.3556098,17.134745600000002,17.913881399999998,18.6930172,19.472153,20.251288,21.030424,21.80956,22.588696,23.367832,24.146967999999998,25.25976,26.37255,27.485342,28.598134,29.710926,30.823715999999997,31.936508,33.0493,34.16209,35.274882,35.642846,36.01081,36.378776,36.74674,37.114703999999996,37.482668,37.850632,38.218596000000005,38.58656,38.954524,39.727768,40.50101,41.274254,42.047496,42.82074,43.593982000000004,44.367226,45.140468,45.913712,46.686954,47.509912,48.332868,49.155826,49.978784000000005,50.80174,51.624697999999995,52.447656,53.270612,54.09356999999999,54.916526,55.680884,56.445240000000005,57.209598,57.973954000000006,58.738312,59.50266800000001,60.267026,61.031381999999994,61.795738,62.560095999999994,65.733896,68.907698,72.081498,75.2553,78.4291,81.602902,84.776702,87.95050400000001,91.12430400000001,94.298106,97.54151999999999,100.784936,104.028352,107.271768,110.515184,113.7586,117.002016,120.24543200000001,123.488848,126.73226399999999,127.091726,127.45118799999999,127.810652,128.17011399999998,128.529576,128.889038,129.248502,129.60796399999998,129.967426,130.326888,130.087766,129.84864199999998,129.60952,129.370398,129.131274,128.892152,128.653028,128.413906,128.174782,127.93566000000001,125.910334,123.88500800000001,121.859682,119.834356,117.80903,115.783704,113.75837800000001,111.733052,109.707726,107.6824,108.8382,109.9922,111.1432,112.2922,113.439,110.8286,108.2234,105.629466,103.035534,100.4416,99.937,99.4324,98.9278,98.4232,97.9186,97.414,96.9094,96.4048,95.9002,95.3956,94.35191999999999,93.30824,92.26456,91.22088000000001,90.1772,89.13351999999999,88.08984,87.04616,86.00248,84.9588,83.00904,81.05928,79.10951999999999,77.15975999999999,75.21,73.26024,71.31048,69.36072,67.41096,65.4612,64.13726,62.81332,61.489380000000004,60.165440000000004,58.8415,57.517559999999996,56.193619999999996,54.86968,53.54574,52.2218,51.54074,50.85968,50.17862,49.49756,48.8165,48.13544,47.45438,46.77332,46.092259999999996,45.4112,44.88296,44.35472,43.82648,43.29824,42.77,42.24176,41.71352,41.18528,40.65704,40.1288,39.805040000000005,39.48128,39.15752,38.83376,38.51,38.186240000000005,37.86248,37.53872,37.21496,36.8912,36.09738,35.30356,34.50974,33.715920000000004,32.9221,32.12828,31.334459999999996,30.540640000000003,29.74682,28.953,28.62898,28.304959999999998,27.980940000000004,27.65692,27.3329,27.008879999999998,26.684859999999997,26.360840000000003,26.036820000000002,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128,25.7128};
    Aero_ENMVOC_em={0.0,1.5968746999999999,2.2923164000000003,2.9886478,3.6858966,4.3840909,5.0832602,5.7834346,6.484645099999999,7.1869238,7.8903037,8.5948188,9.300504400000001,10.007397000000001,10.715533,11.424951,12.135692,12.847795,13.561303,14.27626,14.992710999999998,15.710701,16.430278,17.151491,17.874391,18.59903,19.325461999999998,20.053742,20.783927,21.516077,22.250252,22.986514,23.724929,24.465563,25.208484,25.953763000000002,26.701472999999996,27.451690000000003,28.204490999999997,28.959954999999997,29.718165000000003,30.479207000000002,31.243167,32.010135999999996,32.780207,33.553476,34.330042,35.110006,35.893474,36.680555,37.471359,38.266003000000005,39.064605,39.867286,40.674175,41.485399,42.301095000000004,43.121399,43.946455,44.77641,45.611414,46.451625,47.297202,48.148313,49.005128000000006,49.867824,50.736582,51.611591,52.49304300000001,53.381137,54.27608000000001,55.178081999999996,56.087363,57.004146999999996,57.928667000000004,58.861160999999996,59.801876,60.751067000000006,61.708996,62.675931999999996,63.652156000000005,64.637952,65.633619,66.639461,67.655792,68.68293800000001,68.727765,68.772592,68.817418,68.862245,68.907072,68.951899,68.996726,69.04155300000001,69.08638,69.131206,69.269044,69.406881,69.544719,69.682556,69.82039300000001,69.95823100000001,70.096068,70.23390500000001,70.37174300000001,70.50958,70.65333100000001,70.79708199999999,70.940834,71.084585,71.228336,71.372087,71.515838,71.659589,71.80334,71.947091,72.099835,72.252579,72.405323,72.55806700000001,72.71081099999999,72.863555,73.016299,73.169043,73.321787,73.474531,73.700338,73.92614499999999,74.151953,74.37776,74.603567,74.829374,75.055181,75.280989,75.506796,75.732603,75.920477,76.108351,76.296224,76.484098,76.671972,76.85984599999999,77.04772,77.23559300000001,77.423467,77.61134100000001,77.272725,76.93410899999999,76.59549200000001,76.256876,75.91826,75.57964399999999,75.241028,74.902412,74.563795,74.225179,74.68028000000001,75.13538,75.59048,76.045581,76.500681,76.955782,77.410882,77.86598199999999,78.321083,78.77618299999999,78.909446,79.042709,79.175973,79.309236,79.442499,79.575762,79.709025,79.842288,79.97555200000001,80.108815,81.24331,82.37780500000001,83.5123,84.646796,85.78129100000001,86.915786,88.05028100000001,89.184777,90.319272,91.453767,94.848353,98.242938,101.63752,105.03211,108.4267,111.82128,115.21587,118.61045,122.00504,125.39962,129.24133,133.08303,136.92473,140.76643,144.60813000000002,148.44984,152.29154,156.13324,159.97494,163.81663999999998,167.16131000000001,170.50597,173.85064,177.19531,180.53996999999998,183.88464,187.2293,190.57397,193.91863999999998,197.2633,199.79888,202.33446,204.87003,207.40561,209.94118999999998,212.47677000000002,215.01235,217.54792,220.0835,222.61907999999997,221.41947000000002,220.21986,219.02026,217.82065,216.62104,215.42143,214.22182,213.02222000000003,211.82261,210.623,211.5938,212.5632,213.5311,214.4977,215.4628,215.6435,215.8292,216.0247,216.2202,216.4157,217.31987,218.22404,219.12821,220.03238,220.93655,221.84072,222.74489,223.64906000000002,224.55322999999999,225.4574,225.45702999999997,225.45666,225.45629,225.45592000000002,225.45555,225.45517999999998,225.45481,225.45443999999998,225.45407000000003,225.4537,224.72621,223.99872000000002,223.27122999999997,222.54373999999999,221.81625,221.08876,220.36127000000002,219.63377999999997,218.90628999999998,218.1788,217.20395,216.2291,215.25425,214.2794,213.30455,212.3297,211.35485,210.38,209.40515,208.4303,207.70767,206.98504,206.26241000000002,205.53978,204.81715,204.09452,203.37188999999998,202.64926,201.92663000000002,201.204,200.44051000000002,199.67702,198.91353,198.15004,197.38655,196.62306,195.85957,195.09608,194.33258999999998,193.5691,193.07591000000002,192.58272,192.08953,191.59634,191.10315,190.60996,190.11677,189.62358,189.13038999999998,188.6372,187.89006,187.14292,186.39578,185.64864,184.9015,184.15436,183.40722,182.66008,181.91294,181.1658,180.67318,180.18056,179.68794,179.19532,178.7027,178.21008,177.71746000000002,177.22484,176.73221999999998,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396,176.2396};
    
}

void set_concs_ssp585() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.665241152,9.603058728,9.540876303,9.478693879,9.416511454,9.318521072,9.22053069,9.122540308,9.024549926,8.926559544,8.828569162,8.73057878,8.632588398,8.534598016,8.436607634,8.399193441,8.361779249,8.324365056,8.286950864,8.249536671,8.212122479,8.174708286,8.137294094,8.099879901,8.062465709,7.946306556,7.830147404,7.713988251,7.597829098,7.481669946,7.365510793,7.249351641,7.133192488,7.017033336,6.900874183,6.86775827,6.834642356,6.801526443,6.768410529,6.735294616,6.702178703,6.669062789,6.635946876,6.602830963,6.569715049,6.521597973,6.473480897,6.425363821,6.377246745,6.329129668,6.281012592,6.232895516,6.18477844,6.136661364,6.088544288,6.022095762,5.955647237,5.889198711,5.822750186,5.75630166,5.689853135,5.623404609,5.556956084,5.490507558,5.424059033,5.322125268,5.220191503,5.118257738,5.016323974,4.914390209,4.812456444,4.710522679,4.608588914,4.506655149,4.404721384,4.29562444,4.186527496,4.077430552,3.968333609,3.859236665,3.750139721,3.641042777,3.531945833,3.422848889,3.313751945,3.302680746,3.291609546,3.280538347,3.269467148,3.258395948,3.247324749,3.23625355,3.22518235,3.214111151,3.203039952,3.191968752,3.180897553,3.169826354,3.158755154,3.147683955,3.136612756,3.125541556,3.114470357,3.103399158,3.092327958,3.081256759,3.07018556,3.05911436,3.048043161,3.036971962,3.025900763,3.014829563,3.003758364,2.992687165,2.981615965,2.970544766,2.959473567,2.948402367,2.937331168,2.926259969,2.915188769,2.90411757,2.893046371,2.881975171,2.870903972,2.859832773,2.848761573,2.837690374,2.826619175,2.815547975,2.804476776,2.793405577,2.782334377,2.771263178,2.760191979,2.749120779,2.73804958,2.726978381,2.715907181,2.704835982,2.693764783,2.682693583,2.671622384,2.660551185,2.649479985,2.638408786,2.627337587,2.616266387,2.605195188,2.594123989,2.58305279,2.57198159,2.560910391,2.549839192,2.538767992,2.527696793,2.516625594,2.505554394,2.494483195,2.483411996,2.472340796,2.461269597,2.450198398,2.439127198,2.428055999,2.4169848,2.4059136,2.394842401,2.383771202,2.372700002,2.361628803,2.350557604,2.339486404,2.328415205,2.317344006,2.306272806,2.295201607,2.284130408,2.273059208,2.261988009,2.25091681,2.23984561,2.228774411,2.217703212,2.206632012,2.195560813,2.184489614,2.173418415,2.162347215,2.151276016,2.140204817,2.129133617,2.118062418,2.106991219,2.095920019,2.08484882,2.073777621,2.062706421,2.051635222,2.040564023,2.029492823,2.018421624,2.007350425,1.996279225,1.985208026,1.974136827,1.963065627,1.951994428,1.940923229,1.929852029,1.91878083,1.907709631,1.896638431,1.885567232,1.874496033,1.863424833,1.852353634,1.841282435,1.830211235,1.819140036,1.808068837,1.796997637,1.785926438,1.774855239,1.763784039,1.75271284,1.741641641,1.730570442,1.719499242,1.708428043,1.697356844,1.686285644,1.675214445,1.664143246,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046,1.653072046};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,33.98323709,33.22044995,32.4576628,31.69487566,30.93208852,30.27921928,29.62635004,28.9734808,28.32061156,27.66774232,27.01487307,26.36200383,25.70913459,25.05626535,24.40339611,24.09682947,23.79026283,23.48369619,23.17712955,22.87056291,22.56399627,22.25742963,21.95086299,21.64429635,21.3377297,21.23722097,21.13671224,21.0362035,20.93569477,20.83518603,20.7346773,20.63416857,20.53365983,20.4331511,20.33264236,20.27601079,20.21937922,20.16274765,20.10611608,20.0494845,19.99285293,19.93622136,19.87958979,19.82295822,19.76632665,19.72570981,19.68509297,19.64447613,19.60385929,19.56324245,19.52262561,19.48200877,19.44139193,19.4007751,19.36015826,19.31837395,19.27658964,19.23480533,19.19302102,19.15123671,19.1094524,19.06766809,19.02588378,18.98409947,18.94231516,18.86989004,18.79746492,18.72503981,18.65261469,18.58018957,18.50776446,18.43533934,18.36291422,18.29048911,18.21806399,18.15654725,18.09503051,18.03351376,17.97199702,17.91048028,17.84896353,17.78744679,17.72593005,17.66441331,17.60289656,17.58189946,17.56090237,17.53990527,17.51890817,17.49791107,17.47691397,17.45591687,17.43491977,17.41392267,17.39292557,17.37192848,17.35093138,17.32993428,17.30893718,17.28794008,17.26694298,17.24594588,17.22494878,17.20395169,17.18295459,17.16195749,17.14096039,17.11996329,17.09896619,17.07796909,17.05697199,17.03597489,17.0149778,16.9939807,16.9729836,16.9519865,16.9309894,16.9099923,16.8889952,16.8679981,16.847001,16.82600391,16.80500681,16.78400971,16.76301261,16.74201551,16.72101841,16.70002131,16.67902421,16.65802711,16.63703002,16.61603292,16.59503582,16.57403872,16.55304162,16.53204452,16.51104742,16.49005032,16.46905323,16.44805613,16.42705903,16.40606193,16.38506483,16.36406773,16.34307063,16.32207353,16.30107643,16.28007934,16.25908224,16.23808514,16.21708804,16.19609094,16.17509384,16.15409674,16.13309964,16.11210254,16.09110545,16.07010835,16.04911125,16.02811415,16.00711705,15.98611995,15.96512285,15.94412575,15.92312865,15.90213156,15.88113446,15.86013736,15.83914026,15.81814316,15.79714606,15.77614896,15.75515186,15.73415476,15.71315767,15.69216057,15.67116347,15.65016637,15.62916927,15.60817217,15.58717507,15.56617797,15.54518088,15.52418378,15.50318668,15.48218958,15.46119248,15.44019538,15.41919828,15.39820118,15.37720408,15.35620699,15.33520989,15.31421279,15.29321569,15.27221859,15.25122149,15.23022439,15.20922729,15.18823019,15.1672331,15.146236,15.1252389,15.1042418,15.0832447,15.0622476,15.0412505,15.0202534,14.9992563,14.97825921,14.95726211,14.93626501,14.91526791,14.89427081,14.87327371,14.85227661,14.83127951,14.81028242,14.78928532,14.76828822,14.74729112,14.72629402,14.70529692,14.68429982,14.66330272,14.64230562,14.62130853,14.60031143,14.57931433,14.55831723,14.53732013,14.51632303,14.49532593,14.47432883,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173,14.45333173};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,96.64709616,92.52302535,88.39895453,84.27488372,80.1508129,79.28668059,78.42254827,77.55841596,76.69428365,75.83015133,74.96601902,74.10188671,73.23775439,72.37362208,71.50948976,71.5059388,71.50238784,71.49883688,71.49528592,71.49173496,71.488184,71.48463303,71.48108207,71.47753111,71.47398015,70.37078693,69.26759372,68.1644005,67.06120729,65.95801407,64.85482086,63.75162764,62.64843443,61.54524121,60.442048,60.78442022,61.12679245,61.46916467,61.8115369,62.15390913,62.49628135,62.83865358,63.18102581,63.52339803,63.86577026,63.61895248,63.37213469,63.12531691,62.87849912,62.63168134,62.38486356,62.13804577,61.89122799,61.64441021,61.39759242,60.58718648,59.77678055,58.96637461,58.15596867,57.34556274,56.5351568,55.72475086,54.91434492,54.10393899,53.29353305,52.15768382,51.02183459,49.88598536,48.75013613,47.6142869,46.47843767,45.34258844,44.20673921,43.07088998,41.93504075,40.69301051,39.45098026,38.20895002,36.96691977,35.72488952,34.48285928,33.24082903,31.99879878,30.75676854,29.51473829,29.33131033,29.14788237,28.96445442,28.78102646,28.5975985,28.41417054,28.23074258,28.04731462,27.86388666,27.6804587,27.49703074,27.31360278,27.13017483,26.94674687,26.76331891,26.57989095,26.39646299,26.21303503,26.02960707,25.84617911,25.66275115,25.47932319,25.29589524,25.11246728,24.92903932,24.74561136,24.5621834,24.37875544,24.19532748,24.01189952,23.82847156,23.6450436,23.46161565,23.27818769,23.09475973,22.91133177,22.72790381,22.54447585,22.36104789,22.17761993,21.99419197,21.81076401,21.62733606,21.4439081,21.26048014,21.07705218,20.89362422,20.71019626,20.5267683,20.34334034,20.15991238,19.97648442,19.79305647,19.60962851,19.42620055,19.24277259,19.05934463,18.87591667,18.69248871,18.50906075,18.32563279,18.14220483,17.95877688,17.77534892,17.59192096,17.408493,17.22506504,17.04163708,16.85820912,16.67478116,16.4913532,16.30792524,16.12449729,15.94106933,15.75764137,15.57421341,15.39078545,15.20735749,15.02392953,14.84050157,14.65707361,14.47364565,14.2902177,14.10678974,13.92336178,13.73993382,13.55650586,13.3730779,13.18964994,13.00622198,12.82279402,12.63936606,12.45593811,12.27251015,12.08908219,11.90565423,11.72222627,11.53879831,11.35537035,11.17194239,10.98851443,10.80508647,10.62165852,10.43823056,10.2548026,10.07137464,9.887946679,9.70451872,9.521090761,9.337662802,9.154234843,8.970806884,8.787378925,8.603950966,8.420523007,8.237095048,8.053667089,7.87023913,7.686811171,7.503383212,7.319955253,7.136527294,6.953099335,6.769671376,6.586243417,6.402815458,6.219387499,6.03595954,5.852531581,5.669103622,5.485675663,5.302247704,5.118819745,4.935391786,4.751963827,4.568535868,4.385107909,4.20167995,4.018251991,3.834824032,3.651396073,3.467968114,3.284540155,3.101112196,2.917684237,2.734256278,2.550828319,2.36740036,2.183972401,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442,2.000544442};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,156.9508471,158.3812442,159.8116413,161.2420384,162.6724355,162.6421968,162.6119582,162.5817196,162.5514809,162.5212423,162.4910036,162.460765,162.4305264,162.4002877,162.3700491,163.0956038,163.8211585,164.5467132,165.272268,165.9978227,166.7233774,167.4489321,168.1744868,168.9000415,169.6255963,168.7844378,167.9432794,167.102121,166.2609625,165.4198041,164.5786456,163.7374872,162.8963288,162.0551703,161.2140119,161.5888579,161.9637039,162.3385499,162.713396,163.088242,163.463088,163.837934,164.21278,164.587626,164.962472,164.1963391,163.4302062,162.6640732,161.8979403,161.1318073,160.3656744,159.5995414,158.8334085,158.0672755,157.3011426,156.1084159,154.9156891,153.7229624,152.5302357,151.337509,150.1447823,148.9520555,147.7593288,146.5666021,145.3738754,143.1915693,141.0092632,138.8269572,136.6446511,134.4623451,132.280039,130.0977329,127.9154269,125.7331208,123.5508147,121.068795,118.5867752,116.1047554,113.6227357,111.1407159,108.6586961,106.1766764,103.6946566,101.2126369,98.73061709,98.22427449,97.71793188,97.21158928,96.70524668,96.19890408,95.69256148,95.18621888,94.67987628,94.17353367,93.66719107,93.16084847,92.65450587,92.14816327,91.64182067,91.13547807,90.62913547,90.12279286,89.61645026,89.11010766,88.60376506,88.09742246,87.59107986,87.08473726,86.57839465,86.07205205,85.56570945,85.05936685,84.55302425,84.04668165,83.54033905,83.03399645,82.52765384,82.02131124,81.51496864,81.00862604,80.50228344,79.99594084,79.48959824,78.98325563,78.47691303,77.97057043,77.46422783,76.95788523,76.45154263,75.94520003,75.43885743,74.93251482,74.42617222,73.91982962,73.41348702,72.90714442,72.40080182,71.89445922,71.38811661,70.88177401,70.37543141,69.86908881,69.36274621,68.85640361,68.35006101,67.84371841,67.3373758,66.8310332,66.3246906,65.818348,65.3120054,64.8056628,64.2993202,63.79297759,63.28663499,62.78029239,62.27394979,61.76760719,61.26126459,60.75492199,60.24857938,59.74223678,59.23589418,58.72955158,58.22320898,57.71686638,57.21052378,56.70418118,56.19783857,55.69149597,55.18515337,54.67881077,54.17246817,53.66612557,53.15978297,52.65344036,52.14709776,51.64075516,51.13441256,50.62806996,50.12172736,49.61538476,49.10904216,48.60269955,48.09635695,47.59001435,47.08367175,46.57732915,46.07098655,45.56464395,45.05830134,44.55195874,44.04561614,43.53927354,43.03293094,42.52658834,42.02024574,41.51390314,41.00756053,40.50121793,39.99487533,39.48853273,38.98219013,38.47584753,37.96950493,37.46316232,36.95681972,36.45047712,35.94413452,35.43779192,34.93144932,34.42510672,33.91876412,33.41242151,32.90607891,32.39973631,31.89339371,31.38705111,30.88070851,30.37436591,29.8680233,29.3616807,28.8553381,28.3489955,27.8426529,27.3363103,26.8299677,26.3236251,25.81728249,25.31093989,24.80459729,24.29825469,23.79191209,23.28556949,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689,22.77922689};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,66.16008017,67.0404572,67.92083423,68.80121127,69.6815883,70.42946495,71.1773416,71.92521824,72.67309489,73.42097154,74.16884819,74.91672483,75.66460148,76.41247813,77.16035477,77.5339096,77.90746443,78.28101926,78.65457409,79.02812892,79.40168375,79.77523858,80.1487934,80.52234823,80.89590306,80.91751696,80.93913085,80.96074474,80.98235864,81.00397253,81.02558643,81.04720032,81.06881422,81.09042811,81.112042,81.34046986,81.56889772,81.79732558,82.02575343,82.25418129,82.48260915,82.71103701,82.93946487,83.16789272,83.39632058,83.58140095,83.76648133,83.9515617,84.13664207,84.32172245,84.50680282,84.69188319,84.87696357,85.06204394,85.24712431,85.17560606,85.10408781,85.03256956,84.96105131,84.88953306,84.81801481,84.74649656,84.67497831,84.60346006,84.53194181,84.54350715,84.55507249,84.56663783,84.57820317,84.58976851,84.60133385,84.61289919,84.62446453,84.63602987,84.64759521,84.33537508,84.02315495,83.71093482,83.39871469,83.08649457,82.77427444,82.46205431,82.14983418,81.83761405,81.52539392,81.430945,81.33649608,81.24204716,81.14759825,81.05314933,80.95870041,80.86425149,80.76980257,80.67535365,80.58090473,80.48645581,80.39200689,80.29755797,80.20310905,80.10866014,80.01421122,79.9197623,79.82531338,79.73086446,79.63641554,79.54196662,79.4475177,79.35306878,79.25861986,79.16417094,79.06972203,78.97527311,78.88082419,78.78637527,78.69192635,78.59747743,78.50302851,78.40857959,78.31413067,78.21968175,78.12523283,78.03078392,77.936335,77.84188608,77.74743716,77.65298824,77.55853932,77.4640904,77.36964148,77.27519256,77.18074364,77.08629472,76.99184581,76.89739689,76.80294797,76.70849905,76.61405013,76.51960121,76.42515229,76.33070337,76.23625445,76.14180553,76.04735661,75.9529077,75.85845878,75.76400986,75.66956094,75.57511202,75.4806631,75.38621418,75.29176526,75.19731634,75.10286742,75.0084185,74.91396959,74.81952067,74.72507175,74.63062283,74.53617391,74.44172499,74.34727607,74.25282715,74.15837823,74.06392931,73.96948039,73.87503148,73.78058256,73.68613364,73.59168472,73.4972358,73.40278688,73.30833796,73.21388904,73.11944012,73.0249912,72.93054229,72.83609337,72.74164445,72.64719553,72.55274661,72.45829769,72.36384877,72.26939985,72.17495093,72.08050201,71.98605309,71.89160418,71.79715526,71.70270634,71.60825742,71.5138085,71.41935958,71.32491066,71.23046174,71.13601282,71.0415639,70.94711498,70.85266607,70.75821715,70.66376823,70.56931931,70.47487039,70.38042147,70.28597255,70.19152363,70.09707471,70.00262579,69.90817687,69.81372796,69.71927904,69.62483012,69.5303812,69.43593228,69.34148336,69.24703444,69.15258552,69.0581366,68.96368768,68.86923876,68.77478985,68.68034093,68.58589201,68.49144309,68.39699417,68.30254525,68.20809633,68.11364741,68.01919849,67.92474957,67.83030065,67.73585174,67.64140282,67.5469539,67.45250498,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606,67.35805606};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,227.6426909,228.0405626,228.4384342,228.8363058,229.2341774,228.1913852,227.148593,226.1058008,225.0630086,224.0202165,222.9774243,221.9346321,220.8918399,219.8490477,218.8062555,217.8821935,216.9581315,216.0340695,215.1100075,214.1859455,213.2618835,212.3378215,211.4137595,210.4896975,209.5656355,209.0394505,208.5132654,207.9870804,207.4608953,206.9347103,206.4085252,205.8823402,205.3561551,204.8299701,204.303785,204.6249251,204.9460652,205.2672053,205.5883455,205.9094856,206.2306257,206.5517658,206.8729059,207.194046,207.5151861,207.0829338,206.6506815,206.2184293,205.786177,205.3539247,204.9216725,204.4894202,204.0571679,203.6249157,203.1926634,202.8850402,202.5774171,202.269794,201.9621708,201.6545477,201.3469246,201.0393014,200.7316783,200.4240552,200.116432,198.9621115,197.807791,196.6534705,195.49915,194.3448295,193.190509,192.0361885,190.881868,189.7275475,188.573227,186.0471806,183.5211342,180.9950878,178.4690414,175.942995,173.4169486,170.8909022,168.3648558,165.8388093,163.3127629,162.6346611,161.9565593,161.2784575,160.6003557,159.9222539,159.244152,158.5660502,157.8879484,157.2098466,156.5317448,155.853643,155.1755411,154.4974393,153.8193375,153.1412357,152.4631339,151.7850321,151.1069303,150.4288284,149.7507266,149.0726248,148.394523,147.7164212,147.0383194,146.3602175,145.6821157,145.0040139,144.3259121,143.6478103,142.9697085,142.2916066,141.6135048,140.935403,140.2573012,139.5791994,138.9010976,138.2229958,137.5448939,136.8667921,136.1886903,135.5105885,134.8324867,134.1543849,133.476283,132.7981812,132.1200794,131.4419776,130.7638758,130.085774,129.4076722,128.7295703,128.0514685,127.3733667,126.6952649,126.0171631,125.3390613,124.6609594,123.9828576,123.3047558,122.626654,121.9485522,121.2704504,120.5923485,119.9142467,119.2361449,118.5580431,117.8799413,117.2018395,116.5237377,115.8456358,115.167534,114.4894322,113.8113304,113.1332286,112.4551268,111.7770249,111.0989231,110.4208213,109.7427195,109.0646177,108.3865159,107.7084141,107.0303122,106.3522104,105.6741086,104.9960068,104.317905,103.6398032,102.9617013,102.2835995,101.6054977,100.9273959,100.2492941,99.57119226,98.89309045,98.21498863,97.53688682,96.858785,96.18068318,95.50258137,94.82447955,94.14637774,93.46827592,92.79017411,92.11207229,91.43397047,90.75586866,90.07776684,89.39966503,88.72156321,88.0434614,87.36535958,86.68725777,86.00915595,85.33105413,84.65295232,83.9748505,83.29674869,82.61864687,81.94054506,81.26244324,80.58434142,79.90623961,79.22813779,78.55003598,77.87193416,77.19383235,76.51573053,75.83762871,75.1595269,74.48142508,73.80332327,73.12522145,72.44711964,71.76901782,71.09091601,70.41281419,69.73471237,69.05661056,68.37850874,67.70040693,67.02230511,66.3442033,65.66610148,64.98799966,64.30989785,63.63179603,62.95369422,62.2755924,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059,61.59749059};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9475911458333,1851.5940551757812,1873.5191243489583,1885.9708862304688,1897.0604858398438,1906.8804626464844,1915.5205078125,1924.0206502278645,1933.3906962076824,1943.5707295735676,1954.4907735188801,1966.100809733073,1978.3508402506511,1991.1708679199219,2004.5209045410156,2018.3609110514324,2032.6410013834636,2047.8211364746094,2064.3311971028647,2082.061238606771,2100.911336263021,2120.7913411458335,2141.6114095052085,2163.3014526367188,2185.771484375,2208.9615478515625,2232.8115030924478,2256.9115193684897,2280.9215087890625,2304.8414713541665,2328.6714884440103,2352.4114786783853,2376.051472981771,2399.6114501953125,2423.0814819335938,2446.4514973958335,2469.7413736979165,2492.0211181640625,2512.4310506184897,2531.1110026041665,2548.1609700520835,2563.6908569335938,2577.82080078125,2590.6306966145835,2602.210652669271,2612.6406046549478,2622.010538736979,2630.4105224609375,2637.920450846354,2644.6004231770835,2650.5303548177085,2655.7403564453125,2660.2903442382812,2664.2303263346353,2667.6002604166665,2670.4302368164062,2672.7801717122397,2674.2900594075522,2674.6500244140625,2673.9499715169272,2672.2698974609375,2669.699910481771,2666.2898152669272,2662.1098429361978,2657.2398274739585,2651.7197875976562,2645.5996704101562,2638.609619140625,2630.479532877604,2621.2994995117188,2611.16943359375,2600.1593627929688,2588.3493855794272,2575.8193155924478,2562.6193033854165,2548.8192138671875,2534.469278971354,2520.0293172200522,2505.9393920898438,2492.1693725585938,2478.7093505859375,2465.5194295247397,2452.6094360351562,2439.9493815104165,2427.5293986002603,2415.3294067382812,2403.3394165039062,2391.4794311523438,2379.6594034830728,2367.909423828125,2356.199462890625,2344.5594889322915,2332.9894409179688,2321.479451497396,2310.0494181315103,2298.6894327799478,2287.409464518229,2276.20947265625,2265.0894571940103,2254.0594889322915,2243.0994873046875,2232.229451497396,2221.449462890625,2210.749471028646,2200.1294759114585,2189.5894775390625,2179.1395060221353,2168.7794596354165,2158.489501953125,2148.279541015625,2138.1595052083335,2128.1095174153647,2118.1395467122397,2108.2395222981772,2098.4195353190103,2088.6795247395835,2078.99951171875,2069.3995157877603,2059.8595377604165,2050.3895365397134,2040.9895324707031,2031.6495463053386,2022.3795572916667,2013.1695353190105,2004.0195414225261,1994.9195454915364,1985.8895365397136,1976.9095357259114,1967.9795430501301,1959.1095479329426,1950.28955078125,1941.5195617675781,1932.7995503743489,1924.1195576985676,1915.4995829264324,1906.9195556640625,1898.3795674641926,1889.8895568847656,1881.4295654296875,1873.0195719401042,1864.6495768229167,1856.3195699055989,1848.0195821126301,1839.7595825195312,1831.5395609537761,1823.3495686848958,1815.1895650227864,1807.0595804850261,1798.9695739746094,1790.9095764160156,1782.8795776367188,1774.8795878092449,1766.9095662434895,1758.9595743815105,1751.0396016438801,1743.1495971679688,1735.2795817057292,1727.4395650227864,1719.6195780436199,1711.8195902506511,1704.0495910644531,1696.2995503743489,1688.569580078125,1680.8595784505208,1673.1695963541667,1665.4995727539062,1657.8595886230469,1650.2195841471355,1642.6095682779949,1635.0195821126301,1627.4395853678386,1619.8795776367188,1612.3395894368489,1604.8095703125,1597.299580891927,1589.799580891927,1582.3195699055989,1574.849589029948,1567.3995869954426,1559.9595947265625,1552.5295817057292,1545.1095784505208,1537.7095845540364,1530.319580078125,1522.9395853678386,1515.5795796712239,1508.2195841471355,1500.8795878092449,1493.5396016438801,1486.2195841471355,1478.9095967610676,1471.6095784505208,1464.309549967448,1457.0295715332031,1449.7595723470051,1442.4895833333333,1435.2395833333333,1427.9895731608074,1420.7495727539062,1413.5195719401042,1406.299560546875,1399.0795491536458,1391.8695678710938,1384.6695760091145,1377.4695638020833,1370.2895609537761,1363.0995992024739,1355.9295654296875,1348.7595621744792,1341.5995686848958,1334.4395751953125,1327.28955078125,1320.1495666503906,1313.0095621744792,1305.8795674641926,1298.7595621744792,1291.6395467122395,1284.5195617675781,1277.4195658365886,1270.3095703125,1263.2095743815105,1256.1195678710938,1249.029561360677,1241.9495646158855,1234.8695678710938,1227.799560546875,1220.7295532226562,1213.6595662434895,1206.5995483398438,1199.549560546875,1192.4995422363281,1185.4495544433594,1178.4095560709636,1171.3695576985676,1164.329569498698,1157.2995503743489,1150.2695821126301,1143.5796407063801,1137.4996744791667,1131.9796854654949,1126.9697163899739,1122.4197285970051,1118.2697652180989,1114.4997660319011,1111.059794108073,1107.9298095703125,1105.0698140462239,1102.4498291015625,1100.0498352050781,1097.8598531087239,1095.8398539225261,1093.9798787434895,1092.2798563639324,1090.6998697916667,1089.2398681640625,1087.889892578125,1086.639892578125,1085.4698893229167,1084.3799133300781,1083.3599039713542,1082.3998921712239,1081.5099080403645,1080.6599019368489,1079.8598937988281,1079.0999043782551,1078.3799336751301,1077.6999104817708,1077.0399169921875,1076.4199117024739,1075.8099263509114,1075.2299194335938,1074.6799418131511,1074.1399027506511,1073.6099141438801,1073.0999348958333,1072.6099039713542,1072.1199340820312,1071.6499125162761,1071.189921061198,1070.7399495442708,1070.2999369303386,1069.8599243164062,1069.429931640625,1069.0099487304688,1068.5899353027344,1068.1699320475261,1067.7699279785156,1067.3599243164062,1066.9599202473958,1066.5699259440105,1066.169921875,1065.7799377441406,1065.399922688802,1065.0099385579426,1064.6299438476562,1064.2499186197917,1063.8699340820312,1063.4999287923176,1063.1199239095051,1062.7499389648438,1062.3799133300781,1062.0099283854167,1061.6399230957031,1061.2799275716145,1060.9099222819011,1060.5499369303386,1060.1799214680989,1059.8199259440105,1059.459940592448,1059.0999247233074,1058.7399190266926,1058.3899332682292,1058.0299275716145,1057.6799418131511,1057.3199157714844,1056.9699096679688,1056.6099344889324,1056.2599283854167,1055.9099222819011,1055.5599466959636,1055.209940592448,1054.8599243164062,1054.5199076334636,1054.1799214680989,1053.8499247233074,1053.5399169921875,1053.2199605305989,1052.919942220052,1052.6199239095051,1052.3299255371094,1052.0399068196614,1051.7499287923176,1051.4699401855469,1051.1899515787761,1050.9199320475261,1050.6499430338542,1050.3799235026042,1050.1099344889324,1049.8399353027344,1049.5799153645833,1049.3099466959636,1049.0499471028645,1048.7899373372395,1048.5299173990886,1048.2799377441406,1048.0199178059895,1047.7599385579426,1047.5099385579426,1047.2599385579426,1046.9999287923176,1046.7499389648438,1046.4999287923176,1046.2499186197917,1045.9999389648438,1045.7499389648438,1045.4999389648438,1045.2599385579426,1045.0099487304688,1044.7699279785156,1044.5199381510417,1044.2799173990886,1044.0399373372395,1043.7999471028645,1043.5599365234375,1043.3199259440105,1043.0799458821614,1042.8499450683594,1042.6099446614583,1042.3799438476562,1042.1499532063801,1041.909932454427,1041.679931640625,1041.4499409993489,1041.2199300130208,1040.9899393717449,1040.7599487304688,1040.5299275716145,1040.2999369303386,1040.0699462890625,1039.8499450683594,1039.6199340820312,1039.3899434407551,1039.169942220052,1038.949930826823,1038.7199401855469,1038.4999389648438,1038.2799377441406,1038.0499572753906,1037.8299255371094,1037.6099446614583,1037.3899434407551,1037.1699320475261,1036.949930826823,1036.7299397786458,1036.5199381510417,1036.2999471028645,1036.0799560546875,1035.8699340820312,1035.6499532063801,1035.439921061198,1035.2199198404949,1035.0099283854167,1034.7899576822917,1034.5799357096355,1034.3699340820312,1034.1599222819011,1033.9499409993489,1033.7399495442708,1033.5299479166667,1033.3199361165364,1033.1099446614583,1032.8999532063801,1032.68994140625,1032.4899495442708,1032.2799377441406,1032.0699564615886,1031.8699442545574,1031.6599527994792,1031.459940592448,1031.2499389648438,1031.0499267578125,1030.8499450683594,1030.6499328613281,1030.43994140625,1030.2399393717449,1030.0399271647136,1029.8399353027344,1029.6399332682292,1029.4399312337239,1029.2499491373699,1029.0499369303386,1028.8499450683594,1028.6499328613281,1028.459940592448,1028.2599487304688,1028.0699361165364,1027.8699544270833,1027.679946899414,1027.4799346923828,1027.2899271647136,1027.0999196370442,1026.899917602539,1026.709945678711,1026.5199483235676,1026.3299407958984,1026.1399485270183,1025.949951171875,1025.7599334716797,1025.5699412027996,1025.3799489339192,1025.199930826823,1025.0099487304688,1024.8199259440105,1024.6399485270183,1024.449946085612,1024.2699381510417,1024.0799509684246,1023.8999430338541,1023.7099456787109,1023.5299479166666,1023.3499450683594,1023.169932047526,1022.9799499511719,1022.7999318440756,1022.6199544270834,1022.43994140625,1022.2599436442057,1022.0799357096354,1021.8999328613281,1021.7299397786459,1021.5499420166016,1021.3699340820312,1021.189951578776,1021.0199381510416,1020.8399353027344,1020.6599527994791,1020.4899393717448,1020.3099466959635,1020.1399434407552,1019.9699350992838,1019.7899373372396,1019.6199391682943,1019.449940999349,1019.2799326578776,1019.1099497477213,1019.0199381510416};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.94878641764325,403.11696370442706,405.79396057128906,408.7599639892578,411.78996022542316,414.8909632364909,418.06495666503906,421.33495839436847,424.720952351888,428.21995544433594,431.82995859781903,435.5499547322591,439.37795003255206,443.31495157877606,447.36094665527344,451.51494852701825,455.7789484659831,460.16394805908203,464.6819483439128,469.33094533284503,474.1119384765625,479.02494049072266,484.07193756103516,489.2519353230794,494.5669352213542,500.01893107096356,505.60793050130206,511.34192657470703,517.2279256184896,523.2669321695963,529.4599202473959,535.8089345296224,542.3139139811198,548.9769185384115,555.7999216715494,562.783925374349,569.9299163818359,577.2579091389974,584.7839202880859,592.5069071451823,600.4289093017578,608.5499013264974,616.8699035644531,625.3909047444662,634.1138865152994,643.0408986409506,652.1719004313151,661.5069071451823,671.0448862711588,680.7888946533203,690.7388814290365,700.8988850911459,711.2688802083334,721.8508860270182,732.6478830973307,743.6618703206381,754.8928833007812,766.3228708902994,777.9298706054688,789.7188822428385,801.6908721923828,813.8478749593099,826.19287109375,838.7268778483073,851.4518636067709,864.3688659667969,877.4798634847006,890.7088673909506,903.9808654785156,917.3008728027344,930.6708628336588,944.0918680826823,957.5668690999349,971.0958658854166,984.6808675130209,998.3208618164062,1012.0198669433594,1025.7398529052734,1039.4498596191406,1053.149881998698,1066.849873860677,1080.5298563639324,1094.2098795572917,1107.8898620605469,1121.5498758951824,1135.2098693847656,1148.8598734537761,1162.4698791503906,1176.0298665364583,1189.5298767089844,1202.9798889160156,1216.369873046875,1229.6998697916667,1242.9698791503906,1256.1898701985676,1269.3498942057292,1282.4498697916667,1295.4898783365886,1308.4698791503906,1321.3898824055989,1334.2498881022136,1347.0498657226562,1359.7798970540364,1372.4398803710938,1385.0398966471355,1397.5698852539062,1410.0398864746094,1422.4298807779949,1434.7598876953125,1447.0099080403645,1459.1898803710938,1471.2898864746094,1483.3199055989583,1495.2798970540364,1507.1599019368489,1518.9598897298176,1530.6798909505208,1542.3198954264324,1553.879903157552,1565.3599039713542,1576.7598978678386,1588.0799051920574,1599.3099060058594,1610.4499104817708,1621.5098876953125,1632.4899088541667,1643.3799133300781,1654.169901529948,1664.8799235026042,1675.5098978678386,1686.0399068196614,1696.4798990885417,1706.8198954264324,1717.0799255371094,1727.2399088541667,1737.3199055989583,1747.2899271647136,1757.1699117024739,1766.9499104817708,1776.6399027506511,1786.2199096679688,1795.6999104817708,1805.0799255371094,1814.3599141438801,1823.5399271647136,1832.6099243164062,1841.5799051920574,1850.4599202473958,1859.2199198404949,1867.8899230957031,1876.449930826823,1884.8999328613281,1893.2399393717449,1901.4899393717449,1909.6199239095051,1917.6499125162761,1925.5799255371094,1933.3999328613281,1941.1099446614583,1948.7099304199219,1956.2099304199219,1963.5999450683594,1970.8799336751301,1978.0499369303386,1985.1099548339844,1992.0699462890625,1998.9299418131511,2005.669942220052,2012.2999369303386,2018.8299458821614,2025.2499491373699,2031.5599365234375,2037.7599589029949,2043.8499552408855,2049.8099365234375,2055.6599324544272,2061.419962565104,2067.0899658203125,2072.6399739583335,2078.0599161783853,2083.3799641927085,2088.5899454752603,2093.679972330729,2098.6699829101562,2103.539998372396,2108.3099568684897,2112.959920247396,2117.5099283854165,2121.9499308268228,2126.2699584960938,2130.4899698893228,2134.5899454752603,2138.5999552408853,2142.47998046875,2146.2599487304688,2149.929972330729,2153.47998046875,2156.9199829101562,2160.239949544271,2163.4599405924478,2166.5700073242188,2169.5799763997397,2172.479939778646,2175.2699584960938,2177.929972330729,2180.489990234375,2182.9500122070312,2185.2899373372397,2187.519978841146,2189.6500244140625,2191.6699829101562,2193.5699666341147,2195.3299560546875,2197.009969075521,2198.5899658203125,2200.0700073242188,2201.4299519856772,2202.6599731445312,2203.789998372396,2204.8099975585938,2205.7300008138022,2206.529988606771,2207.22998046875,2207.8099975585938,2208.289998372396,2208.6500040690103,2208.9099934895835,2209.0699462890625,2209.1099853515625,2209.029988606771,2208.8400065104165,2208.5699869791665,2208.1900024414062,2207.6900024414062,2207.0700073242188,2206.3500162760415,2205.5199991861978,2204.6399739583335,2203.75,2202.8600260416665,2201.9699910481772,2201.0999959309897,2200.220011393229,2199.3399861653647,2198.4400024414062,2197.539998372396,2196.6299845377603,2195.7300008138022,2194.8300170898438,2193.9500325520835,2193.0599975585938,2192.1600341796875,2191.2500203450522,2190.3400065104165,2189.4300130208335,2188.5299682617188,2187.6200154622397,2186.7199910481772,2185.8200073242188,2184.9000244140625,2183.989990234375,2183.0899861653647,2182.1900024414062,2181.289998372396,2180.3999837239585,2179.4999796549478,2178.5999959309897,2177.7000122070312,2176.8000284830728,2175.9100138346353,2175.010009765625,2174.1199951171875,2173.2300008138022,2172.3399861653647,2171.4600423177085,2170.5700073242188,2169.6799926757812,2168.7900187174478,2167.9099934895835,2167.029988606771,2166.1399943033853,2165.2699991861978,2164.4000244140625,2163.5199584960938,2162.6300659179688,2161.740030924479,2160.8700154622397,2159.9999796549478,2159.1400146484375,2158.2699991861978,2157.3999837239585,2156.5300089518228,2155.6599731445312,2154.789998372396,2153.9200236002603,2153.0600382486978,2152.220011393229,2151.3699747721353,2150.5199991861978,2149.6599934895835,2148.8099975585938,2147.9500528971353,2147.0900065104165,2146.2399698893228,2145.3900146484375,2144.5400187174478,2143.699991861979,2142.8599650065103,2142.02001953125,2141.1700236002603,2140.3099772135415,2139.4600219726562,2138.6199747721353,2137.7999877929688,2136.9600219726562,2136.1399943033853,2135.3200073242188,2134.4700317382812,2133.6200154622397,2132.800008138021,2131.9900105794272,2131.1400146484375,2130.289998372396,2129.4699503580728,2128.6499837239585,2127.8299763997397,2127.0,2126.1800130208335,2125.3800048828125,2124.5700073242188,2123.750040690104,2122.9200032552085,2122.1000162760415,2121.2899780273438,2120.4799601236978,2119.669962565104,2118.8599650065103,2118.0499877929688,2117.239990234375,2116.4300130208335,2115.6300048828125,2114.820027669271,2114.02001953125,2113.210001627604,2112.4099934895835,2111.6000162760415,2110.81005859375,2110.009969075521,2109.219970703125,2108.4199829101562,2107.6200154622397,2106.8299967447915,2106.0300089518228,2105.2399698893228,2104.4500122070312,2103.6599934895835,2102.8800252278647,2102.0899861653647,2101.300008138021,2100.529988606771,2099.739949544271,2098.949991861979,2098.1700032552085,2097.3899943033853,2096.6100260416665,2095.8300170898438,2095.039998372396,2094.2599894205728,2093.4900105794272,2092.7300008138022,2091.9500122070312,2091.1700032552085,2090.3899739583335,2089.6200154622397,2088.8700154622397,2088.0900065104165,2087.2999877929688,2086.5500284830728,2085.800008138021,2085.0300089518228,2084.25,2083.4800008138022,2082.72998046875,2081.970011393229,2081.22998046875,2080.480021158854,2079.7000122070312,2078.949991861979,2078.220011393229,2077.460001627604,2076.689982096354,2075.9399617513022,2075.1900024414062,2074.4400227864585,2073.6900227864585,2072.9500325520835,2072.199991861979,2071.4400024414062,2070.7100219726562,2069.970011393229,2069.220011393229,2068.47998046875,2067.7400105794272,2067.0,2066.260009765625,2065.529988606771,2064.7899780273438,2064.0499877929688,2063.3199869791665,2062.5899861653647,2061.8600056966147,2061.1300252278647,2060.4000040690103,2059.6599934895835,2058.9299926757812,2058.2099812825522,2057.4899698893228,2056.77001953125,2056.0499674479165,2055.3199869791665,2054.5999959309897,2053.8700358072915,2053.1400146484375,2052.4200032552085,2051.700022379557,2050.9800008138022,2050.260009765625,2049.5499877929688,2048.8299967447915,2048.1200358072915,2047.4100036621094,2046.6999918619792,2045.9800109863281,2045.2799987792969,2044.5800069173176,2043.8799845377605,2043.1700032552083,2042.4600016276042,2041.75,2041.0499979654949,2040.3599853515625,2039.6500040690105,2038.9400024414062,2038.2400004069011,2037.5499877929688,2036.8600158691406,2036.1499938964844,2035.4500020345051,2034.7499898274739,2034.0600077311199,2033.3699849446614,2032.6900126139324,2031.9999898274739,2031.2999877929688,2030.5999959309895,2029.9199930826824,2029.2400004069011,2028.5499979654949,2027.8500061035156,2027.1600036621094,2026.469991048177,2025.7899881998699,2025.1099955240886,2024.4300028483074,2023.7400004069011,2023.0699869791667,2022.4199829101562,2021.7200113932292,2021.0400085449219,2020.4000040690105,2019.7000020345051,2019.019999186198,2018.3700052897136,2017.6700032552083,2016.989990234375,2016.3499959309895,2015.6799926757812,2015.000020345052,2014.3300069173176,2013.6700032552083,2013.0099995930989,2012.3399963378906,2011.6699930826824,2011.0099995930989,2010.3599955240886,2010.0199890136719};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.753954728444416,21.18809445699056,23.582992553710938,28.04569133122762,33.29298973083496,39.29728921254476,46.031688372294106,53.39218680063883,61.27928606669108,69.67468452453613,78.56088320414226,87.92068227132161,97.73788261413574,107.99598121643066,118.6809794108073,129.77597745259604,141.2679786682129,152.9639778137207,164.6779759724935,176.40897623697916,188.15697479248047,199.9219767252604,211.70197550455728,223.49797566731772,235.3089739481608,247.13397343953451,258.97397232055664,270.89896901448566,282.97996520996094,295.21296946207684,307.5939687093099,320.1199696858724,332.7859649658203,345.5879669189453,358.521967569987,371.584966023763,384.77296447753906,398.12396240234375,411.67095947265625,425.40296427408856,439.30896759033203,453.3789647420247,467.6029586791992,481.96996307373047,496.47196197509766,511.0979537963867,525.8399505615234,540.7299550374349,555.8029429117838,571.0489501953125,586.4579569498698,602.0209452311198,617.7299499511719,633.5749664306641,649.5479532877604,665.6409505208334,681.8469441731771,697.9729461669922,713.8349456787109,729.4359436035156,744.7799479166666,759.8729451497396,774.7169443766276,789.3189493815104,803.6799519856771,817.8069356282552,831.7019449869791,845.1509450276693,857.9459381103516,870.1049448649088,881.6459452311198,892.5889485677084,902.949951171875,912.7479604085287,921.9979502360026,930.7179514567057,938.9239349365234,946.5829467773438,953.6639455159506,960.189951578776,966.1809488932291,971.6569468180338,976.6389516194662,981.1449534098307,985.1939544677734,988.8029530843099,991.9889424641927,994.7279459635416,996.9959513346354,998.8109486897787,1000.1899464925131,1001.1499582926432,1001.699961344401,1001.8599548339844,1001.6499481201172,1001.0799509684244,1000.1699523925781,998.9269612630209,997.3679504394531,995.5069580078125,993.3549550374349,990.9249521891276,988.2289530436198,985.2799631754557,982.0879567464193,978.6639607747396,975.0189514160156,971.1629435221354,967.1059519449869,962.8569641113281,958.4249471028646,953.8199564615885,949.0499623616537,944.1219635009766,939.0459696451823,933.8279673258463,928.4759623209635,922.9969584147135,917.3979644775391,911.6849568684896,905.8639628092448,899.9419657389323,893.9239552815756,887.8149617513021,881.6219533284506,875.3489583333334,869.000966389974,862.5829671223959,856.0989634195963,849.5529632568359,842.9499715169271,836.2939758300781,829.5869649251302,822.8349609375,816.0389709472656,809.2039642333984,802.3329569498698,795.4289703369141,788.4929656982422,781.5299631754557,774.5419769287109,767.5299682617188,760.4989776611328,753.4479675292969,746.3819681803385,739.3019765218099,732.2089691162109,725.1049753824869,717.9929606119791,710.8739776611328,703.7489624023438,696.6199696858724,689.4879760742188,682.35498046875,675.2209676106771,668.0889689127604,660.9579722086588,653.8309682210287,646.7069702148438,639.5889841715494,632.4759775797526,625.3699696858724,618.2709655761719,611.1799672444662,604.0989735921224,597.0259755452474,589.9629770914713,582.9109700520834,575.8699747721354,568.8399759928385,561.8229777018229,554.8169860839844,547.823974609375,540.8439737955729,533.8779805501302,526.9249827067057,519.9859720865885,513.0609741210938,506.14998118082684,499.2539800008138,492.37198130289715,485.5049819946289,478.6539815266927,471.81698354085285,464.9959767659505,458.18898010253906,451.39898681640625,444.6229832967122,437.8629862467448,431.1189829508464,424.38998158772785,417.67698669433594,410.9789861043294,404.29698435465497,397.63098398844403,390.97998301188153,384.34398651123047,377.72398376464844,371.1199900309245,364.52999114990234,357.95698801676434,351.39798736572266,344.854985555013,338.3269856770833,331.8149922688802,325.3169911702474,318.83399200439453,312.3659973144531,305.9139912923177,299.4749933878581,293.05198923746747,286.6429901123047,280.24899037679035,273.86999257405597,267.5039927164714,261.1529947916667,254.8169962565104,248.49399439493814,242.18599446614584,235.89099629720053,229.6109937032064,223.34399541219076,217.09099451700845,210.85199356079102,204.62599817911783,198.4149958292643,192.21599833170572,186.03099568684897,179.85899607340494,173.70100021362305,167.55499521891275,161.4229965209961,155.30399958292642,149.197998046875,143.10499827067056,137.0249989827474,130.95800018310547,125.03000005086263,119.36299959818523,113.9450003306071,108.76800028483073,103.82100041707356,99.0948003133138,94.57969983418782,90.26699892679851,86.14799944559734,82.2145004272461,78.45829963684082,74.87179883321126,71.44759941101074,68.17850112915039,65.05779997507732,62.078700383504234,59.235100428263344,56.520800272623696,53.930200258890785,51.45760027567545,49.0977996190389,46.845699628194176,44.69640032450358,42.645300229390465,40.68790054321289,38.82010014851888,37.03770033518473,35.33690039316813,33.71389929453532,32.16530021031698,30.687599976857502,29.277599970499676,27.932199954986572,26.648500283559162,25.42360003789266,24.254899978637695,23.13980007171631,22.075900077819824,21.060800234476726,20.092300097147625,19.168199857076008,18.286500136057537,17.44539992014567,16.642800172170002,15.877099990844727,15.146600008010864,14.449600060780844,13.784599939982096,13.150200128555298,12.544899940490723,11.967400074005127,11.416500091552734,10.890900055567423,10.38949998219808,9.911070108413696,9.454669952392578,9.01924999554952,8.60384996732076,8.207549969355265,7.829479972521464,7.4687899351119995,7.124690016110738,6.796430031458537,6.483259956041972,6.184499899546306,5.899490038553874,5.62758998076121,5.368200023969014,5.120750029881795,4.884690046310425,4.6594999233881635,4.444670041402181,4.239730040232341,4.044219970703125,3.8577199578285217,3.6797999938329062,3.5100799997647605,3.3481800158818564,3.1937299768129983,3.0463899771372476,2.905839999516805,2.7717700004577637,2.643869956334432,2.521869977315267,2.405490001042684,2.2944699923197427,2.188569962978363,2.0875700314839682,1.9912200172742207,1.8993299901485443,1.8116699953873951,1.7280700107415516,1.6483199894428253,1.5722499986489613,1.4996900061766307,1.430489997069041,1.3644799888134003,1.3015100061893463,1.2414499918619792,1.1841599941253662,1.1295199990272522,1.077400008837382,1.0276900231838226,0.9802650064229965,0.9350329985221227,0.8918890009323756,0.8507359971602758,0.8114819924036661,0.7740399887164434,0.7383259981870651,0.7042610098918279,0.671766996383667,0.6407730033000311,0.6112100034952164,0.5830099930365881,0.5561130046844482,0.5304560015598933,0.5059829925497373,0.4826400006810824,0.46037400017182034,0.43913499762614566,0.4188769981265068,0.3995530034104983,0.3811209996541341,0.36354000369707745,0.3467690000931422,0.3307729984323184,0.3155150040984154,0.3009599993626277,0.28707800308863324,0.2738350008924802,0.261203999320666,0.24915599698821703,0.23766299958030382,0.22670100008447966,0.21624499807755151,0.20627099896470705,0.19675700118144354,0.1876820002992948,0.17902600020170212,0.1707690010468165,0.16289300099015236,0.15538000191251436,0.14821399872501692,0.14137899999817213,0.13485800102353096,0.12863899891575178,0.1227070006231467,0.11704800029595692,0.11165000001589458,0.10650099938114484,0.10159000071386497,0.09690539973477523,0.09243679915865262,0.0881742996474107,0.08410839984814326,0.08023009883860747,0.07653060058752696,0.07300180072585742,0.06963579977552097,0.06642500000695388,0.06336229853332043,0.06044080046315988,0.057654100159804024,0.05499589970956246,0.05246029980480671,0.05004160013049841,0.04773450021942457,0.045533799876769386,0.043434600035349526,0.041432199689249195,0.03952209961911043,0.03770010049144427,0.03596209983030955,0.034304299702246986,0.03272290031115214,0.031214499846100807,0.02977559979384144,0.028403100091964006,0.02709379993999998,0.02584490009273092,0.024653599752734106,0.023517200102408726,0.022433299881716568,0.021399300079792738,0.020412900019437075,0.019472099995861452,0.018574600107967854,0.01771849999204278,0.016901900060474873,0.01612290010477106,0.015379899957527718,0.014671099915479621,0.013994899966443578,0.013350000216936072,0.012734800033892194,0.012147900105143586,0.011588100111111999,0.011054099925483266,0.0105447000823915,0.010058799913773933,0.009595289981613556,0.009153150022029877,0.008731379949798187,0.00832906000626584,0.00794528987413893,0.007579200008573632,0.007229980003709595,0.006896860043828686,0.006579099999119838,0.006275979957232873,0.005986830025600891,0.005710999985846381,0.005447890027426183,0.005196910002268851,0.004957490018568933,0.004729099998561044,0.0045112400548532605,0.004303420040135582,0.004105179997471471,0.003916069962239514,0.0037356800166890025,0.003563599990836034,0.003399450002082934,0.0032428599855241678,0.003093489989017447,0.0029509999828102687,0.0028150699993905923,0.0026854099899840853,0.0025617299834266305,0.0024437400279566646,0.0023311899858526886,0.0022238200181163847,0.0021214000104616084,0.002023700023225198,0.0019304999829425167,0.0018415900024895866,0.0017567800047496955,0.0016758799902163446,0.0015987100002045433,0.0015250799964026858,0.0014548599914026756,0.001387860005100568,0.0013239500015818824,0.0012629900108246754,0.0012048300025829424,0.0011493599934813876,0.0010964300017803907,0.001070600003004074};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76681009928386,90.27675183614095,96.32187016805013,101.78844515482585,107.54095141092937,113.55129114786784,119.79557673136394,126.05044492085774,132.1101557413737,137.98892211914062,143.6996981302897,149.25649388631186,154.6683006286621,159.94812774658203,165.10295740763345,170.1438217163086,175.07866032918295,179.79629516601562,184.19484837849936,188.30046590169272,192.13510386149088,195.7197723388672,199.0754712422689,202.21918741861978,205.16693623860678,207.93367640177408,210.5334841410319,213.1466064453125,215.93587493896484,218.88808059692383,221.99128341674805,225.23446782430014,228.60463587443033,232.0927937825521,235.68994013468424,239.3880704243978,243.17819213867188,247.07434844970703,251.08750788370767,255.20263799031576,259.4067548116048,263.68785603841144,268.0359395345052,272.4410120646159,276.89307657877606,281.3841247558594,285.90617116292316,290.5183283487956,295.2725346883138,300.1566925048828,305.15685272216797,310.260986328125,315.4581044514974,320.7372131347656,326.0903091430664,331.5073979695638,336.9814707438151,342.4183629353841,347.73316955566406,352.9300257364909,358.0138676961263,362.9887212117513,367.85858154296875,372.6264419555664,377.2973175048828,381.87518819173175,386.362065633138,390.62968190511066,394.55919138590497,398.1717936197917,401.48938751220703,404.5290247599284,407.3116811116536,409.85135650634766,412.1660639444987,414.2707773844401,416.1785202026367,417.8531773885091,419.26180267333984,420.42750040690106,421.3691889444987,422.10793050130206,422.65867106119794,423.03845469156903,423.2622426350911,423.3440653483073,423.29387919108075,423.0245081583659,422.4500961303711,421.5967305501302,420.4863866170247,419.1400782267253,417.57979583740234,415.8225326538086,413.88629659016925,411.7870864868164,409.54089101155597,407.15970611572266,404.65855662027997,402.04740651448566,399.3382822672526,396.5411605834961,393.66505940755206,390.71997324625653,387.7118886311849,384.64981842041016,381.5397542317708,378.387700398763,375.19865163167316,371.97961171468097,368.73358154296875,365.46655527750653,362.18052673339844,358.88050587972003,355.57050069173175,352.25148518880206,348.9264780680339,345.59947713216144,342.27147674560547,338.94447835286456,335.62048085530597,332.30149332682294,328.9875005086263,325.6825129191081,322.38452402750653,319.09654235839844,315.81954701741535,312.55356852213544,309.298578898112,306.0565999348958,302.82762145996094,299.6126403808594,296.41065979003906,293.2226740519206,290.04869333902997,286.88971455891925,283.7457326253255,280.6157506306966,277.5007731119792,274.4007924397786,271.31481170654297,268.2448323567708,265.18885294596356,262.1468734741211,259.12089411417645,256.10790888468426,253.10993321736655,250.12695185343424,247.1569684346517,244.20098876953125,241.25900904337564,238.33002599080405,235.41504542032877,232.5130615234375,229.6230786641439,226.74709828694662,223.88311513264975,221.03213246663412,218.19314829508463,215.3661626180013,212.55017852783203,209.74719365437826,206.9552090962728,204.1742261250814,201.40423838297525,198.64525604248047,195.89626693725586,193.15928649902344,190.4312947591146,187.7143122355143,185.0063222249349,182.30934143066406,179.6213493347168,176.94236501057944,174.27337646484375,171.61338806152344,168.96240234375,166.31941095987955,163.6864242553711,161.0614331563314,158.44444783528647,155.83545939127603,153.235471089681,150.64347966512045,148.05848948160806,145.48149998982748,142.9125124613444,140.35152180989584,137.79653294881186,135.24954096476236,132.70955022176108,130.17756017049155,127.65157127380371,125.13257789611816,122.61958758036296,120.11459795633952,117.61560567220052,115.12261454264323,112.63662338256836,110.15663146972656,107.68263943990071,105.21464920043945,102.75365702311198,100.29766464233398,97.84807205200195,95.40428098042806,92.96618843078613,90.53389739990234,88.10720443725586,85.68611081441243,83.27051734924316,80.86042594909668,78.4557336171468,76.05644035339355,73.66244824727376,71.2737553914388,68.89026196797688,66.51206906636556,64.13887564341228,61.77088292439779,59.407990137736,57.05009619394938,54.69720331827799,52.34931023915609,50.006317138671875,47.66832319895426,45.335130055745445,43.006836891174316,40.68344370524088,38.36474927266439,36.05095609029134,33.741861979166664,31.437569618225098,29.13807471593221,26.843283971150715,24.55318291982015,22.267802238464355,20.094918251037598,18.131423155466717,16.357462008794148,14.755392710367838,13.308695554733276,12.002581199010214,10.823648611704508,9.759750048319498,8.799716711044312,7.933560411135356,7.152201890945435,6.447412768999736,5.811763763427734,5.2385358810424805,4.721619923909505,4.255546847979228,3.835327168305715,3.456481655438741,3.1149507562319436,2.8070950309435525,2.5295849442481995,2.279450992743174,2.054003417491913,1.850812743107478,1.6676891247431438,1.5026529332002003,1.3539243737856548,1.2198937038580577,1.0991211632887523,0.9902798434098562,0.8922070215145746,0.8038357595602671,0.7242072770992914,0.6524576246738434,0.5878099749485651,0.5295613904794058,0.4770789792140325,0.4297928065061569,0.3871889685591062,0.3488055194417636,0.3142235154906909,0.283067025244236,0.254997082054615,0.2297087386250496,0.2069260353843371,0.1864010045925776,0.16791068265835443,0.15125309055050215,0.13624626273910204,0.12272722149888675,0.11054898425936699,0.09957837251325448,0.08969560327629249,0.08079289086163044,0.072773152962327,0.06554899954547484,0.059041441728671394,0.053179391038914524,0.04789905591557423,0.04314264468848705,0.038858165654043354,0.03499892478187879,0.031522728192309536,0.028391482153286535,0.02557119121775031,0.023030759301036596,0.020742591004818678,0.018681589514017105,0.0168251587698857,0.015153201141705116,0.013647219554210702,0.012290816210831204,0.011069093520442644,0.009968783085544905,0.008977756757910052,0.008085196216901144,0.007281302862490217,0.006557297970478733,0.0059052225745593505,0.005317957800192137,0.004789054510183632,0.00431272368102024,0.00388373585883528,0.003497391977968315,0.00314945246403416,0.002836107994274547,0.002553948957938701,0.0022998558318552873,0.002071039149692903,0.0018649990961421281,0.0016794560263709475,0.0015123802974509697,0.0013619221475285788,0.0012264318259743352,0.0011044195562135428,0.0009945535275619477,0.0008956159047860032,0.0008065208385232836,0.0007262905031287422,0.0006540420048016434,0.0005889804548739145,0.0005303919606376439,0.00047763262652248767,0.00043012152552061406,0.000387337740297274,0.0003488093352643773,0.00031411337840836495,0.00028286991679730516,0.00025473400213134784,0.00022939668148562,0.0002065799987273446,0.00018603298061255677,0.00016752966742690964,0.00015086708905679794,0.00013586226972014023,0.00012235023132234346,0.0001101809975807555,9.922329203012244e-05,8.935512293343588e-05,8.046851447337151e-05,7.246577661135234e-05,6.525902487434602e-05,5.8769065617525484e-05,5.292461446515517e-05,4.7661479887513757e-05,4.292166734861288e-05,3.865338658215478e-05,3.4809545165141266e-05,3.134804774163058e-05,2.823080073236876e-05,2.5423508456394e-05,2.2895475770686364e-05,2.0618805895840826e-05,1.8568604142880456e-05,1.67222716906205e-05,1.5059513543747016e-05,1.3562131016442436e-05,1.2213626556937621e-05,1.0999203141182079e-05,9.905602003830912e-06,8.920724894778687e-06,8.033773610804928e-06,7.235029746273843e-06,6.515704058074334e-06,5.867908195493025e-06,5.284512932727618e-06,4.759139225522328e-06,4.285997571666182e-06,3.859899720737303e-06,3.476175398494282e-06,3.1305955493129054e-06,2.8193807490121494e-06,2.539101425706273e-06,2.2866881295158237e-06,2.059371070117777e-06,1.8546608278787364e-06,1.6702975642601814e-06,1.5042616610116966e-06,1.3547333518696785e-06,1.220072931573668e-06,1.0988005101353338e-06,9.895803761613327e-07,8.912196515590646e-07,8.026365113285768e-07,7.228590893267514e-07,6.510125274417078e-07,5.863069153141017e-07,5.280343771119078e-07,4.7555398670814003e-07,4.282898492154648e-07,3.8572402871750455e-07,3.473895873185029e-07,3.128646000050139e-07,2.817721096448622e-07,2.537691775235847e-07,2.2855083751475527e-07,2.0583813172455243e-07,1.853821001892205e-07,1.6696077646353538e-07,1.503691796263714e-07,1.3542634983802296e-07,1.219693051742373e-07,1.098500626757944e-07,4.2102797692677996e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.742686986923218,19.401511669158936,20.785216967264812,23.29192002614339,26.184722582499187,29.455424626668293,33.09572680791219,37.075628916422524,41.366031328837074,45.960433642069496,50.85233497619629,56.03573767344157,61.504340489705406,67.25214258829753,73.27334531148274,79.56204605102539,86.1126480102539,92.85064951578777,99.70325088500977,106.66805203755696,113.74305407206218,120.92605527242024,128.21405474344888,135.60606002807617,143.0980593363444,150.690060933431,158.37906392415366,166.19706598917642,174.17606735229492,182.31306838989258,190.6050682067871,199.049072265625,207.64207204182944,216.38307444254556,225.26707712809244,234.29408009847006,243.45907974243164,252.78008143107095,262.27208455403644,271.9310887654622,281.7510935465495,291.7270914713542,301.85509490966797,312.12909444173175,322.5440953572591,333.0960998535156,343.7811024983724,354.6271006266276,365.6661071777344,376.89110565185547,388.2991078694661,399.8821105957031,411.63711802164715,423.55911509195965,435.6421203613281,447.8811213175456,460.2721201578776,472.7041269938151,485.06812540690106,497.36413319905597,509.5911280314128,521.7491404215494,533.8371327718099,545.8551279703776,557.8021443684896,569.6791330973307,581.4851226806641,593.0801391601562,604.3291269938151,615.2371368408203,625.8101298014323,636.0541330973307,645.9731394449869,655.5731302897135,664.8611297607422,673.8411254882812,682.5191396077474,690.8731333414713,698.8821258544922,706.5551249186198,713.8991241455078,720.9211120605469,727.6291147867838,734.0301157633463,740.1311238606771,745.9401245117188,751.4611256917318,756.6861165364584,761.6021270751953,766.2161204020182,770.5351206461588,774.5641174316406,778.3101196289062,781.7791137695312,784.9771016438802,787.911122639974,790.5871022542318,793.0101064046224,795.1871134440104,797.1231180826823,798.8241119384766,800.2961171468099,801.5441080729166,802.5741068522135,803.3911081949869,804.0001118977865,804.4071044921875,804.6171010335287,804.6341094970703,804.4641062418619,804.1120910644531,803.5821024576823,802.8790944417318,802.0071004231771,800.9711049397787,799.7760925292969,798.4260965983073,796.9240926106771,795.2750956217448,793.4840952555338,791.5540873209635,789.4880879720052,787.2920939127604,784.9680938720703,782.5200907389323,779.9510803222656,777.2660878499349,774.4680887858073,771.55908203125,768.5430755615234,765.4240875244141,762.2040863037109,758.8860880533854,755.4740804036459,751.9700775146484,748.3770904541016,744.6980794270834,740.9360911051432,737.0920766194662,733.1700744628906,729.1720733642578,725.10107421875,720.9590759277344,716.7470753987631,712.4700775146484,708.1280619303385,703.7230631510416,699.2590688069662,694.7360687255859,690.1580657958984,685.5250600179037,680.8390655517578,676.1030782063802,671.3190663655599,666.487070719401,661.6100667317709,656.6890614827474,651.726064046224,646.7220509847006,641.6790618896484,636.5980682373047,631.4820658365885,626.3300577799479,621.1450602213541,615.9270629882812,610.6780598958334,605.4000549316406,600.0930684407552,594.7590535481771,589.3990529378256,584.0130513509115,578.6030476888021,573.1700439453125,567.7150472005209,562.2390441894531,556.7430470784506,551.2270456949869,545.6930491129557,540.1420440673828,534.5730489095052,528.9890391031901,523.3900553385416,517.7770487467448,512.150042215983,506.51004282633465,500.85803985595703,495.1950327555339,489.52003987630206,483.83603922526044,478.1420415242513,472.4390360514323,466.7270329793294,461.0080337524414,455.2810312906901,449.5470326741536,443.8070297241211,438.06203206380206,432.31103261311847,426.5550282796224,420.79503122965497,415.03102620442706,409.2630259195964,403.4920298258464,397.71802775065106,391.94202423095703,386.16402943929035,380.38402303059894,374.603022257487,368.82102457682294,363.0380223592122,357.25502014160156,351.4720204671224,345.6890182495117,339.90601857503253,334.12501525878906,328.3440195719401,322.5650151570638,316.7870178222656,311.0110117594401,305.2370147705078,299.4660110473633,293.69701385498047,287.9300079345703,282.16701253255206,276.4070078531901,270.65000406901044,264.89601135253906,259.1470006306966,253.40100479125977,247.65900293986002,241.92100524902344,236.1880022684733,230.45899963378906,224.73500442504883,219.01499938964844,213.3009999593099,207.59200032552084,201.95899963378906,196.47099939982095,191.12700017293295,185.92199834187826,180.8540013631185,175.9199981689453,171.11600240071616,166.43999735514322,161.8890012105306,157.4599978129069,153.1489995320638,148.95399856567383,144.87200164794922,140.9010009765625,137.0369987487793,133.27699915568033,129.6189982096354,126.06099955240886,122.59899965922038,119.2309996287028,115.95599873860677,112.76899973551433,109.66899998982747,106.65400060017903,103.72199948628743,100.86899948120117,98.09479967753093,95.39620018005371,92.77139981587727,90.21860059102376,87.73560015360515,85.32069905598958,82.97200012207031,80.68770027160645,78.46609942118327,76.30530039469402,74.20390065511067,72.16010093688965,70.17249997456868,68.23940022786458,66.35940106709798,64.53099950154622,62.75279998779297,61.02350044250488,59.3417002360026,57.70620059967041,56.11549949645996,54.56860033671061,53.06419976552328,51.60120042165121,50.17839972178141,48.79469998677572,47.44909985860189,46.140499432881676,44.86789925893148,43.63029925028483,42.426700274149574,41.2562001546224,40.11800034840902,39.01110045115153,37.93460019429525,36.88779989878336,35.86979993184408,34.87979952494303,33.91700045267741,32.98079967498779,32.07029994328817,31.18499994277954,30.324000199635822,29.486699899037678,28.672400156656902,27.880599975585938,27.110599994659424,26.361900011698406,25.633699735005695,24.925599892934162,24.23709996541341,23.56749963760376,22.91629997889201,22.283100128173828,21.667399883270264,21.068600177764893,20.486299991607666,19.92009989420573,19.369500001271565,18.834100087483723,18.31350024541219,17.807300090789795,17.31510003407796,16.83650000890096,16.371099948883057,15.918600161870321,15.478599945704142,15.05079984664917,14.634799798329672,14.230300108591715,13.837000052134195,13.454499959945679,13.08269993464152,12.721100091934204,12.369500001271566,12.027599970499674,11.695200045903524,11.371999979019165,11.057699998219809,10.752099911371866,10.455000082651773,10.166100104649862,9.885129928588867,9.611959854761759,9.346340099970499,9.088060061136881,8.836920022964478,8.592720111211142,8.35528008143107,8.124399979909262,7.899900039037068,7.681610027949016,7.469350020090739,7.262959996859233,7.062280019124349,6.867140054702759,6.67739999294281,6.492899974187215,6.313500006993611,6.139060020446777,5.96944002310435,5.804509957631429,5.6441400448481245,5.488210002581279,5.336579918861389,5.18914000193278,5.045779983202617,4.9063800573349,4.770840009053548,4.639040072758992,4.510880033175151,4.386260112126668,4.265089948972066,4.14726996421814,4.032709976037343,3.9213099678357444,3.812979996204376,3.7076599995295205,3.605240007241567,3.5056599974632263,3.4088199734687805,3.3146599729855857,3.2231099605560303,3.1340799927711487,3.0475199818611145,2.9633399645487466,2.8814899921417236,2.8019100228945413,2.7245200077692666,2.649269978205363,2.576099991798401,2.504959980646769,2.4357800086339316,2.3685099879900613,2.3030999898910522,2.23949001232783,2.1776400009791055,2.11750998099645,2.059029996395111,2.002169986565908,1.9468799928824108,1.8931200007597606,1.8408400217692058,1.7900099953015645,1.740580012400945,1.692520002524058,1.6457900007565816,1.6003399988015492,1.5561500092347462,1.5131900012493134,1.4714099963506062,1.4307800233364105,1.3912800053755443,1.3528600136439006,1.3155100246270497,1.2791899939378102,1.2438800036907196,1.2095399896303813,1.1761400004227955,1.1436700125535328,1.1121000150839488,1.0813999871412914,1.0515500009059906,1.02252001563708,0.9942900041739146,0.9668430040280024,0.9401539961496989,0.9142019897699356,0.8889670123656591,0.8644289920727412,0.8405679961045583,0.8173659940560659,0.7948059936364492,0.7728679974873861,0.7515360017617544,0.7307929893334707,0.7106229960918427,0.6910099883874258,0.6719389855861664,0.6533939987421036,0.6353610108296076,0.6178259998559952,0.6007760018110275,0.584196001291275,0.5680740078290304,0.5523969928423563,0.5371530105670294,0.5223300009965897,0.5079169968763987,0.4939010019103686,0.48027200003465015,0.4670199975371361,0.454133003950119,0.44160200158754986,0.4294169992208481,0.41756899903217953,0.4060469965140025,0.3948440005381902,0.38395000000794727,0.3733569954832395,0.3630560015638669,0.3530390039086342,0.343299001455307,0.33382800221443176,0.32461900015672046,0.3156629999478658,0.3069549997647603,0.2984870026508967,0.2902530034383138,0.2822460010647774,0.27446000029643375,0.2668890009323756,0.2595270002881686,0.2523679994046688,0.24540700018405914,0.2386380024254322,0.23205600182215372,0.22565499941507974,0.21943099920948347,0.21337900186578432,0.20749400183558464,0.2017710010210673,0.19894999638199806};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473157167434692,7.644413391749064,7.721483985582988,7.842787067095439,7.9854438702265425,8.137296636899313,8.292397777239481,8.381964604059855,8.371402581532797,8.309913754463196,8.222858667373657,8.123189330101013,8.017469644546509,7.9090336561203,7.799525698026021,7.689734896024068,7.580045779546102,7.467166264851888,7.349635124206543,7.230486671129863,7.111116449038188,6.99215551217397,6.873813350995381,6.7561235427856445,6.638998548189799,6.52237602074941,6.406111876169841,6.329296787579854,6.311763922373454,6.324150005976359,6.351482351620992,6.386170744895935,6.424364725748698,6.464082638422648,6.50430182615916,6.544522523880005,6.58451235294342,6.626765012741089,6.672128955523173,6.718089620272319,6.763401508331299,6.807474652926127,6.850067973136902,6.891101559003194,6.930574814478557,6.968548734982808,7.00506059328715,7.046632965405782,7.096724669138591,7.150710423787435,7.206167618433635,7.261917908986409,7.317348798116048,7.3721604744593305,7.426222284634908,7.479493419329326,7.531956911087036,7.571836908658345,7.592957496643066,7.60396142800649,7.609343568483989,7.611408591270447,7.611393173535665,7.60994565486908,7.607458035151164,7.604129314422607,7.6001118421554565,7.582207202911377,7.543681184450786,7.494405031204224,7.439457933108012,7.3814215660095215,7.321645895640056,7.260836998621623,7.199398557345073,7.137549122174581,7.075439810752869,7.011485695838928,6.945090492566426,6.877801020940145,6.8103814125061035,6.743190407752991,6.6763997077941895,6.610058426856995,6.5441974401474,6.4788163503011065,6.413875420888265,6.3494739929835005,6.285682717959086,6.222431461016337,6.159730315208435,6.097579002380371,6.036007761955261,5.9750064214070635,5.914595127105713,5.854743878046672,5.795462687810262,5.736741383870442,5.678560177485148,5.620918949445088,5.563807765642802,5.507206638654073,5.451125542322795,5.39553435643514,5.340433279673259,5.285802245140076,5.231651147206624,5.177940249443054,5.124679207801819,5.071848313013713,5.019447247187297,4.967466433842977,4.91588552792867,4.864694555600484,4.81390376885732,4.763482928276062,4.7134320338567095,4.66374131043752,4.614400585492452,4.565409739812215,4.516749024391174,4.46841828028361,4.4204074939092,4.372716784477234,4.325326124827067,4.27823539574941,4.2314348220825195,4.184924205144246,4.138683517773946,4.092732926209767,4.047032395998637,4.001601715882619,3.956421196460724,3.9114906390508017,3.8668100436528525,3.822359542051951,3.7781490087509155,3.7341684699058533,3.6903979976971946,3.646857500076294,3.603527029355367,3.5603965719540915,3.5174761215845742,3.474765658378601,3.4322352210680642,3.389904777208964,3.3477643529574075,3.3058139085769653,3.264033536116282,3.222433110078176,3.1810027360916138,3.139752288659414,3.0986520051956177,3.057731568813324,3.0169612963994346,2.9763508439064026,2.935890555381775,2.89559014638265,2.8554299076398215,2.815419554710388,2.7755491932233176,2.735818862915039,2.696228583653768,2.656768282254537,2.6174479126930237,2.5782576402028403,2.5391873518625894,2.500247061252594,2.461426794528961,2.4227364659309387,2.3841562469800315,2.345695992310842,2.3073557019233704,2.269125441710154,2.2310151855150857,2.1930049856503806,2.1551146507263184,2.117324431737264,2.079634189605713,2.0420539379119873,2.0045736928780875,1.967203438282013,1.9299232761065166,1.8927330374717712,1.8556527594725292,1.8186625738938649,1.7817723552385967,1.7449721495310466,1.7082619468371074,1.6716417372226715,1.6351114908854167,1.5986713270346324,1.5623111228148143,1.526040921608607,1.4898606737454732,1.453770528237025,1.4177503387133281,1.3818201224009197,1.3459699352582295,1.3101997673511505,1.2745095491409302,1.2389093736807506,1.2033791840076447,1.1679290235042572,1.1325488090515137,1.0972586472829182,1.0620284875233967,1.0268882711728413,0.9918181200822195,0.9568219383557638,0.921901747584343,0.8870555907487869,0.8522834231456121,0.8175852447748184,0.782956083615621,0.7484009067217509,0.7139187355836233,0.6795055717229843,0.6451653937498728,0.6108972380558649,0.5766970713933309,0.5425688872734705,0.5085127254327139,0.4745235765973727,0.44060639788707096,0.40676023562749225,0.372980073094368,0.3392729063828786,0.3056347419818242,0.2720675791303317,0.23856940368811289,0.20513827974597612,0.171778022001187,0.13848808531959853,0.10526433090368907,0.07211444340646267,0.039030535612255335,0.01578784842664997,0.006368886291359861,0.0025690393522381783,0.001033956723404117,0.00041615661515000585,0.0001671617452908928,6.716052090875262e-05,2.6932199186073074e-05,1.0804916504033221e-05,4.326704621841297e-06,1.733832154589739e-06,6.934212587831704e-07,2.7762866849911916e-07,7.503522366410682e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911458035310109,1.2003816465536754,1.2822915613651276,1.392161637544632,1.512231747309367,1.6421518921852112,1.7816219627857208,1.9277320404847462,2.0776921113332114,2.2314022183418274,2.388732294241587,2.5495723883310952,2.713832437992096,2.881392558415731,3.0521625876426697,3.2260426680246987,3.4029327034950256,3.5795027017593384,3.752532740434011,3.9221327702204385,4.088412761688232,4.2514728307724,4.411412795384725,4.56833291053772,4.722322901089986,4.8734729290008545,5.021872878074646,5.169312953948975,5.3175530433654785,5.466583013534546,5.6163930495580034,5.766953190167745,5.918243209520976,6.070253213246663,6.222963253657023,6.3763532638549805,6.5304034153620405,6.68410340944926,6.836443463961284,6.987403512001038,7.136963407198588,7.2851035594940186,7.4318035046259565,7.577043533325195,7.720823566118876,7.863123655319214,8.003923734029135,8.143303553263346,8.281343698501587,8.418043613433838,8.553403695424398,8.687423706054688,8.820103804270426,8.951453844706217,9.08147382736206,9.210173845291138,9.337543884913126,9.461973826090494,9.581893841425577,9.69736393292745,9.808493773142496,9.915353854497274,10.018003861109415,10.116603771845499,10.211203893025717,10.301903883616129,10.3887038230896,10.470303694407145,10.545203606287638,10.613503615061441,10.675503651301065,10.731303612391153,10.781103610992432,10.825003385543823,10.86310346921285,10.895703395207724,10.922903617223104,10.944703340530396,10.961203495661417,10.972703218460083,10.979303201039633,10.981203238169352,10.978503147761026,10.971303145090738,10.959903081258139,10.944403012593588,10.924903074900309,10.902203241984049,10.877003033955893,10.84950296084086,10.819703181584677,10.7876029809316,10.753503004709879,10.717302958170572,10.679102818171183,10.639002958933512,10.597202777862549,10.553602774937948,10.508402903874716,10.461602926254272,10.41320276260376,10.363502820332846,10.312302748362223,10.25980273882548,10.2061026096344,10.151202519734701,10.095102707544962,10.03790251413981,9.979742685953775,9.920572678248087,9.860472599665323,9.799502611160278,9.737692515055338,9.675092458724976,9.61175243059794,9.547712484995523,9.483012437820435,9.41768248875936,9.35178248087565,9.285322427749634,9.218362410863241,9.150912284851074,9.083022197087606,9.0147123336792,8.946022431055704,8.876972277959188,8.807592312494913,8.737912257512411,8.667952140172323,8.597732146581015,8.527292172114054,8.456642150878906,8.385802110036215,8.314791997273764,8.243642091751099,8.172352075576782,8.100962162017822,8.02947207291921,7.957912007967631,7.886282006899516,7.8146019379297895,7.7428819338480634,7.671151876449585,7.599411805470784,7.527671893437703,7.455941875775655,7.384251832962036,7.312581817309062,7.240961790084839,7.16940180460612,7.097901741663615,7.026471773783366,6.955121715863545,6.883851687113444,6.812681635220845,6.74161159992218,6.670641581217448,6.5997815529505415,6.529041568438212,6.458431561787923,6.387941559155782,6.317571560541789,6.247351447741191,6.177261471748352,6.107311566670735,6.037501533826192,5.967851400375366,5.898341417312622,5.828991373380025,5.759801348050435,5.69076132774353,5.621881326039632,5.553151249885559,5.4846012989679975,5.41620131333669,5.347971200942993,5.279911200205485,5.212011178334554,5.144281188646953,5.076721111933391,5.009321093559265,4.9421011209487915,4.875041127204895,4.808151086171468,4.74143115679423,4.674881060918172,4.608500997225444,4.542290965716044,4.476251006126404,4.410370906194051,4.344660957654317,4.279120922088623,4.213750878969829,4.148540894190471,4.083500782648723,4.018630882104238,3.9539108077685037,3.8893707593282065,3.8249807953834534,3.76076078414917,3.6966907183329263,3.6327907045682273,3.569040675957998,3.5054606596628823,3.4420306285222373,3.3787606159845986,3.3156405687332153,3.252680559953054,3.189870536327362,3.127210557460785,3.064700504144033,3.0023505091667175,2.9401504596074424,2.878090500831604,2.816180427869161,2.754420439402262,2.6928003827730813,2.63133039077123,2.5700003504753113,2.508820335070292,2.4477803111076355,2.386870265007019,2.326110283533732,2.265490253766378,2.2050002018610635,2.144660214583079,2.0844501852989197,2.0243701537450156,1.964430143435796,1.9046301345030467,1.84496009349823,1.7854200700918834,1.7260100444157918,1.6667400399843852,1.6075900097688038,1.548580010732015,1.4896899958451588,1.4319700102011363,1.3763999938964844,1.3229299982388814,1.2714699904123943,1.221970001856486,1.1743500034014385,1.1285399893919628,1.0844900012016296,1.0421299934387207,1.0013899952173233,0.9622250000635783,0.9245709975560507,0.888372004032135,0.8535749961932501,0.8201269954442978,0.7879770050446192,0.7570769985516866,0.7273789991935095,0.6988370021184286,0.6714080025752386,0.645048995812734,0.6197179853916168,0.5953770081202189,0.57198799153169,0.5495119988918304,0.5279160042603811,0.5071659858028094,0.487226997812589,0.46806999295949936,0.4496629983186722,0.431977999707063,0.4149859994649887,0.3986599991718928,0.3829749996463458,0.36790499836206436,0.3534270003437996,0.3395159989595413,0.3261519993344943,0.31331299990415573,0.3009780024488767,0.28912700215975445,0.27774200091759366,0.26680399974187213,0.2562960038582484,0.24620099986592928,0.2365030013024807,0.22718600059549013,0.21823500220974287,0.20963599905371666,0.20137600104014078,0.19343999897440275,0.18581600114703178,0.17849200094739595,0.1714560016989708,0.1646970013777415,0.15820400168498358,0.1519669989744822,0.1459749974310398,0.1402189979950587,0.1346889982620875,0.129376998792092,0.1242739986628294,0.1193720002969106,0.11466299928724766,0.11013899991909663,0.10579400012890498,0.10161900085707505,0.09760939950744311,0.09375739966829617,0.09005720044175784,0.08650270104408264,0.08308819929758708,0.07980829911927383,0.07665760007997353,0.07363110035657883,0.07072389932970206,0.06793120006720225,0.06524859927594662,0.06267180076489846,0.060196599612633385,0.05781889986246824,0.05553499981760979,0.05334109968195359,0.0512338001281023,0.0492095003525416,0.047265199633936085,0.045397600159049034,0.04360390019913515,0.041881000312666096,0.04022630024701357,0.038636899863680206,0.03711040007571379,0.0356442000096043,0.03423590026795864,0.03288329920421044,0.03158410017689069,0.030336300376802683,0.029137799981981516,0.02798669971525669,0.02688099987184008,0.025819100129107635,0.024799099812904995,0.023819399997591972,0.022878400205324095,0.02197460023065408,0.021106500178575516,0.020272799922774237,0.019471899916728336,0.018702699958036344,0.01796400003756086,0.017254399756590526,0.016572799999266863,0.01591820005948345,0.01528940008332332,0.01468549994751811,0.014105399992937842,0.013548300058270494,0.0130131000187248,0.01249920018017292,0.01200550002977252,0.011531299989049634,0.011075900013869008,0.010638399903352061,0.01021830008054773,0.00981469980130593,0.009427070074404279,0.00905477007230123,0.008697169988105694,0.008353689995904764,0.008023790006215373,0.007706919995447,0.0074025599751621485,0.007110230042599142,0.00682945002336055,0.006559759999314944,0.006300719959350924,0.00605190999340266,0.005812939954921603,0.005583399945559601,0.005362929970336457,0.005151169995466868,0.004947769998883207,0.004752400020758311,0.004564759981197615,0.0043845200367892785,0.004211400053463876,0.004045119974762201,0.003885409988773366,0.0037320099848633013,0.0035846600076183677,0.0034431300203626356,0.003307200036942959,0.0031766299701606235,0.0030512199931157133,0.0029307600149574378,0.0028150600264780223,0.0027039299990671375,0.002597180001127223,0.002494650000395874,0.00239617001110067,0.0023015800203817585,0.0022107300464995205,0.0021234600183864436,0.002039640035945922,0.001959129973935584,0.001881800009869039,0.0018075199914164841,0.001736169991393884,0.0016676399876208354,0.0016018199967220426,0.0015385999771145482,0.0014778699939294408,0.00141953999021401,0.0013635099943106372,0.0013097000094906737,0.001258009986486286,0.0012083600061790396,0.0011606699942300718,0.0011148599927158405,0.0010708700186417748,0.0010286100150551647,0.000988013014042129,0.0009490230004303157,0.0009115719973730544,0.0008755999976225818,0.0008410479980132853,0.0008078589986932153,0.0007759810008186226,0.0007453620006951193,0.0007159499994789561,0.0006877000026482468,0.0006605649881142502,0.0006345009993916998,0.0006094660008481393,0.000585418994887732,0.0005623220010117317,0.0005401350014532605,0.0005188250021698574,0.0004983559968726089,0.00047869399713817984,0.0004598090041933271,0.0004416680021677166,0.00042424400210923824,0.0004075079972002034,0.0003914319968316704,0.00037598999915644526,0.0003611580007903588,0.00034691099911772955,0.00033322599483653903,0.00032008200165970874,0.00030745600088266656,0.00029532800302452716,0.0002836789984333639,0.0002724899968598038,0.00026174200320383534,0.0002514180038512374,0.00024150100216502324,0.00023197599997123083,0.00022282700228970498,0.00021403900124520683,0.00020559699987643398,0.00019748799968510866,0.00018969999897914627,0.00018221900002875677,0.00017503199948502393,0.0001681299994136983,0.0001614990020849897,0.00015513100152020343,0.00014901300043372126,0.00014313700012280606,0.0001374929997837171,0.0001320709998253733,0.00012686300033237785,0.00012186099957034457,0.00011705599899869412,0.0001124399999146893,0.00010800700025962821,0.0001037479996739421,9.965780069857526e-05,9.572859926265664e-05,9.1954400583442e-05,8.83290006944056e-05,8.484659883833956e-05,8.150160101649817e-05,7.82885011479569e-05,7.52020999546706e-05,7.223739946008816e-05,6.938970060825038e-05,6.799449935594264e-05};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.94632927576701,28.906192779541016,29.845894813537598,30.637296040852863,31.22409725189209,31.60739866892497,31.78779888153076,31.85909875233968,31.914298852284748,31.953498999277752,31.976699034372967,31.98409907023112,31.975799401601154,31.951799392700195,31.912299474080402,31.857199668884277,31.786799430847168,31.707399527231853,31.62579933802287,31.54189936319987,31.45569944381714,31.36739953358968,31.27679967880249,31.184099515279133,31.089199384053547,30.99209992090861,30.89299949010213,30.79219977060954,30.69039996465047,30.587599754333496,30.48359966278076,30.378599961598713,30.272399584452312,30.165099779764812,30.056700070699055,29.947099685668945,29.836400190989178,29.724799791971844,29.612699667612713,29.500099658966064,29.386799812316895,29.273000081380207,29.15850003560384,29.043299833933514,28.9274001121521,28.81090021133423,28.693600018819172,28.575899918874104,28.457899888356526,28.339699904123943,28.221199830373127,28.102499961853027,27.983500321706135,27.86419979731242,27.744600137074787,27.62470022837321,27.504499912261963,27.38419993718465,27.2637996673584,27.14330021540324,27.022799968719482,26.902199586232502,26.78150002161662,26.660699526468914,26.539700190226238,26.418699741363525,26.297499974568684,26.17639970779419,26.055400053660076,25.934599717458088,25.813999970753986,25.69350020090739,25.573200225830078,25.45299990971883,25.332900047302246,25.21299997965495,25.09320004781087,24.9735000928243,24.853999932607014,24.734700043996174,24.61550013224284,24.49659999211629,24.37790012359619,24.25940004984538,24.14109977086385,24.02299976348877,23.905100027720135,23.78749990463257,23.670100212097168,23.552899837493896,23.435900052388508,23.31919987996419,23.20269997914632,23.086400190989178,22.970399856567383,22.854599793752033,22.739099661509197,22.623899936676025,22.508900324503582,22.39420000712077,22.279800097147625,22.16569979985555,22.051899909973145,21.938300132751465,21.825100262959797,21.712199846903484,21.59950017929077,21.487200101216633,21.375199953715008,21.263500054677326,21.152199904123943,21.041199843088787,20.930499871571858,20.820099989573162,20.710100173950195,20.600499947865803,20.491199652353924,20.382200082143147,20.273600260416668,20.16540002822876,20.057499885559082,19.950000286102295,19.84280014038086,19.73599974314372,19.629599889119465,19.523600101470947,19.417899926503498,19.312600135803223,19.2076997756958,19.10320011774699,18.99910004933675,18.895299911499023,18.79200013478597,18.689000129699707,18.586399873097736,18.48420015970866,18.382400035858154,18.2810001373291,18.179999987284344,18.079400221506756,17.97920020421346,17.87939993540446,17.779999891916912,17.681000073750813,17.582499980926514,17.484299818674724,17.386500040690105,17.289100011189777,17.192100207010906,17.09559981028239,16.99939997990926,16.90370003382365,16.80840015411377,16.7134002049764,16.618899822235107,16.524799823760986,16.43110005060832,16.33780002593994,16.244900067647297,16.152399857838947,16.060400168100994,15.968700170516968,15.87749989827474,15.786600033442179,15.696199973424276,15.606200138727823,15.516499996185303,15.427299976348877,15.338500022888184,15.250099897384644,15.162200053532919,15.074600060780844,14.98740005493164,14.900600035985311,14.814300060272217,14.728300094604492,14.642699956893921,14.557600100835165,14.472800016403198,14.388500054677328,14.304499944051107,14.220999876658121,14.137800057729086,14.055000066757202,13.972700039545694,13.890700101852417,13.809100071589151,13.72790010770162,13.647100130716959,13.566799799601236,13.48669981956482,13.407099962234497,13.327900012334188,13.249099969863892,13.170600016911825,13.092499812444052,13.014899889628092,12.937599976857504,12.860600074132284,12.78409997622172,12.707900047302246,12.632199923197428,12.5567999680837,12.48170002301534,12.407099882761637,12.332799911499023,12.258900006612143,12.185400088628134,12.112200021743774,12.039400021235148,11.966999848683676,11.894899924596151,11.823199987411499,11.75190003712972,11.68090009689331,11.610299905141195,11.539999882380167,11.470099846522013,11.40059987703959,11.331399838129679,11.262600104014078,11.19409990310669,11.125900109608969,11.058199961980185,10.990700006484985,10.92359987894694,10.856900056203207,10.790499846140543,10.724399964014689,10.658700068791708,10.593400001525879,10.528300126393637,10.463600158691406,10.399200201034546,10.33519991238912,10.271499872207642,10.208099921544393,10.145099957784018,10.082300027211508,10.01990008354187,9.957739988962809,9.89592989285787,9.834450085957846,9.773300011952719,9.712479988733927,9.652000029881796,9.591860055923462,9.532049973805746,9.472580115000406,9.41346001625061,9.354680061340332,9.296240091323853,9.238149960835775,9.180390040079752,9.122979958852133,9.065920114517212,9.009190003077189,8.952800114949545,8.896759907404581,8.841050068537394,8.785679976145426,8.730650027592977,8.675949970881144,8.621580044428507,8.56755002339681,8.513839880625406,8.460469961166382,8.407419999440512,8.354700167973837,8.3023099899292,8.250229994455973,8.198479890823364,8.147040128707886,8.095920006434122,8.045120000839233,7.994630018870036,7.944459994633992,7.894589980443318,7.845029989878337,7.795780022939046,7.7468299468358355,7.698190013567607,7.649850010871887,7.601800044377645,7.5540599425633745,7.506609956423442,7.4594500462214155,7.412589987119039,7.366020043690999,7.319730043411255,7.2737299998601275,7.228020032246907,7.182600061098735,7.137449940045674,7.092589974403381,7.047999978065491,7.003690044085185,6.959649960199992,6.915890018145244,6.8724000453948975,6.829179962476094,6.786229968070984,6.743549982706706,6.701129953066508,6.658980011940002,6.617079973220825,6.575449983278911,6.534079988797505,6.4929600556691485,6.452099959055583,6.4114900430043535,6.371140003204346,6.331039985020955,6.29117997487386,6.251579960187276,6.2122199932734175,6.173099954922994,6.134229977925618,6.095600008964539,6.057220021883647,6.019069989522298,5.981149991353353,5.943480014801025,5.9060399532318115,5.868839939435323,5.831869999567668,5.795139988263448,5.758639971415202,5.722369909286499,5.686319986979167,5.65051007270813,5.614920059839885,5.57955002784729,5.544409990310669,5.509490013122559,5.4747900168101,5.440310041109721,5.406050006548564,5.372000018755595,5.338170011838277,5.304550011952718,5.271140019098918,5.2379500071207685,5.204959948857625,5.172179977099101,5.139610052108765,5.107250014940898,5.0750900109608965,5.043129920959473,5.011370023091634,4.979809919993083,4.948460022608439,4.91730002562205,4.886329968770345,4.855569958686829,4.824989994366963,4.794609983762105,4.764419913291931,4.73442002137502,4.704609950383504,4.6749900579452515,4.645560026168823,4.616310000419617,4.587240060170491,4.558360020319621,4.529660026232402,4.501150012016296,4.472809950510661,4.444649934768677,4.416670083999634,4.388859987258911,4.3612300157547,4.333779970804851,4.30649995803833,4.279389977455139,4.252449989318848,4.225680033365886,4.199079950650533,4.1726500193278,4.146379987398784,4.120280027389526,4.0943498611450195,4.068569978078206,4.042959968249003,4.017520030339559,3.992229998111725,3.9671000242233276,3.942129989465078,3.9173200130462646,3.892669995625814,3.8681700030962625,3.8438199957211814,3.8196300069491067,3.7955900033315024,3.7717000246047974,3.7479699850082397,3.7243799567222595,3.7009400129318237,3.677649994691213,3.654510021209717,3.631510019302368,3.6086600025494895,3.5859499971071878,3.5633899768193564,3.5409599939982095,3.5186800360679626,3.4965399702390036,3.4745400150616965,3.452679991722107,3.4309499859809875,3.409369965394338,3.387909988562266,3.366599977016449,3.345420002937317,3.3243699868520102,3.303450028101603,3.282670040925344,3.262019991874695,3.241499980290731,3.2210999925931296,3.2008400162061057,3.1806999842325845,3.1606899897257485,3.140810012817383,3.121049960454305,3.101420005162557,3.081909994284312,3.0625200072924295,3.0432599584261575,3.024119953314463,3.005089978377024,2.9861900011698403,2.9674099485079446,2.9487499992052713,2.9302000403404236,2.9117700258890786,2.8934600154558816,2.8752599954605103,2.8571700056393943,2.8391999999682107,2.8213499983151755,2.803599993387858,2.7859700123469033,2.7684499820073447,2.7510400215784707,2.7337400118509927,2.7165499726931253,2.699469963709513,2.6824899911880493,2.6656299829483032,2.6488600174585977,2.6322099566459656,2.615659991900126,2.599209984143575,2.5828699866930642,2.5666299859682717,2.5504899819691977,2.5344499945640564,2.518520017464956,2.502680003643036,2.4869500001271567,2.471309999624888,2.4557799895604453,2.4403400222460427,2.424999992052714,2.4097500244776406,2.394599994023641,2.379550019900004,2.3645900090535483,2.3497300346692405,2.3349600036938987,2.3202800154685974,2.3056899905204773,2.2912000020345054,2.276799996693929,2.262489994366964,2.248270034790039,2.2341399788856506,2.2200899720191956,2.2061400214831033,2.1922700007756553,2.17849995692571,2.164799968401591,2.151199996471405,2.137680013974508,2.130940020084381};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.14046400288740793,0.14906380325555801,0.1594048279027144,0.1713378131389618,0.1848857911924521,0.20003977293769518,0.2167927511036396,0.23509473229448,0.2548957094550133,0.2761876930793126,0.2989646742741267,0.323220652838548,0.3489476318160693,0.37613661338885623,0.40478259325027466,0.43487657358249027,0.46641356498003006,0.49914154907067615,0.5328075389067332,0.5674085319042206,0.6029405097166697,0.6393984903891882,0.6767794787883759,0.7150754630565643,0.7542844514052073,0.7944024453560511,0.8354254166285197,0.8775434096654257,0.9209463894367218,0.9656273623307546,1.0115893532832463,1.0588093400001526,1.1072993179162343,1.1570492784182231,1.2080392738183339,1.2602892617384593,1.3137792348861694,1.368669221798579,1.4251092076301575,1.4831091662247975,1.5426491300264995,1.6037191152572632,1.6663190921147664,1.7304190794626872,1.7960290412108104,1.8631290296713512,1.931709001461665,2.0018989642461142,2.073798934618632,2.147408962249756,2.222718874613444,2.2997188766797385,2.37838884194692,2.458728849887848,2.540728807449341,2.624378760655721,2.7096587816874185,2.79611873626709,2.8832987348238626,2.971188724040985,3.0597787300745645,3.1490686933199563,3.2390586932500205,3.329728682835897,3.4210886557896933,3.5131086111068726,3.605808655420939,3.6985786159833274,3.790818671385447,3.8825286626815796,3.973718603452047,4.064388593037923,4.1545186042785645,4.244138598442078,4.333218653996785,4.421788613001506,4.509828607241313,4.597148696581523,4.683558622996013,4.769068638483684,4.853678623835246,4.93738869825999,5.020218690236409,5.102148652076721,5.183208624521892,5.26339868704478,5.342708706855774,5.42098871866862,5.49807870388031,5.573998689651489,5.648728768030803,5.722298741340637,5.794688820838928,5.865928769111633,5.935998717943828,6.004918694496155,6.072688778241475,6.13930881023407,6.204798777898152,6.269158760706584,6.3323788245519,6.394478797912598,6.455468813578288,6.515338857968648,6.574108878771464,6.631768822669983,6.688328862190247,6.74380894502004,6.798198858896892,6.851498921712239,6.903738975524902,6.954898873964946,7.0049989223480225,7.054038961728414,7.102028965950012,7.148968935012817,7.194868961970012,7.239738980929057,7.283568938573201,7.32637898127238,7.368168989817302,7.408949017524719,7.448719024658203,7.487489064534505,7.525259097417195,7.5620390971501665,7.597829103469849,7.632648944854736,7.666489084561666,7.699359138806661,7.731269081433614,7.762219071388245,7.7922290960947675,7.821279128392537,7.849399089813232,7.876579125722249,7.902829209963481,7.928149183591207,7.952559192975362,7.976059079170227,7.99864908059438,8.020329316457113,8.04111917813619,8.06101910273234,8.080029249191284,8.098169247309366,8.115429242451986,8.13180939356486,8.147339264551798,8.162009159723917,8.175819317499796,8.188779354095459,8.200899283091227,8.212189277013143,8.222639322280884,8.232269207636515,8.241069396336874,8.249049345652262,8.256229321161905,8.26259938875834,8.26815938949585,8.272929509480795,8.276909430821737,8.280109326044718,8.282519340515137,8.284149328867594,8.285019397735596,8.285119454065958,8.284459352493286,8.283039490381876,8.280869404474894,8.277949492136637,8.274289608001709,8.26988943417867,8.264759381612143,8.258909384409586,8.252329587936401,8.24502960840861,8.237019697825113,8.228299538294474,8.218879302342733,8.208749373753866,8.19793955485026,8.186429738998413,8.174229621887207,8.161359469095865,8.147809425989786,8.13357957204183,8.11868945757548,8.103129625320435,8.086909612019857,8.070039590199789,8.05251955986023,8.034359614054361,8.015549580256144,7.9960997104644775,7.976029713948567,7.9553196032842,7.933979709943135,7.9120296239852905,7.889459689458211,7.866279641787211,7.842489679654439,7.818089723587036,7.793099721272786,7.767509738604228,7.7413196961085005,7.714549740155538,7.687199751536052,7.659259756406148,7.630749781926473,7.601669788360596,7.572009762128194,7.541799783706665,7.511019825935364,7.4796797434488935,7.447799841562907,7.415359894434611,7.38237984975179,7.348849813143413,7.314789851506551,7.280199885368347,7.245069861412048,7.209409872690837,7.1732399463653564,7.136539896329244,7.099329908688863,7.061609983444214,7.023369948069255,6.98462986946106,6.945389986038208,6.905649979909261,6.8654199441274,6.824690024058024,6.783480008443196,6.741780002911885,6.699610034624736,6.657290021578471,6.615190029144287,6.5733100573221845,6.531649986902873,6.4902100165685015,6.4490000406901045,6.40802001953125,6.367269992828369,6.326750040054321,6.286470055580139,6.24641998608907,6.206599990526835,6.1670200030008955,6.127679944038391,6.08856995900472,6.049690047899882,6.0110600392023725,5.972659985224406,5.934490005175273,5.896560033162435,5.858860055605571,5.821389993031819,5.784150083859761,5.74714998404185,5.710379997889201,5.673829952875773,5.63752003510793,5.60142997900645,5.565560022989909,5.529929995536804,5.494510014851888,5.459320028622945,5.424349983533223,5.389599959055583,5.355069994926453,5.320749958356221,5.286649982134501,5.252769986788432,5.219099998474121,5.185650030771892,5.152400016784668,5.119370023409526,5.08653998374939,5.053929964701335,5.021520058314006,4.989310026168823,4.95730996131897,4.925510048866272,4.8939099709192915,4.862520058949788,4.831319967905681,4.800319989522298,4.76951003074646,4.73891003926595,4.708490014076233,4.678270022074382,4.6482400099436445,4.618400017420451,4.588749925295512,4.559289971987407,4.530019998550415,4.500929991404216,4.4720299243927,4.443310022354126,4.414770007133484,4.386410037676494,4.358240048090617,4.33024001121521,4.302420059839885,4.274780074755351,4.247309962908427,4.220019976298015,4.192900061607361,4.165949980417888,4.139180024464925,4.112579981486003,4.086139957110087,4.059870004653931,4.033769885698955,4.007840017477672,3.982070028781891,3.9564599990844727,3.9310200015703836,3.905739982922872,3.880620002746582,3.8556599815686545,3.8308600187301636,3.80621999502182,3.7817400097846985,3.757420003414154,3.733259995778402,3.7092399994532266,3.685389995574951,3.6616899967193604,3.638140002886454,3.614740014076233,3.5914899706840515,3.568399965763092,3.54544997215271,3.5226499835650125,3.5,3.47749000787735,3.4551299810409546,3.4329100052515664,3.410830001036326,3.3888999819755554,3.3671099742253623,3.3454599579175315,3.323940018812815,3.3025700052579245,3.2813300093015036,3.2602399786313376,3.239270031452179,3.2184400161107383,3.1977500120798745,3.1771899660428367,3.156760017077128,3.1364700198173523,3.1163000067075095,3.0962599913279214,3.076360007127126,3.0565799872080484,3.036930024623871,3.017400006453196,2.998009999593099,2.978730003039042,2.9595800042152405,2.940559963385264,2.921649992465973,2.9028700391451516,2.8842099706331887,2.8656700054804483,2.847249964872996,2.8289400736490884,2.810759961605072,2.7926899592081704,2.774740000565847,2.7568999926249185,2.739180028438568,2.7215800086657205,2.704080045223236,2.68670000632604,2.6694300174713135,2.6522799730300903,2.63522998491923,2.6182900071144104,2.601460059483846,2.5847400228182473,2.5681300163269043,2.5516300201416016,2.535230020682017,2.518940011660258,2.5027499993642173,2.4866600235303244,2.470679998397827,2.4548099637031555,2.4390300114949546,2.423359990119934,2.4077800114949546,2.3923099637031555,2.3769399722417197,2.3616699973742166,2.34649004538854,2.331409990787506,2.3164299527804055,2.301549971103668,2.2867600123087564,2.2720700105031333,2.2574700117111206,2.242959996064504,2.2285499771436057,2.2142299811045327,2.2000099817911782,2.1858700116475425,2.1718300183614097,2.1578800082206726,2.144010007381439,2.130239983399709,2.1165599822998047,2.102960010369619,2.0894499818483987,2.076029976209005,2.062689960002899,2.0494399865468345,2.036280035972595,2.023199995358785,2.010200003782908,1.997290015220642,1.9844599862893422,1.9717099964618683,1.9590500096480052,1.946459988753001,1.93396000067393,1.9215400119622548,1.9092000027497609,1.896940012772878,1.8847500185171764,1.872649997472763,1.8606200019518535,1.848669985930125,1.8367999891440074,1.825000007947286,1.8132799963156383,1.801640013853709,1.7900699973106384,1.7785800099372864,1.767149994770686,1.755809982617696,1.7445300022761028,1.7333300014336903,1.722199986378352,1.7111399968465169,1.7001600066820781,1.6892400085926056,1.6783899863560994,1.6676200032234192,1.6569099922974904,1.6462700068950653,1.6356999973456066,1.6252000033855438,1.6147700250148773,1.6044000089168549,1.5940999885400136,1.5838700036207836,1.5737000107765198,1.5635999937852223,1.5535599986712139,1.5435899992783864,1.533680001894633,1.523829976717631,1.514050006866455,1.504329999287923,1.4946800072987874,1.4850799938042958,1.4755499958992004,1.4660800000031788,1.456669996182124,1.4473199943701427,1.4380300045013428,1.4288000067075093,1.419629991054535,1.4105199972788494,1.40146999557813,1.3924700220425923,1.3835399945576985,1.3746599853038788,1.365839997927348,1.3570699989795685,1.3526999950408936};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2213880022366843,2.4407403071721396,2.636770228544871,2.918560286362966,3.2446503043174744,3.609150310357412,4.006840368111928,4.43168044090271,4.878550410270691,5.344630479812622,5.827420473098755,6.324760516484578,6.8347404797871905,7.355700532595317,7.886180480321248,8.424900571505228,8.970750570297241,9.510810613632202,10.033900737762451,10.542100747426352,11.037500778834024,11.521800597508749,11.996500571568808,12.462700843811035,12.921700795491537,13.374400774637857,13.821500698725382,14.276000817616781,14.748900890350342,15.238200902938843,15.741800864537558,16.258100827534992,16.785600980122883,17.322900772094727,17.869001070658367,18.42280117670695,18.98340129852295,19.555501143137615,20.14290126164754,20.742701212565105,21.35270118713379,21.970701217651367,22.595001538594563,23.22390127182007,23.856001218159992,24.490101019541424,25.125101407368977,25.768301645914715,26.42600154876709,27.096001466115315,27.77600161234538,28.46420160929362,29.15900182723999,29.85880168279012,30.562501748402912,31.268901824951172,31.977001825968426,32.6657018661499,33.31630166371664,33.932902336120605,34.5192019144694,35.07820192972819,35.61280186971029,36.12540213267008,36.61830202738444,37.09340159098307,37.552401860555015,37.970801989237465,38.3273016611735,38.62910238901774,38.883001963297524,39.094702084859215,39.269201596577965,39.41100184122721,39.524102528889976,39.611802419026695,39.677401860555015,39.714402516682945,39.71800168355306,39.69270102183024,39.64270210266113,39.57150173187256,39.48230171203613,39.37770207722982,39.26010195414225,39.13140137990316,38.99330202738444,38.835402488708496,38.648502349853516,38.43660195668539,38.20350170135498,37.95220216115316,37.68550173441569,37.406002044677734,37.11570167541504,36.8165012995402,36.51000181833903,36.19760195414225,35.88050206502279,35.559702237447105,35.236101150512695,34.9106019337972,34.58370145161947,34.25610160827637,33.928300857543945,33.60060183207194,33.27330207824707,32.94690195719401,32.62150128682455,32.297401428222656,31.97470172246297,31.653501510620117,31.334001382191975,31.01630163192749,30.70040162404378,30.386401335398357,30.07430140177409,29.76410166422526,29.45600159962972,29.14980125427246,28.84550142288208,28.543301264444988,28.243001302083332,27.94460153579712,27.648101488749187,27.353601296742756,27.060901323954266,26.770001252492268,26.481001377105713,26.19370126724243,25.908201376597088,25.624401410420734,25.3423015276591,25.061901410420734,24.783101240793865,24.5058012008667,24.230101108551025,23.95600112279256,23.6833012898763,23.41210126876831,23.142301082611084,22.8739013671875,22.60690100987752,22.341201146443684,22.076901117960613,21.813801288604736,21.552000840504963,21.291400909423828,21.03200101852417,20.77380100886027,20.51680103937785,20.26090129216512,20.00610113143921,19.752301057179768,19.499701182047527,19.248101075490315,18.997501055399578,18.74790096282959,18.499300797780354,18.25160090128581,18.004901091257732,17.759201049804688,17.51430082321167,17.27030070622762,17.02720085779826,16.784900665283203,16.543500741322834,16.302900950113933,16.063100814819336,15.824100732803345,15.5859006245931,15.348400751749674,15.111700852711996,14.875800768534342,14.640600681304932,14.40600069363912,14.172200759251913,13.939100742340088,13.706600904464722,13.474900722503662,13.243700742721558,13.013300657272339,12.783400694529215,12.554200728734335,12.325600624084473,12.097600618998209,11.870200475056967,11.643400430679321,11.417200644810995,11.191600640614828,10.966500520706177,10.742000579833984,10.518000523249308,10.294600566228231,10.07170057296753,9.849330425262451,9.627500454584757,9.406180381774902,9.185370445251465,8.965070406595865,8.745270570119223,8.525970538457235,8.30715036392212,8.088820377985636,7.870960394541423,7.65358038743337,7.436670343081157,7.2202203671137495,7.004240314165751,6.788710316022237,6.5736403465271,6.359010259310405,6.144830346107483,5.931100249290466,5.717800219853719,5.504950205485026,5.29252028465271,5.080530206362407,4.8689701954523725,4.657830198605855,4.447120149930318,4.2368301550547285,4.0269701679547625,3.817520181337992,3.6084901293118796,3.399870137373606,3.191670080025991,2.98388010263443,2.776500105857849,2.569530109564463,2.3629700541496277,2.156820058822632,1.9510800242424011,1.7457400262355804,1.5408200124899547,1.3363000055154164,1.1321799953778584,0.9450059980154037,0.7885699967543284,0.6578769981861115,0.5487279941638311,0.4575989991426468,0.3815369978547096,0.3180670017997424,0.2651169995466868,0.2209519992272059,0.1841219998896122,0.15341400106747946,0.12781399860978127,0.10647599895795186,0.08869330088297527,0.07387450026969115,0.061527199732760586,0.05124020048727592,0.042670500464737415,0.03553210043658813,0.029586299943427246,0.024634300265461206,0.02051019963497917,0.017075899988412857,0.014216000058998665,0.011834700126200914,0.009851939898605147,0.008201110060326755,0.006826690048910677,0.005682440047773222,0.004729860035392146,0.003936869965400547,0.003276739987389495,0.0027272400135795274,0.0022698399455597005,0.0018891100286661338,0.001572210011848559,0.0013084400173587103,0.0010888999871288736,0.0009061829914571717,0.0007541100009499738,0.000627547002901944,0.0005222149945135849,0.0004345560009824112,0.000361604996821067,0.00030089500069152564,0.0002503740021590299,0.00020833200323977508,0.00017334699320296446,0.0001442339998902753,0.00012000900096609257,9.985150002952044e-05,8.307819856175531e-05,6.912149971564456e-05,5.750860054831719e-05,4.784599999159885e-05,3.980630056806452e-05,3.311710012591599e-05,2.755149989752681e-05,2.292099982999692e-05,1.9068399979005335e-05,1.586310016440014e-05,1.319639992895342e-05,1.0977900046782452e-05,9.132169983179969e-06,7.596670040281121e-06,6.319259985806032e-06,5.256580000908191e-06,4.372540009474808e-06,3.6371200356673703e-06,3.0253600016294513e-06,2.5164500054112673e-06,2.0931199742335593e-06,1.7409799966117134e-06,1.4480700182654498e-06,1.2044100022497635e-06,1.0017499931791463e-06,8.331700011391755e-07,6.929520045180956e-07,5.763239935655898e-07,4.793179968487493e-07,3.9863499760410076e-07,3.3152899921636464e-07,2.7571500046027114e-07,2.2929499958005786e-07,1.9068700159626437e-07,1.5857899882121274e-07,1.3187700057907628e-07,1.096709999851934e-07,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834432284037272,12.709800720214844,13.167000452677408,13.881100336710611,13.805300235748291,13.078700145085653,11.817000230153402,10.421300172805786,9.221230109532675,8.18275010585785,7.277600089708964,6.482380072275798,5.7778000831604,5.147900025049846,4.57951005299886,4.06179000933965,3.585800031820933,3.1653800209363303,2.8119000593821206,2.513480007648468,2.2603500485420227,2.0444400310516357,1.8591100374857585,1.698870023091634,1.5592400232950847,1.4365200102329254,1.3276700178782146,1.231520007054011,1.1470500230789185,1.0720400114854176,1.0046800126632054,0.943514014283816,0.887348011136055,0.8352210174004236,0.7863500018914541,0.7400990178187689,0.6959530115127563,0.6549580047527949,0.6179830133914948,0.5842860092719396,0.5532670120398203,0.5244460105895996,0.49742400894562405,0.4718780095378558,0.4475400075316429,0.4241960073510806,0.40168001006046933,0.3804440051317215,0.3608480046192805,0.34259800612926483,0.32545700669288635,0.3092230061690013,0.2937349999944369,0.278866005440553,0.26450300465027493,0.2505600042641163,0.23697000245253244,0.2240020049115022,0.21189000209172568,0.20047600318988165,0.18961700052022934,0.17921600366632143,0.16919000198443732,0.15947600454092026,0.15002100293835005,0.14078800256053606,0.131740003824234,0.12315600117047627,0.11526900281508763,0.10794900233546893,0.10109500028192997,0.09462730151911576,0.08847649954259396,0.08258110160628955,0.07689620119829972,0.071385499710838,0.06601920040945213,0.06083120126277208,0.055849200735489525,0.0510330010826389,0.04635480108360449,0.04179160048564275,0.037324500580628715,0.03293800028041005,0.028619200146446627,0.024357599982370932,0.020144199952483177,0.016345399742325146,0.013253999951605996,0.010740099940449,0.008697280039389929,0.007038339972496033,0.005692110008870562,0.00460039001579086,0.0037156699884993336,0.002999189969462653,0.0024193500091011324,0.001950400018055613,0.0015713799997077633,0.0012652499814673017,0.001018140009061123,0.0008188119924549634,0.0006581189954886213,0.0005286549955296019,0.000424415004090406,0.0003405360015070376,0.0002730819978751242,0.00021886700172520554,0.00017532000128994696,0.00014036099916362824,0.00011231300049985293,8.982210116907179e-05,7.179759995779023e-05,5.73604005088176e-05,4.580289957326992e-05,3.655560036956255e-05,2.9160800143775607e-05,2.3250300121920493e-05,1.852879980409246e-05,1.4759000047585383e-05,1.1750599999989694e-05,9.351020025860635e-06,7.437979888891277e-06,5.913589954313163e-06,4.699480011064831e-06,3.7329600104385463e-06,2.963890021116337e-06,2.352230012547807e-06,1.865990014948693e-06,1.4796299675860307e-06,1.172760012953707e-06,9.291430084582922e-07,7.358269868973366e-07,5.824909929212178e-07,4.6092002511007496e-07,3.645740254872483e-07,2.8825199175723054e-07,2.278179837370923e-07,1.799830198952653e-07,1.4213702096791772e-07,1.1220596896066581e-07,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708094507455826,0.9575150708357493,1.0311000694831212,1.1069500744342804,1.184730072816213,1.2641100684801738,1.3448200821876526,1.423490087191264,1.4971800943215687,1.5664601027965546,1.6318400899569194,1.6937601069609325,1.752630094687144,1.8088001211484273,1.86257008711497,1.9142200847466786,1.9640000959237416,2.010270098845164,2.051620046297709,2.088650087515513,2.1218701203664145,2.151750107606252,2.178700069586436,2.2030701438585916,2.225170095761617,2.245280106862386,2.2636200984319053,2.2830101251602173,2.3059001167615256,2.3318700989087424,2.360550125439962,2.39162011941274,2.424790104230245,2.459800124168396,2.4964400927225747,2.5345001022020974,2.573820094267527,2.614560147126516,2.656830132007599,2.7003801266352334,2.744960129261017,2.7903801004091897,2.836450139681498,2.8830201625823975,2.9299501180648804,2.977130174636841,3.024450163046519,3.0728201270103455,3.1230701406796775,3.174930195013682,3.2281501491864524,3.2825201551119485,3.3378601471583047,3.393990178902944,3.4507701794306436,3.508070190747579,3.565780202547709,3.6224801341692605,3.6769102017084756,3.7292701601982117,3.77972020705541,3.8284402092297873,3.8755401770273843,3.9211801886558533,3.965460181236267,4.0084802110989886,4.050340175628662,4.0890902280807495,4.122970143953959,4.152520140012105,4.178200125694275,4.20041028658549,4.219540158907573,4.235910256703694,4.249820152918498,4.261540214220683,4.271300236384074,4.2785301605860395,4.282770156860352,4.284400224685669,4.283770163853963,4.281170169512431,4.276870171229045,4.271110097567241,4.264080206553142,4.255960146586101,4.246920188268025,4.235520164171855,4.220540205637614,4.202410141626994,4.181560158729553,4.158340175946553,4.1330801248550415,4.106050173441569,4.0775201718012495,4.047710180282593,4.016800204912822,3.984990119934082,3.9524101416269937,3.9192001819610596,3.8854801654815674,3.851340174674988,3.8168901205062866,3.7821901639302573,3.7473201553026834,3.7123201489448547,3.6772701740264893,3.642190158367157,3.607130150000254,3.5721101562182107,3.537170171737671,3.5023301442464194,3.4676001270612082,3.4330201745033264,3.3985801537831626,3.3643001516660056,3.330200175444285,3.296270191669464,3.2625301480293274,3.2289701302846274,3.1956001122792563,3.162430167198181,3.1294501225153604,3.096670150756836,3.064090112845103,3.0317001342773438,2.9995001355806985,2.9674901167551675,2.9356701374053955,2.9040401180585227,2.8726001381874084,2.8413401444753013,2.8102601567904153,2.7793601353963218,2.7486301263173423,2.718070129553477,2.687680105368296,2.657450099786123,2.6273900866508484,2.597490131855011,2.5677400827407837,2.538150111834208,2.50870011250178,2.479400098323822,2.4502500891685486,2.42123011747996,2.3923500974973044,2.363610088825226,2.3350100914637246,2.3065300981203714,2.2781700690587363,2.2499400774637857,2.2218401233355203,2.193850100040436,2.165980080763499,2.138230085372925,2.110580086708069,2.083050092061361,2.055630087852478,2.0283101201057434,2.0010900696118674,1.9739800890286763,1.9469700654347737,1.9200500845909119,1.893230100472768,1.8665100832780201,1.8398700853188832,1.8133300840854645,1.7868700722853343,1.7605100969473522,1.7342300713062286,1.7080300748348236,1.6819200615088146,1.6558800637722015,1.6299300789833069,1.6040500700473785,1.5782500902811687,1.5525300701459248,1.5268900692462921,1.5013100604216258,1.4758100708325703,1.4503800769646962,1.4250200688838959,1.3997300664583843,1.3745000660419464,1.34934006134669,1.324250062306722,1.2992200553417206,1.2742600639661152,1.2493600646654766,1.224520057439804,1.199740062157313,1.1750200390815735,1.1503600577513378,1.1257600486278534,1.101220041513443,1.0767400463422139,1.0523100694020588,1.0279400448004405,1.0036200433969498,0.9793580373128256,0.9551500429709753,0.9309970438480377,0.9068950364987055,0.8828460425138474,0.8588470369577408,0.8348990281422933,0.8110020309686661,0.787154033780098,0.763358031709989,0.7396130263805389,0.7159160226583481,0.6922660320997238,0.6686650266249975,0.6451110243797302,0.6216040203968684,0.5981440246105194,0.5747320204973221,0.5513680229584376,0.5280500203371048,0.5047780176003774,0.48155001550912857,0.458368015786012,0.4352310101191203,0.4121380150318146,0.38909300913413364,0.3660930097103119,0.3431370109319687,0.3202260086933772,0.2973580062389374,0.27453400442997616,0.2517530048886935,0.2290170043706894,0.20632600163420042,0.18368100126584372,0.16107799982031187,0.13851900026202202,0.11766500025987625,0.09992770043512185,0.0848468008140723,0.07202839913467567,0.06113620071361462,0.051883100221554436,0.044024200178682804,0.037350899539887905,0.03168549994006753,0.026876499876379967,0.02279520019267996,0.01933189993724227,0.016393499992166955,0.013900600063304106,0.011785999949400624,0.009992480045184493,0.008471369976177812,0.0071814400143921375,0.006087620005321999,0.005160169947581987,0.004373830005836983,0.003707170020788908,0.0031420100131072104,0.0026629200049986443,0.002256809986041238,0.0019125700152168672,0.0016208000015467405,0.0013734999908289562,0.0011639100072594981,0.0009862720132029306,0.0008357290062122047,0.0007081490136139715,0.0006000330079890167,0.0005084129952592775,0.00043077400187030435,0.00036498499927499023,0.0003092379944670635,0.0002620009981910698,0.00022197600264917128,0.00018806200265923204,0.00015932700019523813,0.0001349809972452931,0.00011435300136023822,9.687589893777233e-05,8.206880071763105e-05,6.952390018947578e-05,5.889580127889834e-05,4.989169883629074e-05,4.2263499684243776e-05,3.5801199373963755e-05,3.0326600153784966e-05,2.56886996794492e-05,2.1759900240188774e-05,1.843170002757688e-05,1.5612299951802317e-05,1.3223999985711998e-05,1.1200999930830827e-05,9.487269987099959e-06,8.035649974165912e-06,6.806049971904334e-06,5.764529987573042e-06,4.882330055503796e-06,4.135090004335022e-06,3.5021600031844477e-06,2.966080008566981e-06,2.5120300127431014e-06,2.127450007568162e-06,1.8017299983815367e-06,1.525860000128887e-06,1.2922099964877514e-06,1.0943299931417034e-06,9.267370018051224e-07,7.848009981141028e-07,6.645959918690399e-07,5.627950088182843e-07,4.765809980729803e-07,4.0357000112104896e-07,3.417400004461039e-07,2.893790001697501e-07,2.450380011490931e-07,2.0748800011460844e-07,1.75691001894999e-07,1.4876400082168098e-07,1.2596299884629994e-07,9.843006705996989e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.2528558596968651,0.26552996536095935,0.27535797903935116,0.28538497537374496,0.2953829765319824,0.3053449789683024,0.31526297330856323,0.3246489812930425,0.33304697771867114,0.34052297721306485,0.3471349775791168,0.35294098158677417,0.3579919785261154,0.36233798166116077,0.3660239825646083,0.3690929760535558,0.3715839758515358,0.37351197997728985,0.3748909855882327,0.37575797984997433,0.376150980591774,0.37610198309024173,0.37564098089933395,0.374797984957695,0.37359698365132016,0.3720619852344195,0.3702169805765152,0.3683599804838498,0.36677198112010956,0.3654309809207916,0.36431798338890076,0.36341698467731476,0.36271098007758457,0.36218498398860294,0.36182398597399396,0.36161597818136215,0.3615499834219615,0.3616349870959918,0.36188098539908725,0.3622709835569064,0.3627909794449806,0.36342598249514896,0.36416498323281604,0.3649949828783671,0.36590898036956787,0.3668949802716573,0.36794498066107434,0.36909497777620953,0.3703789835174878,0.3717849800984065,0.3733019803961118,0.3749199757973353,0.3766309743126233,0.378425973157088,0.3802969778577487,0.38223697741826373,0.3842389831940333,0.38620998213688534,0.3880619779229164,0.38979998230934143,0.39142798135677975,0.39294997851053876,0.394368976354599,0.3956919809182485,0.39691997816165286,0.3980589807033539,0.3991119811932246,0.39998498062292737,0.40058698256810504,0.40093497683604556,0.4010429804523786,0.40092498312393826,0.40059397866328555,0.4000629757841428,0.39934397985537845,0.398447980483373,0.39738698303699493,0.3961579849322637,0.39475998282432556,0.39320797969897586,0.39151197920242947,0.3896849875648816,0.3877359827359517,0.3856759841243426,0.3835129787524541,0.38125598678986233,0.3789119819800059,0.376490980386734,0.3740009864171346,0.37144798040390015,0.3688389832774798,0.3661779860655467,0.36347098151842755,0.36072298387686413,0.3579379816850026,0.3551219825943311,0.3522769833604495,0.34940798332293826,0.34651898344357807,0.3436119829614957,0.3406899844606717,0.33775698641935986,0.33481398473183316,0.33186498284339905,0.3289119824767113,0.3259559820095698,0.32299798478682834,0.32004098345836,0.31708698719739914,0.31413697948058444,0.31119198848803836,0.30825398365656537,0.3053239832321803,0.30240198224782944,0.29948898653189343,0.29658698042233783,0.29369598378737766,0.2908159817258517,0.28794798503319424,0.2850929871201515,0.2822509879867236,0.27942099173863727,0.276605986058712,0.2738039841254552,0.2710159868001938,0.26824098577102023,0.26547998438278836,0.26273298511902493,0.2600009888410568,0.2572839880983035,0.25458098699649173,0.25189199298620224,0.24921798954407373,0.24655898908774057,0.24391298865278563,0.2412819874783357,0.23866499091188112,0.23606098939975104,0.23347199087341627,0.23089598615964255,0.22833298767606416,0.22578398883342743,0.22324898963173231,0.22072598959008852,0.21821398908893266,0.21571498860915503,0.21322899063428244,0.2107549880941709,0.20829398930072784,0.2058439888060093,0.20340598995486894,0.20097899188597998,0.1985639917353789,0.1961599886417389,0.19376699005564055,0.19138498976826668,0.18901398902138075,0.18665299067894617,0.18430199225743613,0.18196099127332369,0.17962998896837234,0.1773069923122724,0.1749939906100432,0.17268999417622885,0.1703959902127584,0.16810999189813933,0.1658339910209179,0.163565993309021,0.16130699341495833,0.15905599296092987,0.15681399405002594,0.15457899123430252,0.15235299244523048,0.15013399347662926,0.14792299146453539,0.14571999261776605,0.14352399110794067,0.14133499066034952,0.1391539933780829,0.1369789938131968,0.13480999444921812,0.13264699404438338,0.13049199432134628,0.1283429947992166,0.1262009913722674,0.12406399349371593,0.12193499381343524,0.11981099471449852,0.11769399419426918,0.11558199487626553,0.11347599451740582,0.11137599435945351,0.10928199502329032,0.10719299502670765,0.10510999523103237,0.10303199539581935,0.10095999638239543,0.09889259499808152,0.09683049594362576,0.09477219606439273,0.09271899610757828,0.09067089669406414,0.08862769541641076,0.08658939537902673,0.08455599658191204,0.08252739657958348,0.08050349603096645,0.07848419683674972,0.07646949651340644,0.07445929696162541,0.07245359631876151,0.07045229648550351,0.06845539684096973,0.0664627980440855,0.0644744982322057,0.062490397753814854,0.06051049785067638,0.0585347975914677,0.05656169820576906,0.05459289780507485,0.05262819863855839,0.050667498571177326,0.04871099845816692,0.046758398724099,0.0448098989824454,0.04286529899885257,0.04092459908376137,0.03898779954761267,0.03705479918668667,0.03512569951514403,0.033200399639705815,0.03127879944319526,0.02936109947040677,0.027447099797427654,0.025536799958596628,0.02363019995391369,0.021727300093819697,0.019904100025693577,0.018231799981246393,0.016698199945191543,0.015292200104643902,0.014003299952795109,0.012821999999384085,0.011739599984139204,0.010747800037885705,0.009839150045687953,0.009006860045095285,0.008244560022527972,0.0075464199762791395,0.006907119958971937,0.0063217299757525325,0.005785750031160812,0.005295039930691321,0.0048457999946549535,0.004434559998723368,0.004058110003825277,0.00371352998384585,0.0033981400192715228,0.003109470009803772,0.0028452700353227556,0.00260346995977064,0.002382179993825654,0.002179669992377361,0.001994340001450231,0.0018247499926170956,0.00166955998671862,0.0015275399976720412,0.001397590017101417,0.0012786900042556226,0.0011698799983908732,0.0010703199950512499,0.0009792290074983612,0.0008958789985626936,0.0008196169947041199,0.0007498390041291714,0.0006859960024788355,0.0006275829994895806,0.0005741400042703996,0.00052524299826473,0.00048050700085392844,0.00043957799789495766,0.0004021319982712157,0.00036787300147504237,0.0003365310064206521,0.0003078559966525063,0.00028162300198649365,0.00025762300356291234,0.00023566699989411669,0.00021558099858035953,0.00019720500010104539,0.00018039399947156198,0.00016501499946267964,0.00015094700089927451,0.00013807600043946877,0.00012630300019130422,0.0001155319999573597,0.0001056790000196391,9.666629921412095e-05,8.842130046105012e-05,8.08789997487717e-05,7.397950018154613e-05,6.766819994178756e-05,6.189490037892635e-05,5.661379994611101e-05,5.178300004142026e-05,4.736409967639096e-05,4.332200023782207e-05,3.962459989755492e-05,3.624250075517921e-05,3.3148900304998584e-05,3.0319200201726442e-05,2.773080010835353e-05,2.5363299907136632e-05,2.3197699799008358e-05,2.1216900070915774e-05,1.9405100071404984e-05,1.7747999815280007e-05,1.6232200171846973e-05,1.4845799872394613e-05,1.3577699898329835e-05,1.2417899976450522e-05,1.1357100068683698e-05,1.0386800189129039e-05,9.499439935704382e-06,8.687890082607433e-06,7.945680143469266e-06,7.266880023356255e-06,6.646079934095421e-06,6.078320022121868e-06,5.55907001853484e-06,5.084179974801373e-06,4.6498599128123414e-06,4.252650038930976e-06,3.889380006209346e-06,3.5571400000359668e-06,3.2532799991713546e-06,2.975390013186067e-06,2.7212300324208627e-06,2.4887900167414045e-06,2.276200007145235e-06,2.081779977440116e-06,1.9039599976622412e-06,1.7413400049311651e-06,1.5926000003219087e-06,1.4565700136396724e-06,1.3321700009782944e-06,1.218379992451446e-06,1.114319995091743e-06,1.0191499958030665e-06,9.32106999584903e-07,8.524979998962104e-07,7.7969000263541e-07,7.131010022476403e-07,6.522000006725648e-07,5.96499996656045e-07,5.455579952240441e-07,4.98966992760567e-07,4.5635500356411285e-07,4.173829969052652e-07,3.8173999901876715e-07,3.4913999987414474e-07,3.1932500140404346e-07,2.920560030853873e-07,2.671169999265051e-07,2.4430699833525676e-07,2.2344499939208617e-07,2.043649989976378e-07,1.8691399953733404e-07,1.7095399940103562e-07,1.5635700023608479e-07,1.4300599815442183e-07,1.3079500149615342e-07,1.196280011347047e-07,1.0941300014148207e-07,5.115157778827021e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
                   
                   //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3640317022800446,1.475160002708435,1.5928399860858917,1.7053600152333577,1.818800002336502,1.9331299761931102,2.048369993766149,2.164589981238047,2.281839986642202,2.4001200199127197,2.519440015157064,2.6397800048192344,2.7611499627431235,2.8835399945576987,3.0069600145022073,3.1313900152842202,3.256849984327952,3.383150021235148,3.5101500153541565,3.637839992841085,3.766219993432363,3.8952800035476685,4.0250199635823565,4.155449986457825,4.286550045013428,4.418329993883769,4.550789992014567,4.684000054995219,4.818059961001079,4.95295004049937,5.088669935862224,5.225229978561401,5.362619956334432,5.500839988390605,5.639879981676738,5.77974001566569,5.920429984728496,6.0615999301274615,6.202940066655477,6.34444002310435,6.486110091209412,6.6279300053914385,6.769910017649333,6.912050008773804,7.054339965184529,7.196799914042155,7.339400053024292,7.4820899566014605,7.624819993972778,7.767590045928955,7.910379966100057,8.053200006484985,8.196060021718344,8.338939984639486,8.481849988301596,8.62477993965149,8.76774009068807,8.910459915796915,9.052640040715536,9.194299936294556,9.33542005221049,9.476020018259684,9.616089979807535,9.755639950434366,9.894650141398111,10.03309996922811,10.17110006014506,10.308500051498413,10.445199966430664,10.581200122833252,10.716600020726522,10.85130000114441,10.985299905141195,11.11870010693868,11.251500050226847,11.383500019709269,11.514899969100952,11.645600080490112,11.77559987703959,11.904800097147623,12.033300081888834,12.161099990208944,12.288100004196167,12.414400100708008,12.539899984995523,12.664699951807657,12.788800160090128,12.911900043487549,13.033700148264566,13.154200077056885,13.273499886194864,13.391499996185303,13.508200089136759,13.62369990348816,13.737899939219156,13.850899855295816,13.962599913279215,14.073100090026855,14.182399988174438,14.290299971898397,14.39709997177124,14.502599954605103,14.606899976730347,14.709900061289469,14.811699946721395,14.912300030390421,15.011600017547607,15.10979994138082,15.206700007120768,15.30239995320638,15.396900018056234,15.490099906921387,15.582200050354004,15.67300001780192,15.76259994506836,15.851099888483683,15.938300053278605,16.02430009841919,16.10919984181722,16.192799886067707,16.275300184885662,16.356599807739258,16.436599890391033,16.51550006866455,16.593299706776936,16.669800281524658,16.74519983927409,16.8193998336792,16.892399946848553,16.96430015563965,17.03499984741211,17.10449981689453,17.17289972305298,17.240100065867107,17.30620018641154,17.371099948883057,17.434900283813477,17.49750026067098,17.55900001525879,17.61930004755656,17.678500175476074,17.736600081125896,17.79349994659424,17.849299907684326,17.90399996439616,17.95750029881795,18.009899934132893,18.06120014190674,18.11140012741089,18.160500208536785,18.208399931589764,18.25530020395915,18.301000118255615,18.345600128173828,18.38920005162557,18.431600252787273,18.472899913787842,18.51319980621338,18.552299976348877,18.590400060017902,18.627299944559734,18.66319990158081,18.698000113169353,18.73169994354248,18.764399846394856,18.795900026957195,18.82639996210734,18.85579999287923,18.884199778238933,18.911499977111816,18.937699953715008,18.962900161743164,18.987000465393066,19.010000069936115,19.032000064849854,19.05300013224284,19.07289997736613,19.091700236002605,19.10949993133545,19.1263001759847,19.14199956258138,19.156700134277344,19.170399983723957,19.182999928792317,19.194599946339924,19.2052001953125,19.214699904123943,19.223300139109295,19.23079999287923,19.237299919128418,19.24270009994507,19.24720001220703,19.25069983800252,19.25309991836548,19.254599889119465,19.25499979654948,19.254400094350178,19.252899805704754,19.25029993057251,19.2467999458313,19.242199897766113,19.2367000579834,19.23020013173421,19.222699960072834,19.214200019836426,19.204700311024983,19.194299856821697,19.182899792989094,19.170499960581463,19.15709988276164,19.142800013224285,19.12749989827474,19.111199855804443,19.094000180562336,19.075800100962322,19.056700229644775,19.03660011291504,19.01549990971883,18.993499914805096,18.97059981028239,18.946699778238933,18.921899954477947,18.896099885304768,18.86929988861084,18.841700077056885,18.81310002009074,18.783600171407063,18.75309991836548,18.721700032552082,18.68939971923828,18.656099796295166,18.621999899546307,18.586899916330974,18.550900141398113,18.513999938964844,18.476099809010822,18.437400341033936,18.398200035095215,18.35920000076294,18.320199648539226,18.28129990895589,18.242400010426838,18.203699747721355,18.165099779764812,18.126500129699707,18.088000138600666,18.049599806467693,18.011300086975098,17.972999890645344,17.93489996592204,17.89680020014445,17.858800252278645,17.820900281270344,17.783099969228108,17.745399792989094,17.7076997756958,17.670100053151447,17.63260014851888,17.595200220743816,17.557799975077312,17.520599842071533,17.483399868011475,17.44630002975464,17.409299850463867,17.372299989064533,17.335500081380207,17.2987003326416,17.26200008392334,17.225300153096516,17.18879985809326,17.152299880981445,17.11590035756429,17.079600016276043,17.043399810791016,17.00719992319743,16.971100012461346,16.935099760691326,16.89919964472453,16.86330000559489,16.82760016123454,16.791899998982746,16.756200154622395,16.720699787139893,16.685200055440266,16.649799982706707,16.614499886830647,16.57919994990031,16.544100125630695,16.508999983469646,16.473900000254314,16.43899981180827,16.4041002591451,16.36929972966512,16.33459997177124,16.299999872843426,16.265399932861328,16.230899810791016,16.196399847666424,16.162099838256836,16.12779998779297,16.093600114186604,16.059500058492024,16.025399843851726,15.991400003433228,15.957499980926514,15.92359987894694,15.88979991277059,15.8561000029246,15.822500069936117,15.789000034332275,15.755499919255575,15.721999963124594,15.688699960708618,15.655400037765503,15.622199853261312,15.589100042978922,15.555999994277954,15.522999922434488,15.490099986394247,15.457200050354004,15.424499988555908,15.391800085703531,15.359100023905436,15.326500018437704,15.293999910354614,15.261600097020468,15.22920004526774,15.196900049845377,15.164700110753378,15.132499933242798,15.1003999710083,15.068399906158447,15.036499897638956,15.004600048065186,14.972800016403198,14.940999984741211,14.909300009409586,14.877700010935465,14.846199909845987,14.81469996770223,14.783299922943115,14.75190003712972,14.720600048700968,14.68940003712972,14.658300081888834,14.62719988822937,14.596200068791708,14.565199931462606,14.534300088882446,14.503500064214071,14.472699960072836,14.442099968592325,14.411400000254313,14.380900065104166,14.35040012995402,14.319999933242798,14.289600054423014,14.259299914042154,14.229100147883097,14.198900063832602,14.168799797693888,14.138700008392334,14.108800093332926,14.07889993985494,14.048999945322672,14.019200086593628,13.989499966303507,13.959800084431967,13.930200099945068,13.900700092315674,13.871200005213419,13.841800053914389,13.81250007947286,13.783199946085611,13.754000027974447,13.724799950917562,13.69569993019104,13.666699965794882,13.637700001398722,13.608800013860067,13.57989994684855,13.551199833552042,13.52239990234375,13.493800083796183,13.465199947357178,13.436599890391031,13.408099810282389,13.379700104395548,13.35130008061727,13.322999954223633,13.294799963633219,13.266600052515665,13.238499959309896,13.210400025049845,13.182399908701578,13.154499928156534,13.126599868138632,13.09879994392395,13.071000019709269,13.04330007235209,13.015699863433838,12.988100131352743,12.960600137710571,12.93309998512268,12.905699888865152,12.878299951553345,12.8510000705719,12.823799928029379,12.796600023905436,12.769499937693277,12.742400089899698,12.715400060017904,12.688500006993612,12.66159995396932,12.634699980417887,12.607999960581461,12.581199884414673,12.55460000038147,12.528000116348267,12.501400073369345,12.474900007247925,12.448499917984009,12.422099908192953,12.39579995473226,12.369499921798706,12.343299865722656,12.317199945449829,12.291099866231283,12.265000025431315,12.239000082015991,12.213100035985311,12.18720006942749,12.161400000254313,12.135600090026855,12.109900077184042,12.084199905395508,12.058599869410196,12.03309996922811,12.007599830627441,11.982100009918213,11.956799983978271,11.931399981180826,11.906100114186605,11.880899906158447,11.855700095494589,11.830599943796793,11.805599848429361,11.780499935150146,11.755599896113077,11.730700016021729,11.70579997698466,11.680999994277954,11.656300067901611,11.631600062052408,11.606899897257486,11.58240000406901,11.55779997507731,11.533300002415976,11.508899927139282,11.484500090281168,11.460200071334839,11.43590005238851,11.411700010299683,11.387499888737997,11.363399902979532,11.33929999669393,11.315299987792969,11.29129989941915,11.267400026321411,11.243599971135458,11.21970009803772,11.196000099182129,11.172300100326538,11.148600021998087,11.12500007947286,11.101399978001913,11.077900012334188,11.054400046666464,11.030999978383383,11.007700045903524,10.984299977620443,10.961099863052368,10.937899986902872,10.914700110753378,10.891600052515665,10.879999876022339};
                   C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.4800931215286255,4.563908696174622,4.607269088427226,4.680289109547933,4.757159074147542,4.837888995806376,4.9224690198898315,5.007549126942952,5.0897791385650635,5.169159173965454,5.245689233144124,5.319379250208537,5.3902192910512285,5.458209196726481,5.523349324862163,5.585639317830403,5.645089348157247,5.702199379603068,5.757489363352458,5.810959537823995,5.862599492073059,5.912419478098552,5.960409482320149,6.006589492162068,6.050939520200093,6.093459606170654,6.134169618288676,6.17337961991628,6.211419582366943,6.2482995589574175,6.284009615580241,6.318549593289693,6.351929585138957,6.384149630864461,6.415199677149455,6.445079763730367,6.473799745241801,6.501559694608052,6.52856969833374,6.554829756418864,6.580349683761597,6.6051197449366255,6.62913978099823,6.652419805526733,6.674939870834351,6.696719725926717,6.717759728431702,6.738179802894592,6.7581197420756025,6.777579824129741,6.796559810638428,6.815069794654846,6.833089828491211,6.850639780362447,6.867709835370381,6.884299834569295,6.900409817695618,6.91612982749939,6.93153981367747,6.9466398159662885,6.961439847946167,6.975929816563924,6.990119854609172,7.003989934921265,7.017559885978699,7.030829826990764,7.043789863586426,7.056319912274678,7.068309903144836,7.079759915669759,7.090659936269124,7.101019859313965,7.110839923222859,7.120109875996907,7.12883992989858,7.137029965718587,7.14467990398407,7.1520499388376875,7.159429907798767,7.166799863179524,7.174169858296712,7.181539972623189,7.188909928003947,7.196279923121135,7.203649997711182,7.21101991335551,7.2183899482091265,7.225729902585347,7.233010013898213,7.2402398983637495,7.247419873873393,7.254539926846822,7.261599938074748,7.268610000610352,7.275569915771484,7.282469908396403,7.28931991259257,7.296109914779663,7.302849968274434,7.309530019760132,7.316159963607788,7.322739919026692,7.329259872436523,7.33571990331014,7.342129945755005,7.348489920298259,7.3547898928324384,7.361039956410726,7.36722993850708,7.3733698924382525,7.379449923833211,7.385479887326558,7.3914599021275835,7.397379914919536,7.403239925702413,7.409049908320109,7.414809902509053,7.420509894688924,7.426159898440043,7.43175995349884,7.437289913495381,7.442779898643494,7.448209921518962,7.453579942385356,7.458909908930461,7.4641698996226,7.469380021095276,7.474539955457051,7.479649901390076,7.484699885050456,7.489689985911052,7.4946298996607466,7.499519944190979,7.504349946975708,7.509119987487793,7.513849973678589,7.518519957860311,7.523129979769389,7.527689854303996,7.532189965248108,7.536649902661641,7.541039943695068,7.545379916826884,7.549670020739238,7.55390997727712,7.558089931805928,7.562209924062093,7.566279967625936,7.570299983024597,7.574259916941325,7.5781699021657305,7.582019964853923,7.585819959640503,7.589569926261902,7.593259930610657,7.596889932950337,7.6004800001780195,7.603999932607015,7.607479969660441,7.610900004704793,7.614259918530782,7.617569963137309,7.6208300193150835,7.624029994010925,7.627169926961263,7.630269964536031,7.633299986521403,7.636289993921916,7.639219919840495,7.6420899629592896,7.644909938176473,7.647680044174194,7.650389949480693,7.653049985567729,7.655649979909261,7.6581999858220415,7.660699923833211,7.6631399393081665,7.665529886881511,7.66786007086436,7.670139869054158,7.672370036443074,7.674540003140767,7.676659981409709,7.678719957669576,7.680730064709981,7.682679971059163,7.684580008188884,7.686429937680562,7.688219984372457,7.68995996316274,7.691649953524272,7.693279981613159,7.694849967956543,7.696370005607605,7.697839975357056,7.699259996414185,7.70061997572581,7.701919953028361,7.703169981638591,7.704369982083638,7.705519994099935,7.7066099643707275,7.707639892896016,7.708619991938273,7.709549983342488,7.710429946581523,7.7112499078114825,7.712009986241658,7.712719996770223,7.713380018870036,7.713989973068237,7.7145399649937945,7.715030074119568,7.715480009714763,7.71586000919342,7.716200033823649,7.716479976971944,7.716710011164348,7.716880043347676,7.7170000076293945,7.717060089111328,7.717069983482361,7.717030048370361,7.716929952303569,7.716779947280884,7.716579953829448,7.7163199583689375,7.716010014216105,7.715640028317769,7.715219974517822,7.714750011761983,7.71422000726064,7.713639974594116,7.7130000193913775,7.712310115496318,7.711570064226787,7.7107999722162885,7.71002991994222,7.709249973297119,7.708480000495911,7.707709987958272,7.706939975420634,7.706170002619426,7.705399990081787,7.7046299775441485,7.70386000474294,7.703089992205302,7.702320019404094,7.701550006866455,7.700779994328816,7.700009981791179,7.69924000898997,7.6984699964523315,7.697700023651123,7.696930011113484,7.6961599588394165,7.695390025774638,7.6946200132369995,7.693850000699361,7.693080027898152,7.6923099756240845,7.691540042559306,7.690769990285237,7.690009991327922,7.689240097999573,7.688470005989075,7.687700072924296,7.686930020650228,7.68615996837616,7.685390035311381,7.684620022773743,7.683859904607137,7.6830900112787885,7.682320078214009,7.681550025939941,7.680780013402303,7.6800200541814165,7.679250001907349,7.67848002910614,7.6777100165685015,7.676940004030864,7.6761800448099775,7.675409992535909,7.674639979998271,7.6738700071970625,7.673109968503316,7.6723399957021075,7.67156998316447,7.670800010363261,7.670040011405945,7.669269998868306,7.668499946594238,7.667739947636922,7.6669700145721436,7.666200041770935,7.665439923604329,7.664670030275981,7.663900017738342,7.663139979044597,7.662370006243388,7.661610007286072,7.660839994748433,7.660069982210795,7.659309983253479,7.65853997071584,7.657779971758525,7.657009998957316,7.656240026156108,7.655479947725932,7.654710014661153,7.653949936230977,7.653180003166199,7.652419924736023,7.651649991671245,7.650889992713928,7.65011998017629,7.649359981218974,7.648590008417766,7.647830009460449,7.647059917449951,7.646299997965495,7.6455299854278564,7.64476998647054,7.644000013669332,7.643240054448445,7.6424800157547,7.641709923744202,7.640949924786885,7.640179991722107,7.639419992764791,7.638659993807475,7.637889981269836,7.63713002204895,7.636360049247742,7.635600050290425,7.6348399718602495,7.634070038795471,7.633309920628865,7.632549961407979,7.631779948870341,7.631020029385884,7.630260030428569,7.62949001789093,7.628730098406474,7.627969980239868,7.627210021018982,7.626440008481343,7.625680009524028,7.624920010566711,7.624160011609395,7.623389999071757,7.622630000114441,7.621870040893555,7.621110041936238,7.62034006913503,7.619579990704854,7.6188199917475385,7.618059992790222,7.617300073305766,7.61654003461202,7.615770022074382,7.615009983380635,7.61424998442332,7.613490025202434,7.612729946772258,7.611970027287801,7.611210028330485,7.6104399760564165,7.609679977099101,7.608920017878215,7.608160018920898,7.607399980227153,7.606639981269836,7.60588006178538,7.605119983355205,7.604360024134318,7.603599985440572,7.602840026219686,7.60207998752594,7.601320028305054,7.600559989611308,7.599799990653992,7.599039991696675,7.598280032475789,7.5975199937820435,7.596759994824727,7.596000035603841,7.595239996910095,7.594479997952779,7.593719959259033,7.5929601192474365,7.592200001080831,7.591440041859944,7.590679963429769,7.589920004208882,7.589159965515137,7.588410059611003,7.587650100390117,7.586889982223511,7.5861300230026245,7.585369984308879,7.584610025087993,7.583849986394246,7.583100001017253,7.582339962323506,7.58158000310262,7.580820004145305,7.580060005187988,7.579309980074565,7.5785499811172485,7.577789982159932,7.577030022939046,7.57626994450887,7.575520038604736,7.57476003964742,7.574000000953674,7.573240001996358,7.572489937146504,7.571730017662048,7.570969978968303,7.570220073064168,7.569460034370422,7.568700035413106,7.56793999671936,7.567190051078796,7.566430012385051,7.565669933954875,7.56492002805074,7.564159989356995,7.5634100039800005,7.562650005022685,7.5618899663289385,7.561139980951945,7.560379981994629,7.559620022773743,7.558869997660319,7.558110038439433,7.557360053062439,7.556600054105123,7.55584990978241,7.555090030034383,7.554330031077067,7.553580005963643,7.552820007006328,7.5520700216293335,7.551310022672017,7.550559997558594,7.549799998601277,7.549050052960713,7.548289974530538,7.547540068626404,7.546779990196228,7.546030004819234,7.5452799797058105,7.544519941012065,7.543769995371501,7.543010036150615,7.5422600110371905,7.541500012079875,7.540749986966451,7.5400000015894575,7.539239962895711,7.538490017255147,7.537729978561401,7.536979913711548,7.536230047543843,7.535470008850098,7.534719944000244,7.53396999835968,7.533210039138794,7.53245997428894,7.531709949175517,7.530949989954631,7.530199964841207,7.529450058937073,7.528689940770467,7.527940034866333,7.5271899700164795,7.5264400243759155,7.52567998568217,7.524930000305176,7.524179975191752,7.5234300295511884,7.522670030593872,7.522300044695537};
                   //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174860845009486,0.6330969432989756,0.6434339483579,0.6587269405523936,0.674825926621755,0.6917289396127065,0.7094389349222183,0.7272539287805557,0.7444709440072378,0.7610909342765808,0.7771139393250147,0.7925389359394709,0.8073669423659643,0.8215979486703873,0.8352319498856863,0.8482709527015686,0.8607139587402344,0.8726669500271479,0.8842359632253647,0.8954239586989085,0.9062289545933405,0.9166519592205683,0.9266929576794306,0.9363519648710886,0.9456289658943812,0.9545229772726694,0.9630369693040848,0.9712369640668234,0.9791919638713201,0.9869029670953751,0.9943689753611883,1.0015899588664372,1.0085699756940205,1.0152999659379323,1.0217899878819783,1.028029978275299,1.0340399742126465,1.0398399829864502,1.045479953289032,1.0509699781735737,1.056289980808894,1.061469982067744,1.0664799610773723,1.0713399946689606,1.076039989789327,1.0805899997552235,1.0849799911181133,1.0892399946848552,1.0933999915917714,1.0974599818388622,1.101419985294342,1.1052799820899963,1.1090399821599324,1.112689991792043,1.1162499785423279,1.119709978501002,1.1230699916680653,1.1263399918874104,1.129550000031789,1.132699986298879,1.1357799867788951,1.1387999753157299,1.1417499879995983,1.1446399887402852,1.1474599838256836,1.150219996770223,1.1529199878374736,1.1555299659570057,1.1580199897289276,1.1603999733924866,1.162669986486435,1.1648199955622356,1.1668499906857808,1.1687799990177155,1.1705899735291798,1.1722899874051411,1.1738699972629547,1.1753899852434795,1.1769199868043263,1.1784400045871735,1.179969996213913,1.181489994128545,1.183019995689392,1.1845400035381317,1.1860699951648712,1.1875900030136108,1.189110000928243,1.1906299988428752,1.1921399931112926,1.1936299900213878,1.1951099932193756,1.196590006351471,1.1980500022570293,1.1995000143845875,1.200929989417394,1.2023600041866302,1.203769991795222,1.2051700055599213,1.2065600156784058,1.2079400022824605,1.209309995174408,1.2106699844201405,1.2120100061098735,1.213349978129069,1.2146699925263722,1.2159800132115681,1.217280000448227,1.2185699939727783,1.2198399901390076,1.2211099962393444,1.2223599950472515,1.2236099938551586,1.2248399953047435,1.2260499894618988,1.2272599935531616,1.228460003932317,1.2296399970849354,1.2308199803034465,1.23197998603185,1.2331299980481465,1.2342699964841206,1.2354000012079875,1.2365099986394246,1.2376199960708618,1.2387099762757618,1.239790012439092,1.2408600052197774,1.241919994354248,1.2429699897766113,1.2439999679724376,1.245030015707016,1.2460399866104126,1.2470399936040242,1.2480299770832062,1.2490099867184956,1.2499799927075703,1.2509299914042156,1.2518800000349681,1.2528099914391835,1.2537299891312916,1.2546400030454,1.2555399934450786,1.2564300000667572,1.2572999894618988,1.258169988791148,1.2590200006961823,1.2598599990208943,1.2606900036334991,1.261510004599889,1.2623200019200642,1.2631199955940247,1.263899991909663,1.2646699845790863,1.2654400169849396,1.266189992427826,1.2669299840927124,1.2676499883333843,1.268369992574056,1.2690700093905132,1.2697700063387554,1.2704499959945679,1.2711200018723805,1.2717799842357635,1.2724300026893616,1.27306001385053,1.2736900051434834,1.2742999891440074,1.2749000092347462,1.2754999895890553,1.2760799924532573,1.276639997959137,1.2771999935309093,1.2777500053246815,1.278279980023702,1.2787999908129375,1.279319981733958,1.2798199951648712,1.2803100049495697,1.2807800074418385,1.2812500099341075,1.2816999951998393,1.282150000333786,1.2825799981753032,1.283000002304713,1.2834100027879078,1.2838099896907806,1.2841899991035461,1.284569998582204,1.284929980834325,1.2852799892425537,1.2856299877166748,1.2859600087006886,1.2862800061702728,1.2865799963474274,1.2868799964586894,1.2871600190798442,1.2874400118986766,1.2876999974250793,1.2879500091075897,1.288189987341563,1.2884200016657512,1.2886299987634022,1.288839985926946,1.2890299956003826,1.289220005273819,1.2893899977207184,1.2895499964555104,1.2897000114123027,1.2898299892743428,1.2899599969387054,1.290070007244746,1.290180007616679,1.2902700106302898,1.2903500099976857,1.2904199957847595,1.2904800077279408,1.290529986222585,1.2905599971612294,1.2905899981657665,1.2906000018119812,1.2906000018119812,1.290589988231659,1.2905699809392293,1.2905399898688,1.2904900014400482,1.2904400030771892,1.2903699974219005,1.2903000017007191,1.2902100086212158,1.2901100019613903,1.2899999817212422,1.2898800075054169,1.2897399961948395,1.289600004752477,1.28943998614947,1.2892800172170003,1.2891000111897786,1.2889100015163422,1.2887299756209056,1.2885500093301137,1.2883599897225697,1.2881799936294556,1.2879899938901265,1.2878099878629048,1.2876300017038982,1.2874400118986766,1.287260005871455,1.2870699961980183,1.2868900001049042,1.2867099940776825,1.2865199943383534,1.2863400081793468,1.2861499885718028,1.285970002412796,1.2857899963855743,1.285599986712138,1.2854199806849163,1.285240004460017,1.2850500047206879,1.2848699986934662,1.2846900125344594,1.284500002861023,1.2843200067679088,1.2841399908065796,1.2839500109354656,1.2837699949741364,1.2835899988810222,1.2833999991416931,1.283220003048579,1.2830399870872498,1.2828499972820282,1.2826700111230214,1.2824900050957997,1.2822999854882557,1.2821200092633565,1.2819400032361348,1.2817499935626984,1.2815700074036915,1.2813900113105774,1.2812000115712483,1.2810199956099193,1.280839999516805,1.2806499898433685,1.2804699937502544,1.280290017525355,1.2801100114981334,1.2799200018246968,1.2797399858633678,1.279559999704361,1.2793699999650319,1.2791900038719177,1.2790100077788036,1.2788299918174744,1.2786400020122528,1.2784600059191387,1.2782799899578094,1.2780999938646953,1.277910013993581,1.2777299880981445,1.2775499920050304,1.277369995911916,1.2771799961725872,1.2770000100135803,1.276819994052251,1.2766399880250294,1.276450018088023,1.2762699921925862,1.276089996099472,1.2759100099404652,1.2757200002670288,1.2755400041739147,1.275359998146693,1.2751800020535786,1.274999996026357,1.274810016155243,1.2746299902598064,1.2744500041007996,1.2742699881394703,1.2740899920463562,1.2738999823729198,1.2737200061480205,1.2735399901866913,1.2733600040276845,1.2731799980004628,1.2729900081952412,1.2728100021680195,1.2726299961407979,1.2724499901135762,1.2722700039545696,1.2720800042152405,1.2718999981880188,1.2717199921607971,1.271539996067683,1.2713600099086761,1.2711800038814545,1.270989994208018,1.2708099981149037,1.270629992087682,1.2704499959945679,1.2702699899673462,1.2700900038083394,1.2699099977811177,1.2697200079758961,1.2695400019486744,1.2693599959214528,1.269179989894231,1.2689999838670094,1.2688199877738953,1.268640011548996,1.2684600154558818,1.2682700057824452,1.2680899997552235,1.2679099837938945,1.2677299877007802,1.2675500214099884,1.2673699955145519,1.2671899994214375,1.2670099933942158,1.2668299973011017,1.2666400074958801,1.266459991534551,1.2662799954414368,1.2660999993483226,1.2659200032552083,1.2657399972279866,1.2655600309371948,1.2653800050417583,1.2651999990145366,1.2650200029214222,1.2648399968942006,1.264660010735194,1.2644799848397572,1.2642900049686432,1.264110008875529,1.2639300127824147,1.2637499968210857,1.2635700205961864,1.2633900046348572,1.263210008541743,1.2630299925804138,1.2628499865531921,1.2626700003941853,1.2624900341033936,1.2623099982738495,1.2621300121148427,1.2619499961535137,1.2617700000603993,1.2615900039672852,1.2614099979400635,1.2612299919128418,1.261050005753835,1.2608699997266133,1.2606899936993916,1.260510007540385,1.2603300015131633,1.2601499954859416,1.2599699993928273,1.2597900032997131,1.2596099972724915,1.2594300011793773,1.259250005086263,1.2590699990590413,1.2588899930318196,1.258710006872813,1.2585300008455913,1.2583499948183696,1.2581699987252553,1.2579900026321411,1.2578099966049194,1.2576300005118053,1.257450004418691,1.2572699983914692,1.2570899923642476,1.256910006205241,1.2567300001780193,1.2565500140190125,1.2563699980576832,1.2561899920304616,1.256010005871455,1.2558300097783406,1.2556499938170116,1.2554799914360046,1.2553000052769978,1.2551200091838837,1.2549400130907695,1.2547600169976552,1.2545800010363262,1.2544000049432118,1.2542199989159901,1.254040002822876,1.2538599967956543,1.2536800305048625,1.2534999946753185,1.2533200085163116,1.2531499862670898,1.252970000108083,1.2527900040149689,1.2526100079218547,1.2524299919605255,1.2522499561309814,1.252069999774297,1.2518900235493977,1.2517099976539612,1.2515399952729542,1.2513599892457326,1.2511799931526184,1.2509999970595043,1.25082000096639,1.2506400048732758,1.250459998846054,1.2502799928188324,1.2501100103060405,1.2499300042788188,1.249749978383382,1.2495699922243755,1.2493900159994762,1.249210000038147,1.2490399877230327,1.2488600114981334,1.2486799955368042,1.24849999944369,1.2483200132846832,1.248139997323354,1.2479700048764546,1.247789998849233,1.2476099928220112,1.247429996728897,1.2472499907016754,1.2470700045426686,1.2469000021616619,1.2467199961344402,1.2465400000413258,1.2463600039482117,1.2461799879868825,1.2460100154081981,1.245829979578654,1.2456500033537548,1.2454699873924255,1.2452900012334187,1.245119998852412,1.2449400027592976,1.2447600066661835,1.2445799907048543,1.244400014479955,1.2442300220330555,1.2441399991512299};
        //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194267277916273,0.18438099945584932,0.18694199994206429,0.18960299963752428,0.1924040007094542,0.19534699991345406,0.1984309988717238,0.20153299843271574,0.2045300006866455,0.20742199942469597,0.21020800123612085,0.2128900003929933,0.2154660001397133,0.21793799847364426,0.2203070012231668,0.22257000083724657,0.22472899903853735,0.22680100301901499,0.22880699982245764,0.23074500014384589,0.232614999016126,0.2344179985423883,0.23615399996439615,0.2378240004181862,0.2394269990424315,0.24096399918198586,0.2424319994946321,0.2438459979991118,0.24521700044473013,0.24654400100310644,0.2478280005355676,0.24906899904211363,0.25026799986759823,0.25142399966716766,0.25253699719905853,0.25360699743032455,0.25463500370581943,0.25562600543101627,0.25658999880154926,0.2575270061691602,0.25843599687019986,0.25931799908479053,0.2601740037401517,0.26100000242392224,0.2617989977200826,0.2625710020462672,0.26331599801778793,0.26403700063625973,0.2647409935792287,0.26542599747578305,0.26609399914741516,0.26674500356117886,0.2673790007829666,0.2679949998855591,0.26859400421380997,0.2691739971439044,0.26973599940538406,0.2702840020259221,0.2708220010002454,0.2713479995727539,0.2718629986047745,0.2723659972349803,0.27285800129175186,0.27333899835745495,0.2738090008497238,0.2742669979731242,0.2747129946947098,0.27514400084813434,0.2755559980869293,0.27594699958960217,0.276318001250426,0.2766690005858739,0.27700000007947284,0.2773119981090228,0.2776029979189237,0.27787400037050247,0.27812500049670535,0.27836500108242035,0.27860499918460846,0.27884600311517715,0.27908600370089215,0.2793259993195534,0.27956599990526837,0.2798059955239296,0.2800459985931714,0.2802859942118327,0.2805259997646014,0.28076399862766266,0.2810000032186508,0.2812349970142047,0.2814680015047391,0.281699001789093,0.2819269970059395,0.2821539988120397,0.28237999975681305,0.2826020047068596,0.28282299886147183,0.28304000447193783,0.28325700014829636,0.2834720015525818,0.28368400285641354,0.28389400243759155,0.28410299867391586,0.2843100006381671,0.28451499591271084,0.28471700102090836,0.2849170044064522,0.2851170003414154,0.28531400362650555,0.28550799936056137,0.2856999958554904,0.28589000056187314,0.28607900192340213,0.2862650007009506,0.28644899775584537,0.2866319964329402,0.28681300083796185,0.28699200103680295,0.2871679986516635,0.28734100113312405,0.28751299778620404,0.28768399854501087,0.2878519992033641,0.28801799813906354,0.28818199783563614,0.2883450041214625,0.2885059987505277,0.2886640007297198,0.2888200009862582,0.28897599627574283,0.28912800053755444,0.28927799810965854,0.2894259989261627,0.2895719955364863,0.2897170012195905,0.28985899935166043,0.28999900569518405,0.29013799875974655,0.29027500251928967,0.29040900121132535,0.29054100314776105,0.2906709983944893,0.2907989944020907,0.2909259994824727,0.2910499970118205,0.2911720002690951,0.2912919968366623,0.2914110024770101,0.2915270005663236,0.2916409994165103,0.29175399492184323,0.29186499615510303,0.2919740006327629,0.29207999755938846,0.2921839977304141,0.2922860061128934,0.2923869987328847,0.29248600204785663,0.2925810019175212,0.2926759993036588,0.29276900241772336,0.2928600013256073,0.2929479976495107,0.293033999701341,0.2931180000305176,0.2932010019818942,0.29328099886576336,0.2933589965105057,0.293435995777448,0.293511005739371,0.29358399907747906,0.29365399728218716,0.2937210003534953,0.29378800094127655,0.29385299732287723,0.2939150035381317,0.29397500306367874,0.2940330008665721,0.29409099866946536,0.29414500296115875,0.29419800142447156,0.2942479997873306,0.29429800311724347,0.29434500137964886,0.2943890045086543,0.2944309984644254,0.29447199900945026,0.29451100279887515,0.2945480023821195,0.2945820018649101,0.2946150029699008,0.2946470056970914,0.2946760008732478,0.2947029968102773,0.29472699513038,0.2947490041454633,0.2947709957758586,0.2947889988621076,0.2948060060540835,0.29482099413871765,0.29483500123023987,0.2948459982872009,0.294854000210762,0.29486199965079624,0.29486799985170364,0.2948710024356842,0.2948720008134842,0.2948709949851036,0.29486799985170364,0.2948639988899231,0.2948570027947426,0.2948480024933815,0.29483800133069354,0.2948259984453519,0.2948110004266103,0.2947949965794881,0.29477500170469284,0.2947539985179901,0.2947330002983411,0.2947080011169116,0.29468100269635517,0.2946530009309451,0.2946229974428813,0.2945909996827443,0.29455600182215375,0.2945199981331825,0.2944830035169919,0.2944429963827133,0.29440099994341534,0.29435600092013675,0.2943099985520045,0.2942630002895991,0.29421299944321316,0.29416000097990036,0.29410699754953384,0.29405199984709424,0.293993999560674,0.29393500089645386,0.2938770030935605,0.29381800442934036,0.29375900079806644,0.2937000021338463,0.29364199688037235,0.2935829982161522,0.29352399955193204,0.293464998404185,0.2934069981177648,0.29334799697001773,0.2932889983057976,0.29323100050290424,0.29317199687163037,0.29311300565799076,0.2930550028880437,0.29299600174029666,0.2929379964868228,0.29287899533907574,0.29282000412543613,0.29276200632254284,0.2927029952406883,0.29264500240484875,0.2925860012571017,0.29252799848715466,0.29246900230646133,0.2924109995365143,0.29235199838876724,0.2922940030694008,0.29223499447107315,0.2921770016352336,0.2921189988652865,0.2920599977175395,0.29200199743111926,0.291943001250426,0.29188500096400577,0.2918270031611125,0.29176799952983856,0.2917100017269452,0.29165199895699817,0.2915930027763049,0.29153499752283096,0.2914769972364108,0.2914179985721906,0.2913600007692973,0.2913020004828771,0.29124399771293,0.29118499904870987,0.2911269987622897,0.2910689984758695,0.2910109981894493,0.290952002008756,0.2908939967552821,0.2908360039194425,0.2907779961824417,0.29071999589602154,0.2906620005766551,0.2906030019124349,0.2905450016260147,0.29048700133959454,0.2904290010531743,0.29037100076675415,0.290313000480334,0.29025500019391376,0.2901969999074936,0.2901389996210734,0.2900809993346532,0.29002299904823303,0.2899650012453397,0.28990699847539264,0.2898489981889725,0.28979100038607913,0.28973300009965897,0.2896749973297119,0.2896169995268186,0.2895589967568715,0.28950100143750507,0.2894430036346118,0.28938599675893784,0.2893280014395714,0.2892700011531512,0.28921199838320416,0.28915399809678394,0.28909600029389065,0.28903800000747043,0.28898100058237713,0.2889229953289032,0.28886499752600986,0.2888069997231166,0.2887500002980232,0.28869200497865677,0.288633997241656,0.28857600192228955,0.2885190000136693,0.28846099972724915,0.288402999440829,0.2883460000157356,0.2882879972457886,0.2882300019264221,0.28817299753427505,0.2881149997313817,0.28805699944496155,0.28799999753634137,0.28794199973344803,0.28788500279188156,0.2878269975384076,0.28776899725198746,0.287712000310421,0.28765399754047394,0.2875969981153806,0.2875390003124873,0.28748199592034024,0.2874239981174469,0.28736699869235355,0.2873089984059334,0.2872520014643669,0.28719499458869296,0.2871369992693265,0.2870799998442332,0.28702199707428616,0.2869649976491928,0.28690699736277264,0.2868500004212062,0.2867930009961128,0.2867350031932195,0.2866779988010724,0.28662100434303284,0.28656299660603207,0.2865059996644656,0.28644900023937225,0.2863920032978058,0.286333995560805,0.28627699861923855,0.2862199967106183,0.28616199890772503,0.28610500196615857,0.2860479975740115,0.28599100311597186,0.2859339987238248,0.28587600340445835,0.2858189990123113,0.285761999587218,0.28570499767859775,0.2856480007370313,0.285591001311938,0.2855339969197909,0.28547699997822445,0.28541899969180423,0.28536200026671094,0.2853049983580907,0.28524800141652423,0.28519099950790405,0.2851339975992839,0.2850770006577174,0.28501999874909717,0.284962996840477,0.2849059998989105,0.28484900047381717,0.2847919960816701,0.28473499914010364,0.28467799971501034,0.2846209978063901,0.2845639983812968,0.28450799981753033,0.284451000392437,0.2843939984838168,0.28433700154225033,0.2842799996336301,0.2842230051755905,0.28416600078344345,0.28410999725262326,0.2840530003110568,0.28399600088596344,0.28393899897734326,0.283881997068723,0.28382600098848343,0.28376899907986325,0.283711997171243,0.2836549977461497,0.28359899918238324,0.2835419997572899,0.2834850028157234,0.28342799842357635,0.28337200234333676,0.2833150004347165,0.28325800100962323,0.283201997478803,0.2831450005372365,0.2830889994899432,0.28303200503190357,0.28297500560681027,0.2829189946254094,0.28286199768384296,0.2828059991200765,0.2827489996949832,0.2826930011312167,0.28263600418965024,0.28257899979750317,0.2825230037172635,0.28246600180864334,0.28240999827782315,0.2823529963692029,0.28229699780543643,0.28224100172519684,0.2821840023001035,0.2821279987692833,0.28207099934418994,0.28201500078042346,0.2819579988718033,0.2819019978245099,0.2818459967772166,0.28178899983565014,0.2817330037554105,0.2816770002245903,0.28162000328302383,0.28156399975220364,0.2815079987049103,0.2814510017633438,0.2813949982325236,0.28133900215228397,0.2812830035885175,0.2812260041634242,0.28117000063260394,0.28111400206883747,0.28105800102154416,0.2810009991129239,0.2809449980656306,0.28088899701833725,0.28083299845457077,0.2807769998908043,0.2807210013270378,0.28066399693489075,0.28060800085465115,0.2805519998073578,0.2804960037271182,0.2804399977127711,0.28038400163253147,0.28032799313465756,0.2802719995379448,0.28021599849065143,0.28015999992688495,0.28010399887959164,0.2800479978322983,0.2799919992685318,0.27993599822123844,0.2798799971739451,0.27982399861017865,0.2797679975628853,0.27973999828100204};
               //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12689304103453955,0.12773900106549263,0.1286800019443035,0.1296250025431315,0.13061999902129173,0.13166500007112822,0.1327619987229506,0.1338659996787707,0.13493100057045618,0.13595799977580705,0.13694700226187706,0.137899000197649,0.1388119993110498,0.13968700170516968,0.1405249983072281,0.14132499943176904,0.1420880009730657,0.14281999692320824,0.14352700114250183,0.14421100045243898,0.14486899971961975,0.14550199980537096,0.14611100032925606,0.14669499918818474,0.14725600058833757,0.14779199908177057,0.14830400173862776,0.14879600082834563,0.149272999415795,0.14973400036493936,0.15017900119225183,0.15060900151729584,0.15102400009830794,0.15142200142145157,0.15180599937836328,0.15217299883564314,0.15252499903241792,0.15286500255266824,0.15319599956274033,0.15351600075761476,0.15382500117023787,0.15412500003973642,0.15441599984963736,0.15469600136081377,0.15496600170930228,0.15522599965333939,0.1554770010213057,0.15571899836262068,0.15595500047008196,0.156184001515309,0.15640699863433838,0.15662300089995065,0.1568330004811287,0.15703700110316277,0.1572340006629626,0.15742500126361847,0.15761000166336694,0.1577899989982446,0.15796500196059546,0.1581370010972023,0.1583039971689383,0.1584670009712378,0.15862600008646646,0.15878099823991457,0.15893099953730902,0.15907799825072289,0.1592209984858831,0.1593570001423359,0.15948700035611788,0.1596089998881022,0.159725001702706,0.1598330003519853,0.15993299956123033,0.16002600019176802,0.1601130006213983,0.16019199912746748,0.16026399905482927,0.16033099964261055,0.16039899736642838,0.1604660004377365,0.1605340006450812,0.16060099999109903,0.16066799933711687,0.16073600202798843,0.16080300013224283,0.16086999947826067,0.1609380009273688,0.16100499778985977,0.16107100124160448,0.16113700220982233,0.16120199983318648,0.16126499821742377,0.16132899870475134,0.16139199833075205,0.16145400082071623,0.1615150012075901,0.16157600035270056,0.16163500025868416,0.1616929993033409,0.1617519992093245,0.1618099994957447,0.16186600178480148,0.1619220015903314,0.161976999292771,0.1620320019622644,0.162086001286904,0.16214000061154366,0.16219199945529303,0.16224400078256926,0.16229399914542833,0.16234400123357773,0.16239399835467339,0.1624429983397325,0.16249099870522818,0.16253799945116043,0.16258400306105614,0.1626300004621347,0.1626759978632132,0.1627199985086918,0.16276400039593378,0.1628070001800855,0.16284899786114693,0.16289100175102553,0.1629320022960504,0.16297200073798498,0.16301200042168298,0.16304999962449074,0.1630879988272985,0.16312499965230623,0.163162000477314,0.16319800168275833,0.16323300078511238,0.1632669990261396,0.16330100099245706,0.16333400085568428,0.16336599985758463,0.16339800010124841,0.1634290007253488,0.1634590004881223,0.16348899900913239,0.16351800163586935,0.16354599967598915,0.16357299933830896,0.16359899938106537,0.16362399980425835,0.16365000108877817,0.16367400189240774,0.16369800145427385,0.16372100015481314,0.16374300171931586,0.16376499955852827,0.16378600026170412,0.1638059988617897,0.16382500156760216,0.16384399806459746,0.16386100153128305,0.16387800003091493,0.1638949972887834,0.1639110011359056,0.16392600039641061,0.16394000127911568,0.163952998816967,0.1639659988383452,0.16397900010148683,0.1639900008837382,0.16400100166598955,0.16401100034515062,0.16402100026607513,0.16402999932567278,0.16403800000747046,0.16404499734441438,0.16405100002884865,0.1640569989879926,0.16406200205286345,0.1640659992893537,0.1640699990093708,0.16407300035158792,0.16407499834895134,0.16407599796851477,0.1640780009329319,0.16407799844940504,0.16407700007160506,0.16407600045204163,0.16407399997115135,0.16407099987069765,0.16406699766715369,0.16406300043066344,0.16405799984931946,0.16405300050973892,0.1640460006892681,0.16403899962703386,0.16403099770347276,0.1640230007469654,0.16401399920384088,0.1640039992829164,0.16399299974242845,0.16398300106326738,0.16397099941968918,0.16395799815654755,0.16394499937693277,0.1639310009777546,0.16391600047548613,0.16390000035365423,0.16388400147358576,0.16386699800690016,0.16384999826550484,0.16383099928498268,0.16381199657917023,0.16379200170437494,0.16377199937899908,0.1637509986758232,0.1637290008366108,0.16370700051387152,0.16368399932980537,0.16365999852617583,0.16363600020607313,0.16361000140508017,0.1635839988787969,0.16355699797471365,0.16352900117635727,0.16350199903051058,0.16347300012906393,0.16344299912452698,0.16341299936175346,0.16338199997941652,0.16334999849398932,0.16331799949208894,0.16328499962886175,0.16325199976563454,0.1632170006632805,0.1631810006995996,0.16314499825239182,0.16310900077223778,0.1630710003276666,0.16303299988309541,0.16299400106072426,0.1629549985130628,0.16291500007112822,0.1628750003874302,0.1628359965980053,0.16279599939783415,0.16275599971413612,0.16271600127220154,0.16267699872454008,0.16263699904084206,0.16259699811538061,0.16255799929300943,0.16251799960931143,0.1624789983034134,0.1624389998614788,0.16239900266130766,0.16235999887188277,0.16232000042994818,0.1622799995044867,0.1622409994403521,0.16220099851489067,0.16216199969251952,0.16212199876705805,0.1620829999446869,0.162042997777462,0.1620039977133274,0.16196399802962938,0.16192499796549478,0.16188500200708708,0.16184600070118904,0.16180600225925446,0.16176700095335642,0.16172700002789497,0.16168799872199693,0.16164799903829893,0.1616090014576912,0.16156999891002974,0.16153000170985857,0.1614909991621971,0.16145099823673567,0.16141200189789137,0.16137300059199333,0.1613329996665319,0.1612940008441607,0.1612550045053164,0.1612150010963281,0.16117600227395693,0.1611370009680589,0.16109700128436089,0.1610580012202263,0.16101899991432825,0.16097999860843024,0.16094000140825906,0.1609009988605976,0.16086200003822645,0.16082299873232841,0.16078300029039383,0.16074400146802267,0.16070500016212463,0.16066600133975348,0.160626998792092,0.1605870003501574,0.1605480002860228,0.16050899773836136,0.16047000015775362,0.16043100133538246,0.1603920025130113,0.16035299996534982,0.16031300028165182,0.16027399897575378,0.1602349989116192,0.16019600008924803,0.16015700002511343,0.16011800120274225,0.1600789986550808,0.16003999983270964,0.16000100101033846,0.15996200094620386,0.1599229983985424,0.15988399957617125,0.15984500075380007,0.15980600068966547,0.15976699938376746,0.15972800056139627,0.15968900049726167,0.15964999919136366,0.15961100036899248,0.15957199782133102,0.15953300024072328,0.15949400017658869,0.15945600097378096,0.15941699966788292,0.15937800084551176,0.15933899953961372,0.15929999947547913,0.15926099941134453,0.15922199934720993,0.15918400014440218,0.15914500008026758,0.15910599877436957,0.15906700119376183,0.15902800112962723,0.15899000068505606,0.15895099937915802,0.15891200179855028,0.15887299925088882,0.15883399918675423,0.15879599998394647,0.15875699867804846,0.15871799985567728,0.1586799994111061,0.15864099810520807,0.15860199804107347,0.15856399883826575,0.15852500249942145,0.1584860011935234,0.1584479995071888,0.1584089994430542,0.15837000186244646,0.15833200017611185,0.15829300011197725,0.15825400004784265,0.15821599836150804,0.1581769995391369,0.15813899909456572,0.15810000027219454,0.15806199982762337,0.15802299976348877,0.15798500056068102,0.15794600049654642,0.15790699794888496,0.15786899998784065,0.1578299974401792,0.1577920007208983,0.15775299817323685,0.15771500021219254,0.15767700100938478,0.15763799970348677,0.15760000050067902,0.15756100043654442,0.15752299999197325,0.15748400116960207,0.1574460007250309,0.15740800028045973,0.1573689989745617,0.15733099977175394,0.15729199970761934,0.15725400050481161,0.15721600006024042,0.15717699751257896,0.15713899955153465,0.1571010003487269,0.1570620002845923,0.1570239985982577,0.15698599691192308,0.15694799895087877,0.15690900012850761,0.15687099968393645,0.15683299923936525,0.1567940004169941,0.15675599997242293,0.15671800076961517,0.15667999908328056,0.15664200112223625,0.1566029998163382,0.1565650006135305,0.15652700141072273,0.15648899972438812,0.15645099927981695,0.1564130000770092,0.1563740000128746,0.15633600081006685,0.15629800036549568,0.1562599999209245,0.15622199947635332,0.15618399903178215,0.15614600107073784,0.15610800186793009,0.15607000018159548,0.15603100135922432,0.15599300091465315,0.15595499922831854,0.15591700126727423,0.15587899958093962,0.15584100037813187,0.15580300241708755,0.15576500073075294,0.1557270015279452,0.15568899984161058,0.1556509993970394,0.1556130014359951,0.15557500099142393,0.15553799892465273,0.15549999848008156,0.15546200051903725,0.15542399883270264,0.15538599962989488,0.15534800042708716,0.15530999998251596,0.1552719995379448,0.15523399660984674,0.15519599989056587,0.15515900030732155,0.15512099986275038,0.15508300065994263,0.15504500021537146,0.15500699977080026,0.15497000018755594,0.1549320009847482,0.1548939992984136,0.1548559988538424,0.15481799965103468,0.15478100130955377,0.15474299962321916,0.15470500042041144,0.15466700121760368,0.1546299991508325,0.15459199994802475,0.15455400198698044,0.15451699992020926,0.15447899823387465,0.15444099778930345,0.154404000689586,0.1543659990032514,0.15432799980044365,0.15429100145896277,0.15425300101439157,0.1542150005698204,0.15417800098657608,0.15414000178376833,0.15410299971699715,0.15406499927242598,0.15402700006961823,0.15399000296990076,0.15395200128356615,0.1539150004585584,0.15387700001398721,0.1538400004307429,0.15380199874440828,0.15376499916116396,0.15372700120011965,0.15368999789158502,0.15365200117230415,0.15361499786376953,0.15357700114448866,0.15353999907771745,0.15350199987490973,0.1534650002916654,0.15342800070842108,0.15339000274737677,0.15337099879980087};
               C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.28434206545352936,0.28995800018310547,0.2954609990119934,0.3020529995361964,0.3089950035015742,0.31628500173489255,0.32392499844233197,0.33160799741744995,0.33903099844853085,0.34619300067424774,0.3530930032332738,0.3597329979141553,0.36611200124025345,0.37223099917173386,0.3780889982978503,0.38368599861860275,0.38902400185664493,0.39414799958467484,0.3991049975156784,0.40389499564965564,0.4085179964701335,0.4129729966322581,0.4172609969973564,0.421383003393809,0.42533699919780094,0.42912500103314716,0.4327460005879402,0.43622900048891705,0.43960700184106827,0.44287900626659393,0.44604400048653287,0.4491009960571925,0.45205200215180713,0.4548959980408351,0.45763300110896427,0.46026399979988736,0.46278699735800427,0.4652229994535446,0.46759100009997684,0.469890000919501,0.4721199994285901,0.47428100059429806,0.4763750011722247,0.47839999943971634,0.4803570012251536,0.48224399983882904,0.4840630019704501,0.48582599808772403,0.4875450034936269,0.4892199983199437,0.4908520008126895,0.4924389993151029,0.4939830005168915,0.49548200021187466,0.49693800260623294,0.49834999938805896,0.499719001352787,0.501050998767217,0.5023549993832906,0.5036310106515884,0.5048779994249344,0.5060979922612509,0.5072889924049377,0.5084519982337952,0.5095869998137156,0.5106940120458603,0.5117719968159994,0.5128119985262553,0.5138020118077596,0.5147430002689362,0.5156340003013611,0.5164749970038732,0.5172660052776337,0.5180079986651739,0.5186999986569086,0.5193430036306381,0.5199360052744547,0.5205039978027344,0.5210720052321752,0.5216390043497086,0.5222069919109344,0.5227739959955215,0.5233409951130549,0.523907999197642,0.5244749983151754,0.5250410040219625,0.5256069997946421,0.5261710037787756,0.5267290075620016,0.5272820045550665,0.5278300046920776,0.5283740013837814,0.5289120028416315,0.5294449975093206,0.5299730002880096,0.5304969996213913,0.5310149987538656,0.5315279960632324,0.5320359965165457,0.5325379967689514,0.5330359935760498,0.5335279951492945,0.5340160032113394,0.5344980011383692,0.5349759956200918,0.5354479849338531,0.5359159956375757,0.5363789945840836,0.5368359933296839,0.5372879952192307,0.5377349952856699,0.5381769935290018,0.5386139949162801,0.5390460044145584,0.5394730021556219,0.5398950030406316,0.5403119971354803,0.5407240043083826,0.5411309997240702,0.5415329933166504,0.5419299999872843,0.5423209965229034,0.5427080045143763,0.5430890023708344,0.5434660017490387,0.5438370058933893,0.544204001625379,0.5445660005013148,0.544923002521197,0.545273999373118,0.5456199993689855,0.5459609975417455,0.5462969938913981,0.5466280033191045,0.546954000989596,0.5472759952147802,0.5475920041402181,0.5479039996862411,0.548210988442103,0.5485120018323263,0.5488080084323883,0.5490990032752355,0.5493850062290827,0.5496660073598226,0.5499430050452551,0.5502140074968338,0.5504800031582514,0.550741990407308,0.5509990106026331,0.5512500057617823,0.5514969925085703,0.5517380038897196,0.5519739985466003,0.5522049963474274,0.5524320006370544,0.5526529997587204,0.5528700004021326,0.5530809909105301,0.5532879928747813,0.5534900029500326,0.5536870012680689,0.553878997762998,0.554065003991127,0.5542469968398412,0.5544229994217554,0.554595003525416,0.5547619958718618,0.5549239963293076,0.5550809999306997,0.5552330017089844,0.5553800016641617,0.5555229981740316,0.5556609978278478,0.555791993935903,0.5559190014998118,0.5560410022735596,0.5561589946349462,0.5562709967295328,0.5563789953788122,0.5564809987942377,0.5565789937973022,0.5566719969113668,0.5567599982023239,0.5568429976701736,0.556920995314916,0.5569940060377121,0.5570609966913859,0.5571239938338598,0.5571829974651337,0.5572359959284464,0.557284007469813,0.5573279907306036,0.5573669920365015,0.5574009865522385,0.5574299941460291,0.5574530015389124,0.5574719955523809,0.5574859927097956,0.5574950029452642,0.5574990014235178,0.5574980030457178,0.5574919978777567,0.5574820091327032,0.5574669986963272,0.5574460079272588,0.5574200004339218,0.5573900093634924,0.5573539932568868,0.55731400847435,0.5572689970334371,0.5572200020154318,0.5571650018294653,0.5571060031652451,0.5570420026779175,0.5569730003674825,0.5568979978561401,0.5568189968665441,0.5567340056101481,0.5566449960072836,0.5565509994824728,0.5564530044794083,0.5563489943742752,0.5562409907579422,0.5561279952526093,0.5560099979241689,0.5558880021174749,0.5557600011428198,0.5556269983450571,0.5554889986912409,0.5553460021813711,0.5551989922920862,0.5550469954808553,0.5548900018135706,0.5547279963890711,0.5545620073874792,0.5543910066286722,0.5542149891455969,0.5540359914302826,0.5538570086161295,0.5536789894104004,0.5534999966621399,0.5533220022916794,0.5531429946422577,0.5529649953047434,0.5527859975894293,0.5526080081860224,0.5524300138155619,0.5522519995768865,0.5520740002393723,0.551896000901858,0.55171799659729,0.5515400022268295,0.5513619979222616,0.5511840035518011,0.551005999247233,0.5508279999097189,0.5506509989500046,0.5504729996124903,0.5502960036198298,0.5501179993152618,0.5499410082896551,0.5497629890839258,0.5495859980583191,0.5494090020656586,0.549232006072998,0.5490539968013763,0.5488770008087158,0.5486999948819479,0.5485229939222336,0.5483459979295731,0.5481700003147125,0.5479929943879446,0.5478160033623377,0.5476390024026235,0.547463004787763,0.5472859988609949,0.5471100062131882,0.5469329953193665,0.5467570076386133,0.5465799967447916,0.5464039991299311,0.5462280064821243,0.5460519939661026,0.5458760062853495,0.5456999987363815,0.5455240060885748,0.5453479985396067,0.5451720009247462,0.5449959933757782,0.5448200106620789,0.5446440031131109,0.5444689939419428,0.5442929913600286,0.5441179970900217,0.5439419994751612,0.5437670052051544,0.5435910026232401,0.5434159984191259,0.5432409942150116,0.5430650015672048,0.5428900023301443,0.54271499812603,0.5425399790207545,0.5423649946848551,0.5421900004148483,0.5420150061448415,0.5418410003185272,0.5416660110155741,0.5414910068114599,0.5413159976402918,0.541142001748085,0.5409670025110245,0.5407930066188177,0.5406180024147034,0.540443996588389,0.540270005663236,0.5400950014591217,0.5399210005998611,0.5397469997406006,0.53957299888134,0.5393990029891332,0.5392250170310339,0.5390510062376658,0.5388769954442978,0.5387040078639984,0.5385300119717916,0.5383560111125311,0.5381820052862167,0.5380090028047562,0.5378350168466568,0.5376619944969813,0.5374879986047745,0.5373150060574213,0.5371419886747996,0.5369689961274465,0.5367950052022934,0.5366219977537791,0.5364490151405334,0.5362760027249655,0.5361030002435049,0.535930002729098,0.5357570002476374,0.5355850011110306,0.5354120035966238,0.5352390011151632,0.5350669970115026,0.5348939994970957,0.5347209920485815,0.5345489978790283,0.5343769937753677,0.5342039962609609,0.5340320070584615,0.533860002954801,0.533688003818194,0.5335150013367335,0.5333429972330729,0.5331710030635198,0.5329989989598592,0.5328269898891449,0.5326560089985529,0.5324839999278387,0.5323120007912318,0.5321400016546249,0.5319689959287643,0.5317970017592112,0.5316260010004044,0.5314540018637975,0.5312830060720444,0.5311110019683838,0.530940001209577,0.5307690054178238,0.530598004659017,0.5304269939661026,0.5302549948294958,0.5300839990377426,0.5299130082130432,0.5297430008649826,0.5295720050732294,0.5294009943803152,0.529229998588562,0.5290590077638626,0.5288889954487482,0.5287180046240488,0.528548002243042,0.5283770014842352,0.5282069991032282,0.5280359983444214,0.5278660009304682,0.5276960035165151,0.5275260011355082,0.5273560037215551,0.5271849930286407,0.5270150005817413,0.5268450031677882,0.5266760041316351,0.5265060017506281,0.5263359993696213,0.5261659969886144,0.525996004541715,0.5258270005385081,0.5256569981575012,0.525487999121348,0.525318001707395,0.525148997704188,0.5249790102243423,0.5248099913199743,0.5246410022179285,0.5244720031817754,0.5243019908666611,0.5241330067316691,0.523964007695516,0.5237950086593628,0.5236259996891022,0.5234570056200027,0.5232889950275421,0.5231200009584427,0.5229510019222895,0.5227820078531901,0.5226139972607294,0.5224449982245764,0.5222769975662231,0.5221079935630163,0.5219400028387705,0.5217720021804174,0.5216030031442642,0.521435002485911,0.5212669968605042,0.5210989962021509,0.5209310005108515,0.5207629948854446,0.520595004161199,0.5204270035028458,0.5202589929103851,0.5200909972190857,0.5199230015277863,0.5197560042142868,0.5195880035559336,0.519419992963473,0.519253005584081,0.5190850049257278,0.5189180076122284,0.5187510003646215,0.5185830046733221,0.5184160073598226,0.5182490050792694,0.5180819978316625,0.5179150005181631,0.5177479982376099,0.517580990990003,0.517414003610611,0.5172470013300577,0.5170799990495046,0.5169130017360052,0.516746997833252,0.5165799955526987,0.516413003206253,0.5162469943364462,0.5160800069570541,0.5159140080213547,0.515746995806694,0.5155810018380483,0.5154149929682413,0.5152479956547419,0.5150820016860962,0.5149160027503967,0.5147499988476435,0.514583999911944,0.5144180059432983,0.5142519970734915,0.5140859931707382,0.5139199992020925,0.5137550036112467,0.5135889947414398,0.5134230007727941,0.5132580002148946,0.5130920012791952,0.5129270007212957,0.512760986884435,0.5125960012276968,0.5124310006697973,0.5122649967670441,0.5121000011761984,0.5119350006182989,0.5117700050274531,0.5116049895683924,0.5115219950675964};
               //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12939697379867235,0.13274599984288216,0.136223999162515,0.1400709996620814,0.1441200003027916,0.1483719994624456,0.1528280017276605,0.15730899944901466,0.161636999497811,0.1658139998714129,0.16983900095025697,0.17371200025081635,0.17743399987618128,0.1810039977232615,0.18442299962043762,0.18769000098109245,0.19080499932169914,0.19379600137472153,0.19668999935189882,0.1994869994620482,0.20218599836031595,0.20478699977199236,0.2072920004526774,0.20969999954104424,0.21201000114281973,0.21422399953007698,0.21633999794721603,0.2183770015835762,0.22035100186864534,0.22226399928331375,0.22411400079727173,0.22590199982126555,0.22762899721662203,0.2292920003334681,0.23089299723505974,0.23243300120035806,0.23390999933083853,0.23533600072065988,0.2367229995628198,0.23806999872128168,0.23937700067957243,0.24064299960931143,0.24187000220020613,0.2430579997599125,0.24420500049988428,0.24531200031439462,0.24637899920344353,0.2474140003323555,0.2484229989349842,0.24940700083971024,0.2503649952510993,0.2512980004151662,0.2522040009498596,0.25308600068092346,0.25394099950790405,0.25477099418640137,0.2555759971340497,0.25635900100072223,0.2571259985367457,0.2578770046432813,0.2586110010743141,0.2593289986252785,0.26003100474675495,0.26071599622567493,0.2613850037256877,0.2620380024115245,0.2626739963889122,0.2632879987359047,0.2638730009396871,0.2644280021389325,0.2649550015727679,0.2654529983798663,0.2659220000108083,0.2663629949092865,0.2667740037043889,0.2671569958329201,0.2675099993745486,0.26784899830818176,0.2681880022088687,0.26852599779764813,0.2688640008370082,0.26920200139284134,0.2695410003264745,0.2698789983987808,0.2702160030603409,0.2705540011326472,0.2708919992049535,0.27122800052165985,0.27156099677085876,0.2718899995088577,0.272217000524203,0.2725420023004214,0.27286400149265927,0.27318200717369717,0.27349799623092014,0.2738100017110507,0.2741189996401469,0.2744249974687894,0.27472899854183197,0.2750299995144208,0.27532799790302914,0.2756229986747106,0.2759140009681384,0.2762029965718587,0.2764879986643791,0.2767720048626264,0.27705200264851254,0.2773300011952718,0.27760399381319684,0.2778740053375562,0.2781420002381007,0.2784070000052452,0.27867000301678974,0.2789299984773,0.27918699383735657,0.2794399956862132,0.2796910007794698,0.2799379974603653,0.28018199900786084,0.28042399883270264,0.28066300104061764,0.28089900066455203,0.28113200267155963,0.28136199712753296,0.28158899893363315,0.28181199729442596,0.2820329988996188,0.2822520012656848,0.2824679985642433,0.28267999986807507,0.28289000193277997,0.2830960030357043,0.2832989990711212,0.2834999958674113,0.2836980000138283,0.28389299660921097,0.2840849955876668,0.2842740019162496,0.28446000069379807,0.2846430043379466,0.2848230029145877,0.285000999768575,0.28517599652210873,0.2853480006257693,0.28551699966192245,0.28568200021982193,0.28584500153859455,0.28600500027338666,0.28616200139125186,0.28631699830293655,0.2864680017034213,0.2866169984141986,0.2867620016137759,0.2869039997458458,0.2870440011223157,0.2871809999148051,0.2873150060574214,0.2874470030268033,0.28757500151793164,0.28769999990860623,0.2878209948539734,0.28794100135564804,0.2880580003062884,0.28817199915647507,0.28828299542268115,0.28839100152254105,0.2884960000713666,0.2885970001419385,0.28869599600632984,0.2887919992208481,0.28888600319623947,0.2889770021041234,0.28906499594449997,0.2891489962736766,0.2892309973637263,0.2893090049425761,0.28938500334819156,0.2894590000311534,0.2895299990971883,0.28959700216849643,0.28966199855009717,0.289722998936971,0.28978099673986435,0.28983700027068454,0.2898909995953242,0.28994199881951016,0.28998900204896927,0.2900340010722478,0.2900750016172727,0.29011300206184387,0.2901490032672882,0.29018300026655197,0.2902130037546158,0.290241003036499,0.29026499887307483,0.29028599957625073,0.2903049985567729,0.2903209949533145,0.2903340011835098,0.29034500072399777,0.2903519968191783,0.29035700112581253,0.29035799702008563,0.29035599778095883,0.2903519993027051,0.29034599910179776,0.2903369988004367,0.29032400250434875,0.29030899703502655,0.2902899955709775,0.29026899486780167,0.29024400065342587,0.29021699478228885,0.2901880020896594,0.29015500098466873,0.29012000064055127,0.29008200019598007,0.29003999878962833,0.28999600062767666,0.2899489998817444,0.2898999974131584,0.28984800229469937,0.289792001247406,0.28973399847745895,0.28967300057411194,0.2896089976032575,0.2895419970154762,0.289472999672095,0.28940099974473316,0.2893260022004445,0.2892479995886485,0.28916700432697934,0.28908300151427585,0.28899699946244556,0.2889079997936885,0.2888160025080045,0.2887210001548131,0.28862500190734863,0.2885289986928304,0.2884330004453659,0.28833699971437454,0.28824100146691006,0.2881449982523918,0.28804900000492734,0.287952999273936,0.28785700102647144,0.28776099781195325,0.2876649995644887,0.28756900131702423,0.28747300058603287,0.2873769948879878,0.28728099664052326,0.28718599925438565,0.287090003490448,0.28699400275945663,0.2868989979227384,0.2868029996752739,0.2867070014278094,0.28661199659109116,0.2865159983436267,0.28642099847396213,0.28632500271002453,0.28623000284036,0.2861350004871686,0.28603899975617725,0.28594400237003964,0.2858490025003751,0.2857529992858569,0.2856580043832461,0.28556300203005475,0.2854680021603902,0.285372997323672,0.28527800490458805,0.2851819967230161,0.2850870018204053,0.28499199946721393,0.28489699959754944,0.28480200469493866,0.28470800320307416,0.2846130008498828,0.28451800098021823,0.28442299862702686,0.28432800124088925,0.2842330013712247,0.2841390023628871,0.2840440000096957,0.28394900262355804,0.28385499864816666,0.28375999877850216,0.2836659997701645,0.2835709999005,0.28347599506378174,0.28338199853897095,0.28328799953063327,0.2831929996609688,0.2830989981691043,0.28300399829943973,0.2829099968075752,0.28281600524981815,0.28272199879089993,0.28262700388828915,0.2825330023964246,0.2824389959375064,0.2823449994126956,0.2822510004043579,0.28215700139602023,0.28206299990415573,0.28196900089581806,0.28187499940395355,0.28178099791208905,0.28168700138727826,0.2815929998954137,0.2814989984035492,0.2814050018787384,0.2813110003868739,0.2812180022398631,0.2811240032315254,0.28102999925613403,0.28093699862559635,0.2808429996172587,0.28074900060892105,0.28065599749485654,0.28056199848651886,0.28046900033950806,0.2803750013311704,0.28028200070063275,0.2801879942417145,0.28009500354528427,0.28000199794769287,0.2799080063899358,0.2798149958252907,0.2797220026453336,0.2796290044983228,0.2795350005229314,0.2794419974088669,0.27934900174538296,0.2792560011148453,0.2791630029678345,0.27906999240318936,0.278977004190286,0.27888399362564087,0.2787910004456838,0.27869800478219986,0.27860499173402786,0.27851200352112454,0.27841999630133313,0.2783270056049029,0.27823399504025775,0.2781410018603007,0.2780490020910899,0.2779560014605522,0.2778629958629608,0.2777710010608037,0.2776779979467392,0.2775859956940015,0.27749300251404446,0.27740100026130676,0.27730800211429596,0.27721600234508514,0.27712300419807434,0.27703100194533664,0.2769390046596527,0.2768459965785344,0.2767540017763774,0.2766619970401128,0.27656999975442886,0.2764769991238912,0.27638500183820724,0.2762929971019427,0.2762009973327319,0.2761090025305748,0.2760169953107834,0.27592499802509945,0.27583299825588864,0.27574100097020465,0.27564900120099384,0.275557001431783,0.2754649942119916,0.27537400275468826,0.27528199801842373,0.2751899982492129,0.27509800096352893,0.2750069970885913,0.27491499731938046,0.27482399841149646,0.27473200112581253,0.27464000632365543,0.2745489999651909,0.2744569977124532,0.27436600128809613,0.27427399655183154,0.2741830026110013,0.27409199873606366,0.27399999896685284,0.273908997575442,0.2738180011510849,0.27372600386540097,0.27363499502340954,0.2735440010825793,0.2734529996911685,0.27336199829975766,0.2732710043589274,0.2731800004839897,0.2730880031983058,0.27299700180689496,0.27290600041548413,0.27281500150760013,0.27272500346104306,0.27263400206963223,0.2725429981946945,0.2724519992868106,0.2723610003789266,0.27226999898751575,0.2721799959739049,0.27208899706602097,0.27199800064166385,0.2719080025951068,0.2718170036872228,0.2717259998122851,0.2716359967986743,0.2715449978907903,0.2714550048112869,0.2713640009363492,0.27127400288979214,0.2711839998761813,0.2710930009682973,0.27100300043821335,0.2709120015303294,0.27082199851671857,0.27073199798663455,0.2706419999400775,0.2705510010321935,0.27046099801858264,0.2703709974884987,0.27028099944194156,0.2701909989118576,0.2701010008653005,0.2700110028187434,0.26992099980513257,0.26983099927504856,0.2697410012284915,0.2696510006984075,0.2695610026518504,0.2694709971547127,0.2693819999694824,0.2692919969558716,0.2692019964257876,0.2691120008627574,0.26902299871047336,0.2689330031474431,0.26884300510088605,0.2687539979815483,0.26866399745146435,0.2685750027497609,0.2684849997361501,0.268396000067393,0.268305999537309,0.2682169998685519,0.2681269993384679,0.26803800215323764,0.26794900248448056,0.2678589994708697,0.2677699998021126,0.2676809976498286,0.26759199798107147,0.2675030032793681,0.2674130027492841,0.267324003080527,0.267235000928243,0.2671460012594859,0.2670569991072019,0.2669680019219716,0.26687899728616077,0.2667899976174037,0.26670100291570026,0.2666119957963626,0.26652399947245914,0.26643499980370206,0.2663460026184718,0.2662570004661878,0.2661679983139038,0.26607999702294666,0.2659910023212433,0.26590199768543243,0.26581400136152905,0.26576899985472363};
               //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.0922222329924504,0.09350149954358737,0.09477110020816326,0.09623499897619088,0.09777659984926383,0.0993956991781791,0.10109299918015797,0.1028010006994009,0.10445000045001507,0.10603999967376392,0.10757300009330113,0.10904599974552791,0.11046200059354305,0.1118200005342563,0.11311899994810422,0.11436000031729539,0.11554299977918465,0.11667800011734168,0.11777500001092751,0.11883599931995074,0.11985900066792965,0.12084499994913737,0.12179200102885564,0.12270299966136615,0.12357699995239575,0.12441400003929932,0.12521200068295002,0.1259810005625089,0.12672500063975653,0.12744600077470145,0.12814299886425337,0.12881599987546602,0.12946500008304915,0.13009000072876611,0.13069099808732668,0.13126899922887483,0.13182300080855688,0.13235700130462646,0.13287600005666414,0.1333799995481968,0.1338680014014244,0.1343400018910567,0.1347970006366571,0.13523900136351585,0.1356660003463427,0.1360779975851377,0.1364750030140082,0.13685799886782965,0.1372320018708706,0.13759600122769675,0.1379500019053618,0.13829399893681207,0.13862900187571844,0.13895399992664656,0.13926899805665016,0.1395739975074927,0.1398689995209376,0.14015700047214827,0.14043800036112467,0.1407130000491937,0.14098100115855536,0.1412429983417193,0.1414990002910296,0.14174800117810568,0.14199099938074747,0.14222799862424532,0.1424579992890358,0.14267899841070175,0.14288999885320663,0.1430899960299333,0.14327799901366234,0.1434559983511766,0.14362299938996634,0.14377900088826814,0.1439229982594649,0.14405600105722746,0.1441769984861215,0.1442939986785253,0.14440999800960222,0.14452600106596947,0.14464199915528297,0.14475799848635992,0.14487500116229057,0.14499100049336752,0.14510700106620789,0.14522299791375795,0.1453390009701252,0.14545400068163872,0.1455679995318254,0.14568100248773894,0.1457929996152719,0.14590399836500487,0.1460140012204647,0.14612200111150742,0.14623000100255013,0.1463359979291757,0.14644199858109155,0.1465459999938806,0.1466479984422525,0.14675000061591467,0.1468509982029597,0.14695100113749504,0.1470499982436498,0.14714699859420458,0.14724199970563254,0.14733700081706047,0.147431002308925,0.14752399921417236,0.14761600146691004,0.14770599827170372,0.14779500042398772,0.14788399885098139,0.14797099928061166,0.14805700009067854,0.14814100041985512,0.14822500199079514,0.148307998975118,0.14838899920384088,0.14847000067432722,0.14854900166392326,0.1486269993086656,0.14870399981737137,0.14878000194827715,0.14885499949256578,0.14892799903949103,0.1490010010699431,0.14907299975554147,0.14914299796024957,0.1492130011320114,0.1492799979945024,0.14934700230757395,0.14941400041182837,0.14947900051871935,0.14954200014472008,0.1496049997707208,0.14966499929626784,0.14972600092490515,0.1497849983473619,0.14984300111730894,0.14990000054240227,0.1499550019701322,0.1500099984308084,0.1500640002389749,0.15011599784096083,0.15016700079043707,0.15021699791153273,0.15026599913835526,0.15031500036517778,0.15036199986934662,0.15040700137615204,0.15045099829634032,0.15049500142534575,0.1505379987259706,0.15057900299628577,0.15061999981602034,0.15065800274411836,0.15069600070516267,0.15073399742444357,0.15077000111341476,0.15080400059620538,0.1508379988372326,0.15087000156442323,0.15090099970499674,0.15093099822600684,0.15096099923054376,0.15098800013462702,0.15101499979694685,0.1510400027036667,0.15106600150465965,0.1510889989634355,0.15111200138926506,0.15113199998935065,0.1511530006925265,0.15117199967304865,0.1511909986535708,0.1512069987754027,0.15122300138076147,0.1512380006412665,0.1512519990404447,0.1512649990618229,0.15127599984407425,0.15128600224852562,0.15129500006635985,0.15130400036772093,0.1513109989464283,0.15131700163086256,0.1513220022122065,0.1513260006904602,0.1513290007909139,0.1513309987882773,0.1513309987882773,0.15133000165224075,0.15132799868782362,0.15132499982913336,0.15132199972867966,0.15131699790557226,0.1513109989464283,0.15130299950639406,0.15129500006635985,0.15128599976499876,0.1512749989827474,0.15126399820049605,0.15125000228484473,0.1512370010217031,0.1512220005194346,0.1512069987754027,0.1511890006562074,0.1511710025370121,0.15115199983119965,0.15113200123111406,0.15111100052793822,0.15108799934387207,0.15106399978200594,0.15104000146190324,0.15101499731341997,0.15098800013462702,0.15095999961098036,0.1509310007095337,0.15090100094676018,0.15086999783913294,0.15083800007899603,0.15080499897400537,0.1507710007329782,0.15073499952753386,0.1506980024278164,0.15066099911928177,0.15062199905514717,0.15058199937144914,0.1505410000681877,0.1504990023871263,0.1504560001194477,0.15041200195749602,0.15036600083112717,0.15031999970475832,0.15027200306455293,0.15022400145729384,0.15017500023047128,0.15012499938408533,0.15007499853769937,0.1500250001748403,0.14997500057021776,0.1499249997238318,0.1498750001192093,0.14982499927282333,0.14977499966820082,0.14972500006357828,0.14967499921719232,0.1496249996125698,0.14957499876618385,0.14952600002288818,0.14947599917650223,0.14942600081364313,0.14937599996725717,0.14932600036263466,0.14927699913581213,0.1492269995311896,0.14917700241009393,0.14912699783841768,0.14907800033688545,0.14902799824873605,0.14897799864411354,0.1489290011425813,0.14887899781266847,0.1488289994498094,0.1487799994647503,0.1487300011018912,0.14868099987506866,0.14863100027044615,0.14858200028538704,0.14853199819723764,0.14848299945394197,0.1484330010910829,0.1483840011060238,0.1483339990178744,0.14828500151634216,0.14823499942819277,0.1481860006848971,0.148137000699838,0.14808700109521547,0.1480380011101564,0.147987999022007,0.14793900152047476,0.1478900002936522,0.14784100030859312,0.14779099946220717,0.1477420007189115,0.14769299949208894,0.14764400074879327,0.14759399990240732,0.14754499991734824,0.14749599869052568,0.14744700118899345,0.14739800244569778,0.14734900121887526,0.1472990003724893,0.14724999914566675,0.14720100288589796,0.147152000417312,0.14710299794872603,0.14705399920543036,0.1470050004621347,0.14695600047707558,0.1469070017337799,0.14685800050695738,0.1468089980383714,0.14676000053683916,0.14671100055178007,0.1466630001862844,0.14661399895946184,0.14656499897440275,0.1465159977475802,0.14646699900428453,0.14641800026098886,0.14636899903416634,0.14632099866867065,0.14627199992537498,0.14622300118207932,0.14617399871349335,0.14612600083152452,0.14607700208822885,0.14602799837787947,0.1459799992541472,0.14593099926908812,0.145881999284029,0.14583399891853333,0.14578500017523766,0.14573700105150542,0.14568799982468286,0.14563899983962378,0.14559100195765495,0.14554200073083243,0.14549400036533675,0.14544500162204108,0.14539700001478195,0.14534800002972284,0.14529999966422716,0.14525200054049492,0.1452030005554358,0.1451549989481767,0.14510599772135416,0.14505800108114877,0.14500999947388968,0.144961000730594,0.14491299788157144,0.14486499999960264,0.14481700087587038,0.14476799964904785,0.1447200005253156,0.1446719989180565,0.14462399979432425,0.14457499980926514,0.1445270006855329,0.14447900032003722,0.14443099995454153,0.1443829983472824,0.14433500170707703,0.1442859967549642,0.14423800135652223,0.14418999726573625,0.14414199938376746,0.1440940002600352,0.1440459998945395,0.14399799952904382,0.14395000040531158,0.14390199879805246,0.14385399967432022,0.1438060017923514,0.1437580014268557,0.14370999981959662,0.14366299783190092,0.14361500119169554,0.14356699958443642,0.1435189979771773,0.1434709976116816,0.1434230034550031,0.14337600146730742,0.14332800110181174,0.14328000073631605,0.14323200037082037,0.14318500210841498,0.14313700050115585,0.14308899889389673,0.1430409997701645,0.14299399902423224,0.1429460011422634,0.14289800201853117,0.14285100003083548,0.1428029996653398,0.14275599891940752,0.14270799855391184,0.14266000191370645,0.1426130011677742,0.14256499956051508,0.14251800129810968,0.14246999844908714,0.1424230026702086,0.14237499982118607,0.1423279990752538,0.14228100205461183,0.1422329992055893,0.1421860009431839,0.14213800057768822,0.14209099858999252,0.14204399660229683,0.141995998720328,0.1419490004579226,0.14190199847022691,0.14185400058825812,0.14180699984232584,0.14176000033815703,0.14171299959222475,0.14166499922672907,0.14161799848079681,0.14157100270191827,0.14152400195598602,0.14147700245181719,0.14142899960279465,0.1413819988568624,0.141335000594457,0.14128799984852472,0.14124099910259247,0.14119400084018707,0.14114700009425482,0.14110000059008598,0.14105299984415373,0.1410060003399849,0.14095899959405264,0.1409120000898838,0.14086500058571497,0.14081799983978271,0.14077100033561388,0.14072399834791818,0.14067699884374937,0.14062999933958054,0.14058299859364828,0.14053699870904288,0.14049000293016434,0.14044300218423209,0.1403959977130095,0.140349001934131,0.14030300080776215,0.1402560000618299,0.1402090017994245,0.14016199856996536,0.1401159974435965,0.14006900290648142,0.1400219996770223,0.13997600103418031,0.1399290015300115,0.1398819995423158,0.13983600089947382,0.13978900015354156,0.1397419994076093,0.13969600076476732,0.1396490012605985,0.13960299889246622,0.13955600187182426,0.13951000074545541,0.1394630012412866,0.1394169976313909,0.13937000061074892,0.1393240007261435,0.13927699998021126,0.13923100009560585,0.13918500021100044,0.1391379994650682,0.13909199958046278,0.1390450013180574,0.13899900143345198,0.13895300154884657,0.1389060008029143,0.13885999967654547,0.13881400103370348,0.13876799742380777,0.13872099916140238,0.1386750005185604,0.13862899939219156,0.13858299950758615,0.13853699962298074,0.1384899988770485,0.13844400023420653,0.13839799786607423,0.1383520004649957,0.13830600182215372,0.1382600019375483,0.13823699951171875};
               CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.8340072631836,82.68911743164062,83.15111351013184,83.92251396179199,84.71921412150066,85.54141553243001,86.38881429036458,87.24091466267903,88.07681401570638,88.89651425679524,89.70011329650879,90.48751386006673,91.2587121327718,92.01381301879883,92.75271161397298,93.4755121866862,94.18211110432942,94.87551053365071,95.55851173400879,96.2313117980957,96.8938102722168,97.54591051737468,98.1878096262614,98.81930923461914,99.44051106770833,100.05101013183594,100.65201059977214,101.24400838216145,101.83000946044922,102.4090092976888,102.98101043701172,103.54700978597005,104.10600980122884,104.6580098470052,105.20400873819987,105.74300956726074,106.27600924173991,106.80300839742024,107.32600847880046,107.84500885009766,108.35900815327962,108.86900838216145,109.37500826517741,109.87600771586101,110.37400881449382,110.86700757344563,111.35500907897949,111.84000778198242,112.32300758361816,112.80300649007161,113.28000831604004,113.75400797526042,114.2260087331136,114.69500732421875,115.16100756327312,115.62500762939453,116.08500862121582,116.544007619222,117.00100898742676,117.45600827534993,117.90900802612305,118.3610070546468,118.81100845336914,119.25900840759277,119.70500755310059,120.1500072479248,120.59300740559895,121.03300793965657,121.47100766499837,121.90500831604004,122.33600743611653,122.76500829060872,123.19000752766927,123.6120065053304,124.03100713094075,124.44600613911946,124.85900688171387,125.27000554402669,125.68100802103679,126.09300740559895,126.50400733947754,126.91500663757324,127.3260072072347,127.73700714111328,128.14800771077475,128.5590082804362,128.97000630696616,129.380007425944,129.78700637817383,130.19100697835287,130.59300486246744,130.99100875854492,131.38700485229492,131.78000768025717,132.1710065205892,132.55800501505533,132.94300587972006,133.32500457763672,133.70500818888345,134.08100382486978,134.45500691731772,134.82600784301758,135.19400533040366,135.56000645955405,135.9220059712728,136.28200403849283,136.63900502522787,136.9940071105957,137.3450050354004,137.6940066019694,138.04000600179037,138.3840077718099,138.72400538126627,139.06200790405273,139.3970069885254,139.72900517781576,140.0590031941732,140.3860066731771,140.71000289916992,141.03100204467773,141.3490079243978,141.66500600179037,141.9780069986979,142.28800582885742,142.59600575764975,142.90000661214194,143.2020060221354,143.50100580851236,143.79800669352213,144.09100468953451,144.38200505574545,144.67000325520834,144.9550043741862,145.2380027770996,145.51800537109375,145.79500579833984,146.06900533040366,146.34000523885092,146.60900497436523,146.87500508626303,147.13800557454428,147.3990020751953,147.6560033162435,147.91100438435873,148.16300455729166,148.41300455729166,148.65900675455728,148.9030024210612,149.14400227864584,149.38300450642905,149.6180051167806,149.85100428263345,150.08100382486978,150.30800247192383,150.5330022176107,150.755002339681,150.974001566569,151.19000371297201,151.40300114949545,151.6140047709147,151.82200368245444,152.02700551350912,152.23000462849936,152.4290033976237,152.62600580851236,152.81999969482422,153.01200230916342,153.20000457763672,153.38600413004556,153.5690015157064,153.7500025431315,153.92700068155924,154.10200373331705,154.27400334676108,154.44300333658853,154.61000315348306,154.77400334676108,154.93400192260742,155.09300104777017,155.24800618489584,155.4010009765625,155.5510050455729,155.69800313313803,155.84200286865234,155.98400370279947,156.1230036417643,156.25900268554688,156.39300537109375,156.52300135294595,156.65100224812826,156.77600224812826,156.89900334676108,157.01800282796225,157.13500213623047,157.2490030924479,157.36000061035156,157.46900177001953,157.57500076293945,157.6779988606771,157.7780024210612,157.87500381469727,157.96999867757162,158.06200154622397,158.1510009765625,158.23799896240234,158.3220011393229,158.4030024210612,158.4810002644857,158.55600102742514,158.62900034586588,158.69900131225586,158.76599884033203,158.8300018310547,158.89200083414713,158.95100021362305,159.00699996948242,159.06000137329102,159.11100133260092,159.15899785359701,159.2040023803711,159.24600092569986,159.28600056966147,159.32200241088867,159.3560028076172,159.38799921671549,159.41600290934244,159.44200007120767,159.4650001525879,159.4849993387858,159.50300089518228,159.51800028483072,159.53000132242838,159.53899892171225,159.5450007120768,159.54900105794272,159.54999923706055,159.54799779256186,159.5449981689453,159.5420010884603,159.5380007425944,159.5349998474121,159.53200022379556,159.52900187174478,159.52599970499674,159.52300008138022,159.5189997355143,159.51600138346353,159.51300048828125,159.51000213623047,159.50699869791666,159.50300089518228,159.50000127156576,159.49700037638345,159.4939982096354,159.4909985860189,159.48700078328451,159.48400115966797,159.48099899291992,159.47799809773764,159.47499720255533,159.47100194295248,159.46800104777017,159.46499888102213,159.4619992574056,159.4589983622233,159.45600128173828,159.4520009358724,159.4490000406901,159.44600041707358,159.44300079345703,159.44000116984049,159.4360008239746,159.43300247192383,159.42999903361002,159.4269994099935,159.42400105794272,159.4200007120768,159.41699981689453,159.41399892171225,159.41099802652994,159.40799967447916,159.4049975077311,159.400998433431,159.39799880981445,159.39499791463217,159.3919995625814,159.3890012105306,159.38499959309897,159.3820012410482,159.37900034586588,159.3759994506836,159.3730010986328,159.3689982096354,159.3660011291504,159.36299896240234,159.36000061035156,159.35699971516928,159.35400263468424,159.3500010172526,159.3470001220703,159.34400177001953,159.34099833170572,159.33799997965494,159.33399963378906,159.33100001017252,159.328000386556,159.3249994913737,159.3220011393229,159.31799952189127,159.31499735514322,159.31199900309244,159.30900065104166,159.30600102742514,159.3029988606771,159.29899978637695,159.29599889119467,159.2930005391439,159.29000091552734,159.28700002034506,159.28299713134766,159.28000005086264,159.27700169881186,159.2739995320638,159.27099990844727,159.26799901326498,159.26399866739908,159.26100158691406,159.25800069173178,159.25499725341797,159.25200017293295,159.2480010986328,159.24500020345053,159.24199930826822,159.2389996846517,159.23600260416666,159.23199971516928,159.22899881998697,159.2260004679362,159.22299575805664,159.21999867757162,159.21700159708658,159.21299997965494,159.21000162760416,159.2069994608561,159.20400110880533,159.20099894205728,159.19700241088867,159.19400024414062,159.19099934895834,159.18800099690756,159.18500137329102,159.18200174967447,159.1779988606771,159.17499923706055,159.171999613444,159.16900126139322,159.16600036621094,159.1620012919108,159.15900039672852,159.15600077311197,159.15300114949545,159.15000025431314,159.14699935913086,159.14299901326498,159.13999938964844,159.1369997660319,159.1340014139811,159.13099924723306,159.12700017293295,159.12400182088217,159.12099838256836,159.11800003051758,159.1150016784668,159.11100006103516,159.1080004374186,159.10500208536783,159.10200119018555,159.09900029500326,159.09600194295248,159.09199905395508,159.0889981587728,159.08600107828775,159.08300018310547,159.08000055948892,159.07600021362305,159.07300186157227,159.06999842325845,159.06699879964194,159.06400044759116,159.0610008239746,159.0569979349772,159.05399958292642,159.05100123087564,159.04799779256186,159.04500198364258,159.04199600219727,159.03799947102866,159.0349973042806,159.03200022379556,159.02899932861328,159.0260009765625,159.02199935913086,159.01900227864584,159.01599884033203,159.01299921671549,159.01000213623047,159.0070012410482,159.00300216674805,159.0,158.99699910481772,158.99400075276694,158.99099985758463,158.98699951171875,158.98400115966797,158.98099899291992,158.97800064086914,158.97499974568686,158.9720001220703,158.96800104777017,158.96500142415366,158.96199798583984,158.9589983622233,158.95600001017252,158.95199966430664,158.9490000406901,158.94599787394205,158.94299825032553,158.94000116984049,158.9369977315267,158.93299992879233,158.93000030517578,158.9269994099935,158.92399978637695,158.92099889119467,158.91699981689453,158.91400019327799,158.91100056966147,158.90799967447916,158.90500005086264,158.90199915568033,158.89800135294595,158.89500045776367,158.8919995625814,158.88899866739908,158.8860003153483,158.88300323486328,158.87900034586588,158.8760019938151,158.8729985555013,158.87000020345053,158.86700057983398,158.8630002339681,158.8599993387858,158.85699844360352,158.85400009155273,158.85099665323892,158.8479995727539,158.84399922688803,158.84099833170572,158.8380012512207,158.83499908447266,158.83200073242188,158.82899729410806,158.82499821980795,158.82200241088867,158.81899897257486,158.81599934895834,158.8130022684733,158.80900065104166,158.80600102742514,158.80299758911133,158.8000005086263,158.796999613444,158.79400126139322,158.7900021870931,158.78700256347656,158.78400166829428,158.78099950154623,158.7780024210612,158.7749989827474,158.77099990844727,158.76800028483072,158.76499938964844,158.7619997660319,158.7590014139811,158.75699996948242};
               //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761542737483978,1.4129000008106232,1.4511199990908306,1.4903099934260051,1.530790001153946,1.5725699961185455,1.6156300107638042,1.658920019865036,1.7013599872589111,1.7429600059986115,1.7837199966112773,1.8236399988333385,1.862720012664795,1.9009600182374318,1.9383500119050343,1.9749099910259247,2.0106300115585327,2.0456600189208984,2.080149988333384,2.11409999926885,2.14750999212265,2.1803899804751077,2.2127299904823303,2.2445300022761026,2.275790015856425,2.306510031223297,2.3367000222206116,2.366439998149872,2.3958400090535483,2.4248899817466736,2.4535800218582153,2.4819299777348838,2.5099300344785056,2.5375900069872537,2.564900000890096,2.591859976450602,2.6184699535369873,2.6448000073432922,2.670900026957194,2.696769972642263,2.722410003344218,2.7478299935658774,2.7730300029118857,2.7979900240898132,2.82272998491923,2.847250004609426,2.8715399503707886,2.8956399957338967,2.919599990049998,2.943410019079844,2.967070003350576,2.99058997631073,3.0139600038528442,3.037190000216166,3.0602700114250183,3.0832000176111856,3.1059899727503457,3.128660003344218,3.1512300173441568,3.1737000147501626,3.1960800290107727,3.2183600266774497,3.2405500014623008,3.2626399596532187,3.2846399943033853,3.306540012359619,3.328339993953705,3.3500199715296426,3.371529996395111,3.3928800026575723,3.4140600164731345,3.4350800116856894,3.455929974714915,3.476619998613993,3.4971399903297424,3.5175000031789145,3.5377000172932944,3.5578099687894187,3.5779200196266174,3.5980199774106345,3.6181100010871887,3.638200044631958,3.658289988835653,3.6783599853515625,3.6984300216039023,3.7184899846712747,3.7385500073432922,3.7585299809773765,3.7783599694569907,3.798050026098887,3.8175900181134543,3.8369800051053367,3.856220006942749,3.875320017337799,3.894260028998057,3.913060029347738,3.9317100048065186,3.950220008691152,3.9685800075531006,3.9867800076802573,4.004849970340729,4.022760033607483,4.0405300060908,4.058159947395325,4.075629989306132,4.092959920565288,4.1101400057474775,4.127180020014445,4.144069989522298,4.1608099937438965,4.17739999294281,4.193850000699361,4.2101500034332275,4.226309895515442,4.242310007413228,4.258170008659363,4.273889938990275,4.2894599835077925,4.304879983266194,4.320159951845805,4.33528995513916,4.35026999314626,4.365109999974568,4.379810055096944,4.394350012143453,4.4087499777476,4.422999978065491,4.43710994720459,4.451069951057434,4.464890082677205,4.478560010592143,4.492080012957255,4.5054599444071455,4.51868999004364,4.531789978345235,4.544729987780253,4.557520031929016,4.570170044898987,4.582679986953735,4.595040003458659,4.60725998878479,4.619329929351807,4.631250023841858,4.643030047416687,4.654660026232402,4.666150053342183,4.677499969800313,4.688689986864726,4.699749986330668,4.710659980773926,4.721430102984111,4.732040047645569,4.7425200541814165,4.75285001595815,4.763039906819661,4.773069977760315,4.782969991366069,4.792719999949138,4.802330017089844,4.811790029207866,4.821110010147095,4.8302799463272095,4.839310010274251,4.848199963569641,4.856939951578776,4.865539987881978,4.873990019162496,4.882300019264221,4.890460014343262,4.898489952087402,4.906360030174255,4.914089957873027,4.921679973602295,4.929129958152771,4.93641992410024,4.943579991658528,4.950600028038025,4.957470059394836,4.964189966519673,4.97077997525533,4.977220018704732,4.983509977658589,4.989660024642944,4.995680014292399,5.001539945602417,5.007260004679362,5.012839953104655,5.018279989560445,5.023569941520691,5.028720021247864,5.033719976743062,5.038589954376221,5.0433099667231245,5.047890027364095,5.0523200035095215,5.056620001792908,5.060759981473287,5.064769943555196,5.068640033404033,5.072359959284465,5.075929959615071,5.079369982083638,5.082659959793091,5.085809985796611,5.088820020357768,5.091689944267273,5.094409982363383,5.0969899495442705,5.099430004755656,5.101729949315389,5.103879968325297,5.105900049209595,5.107769966125488,5.109499971071879,5.111080050468445,5.112529953320821,5.113829970359802,5.114989995956421,5.1160099903742475,5.116879979769389,5.11761999130249,5.1182100375493365,5.118659933408101,5.118969917297363,5.119149963061015,5.11916999022166,5.119059960047404,5.118799964586894,5.118409991264343,5.117869973182678,5.117190003395081,5.116370002428691,5.1154100100199384,5.114299972852071,5.113050063451131,5.1116699775060015,5.110140045483907,5.108549952507019,5.106950004895528,5.105350017547607,5.103760043780009,5.102170030275981,5.10057000319163,5.098979989687602,5.097380042076111,5.095789988835652,5.094199975331624,5.092610001564026,5.091020027796428,5.089430014292399,5.087839961051941,5.086250027020772,5.084659973780314,5.0830700397491455,5.081479986508687,5.079890012741089,5.07830011844635,5.076720039049785,5.075130025545756,5.073549906412761,5.071959972381592,5.070379972457886,5.068789998690288,5.0672099987665815,5.065619945526123,5.0640400648117065,5.062459945678711,5.060880064964294,5.059299985567729,5.057720025380452,5.056139945983887,5.05456006526947,5.052980025609334,5.051399985949199,5.049820065498352,5.0482399463653564,5.04665994644165,5.0450899203618365,5.0435099601745605,5.041940013567607,5.040360013643901,5.038780013720195,5.037209987640381,5.0356400807698565,5.034059961636861,5.032490015029907,5.030919988950093,5.0293500026067095,5.0277700026830034,5.02620001633962,5.024629910786946,5.0230599244435625,5.021490017573039,5.019919991493225,5.018359978993733,5.01679007212321,5.015219966570537,5.013650019963582,5.012090007464091,5.010520060857137,5.008959968884786,5.007390022277832,5.005829930305481,5.004259943962097,5.002700050671895,5.001139998435974,4.9995700518290205,4.998009999593099,4.996449987093608,4.994890014330546,4.993330001831055,4.991769949595134,4.990209976832072,4.988650004069011,4.987089991569519,4.985530058542888,4.983969966570537,4.982419927914937,4.980860034624736,4.979299942652385,4.977750023206075,4.976190050443013,4.9746400117874146,4.973079999287923,4.971530000368754,4.969980001449585,4.968419988950093,4.966869990030925,4.965319911638896,4.963769952456157,4.962220033009847,4.960669994354248,4.959119995435079,4.957570036252339,4.956020037333171,4.954469958941142,4.952919999758403,4.951369961102803,4.949829975763957,4.948279976844788,4.946730017662048,4.945189992586772,4.9436399936676025,4.942099968592326,4.940549969673157,4.93901002407074,4.937470038731893,4.935920000076294,4.934380014737447,4.93283998966217,4.931299924850464,4.929760018984477,4.9282199939092,4.926680048306783,4.925139983495076,4.923600037892659,4.922060012817383,4.920519948005676,4.9189900159835815,4.917450030644734,4.915909965833028,4.914379994074504,4.912839968999227,4.9113099575042725,4.909769972165425,4.908240000406901,4.906700015068054,4.9051700035731,4.903639992078145,4.902109940846761,4.900570034980774,4.89903998374939,4.8975099722544355,4.8959799607594805,4.8944499890009565,4.8929199775060015,4.891389966011047,4.8898699680964155,4.888339996337891,4.8868099848429365,4.885280013084412,4.88376001516978,4.8822299639383955,4.880710005760193,4.879179994265239,4.877659996350606,4.876129984855652,4.874610026677449,4.8730900684992475,4.871559937795003,4.8700400193532305,4.8685199817021685,4.866999983787537,4.865480025609334,4.863959987958272,4.86243999004364,4.860919952392578,4.859400033950806,4.857879996299744,4.856360077857971,4.854850014050801,4.853329976399739,4.851809938748677,4.850299994150798,4.848779996236165,4.8472700119018555,4.845750053723653,4.844240029652913,4.842719992001851,4.841209967931111,4.839700023333232,4.838190078735352,4.83667008082072,4.83515993754069,4.83364995320638,4.83213996887207,4.830629984537761,4.829119920730591,4.827610055605571,4.826110005378723,4.8246000210444135,4.823089957237244,4.821580012639363,4.820079962412517,4.818569938341777,4.817069927851359,4.815560062726338,4.8140599727630615,4.812549908955892,4.811049938201904,4.809539993604024,4.808040022850037,4.806540052096049,4.8050399621327715,4.803539991378784,4.802039980888367,4.800540010134379,4.799040039380391,4.797539989153544,4.796039978663127,4.794540007909139,4.793039997418721,4.791539986928304,4.790050029754639,4.788549979527791,4.787050048510234,4.785559972127278,4.784060001373291,4.782570044199626,4.7810700337092085,4.779580036799113,4.778090000152588,4.77659006913503,4.775100032488505,4.77360999584198,4.772120038668315,4.770629962285359,4.7691400448481245,4.767639954884847,4.766160011291504,4.764669934908549,4.763179937998454,4.761690020561218,4.760199864705403,4.758709987004598,4.757230003674825,4.7557399670283,4.754249970118205,4.752769947052002,4.751279950141907,4.749799966812134,4.748320023218791,4.746830026308696,4.7453499635060625,4.74387005964915,4.7423800230026245,4.740900079409282,4.7394200166066485,4.737939993540446,4.736460010210673,4.73497998714447,4.733500043551127,4.732019980748494,4.730539997418721,4.729060014088948,4.728329976399739};
               SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568445841471354,8.884455839792887,9.182517131169638,9.511126597722372,9.84283677736918,10.17760682106018,10.515506982803345,10.856706857681274,11.201407194137573,11.549506982167562,11.901207208633423,12.256307204564413,12.614907344182333,12.9769074122111,13.342507521311441,13.711507558822632,14.084007581075033,14.459507624308268,14.837507804234823,15.21810777982076,15.60130778948466,15.987007856369019,16.375207742055256,16.766007900238037,17.159307797749836,17.555107911427815,17.953508059183758,18.354708194732666,18.75890827178955,19.16610844930013,19.57640854517619,19.98960828781128,20.40590826670329,20.82520850499471,21.24750852584839,21.67280848821004,22.101208686828613,22.53160874048869,22.9632085164388,23.39590867360433,23.82970889409383,24.26460886001587,24.700708866119385,25.138008912404377,25.576408704121906,26.01590871810913,26.456508954366047,26.898108959197998,27.340508778889973,27.783709049224854,28.227709134419758,28.672409216562908,29.118008931477863,29.564309279123943,30.01150910059611,30.45940907796224,30.908108870188396,31.35690911610921,31.8048095703125,32.251909255981445,32.69820912679037,33.14380900065104,33.58850924173991,34.0325091679891,34.475609143575035,34.91800912221273,35.35950915018717,35.80010954538981,36.23950926462809,36.677608807881676,37.114608446756996,37.550408363342285,37.98500919342041,38.418308893839516,38.85050900777181,39.28150908152262,39.71130816141764,40.139808654785156,40.566908836364746,40.992508252461754,41.41670831044515,41.83940855662028,42.260708491007485,42.68060843149821,43.099008560180664,43.51600869496664,43.93160820007324,44.34500821431478,44.7554079691569,45.16270796457926,45.567108154296875,45.9686082204183,46.367008209228516,46.762508392333984,47.154907862345375,47.544407526652016,47.93100770314535,48.314507484436035,48.69510714213053,49.07270749409994,49.4473082224528,49.818907737731934,50.187607765197754,50.55330721537272,50.91600735982259,51.27580706278483,51.63260714213053,51.98640727996826,52.33720715840658,52.68510723114014,53.03000672658285,53.37200673421224,53.71100680033366,54.047006924947105,54.38010597229004,54.71020698547363,55.037306785583496,55.36150646209717,55.68270683288574,56.00100644429525,56.316305796305336,56.628706296284996,56.93810590108236,57.244506200154625,57.54800573984782,57.848605473836265,58.14620621999105,58.440805753072105,58.732505798339844,59.02130572001139,59.307106018066406,59.59000555674235,59.86990547180176,60.14680608113607,60.420905431111656,60.691905657450356,60.96010557810465,61.2253049214681,61.48760541280111,61.7469056447347,62.003305435180664,62.25670464833578,62.50720532735189,62.75480524698893,62.99940458933512,63.24110476175944,63.47990481058756,63.715804735819496,63.948704401652016,64.1787052154541,64.40570386250813,64.62990442911784,64.85110410054524,65.06930414835612,65.28470420837402,65.49710337320964,65.70660400390625,65.91320419311523,66.11690457661946,66.3176040649414,66.51540311177571,66.71030298868816,66.9023043314616,67.09140396118164,67.27750396728516,67.46080334981282,67.64110374450684,67.81850369771321,67.99300384521484,68.16460291544597,68.3333028157552,68.49900309244792,68.66190401713054,68.82190259297688,68.97890345255534,69.13300323486328,69.28430302937825,69.43260320027669,69.57800420125325,69.72060330708821,69.86020215352376,69.99690373738606,70.13070233662923,70.26160303751628,70.38970375061035,70.51480229695638,70.63700167338054,70.75640106201172,70.872802734375,70.98640314737956,71.09700139363606,71.20480219523112,71.30970128377278,71.41170183817546,71.51080131530762,71.60700225830078,71.70030148824056,71.79070281982422,71.87829971313477,71.96300188700359,72.04480171203613,72.12370173136394,72.19970194498698,72.27280044555664,72.34310150146484,72.41050148010254,72.47500101725261,72.53660074869792,72.59540049235027,72.65120124816895,72.70430183410645,72.75440088907878,72.80160077412923,72.84600067138672,72.88750012715657,72.92620023091634,72.96200116475423,72.99489974975586,73.02490043640137,73.0521011352539,73.07640012105306,73.09790102640788,73.11640040079753,73.13220087687175,73.14499982198079,73.15499877929688,73.16219902038574,73.16639963785808,73.16790008544922,73.16640027364095,73.16209920247395,73.15499877929688,73.14499918619792,73.13209978739421,73.11639912923177,73.09789975484212,73.07639948527019,73.0536003112793,73.03079922993977,73.00799878438313,72.98520024617513,72.96239980061848,72.93959935506184,72.91680018107097,72.89399973551433,72.8711986541748,72.8484001159668,72.82569821675618,72.8028990427653,72.7801996866862,72.75739860534668,72.73469924926758,72.71199862162273,72.68929926554362,72.66649945576985,72.64379946390788,72.62110074361165,72.59849993387859,72.5757999420166,72.5531005859375,72.53039868672688,72.50779978434245,72.48509915669759,72.46249898274739,72.43980026245117,72.41719881693523,72.3945992787679,72.3718999226888,72.3492997487386,72.32669893900554,72.30409876505534,72.28149859110515,72.2588996887207,72.2363993326823,72.21380043029785,72.19119962056477,72.16869926452637,72.1461009979248,72.12359937032063,72.10109965006511,72.07849884033203,72.05599975585938,72.03350003560384,72.01100031534831,71.98850123087566,71.96599833170573,71.94349924723308,71.92099952697754,71.89860026041667,71.87609926859538,71.85360018412273,71.83120028177898,71.8086986541748,71.78629875183105,71.76389948527019,71.74139976501465,71.7189998626709,71.69659932454427,71.6742000579834,71.6517988840739,71.62939961751302,71.60709953308105,71.5846996307373,71.56229909261067,71.53999837239583,71.51759847005208,71.49529838562012,71.47289975484212,71.45059903462727,71.4282995859782,71.40589904785156,71.38359959920247,71.36129887898763,71.33900006612141,71.31669934590657,71.2944990793864,71.27219835917155,71.24989891052246,71.2277005513509,71.2053991953532,71.18310038248698,71.16089884440105,71.13869984944661,71.11639976501465,71.09420077006023,71.07199923197429,71.04979960123698,71.02759997049968,71.00539970397949,70.9831994374593,70.96099917093913,70.93889999389648,70.9166997273763,70.89459991455078,70.8723996480306,70.8502991994222,70.82809956868489,70.80599975585938,70.78389930725098,70.76180013020833,70.73959986368816,70.71750005086263,70.69539896647136,70.67340024312337,70.65129979451497,70.62919998168945,70.60710016886394,70.5851001739502,70.5629997253418,70.54099782307942,70.51889991760254,70.4968999226888,70.47489929199219,70.45280011494954,70.43079948425293,70.40879948933919,70.38679885864258,70.36479886372884,70.34280014038086,70.32089932759602,70.2988993326823,70.27689997355144,70.2549991607666,70.23299916585286,70.21110026041667,70.18909962972005,70.1671994527181,70.14529991149902,70.12339909871419,70.10149892171223,70.07959938049316,70.05769920349121,70.03580093383789,70.0138988494873,69.9919999440511,69.9700984954834,69.94830004374187,69.92639986673991,69.90459887186687,69.88269869486491,69.86090024312337,69.83909924825032,69.81729952494304,69.79539998372395,69.77359962463379,69.75179926554362,69.72999954223633,69.70819918314616,69.6865005493164,69.66469955444336,69.6428991953532,69.62119928995769,69.59939893086751,69.577699025472,69.55589930216472,69.53420003255208,69.51249885559082,69.49069849650066,69.46899922688802,69.44729868570964,69.42560132344563,69.40389951070149,69.38230069478352,69.36059951782227,69.33889961242676,69.31719907124837,69.29559898376465,69.27389907836914,69.25230026245117,69.23060035705566,69.20899963378906,69.18739954630534,69.16579945882161,69.14419937133789,69.12259928385417,69.10099919637044,69.07939910888672,69.057799021403,69.03619956970215,69.0146001180013,68.99309921264648,68.97149976094563,68.94999885559082,68.92840067545573,68.90689913431804,68.88540077209473,68.86379877726237,68.84229850769043,68.82079887390137,68.79930051167806,68.77780024210612,68.75630060831706,68.73479906717937,68.71339925130208,68.69189961751302,68.67039934794109,68.64899762471516,68.62749926249187,68.60609944661458,68.5846004486084,68.56319999694824,68.54179954528809,68.52039845784505,68.4990005493164,68.47760009765625,68.45619901021321,68.43479919433594,68.41339874267578,68.39199956258138,68.37060038248698,68.34930102030437,68.32789993286133,68.30659929911296,68.2851988474528,68.26389948527019,68.2425988515218,68.22129885355632,68.19989967346191,68.17859967549641,68.1573003133138,68.13600095113118,68.11470031738281,68.09349950154622,68.07219950358073,68.05090077718098,68.02959950764973,68.0083999633789,67.98709932963054,67.96590042114258,67.94469833374023,67.92340024312337,67.9021987915039,67.88099988301595,67.85979906717937,67.83859952290852,67.81739934285481,67.7961991628011,67.77499898274739,67.75379880269368,67.73269907633464,67.7114995320638,67.69029935201009,67.66920026143391,67.64809926350911,67.62689971923828,67.6164010365804};
               //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129462162653605,2.2204294006029763,2.2993471026420593,2.3890169660250344,2.4812171459198,2.5758673548698425,2.6728772719701133,2.7681070963541665,2.8574770092964172,2.9411569039026895,3.0193167130152383,3.0920965671539307,3.159646431605021,3.222116311391195,3.2796361645062766,3.332356055577596,3.3803959687550864,3.424475848674774,3.465275764465332,3.502885659535726,3.5374056100845337,3.568915526072184,3.597495416800181,3.6232353250185647,3.646205186843872,3.666485150655111,3.684165080388387,3.6996750235557556,3.7134849627812705,3.7256348927815757,3.736164848009745,3.7451248367627463,3.7525447607040405,3.758484701315562,3.762964606285095,3.7660345832506814,3.767724553743998,3.768304487069448,3.767994483311971,3.7668444315592446,3.7648444175720215,3.7620443304379783,3.758444309234619,3.7540643016497293,3.7489242355028787,3.7430442174275718,3.7364441752433777,3.7293041348457336,3.721804122130076,3.713954130808512,3.7057540814081826,3.6972240606943765,3.6883639891942344,3.6791740457216897,3.669674019018809,3.659873982270559,3.649773975213369,3.6394839882850647,3.6291039188702903,3.6186439394950867,3.60810387134552,3.5974838733673096,3.5867738723754883,3.5759938756624856,3.565133810043335,3.55419385433197,3.5431838234265647,3.5319737593332925,3.5204337437947593,3.5085837046305337,3.4964337150255838,3.4839836955070496,3.471233626206716,3.4582136074701944,3.444913605848948,3.4313535491625466,3.4175235827763877,3.40374356508255,3.390323599179586,3.3772635658582053,3.3645335833231607,3.352133552233378,3.3400535583496094,3.328293561935425,3.316843569278717,3.3056935469309487,3.2948235074679055,3.2839635213216147,3.2728134791056314,3.261373440424601,3.2496634324391684,3.2377034028371177,3.225473423798879,3.213003396987915,3.2002933422724404,3.187353273232778,3.174193322658539,3.160803278287252,3.147213260332743,3.1334132154782615,3.119423230489095,3.1052331725756326,3.090873142083486,3.0763231118520102,3.0616031289100647,3.046713093916575,3.0316730737686157,3.016473035017649,3.001122991243998,2.9856229623158774,2.969982941945394,2.954202950000763,2.938302914301554,2.922272880872091,2.906112869580587,2.8898428281148276,2.87345282236735,2.856962819894155,2.840352793534597,2.823652744293213,2.8068427244822183,2.789942741394043,2.772952675819397,2.755872666835785,2.7387026151021323,2.7214525938034058,2.7041325767834983,2.6867225567499795,2.669242560863495,2.651692489782969,2.634082476298014,2.6163924733797708,2.5986424485842385,2.5808324416478476,2.5629724264144897,2.545042395591736,2.5270623564720154,2.509032348791758,2.4909522930781045,2.472832282384237,2.454652269681295,2.4364322423934937,2.4181721806526184,2.3998621503512063,2.3815221786499023,2.3631421526273093,2.344722112019857,2.3262720902760825,2.3077820539474487,2.289262036482493,2.2707220315933228,2.252142012119293,2.2335419257481894,2.214911957581838,2.19625190893809,2.177561899026235,2.1588618556658425,2.1401318311691284,2.121381858984629,2.1026118199030557,2.083831787109375,2.0650217731793723,2.046201745669047,2.0273617108662925,2.0085016886393228,1.989631672700246,1.9707416395346324,1.9518416027228038,1.9329316020011902,1.9140115678310394,1.8950715363025665,1.8761315246423085,1.8571714957555134,1.8382014731566112,1.8192314406236012,1.8002514441808064,1.781261424223582,1.7622613906860352,1.743251343568166,1.7242513199647267,1.7052313089370728,1.6862112780412037,1.667181263367335,1.6481512188911438,1.6291112303733826,1.6100712021191914,1.591031163930893,1.5719811419645946,1.5529311100641887,1.5338810781637828,1.5148310760656993,1.495781034231186,1.4767210284868877,1.4576609929402669,1.4386009673277538,1.4195409615834553,1.4004809260368347,1.3814208805561066,1.3623608748118083,1.3433008392651875,1.3242408136526744,1.3051908016204834,1.2861307859420776,1.267070750395457,1.248020738363266,1.22897070646286,1.2099106808503468,1.1908606588840485,1.1718106468518574,1.1527706185976665,1.133720596631368,1.114680568377177,1.0956405401229858,1.0766105353832245,1.057570497194926,1.0385404825210571,1.019510457913081,1.0004904220501583,0.9814644058545431,0.962447389960289,0.9434313575426737,0.9244183252255121,0.9054093112548193,0.8864062875509262,0.8674052606026331,0.8484062403440475,0.8294132153193156,0.8104231953620911,0.7914351721604665,0.7724521458148956,0.7534761180480322,0.7345020969708761,0.7155310660600662,0.6965660552183787,0.6776060312986374,0.6586500008900961,0.6396960119406382,0.6210210025310516,0.6028860012690226,0.5852769911289215,0.5681790063778559,0.5515779952208201,0.5354600052038828,0.5198100010553995,0.504616009692351,0.4898639991879463,0.4755420039097468,0.4616380011041959,0.44813799609740573,0.43503300100564957,0.4223099996646245,0.40995699912309647,0.39796599994103116,0.3863249992330869,0.3750229999423027,0.36405200014511746,0.3534010003010432,0.34306100010871887,0.3330239951610565,0.3232790008187294,0.3138200019796689,0.30463700244824093,0.29572299867868423,0.287069005270799,0.27866799881060916,0.27051300058762234,0.2625960012276967,0.2549110030134519,0.2474500002960364,0.24020800242821375,0.23317799841364226,0.2263530008494854,0.21972800170381865,0.21329700201749802,0.20705300072828928,0.20099300146102905,0.19510999942819277,0.1893979993959268,0.1838540012637774,0.17847299948334694,0.17324800044298172,0.16817699993650118,0.16325399776299795,0.15847399830818176,0.15383499984939894,0.14933199808001518,0.14496000235279402,0.14071599890788397,0.1365970013042291,0.13259800026814142,0.128716000666221,0.12494699905316035,0.12128899929424126,0.11773799980680148,0.11429099986950557,0.11094500000278155,0.1076959998657306,0.10454299921790759,0.10148199896017711,0.0985105000436306,0.095626100897789,0.09282610068718593,0.09010810032486916,0.08746959952016671,0.08490830038984616,0.08242199942469597,0.08000850180784862,0.07766559968392055,0.07539129878083865,0.07318360048035781,0.0710404006143411,0.06896009979148705,0.06694059943159421,0.06498020080228646,0.06307730047653119,0.06122999979803959,0.059436799958348274,0.05769610001395146,0.05600640053550402,0.05436610026905934,0.05277389970918497,0.051228300047417484,0.049727900264163814,0.048271399922668934,0.0468577000622948,0.04548529970149199,0.04415309987962246,0.042860000083843865,0.04160470049828291,0.040386199640731014,0.039203400102754436,0.03805520044018825,0.036940700064102806,0.03585880001386007,0.034808600321412086,0.033789100125432014,0.03279960000266632,0.031839000061154366,0.030906500294804573,0.030001299921423197,0.029122699983417988,0.02826980035752058,0.027441799795875948,0.026638200040906668,0.025857999920845032,0.025100700091570616,0.02436560035372774,0.023651999887079,0.022959399813165266,0.022287000125894945,0.021634299928943317,0.021000700071454048,0.020385700122763712,0.0197887000006934,0.01920909993350506,0.01864660003532966,0.018100500106811523,0.01757039998968442,0.01705589983612299,0.01655639971916874,0.01607150010143717,0.015600899932906032,0.015143999985108772,0.014700499984125296,0.014269999926909804,0.013852100043247143,0.013446400019650659,0.013052700009817878,0.012670400009180108,0.012299399900560578,0.011939200029398004,0.011589600083728632,0.011250199982896447,0.01092069991864264,0.01060090004466474,0.01029050008704265,0.009989119988555709,0.009696599872161945,0.009412650018930435,0.009137009968981147,0.008869439906751117,0.008609709950784842,0.008357589831575751,0.008112850055719415,0.007875280027898649,0.007644670084118843,0.00742080993950367,0.007203500019386411,0.006992559996433556,0.0067877999584500985,0.006589030032046139,0.006396089952128629,0.006208790039333205,0.006026980040284495,0.005850500000330309,0.005679179991905888,0.005512879967379074,0.005351449983815352,0.005194749993582566,0.005042640026658773,0.0048949799578016,0.0047516500344499946,0.004612510014946262,0.004477450042031705,0.0043463399245714145,0.00421906999933223,0.004095530059809486,0.003975610015913844,0.003859200010386606,0.0037461999842586615,0.00363650006086876,0.0035300200106576085,0.0034266599686816335,0.003326329965299616,0.0032289300191526613,0.003134379997694244,0.0030426099935236075,0.002953520005879303,0.0028670400109452507,0.0027830900119928024,0.002701600024010986,0.0026225000231837234,0.0025457099933798113,0.0024711700001110635,0.0023988199924739697,0.0023285800319475434,0.0022603999823331833,0.0021942200255580246,0.0021299700213906667,0.0020676100199731686,0.002007070016892006,0.0019483099749777466,0.0018912600256347407,0.0018358899978920817,0.0017821400057679664,0.0017299600003752857,0.0016793100027522694,0.0016301399931156386,0.0015824100022049,0.0015360799831493448,0.0014911100054935862,0.0014474500009479623,0.0014050700022683789,0.0013639299916879584,0.001324000011663884,0.0012852400056241702,0.0012476099946070462,0.001211080001667142,0.001175629993667826,0.0011412099993322045,0.0011077900126110762,0.001075359982981657,0.001043879989689837,0.0010133199975825846,0.0009836500054613377,0.0009548519980550433,0.0009268969927992051,0.0008997610081375266,0.0008734189953732615,0.0008478489956663301,0.0008230269983566055,0.0007989320001797751,0.0007755429978715256,0.0007528379937866703,0.0007307980073771129,0.000709403000655584,0.0006886350020067766,0.0006684750017787641,0.0006489049944017703,0.0006299080123426393,0.000611468004838874,0.0005935670002751673,0.000576189995626919,0.0005593219927201668,0.0005429479982315873,0.0005270539986668155,0.0005116249958518893,0.0004966470102469126,0.0004821079977167149,0.0004679949997807853,0.00045429499975095194,0.00044099599957310903,0.0004280860011931509,0.0004155540033631648,0.00040338900240991887,0.0003973970015067607};
        CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11865933736165,80.86888885498047,79.52099164326985,78.117493947347,76.66689618428548,75.17669677734375,73.65429878234863,72.10620053609212,70.53860219319661,68.95680236816406,67.36580467224121,65.77030499776204,64.17410500844319,62.58110682169596,60.99460697174072,59.41750717163086,57.85260804494222,56.30240821838379,54.768908182779946,53.25410874684652,51.75970904032389,50.287110010782875,48.83770942687988,47.41250991821289,46.0125093460083,44.63850975036621,43.29130935668945,41.97121016184489,40.678810119628906,39.41440931955973,38.178309758504234,36.97060998280843,35.79130935668945,34.64060910542806,33.51830927530924,32.42430877685547,31.3584090868632,30.3205091158549,29.310208956400555,28.32740847269694,27.37160841623942,26.44260835647583,25.53980811436971,24.663008054097492,23.811607837677002,22.985307693481445,22.18360773722331,21.406007289886475,20.651907126108807,19.92100699742635,19.21270688374837,18.52660671869914,17.862006505330402,17.21860631306966,16.595706462860107,15.993005832036337,15.409905672073364,14.845805565516153,14.300305287043253,13.77300532658895,13.26320513089498,12.770605007807413,12.294704755147299,11.834904591242472,11.390904506047567,10.962104241053263,10.548204183578491,10.148704051971436,9.763183991114298,9.39120364189148,9.032353480656942,8.686253627141317,8.352503379185995,8.030713359514872,7.720513145128886,7.421533107757568,7.133402943611145,6.855792840321858,6.588342785835266,6.330732663472493,6.082622607549031,5.843712488810222,5.613672375679016,5.392222325007121,5.179062247276306,4.973902146021525,4.771802186965942,4.572952310244243,4.382222135861714,4.199282010396321,4.023832003275554,3.8555618723233542,3.694191833337148,3.5394517381985984,3.3910616437594094,3.248781601587931,3.1123615304629006,2.9815615018208823,2.856171409289042,2.73595138390859,2.6207112471262612,2.5102412501970925,2.4043511549631753,2.302851140499115,2.2055710752805076,2.1123310724894204,2.0229709645112357,1.9373409648736317,1.8552709221839905,1.7766308883825939,1.7012708485126495,1.6290708084901173,1.5598907669385274,1.493600755929947,1.430090715487798,1.3692506849765778,1.3109606603781383,1.2551206250985463,1.2016206085681915,1.1503805915514629,1.1013005475203197,1.054280549287796,1.0092505166927974,0.9661224881807963,0.9248144676287969,0.8852524360020956,0.8473634272813797,0.811078409353892,0.7763303965330124,0.7430553783973058,0.7111923595269521,0.6806803445021311,0.6514653265476227,0.6234913021326065,0.596707304318746,0.5710622916618983,0.5465102742115656,0.5230032652616501,0.5004982476433119,0.47895323981841403,0.45832723130782443,0.4385822241504987,0.41968021045128506,0.4015862047672272,0.384266197681427,0.367687185605367,0.3518181766072909,0.33662917216618854,0.32209016134341556,0.30817416061957675,0.2948561484615008,0.2821091463168462,0.2699091409643491,0.2582331324617068,0.24705912296970686,0.23636511961619058,0.2261311151087284,0.21633711084723473,0.20696510498722395,0.1979971006512642,0.18941409761706987,0.1812020925184091,0.1733440893391768,0.16582408547401428,0.15862907841801643,0.1517440751194954,0.14515707517663637,0.13885407149791718,0.13282406826814017,0.12705406608680883,0.12153306230902672,0.11625206097960472,0.11119805773099263,0.10636405584712823,0.10173905206223328,0.09731354999045531,0.0930802480628093,0.08903024531900883,0.08515584468841553,0.08144934164981048,0.07790354018410046,0.07451163791120052,0.07126673683524132,0.06816273555159569,0.06519353451828162,0.062353131671746574,0.059636130618552365,0.05703712937732538,0.054551128298044205,0.052173126178483166,0.04989842573801676,0.04772272457679113,0.045641523165007435,0.043650922986368336,0.04174692121644815,0.03992582050462564,0.038183819192151226,0.036517818458378315,0.03492421812067429,0.03340011679877838,0.031942316330969334,0.030548115726560354,0.0292145151955386,0.02793911440918843,0.026719313735763233,0.025552713001767795,0.02443691265458862,0.023369711668541033,0.022349111425379913,0.02137301101659735,0.020439510699361563,0.019546810071915388,0.018692909584691126,0.01787630918746193,0.017095408712824185,0.016348608459035557,0.015634307948251564,0.01495130763699611,0.014298007435475787,0.0136733070636789,0.013075906628121933,0.012504506468152007,0.011958106188103557,0.011435605973626176,0.010935905622318387,0.010458105398962894,0.010001105101158222,0.009564095021535953,0.009146174881607294,0.008746524496624867,0.00836434424854815,0.007998864011218151,0.007649363988700013,0.00731513377589484,0.006995513569563627,0.006689873446399967,0.006397593261984487,0.006118093190404276,0.005850823052848379,0.005595232903336485,0.005350812726343672,0.005117092669631044,0.004893582547083497,0.004679842347589632,0.004475442343391478,0.00427998222100238,0.004093062093791862,0.00391431205207482,0.00374337190684552,0.0035799118146921196,0.0034235817923521004,0.003274081682320684,0.0031311216104465225,0.002994401555042714,0.0028636514907702804,0.0027386114040079215,0.002619041323972245,0.002504691268162181,0.0023953312387069068,0.0022907511641581855,0.0021907411282882094,0.0020951010713664195,0.00200363101127247,0.001916161001039048,0.001832500915043056,0.001752500907362749,0.0016760008487229545,0.0016028308309614658,0.0015328607890599717,0.001465940741278852,0.001401950711927687,0.0013407506824781497,0.0012822206578372668,0.0012262506449284654,0.001172720609853665,0.0011215305809552472,0.0010725805671730388,0.0010257605269240837,0.0009809824987314641,0.0009381634881719947,0.0008972124536133682,0.0008580504412141939,0.0008205974202913543,0.0007847794089078283,0.0007505253791653862,0.0007177663695377609,0.000686437352366435,0.0006564763316418976,0.0006278233195189387,0.0006004203023621812,0.0005742142966482788,0.0005491522897500545,0.0005251842667348683,0.0005022622644901276,0.00048034124726351973,0.00045937623508507386,0.00043932722716514644,0.00042015321863194305,0.0004018162120094833,0.00038427919935202226,0.0003675081849602672,0.0003514681787540515,0.0003361291771094936,0.00032146016746992245,0.000307430156681221,0.00029401315744811046,0.00028118214443869266,0.0002689111327830081,0.0002571751368426097,0.00024595212380518205,0.00023521812060304606,0.00022495311471478394,0.0002151361113646999,0.00020574810453884615,0.00019676910111835846,0.00018818209719029255,0.00017997009247968285,0.00017211608671156378,0.00016460508413729258,0.00015742208051960915,0.00015055207647189187,0.00014398307515269457,0.0001376990706679256,0.00013169106629599506,0.00012594406507560052,0.00012044806256502245,0.00011519205994166744,0.00011016605822078418,0.00010535805449762847,6.766783371858764e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
              CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.4519182840983,229.59260431925455,226.30871963500977,223.63971074422201,220.94371032714844,218.22370783487955,215.48370742797852,212.72770309448242,209.95770390828451,207.17770131429037,204.3907012939453,201.59970347086588,198.80570220947266,196.01170094807944,193.21970494588217,190.4327023824056,187.65270614624023,184.87970606486002,182.11670557657877,179.36570739746094,176.62670771280924,173.90271123250326,171.19371287027994,168.50171534220377,165.82771682739258,163.1727180480957,160.5377197265625,157.92272313435873,155.32972844441733,152.7597287495931,150.21173095703125,147.6877326965332,145.1877352396647,142.71373875935873,140.26374181111655,137.8407440185547,135.442746480306,133.07174936930338,130.72775522867838,128.41175587972006,126.12275886535645,123.86176109313965,121.6277650197347,119.42276827494304,117.24577077229817,115.09777514139812,112.97777493794759,110.88578033447266,108.82278378804524,106.7877852121989,104.78178977966309,102.80379231770833,100.85379536946614,98.93309783935547,97.04020118713379,95.17530377705891,93.33850733439128,91.52941068013509,89.74811299641927,87.99431546529134,86.26791826883952,84.56862195332845,82.8964246114095,81.25102806091309,79.6323299407959,78.0400333404541,76.47383562723796,74.93373807271321,73.41934013366699,71.93054262797038,70.46694628397624,69.02854919433594,67.61495208740234,66.22595469156902,64.86135673522949,63.52075926462809,62.204161643981934,60.910964012145996,59.64116668701172,58.394369761149086,57.17037105560303,55.96877415974935,54.7893762588501,53.63187917073568,52.495981216430664,51.38148466746012,50.30908997853597,49.27769152323405,48.264793395996094,47.2702964146932,46.293797175089516,45.33509953816732,44.39400100708008,43.47020308176676,42.563604990641274,41.6738068262736,40.80060895284017,39.94391059875488,39.10331153869629,38.278713862101235,37.469715436299644,36.6762170791626,35.89801851908366,35.13471984863281,34.38622188568115,33.652222633361816,32.93252499898275,32.22692632675171,31.535127957661945,30.85702912012736,30.19233051935832,29.54073190689087,28.902233123779297,28.276334762573242,27.66313584645589,27.062137285868328,26.473238309224445,25.896339416503906,25.331140836079914,24.77744213740031,24.23504336675008,23.703644434611004,23.18324549992879,22.673446655273438,22.17424774169922,21.685349146525066,21.206650257110596,20.7377511660258,20.278751850128174,19.82925271987915,19.389153798421223,18.95825497309367,18.53645610809326,18.123556931813557,17.71935796737671,17.323758284250896,16.936559677124023,16.557560284932453,16.18656126658122,15.823561986287435,15.468262831370035,15.120563745498657,14.780364354451498,14.447465260823568,14.121766010920206,13.803066651026407,13.491267442703247,13.186268329620361,12.887868801752726,12.595869382222494,12.310270150502523,12.030970891316732,11.75767151514689,11.49037218093872,11.228972752888998,10.973273356755575,10.72317393620809,10.478574434916178,10.239375034968058,10.005475521087646,9.776736179987589,9.553046703338623,9.334316968917847,9.120437701543173,8.91130797068278,8.706828435262045,8.506909052530924,8.311439673105875,8.120329936345419,7.933500488599141,7.750840902328491,7.572281360626221,7.397731741269429,7.227102279663086,7.060292601585388,6.897243022918701,6.737873435020447,6.582093755404155,6.42984406153361,6.281044403711955,6.135594765345256,5.993445158004761,5.854525605837504,5.718745867411296,5.586046099662781,5.456366419792175,5.329626758893331,5.2057870626449585,5.084757407506307,4.966477672259013,4.8509078820546465,4.737988233566284,4.62764847278595,4.519838770230611,4.414489030838013,4.311559240023295,4.210969527562459,4.112709720929463,4.016710003217061,3.922910233338674,3.83126038312912,3.7417306701342263,3.6542608936627707,3.5688010851542153,3.4853113094965615,3.4037615259488425,3.3240817189216614,3.246241887410482,3.1702120502789817,3.0959422985712686,3.023402432600657,2.9525426030158997,2.8833327492078147,2.815722942352295,2.7496930956840515,2.68518328666687,2.6221734484036765,2.560623586177826,2.5005037585894265,2.4417738914489746,2.384404023488363,2.3283841411272683,2.2736742893854776,2.220234433809916,2.1680245200792947,2.1170447071393332,2.067254821459452,2.018624941507975,1.9711250364780426,1.9247451623280842,1.8794552783171337,1.8352253933747609,1.7920354902744293,1.7498556077480316,1.7086556951204936,1.66843581199646,1.6291459103425343,1.5907860100269318,1.5533161163330078,1.5167261858781178,1.4809962809085846,1.4461163679758708,1.412056456009547,1.3787865440050762,1.3462865948677063,1.3145466844240825,1.2835767567157745,1.2533168494701385,1.2237569093704224,1.194916993379593,1.166757086912791,1.1392471392949421,1.1123771965503693,1.0861572623252869,1.060537318388621,1.0355073908964794,1.0110774636268616,0.9872285226980845,0.9639515727758408,0.9412106374899546,0.9189916799465815,0.8973037401835123,0.8761337995529175,0.8554698477188746,0.8352788984775543,0.8155489514271418,0.796289990345637,0.7774910430113474,0.7591420908768972,0.7412311335404714,0.7237261732419332,0.7066192229588827,0.6899202615022659,0.6736202985048294,0.6577093402544657,0.6421783715486526,0.6270194053649902,0.612200453877449,0.5977134903271993,0.5835735301176707,0.569770559668541,0.5562975953022639,0.5431466301282247,0.5303096622228622,0.5177786896626154,0.5055477172136307,0.4936087528864543,0.48193278660376865,0.47051480909188587,0.45936983575423557,0.4484898621837298,0.4378708948691686,0.42750491698582965,0.41738694657882053,0.4075099751353264,0.39786899586518604,0.3884580185015996,0.3792720412214597,0.37030606468518573,0.36155308534701663,0.3530091121792793,0.3446701318025589,0.3365081499020259,0.32852016637722653,0.32072219004233676,0.31311020503441495,0.3056802252928416,0.2984282424052556,0.29134926448265713,0.28443827976783115,0.27769329647223157,0.27110931277275085,0.2646823301911354,0.2584083477656047,0.2522843616704146,0.24630737801392874,0.24047239124774933,0.234776404996713,0.2292164204021295,0.22378943488001823,0.21849244832992554,0.21332146103183428,0.20827347164352736,0.2033464858929316,0.19853749747077623,0.19384251038233438,0.18925952290495238,0.18478653207421303,0.18042054399847984,0.17615855609377226,0.17199756701787314,0.16793657715121904,0.16397258639335632,0.1601025958855947,0.15632560600837073,0.15261660888791084,0.14897562066713968,0.14542162915070853,0.14195163796345392,0.13856464748581251,0.1352586547533671,0.13203166301051775,0.1288816717763742,0.12580667808651924,0.12280568728844325,0.11987569493552049,0.11701570202906926,0.11422370746731758,0.11149871597687404,0.10883872273067634,0.10624272873004277,0.10370773635804653,0.10123374188939731,0.09881874856849511,0.09646135506530602,0.09416015942891438,0.09191396584113438,0.08972137173016866,0.08758107634882133,0.0854917826751868,0.08345248736441135,0.08146179219086964,0.07951859757304192,0.0776217021048069,0.07577020799120267,0.07396281138062477,0.07219851637880008,0.07047642146547635,0.06879532399276893,0.06715442861119907,0.06555263201395671,0.06398903826872508,0.06246274057775736,0.06097294514377912,0.05951864862193664,0.0580990519374609,0.05671335539470116,0.05536065902560949,0.05404026247560978,0.052751366049051285,0.0514932693913579,0.050265172185997166,0.04906637500971556,0.047896177818377815,0.046753881188730397,0.045638883796830974,0.044550386567910515,0.04348798934370279,0.042450791535278164,0.04143849480897188,0.04045029729604721,0.03948559953520695,0.0385440019890666,0.03762480430305004,0.03672760693977276,0.035851808885733284,0.03499681161095699,0.034162313056488834,0.03334761473039786,0.032552517019212246,0.03177621898551782,0.031018521015842754,0.030278922834744055,0.029556924632440012,0.02885212640588482,0.028164228424429893,0.027492630140235026,0.02683713162938754,0.026197233392546575,0.025572635078181822,0.024962836721291144,0.02436773789425691,0.023786739601443212,0.02321954071521759,0.022665942398210365,0.02212554356083274,0.021598044627656538,0.021083146333694458,0.020580547706534464,0.020089848898351192,0.01961094979196787,0.019143351043264072,0.018686952379842598,0.01824155372257034,0.01780665448556344,0.017382155638188124,0.016967756828914087,0.016563257823387783,0.0161684585424761,0.015783059565971296,0.015406760775173703,0.015039561704422036,0.014681062661111355,0.014331063410888115,0.013989464535067478,0.013655965138847629,0.013330466113984585,0.013012766993294159,0.012702567735686898,0.012399768534426888,0.012104269117116928,0.011815769908328852,0.011534170713275671,0.01125927137521406,0.010990872047841549,0.010728872691591581,0.010473173266897598,0.010223573927457133,0.009979934664443135,0.009742085123434663,0.009509905784701308,0.009283266340692839,0.009062026937802633,0.008846067590638995,0.008635247979934016,0.008429468687002858,0.008228578992808858,0.008032489335164428,0.007841080116728941,0.007654220564290881,0.007471820999247332,0.007293771370314062,0.007119971909560263,0.00695031233287106,0.006784692755900323,0.006623023150799175,0.0064652135673289495,0.006311163927117984,0.006160784279927611,0.006013984675519168,0.005870695070674022,0.0057308154258256154,0.005594265802452962,0.005460976157337427,0.00533086647434781,0.005203856737352908,0.0050798770583545165,0.0049588473824163275,0.004840697743929923,0.004725378006696701,0.004612798220477998,0.004502898508993288,0.004395628930069506,0.004290908730278413,0.004188692197203636,0.004138195809597771};
              CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452964782715,71.41004053751628,70.57004610697429,69.8157418568929,69.06554285685222,68.31994120279948,67.57924143473308,66.84374109903972,66.11363983154297,65.38923899332683,64.6707394917806,63.95813910166422,63.251538594563804,62.55103778839111,61.856737772623696,61.16863759358724,60.48673788706461,59.811137199401855,59.141636530558266,58.4784361521403,57.82143592834473,57.170535723368324,56.52583535512289,55.887234687805176,55.25473499298096,54.628134409586586,54.00763352711996,53.3930336634318,52.78433354695638,52.1814333597819,51.58433278401693,50.99293168385824,50.407331784566246,49.82733186086019,49.25293159484863,48.68413098653158,48.12083117167155,47.562930742899574,47.01053015391032,46.46352926890055,45.921829541524254,45.38542970021566,44.85432879130045,44.328529040018715,43.80782890319824,43.29222838083903,42.78172810872396,42.27632713317871,41.775827725728355,41.28042729695638,40.78982702891032,40.304226875305176,39.823426246643066,39.347426096598305,38.876125971476235,38.40962632497152,37.94782511393229,37.490625063578285,37.03802458445231,36.59012413024902,36.14662520090739,35.70772393544515,35.27322324117025,34.8432232538859,34.41762351989746,33.99642372131348,33.57952276865641,33.16692320505778,32.75862216949463,32.35462220509847,31.954821427663166,31.559322039286297,31.167921543121338,30.780621369679768,30.397521018981934,30.018520832061768,29.643620491027832,29.272820154825848,28.905920028686523,28.54311990737915,28.184219678243,27.8293194770813,27.47821919123332,27.1311190923055,26.787818908691406,26.448318640391033,26.1127184232076,25.780818303426106,25.45261796315511,25.128117720286053,24.807317574818928,24.49011691411336,24.176517327626545,23.86661720275879,23.5601167678833,23.257216453552246,22.957816282908123,22.661815961201984,22.36931610107422,22.08021593093872,21.79441547393799,21.51201518376668,21.23291524251302,20.957114855448406,20.684614658355713,20.41531467437744,20.14921458562215,19.886314233144123,19.626514434814453,19.36981423695882,19.11621363957723,18.865713755289715,18.618213494618733,18.37371301651001,18.13221311569214,17.89361302057902,17.657912731170654,17.42511256535848,17.195112387339275,16.968012015024822,16.743712425231934,16.522112369537354,16.30331214269002,16.087211688359577,15.873711744944254,15.66301147143046,15.454811414082846,15.249311367670694,15.046311060587565,14.845910787582397,14.648010969161987,14.452510674794516,14.259610652923584,14.06911039352417,13.880910237630209,13.695210218429565,13.511810143788656,13.330809911092123,13.152109702428183,12.975609540939331,12.801409562428793,12.629509290059408,12.459709405899048,12.292109251022339,12.126709143320719,11.963409026463827,11.802208741505941,11.643108606338501,11.486108541488647,11.331008434295654,11.178008238474527,11.027008136113485,10.878008206685385,10.730808019638062,10.585607926050821,10.442307790120443,10.300907611846924,10.161307573318481,10.02360757191976,9.887627363204956,9.753467480341593,9.621067126592001,9.490407148996988,9.361467043558756,9.234226942062378,9.108666817347208,8.984776735305786,8.862506786982218,8.74186666806539,8.62282657623291,8.505366404851278,8.389456272125244,8.27509625752767,8.162256240844727,8.050916194915771,7.94105605284373,7.832665920257568,7.725725809733073,7.620205720265706,7.516105612119039,7.413395643234253,7.312065561612447,7.212085485458374,7.1134553750356035,7.016145348548889,6.920145233472188,6.825425187746684,6.731995066006978,6.639815052350362,6.548874934514363,6.459164937337239,6.370664755503337,6.28336485226949,6.197244644165039,6.112284620602925,6.028474609057109,5.945794502894084,5.86424446105957,5.783794442812602,5.704434355099996,5.62615434328715,5.5489342212677,5.4727641344070435,5.397634069124858,5.323523998260498,5.250423987706502,5.178313930829366,5.107193827629089,5.037033875783284,4.967843810717265,4.899583697319031,4.832263708114624,4.7658636172612505,4.700373609860738,4.635773579279582,4.5720534324646,4.509213407834371,4.447233398755391,4.386103391647339,4.3258033990859985,4.266333222389221,4.207683285077413,4.14983316262563,4.092783093452454,4.036513050397237,3.981013019879659,3.9262830018997192,3.872302989164988,3.819062908490499,3.7665528853734336,3.7147728204727173,3.6636927922566733,3.613332728544871,3.5636526942253113,3.5146626830101013,3.466352621714274,3.4187026023864746,3.371712585290273,3.3253725369771323,3.2796724836031594,3.234612464904785,3.190162420272827,3.146332403024038,3.103102366129557,3.0604723493258157,3.0184322595596313,2.9769622484842935,2.9360722502072654,2.8957422176996865,2.855972190697988,2.816742161909739,2.778062125047048,2.7399120728174844,2.7022820512453714,2.665172040462494,2.628582020600637,2.5924819707870483,2.5568919579188027,2.5217819213867188,2.487151881059011,2.4530118703842163,2.4193318486213684,2.386111835638682,2.3533518314361572,2.321041762828827,2.2891817688941956,2.2577617168426514,2.2267616788546243,2.196191688378652,2.1660516460736594,2.136311630407969,2.1069915890693665,2.0780715942382812,2.0495415329933167,2.021411577860514,1.9936715066432953,1.9663015007972717,1.9393114844957988,1.9126914540926616,1.8864414195219676,1.8605514168739319,1.8350213865439098,1.8098313709100087,1.7849913736184437,1.7605013251304626,1.736331323782603,1.712501307328542,1.6890012820561726,1.665821264187495,1.6429612338542938,1.6204212307929993,1.5981812179088593,1.5762511988480885,1.5546211798985798,1.5332811673482258,1.5122411648432414,1.4914911290009816,1.4710311194260914,1.4508411089579265,1.4309310813744862,1.411301076412201,1.391931066910426,1.3728310366471608,1.353991021712621,1.3354210257530212,1.3170909980932872,1.2990209857622783,1.2812009751796722,1.263620952765147,1.246280958255132,1.2291809221108754,1.2123209337393444,1.1956809063752492,1.1792808969815571,1.1631008783976238,1.147140880425771,1.1314008335272472,1.1158808668454487,1.100570837656657,1.085470825433731,1.070580820242564,1.0558908085028331,1.0414107938607533,1.0271207789580028,1.013030767440796,0.9991347591082255,0.9854277422030767,0.971909741560618,0.9585767289002737,0.9454277207454046,0.9324587086836497,0.9196667025486628,0.907051682472229,0.8946086714665095,0.8823376645644506,0.8702346632877985,0.8582976559797922,0.8465236524740855,0.834912637869517,0.8234606186548868,0.8121656080087026,0.8010256091753641,0.790038600564003,0.7792015920082728,0.7685145884752274,0.7579735765854517,0.7475775728623072,0.7373235573371252,0.7272115598122278,0.7172375520070394,0.7074005454778671,0.6976975252230962,0.6881295293569565,0.6786915212869644,0.6693835059801737,0.6602035015821457,0.6511484930912653,0.6422184904416403,0.6334114770094553,0.6247244874636332,0.6161574671665827,0.6077074706554413,0.5993734548489252,0.5911534527937571,0.5830474495887756,0.5750514368216196,0.5671664327383041,0.5593884289264679,0.5517174154520035,0.5441524187723795,0.5366903940836588,0.5293314109245936,0.5220723897218704,0.5149143934249878,0.5078533838192621,0.5008893758058548,0.4940213809410731,0.48724836856126785,0.480567363401254,0.473978358010451,0.46747935314973194,0.46106934795777005,0.4547483449180921,0.44851334393024445,0.44236333419879276,0.43629834055900574,0.4303163265188535,0.4244173268477122,0.41859831909338635,0.41285931318998337,0.40719931075970334,0.40161630262931186,0.3961113045612971,0.39068029075860977,0.38532429685195285,0.38004227230946225,0.37483231723308563,0.36969422549009323,0.3646263654033343,0.3596271425485611,0.3546974336107572,0.34983505805333454,0.3450404877463977,0.34031002471844357,0.3356454794605573,0.3310440455873807,0.32650741438070935,0.3220311179757118,0.31761733442544937,0.313263180355231,0.30897026757399243,0.3047352110346158,0.3005582392215729,0.2964382196466128,0.29237622519334155,0.28836821268002194,0.28441621859868366,0.28051821142435074,0.27667320768038434,0.27288120488325757,0.26914220054944354,0.2654531995455424,0.2618152052164078,0.2582271794478099,0.25468822320302326,0.2511981427669525,0.2477552555501461,0.24436008806029955,0.24101130540172258,0.23770903423428535,0.23445133740703264,0.23123901337385178,0.2280703249077002,0.22494503979881605,0.22186227391163507,0.2188220868508021,0.21582421908775964,0.21286712462703386,0.2099501813451449,0.2070731446146965,0.20423616096377373,0.20143715043862662,0.1986771523952484,0.19595514858762422,0.19327114522457123,0.19062314306696257,0.1880111445983251,0.18543513988455138,0.1828941417237123,0.18038913359244665,0.17791714270909628,0.17548011988401413,0.17307615404327711,0.17070509244998297,0.16836618011196455,0.1660600540538629,0.16378521546721458,0.161541019876798,0.15932823220888773,0.1571460117896398,0.15499321868022284,0.1528700329363346,0.15077618012825647,0.1487110642095407,0.1466741437713305,0.14466508974631628,0.1426831210652987,0.14072910199562708,0.1388011115292708,0.13690010209878287,0.13502510264515877,0.13317610075076422,0.13135209927956262,0.1295530969897906,0.12777809674541155,0.12602809692422548,0.12430209231873353,0.12260009596745174,0.12092108651995659,0.11926510060826938,0.11763207303980987,0.1160211122284333,0.11443205301960309,0.11286513010660808,0.11131903901696205,0.11055201850831509};
              CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297693729400635,16.274217287699383,16.21771017710368,16.178007920583088,16.132807572682697,16.08280674616496,16.02850580215454,15.970504999160767,15.909404516220093,15.845403909683228,15.778903484344482,15.710403203964233,15.640102704366049,15.568102518717447,15.49490221341451,15.420501867930094,15.345101753870646,15.268901427586874,15.192001263300577,15.114601055781046,15.036600828170776,14.958300987879435,14.879800717035929,14.801000674565634,14.722000678380331,14.64300044377645,14.563900470733643,14.484700361887613,14.405600388844809,14.326600313186646,14.247700293858847,14.168800354003906,14.090100129445394,14.011600176493326,13.933200120925903,13.855100154876709,13.777100086212158,13.699299971262613,13.621800263722738,13.54450011253357,13.467399994532267,13.390599966049194,13.314000050226847,13.23770006497701,13.161700169245401,13.085900068283081,13.01040005683899,12.935200055440268,12.86020016670227,12.785499970118204,12.711099942525228,12.636999924977621,12.563199996948242,12.48959994316101,12.416299978892008,12.343300104141235,12.270599921544393,12.198199987411499,12.126099983851114,12.054199934005737,11.982700030008951,11.911399920781454,11.840400060017904,11.769700129826864,11.699300050735474,11.629200061162313,11.559300104777018,11.489799976348877,11.420499960581461,11.35160001118978,11.282900015513102,11.214499870936075,11.146399895350138,11.078699986139933,11.011200030644735,10.944000085194906,10.877099911371866,10.810499906539917,10.744199911753336,10.678200085957846,10.612600008646647,10.547200123469034,10.482100089391073,10.41729998588562,10.35290002822876,10.288699944814047,10.224799871444702,10.16129986445109,10.097999890645346,10.035099903742472,9.97245987256368,9.91013010342916,9.848100105921427,9.786380132039389,9.724960009256998,9.663849910100302,9.603050152460733,9.542550007502237,9.482360045115152,9.422479947408041,9.362900018692017,9.303629954655966,9.244659980138143,9.186010042826334,9.127649943033854,9.069610039393107,9.01186998685201,8.954439878463745,8.897309939066568,8.840489943822226,8.783969958623251,8.727759917577108,8.671850045522055,8.61624002456665,8.560940027236938,8.505950053532919,8.451249917348227,8.396859963734945,8.342769861221313,8.28896983464559,8.235479911168417,8.182289997736612,8.129400173823038,8.076810042063395,8.02450998624166,7.9725199937820435,7.920809944470723,7.869409998257955,7.818300088246663,7.7674800157547,7.716959913571675,7.666719992955525,7.616780042648315,7.567129929860433,7.51777998606364,7.468700011571248,7.419919967651367,7.371429999669393,7.3232200145721436,7.275290052096049,7.227649966875712,7.180300037066142,7.133219917615254,7.086430033047994,7.039920012156169,6.993680000305176,6.9477299451828,6.902050058046977,6.856649994850159,6.811520020167033,6.766669909159343,6.722090005874634,6.6777799526850385,6.633740067481995,6.589979966481526,6.546479980150859,6.5032399495442705,6.460279981295268,6.417579968770345,6.375139991442363,6.332970023155212,6.291060010592143,6.249400019645691,6.208009998003642,6.166880051294963,6.126000006993611,6.08538003762563,6.045010010401408,6.0049000183741255,5.96504004796346,5.925429979960124,5.8860699733098345,5.846959948539734,5.808090051015218,5.769479910532634,5.7311000029246015,5.69297997156779,5.655089974403381,5.61745007832845,5.580040017763774,5.542880018552144,5.505949974060059,5.469259977340698,5.432810028394063,5.396590034166972,5.360599994659424,5.324839949607849,5.28932003180186,5.2540199756622314,5.218949953715007,5.184110005696614,5.149499972661336,5.115109999974568,5.080940008163452,5.047000050544739,5.013269980748494,4.9797699848810835,4.94647999604543,4.913420001665751,4.880559961001079,4.847930034001668,4.815500020980835,4.783289988835652,4.751290003458659,4.719510038693746,4.687930067380269,4.65654997030894,4.62539001305898,4.594429969787598,4.563669999440511,4.533120036125183,4.502769986788432,4.472620010375977,4.442670027414958,4.4129200379053755,4.383370002110799,4.354010025660197,4.3248500029246015,4.29587999979655,4.267110029856364,4.23851998647054,4.210129936536153,4.181930025418599,4.153909921646118,4.12608007589976,4.098440011342366,4.070990006128947,4.043709993362427,4.016619960467021,3.9897199869155884,3.9629900058110556,3.9364399909973145,3.910069982210795,3.883879999319712,3.857860008875529,3.832020024458567,3.8063599864641824,3.780870000521342,3.755549987157186,3.730400025844574,3.7054199973742166,3.6806100010871887,3.655970056851705,3.6314900120099387,3.6071799794832864,3.5830399990081787,3.5590500036875405,3.535230020682017,3.5115699966748557,3.488070011138916,3.4647200107574463,3.441540022691091,3.4185099999109902,3.3956300218900046,3.372909982999166,3.3503400087356567,3.3279199798901877,3.305649975935618,3.283539970715841,3.2615699966748557,3.2397499879201255,3.2180700302124023,3.1965400179227195,3.175159990787506,3.153919994831085,3.1328200101852417,3.1118600368499756,3.0910500486691794,3.070369998613993,3.0498299996058145,3.0294300317764282,3.0091699759165444,2.9890400171279907,2.9690500100453696,2.949190000693003,2.9294599692026773,2.9098700086275735,2.89040998617808,2.8710699677467346,2.8518700202306113,2.8327999909718833,2.8138500253359475,2.7950299978256226,2.7763400077819824,2.757770001888275,2.739329973856608,2.7210100094477334,2.7028200229008994,2.6847400267918906,2.666790008544922,2.6489499608675637,2.631239970525106,2.613640050093333,2.5961699883143106,2.5788100361824036,2.5615599950154624,2.5444299777348838,2.5274200240770974,2.5105200012524924,2.4937300086021423,2.4770599802335105,2.4604899883270264,2.4440400203069053,2.4277000228563943,2.4114699959754944,2.395340005556742,2.3793299992879233,2.3634199698766074,2.3476199905077615,2.3319199879964194,2.316329995791117,2.3008399605751038,2.2854600151379905,2.2701799869537354,2.2549999753634133,2.2399200002352395,2.2249499758084617,2.2100699742635093,2.1953000028928122,2.180619994799296,2.166040023167928,2.1515600085258484,2.1371800303459167,2.1228899558385215,2.1086999972661338,2.0946000019709268,2.0806000232696533,2.0666900078455606,2.0528799891471863,2.0391499598821006,2.0255200068155923,2.0119799772898355,1.998529980580012,1.9851700166861217,1.9718999962011974,1.9587200085322063,1.9456300139427185,1.9326200087865193,1.9197100102901459,1.9068700075149536,1.8941299815972645,1.8814699947834015,1.8688899874687195,1.8563999931017559,1.8439900080362956,1.8316700160503387,1.8194200098514557,1.807260016600291,1.7951800028483074,1.783189982175827,1.7712700068950653,1.7594299912452698,1.7476700047651927,1.7359899977842967,1.7243900001049042,1.712859978278478,1.701419989267985,1.6900500059127808,1.6787500182787578,1.6675300002098083,1.6563900113105774,1.6453200081984203,1.6343199908733368,1.6233999927838643,1.612550010283788,1.6017799874146779,1.591070016225179,1.5804400146007538,1.5698800086975098,1.5593900084495544,1.548969993988673,1.5386200149854024,1.5283400019009907,1.518119990825653,1.5079799989859264,1.4979000091552734,1.4878899951775868,1.4779499967892964,1.4680800040562947,1.4582699835300446,1.4485199848810832,1.4388499855995178,1.4292300045490265,1.4196799993515015,1.4101999998092651,1.400769978761673,1.3914200166861217,1.3821199933687847,1.3728899955749512,1.363709996143977,1.3546000023682911,1.3455499807993572,1.3365600109100342,1.3276300032933552,1.3187599976857503,1.3099500040213268,1.3011999825636547,1.2925100028514862,1.2838800052801769,1.2752999862035115,1.26678000887235,1.2583199938138325,1.2499100069204967,1.2415600021680195,1.233269989490509,1.2250299950440724,1.2168500125408173,1.2087199886639912,1.2006400028864543,1.1926199793815613,1.1846599976221721,1.176750014225642,1.168889969587326,1.161080002784729,1.1533200045426686,1.1456199983755748,1.1379700005054474,1.1303700109322865,1.1228200097878773,1.1153199871381123,1.107869992653529,1.100469986597697,1.093119998772939,1.0858199993769329,1.078570008277893,1.0713599820931752,1.064210017522176,1.0571000079313915,1.0500399867693584,1.0430299937725067,1.0360699892044067,1.029150019089381,1.022269994020462,1.0154500007629395,1.0086699922879536,1.0019299983978271,0.9952410012483597,0.9885949989159902,0.9819929997126261,0.9754359871149063,0.9689230024814606,0.9624530027310053,0.9560270011425018,0.94964300096035,0.9433029890060425,0.9370040049155554,0.9307480007410049,0.9245339979728063,0.9183609932661057,0.9122290015220642,0.906139001250267,0.9000890105962753,0.8940799931685129,0.888111005226771,0.8821820020675659,0.8762920002142588,0.8704419980446497,0.8646309971809387,0.8588590025901794,0.8531249910593033,0.8474300056695938,0.84177299340566,0.8361530005931854,0.8305720041195551,0.8250269939502081,0.8195200016101202,0.8140499989191691,0.8086160024007162,0.8032179872194926,0.7978570014238358,0.7925310085217158,0.787241001923879,0.7819869865973791,0.7767670055230459,0.7715819925069809,0.7664330005645752,0.7613169948259989,0.7562360068162283,0.7511890033880869,0.7461750010649363,0.7411949982245764,0.7362479964892069,0.731334999203682,0.7264539996782938,0.7216060012578964,0.7191900064547857};
                  CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.46001672744751,8.488823413848877,8.531164169311523,8.575844287872314,8.618184089660645,8.658273935317993,8.696183840433756,8.732013702392578,8.765823523203531,8.797693570454916,8.827693382898966,8.855913162231445,8.8823930422465,8.907202879587809,8.930412848790487,8.952072858810425,8.972252686818441,8.990992546081543,9.008352597554525,9.024392366409302,9.03914213180542,9.05265220006307,9.06499195098877,9.076182047526041,9.08627200126648,9.095301787058512,9.10332179069519,9.110341707865397,9.116421699523926,9.121591647466024,9.125871578852335,9.129311482111612,9.131931384404501,9.133781353632608,9.134861389795939,9.135211308797201,9.134861071904501,9.133851210276285,9.1321812470754,9.129891157150269,9.126991113026937,9.12351099650065,9.119481086730957,9.11491084098816,9.109811067581177,9.104221026102701,9.09816082318624,9.091630776723227,9.08465083440145,9.077250639597574,9.069430748621622,9.061220725377401,9.052620649337769,9.043670574824015,9.034360647201538,9.024710575739542,9.01473061243693,9.004440546035767,8.993840456008911,8.982950448989868,8.971790472666422,8.960350592931112,8.948650439580282,8.936700582504272,8.924500544865927,8.91208028793335,8.89944044748942,8.886580467224121,8.873520294825235,8.860270420710245,8.84682027498881,8.833200295766195,8.819400151570639,8.80543033281962,8.791300217310587,8.77702029546102,8.762600262959799,8.748030265172323,8.73334010442098,8.718520243962606,8.703570206960043,8.688500165939331,8.673330148061117,8.658050139745077,8.642660220464071,8.627170165379843,8.610270102818808,8.592009941736857,8.573760032653809,8.555529912312826,8.537319978078207,8.51911989847819,8.50094985961914,8.482790072758993,8.46465015411377,8.446529944737753,8.428420066833496,8.410339911778768,8.392279863357544,8.374240001042685,8.356210072835287,8.338209867477417,8.32022992769877,8.30226993560791,8.284329891204834,8.266419967015585,8.248519976933798,8.230649948120117,8.212800025939941,8.194979985555014,8.177169879277548,8.15939998626709,8.141639947891235,8.123910029729208,8.106199979782104,8.088519970575968,8.070859988530477,8.053229888280233,8.035620133082071,8.01803994178772,8.00047997633616,7.98294993241628,7.965439995129903,7.947959979375203,7.930509964625041,7.9130799770355225,7.895680030186971,7.878300031026204,7.860960086186727,7.8436399300893145,7.826350013415019,7.809080044428508,7.791850050290425,7.774640043576558,7.757449984550476,7.740299979845683,7.723180015881856,7.706079999605815,7.68900998433431,7.671969930330913,7.654960036277771,7.637979944547017,7.62103005250295,7.6041100025177,7.587210019429524,7.570349931716919,7.553509950637817,7.536709984143575,7.519929965337117,7.503190080324809,7.486470023790996,7.4697900613149,7.4531300862630205,7.43651004632314,7.419910033543904,7.403350035349528,7.386810064315796,7.370309988657634,7.353840033213298,7.337400039037068,7.320979952812195,7.30460000038147,7.288260022799174,7.2719400723775225,7.255649964014689,7.239400068918864,7.223170042037964,7.206979910532634,7.190820097923279,7.174690008163452,7.158590038617452,7.142520030339559,7.126479983329773,7.110480109850566,7.094510038693746,7.078569968541463,7.062659939130147,7.046779990196228,7.030940016110738,7.0151199499766035,6.999340017636617,6.983590046564738,6.967880010604858,6.952189962069194,6.936540007591248,6.920919934908549,6.905330061912537,6.889769951502482,6.874250014623006,6.858749945958455,6.843290050824483,6.827870051066081,6.812470038731893,6.797110040982564,6.781780004501343,6.766480008761088,6.75120997428894,6.735980033874512,6.72078001499176,6.705609997113545,6.690469940503438,6.6753599643707275,6.660290002822876,6.645249962806702,6.630249977111816,6.6152699788411455,6.600330074628194,6.58542005221049,6.570539951324463,6.5557001034418745,6.540879964828491,6.526099960009257,6.511360049247742,6.496640046437581,6.481959939002991,6.467309991518657,6.452690045038859,6.438099980354309,6.423550009727478,6.409030079841614,6.394539952278137,6.380080024401347,6.365659991900126,6.351269960403442,6.336910049120585,6.322580019632976,6.308290044466655,6.294029990832011,6.279800017674764,6.2656000057856245,6.251429994901021,6.237299958864848,6.223200003306071,6.209130009015401,6.195090015729268,6.181090076764424,6.167120019594829,6.153180003166199,6.139270027478536,6.125399947166443,6.111550013224284,6.097740054130554,6.083960056304932,6.070220033327739,6.05650007724762,6.042820016543071,6.029170036315918,6.015549937884013,6.001960039138794,5.988399982452393,5.974869966506958,5.9613800048828125,5.947909951210022,5.93448003133138,5.921069979667664,5.907699942588806,5.894360065460205,5.881039977073669,5.867759982744853,5.854509989420573,5.84128999710083,5.8281000057856245,5.814939975738525,5.801809986432393,5.788709958394368,5.77563997109731,5.762589971224467,5.749579946200053,5.736599961916606,5.723650058110555,5.710719982783,5.697830080986023,5.684960047403972,5.672129988670349,5.659319996833801,5.646539966265361,5.633800029754639,5.6210800011952715,5.608389973640442,5.595719973246257,5.583089987436931,5.570490002632141,5.557910005251567,5.545359929402669,5.53284998734792,5.520349939664205,5.507890025774638,5.495459993680318,5.483050107955933,5.470680038134257,5.458330074946086,5.445999979972839,5.433710018793742,5.4214500188827515,5.409210006395976,5.3970000346501665,5.384810050328572,5.372660080591838,5.3605300188064575,5.348429997762044,5.336360057195027,5.324310024579366,5.312300006548564,5.300309975941976,5.288340012232463,5.276410023371379,5.26449994246165,5.252609968185425,5.240759968757629,5.228929956754048,5.217129945755005,5.205349961916606,5.193609992663066,5.181879957516988,5.1701899766922,5.158520023028056,5.1468799114227295,5.135260025660197,5.123670021692912,5.112109978993733,5.1005699634552,5.089060028394063,5.077570001284282,5.066119988759358,5.0546800295511884,5.043280005455017,5.031889994939168,5.020540038744609,5.009209990501404,4.997899969418843,4.986630082130432,4.975369970003764,4.964149991671245,4.952940026919047,4.94176999727885,4.930609981218974,4.919490019480388,4.908389965693156,4.897310058275859,4.8862599929173784,4.875240008036296,4.8642299969991045,4.853259960810344,4.842310031255086,4.831380009651184,4.820479989051819,4.809599955876668,4.798750003178914,4.787919958432515,4.777119994163513,4.766340017318726,4.755590001742045,4.744859933853149,4.734149972597758,4.7234699328740435,4.712809960047404,4.702179988225301,4.691570003827413,4.68098000685374,4.670419971148173,4.659890015920003,4.649369994799296,4.6388799746831255,4.628419995307922,4.617980043093364,4.607560038566589,4.5971600612004595,4.586790005366008,4.5764399766922,4.566120028495789,4.555820107460022,4.545540014902751,4.535290002822876,4.525049964586894,4.5148499806722,4.50466001033783,4.4945000012715655,4.484359979629517,4.474250038464864,4.464150031407674,4.454079985618591,4.4440300067265825,4.434010028839111,4.424009919166565,4.414030035336812,4.404070019721985,4.394140005111694,4.384229977925618,4.374340057373047,4.3644700447718305,4.354630033175151,4.344799955685933,4.335000038146973,4.325229962666829,4.315470059712728,4.305739998817444,4.296030044555664,4.286339998245239,4.276669939359029,4.267019987106323,4.257399996121724,4.2478000322977705,4.238219976425171,4.228660027186076,4.219120025634766,4.209610025087993,4.200109958648682,4.190640012423198,4.181190053621928,4.1717599630355835,4.162349899609883,4.15296999613444,4.143600026766459,4.134259939193726,4.124930024147034,4.115629990895589,4.1063499848047895,4.097090005874634,4.087850014368693,4.078630010286967,4.069439967473348,4.060259977976481,4.0511099100112915,4.041969935099284,4.0328599611918134,4.023760000864665,4.014690001805623,4.005640029907227,3.9966100255648294,3.9875899950663247,3.9785999854405723,3.969630002975464,3.9606799880663552,3.9517499804496765,3.942840019861857,3.9339500069618225,3.9250800212224326,3.916230022907257,3.9073999722798667,3.898600002129873,3.889810045560201,3.8810399572054544,3.8722899754842124,3.863559981187185,3.8548499941825867,3.8461599946022034,3.8374900221824646,3.828839977582296,3.820200026035309,3.8115899761517844,3.802999993165334,3.7944299777348838,3.7858699560165405,3.7773400147755942,3.76882004737854,3.7603299816449485,3.7518500089645386,3.7433900237083435,3.7349600394566855,3.7265400091807046,3.7181400060653687,3.709760010242462,3.7013999819755554,3.693050046761831,3.6847299933433533,3.676419953505198,3.6681400140126548,3.6598700284957886,3.651620030403137,3.6433899998664856,3.6351799964904785,3.6269899805386863,3.618809978167216,3.610659976800283,3.602519989013672,3.5943999886512756,3.586300015449524,3.578220009803772,3.570149997870127,3.5621099869410195,3.554079989592234,3.5460700194040933,3.5380799770355225,3.530110021432241,3.5221500396728516,3.518179992834727};
    CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0193379720052,514.5848388671875,508.8189392089844,504.26090749104816,499.6509145100911,495.0059127807617,490.33691151936847,485.6559117635091,480.97191365559894,476.29190826416016,471.6219126383464,466.96691131591797,462.3319142659505,457.71891530354816,453.13091532389325,448.5699157714844,444.03892008463544,439.5389149983724,435.0699183146159,430.6349182128906,426.23292032877606,421.8659210205078,417.5329182942708,413.2339172363281,408.9709192911784,404.74292246500653,400.5489196777344,396.3909225463867,392.2669270833333,388.1789245605469,384.1249262491862,380.10492451985675,376.1199264526367,372.1689224243164,368.2519251505534,364.367925008138,360.5179265340169,356.7019297281901,352.91793060302734,349.1679331461589,345.4499282836914,341.76393636067706,338.1109339396159,334.49093373616535,330.90093485514325,327.3439305623372,323.81793212890625,320.3229344685872,316.8589375813802,313.42593638102215,310.02293904622394,306.6499379475911,303.3079350789388,299.99493408203125,296.7119394938151,293.4589360555013,290.2349344889323,287.0389353434245,283.87294006347656,280.73494720458984,277.6259409586589,274.5449447631836,271.491943359375,268.4669443766276,265.4699452718099,262.4999465942383,259.55794525146484,256.64294687906903,253.75494511922201,250.89395014444986,248.0599505106608,245.25294876098633,242.4729487101237,239.7189483642578,236.99094772338867,234.2899513244629,231.61395009358725,228.96495056152344,226.3419507344564,223.74394734700522,221.1719512939453,218.62495295206705,216.10295232137045,213.60695266723633,211.13495254516602,208.6889533996582,206.2669563293457,203.86995569864908,201.49695841471353,199.14795557657877,196.82395680745444,194.52295684814453,192.2449582417806,189.9909578959147,187.75995890299478,185.5529581705729,183.3679567972819,181.20596313476562,179.06695938110352,176.9499600728353,174.85496139526367,172.7829615275065,170.73296101888022,168.70496241251627,166.6979611714681,164.7129643758138,162.74896240234375,160.80596288045248,158.8849639892578,156.9839655558268,155.10396321614584,153.24396514892578,151.40496571858725,149.58596547444662,147.78696568806967,146.00796763102213,144.2479680379232,142.5079663594564,140.78796895345053,139.08596801757812,137.40397008260092,135.7399698893229,134.09496943155924,132.46896998087564,130.86096954345703,129.2709706624349,127.69897015889485,126.14497184753418,124.60897127787273,123.0899715423584,121.58797264099121,120.10397211710612,118.63697179158528,117.18597348531087,115.75197283426921,114.33497428894043,112.93397331237793,111.5499750773112,110.18097559611003,108.82797559102376,107.49097506205241,106.16997464497884,104.86397552490234,103.57297643025716,102.29797681172688,101.03697649637859,99.791077931722,98.559876759847,97.34317715962727,96.14077822367351,94.95267740885417,93.77857844034831,92.61847813924153,91.47207768758138,90.33927981058757,89.21997896830241,88.11397933959961,87.02117983500163,85.94147936503093,84.87468020121257,83.82058080037434,82.7791805267334,81.75028165181477,80.73368072509766,79.72938092549641,78.73708089192708,77.75688298543294,76.78838221232097,75.83168284098308,74.88648287455241,73.9527816772461,73.03038279215495,72.1191832224528,71.2189826965332,70.32978439331055,69.45138359069824,68.5836836496989,67.72658348083496,66.87988408406575,66.04358418782552,65.21748542785645,64.40148480733235,63.59548568725586,62.79938570658366,62.013086001078285,61.236385663350426,60.46918551127116,59.71148554484049,58.96308581034342,58.223886489868164,57.49378617604574,56.77278677622477,56.06058692932129,55.35718695322672,54.66258684794108,53.976487477620445,53.29888788859049,52.62968762715658,51.96878751118978,51.3159875869751,50.671387672424316,50.03478844960531,49.406088511149086,48.78528849283854,48.172088623046875,47.56658935546875,46.968588511149086,46.37808895111084,45.79488945007324,45.21898969014486,44.65028953552246,44.08868948618571,43.53408972422282,42.986489613850914,42.445689837137856,41.91168975830078,41.384290059407554,40.86359055836996,40.34939034779867,39.84169101715088,39.340291023254395,38.84519068400065,38.35629145304362,37.87359142303467,37.396891276041664,36.92629146575928,36.46149190266927,36.00259145100912,35.54949156443278,35.102091789245605,34.66029167175293,34.22409184773763,33.793392499287926,33.36819267272949,32.94829177856445,32.53369267781576,32.12429221471151,31.720092455546062,31.320992469787598,30.926992734273274,30.53799279530843,30.153892676035564,29.774593035380047,29.400193373362224,29.03039312362671,28.665393193562824,28.304893334706623,27.94899336496989,27.597593307495117,27.250593344370525,26.90799363454183,26.56969388326009,26.23569377263387,25.905893961588543,25.580293973286945,25.25869385401408,24.941194375356037,24.627693970998127,24.31819438934326,24.0125945409139,23.71079428990682,23.412794431050617,23.118494828542072,22.82799466451009,22.54109462102254,22.25789467493693,21.97819455464681,21.701994736989338,21.42929490407308,21.159995079040527,20.89409526189168,20.631594975789387,20.37229522069295,20.116395155588787,19.863595326741535,19.613995393117268,19.367595354715984,19.124295393625896,18.88399585088094,18.646695454915363,18.412495613098145,18.181195894877117,17.952695846557617,17.727195898691814,17.504495938618977,17.28459596633911,17.067495981852215,16.85299603144328,16.641296068827312,16.43229627609253,16.225896040598553,16.02199625968933,15.820796171824137,15.621996323267618,15.425796349843344,15.231996536254883,15.040696541468302,14.851796388626099,14.665196498235067,14.48099652926127,14.299096504847208,14.119496583938599,13.94219676653544,13.767096678415934,13.594096740086874,13.423396825790405,13.254796822865805,13.088296890258789,12.9238969484965,12.761597077051798,12.60129714012146,12.44309687614441,12.286797126134237,12.132497151692709,11.980097134908041,11.829697132110596,11.681097189585367,11.53439736366272,11.389597336451212,11.24649747212728,11.105297327041626,10.965797265370687,10.828097422917685,10.692097504933676,10.557897408803305,10.425297498703003,10.294397354125977,10.165097713470459,10.037497599919638,9.911417643229166,9.786957661310831,9.66406766573588,9.542717774709066,9.422897815704346,9.304577747980753,9.187747875849405,9.072377840677897,8.958467960357666,8.845988035202026,8.734917958577475,8.625247955322266,8.516947905222574,8.41000803311666,8.304418007532755,8.2001580397288,8.097198088963827,7.995538115501404,7.895158171653748,7.7960381507873535,7.698158224423726,7.601508180300395,7.506078243255615,7.411848386128743,7.318798224131267,7.226918299992879,7.136188268661499,7.046598235766093,6.958138386408488,6.870788375536601,6.784538348515828,6.699368437131246,6.6152684688568115,6.532228430112203,6.450228412946065,6.369258483250936,6.289308547973633,6.210358579953511,6.132408618927002,6.055428584416707,5.979418595631917,5.904368599255879,5.830258687337239,5.757078607877095,5.684818665186564,5.613458712895711,5.543008764584859,5.47342864672343,5.404728690783183,5.336898763974507,5.26991871992747,5.203778783480327,5.138458808263143,5.073968807856242,5.010288834571838,4.94740875562032,4.885318835576375,4.824008822441101,4.763468821843465,4.703688979148865,4.644658883412679,4.586368958155314,4.528818925221761,4.471989035606384,4.415868918100993,4.360448996225993,4.305729031562805,4.251699010531108,4.198349038759868,4.145669023195903,4.0936490297317505,4.042279084523519,3.991559088230133,3.941469053427378,3.8920190731684365,3.8431791067123413,3.794959088166555,3.747339129447937,3.7003291646639505,3.6538991133371987,3.608049134413401,3.562779168287913,3.518079141775767,3.473949213822683,3.430359184741974,3.3873191674550376,3.344829241434733,3.3028592069943747,3.261429230372111,3.2205092310905457,3.1801092425982156,3.1402092774709067,3.1008192896842957,3.0619192918141684,3.0235092639923096,2.9855793118476868,2.948129336039225,2.911149322986603,2.874629318714142,2.8385693430900574,2.8029593427975974,2.767799357573191,2.733089327812195,2.6987993518511453,2.664949377377828,2.631529370943705,2.5985193848609924,2.565929392973582,2.533739427725474,2.5019594033559165,2.470579445362091,2.439599414666494,2.408999482790629,2.3787894447644553,2.348949432373047,2.3194894591967263,2.290399452050527,2.261679470539093,2.2333194812138877,2.205309510231018,2.17764945824941,2.1503394842147827,2.1233795086542764,2.096749504407247,2.070459524790446,2.0444895227750144,2.0188595056533813,1.9935395022233326,1.968539535999298,1.9438595473766327,1.9194795489311218,1.89541956782341,1.8716495633125305,1.848179558912913,1.8250095744927723,1.8021295666694641,1.779529591401418,1.7572195827960968,1.7351895968119304,1.713429590066274,1.6919495860735576,1.6707396010557811,1.6497896015644073,1.629109611113866,1.6086796124776204,1.5885196228822072,1.5685996214548747,1.5489396552244823,1.5295196374257405,1.5103496313095093,1.4914096494515736,1.4727196494738262,1.4542596538861592,1.4360296626885731,1.418029636144638,1.4002498785654705,1.391419808069865};
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.921801249186196,40.04995632171631,40.46423053741455,38.038174629211426,39.769005139668785,41.53858884175619,43.307186126708984,44.59110164642334,45.3348274230957,46.0315637588501,46.725084940592446,47.418113708496094,48.11131604512533,48.8043212890625,49.49780591328939,50.19013754526774,50.8848606745402,51.31473859151205,51.4511022567749,51.5616782506307,51.67065175374349,51.779258728027344,51.88789812723795,51.99674574534098,52.10500685373942,52.214497884114586,52.321300188700356,52.74649143218994,53.524393717447914,54.33369445800781,55.14483070373535,55.95638783772787,56.767760594685875,57.57929039001465,58.39071877797445,59.20231533050537,60.013272285461426,60.920759518941246,61.935118993123375,62.95908260345459,63.98350874582926,65.00803820292155,66.03261915842693,67.05724302927653,68.08168697357178,69.10646152496338,70.13039461771648,71.26529534657796,72.52310498555501,73.79204495747884,75.0613244374593,76.33097648620605,77.60045560201009,78.87004979451497,80.13961219787598,81.40885798136394,82.67943382263184,83.73664410909016,84.55738004048665,85.35653877258301,86.15505472819011,86.95288721720378,87.7509822845459,88.54891586303711,89.3470090230306,90.14469782511394,90.94407272338867,91.40321095784505,91.48414421081543,91.5306905110677,91.57643063863118,91.62083498636882,91.6658878326416,91.71042442321777,91.75534121195476,91.79999732971191,91.84526189168294,91.76981353759766,91.56004524230957,91.33799743652344,91.11576588948567,90.89297358194987,90.67051442464192,90.44780667622884,90.22529792785645,90.00241088867188,89.78053538004558,89.41067949930827,88.87572733561198,88.32671546936035,87.77652359008789,87.22632280985515,86.67612266540527,86.12592379252116,85.5756238301595,85.02542304992676,84.47522481282552,83.92492357889812,83.37472279866536,82.82452456156413,82.27422523498535,81.72402381896973,81.17382494608562,80.62352498372395,80.07332293192546,79.52312660217285,78.97282473246257,78.42262522379558,77.87242444356282,77.32222557067871,76.77192560831706,76.22172355651855,75.67152659098308,75.12122408548991,74.57102521260579,74.02082633972168,73.47052637736003,72.92032432556152,72.37012736002605,71.81982549031575,71.26962534586589,70.71942615509033,70.16922760009766,69.61892573038737,69.0687255859375,68.51852671305339,67.96822770436604,67.4180253346761,66.86782741546631,66.31752808888753,65.76732508341472,65.2171277999878,64.6668275197347,64.11662673950195,63.56642691294352,63.01622740427653,62.46592744191488,61.91572634379069,61.36552810668945,60.81522878011068,60.26502672831217,59.71482880910238,59.16452852884928,58.61432679494222,58.06412919362386,57.513828913370766,56.96362717946371,56.413428942362465,55.86312929789225,55.31292724609375,54.76272741953532,54.21252918243408,53.66222953796387,53.1120278040568,52.561829249064125,52.01152992248535,51.46132755279541,50.91112963358561,50.360829989115395,49.810627937316895,49.26042970021566,48.710130055745445,48.15992832183838,47.60972881317139,47.05952994028727,46.50923093159994,45.959028244018555,45.40883096059164,44.858530362447105,44.308329582214355,43.75813007354736,43.207831064860024,42.65762869517008,42.10743045806885,41.55713144938151,41.00693003336588,40.45673147837321,39.90643119812012,39.35622978210449,38.80603059132894,38.25583012898763,37.705532709757485,37.15532906850179,36.60513178507487,36.05483214060465,35.50463008880615,34.954432328542076,34.40413236618042,33.85392967859904,33.30373350779215,32.75343179702759,32.203232288360596,31.65303103129069,31.102832476298016,30.5525328318278,30.002331097920734,29.452133337656658,28.901833216349285,28.35163116455078,27.801433563232422,27.25113344192505,26.700931708017986,26.150733788808186,25.600433349609375,25.05023193359375,24.50003417332967,23.9497332572937,23.39953327178955,22.849332173665363,22.299134254455566,21.748834133148193,21.198632558186848,20.648434162139893,20.098134358723957,19.547932783762615,18.997734705607098,18.447434584299724,17.897233088811237,17.34703493118286,16.796734650929768,16.24653395016988,15.696333726247152,15.146135091781616,14.595835288365683,14.045633554458618,13.4954354763031,12.945135275522867,12.394934018452963,11.844735225041708,11.294436693191528,10.744231621424357,10.194042603174845,9.643756866455078,9.093595345815023,8.543180187543234,7.9934572378794355,7.441829323768616,7.139447728792827,7.1130936940511065,7.111517469088237,7.111156662305196,7.111219922701518,7.111190438270569,7.111202359199524,7.111197431882222,7.111199577649434,7.111198663711548,7.1111990213394165,7.111198862393697,7.111198862393697,7.111198981602986,7.111198941866557,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666959961255391,6.884193738301595,6.611398379007976,6.670585473378499,6.738316655158997,6.807626525561015,6.8766385316848755,6.897372682889302,6.857054948806763,6.800275444984436,6.739274064699809,6.677373329798381,6.615452170372009,6.553711573282878,6.4921800295511884,6.430840611457825,6.369686206181844,6.315890431404114,6.271610657374064,6.230319817860921,6.190179149309794,6.150618513425191,6.111427823702495,6.072507540384929,6.0337962706883745,5.995237270991008,5.956782420476277,5.92673647403717,5.90719719727834,5.8902667760849,5.873796701431274,5.857176423072815,5.840256253878276,5.822985967000325,5.805375814437866,5.787425716718038,5.769155025482178,5.751474499702454,5.734394669532776,5.716914653778076,5.6988247235616045,5.680104653040568,5.660784641901652,5.640924612681071,5.620564421017964,5.599764943122864,5.578543027242024,5.560380856196086,5.546241124471028,5.5329908927281695,5.519771059354146,5.50636084874471,5.49272088209788,5.478840788205464,5.46475072701772,5.450450857480367,5.435979803403218,5.423238595326741,5.412688692410787,5.402508775393168,5.392198801040649,5.38166876633962,5.370888749758403,5.359888752301534,5.3486787875493365,5.337288657824199,5.325738906860352,5.313319206237793,5.299809217453003,5.285819053649902,5.271548946698506,5.257068832715352,5.242418805758159,5.22761869430542,5.212688446044922,5.197648684183757,5.182516813278198,5.1714640855789185,5.165714104970296,5.16150426864624,5.157804091771443,5.154354095458984,5.151074051856995,5.147924025853475,5.144903937975566,5.1420137484868365,5.139214833577474,5.134126464525859,5.126096089680989,5.117306192715962,5.108376065889995,5.099486033121745,5.090665936470032,5.081945935885112,5.0733158985773725,5.064805865287781,5.05638575553894,5.048075755437215,5.039865732192993,5.031755646069844,5.023745616277059,5.015835523605347,5.008025447527568,5.000315388043721,4.992705424626668,4.985195318857829,4.977765321731567,4.97043518225352,4.963205138842265,4.956055084864299,4.948995073636373,4.942025065422058,4.935134967168172,4.928334991137187,4.92161492506663,4.914974848429362,4.908424774805705,4.901944716771443,4.895534714063008,4.889214634895325,4.8829545974731445,4.876774549484253,4.870664556821187,4.864624540011088,4.858654459317525,4.852754473686218,4.8469144105911255,4.841144283612569,4.835434317588806,4.829784274101257,4.824194272359212,4.818664113680522,4.8132041692733765,4.807784120241801,4.802434086799622,4.797134041786194,4.791884024937947,4.786684036254883,4.781543930371602,4.776453971862793,4.771403908729553,4.7664138078689575,4.76146384080251,4.756563822428386,4.75170377890269,4.746893723805745,4.742123643557231,4.737393657366435,4.73271365960439,4.728063623110454,4.723463614781697,4.718893567721049,4.714373588562012,4.709883530934651,4.705423474311829,4.701013445854187,4.69662344455719,4.692273338635762,4.687963406244914,4.683683355649312,4.679433266321818,4.675213257471721,4.67102324962616,4.666863123575847,4.662733197212219,4.658623178799947,4.654553174972534,4.650503118832906,4.646483143170674,4.642483154932658,4.638513008753459,4.634563048680623,4.630643010139465,4.626743038495381,4.622862815856934,4.619012951850891,4.615172902743022,4.611362894376119,4.607572873433431,4.603792866071065,4.600042819976807,4.596302787462871,4.592592716217041,4.588892738024394,4.585202693939209,4.581542770067851,4.577892740567525,4.574262698491414,4.570642630259196,4.56703261534373,4.563442587852478,4.559872547785441,4.556302507718404,4.552752534548442,4.549212574958801,4.545692563056946,4.54217251141866,4.53867244720459,4.535172422726949,4.531692465146382,4.528212388356526,4.5247524579366045,4.521292328834534,4.517842332522075,4.514402270317078,4.510972340901692,4.507542332013448,4.504122296969096,4.500712275505066,4.497302134831746,4.493902246157329,4.490502238273621,4.487112283706665,4.48372217019399,4.480342189470927,4.476962169011434,4.473592122395833,4.47021206219991,4.46684209505717,4.463472008705139,4.46011209487915,4.45674196879069,4.4533820152282715,4.4500120878219604,4.446651975313823,4.443291982014974,4.439921935399373,4.436562021573384,4.433201909065247,4.429831902186076,4.426461935043335,4.423091888427734,4.419721881548564,4.416351834932963,4.41297189394633,4.409581740697225,4.406211813290914,4.402761896451314,4.399351716041565,4.396201570828755,4.393321593602498,4.3907014926274615,4.388321359952291,4.386151313781738,4.38417116800944,4.382371187210083,4.380721131960551,4.379231095314026,4.377861022949219,4.376610994338989,4.3754609028498335,4.374421040217082,4.373450875282288,4.372570951779683,4.3717509508132935,4.37100084622701,4.370310823122661,4.3696707884470625,4.369070808092753,4.3685208559036255,4.368000785509746,4.367520769437154,4.36707071463267,4.366650780042012,4.366250832875569,4.365870753924052,4.365510781606038,4.36517071723938,4.364840745925903,4.364530722300212,4.364230672518413,4.363950729370117,4.3636707464853925,4.36340069770813,4.36314074198405,4.362890720367432,4.362650632858276,4.362410704294841,4.362180709838867,4.361950715382894,4.361730734507243,4.361510713895162,4.361290733019511,4.361080765724182,4.360870718955994,4.360660711924235,4.360450665156047,4.36025067170461,4.360050598780314,4.359850684801738,4.359650691350301,4.359460711479187,4.359260638554891,4.359070698420207,4.35887070496877,4.358680685361226,4.358490705490112,4.358300646146138,4.358110745747884,4.357920686403911,4.357730706532796,4.357550740242004,4.3573607206344604,4.357170780499776,4.356990694999695,4.356800635655721,4.356620669364929,4.356430689493815,4.356250723203023,4.356070677439372,4.355880697568257,4.355700651804606,4.355520685513814,4.355340639750163,4.355160673459371,4.354980667432149,4.354800621668498,4.354620695114136,4.354440689086914,4.354260683059692,4.354080677032471,4.353910724322001,4.353770613670349,4.353720545768738,4.35373055934906,4.353750546773274,4.353780627250671,4.353810588518779,4.353840589523315,4.35386061668396,4.353890617688497,4.353920618693034,4.353950540224711,4.353980580965678,4.354010661443074,4.354040662447612,4.354060610135396,4.354090531667073,4.35412061214447,4.354150613149007,4.354180574417114,4.354210535685222,4.354240536689758,4.354270577430725,4.354300578435262,4.354330579439799,4.354360580444336,4.354390700658162,4.354420622189839,4.354450543721517,4.354480544726054,4.354510585467021,4.3545405467351275,4.354570666948955,4.354600667953491,4.3546305894851685,4.354660590489705,4.354690631230672,4.354720632235209,4.354750593503316,4.3547805945078535,4.354810516039531,4.3548405567804975,4.354870597521464,4.354900598526001,4.3549405336380005,4.354970534642537,4.355000575383504,4.3550305763880415,4.355060617129008,4.355090618133545,4.355130592981975,4.355160633722941,4.355190555254619,4.355220595995585,4.355260570844014,4.355290611584981,4.3553206125895185,4.355360627174377,4.355390548706055,4.355420549710591,4.355450630187988,4.355490565299988,4.355520645777385,4.355550646781921,4.355590621630351,4.3556205828984575,4.355660597483317,4.355690558751424,4.355720678965251,4.3557606140772505,4.355790615081787,4.355830589930217,4.355860551198323,4.355890512466431,4.35593060652415,4.355960567792256,4.356000582377116,4.356030543645223,4.3560705582300825,4.3561006387074785,4.356140653292338,4.356180588404338,4.356210549672444,4.356250564257304,4.356280565261841,4.35632061958313,4.356350580851237,4.356390635172526,4.356430570284526,4.356460531552632,4.356500625610352,4.356540600458781,4.356570601463318,4.356610655784607,4.356650551160176,4.356680591901143,4.356720566749573,4.356760581334432,4.356790542602539,4.356830636660258,4.356870611508687,4.356900572776794,4.356940587361653,4.356980522473653,4.357020537058513,4.357060631116231,4.357090552647908,4.357130567232768,4.357170542081197,4.357210675875346,4.357250610987346,4.357290665308635,4.357320626576741,4.3573605219523115,4.35740065574646,4.35744063059489,4.357480486234029,4.357520620028178,4.357550660769145,4.3575905958811445,4.357630610466003,4.357670625050862,4.357710639635722,4.357750574747722,4.35779054959615,4.3578306039174395,4.357870618502299,4.357910633087158,4.357950647672017,4.357990662256877,4.358030676841736,4.358070691426595,4.358110626538594,4.358150641123454,4.358190576235454,4.358230630556743,4.358270605405171,4.358310619990031,4.35835059483846,4.35839056968689,4.358430544535319,4.358470638593038,4.358510573705037,4.358550628026326,4.358590642611186,4.358640591303508,4.358670552571614,4.358720620473226,4.358760595321655,4.358800649642944,4.358840584754944,4.358880599339803,4.358920574188232,4.358960549036662,4.359010616938273,4.359050631523132,4.359090646107991,4.3591305414835615,4.359170595804851,4.3592106103897095,4.359250624974568,4.35930061340332,4.35934058825175,4.359380602836609,4.359400590260823};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.221917510032654,2.6039249698321023,2.035767694314321,1.6531196335951488,1.3419270316759746,1.0884828368822734,0.8824478884538015,0.7149915099143982,0.5791768083969752,0.4690255895256996,0.37973958253860474,0.30738162994384766,0.24876217792431513,0.20128185426195463,0.16283509383598962,0.13170815693835417,0.10651419684290886,0.08612138964235783,0.06962080672383308,0.05626651054869095,0.045472879273196064,0.03673645947128534,0.02968434849753976,0.02397304183493058,0.019368877944846947,0.01563810541604956,0.01263267508087059,0.010200674723212918,0.008245481721435985,0.00666543278687944,0.005392482232612868,0.004363598961693545,0.0035330652414510646,0.0028615258246039352,0.002318641054444015,0.001879386856065442,0.0015239065687637776,0.00123583382810466,0.0010021136889311795,0.0008124540715167919,0.0006585547574407732,0.0005336578882027728,0.00043233858013991266,0.0003501082877240454,0.0002834543095862803,0.00022934574129370353,0.00018554625542795597,0.00014999537476493666,0.00012129408241889905,4.5473471497340746e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8335927327474,563.0186208089193,558.8313802083334,562.6688181559244,565.9638010660807,568.9905700683594,571.8706410725912,572.6819101969401,570.8572896321615,568.2361958821615,565.3954772949219,562.5115000406901,559.6344350179037,556.7764027913412,553.9392649332682,551.1203816731771,548.3189697265625,545.8007049560547,543.6679433186849,541.6956736246744,539.8054860432943,537.9693654378256,536.1712392171224,534.4032185872396,532.6570434570312,530.9283091227213,529.2105102539062,528.0659942626953,527.658701578776,527.4585520426432,527.2955271402994,527.1186014811198,526.9127044677734,526.6708119710287,526.3929341634115,526.0799942016602,525.7342325846354,525.23388671875,524.5144195556641,523.662701924642,522.7119750976562,521.6771977742513,520.5693969726562,519.3945922851562,518.1597340901693,516.8699747721354,515.5288213094076,514.3838907877604,513.5143814086914,512.7074203491211,511.89644622802734,511.0615463256836,510.19761912027997,509.3047154744466,508.3857701619466,507.44187927246094,506.4748026529948,505.6093292236328,504.8781026204427,504.1611862182617,503.4232432047526,502.6563466389974,501.8604202270508,501.0365041097005,500.1875686645508,499.3156458536784,498.42365010579425,497.55950419108075,496.7324574788411,495.8975346883138,495.04058837890625,494.1616617838542,493.261713663737,492.34376271565753,491.40880330403644,490.4598693847656,489.49874623616535,488.7069320678711,488.15144602457684,487.6833801269531,487.2532424926758,486.84622955322266,486.45814514160156,486.0871175130208,485.73106638590497,485.38990529378253,485.061279296875,484.37304941813153,483.2087758382161,481.9049479166667,480.5669759114583,479.22696177164715,477.8959274291992,476.577885945638,475.2728500366211,473.98180389404297,472.7047627766927,471.4417215983073,470.19268798828125,468.9566421508789,467.73460642496747,466.5255635579427,465.3305257161458,464.1474889119466,462.9774525960286,461.8204116821289,460.67638142903644,459.54334259033203,458.42330678304035,457.3152720133464,456.2182388305664,455.13220469156903,454.0581741333008,452.9951477050781,451.9421157836914,450.90008036295575,449.8690490722656,448.8480224609375,447.8359909057617,446.83496348063153,445.84293874104816,444.8599166870117,443.8858820597331,442.9218495686849,441.9668273925781,441.01980845133465,440.0807825724284,439.15075429280597,438.2287343343099,437.31470998128253,436.40868377685547,435.5106658935547,434.61964416503906,433.7356262207031,432.8585968017578,431.9895833333333,431.1265614827474,430.27054087320965,429.42152913411456,428.57850646972656,427.74248758951825,426.9114685058594,426.0874557495117,425.2684326171875,424.4564158121745,423.64940134684247,422.8473815917969,422.0513636271159,421.26135508219403,420.475336710612,419.695317586263,418.92030843098956,418.14929453531903,417.38427734375,416.62227121988934,415.8662465413411,415.11424763997394,414.36622365315753,413.6232147216797,412.8842010498047,412.1491978963216,411.4181823730469,410.69116973876953,409.96716054280597,409.2481460571289,408.53213755289715,407.82012430826825,407.11111704508465,406.40510813395184,405.70309193929035,405.00408935546875,404.3080749511719,403.61606852213544,402.92606353759766,402.2390543619792,401.55604298909503,400.87503306070965,400.19702402750653,399.5210215250651,398.84800720214844,398.1780064900716,397.50998942057294,396.8449885050456,396.1819839477539,395.52098083496094,394.8629633585612,394.20696512858075,393.5519536336263,392.8999506632487,392.2499415079753,391.60193888346356,390.9559275309245,390.3119303385417,389.6689224243164,389.0289128621419,388.3899205525716,387.75189717610675,387.11691029866535,386.48189544677734,385.84989674886066,385.21788787841797,384.58888244628906,383.9598795572917,383.3328806559245,382.70687611897785,382.0818786621094,381.45786539713544,380.8358688354492,380.2138671875,379.59385172526044,378.974858601888,378.3558527628581,377.7388559977214,377.12184651692706,376.50684356689453,375.891840616862,375.27784220377606,374.6638412475586,374.0508397420247,373.43883260091144,372.8278350830078,372.21682993570965,371.60682678222656,370.996826171875,370.38782501220703,369.77882893880206,369.1698252360026,368.5618209838867,367.9538218180339,367.34582265218097,366.7388178507487,366.13182322184247,365.5248209635417,364.9178212483724,364.31081136067706,363.70384724934894,363.0987269083659,362.5843276977539,362.19605509440106,361.8649597167969,361.56885782877606,361.30078379313153,361.0577214558919,360.8356577555339,360.6346028645833,360.45055389404297,360.28350830078125,360.1304753621419,359.9914296468099,359.86440022786456,359.7473729451497,359.6403401692708,359.5423177083333,359.4522933959961,359.36927795410156,359.2932586669922,359.2232437133789,359.15722910563153,359.0972162882487,359.0402069091797,358.9881896972656,358.93918863932294,358.89317321777344,358.8501688639323,358.8091583251953,358.7711537679036,358.7341537475586,358.69913991292316,358.66613515218097,358.6351318359375,358.6051330566406,358.57513427734375,358.547119140625,358.52012125651044,358.4941228230794,358.46911875406903,358.4441197713216,358.42011006673175,358.39611053466797,358.37310791015625,358.35011291503906,358.3281071980794,358.30610911051434,358.2841059366862,358.26310475667316,358.2421112060547,358.2210973103841,358.20110575358075,358.1801045735677,358.1601079305013,358.14009857177734,358.120112101237,358.10009511311847,358.0811004638672,358.06110127766925,358.04210408528644,358.0220998128255,358.0030975341797,357.98409779866535,357.96509806315106,357.9461034138997,357.9271011352539,357.9080988566081,357.88909403483075,357.87009684244794,357.85109456380206,357.83309682210285,357.81410217285156,357.7950973510742,357.77709706624347,357.75809478759766,357.74009195963544,357.7221043904622,357.7031021118164,357.68509165445965,357.6670964558919,357.6480967203776,357.6300964355469,357.61209869384766,357.5940984090169,357.5760955810547,357.55809529622394,357.5440724690755,357.53904724121094,357.5390396118164,357.5420405069987,357.5440368652344,357.54703521728516,357.55003865559894,357.5530370076497,357.55603790283203,357.5580418904622,357.56103769938153,357.5640360514323,357.5670344034831,357.5700378417969,357.5730387369792,357.57603708902997,357.5780309041341,357.58103434244794,357.58404032389325,357.58703358968097,357.5900344848633,357.59303283691406,357.59603118896484,357.59903717041016,357.60203552246094,357.6050313313802,357.60803476969403,357.6110382080078,357.6140391031901,357.6170374552409,357.62003835042316,357.62303924560547,357.6260350545247,357.6290334065755,357.63203684488934,357.6350351969401,357.6380310058594,357.6410369873047,357.64404042561847,357.64703877766925,357.65003204345703,357.6540298461914,357.6570358276367,357.66003672281903,357.6630376180013,357.6660334269206,357.6690317789714,357.67302958170575,357.67603810628253,357.6790364583333,357.6820373535156,357.6850331624349,357.68903096516925,357.6920445760091,357.69503529866535,357.69903564453125,357.70203653971356,357.7050374348958,357.7080332438151,357.71203358968097,357.7150395711263,357.71803283691406,357.72203572591144,357.72504170735675,357.728032430013,357.73204294840497,357.7350311279297,357.73902893066406,357.7420399983724,357.7450307210286,357.74903869628906,357.7520345052083,357.75603739420575,357.759028116862,357.7630386352539,357.7660268147786,357.77003987630206,357.77302805582684,357.77703348795575,357.780029296875,357.7840347290039,357.7870330810547,357.79103088378906,357.79503631591797,357.79802958170575,357.80203501383465,357.80503336588544,357.8090286254883,357.8130391438802,357.81603240966797,357.8200327555339,357.8230336507161,357.82703399658203,357.8310292561849,357.8350346883138,357.8380304972331,357.84203084309894,357.8460413614909,357.8490346272786,357.85303497314453,357.8570327758789,357.8610331217448,357.8640365600586,357.86803181966144,357.87203216552734,357.87603251139325,357.8800328572591,357.8830337524414,357.88702901204425,357.8910319010417,357.89503479003906,357.8990300496419,357.90303293863934,357.90603892008465,357.9100290934245,357.9140345255534,357.9180272420247,357.9220326741536,357.92603302001953,357.9300359090169,357.9330342610677,357.93703206380206,357.94102986653644,357.9450327555339,357.9490331013997,357.9530309041341,357.95702870686847,357.9610341389974,357.9650344848633,357.9690348307292,357.97303263346356,357.9770329793294,357.9810333251953,357.9850260416667,357.98903401692706,357.99303181966144,357.99703725179035,358.00103251139325,358.0050328572591,358.009033203125,358.01403045654297,358.0180358886719,358.02203369140625,358.0260314941406,358.03002675374347,358.0340321858724,358.0380350748698,358.0420277913411,358.04603322347003,358.0500310262044,358.0540313720703,358.0580317179362,358.0630289713542,358.0670344034831,358.07102457682294,358.0750376383464,358.0790278116862,358.0840250651042,358.0880355834961,358.09202829996747,358.0960337320964,358.10003153483075,358.1040318806966,358.10704040527344};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.448221604029337,9.76348908742269,10.082427342732748,9.470434983571371,9.677613894144693,9.890563090642294,10.103607098261515,10.147454420725504,10.007437149683634,9.852039098739624,9.695418357849121,9.538686990737915,9.381955782572428,9.225218534469604,9.068472782770792,8.911743640899658,8.754984855651855,8.624040762583414,8.521163860956827,8.42063037554423,8.32027781009674,8.219948569933573,8.119617899258932,8.019288897514343,7.918956359227498,7.818641901016235,7.718300819396973,7.634521126747131,7.568739175796509,7.504464824994405,7.440312465031941,7.376173297564189,7.312022844950358,7.247883200645447,7.183742086092631,7.119604667027791,7.055448611577352,7.001840551694234,6.959689259529114,6.918493946393331,6.877371748288472,6.836262543996175,6.795152227083842,6.754042347272237,6.712921977043152,6.671813090642293,6.630699833234151,6.596355080604553,6.569371183713277,6.543004631996155,6.516682783762614,6.490373611450195,6.464063207308452,6.437743465105693,6.411433219909668,6.385123650232951,6.358802080154419,6.33681579430898,6.319546898206075,6.302669485410054,6.285817901293437,6.268978675206502,6.2521283229192095,6.2352884610493975,6.218438506126404,6.201598087946574,6.184759736061096,6.161942839622498,6.132624665896098,6.102760910987854,6.072863419850667,6.042951901753743,6.013052781422933,5.983142217000325,5.9532424211502075,5.923332691192627,5.893420179684957,5.877185304959615,5.875839789708455,5.87573778629303,5.875721573829651,5.875725905100505,5.875722646713257,5.875725150108337,5.875723322232564,5.875723679860433,5.8757244348526,5.8743598858515425,5.871521910031636,5.8685518105824785,5.8655818700790405,5.86260183652242,5.8596318165461225,5.856651822725932,5.853681842486064,5.850701928138733,5.847721854845683,5.844751914342244,5.8417718807856245,5.838801860809326,5.835821827252706,5.832851847012837,5.829871813456218,5.826901753743489,5.823921879132588,5.820941885312398,5.817971865336101,5.81499179204305,5.812021772066752,5.809041817982991,5.806071837743123,5.803091804186503,5.800121823946635,5.797141869862874,5.794161796569824,5.791191816329956,5.788211743036906,5.785241802533467,5.782261848449707,5.7792917887369795,5.776311834653218,5.773341735204061,5.77036186059316,5.767391800880432,5.764411926269531,5.761431852976481,5.758461753527324,5.755481839179993,5.7525118589401245,5.749531825383504,5.746561765670776,5.743581732114156,5.740611712137858,5.737631797790527,5.734651843706767,5.731681783994039,5.728701829910278,5.725731770197551,5.72275181611379,5.719781756401062,5.716801842053731,5.713831702868144,5.710851748784383,5.707871715227763,5.704901615778605,5.701921741167705,5.698951760927836,5.695971727371216,5.6930017073949175,5.690021793047587,5.687041759490967,5.684071699778239,5.681091745694478,5.6781216859817505,5.6751417716344195,5.6721716324488325,5.6691917181015015,5.666221698125203,5.663241823514302,5.660271724065145,5.657291769981384,5.654311696688334,5.651341636975606,5.648361722628276,5.6453917026519775,5.642411708831787,5.639441688855489,5.6364617347717285,5.633491635322571,5.63051172097524,5.62753168741862,5.624561707178752,5.6215817133585615,5.618611653645833,5.615631739298503,5.612661679585774,5.609681685765584,5.606711586316426,5.603731751441956,5.600751678148906,5.597781618436177,5.594801704088847,5.591831644376119,5.588851690292358,5.585881590843201,5.58290163675944,5.579931656519572,5.576951662699382,5.573981602986653,5.571001688639323,5.5680216153462725,5.5650516748428345,5.562071601549785,5.559101740519206,5.556121627489726,5.553151647249858,5.550171613693237,5.547201633453369,5.544221719106038,5.541241645812988,5.53827166557312,5.53529159228007,5.532321572303772,5.529341618220012,5.526371677716573,5.523391644159953,5.520411570866902,5.5174416700998945,5.514461676279704,5.511491616566976,5.508511583010356,5.505541602770488,5.502561648686727,5.499591588973999,5.496611634890239,5.493631601333618,5.49066162109375,5.487681587537129,5.484711607297261,5.481731573740642,5.478761553764343,5.475781559944153,5.472811579704285,5.469831625620524,5.466861605644226,5.463881651560466,5.460901538530986,5.457931598027547,5.4549516042073565,5.451981544494629,5.449001590410869,5.44603157043457,5.44305153687795,5.440081596374512,5.437101483345032,5.43412180741628,5.4311509529749555,5.4295361042022705,5.429403344790141,5.429393966992696,5.429393768310547,5.429383834203084,5.429383754730225,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225465774536133,24.526807467142742,24.88090721766154,25.229507287343342,25.58450698852539,25.94160731633504,26.297107537587483,26.61680730183919,26.872807661692303,27.07370726267497,27.226906776428223,27.33890708287557,27.379806836446125,27.32500648498535,27.189406236012776,26.98660643895467,26.728106021881104,26.39020586013794,25.953405221303303,25.436005115509033,24.85400454203288,24.221004645029705,23.549004395802815,22.848203976949055,22.127203623453777,21.39370361963908,20.65380350748698,19.91360314687093,19.177703380584717,18.44960308074951,17.73200273513794,17.027002493540447,16.33650255203247,15.662102381388346,15.00470232963562,14.365502119064331,13.744901974995932,13.142001946767172,12.555901924769083,11.987001657485962,11.435601631800333,10.90200146039327,10.386301517486572,9.888681332270304,9.40904132525126,8.947311162948608,8.503331263860067,8.077481150627136,7.669960975646973,7.280240972836812,6.907790859540303,6.55207081635793,6.212520798047383,5.88861080010732,5.579780737559001,5.285510698954265,5.005240599314372,4.738620599110921,4.4852205117543535,4.24444051583608,4.015700558821361,3.7984704971313477,3.5922104716300964,3.3964304327964783,3.210660378138224,3.0344303846359253,2.867300351460775,2.7090003887812295,2.5592403213183084,2.4175403118133545,2.283490300178528,2.156680246194204,2.036720265944799,1.9232402443885803,1.8159202535947163,1.7144402265548706,1.6184702118237813,1.5277401904265087,1.442010184129079,1.3610101838906605,1.2845001618067424,1.212250163157781,1.1440201600392659,1.0796201626459758,1.0188201417525609,0.9614421427249908,0.9094661325216293,0.8636281390984853,0.822324146827062,0.785066137711207,0.7514181385437647,0.7209931363662084,0.693442145983378,0.6684561222791672,0.6457551370064417,0.6250941356023153,0.606251135468483,0.5890301217635473,0.5732531348864237,0.5587641149759293,0.5454221268494924,0.5331011215845743,0.5216921220223109,0.51109512646993,0.5012231270472208,0.4919971177975337,0.4833471179008484,0.47521111617485684,0.46753211816151935,0.46026211480299634,0.45335911959409714,0.4467831129829089,0.440499114493529,0.43447811404863995,0.4286921148498853,0.4231141085426013,0.4177261119087537,0.4125081052382787,0.4074431086579959,0.4025171101093292,0.39771610498428345,0.3930271069208781,0.3884391039609909,0.38394410411516827,0.3795331045985222,0.3752001076936722,0.37093810240427655,0.36673809836308163,0.36259809881448746,0.35851309696833294,0.3544790968298912,0.35049209743738174,0.34654809534549713,0.3426450937986374,0.33877809594074887,0.33494609345992404,0.33114809542894363,0.32738108932971954,0.32364408920208615,0.3199350908398628,0.31625308593114215,0.3125930850704511,0.3089580883582433,0.30534608910481137,0.3017560864488284,0.29818708697954815,0.29463807741800946,0.2911090801159541,0.2875970775882403,0.28410207728544873,0.2806260759631793,0.2771660735209783,0.2737230757872264,0.27029607941706973,0.26688407361507416,0.2634860749046008,0.2601020783185959,0.256732073922952,0.25337707499663037,0.2500350698828697,0.24670606727401415,0.2433900684118271,0.2400850678483645,0.2367920664449533,0.23351206382115683,0.23024306446313858,0.22698606302340826,0.22374006112416586,0.22050506249070168,0.21727906167507172,0.21406406164169312,0.21086005742351213,0.2076660580933094,0.20448205744226775,0.20130705709258714,0.1981430562833945,0.19498605653643608,0.19183805212378502,0.18870005259911218,0.18557105089227358,0.18245105197032294,0.1793400483826796,0.1762370504438877,0.17314104860027632,0.1700530449549357,0.1669730469584465,0.1639020455380281,0.16083904231588045,0.1577830451230208,0.15473604202270508,0.15169304236769676,0.14865904425581297,0.14563204099734625,0.14261204128464064,0.13960003852844238,0.13659503559271494,0.13359703620274863,0.13060403491059938,0.12761803468068442,0.12463803340991338,0.1216660322000583,0.11870003181199233,0.11573903014262517,0.11278502953549226,0.10983702850838502,0.10689502768218517,0.10396002605557442,0.1010320254911979,0.09810902612904708,0.09519042447209358,0.0922781229019165,0.08937202331920464,0.0864719208329916,0.08357792037228744,0.08068981890877087,0.07780751834313075,0.07492871768772602,0.07205591599146526,0.06918901577591896,0.06632791521648566,0.06347251279900472,0.060622813180089,0.057778612400094666,0.054937711295982204,0.05210261015842358,0.049273109063506126,0.046449207700788975,0.0436309070015947,0.04081800673156977,0.03801050502806902,0.03520610400786003,0.03240740361313025,0.029614302795380354,0.026826601785918076,0.02404430105040471,0.02126740012317896,0.018495799973607063,0.015917200051868956,0.013695399820183715,0.011781599993507067,0.010133599940066537,0.008714899964009723,0.007493790006265044,0.006442989960002403,0.005538920018201073,0.004761229967698455,0.004092340008355677,0.003517129982355982,0.0030225400696508586,0.0025973200293568275,0.002231770020443946,0.001917559983363996,0.0016474899991105,0.001415389987717693,0.0012159300094936043,0.0010445399966556579,0.0008972690023559456,0.0007707339973421767,0.0006620210042456165,0.0005686239989396805,0.00048838899480567,0.0004194639962709819,0.00036025699955644086,0.0003094000009393009,0.00026571599786014605,0.0002281950000906363,0.00019596800120780244,0.00016828900091544105,0.00014451600266814543,0.00012409999969046717,9.829233749769628e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050167560577393,22.259799321492512,22.12779935201009,22.122599283854168,22.08519919713338,22.020299116770428,21.9322992960612,21.808999220530193,21.64079936345418,21.436299165089924,21.2031995455424,20.947899500528973,20.654999415079754,20.312199274698894,19.930099487304688,19.518099625905354,19.0839999516805,18.61459954579671,18.0990997950236,17.549100081125896,16.97409963607788,16.382599512736004,15.781399885813395,15.17639978726705,14.572499831517538,13.973599831263224,13.383099953333536,12.803099711736044,12.235599915186564,11.682199875513712,11.144399960835775,10.623199860254923,10.119199911753336,9.633109966913858,9.16504987080892,8.715120077133179,8.283310095469156,7.868939995765686,7.471289952596028,7.0900899569193525,6.725039998690288,6.3757699728012085,6.041899959246318,5.723009983698527,5.418649991353353,5.12837000687917,4.8517100016276045,4.58839996655782,4.338110049565633,4.100310027599335,3.8744900226593018,3.6601399978001914,3.45674999554952,3.2638399998346963,3.080940008163452,2.9075899918874106,2.743339995543162,2.5878299673398337,2.4406699538230896,2.3014400005340576,2.1697399814923606,2.045189996560415,1.9274200002352397,1.8160900076230366,1.7108699878056843,1.6114399929841359,1.5175000031789143,1.4288100004196167,1.3451499938964844,1.2662199934323628,1.1917700072129567,1.1215499937534332,1.0553299983342488,0.9928960005442301,0.9340270012617111,0.8785319974025091,0.8262249976396561,0.7769340028365453,0.7304930090904236,0.6867500096559525,0.6455560127894083,0.6067669987678528,0.5702490011850992,0.5358779976765314,0.5035340065757433,0.47310400009155273,0.445024994512399,0.4191339959700902,0.39473599940538406,0.3717479978998502,0.35008999953667325,0.32968899856011075,0.310479000210762,0.292393999795119,0.27536899596452713,0.25934600085020065,0.24426999812324843,0.23008499791224798,0.21674199774861336,0.20419500147302946,0.19239500040809313,0.181298998494943,0.17086999987562498,0.16106799989938736,0.15185500060518584,0.14319899678230286,0.13506799936294556,0.12742799955109754,0.12024999844531219,0.11350899996856849,0.10717999935150146,0.10123499917487304,0.09565419827898343,0.09041530018051465,0.08549549865225951,0.08087779954075813,0.07654389987389247,0.07247429961959521,0.0686527993530035,0.06506659897665183,0.06170130055397749,0.05854089961697658,0.05557509915282329,0.052791999032100044,0.050177699575821556,0.04772189911454916,0.04541689964632193,0.043253399431705475,0.04122009935478369,0.03931119944900274,0.03751889988780022,0.03583339974284172,0.034248000010848045,0.03275869941959778,0.031359399668872356,0.03004199933881561,0.028803599532693624,0.02763919982438286,0.02654159938295682,0.02550899951408307,0.024537199332068365,0.02361989968145887,0.022753499293078978,0.021937199402600527,0.02116769940281908,0.020439699447403353,0.01975269941613078,0.019104099366813898,0.01848899961138765,0.017905399513741333,0.01735339950149258,0.01683099940419197,0.01633399973313014,0.01586289967720707,0.015416199419026574,0.01498979958705604,0.014584799607594809,0.014199799469982585,0.013831099572901925,0.01347759971395135,0.013140799632916847,0.012819399669145545,0.012510099681094289,0.012214599642902613,0.011931799740220109,0.0116585996778061,0.011394399606312314,0.011140899655098716,0.010897399702419838,0.01066099953216811,0.010433399661754569,0.010214199622472128,0.010000299662351608,0.009793939689795176,0.009594459707538286,0.00939910967523853,0.00920763968800505,0.009022129621977607,0.008842189718658725,0.00866511968585352,0.008493089815601707,0.008325759787112474,0.00816047991005083,0.00799713966747125,0.0078379597592478,0.007682669791392982,0.007528679755826791,0.007378249739607175,0.0072311597953860956,0.00708484979501615,0.0069416197172055645,0.006801269793262084,0.006661289759601156,0.006521659825618069,0.006384719745256007,0.006250299862585962,0.0061158997705206275,0.005983859805079798,0.005854049775128563,0.005723979828568797,0.005593689779440562,0.0054655498048911495,0.00533942983020097,0.005212849898574253,0.005088219807172815,0.004965389807087679,0.004841919871978462,0.004717889823950827,0.004595679851869742,0.004475169853928189,0.004353929893113673,0.004234349781957765,0.00411633988066266,0.003997459813642005,0.0038801199019265673,0.0037642299042393765,0.00364736991468817,0.0035296198717939356,0.0034133899219644568,0.0032985999326532087,0.0031828099357274673,0.003068459938125064,0.002955439907964319,0.002841349982190877,0.0027262899287355444,0.002612659998703748,0.0025003799431336424,0.002387029933743179,0.0022750499580676356,0.002164339976540456,0.002052489959169179,0.0019419299690828968,0.001832590001868084,0.0017220599887271721,0.0016104399983305484,0.0015001599967945367,0.0013911399970917653,0.001285600010305643,0.0011879299903133262,0.0010975799911345045,0.0010140100008963298,0.0009367309927862758,0.0008652750014637908,0.0007992150009764979,0.0007381539908237755,0.0006817190005676821,0.0006295669930599009,0.0005813769918556014,0.000536853001297762,0.0004957199926138856,0.00045772100080891204,0.0004226219971315004,0.0003902019986223119,0.00036025899801946554,0.00033260599836163845,0.0003070680007416134,0.0002834839979186654,0.0002617070034223919,0.00024159800280661634,0.0002230299990818215,0.00020588599727489054,0.0001900570011154438,0.00017544200090924278,0.00016194899944821373,0.0001494920021893146,0.00013799100027730068,0.00012737400053689876,0.00011757200021141519,0.00010852399888487223,5.174597451211108e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.69566218058267,237.72884877522787,240.95088068644205,243.35691452026367,244.98993937174478,246.01595306396484,246.56801223754883,246.03809102376303,244.01612091064453,240.95115025838217,237.1881586710612,232.98621241251627,227.8432820638021,221.41530100504556,214.17531967163086,206.47931671142578,198.59235636393228,190.0524139404297,180.53842290242514,170.49642944335938,160.25642267862955,150.0604133605957,140.0813954671224,130.44237772623697,121.2223580678304,112.47333717346191,104.22231737772624,96.4414005279541,89.09968185424805,82.20916239420573,75.76934432983398,69.77132733662923,64.2006098429362,59.038694063822426,54.26457945505778,49.85606575012207,45.79045263926188,42.04134051005045,38.58302974700928,35.39561907450358,32.459709803263344,29.75700092315674,27.27039321263631,24.98348553975423,22.88127867380778,20.94967206319173,19.17526610692342,17.54696051279704,16.054155429204304,14.685950915018717,13.431946674982706,12.28294269243876,11.230339209238688,10.266035874684652,9.382952769597372,8.574260075887045,7.833827575047811,7.156205177307129,6.536323030789693,5.969271024068196,5.450589299201965,4.976167599360148,4.542296131451924,4.145524720350902,3.782733460267385,3.4510523080825806,3.147851208845774,2.8708702325820923,2.617979347705841,2.387088497479757,2.1763077775637307,1.983887126048406,1.808246503273646,1.647915909687678,1.501595397790273,1.3680649399757385,1.2462144990762074,1.135054111480713,1.033673753341039,0.9412154157956442,0.856923113266627,0.7800858368476232,0.7100535879532496,0.6462333500385284,0.5880861431360245,0.5351149390141169,0.4871637523174286,0.44372161477804184,0.40400547037522,0.36770133922497433,0.33454522490501404,0.30429811775684357,0.27670902013778687,0.2515249289572239,0.22856384764115015,0.2076357752084732,0.18856270362933478,0.1711836395164331,0.15535158291459084,0.14095653096834818,0.12787148170173168,0.11595544094840686,0.10510339836279552,0.09524806216359138,0.08630072822173436,0.07817979777852695,0.07081107050180435,0.06412664397309224,0.05806462342540423,0.05254160395512978,0.04750858464588722,0.042947967536747456,0.038816350822647415,0.03507443672666947,0.03168632369488478,0.028619211943199236,0.025843401594708364,0.023331991862505674,0.02106008306145668,0.019005574906865757,0.01714786747470498,0.015468661362926165,0.013951055239886045,0.012579950115953883,0.011341245146468282,0.010222640664627155,0.009212536659712592,0.008300683150688807,0.007477679910759131,0.00673503700333337,0.006065034346344571,0.00546069194873174,0.004915679843785862,0.004424287859971325,0.00398131605470553,0.0035820744815282524,0.0032223130498702326,0.002898181730415672,0.0026062305939073362,0.00234328955411911,0.002106528573979934,0.0018933777367540945,0.0017015269356003653,0.0015288662495246779,0.0013735056466733415,0.0012337450655953337,0.0011080245409781735,0.000994967083291461,0.0008933066807609672,0.000801913304409633,0.000719761970685795,0.0006459296710090712,0.000579586402939943,0.0005199801526032388,0.0004664369359185609,0.000418346736599536,0.00037516155862249434,0.0003363864016137086,0.0003015772551104116,0.00027033213215569657,0.00024229000943402448,0.0002171279071869018,0.00019455281411258815,0.00017430073179032965,0.00015613565483363345,0.00013984558972879313,0.00012523852759234919,0.00011214247266858972,5.156396279441348e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527332067489624,3.5471805334091187,3.4357504645983377,3.3270204861958823,3.2168304721514382,3.1059104998906455,2.9949004451433816,2.88433043162028,2.7747004429499307,2.6663904388745627,2.5597704450289407,2.455100417137146,2.352640390396118,2.2525903979937234,2.1550903717676797,2.060280362764994,1.9682503441969554,1.879080315430959,1.7928002973397572,1.709440290927887,1.6290202836195629,1.5515302916367848,1.4769402742385864,1.4052302638689678,1.3363502422968547,1.2702502210934956,1.2068902254104614,1.1462002197901409,1.0881002048651378,1.0325501958529155,0.9794481893380483,0.9287371685107549,0.8803351720174154,0.8341701676448187,0.7901611576477686,0.7482321510712305,0.7083061387141546,0.6703081329663595,0.6341611295938492,0.5997921129067739,0.5671301186084747,0.5361031095186869,0.5066401039560636,0.47867609808842343,0.4521420920888583,0.4269750838478406,0.40311507880687714,0.3805030733346939,0.3590780695279439,0.3387860680619876,0.3195720687508583,0.3013850624362628,0.28417705992857617,0.2678980554143588,0.25250305111209553,0.23794704675674438,0.2241890455285708,0.21118804315725961,0.19890504082043967,0.18730403731266657,0.17635103687644005,0.16600903620322546,0.15624703342715898,0.147036029646794,0.13834702844421068,0.13015002633134523,0.12242102560897668,0.11513402375082175,0.10826502305765946,0.10179202134410541,0.09569102029005687,0.0899431196351846,0.084529518460234,0.07943131774663925,0.07463041506707668,0.07011171616613865,0.06585921409229438,0.061856312987705074,0.05808911224206289,0.05454621184617281,0.051213510955373444,0.04807780993481477,0.04513020999729633,0.04235870918879906,0.03975240855167309,0.0373024083673954,0.03508600685745478,0.033076007229586445,0.031177406199276447,0.029383106157183647,0.02768660554041465,0.02608170562113325,0.024562504918624956,0.023141004610806704,0.02179360498363773,0.020515604099879663,0.019320004153996706,0.01818410415823261,0.017104103695601225,0.01609380341445406,0.01514890301041305,0.014265102799981833,0.013421102970217666,0.012614302802830935,0.011859802529215813,0.011154202278703451,0.010494402376934886,0.009877461940050125,0.0093005719439437,0.008743761961037913,0.008205761822561422,0.007702771651869019,0.00723253155592829,0.0067929214565083385,0.006381971334728102,0.005997811288883288,0.005638721166178584,0.005303061101585627,0.0049893209943547845,0.004696070992698272,0.004421990908061464,0.004165830789133906,0.003926420758944005,0.003702680735538403,0.003476190807608267,0.003247140751530727,0.0030331106778855124,0.002833120602493485,0.0026462506308841207,0.0024716605354721346,0.0023085305195612213,0.002156120492145419,0.002013730467297137,0.0018807004283492763,0.0017564204172231257,0.001640330379207929,0.0015318703566056986,0.0014305603205381583,0.0013359203197372456,0.001247520277199025,0.0011649402731563896,0.0010878102524050821,0.001015770249068737,0.000948486223933287,0.0008856401982484385,0.0008269451936939731,0.0007721261790720746,0.000720929165254347,0.0006731161556672305,0.0006284631478289763,0.000586764135126335,0.0005478221282828599,0.0005114581144880503,0.0004775001119317797,0.0004457901037919025,0.00041618009709054604,0.0003885310919334491,0.000362714083166793,0.0003386070820852183,0.000316099074552767,0.00029508307003804174,0.0002754610710932563,0.00025714005702563253,0.00024003505556417318,0.00022406505134616358,0.00020915504865115508,0.00019523504306562245,0.00018223904286666462,0.00017010704080651826,0.0001587800373575495,0.000148206033676009,0.00013833503301915093,0.0001291200278501492,0.00012051802756711065,0.00011248702624773917,0.0001049910242727492,1.6801621313788928e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844185034434,3.2989591360092163,3.304389158884684,3.307759245236715,3.309159239133199,3.3086792826652527,3.306419312953949,3.3024592796961465,3.2969093521436057,3.28982937335968,3.2813193798065186,3.271429399649302,3.2602594097455344,3.247849424680074,3.2342894872029624,3.2196394999821982,3.203949491182963,3.187279522418976,3.169699569543203,3.151249567667643,3.131989598274231,3.1119595964749656,3.0912196238835654,3.069799621899923,3.047749658425649,3.025119642416636,3.0019396940867105,2.9782397150993347,2.9540796677271524,2.929469724496206,2.904469688733419,2.8790797193845115,2.8533597389856973,2.8273197611172995,2.8009997606277466,2.7744197448094687,2.7475997606913247,2.720589796702067,2.6933897535006204,2.6660298109054565,2.638529817263285,2.6109098196029663,2.5831998189290366,2.5554098089536033,2.527559836705526,2.499669830004374,2.471749802430471,2.4438198606173196,2.415889879067739,2.3879798650741577,2.3601098457972207,2.332279900709788,2.3044999043146768,2.2767898639043174,2.249159892400106,2.2216298977533975,2.1941898465156555,2.1668599446614585,2.1396499077479043,2.112559894720713,2.0856098930040994,2.058799902598063,2.0321399172147117,2.0056399206320443,1.9793099164962769,1.9531399309635162,1.927149921655655,1.9013399283091228,1.8757099310557048,1.8502799371878307,1.825039933125178,1.7999999423821766,1.7751699487368267,1.7505499521891277,1.7261399328708649,1.701949954032898,1.6779799461364746,1.6542299389839172,1.6306999425093334,1.6073999404907227,1.5843299627304077,1.5614899694919586,1.5388799508412678,1.516509970029195,1.4943699638048809,1.4724600116411846,1.4500299791495006,1.427099992831548,1.4044900139172871,1.3821999927361805,1.3601899941762288,1.3384999930858612,1.3171099921067555,1.2960199813048046,1.2752300004164379,1.2547100186347961,1.2344800134499867,1.2145599921544392,1.1949300070603688,1.1755699912707012,1.1564800043900807,1.1376700003941853,1.1191499928633373,1.100899984439214,1.0828999976317089,1.0651900172233582,1.0477299988269806,1.0305199821790059,1.0135799944400787,0.9968989988168081,0.9804629931847254,0.9642650038003922,0.9483219981193542,0.9326289941867193,0.917184000213941,0.9019639939069748,0.8869639933109283,0.8722030023733774,0.8576759894688925,0.8433810075124105,0.8293139984210333,0.815451001127561,0.8017909924189249,0.7883499960104624,0.7751260101795197,0.762112999955813,0.7493110001087189,0.7367159972588221,0.7243239978949229,0.7121330052614212,0.7001390059789022,0.6883209894100825,0.6766750067472458,0.6652189940214157,0.6539499958356222,0.6428659955660502,0.6319619913895925,0.6212379982074102,0.6106889943281809,0.6003140012423197,0.5901089906692505,0.5800720006227493,0.5702020029226939,0.5604940007130305,0.5509459972381592,0.5415569990873337,0.5323229978481928,0.5232430050770441,0.5143130073944727,0.5055319964885712,0.49689699957768124,0.4884059975544612,0.4800570035974185,0.47182699541250867,0.4637160003185272,0.4557399998108546,0.4478969946503639,0.44018599887688953,0.43260499835014343,0.4251509979367256,0.41782299677530926,0.41061700135469437,0.4035340026021004,0.39656899869441986,0.38972300042708713,0.3829919993877411,0.3763740037878354,0.369868998726209,0.3634739990035693,0.35718800127506256,0.35100800544023514,0.34493299822012585,0.3389610027273496,0.33309000233809155,0.32731999705235165,0.3216480016708374,0.3160720020532608,0.31059199819962185,0.3052049974600474,0.29990999897321063,0.294705996910731,0.2895909994840622,0.28456299751996994,0.2796210050582886,0.27476399888594943,0.2699900045990944,0.2652979989846547,0.2606869985659917,0.25615399827559787,0.251700001458327,0.24732200056314468,0.24301999807357788,0.23879100009799004,0.23463599880536398,0.23055200030406317,0.22653800124923387,0.2225940003991127,0.21871699889500937,0.21490800008177757,0.21116399889190993,0.20748500153422356,0.20387000093857446,0.20031699910759926,0.1968259997665882,0.19339499870936075,0.19002400214473406,0.18671099841594696,0.18345499907930693,0.18025599916776022,0.17711199944218,0.17402299990256628,0.17098799968759218,0.16800499831636748,0.16507399951418242,0.16219400117794672,0.1593639999628067,0.15658400083581606,0.15385099997123083,0.1511670003334681,0.14852900182207426,0.14593599860866865,0.14338999738295874,0.14088699966669083,0.13842799762884775,0.13601200034221014,0.13363800073663393,0.13130599881211916,0.12901400153835615,0.12676299984256426,0.12455000107487042,0.12237599926690261,0.12024100124835968,0.11814199884732564,0.11607999975482623,0.11405500086645286,0.11206399959822495,0.11010900015632312,0.10818799957633018,0.10629999948044618,0.10444600072999795,0.10262400036056836,0.10083400023480256,0.09907480018834273,0.09734680006901424,0.09564900025725365,0.09398089970151584,0.0923419992129008,0.09073169901967049,0.08914960051576297,0.0875951995452245,0.08606790006160736,0.08456730159620444,0.08309289999306202,0.08164429912964503,0.08022090047597885,0.07882239980002244,0.0774483997374773,0.07609829989572366,0.07477180038889249,0.07346850012739499,0.07218789992233117,0.0709296992669503,0.06969339959323406,0.06847870039443175,0.06728519996007283,0.06611249968409538,0.06496030030151208,0.06382809889813264,0.06271580047905445,0.061622799995044865,0.060548900005718075,0.05949370035280784,0.05845700018107891,0.057438299991190434,0.05643739985922972,0.05545390024781227,0.05448760061214367,0.053538200135032334,0.0526052995895346,0.051688600331544876,0.05078800022602081,0.04990299977362156,0.049033500564595066,0.048179199608663716,0.047339700162410736,0.04651490040123463,0.04570439954598745,0.04490809980779886,0.0441256994381547,0.04335690010339022,0.04260150001694759,0.0418593001862367,0.04112999979406595,0.04041339922696352,0.03970940007517735,0.03901760000735521,0.03833780034134785,0.0376698998734355,0.03701370054235061,0.0363688999786973,0.035735300121208034,0.03511280038704475,0.034501099959015846,0.033900100427369274,0.033309500043590866,0.03272930004944404,0.032159099355340004,0.03159889982392391,0.031048499668637913,0.03050759993493557,0.029976200001935165,0.02945409994572401,0.028941000035653513,0.02843689980606238,0.02794159995391965,0.027454899934430916,0.02697669994086027,0.0265067998940746,0.026045100142558415,0.025591399986296892,0.025145699890951317,0.02470770012587309,0.024277400225400925,0.02385449983800451,0.02343910001218319,0.023030799968789022,0.022629699824998777,0.02223559996734063,0.021848300161461037,0.021467800096919138,0.021093900005022686,0.02072650023425619,0.020365600008517504,0.02001090021803975,0.019662400241941214,0.01932000011826555,0.018983499923100073,0.018652899966885645,0.018328099977225065,0.018008900185426075,0.01769530012582739,0.017387100029736757,0.01708430020759503,0.016786800387005012,0.01649449982990821,0.01620729997133215,0.015925099917997915,0.015647700056433678,0.015375300155331692,0.015107500134035945,0.014844499994069338,0.014585999927173058,0.014332000010957321,0.014082400050635139,0.0138371999685963,0.013596300035715103,0.013359600134814778,0.01312689995393157,0.012898399960249662,0.012673800035069386,0.012453100100780526,0.01223630007977287,0.012023300165310502,0.011813899890209237,0.011608200070137778,0.011406100122258067,0.01120749992939333,0.011012399879594644,0.010820700010905663,0.010632299973318974,0.010447199999665221,0.01026529997276763,0.01008659997023642,0.009910999952505032,0.009738459950312972,0.009568930060292283,0.009402340045198798,0.0092386599474897,0.009077829852079352,0.008919799933210015,0.008764530144010982,0.008611949859187007,0.008462040064235529,0.008314740067968765,0.008169999967018763,0.008027780102565885,0.007888040039688349,0.0077507400419563055,0.0076158200002585845,0.007483260007575154,0.007353000032405059,0.007225010000790159,0.007099249982275069,0.006975690058122079,0.006854270041609804,0.0067349699869131046,0.006617739990664025,0.006502559990622103,0.006389389978721738,0.006278179935179651,0.006168909991780917,0.006061549958152075,0.005956050008535385,0.00585239000308017,0.005750539945438504,0.005650460021570325,0.005552120002297063,0.0054554899300759034,0.0053605500143021345,0.005267260014079511,0.005175599983582894,0.005085529992356896,0.004997030016966164,0.004910070022257666,0.004824630101211369,0.004740670012931029,0.004658169966811935,0.00457711995113641,0.004497469984926283,0.0044192099788536625,0.004342310052985947,0.00426675002866735,0.004192509960072736,0.004119560006074607,0.004047879988017182,0.003977449960075319,0.003908239984108756,0.003840239990192155,0.0037734200013801455,0.003707770025357604,0.0036432600463740528,0.0035798699827864766,0.003517580005185058,0.0034563799660342434,0.0033962499971191087,0.003337159985676408,0.003279099997598678,0.0032220600017656884,0.0031660000095143914,0.0031109199820396802,0.0030568000317240753,0.0030036199993143478,0.0029513700089106956,0.002900030017675211,0.0028495800215750933,0.002800010028295219,0.002751300014400234,0.002703440006977568,0.0026564100019944212,0.002610209999450793,0.0025647999912810824,0.0025201899698004127,0.002476349996868521,0.0024332799948751926,0.0023909499868750572,0.002349359953465561,0.002308499999344349,0.0022683499846607447,0.0022288900217972696,0.002190129986653725,0.002152039979894956,0.0021146100286083915,0.0020778300046610334,0.0020416900321530798,0.0020061799829515317,0.0019712900005591414,0.0019370100053492934,0.0019033199835879107,0.0018702200031839311,0.001837690001896893,0.0018057399914444734,0.001774329992864902,0.0017434800101909786,0.001713159988867119,0.0016833700162048142,0.0016540899814572185,0.0016253300030560542,0.0015970699799557526,0.0015692999974514048,0.0015420100050202261,0.0015151899909445394,0.0014888500057471294,0.001462960004573688,0.0014375199971254915,0.001412530002805094,0.0014001400074145447};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.426127590239048,0.4188620373606682,0.4108470280965169,0.4034940227866173,0.3960750227173169,0.3886040225625038,0.3810980220635732,0.3735720217227936,0.3660390203197797,0.3585100198785464,0.35099901755650836,0.34351301689942676,0.3360630199313164,0.3286590129137039,0.3213070159157117,0.314014012614886,0.30678801238536835,0.2996340071161588,0.29255901277065277,0.285566009581089,0.278661015133063,0.2718460112810135,0.2651270081599553,0.2585040107369423,0.2519810075561206,0.2455610086520513,0.23924600705504417,0.23303800697127977,0.22693600753943124,0.2209440072377523,0.21506300816933313,0.20929100612799326,0.20363000656167665,0.19808000574509302,0.19264200578133264,0.18731500456730524,0.1820990058283011,0.17699500421682993,0.1720000058412552,0.16711600249012312,0.16234000523885092,0.15767300377289453,0.15311200295885405,0.1486580048998197,0.14430900290608406,0.14006300270557404,0.13592000305652618,0.1318780022362868,0.12793700272838274,0.12409300232927005,0.12034500204026699,0.11669400334358215,0.11313600279390812,0.10966900301476319,0.10629300276438396,0.10300700180232525,0.0998079019288222,0.09669510213037331,0.09366630266110103,0.09071970172226429,0.08785360182325046,0.08506640171011288,0.08235760281483333,0.07972560202081998,0.07716780093808968,0.07468270199994247,0.07226890201369922,0.06992390130956967,0.06764640100300312,0.0654353021333615,0.06328940267364185,0.06120750121772289,0.059187401086091995,0.057226900942623615,0.05532500147819519,0.05348090113451084,0.05169240074853102,0.049958802138765655,0.04827910071859757,0.04665160117050012,0.04507420056809982,0.04354530076185862,0.04206410050392151,0.04063020025690397,0.03924180008471012,0.037897199702759586,0.036504000114897885,0.035068499855697155,0.0336881997063756,0.03236079992105564,0.03108450025320053,0.029857299911479156,0.028677400201559067,0.027543000256021816,0.02645249990746379,0.025404199957847595,0.02439649977410833,0.023427899926900864,0.02249689990033706,0.021602199878543615,0.02074229981129368,0.01991590003793438,0.01912179992844661,0.01835869997739792,0.017625500137607258,0.016920999934275944,0.01624420005828142,0.015593900112435222,0.014969100011512637,0.014369000059862932,0.01379250013269484,0.01323869995151957,0.01270679997590681,0.012195899849757552,0.011705199955031276,0.011233900130415956,0.010781299788504839,0.010346600087359548,0.009929210102806488,0.009528390054280559,0.009143520068998138,0.008773959940299392,0.008419119908163944,0.008078430080786347,0.007751340007719894,0.007437310026337703,0.007135829965894421,0.006846409989520907,0.0065685800509527326,0.006301869948705037,0.0060458699784552055,0.005800130039763947,0.0055642599472776055,0.005337870020108919,0.005120590018729369,0.0049120400023336215,0.004711900061617295,0.004519820096902549,0.004335480082469682,0.004158589988946915,0.003988830023445189,0.0038259299860025444,0.0036696199676953256,0.0035196300013922155,0.003375719980491946,0.0032376300271910927,0.0031051399807135263,0.002978009986691177,0.002856050016513715,0.002739040006417781,0.002626779993685583,0.0025190800079144537,0.002415760012809187,0.0023166400108796856,0.0022215600474737585,0.00213035000100111,0.0020428499944197633,0.0019589200092013925,0.0018784200074151158,0.0018011900150061895,0.0017271200000929336,0.0016560800043710817,0.0015879400016274303,0.0015225799870677292,0.0014598899967192362,0.0013997700104179482,0.0013421100059834619,0.0012868100117581587,0.0012337800095944356,0.0011829100064157199,0.0011341400095261633,0.0010873600064466398,0.0010425000024649005,0.0009994830179493874,0.0009582300020459419,0.0009186719980789348,0.0008807390064854795,0.0008443640011440342,0.000809485005447641,0.0007760390047527229,0.0007439689943566918,0.0007132189978923028,0.0006837339945680773,0.0006554630041743318,0.0006283569964580238,0.0006023659952916205,0.0005774470046162605,0.0005535550056568658,0.0005306479918848103,0.0005086850045093646,0.0004876280023988026,0.0004674399994352522,0.00044808499903107685,0.0004295290006363454,0.00041173899808200076,0.0003946840006392449,0.00037833399983355775,0.00036265799766018364,0.0003476310012047179,0.0003332250028809843,0.0003194139984164697,0.00030617500306107104,0.0002934830044978298,0.00028131500342472765,0.00026965200231643394,0.0002584710018709302,0.00024775300577554543,0.00023747799908354258,0.0002276290009225098,0.0002181879996593731,0.0002091370006382931,0.00020046199885352203,0.0001921459988807328,0.0001841750005648161,0.00017653300043699952,0.00016920899846203005,0.0001621879988912648,0.00015545899926413162,0.00014900800063818073,0.00014282499978435226,0.00013689800228651924,0.00013121699885232374,0.00012577200080462111,0.00012055200083220068,0.00011554899901966564,0.00011075400046441548,0.00010615799995624305,9.343642826327898e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1795705159505,329.0759785970052,329.7899754842122,330.56297302246094,331.35097249348956,332.1539713541667,332.9739761352539,333.8039728800456,334.63997650146484,335.48197174072266,336.3289744059245,337.1809717814128,338.03897349039715,338.90196736653644,339.7699712117513,340.64297739664715,341.5209782918294,342.4039764404297,343.28797658284503,344.1759745279948,345.06597391764325,345.95897420247394,346.85397084554035,347.75097401936847,348.6509704589844,349.55297088623047,350.45797475179035,351.35897572835285,352.2489725748698,353.12997182210285,353.9999694824219,354.85997517903644,355.70997111002606,356.5499750773112,357.3799794514974,358.1999766031901,359.01097615559894,359.8149770100911,360.6149724324544,361.41297149658203,362.2069727579753,362.9979756673177,363.7849756876628,364.56897735595703,365.35097249348956,366.12897237141925,366.9029795328776,367.6729736328125,368.43697357177734,369.19297281901044,369.94297790527344,370.68596903483075,371.42297617594403,372.1539789835612,372.8779754638672,373.594975789388,374.30597432454425,375.01097106933594,375.71098073323566,376.4049708048503,377.0939763387044,377.7769724527995,378.45497639973956,379.1279780069987,379.7949752807617,380.4569778442383,381.1139729817708,381.7629750569661,382.40297444661456,383.0339762369792,383.6559778849284,384.2679799397786,384.8719762166341,385.4659779866536,386.0519739786784,386.6279780069987,387.1959762573242,387.7539774576823,388.2999776204427,388.83397420247394,389.35597737630206,389.8669738769531,390.3669789632161,390.8559748331706,391.33297475179035,391.7989781697591,392.2539749145508,392.6999766031901,393.14097849527997,393.5749740600586,394.0029754638672,394.4249750773112,394.8409779866536,395.250981648763,395.6549784342448,396.05297597249347,396.44597880045575,396.8329772949219,397.21397654215497,397.58898162841797,397.95897674560547,398.323979695638,398.68297576904297,399.03597768147785,399.3849817911784,399.7269770304362,400.06497955322266,400.39697519938153,400.72498575846356,401.0469792683919,401.3639780680339,401.6759796142578,401.9829813639323,402.28497823079425,402.5819803873698,402.87398020426434,403.1619822184245,403.44397735595703,403.7219823201497,403.99598185221356,404.26498158772785,404.5289764404297,404.78797912597656,405.04297892252606,405.2939809163411,405.5399805704753,405.781977335612,406.0189793904622,406.2529805501302,406.4809824625651,406.7059809366862,406.9269790649414,407.14298248291016,407.35498046875,407.56297810872394,407.7679799397786,407.9679819742839,408.1639811197917,408.35597737630206,408.5449803670247,408.7289810180664,408.90997823079425,409.08698018391925,409.2599817911784,409.4289805094401,409.59498341878253,409.7569808959961,409.91597747802734,410.0709813435872,410.22197977701825,410.36997985839844,410.51498158772785,410.6559804280599,410.79298146565753,410.927978515625,411.0579884847005,411.1859817504883,411.3099772135417,411.4309819539388,411.5489857991536,411.66298421223956,411.77498118082684,411.8829854329427,411.98798116048175,412.08997599283856,412.1889877319336,412.28497823079425,412.3779805501302,412.46797943115234,412.5549850463867,412.6389795939128,412.7209828694661,412.7989807128906,412.87497965494794,412.94697825113934,413.0169855753581,413.0849838256836,413.1489842732747,413.2109832763672,413.26998647054035,413.3259811401367,413.3799819946289,413.4309819539388,413.479985555013,413.52598063151044,413.56898244222003,413.60998280843097,413.6489791870117,413.6849822998047,413.71898396809894,413.7499771118164,413.7789840698242,413.8049850463867,413.82898203531903,413.8509775797526,413.86998494466144,413.8869806925456,413.9019826253255,413.91498311360675,413.9249801635742,413.93298085530597,413.93898518880206,413.94298044840497,413.94398498535156,413.94397989908856,413.9409815470378,413.9369812011719,413.9299774169922,413.9209798177083,413.90997823079425,413.8979771931966,413.8829828898112,413.86598205566406,413.84697977701825,413.8269805908203,413.8039855957031,413.7799835205078,413.7529805501302,413.7249806722005,413.69497934977215,413.66297912597656,413.6289800008138,413.59398396809894,413.5569839477539,413.51798248291016,413.47698465983075,413.4339828491211,413.38998158772785,413.34398651123047,413.2959849039714,413.24698130289715,413.1959813435872,413.14398701985675,413.0899836222331,413.0339838663737,412.9759826660156,412.91798146565753,412.8579839070638,412.79898325602215,412.7409845987956,412.68298594156903,412.62498728434247,412.56798299153644,412.5119806925456,412.4559809366862,412.39998118082684,412.34498341878253,412.2909851074219,412.23598225911456,412.1829833984375,412.1299794514974,412.07698313395184,412.0239842732747,411.9719823201497,411.92098236083984,411.86998494466144,411.81898244222003,411.76898193359375,411.71898396809894,411.66997782389325,411.62098693847656,411.57198333740234,411.5239791870117,411.4759801228841,411.4289830525716,411.3819834391276,411.3349838256836,411.28898366292316,411.24298095703125,411.19698333740234,411.15198516845703,411.1069844563802,411.06298065185547,411.01897684733075,410.97498321533203,410.9319839477539,410.8889846801758,410.84598032633465,410.8039830525716,410.76198323567706,410.71998341878253,410.6789855957031,410.63798268636066,410.5969823201497,410.5569788614909,410.51698303222656,410.4769872029622,410.437983194987,410.39898173014325,410.35998280843097,410.32198333740234,410.2839864095052,410.24598185221356,410.208984375,410.17098236083984,410.1349817911784,410.09797922770184,410.0619837443034,410.02598063151044,409.989985148112,409.9549814860026,409.9199803670247,409.8849792480469,409.84998575846356,409.81598409016925,409.78198496500653,409.7479832967122,409.71497853597003,409.6819839477539,409.64898173014325,409.6159845987956,409.58398183186847,409.5519790649414,409.5199788411458,409.4879837036133,409.4569854736328,409.4259796142578,409.39498138427734,409.36498260498047,409.33398183186847,409.3039830525716,409.2739791870117,409.24498240152997,409.21498107910156,409.1859842936198,409.156982421875,409.1289825439453,409.09998321533203,409.07198333740234,409.0439809163411,409.0159861246745,408.9889831542969,408.9619776407878,408.93398030598956,408.9079844156901,408.8809865315755,408.85498301188153,408.8279851277669,408.8019841512044,408.7769826253255,408.750981648763,408.7259826660156,408.7009811401367,408.67598215738934,408.6509780883789,408.62598419189453,408.6019821166992,408.57798258463544,408.5539779663086,408.5299886067708,408.5069834391276,408.4829813639323,408.45998128255206,408.4369837443034,408.41398366292316,408.3919855753581,408.36898549397785,408.34697977701825,408.32498423258465,408.302983601888,408.28098551432294,408.25997670491535,408.23798116048175,408.2169825236003,408.1959813435872,408.1749801635742,408.1549835205078,408.1339874267578,408.1139856974284,408.09398396809894,408.073979695638,408.0539830525716,408.03397878011066,408.0149841308594,407.99498240152997,407.9759826660156,407.9569803873698,407.93798573811847,407.91897837320965,407.9009831746419,407.8819859822591,407.8639882405599,407.8459828694661,407.82798258463544,407.80997975667316,407.79298146565753,407.7749888102214,407.75797780354816,407.739985148112,407.72297922770184,407.7059809366862,407.6899820963542,407.67298126220703,407.6559778849284,407.6399841308594,407.62398020426434,407.60697682698566,407.5909779866536,407.57598876953125,407.5599848429362,407.54397837320965,407.5289815266927,407.5129852294922,407.4979832967122,407.4829788208008,407.46798451741535,407.45298258463544,407.43898518880206,407.42398834228516,407.4089838663737,407.3949839274089,407.3809814453125,407.3669840494792,407.3529815673828,407.33898162841797,407.32498423258465,407.3109842936198,407.29798380533856,407.2839838663737,407.27098083496094,407.2579854329427,407.24498494466144,407.2319819132487,407.21898651123047,407.2059783935547,407.19398244222003,407.1809819539388,407.1689809163411,407.1559829711914,407.14398193359375,407.1319808959961,407.11998240152997,407.1079864501953,407.0959828694661,407.08398691813153,407.07298278808594,407.0609817504883,407.0499801635742,407.03798421223956,407.0269826253255,407.01598358154297,407.00498453776044,406.99398040771484,406.9829839070638,406.97198486328125,406.9619827270508,406.95098368326825,406.9409815470378,406.9299850463867,406.91998291015625,406.9099833170573,406.8989842732747,406.8889795939128,406.8789825439453,406.86898040771484,406.85998280843097,406.84998321533203,406.83997853597003,406.8309809366862,406.8209813435872,406.8119812011719,406.802983601888,406.7929865519206,406.7839838663737,406.7749837239583,406.76598358154297,406.7569834391276,406.7479832967122,406.73998006184894,406.7309824625651,406.72198486328125,406.7139841715495,406.7049814860026,406.69698333740234,406.68898010253906,406.6799825032552,406.67198181152344,406.66398366292316,406.65598551432294,406.6479797363281,406.63998158772785,406.6319808959961,406.6249821980794,406.61698659261066,406.6089833577474,406.60498809814453};
}

void set_concs_ssp245()
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.546242688,9.3650618,9.183880911,9.002700023,8.821519134,8.741611203,8.661703272,8.581795341,8.50188741,8.421979478,8.342071547,8.262163616,8.182255685,8.102347754,8.022439822,7.947593946,7.87274807,7.797902193,7.723056317,7.64821044,7.573364564,7.498518688,7.423672811,7.348826935,7.273981058,7.179840922,7.085700785,6.991560648,6.897420511,6.803280374,6.709140238,6.615000101,6.520859964,6.426719827,6.332579691,6.252962759,6.173345828,6.093728897,6.014111965,5.934495034,5.854878103,5.775261171,5.69564424,5.616027309,5.536410377,5.449905342,5.363400306,5.276895271,5.190390235,5.103885199,5.017380164,4.930875128,4.844370092,4.757865057,4.671360021,4.5832321,4.495104179,4.406976258,4.318848337,4.230720416,4.142592495,4.054464574,3.966336653,3.878208732,3.790080811,3.713470579,3.636860347,3.560250114,3.483639882,3.407029649,3.330419417,3.253809185,3.177198952,3.10058872,3.023978488,2.986676293,2.949374099,2.912071905,2.87476971,2.837467516,2.800165322,2.762863128,2.725560933,2.688258739,2.650956545,2.64135438,2.631752216,2.622150051,2.612547886,2.602945722,2.593343557,2.583741393,2.574139228,2.564537063,2.554934899,2.545332734,2.53573057,2.526128405,2.51652624,2.506924076,2.497321911,2.487719747,2.478117582,2.468515417,2.458913253,2.449311088,2.439708924,2.430106759,2.420504594,2.41090243,2.401300265,2.391698101,2.382095936,2.372493771,2.362891607,2.353289442,2.343687278,2.334085113,2.324482948,2.314880784,2.305278619,2.295676455,2.28607429,2.276472125,2.266869961,2.257267796,2.247665632,2.238063467,2.228461303,2.218859138,2.209256973,2.199654809,2.190052644,2.18045048,2.170848315,2.16124615,2.151643986,2.142041821,2.132439657,2.122837492,2.113235327,2.103633163,2.094030998,2.084428834,2.074826669,2.065224504,2.05562234,2.046020175,2.036418011,2.026815846,2.017213681,2.007611517,1.998009352,1.988407188,1.978805023,1.969202858,1.959600694,1.949998529,1.940396365,1.9307942,1.921192035,1.911589871,1.901987706,1.892385542,1.882783377,1.873181212,1.863579048,1.853976883,1.844374719,1.834772554,1.825170389,1.815568225,1.80596606,1.796363896,1.786761731,1.777159566,1.767557402,1.757955237,1.748353073,1.738750908,1.729148743,1.719546579,1.709944414,1.70034225,1.690740085,1.68113792,1.671535756,1.661933591,1.652331427,1.642729262,1.633127097,1.623524933,1.613922768,1.604320604,1.594718439,1.585116274,1.57551411,1.565911945,1.556309781,1.546707616,1.537105452,1.527503287,1.517901122,1.508298958,1.498696793,1.489094629,1.479492464,1.469890299,1.460288135,1.45068597,1.441083806,1.431481641,1.421879476,1.412277312,1.402675147,1.393072983,1.383470818,1.373868653,1.364266489,1.354664324,1.34506216,1.335459995,1.32585783,1.316255666,1.306653501,1.297051337,1.287449172,1.277847007,1.268244843,1.258642678,1.249040514,1.239438349,1.229836184,1.22023402,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855,1.210631855};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,34.479772,34.21351977,33.94726754,33.68101532,33.41476309,33.24738459,33.08000609,32.91262759,32.7452491,32.5778706,32.4104921,32.2431136,32.0757351,31.90835661,31.74097811,31.53835369,31.33572928,31.13310486,30.93048045,30.72785603,30.52523162,30.3226072,30.11998279,29.91735837,29.71473396,29.42994786,29.14516176,28.86037566,28.57558957,28.29080347,28.00601737,27.72123127,27.43644518,27.15165908,26.86687298,26.58912503,26.31137707,26.03362911,25.75588115,25.4781332,25.20038524,24.92263728,24.64488933,24.36714137,24.08939341,23.79330997,23.49722652,23.20114308,22.90505963,22.60897618,22.31289274,22.01680929,21.72072584,21.4246424,21.12855895,20.82837316,20.52818737,20.22800158,19.92781579,19.62763,19.32744421,19.02725842,18.72707263,18.42688684,18.12670106,17.88351626,17.64033147,17.39714668,17.15396189,16.9107771,16.66759231,16.42440752,16.18122273,15.93803794,15.69485315,15.5793344,15.46381565,15.3482969,15.23277815,15.1172594,15.00174065,14.8862219,14.77070315,14.6551844,14.53966565,14.51408374,14.48850183,14.46291992,14.43733802,14.41175611,14.3861742,14.36059229,14.33501038,14.30942848,14.28384657,14.25826466,14.23268275,14.20710085,14.18151894,14.15593703,14.13035512,14.10477322,14.07919131,14.0536094,14.02802749,14.00244558,13.97686368,13.95128177,13.92569986,13.90011795,13.87453605,13.84895414,13.82337223,13.79779032,13.77220842,13.74662651,13.7210446,13.69546269,13.66988078,13.64429888,13.61871697,13.59313506,13.56755315,13.54197125,13.51638934,13.49080743,13.46522552,13.43964362,13.41406171,13.3884798,13.36289789,13.33731598,13.31173408,13.28615217,13.26057026,13.23498835,13.20940645,13.18382454,13.15824263,13.13266072,13.10707882,13.08149691,13.055915,13.03033309,13.00475118,12.97916928,12.95358737,12.92800546,12.90242355,12.87684165,12.85125974,12.82567783,12.80009592,12.77451402,12.74893211,12.7233502,12.69776829,12.67218638,12.64660448,12.62102257,12.59544066,12.56985875,12.54427685,12.51869494,12.49311303,12.46753112,12.44194922,12.41636731,12.3907854,12.36520349,12.33962159,12.31403968,12.28845777,12.26287586,12.23729395,12.21171205,12.18613014,12.16054823,12.13496632,12.10938442,12.08380251,12.0582206,12.03263869,12.00705679,11.98147488,11.95589297,11.93031106,11.90472915,11.87914725,11.85356534,11.82798343,11.80240152,11.77681962,11.75123771,11.7256558,11.70007389,11.67449199,11.64891008,11.62332817,11.59774626,11.57216435,11.54658245,11.52100054,11.49541863,11.46983672,11.44425482,11.41867291,11.393091,11.36750909,11.34192719,11.31634528,11.29076337,11.26518146,11.23959955,11.21401765,11.18843574,11.16285383,11.13727192,11.11169002,11.08610811,11.0605262,11.03494429,11.00936239,10.98378048,10.95819857,10.93261666,10.90703475,10.88145285,10.85587094,10.83028903,10.80470712,10.77912522,10.75354331,10.7279614,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949,10.70237949};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,96.63315487,92.49514275,88.35713063,84.21911852,80.0811064,79.96634301,79.85157962,79.73681623,79.62205284,79.50728945,79.39252606,79.27776267,79.16299928,79.04823589,78.9334725,77.6902416,76.4470107,75.20377981,73.96054891,72.71731802,71.47408712,70.23085622,68.98762533,67.74439443,66.50116354,65.18094093,63.86071833,62.54049572,61.22027312,59.90005052,58.57982791,57.25960531,55.9393827,54.6191601,53.2989375,52.56921941,51.83950132,51.10978323,50.38006514,49.65034705,48.92062896,48.19091087,47.46119278,46.73147469,46.0017566,45.59303153,45.18430647,44.7755814,44.36685633,43.95813127,43.5494062,43.14068113,42.73195607,42.323231,41.91450594,41.57363462,41.2327633,40.89189198,40.55102067,40.21014935,39.86927803,39.52840671,39.1875354,38.84666408,38.50579276,37.97130076,37.43680876,36.90231677,36.36782477,35.83333277,35.29884077,34.76434878,34.22985678,33.69536478,33.16087278,32.92702489,32.693177,32.45932912,32.22548123,31.99163334,31.75778545,31.52393756,31.29008967,31.05624179,30.8223939,30.63045035,30.43850681,30.24656327,30.05461973,29.86267618,29.67073264,29.4787891,29.28684555,29.09490201,28.90295847,28.71101493,28.51907138,28.32712784,28.1351843,27.94324075,27.75129721,27.55935367,27.36741012,27.17546658,26.98352304,26.7915795,26.59963595,26.40769241,26.21574887,26.02380532,25.83186178,25.63991824,25.4479747,25.25603115,25.06408761,24.87214407,24.68020052,24.48825698,24.29631344,24.10436989,23.91242635,23.72048281,23.52853927,23.33659572,23.14465218,22.95270864,22.76076509,22.56882155,22.37687801,22.18493447,21.99299092,21.80104738,21.60910384,21.41716029,21.22521675,21.03327321,20.84132966,20.64938612,20.45744258,20.26549904,20.07355549,19.88161195,19.68966841,19.49772486,19.30578132,19.11383778,18.92189424,18.72995069,18.53800715,18.34606361,18.15412006,17.96217652,17.77023298,17.57828943,17.38634589,17.19440235,17.00245881,16.81051526,16.61857172,16.42662818,16.23468463,16.04274109,15.85079755,15.65885401,15.46691046,15.27496692,15.08302338,14.89107983,14.69913629,14.50719275,14.31524921,14.12330566,13.93136212,13.73941858,13.54747503,13.35553149,13.16358795,12.9716444,12.77970086,12.58775732,12.39581378,12.20387023,12.01192669,11.81998315,11.6280396,11.43609606,11.24415252,11.05220898,10.86026543,10.66832189,10.47637835,10.2844348,10.09249126,9.900547718,9.708604175,9.516660632,9.324717089,9.132773546,8.940830003,8.74888646,8.556942917,8.364999374,8.173055831,7.981112288,7.789168745,7.597225202,7.40528166,7.213338117,7.021394574,6.829451031,6.637507488,6.445563945,6.253620402,6.061676859,5.869733316,5.677789773,5.48584623,5.293902687,5.101959144,4.910015601,4.718072058,4.526128516,4.334184973,4.14224143,3.950297887,3.758354344,3.566410801,3.374467258,3.182523715,2.990580172,2.798636629,2.606693086,2.414749543,2.222806,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457,2.030862457};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,154.030184,152.539918,151.049652,149.559386,148.0691201,147.4676648,146.8662095,146.2647543,145.663299,145.0618438,144.4603885,143.8589333,143.257478,142.6560227,142.0545675,140.6560501,139.2575326,137.8590152,136.4604978,135.0619803,133.6634629,132.2649455,130.866428,129.4679106,128.0693932,126.9391512,125.8089092,124.6786672,123.5484252,122.4181832,121.2879413,120.1576993,119.0274573,117.8972153,116.7669733,115.7647825,114.7625916,113.7604008,112.75821,111.7560191,110.7538283,109.7516374,108.7494466,107.7472557,106.7450649,105.6929902,104.6409155,103.5888408,102.5367661,101.4846914,100.4326167,99.38054202,98.32846732,97.27639263,96.22431793,95.61136559,94.99841326,94.38546092,93.77250859,93.15955625,92.54660391,91.93365158,91.32069924,90.7077469,90.09479457,89.38934557,88.68389657,87.97844757,87.27299857,86.56754957,85.86210057,85.15665158,84.45120258,83.74575358,83.04030458,82.50548673,81.97066887,81.43585102,80.90103317,80.36621531,79.83139746,79.29657961,78.76176175,78.2269439,77.69212605,77.27976138,76.86739671,76.45503203,76.04266736,75.63030269,75.21793802,74.80557335,74.39320868,73.98084401,73.56847934,73.15611467,72.74375,72.33138532,71.91902065,71.50665598,71.09429131,70.68192664,70.26956197,69.8571973,69.44483263,69.03246796,68.62010329,68.20773862,67.79537394,67.38300927,66.9706446,66.55827993,66.14591526,65.73355059,65.32118592,64.90882125,64.49645658,64.08409191,63.67172724,63.25936256,62.84699789,62.43463322,62.02226855,61.60990388,61.19753921,60.78517454,60.37280987,59.9604452,59.54808053,59.13571585,58.72335118,58.31098651,57.89862184,57.48625717,57.0738925,56.66152783,56.24916316,55.83679849,55.42443382,55.01206915,54.59970447,54.1873398,53.77497513,53.36261046,52.95024579,52.53788112,52.12551645,51.71315178,51.30078711,50.88842244,50.47605777,50.06369309,49.65132842,49.23896375,48.82659908,48.41423441,48.00186974,47.58950507,47.1771404,46.76477573,46.35241106,45.94004638,45.52768171,45.11531704,44.70295237,44.2905877,43.87822303,43.46585836,43.05349369,42.64112902,42.22876435,41.81639968,41.404035,40.99167033,40.57930566,40.16694099,39.75457632,39.34221165,38.92984698,38.51748231,38.10511764,37.69275297,37.2803883,36.86802362,36.45565895,36.04329428,35.63092961,35.21856494,34.80620027,34.3938356,33.98147093,33.56910626,33.15674159,32.74437691,32.33201224,31.91964757,31.5072829,31.09491823,30.68255356,30.27018889,29.85782422,29.44545955,29.03309488,28.62073021,28.20836553,27.79600086,27.38363619,26.97127152,26.55890685,26.14654218,25.73417751,25.32181284,24.90944817,24.4970835,24.08471883,23.67235415,23.25998948,22.84762481,22.43526014,22.02289547,21.6105308,21.19816613,20.78580146,20.37343679,19.96107212,19.54870744,19.13634277,18.7239781,18.31161343,17.89924876,17.48688409,17.07451942,16.66215475,16.24979008,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541,15.83742541};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,65.63437282,65.9890425,66.34371219,66.69838187,67.05305156,67.59376004,68.13446851,68.67517699,69.21588547,69.75659395,70.29730243,70.83801091,71.37871938,71.91942786,72.46013634,72.75346284,73.04678934,73.34011584,73.63344234,73.92676883,74.22009533,74.51342183,74.80674833,75.10007483,75.39340133,75.45718802,75.52097471,75.5847614,75.64854809,75.71233478,75.77612147,75.83990816,75.90369485,75.96748154,76.03126823,75.94460433,75.85794042,75.77127652,75.68461262,75.59794871,75.51128481,75.4246209,75.337957,75.2512931,75.16462919,74.93462068,74.70461216,74.47460365,74.24459513,74.01458662,73.7845781,73.55456959,73.32456107,73.09455256,72.86454404,72.5688233,72.27310256,71.97738183,71.68166109,71.38594035,71.09021961,70.79449887,70.49877814,70.2030574,69.90733666,69.65501722,69.40269777,69.15037833,68.89805889,68.64573944,68.39342,68.14110056,67.88878111,67.63646167,67.38414223,67.1826857,66.98122917,66.77977264,66.57831611,66.37685958,66.17540305,65.97394651,65.77248998,65.57103345,65.36957692,65.27148573,65.17339454,65.07530334,64.97721215,64.87912096,64.78102977,64.68293857,64.58484738,64.48675619,64.388665,64.2905738,64.19248261,64.09439142,63.99630023,63.89820903,63.80011784,63.70202665,63.60393545,63.50584426,63.40775307,63.30966188,63.21157068,63.11347949,63.0153883,62.91729711,62.81920591,62.72111472,62.62302353,62.52493233,62.42684114,62.32874995,62.23065876,62.13256756,62.03447637,61.93638518,61.83829399,61.74020279,61.6421116,61.54402041,61.44592922,61.34783802,61.24974683,61.15165564,61.05356444,60.95547325,60.85738206,60.75929087,60.66119967,60.56310848,60.46501729,60.3669261,60.2688349,60.17074371,60.07265252,59.97456132,59.87647013,59.77837894,59.68028775,59.58219655,59.48410536,59.38601417,59.28792298,59.18983178,59.09174059,58.9936494,58.89555821,58.79746701,58.69937582,58.60128463,58.50319343,58.40510224,58.30701105,58.20891986,58.11082866,58.01273747,57.91464628,57.81655509,57.71846389,57.6203727,57.52228151,57.42419031,57.32609912,57.22800793,57.12991674,57.03182554,56.93373435,56.83564316,56.73755197,56.63946077,56.54136958,56.44327839,56.3451872,56.247096,56.14900481,56.05091362,55.95282242,55.85473123,55.75664004,55.65854885,55.56045765,55.46236646,55.36427527,55.26618408,55.16809288,55.07000169,54.9719105,54.8738193,54.77572811,54.67763692,54.57954573,54.48145453,54.38336334,54.28527215,54.18718096,54.08908976,53.99099857,53.89290738,53.79481619,53.69672499,53.5986338,53.50054261,53.40245141,53.30436022,53.20626903,53.10817784,53.01008664,52.91199545,52.81390426,52.71581307,52.61772187,52.51963068,52.42153949,52.32344829,52.2253571,52.12726591,52.02917472,51.93108352,51.83299233,51.73490114,51.63680995,51.53871875,51.44062756,51.34253637,51.24444518,51.14635398,51.04826279,50.9501716,50.8520804,50.75398921,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802,50.65589802};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,225.5668824,223.8889455,222.2110086,220.5330716,218.8551347,218.4302047,218.0052747,217.5803447,217.1554147,216.7304846,216.3055546,215.8806246,215.4556946,215.0307646,214.6058346,214.0324247,213.4590148,212.8856049,212.312195,211.7387851,211.1653752,210.5919653,210.0185554,209.4451455,208.8717357,207.6998605,206.5279854,205.3561103,204.1842352,203.0123601,201.840485,200.6686099,199.4967347,198.3248596,197.1529845,195.3983815,193.6437784,191.8891753,190.1345723,188.3799692,186.6253661,184.8707631,183.11616,181.361557,179.6069539,177.8824672,176.1579805,174.4334937,172.709007,170.9845203,169.2600336,167.5355468,165.8110601,164.0865734,162.3620867,160.7822346,159.2023825,157.6225304,156.0426783,154.4628262,152.8829741,151.303122,149.7232699,148.1434178,146.5635657,144.9669951,143.3704245,141.7738538,140.1772832,138.5807126,136.984142,135.3875713,133.7910007,132.1944301,130.5978594,129.6079485,128.6180377,127.6281268,126.6382159,125.648305,124.6583941,123.6684832,122.6785723,121.6886614,120.6987505,120.1625725,119.6263945,119.0902166,118.5540386,118.0178606,117.4816827,116.9455047,116.4093268,115.8731488,115.3369708,114.8007929,114.2646149,113.7284369,113.192259,112.656081,112.1199031,111.5837251,111.0475471,110.5113692,109.9751912,109.4390132,108.9028353,108.3666573,107.8304793,107.2943014,106.7581234,106.2219455,105.6857675,105.1495895,104.6134116,104.0772336,103.5410556,103.0048777,102.4686997,101.9325218,101.3963438,100.8601658,100.3239879,99.7878099,99.25163193,98.71545397,98.17927601,97.64309804,97.10692008,96.57074212,96.03456415,95.49838619,94.96220823,94.42603026,93.8898523,93.35367434,92.81749637,92.28131841,91.74514045,91.20896248,90.67278452,90.13660656,89.60042859,89.06425063,88.52807267,87.9918947,87.45571674,86.91953878,86.38336081,85.84718285,85.31100489,84.77482692,84.23864896,83.702471,83.16629303,82.63011507,82.09393711,81.55775914,81.02158118,80.48540322,79.94922525,79.41304729,78.87686933,78.34069136,77.8045134,77.26833544,76.73215747,76.19597951,75.65980155,75.12362358,74.58744562,74.05126766,73.51508969,72.97891173,72.44273377,71.9065558,71.37037784,70.83419988,70.29802191,69.76184395,69.22566599,68.68948802,68.15331006,67.6171321,67.08095413,66.54477617,66.00859821,65.47242024,64.93624228,64.40006432,63.86388635,63.32770839,62.79153043,62.25535246,61.7191745,61.18299654,60.64681857,60.11064061,59.57446265,59.03828468,58.50210672,57.96592876,57.42975079,56.89357283,56.35739487,55.8212169,55.28503894,54.74886098,54.21268301,53.67650505,53.14032709,52.60414912,52.06797116,51.5317932,50.99561523,50.45943727,49.92325931,49.38708134,48.85090338,48.31472542,47.77854745,47.24236949,46.70619153,46.17001356,45.6338356,45.09765764,44.56147967,44.02530171,43.48912375,42.95294578,42.41676782,41.88058986,41.34441189,40.80823393,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597,40.27205597};
    
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9426676432292,1851.5940958658855,1873.7992146809895,1887.040995279948,1899.4105834960938,1910.9706319173176,1921.7905985514324,1932.0606079101562,1941.9405822753906,1951.4605611165364,1960.6505330403645,1969.5405171712239,1978.1505126953125,1986.4904886881511,1994.6004943847656,2002.4804789225261,2010.1504211425781,2017.2303568522136,2023.3903096516926,2028.6802469889324,2033.1602172851562,2036.900166829427,2039.9401448567708,2042.3401285807292,2044.1300760904949,2045.3600362141926,2046.0800374348958,2046.1099446614583,2045.2799173990886,2043.6598815917969,2041.309834798177,2038.2697855631511,2034.5997517903645,2030.3397318522136,2025.5397033691406,2020.2396647135417,2014.4696248372395,2008.1996053059895,2001.3995869954426,1994.1095581054688,1986.3695170084636,1978.2095336914062,1969.6694946289062,1960.7694905598958,1951.5494689941406,1942.0294392903645,1932.229471842448,1922.4595235188801,1912.9895121256511,1903.7895202636719,1894.8595275878906,1886.1695760091145,1877.7095743815105,1869.4595845540364,1861.4295857747395,1853.5796000162761,1845.9095967610676,1838.3395894368489,1830.7895812988281,1823.2595825195312,1815.7495930989583,1808.2595926920574,1800.7995910644531,1793.3695882161458,1785.9695841471355,1778.5995992024739,1771.2696228027344,1764.1496683756511,1757.40966796875,1751.0296732584636,1744.979715983073,1739.2397359212239,1733.7997131347656,1728.6197611490886,1723.7097676595051,1719.0297749837239,1714.5697733561199,1710.3397725423176,1706.3197937011719,1702.5098266601562,1698.8798421223958,1695.4298299153645,1692.1398518880208,1689.0098470052083,1686.0198567708333,1683.1598612467449,1680.4298706054688,1677.6898295084636,1674.8098246256511,1671.799825032552,1668.6697998046875,1665.4298095703125,1662.0898030598958,1658.6497904459636,1655.1197916666667,1651.509785970052,1647.8298034667969,1644.0797729492188,1640.259785970052,1636.3897705078125,1632.4597778320312,1628.479756673177,1624.4497680664062,1620.3797810872395,1616.269755045573,1612.1197713216145,1607.9397583007812,1603.7297668457031,1599.4797668457031,1595.2197570800781,1590.9297383626301,1586.6097513834636,1582.2797342936199,1577.9197387695312,1573.5497538248699,1569.1597391764324,1564.759745279948,1560.3497314453125,1555.9197285970051,1551.479736328125,1547.0297546386719,1542.5797220865886,1538.1097412109375,1533.6397501627605,1529.1497599283855,1524.6697285970051,1520.1697285970051,1515.6697387695312,1511.1697387695312,1506.6597290039062,1502.1497395833333,1497.6397298177083,1493.1197408040364,1488.5997111002605,1484.0797220865886,1479.5597330729167,1475.0297241210938,1470.4997253417969,1465.979736328125,1461.449727376302,1456.9197285970051,1452.3997294108074,1447.8697509765625,1443.3397216796875,1438.8197123209636,1434.2897338867188,1429.7696940104167,1425.2497151692708,1420.7297261555989,1416.2097269694011,1411.6997172037761,1407.189717610677,1402.679707845052,1398.1697184244792,1393.6697285970051,1389.1597290039062,1384.6597188313801,1380.169698079427,1375.6697082519531,1371.179707845052,1366.6897277832031,1362.209716796875,1357.719706217448,1353.2397054036458,1348.7697143554688,1344.2897033691406,1339.8197123209636,1335.3497111002605,1330.8896993001301,1326.4297281901042,1321.9697163899739,1317.5097147623699,1313.0597127278645,1308.6097005208333,1304.1597188313801,1299.7097269694011,1295.2697245279949,1290.8297017415364,1286.3896993001301,1281.9597066243489,1277.5297139485676,1273.0997009277344,1268.6697082519531,1264.2397155761719,1259.8197021484375,1255.3997090657551,1250.9897054036458,1246.5697021484375,1242.1597188313801,1237.7496846516926,1233.3397115071614,1228.939697265625,1224.5397033691406,1220.1397094726562,1215.7396748860676,1211.3396911621094,1206.9496968587239,1202.5596822102864,1198.1697082519531,1193.7797037760417,1189.3997090657551,1185.0196940104167,1180.6396891276042,1176.2596842447917,1171.8796895345051,1167.5096944173176,1163.1396993001301,1158.7696940104167,1154.3997090657551,1150.0297037760417,1145.669698079427,1141.3096923828125,1136.949686686198,1132.5896911621094,1128.229715983073,1123.8796997070312,1119.5196940104167,1115.1696879069011,1110.8196919759114,1106.4797058105469,1102.1296793619792,1097.7896931966145,1093.449686686198,1089.1096903483074,1084.7696838378906,1080.4296875,1076.0996907552083,1071.7597147623699,1067.4296875,1063.0997009277344,1058.7697041829426,1054.44970703125,1050.1996968587239,1046.0597127278645,1042.0397033691406,1038.1097005208333,1034.2697448730469,1030.6697896321614,1027.4697977701824,1024.6098124186199,1022.0698191324869,1019.8098449707031,1017.7898356119791,1015.9898630777994,1014.3998565673828,1012.9698689778646,1011.6998799641927,1010.5698750813802,1009.5698801676432,1008.6698913574219,1007.8798878987631,1007.1698964436849,1006.5299021402994,1005.9698994954427,1005.4699045817057,1005.0199127197266,1004.6199086507162,1004.2699178059896,1003.9499155680338,1003.669911702474,1003.419921875,1003.1999206542969,1002.9999237060547,1002.8199157714844,1002.659922281901,1002.5099232991537,1002.3899230957031,1002.2699228922526,1002.169921875,1002.0799407958984,1001.9899241129557,1001.919921875,1001.8499348958334,1001.7899169921875,1001.7299296061198,1001.6799265543619,1001.6399230957031,1001.5999196370443,1001.5599263509115,1001.5199279785156,1001.4899241129557,1001.4599253336588,1001.4299265543619,1001.3999277750651,1001.3799235026041,1001.3499298095703,1001.3299255371094,1001.3099212646484,1001.2899220784506,1001.2699228922526,1001.2499287923177,1001.2299397786459,1001.2099304199219,1001.189931233724,1001.169921875,1001.159922281901,1001.1399230957031,1001.1199289957682,1001.0999298095703,1001.0899251302084,1001.0699412027994,1001.0499369303385,1001.0399271647135,1001.0199381510416,1000.9999237060547,1000.9899241129557,1000.9699350992838,1000.9499308268229,1000.9399363199869,1000.919932047526,1000.8999226888021,1000.8799235026041,1000.8699239095052,1000.8499348958334,1000.8299255371094,1000.8099365234375,1000.7999318440756,1000.7799326578776,1000.7599232991537,1000.7399291992188,1000.7199249267578,1000.6999257405599,1000.6799367268881,1000.669932047526,1000.6499328613281,1000.6299336751302,1000.6099344889323,1000.5899353027344,1000.5699310302734,1000.5499267578125,1000.5299275716146,1000.5099232991537,1000.4899342854818,1000.4699198404948,1000.4499359130859,1000.429931640625,1000.4099324544271,1000.3799387613932,1000.3599344889323,1000.3399251302084,1000.3199310302734,1000.2999420166016,1000.2799326578776,1000.2599385579427,1000.2299296061198,1000.2099253336588,1000.1899261474609,1000.1699371337891,1000.1399281819662,1000.1199289957682,1000.0999348958334,1000.0799204508463,1000.0499318440756,1000.0299326578776,1000.0099283854166,999.9809315999349,999.9569346110026,999.9329325358073,999.908925374349,999.8849283854166,999.8599344889323,999.8349253336588,999.8099263509115,999.7849375406901,999.7599334716797,999.7339223225912,999.7079315185547,999.6819254557291,999.6559397379557,999.6299133300781,999.6029205322266,999.575927734375,999.5489247639974,999.5219217936198,999.4949340820312,999.4669291178385,999.4389241536459,999.4109395345052,999.3829345703125,999.3539276123047,999.3249308268229,999.2959238688151,999.2659301757812,999.2369333902994,999.2069295247396,999.1759287516276,999.1459299723307,999.1149241129557,999.0839284261068,999.0519256591797,999.0209197998047,998.9879353841146,998.9559224446615,998.9229278564453,998.8899281819662,998.8559265136719,998.8229268391927,998.7879333496094,998.7539265950521,998.7189229329427,998.6829274495443,998.6469319661459,998.6109263102213,998.5739390055338,998.5369211832682,998.4989267985026,998.460927327474,998.4219309488932,998.3829345703125,998.3439280192057,998.3059234619141,998.2709299723307,998.2389272054037,998.2079264322916,998.1799265543619,998.1539306640625,998.1289265950521,998.1059214274088,998.0839284261068,998.0639241536459,998.0439249674479,998.0249277750651,998.0069224039713,997.9899190266927,997.9739227294922,997.9579264322916,997.9429270426432,997.9279327392578,997.9139353434244,997.8999328613281,997.8859303792318,997.8729298909506,997.8599294026693,997.8469187418619,997.8349355061849,997.8219248453776,997.8099314371744,997.7979278564453,997.7859344482422,997.7749328613281,997.7629241943359,997.7519276936849,997.7399291992188,997.7289326985677,997.7179311116537,997.7069295247396,997.6959228515625,997.6849263509115,997.6739298502604,997.6639302571615,997.6529184977213,997.6419321695963,997.6319274902344,997.6209309895834,997.6099294026693,997.5999298095703,997.5899302164713,997.5789286295573,997.5689239501953,997.5589345296224,997.5479278564453,997.5379282633463,997.5279286702474,997.5179239908854,997.5069325764974,997.4969329833984,997.4869283040365,997.4769236246744,997.4669291178385,997.4569295247396,997.4469248453776,997.4369252522787,997.4269307454427,997.4179331461588,997.4079335530599,997.3979288736979,997.387929280599,997.3779246012369,997.3689320882162,997.3589274088541,997.3489278157552,997.3399302164713,997.3299255371094,997.3199310302734,997.3109283447266,997.3059234619141};
    
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.94909922281903,403.11696370442706,405.76196034749347,408.63196563720703,411.50596618652344,414.3899637858073,417.2869567871094,420.19796498616535,423.1249593098958,426.06895955403644,429.0299580891927,432.0109608968099,435.01196034749347,438.03295644124347,441.0769577026367,444.14295959472656,447.2319590250651,450.3329544067383,453.4349543253581,456.5409622192383,459.6519597371419,462.7699559529622,465.8969548543294,469.032958984375,472.17895762125653,475.3359603881836,478.5039571126302,481.6739552815755,484.83795674641925,487.9959538777669,491.1499506632487,494.29995981852215,497.4469579060872,500.5919545491536,503.7339579264323,506.8749542236328,510.0139516194661,513.1369603474935,516.2299601236979,519.2919565836588,522.3259582519531,525.3319600423177,528.3099568684896,531.2609608968099,534.1859588623047,537.0849558512369,539.9579620361328,542.7949523925781,545.5869496663412,548.334950764974,551.0389607747396,553.699951171875,556.3189544677734,558.8949534098307,561.4309590657552,563.9249572753906,566.3799591064453,568.771962483724,571.0829620361328,573.3139597574869,575.4659678141276,577.5399678548177,579.5369618733724,581.4579722086588,583.303965250651,585.0739695231119,586.7699686686198,588.3779602050781,589.8859710693359,591.2959747314453,592.6089782714844,593.8249664306641,594.9449768066406,595.9699757893881,596.8999786376953,597.7349751790365,598.4769846598307,599.1499837239584,599.7759857177734,600.35498046875,600.8859812418619,601.3659871419271,601.7969818115234,602.1769866943359,602.5049794514974,602.781982421875,603.0049845377604,603.2179870605469,603.458984375,603.7239888509115,604.0119832356771,604.3219858805338,604.6499837239584,604.9959869384766,605.3569793701172,605.7339833577474,606.1239878336588,606.5269877115885,606.9419860839844,607.3669840494791,607.802988688151,608.2479858398438,608.7009887695312,609.1629892985026,609.6329803466797,610.1099853515625,610.5929921468099,611.0819905598959,611.5779825846354,612.0789947509766,612.5849914550781,613.0949961344401,613.6109822591146,614.1299743652344,614.6539866129557,615.1809895833334,615.7119954427084,616.2459971110026,616.7839965820312,617.3239898681641,617.8669942220052,618.4129943847656,618.9609934488932,619.5119934082031,620.0639902750651,620.6189829508463,621.1759948730469,621.7339986165365,622.2949829101562,622.8569844563802,623.4199981689453,623.9849904378256,624.5509847005209,625.1189880371094,625.6869862874349,626.2569986979166,626.8279876708984,627.3939921061198,627.948984781901,628.4939880371094,629.0269978841146,629.5509847005209,630.0640004475912,630.5669911702474,631.0609842936198,631.5439961751302,632.0169830322266,632.4809926350912,632.9339955647787,633.3779856363932,633.8129933675131,634.2379964192709,634.6529897054037,635.0589853922526,635.4549865722656,635.8419952392578,636.219004313151,636.5870005289713,636.9449971516927,637.2939910888672,637.6339874267578,637.9639994303385,638.2849833170573,638.5970001220703,638.8989919026693,639.1919962565104,639.4750010172526,639.7499949137369,640.0149943033854,640.2699991861979,640.5169932047526,640.7539927164713,640.9819895426432,641.1999867757162,641.4100036621094,641.6099904378256,641.8009897867838,641.9819895426432,642.1549936930338,642.3179931640625,642.4720001220703,642.6169993082682,642.7519989013672,642.8789927164713,642.9959920247396,643.103993733724,643.2029927571615,643.2919972737631,643.3729909261068,643.4439951578776,643.5059916178385,643.5589955647787,643.6029917399088,643.6379903157552,643.6630045572916,643.6799875895182,643.6869964599609,643.6859944661459,643.6749877929688,643.6549936930338,643.6260019938151,643.5879923502604,643.5399881998698,643.4839986165365,643.4190063476562,643.3449910481771,643.2609914143881,643.1689961751302,643.0669911702474,642.9570007324219,642.8379872639974,642.7089996337891,642.5719960530599,642.4249979654948,642.2699940999349,642.1059977213541,641.9329935709635,641.7499949137369,641.5590057373047,641.3589986165365,641.1500040690104,640.9319966634115,640.7060089111328,640.4699961344401,640.2259979248047,639.9729970296224,639.7110036214193,639.4399973551432,639.1600036621094,638.8719940185547,638.5740051269531,638.2679951985677,637.9539998372396,637.6299947102865,637.2979990641276,636.9570007324219,636.6069997151693,636.2550048828125,635.9070027669271,635.5599873860677,635.2159983317057,634.8730112711588,634.5320078531901,634.1929982503256,633.8550008138021,633.5179951985677,633.1829935709635,632.8489939371744,632.5169982910156,632.1859944661459,631.8569997151693,631.5289916992188,631.2029978434244,630.8790028889974,630.5559997558594,630.2339935302734,629.9149983723959,629.5969950358073,629.2799987792969,628.9660085042318,628.6530049641927,628.3410085042318,628.031005859375,627.7229970296224,627.417002360026,627.1119995117188,626.8079986572266,626.5060068766276,626.2059987386068,625.9070027669271,625.6099955240885,625.3139953613281,625.0200042724609,624.7269948323568,624.4359995524088,624.1460011800131,623.8569946289062,623.5700073242188,623.2839914957682,622.9990030924479,622.7160034179688,622.4339904785156,622.1530100504557,621.8730010986328,621.5950012207031,621.3179982503256,621.0420074462891,620.7670033772787,620.4940032958984,620.2210083007812,619.9500071207682,619.6800028483073,619.4099985758463,619.1420135498047,618.875,618.6089986165365,618.3450063069662,618.0809987386068,617.8180033365885,617.5559997558594,617.2949930826823,617.0349985758463,616.7759958902994,616.5180002848307,616.2610015869141,616.0039927164713,615.7490030924479,615.4950002034506,615.2409973144531,614.9879964192709,614.7360026041666,614.4849955240885,614.2349904378256,613.9859975179037,613.7370045979818,613.4900054931641,613.2430114746094,612.9969991048177,612.7519938151041,612.5069885253906,612.2630004882812,612.0199940999349,611.7779947916666,611.5369974772135,611.2960001627604,611.0559946695963,610.8160044352213,610.5779978434244,610.3400065104166,610.1030019124349,609.8659922281901,609.6299947102865,609.3949991861979,609.1610107421875,608.9269968668619,608.6940053304037,608.4620005289713,608.2300008138021,607.9989980061849,607.7680002848307,607.5379994710287,607.3090057373047,607.0799967447916,606.8519999186198,606.625,606.3980000813802,606.1710001627604,605.9459991455078,605.7210133870443,605.4959920247396,605.2719930013021,605.0489959716797,604.8259938557943,604.6039988199869,604.3820037841797,604.1609954833984,603.9410044352213,603.7209930419922,603.5010070800781,603.2820027669271,603.0640004475912,602.8459981282552,602.6280008951823,602.4110107421875,602.1949971516927,601.9789988199869,601.7639973958334,601.5489908854166,601.3340047200521,601.1199951171875,600.9070129394531,600.6940002441406,600.4820048014323,600.2699940999349,600.0579935709635,599.8470052083334,599.6360015869141,599.4259897867838,599.2159932454427,599.0070088704427,598.7980041503906,598.5899912516276,598.3819936116537,598.1739959716797,597.9670003255209,597.7599945068359,597.5539957682291,597.3479970296224,597.1419982910156,596.9369964599609,596.7319997151693,596.5279947916666,596.3240000406901,596.1209971110026,595.917002360026,595.7150065104166,595.5119934082031,595.3099975585938,595.1079966227213,594.9070027669271,594.7060038248698,594.5050048828125,594.3049977620443,594.1049957275391,593.9050038655599,593.7059987386068,593.5070037841797,593.3079986572266,593.1089986165365,592.9109903971354,592.7139892578125,592.5160013834635,592.3199920654297,592.1240030924479,591.9279937744141,591.7320048014323,591.5380096435547,591.343007405599,591.1490071614584,590.9559987386068,590.7629954020182,590.5699971516927,590.3779958089193,590.1869964599609,589.9949951171875,589.8050079345703,589.6139984130859,589.4249979654948,589.2350006103516,589.0459950764974,588.8579915364584,588.6689910888672,588.4819895426432,588.2939961751302,588.1080017089844,587.9210001627604,587.7350006103516,587.5499928792318,587.3639882405599,587.1799977620443,586.9949951171875,586.8109995524088,586.6279958089193,586.4450073242188,586.2619934082031,586.0800018310547,585.8980000813802,585.7159983317057,585.5349985758463,585.35400390625,585.1740061442057,584.9940032958984,584.8140004475912,584.634999593099,584.4560038248698,584.2779998779297,584.0999959309896,583.9220021565756,583.7450052897135,583.5679982503256,583.3909962972006,583.2149963378906,583.0399983723959,582.8639984130859,582.6890004475912,582.5139973958334,582.3400065104166,582.166005452474,581.9929911295573,581.8189951578776,581.6469930013021,581.4740041097006,581.3020070393881,581.1300048828125,580.9589996337891,580.7879994710287,580.6169993082682,580.4469960530599,580.2770080566406,580.1070098876953,579.9380035400391,579.7689971923828,579.5999959309896,579.4320068359375,579.2640024820963,579.1800079345703};
    
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.75351683298747,21.18809429804484,23.5944922765096,28.091691335042317,33.39778995513916,39.48688920338949,46.33388805389404,53.559987703959145,60.7984873453776,68.04938697814941,75.31258773803711,82.58788744608562,89.87508583068848,97.17418670654297,104.48498471577962,111.80698521931966,119.13998730977376,126.33498573303223,133.24798583984375,139.8869832356771,146.2619857788086,152.38098653157553,158.25098673502603,163.88198598225912,169.27898661295572,174.45098749796549,179.40398406982422,184.10998916625977,188.53898493448892,192.6999880472819,196.6009864807129,200.24898783365884,203.6509869893392,206.8149871826172,209.74698766072592,212.4539883931478,214.94398752848306,217.31598790486655,219.6679890950521,222.0009854634603,224.31298828125,226.60498682657877,228.8769874572754,231.12898763020834,233.36098607381186,235.57198588053384,237.76398849487305,239.92098744710287,242.02898661295572,244.088986714681,246.10398610432944,248.07598622639975,250.005983988444,251.8949851989746,253.7449862162272,255.55798467000326,257.33398691813153,259.06298573811847,260.72998809814453,262.3389841715495,263.89098358154297,265.3879903157552,266.83198801676434,268.22398885091144,269.5669860839844,270.8619867960612,272.1109873453776,273.32198333740234,274.5049819946289,275.6619822184245,276.79298909505206,277.8999837239583,278.9859873453776,280.04998779296875,281.09599049886066,282.1219838460286,283.1319859822591,284.08198801676434,284.9319839477539,285.6849873860677,286.34498596191406,286.9159876505534,287.40098571777344,287.8049850463867,288.12898508707684,288.3779881795247,288.5539855957031,288.656987508138,288.6849873860677,288.6409861246745,288.52698771158856,288.34498596191406,288.0979868570964,287.7879867553711,287.41698964436847,286.98598225911456,286.4979883829753,285.95398712158203,285.35698954264325,284.70798746744794,284.0089848836263,283.26098887125653,282.4669876098633,281.62699127197266,280.7439880371094,279.81898498535156,278.8519872029622,277.8469874064128,276.80299123128253,275.7229868570964,274.6079915364583,273.4579900105794,272.2749888102214,271.0609842936198,269.8159866333008,268.5409901936849,267.2379837036133,265.90699005126953,264.5499903361003,263.16798909505206,261.76098887125653,260.3299865722656,258.87598673502606,257.40099080403644,255.90399042765299,254.38699213663736,252.85099029541016,251.29599126180014,249.72199122111002,248.13099161783853,246.52399063110352,244.8999900817871,243.2609888712565,241.60699335734049,239.93898900349936,238.25799051920572,236.5629908243815,234.8549893697103,233.13599014282227,231.40498860677084,229.661989847819,227.9099909464518,226.14699172973633,224.37399291992188,222.59199142456055,220.8009910583496,219.00199127197266,217.1939951578776,215.37899271647134,213.5569928487142,211.72699356079102,209.89099248250326,208.0489934285482,206.20099131266275,204.3459930419922,202.48699188232422,200.6219914754232,198.75299453735352,196.87799199422201,194.99999237060547,193.11699295043945,191.2309913635254,189.33999506632486,187.44699478149414,185.54999542236328,183.64999516805014,181.7469940185547,179.84199396769205,177.93399302164713,176.02399444580078,174.11199569702148,172.19799677530924,170.2819964090983,168.36499532063803,166.44599533081055,164.52499389648438,162.6039950052897,160.6809933980306,158.7569948832194,156.8329938252767,154.90799458821616,152.98199590047201,151.05499521891275,149.12799453735352,147.20099639892578,145.27399444580078,143.34699630737305,141.41899236043295,139.49199676513672,137.56499735514322,135.63799540201822,133.71099599202475,131.78399531046549,129.8579978942871,127.93299738566081,126.00799496968587,124.0839958190918,122.1599973042806,120.23799641927083,118.3159974416097,116.3939978281657,114.47399711608887,112.55499649047852,110.63699658711751,108.71999677022298,106.80399703979492,104.88899739583333,102.97499783833821,101.06299654642741,99.15149752298991,97.24169794718425,95.3331979115804,93.42609850565593,91.52039845784505,89.61609840393066,87.71339797973633,85.81209818522136,83.91239738464355,82.01429812113444,80.11779912312825,78.22289911905925,76.32969792683919,74.43819936116536,72.54829915364583,70.6601988474528,68.77389844258626,66.88939984639485,65.00659942626953,63.12569936116537,61.246599197387695,59.36939938863119,57.494099934895836,55.62219969431559,53.75479984283447,51.89169979095459,50.03260040283203,48.17729981740316,46.35880025227865,44.60920015970866,42.925700187683105,41.30589993794759,39.74729983011881,38.24769973754883,36.80479939778646,35.41649977366129,34.080600102742515,32.79529984792074,31.558599789937336,30.36860005060832,29.223600069681805,28.12179978688558,27.061700185139973,26.04170020421346,25.060200055440266,24.115700085957844,23.20699993769328,22.332499821980793,21.491100311279297,20.681399981180828,19.902399857838947,19.152699788411457,18.431300004323322,17.737200260162354,17.069200197855633,16.426499843597412,15.807999928792318,15.212800105412802,14.640100002288818,14.08900006612142,13.55869992574056,13.048399925231934,12.557300011316935,12.084700107574463,11.630000034968058,11.192400058110556,10.771299997965494,10.366099913914999,9.97613008817037,9.60086989402771,9.239759922027588,8.892249902089437,8.557830095291138,8.236009995142618,7.9263201157252,7.628290057182312,7.341489990552266,7.065490007400513,6.799880027770996,6.544269998868306,6.298289895057678,6.061570008595784,5.8337699969609575,5.614530007044475,5.4035600026448565,5.200519998868306,5.005120038986206,4.817079981168111,4.636109987894694,4.461959958076477,4.294349988301595,4.133050044377645,3.9778199593226113,3.8284300168355307,3.684660017490387,3.546300013860067,3.413140038649241,3.2849899927775064,3.1616599758466086,3.042959988117218,2.9287299712498984,2.818790018558502,2.7129899859428406,2.6111599802970886,2.513160010178884,2.418850004673004,2.3280800183614097,2.240720013777415,2.156640032927195,2.075730005900065,1.997849980990092,1.9229000111420949,1.8507699966430664,1.781339983145396,1.7145300010840099,1.6502200067043304,1.5883299907048543,1.5287599960962932,1.4714300036430359,1.4162599941094716,1.3631500105063121,1.3120399912198384,1.262850006421407,1.2155100107192993,1.1699400047461193,1.1260900100072224,1.0838800072669983,1.0432499945163727,1.0041499982277553,0.9665180047353109,0.9302979906400045,0.8954369972149531,0.8618839979171753,0.8295900026957194,0.7985080033540726,0.768591990073522,0.7397979944944382,0.7120849986871084,0.6854110111792883,0.6597369958957037,0.6350270013014475,0.6112429996331533,0.5883519997199377,0.5663189987341563,0.5451120038827261,0.5247000058492025,0.5050540044903755,0.4861440012852351,0.4679440011580785,0.45042499899864197,0.43356400231520337,0.4173339977860451,0.4017130012313525,0.38667699694633484,0.3722049966454506,0.35827500373125076,0.34486700346072513,0.3319619993368785,0.31954000145196915,0.3075839976469676,0.296074998875459,0.2849980021516482,0.27433600276708603,0.2640729993581772,0.2541940013567607,0.24468600004911423,0.23553399865825972,0.22672400002678236,0.2182449996471405,0.2100830003619194,0.20222599928577742,0.1946639989813169,0.18738499780495962,0.18037900080283484,0.17363499850034714,0.16714299842715263,0.16089400028189024,0.1548789987961451,0.14909000073870024,0.14351700122157732,0.13815299918254217,0.13298900052905083,0.12801900009314218,0.12323399881521861,0.11862899983922641,0.11419599999984105,0.10992899971703689,0.10582199941078822,0.10186799988150597,0.09806190058588982,0.09439839919408162,0.09087199904024601,0.08747740027805169,0.0842097991456588,0.08106439995268981,0.07803670006493728,0.07512219995260239,0.07231659938891728,0.06961599985758464,0.06701640039682388,0.06451390000681083,0.062105100601911545,0.05978619990249475,0.05755409970879555,0.05540540007253488,0.053336999689539276,0.051345999663074814,0.04942929993073145,0.04758430023988088,0.04580819979310036,0.04409850047280391,0.042452700436115265,0.040868399975200496,0.03934329996506373,0.03787519969046116,0.03646190029879411,0.03510150033980608,0.033791799719134964,0.032531099704404674,0.03131749962146083,0.03014919984464844,0.0290245000893871,0.02794180018827319,0.026899599935859442,0.025896299940844376,0.024930499959737062,0.024000699787090223,0.02310570003464818,0.022243999876081944,0.021414500040312607,0.020616100014497835,0.01984740002080798,0.019107400284459192,0.01839499982694785,0.017709200425694387,0.017048999822388094,0.01641350022206704,0.01580170006491244,0.015212699848537644,0.014645699877291918,0.014099800027906895,0.013574300178637108,0.013068399935339889,0.0125813998747617,0.012112600107987722,0.011661300047611197,0.011226799882327517,0.010808499918008843,0.01040579991725584,0.010018100030720234,0.00964489004885157,0.009285589912906289,0.008939699890712896,0.008606710005551577,0.008286129993697008,0.007977509948735436,0.007680400003058215,0.007394360067943732,0.007118990062735975,0.0068538900231942534,0.00659866991918534,0.006352959938036899,0.006116410018876195,0.005888690046655635,0.005669449960502486,0.00545837990163515,0.0052551800617948174,0.005059549973035852,0.0048712099669501185,0.0046898900376011925,0.004515330035549899,0.004347269927772383,0.004185469976315896,0.004029710001001756,0.0038797400193288922,0.0037353599715667465,0.003664550002819548};
    
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76600329081218,90.27675882975261,96.35783767700195,101.92962964375813,107.85619862874348,114.1126880645752,120.67602221171062,127.00134150187175,132.58327356974283,137.47437286376953,141.72451527913412,145.37872568766275,148.47898737589517,151.06330235799155,153.1686668395996,154.82807413736978,156.07352574666342,156.95505650838217,157.5216433207194,157.7922477722168,157.78688049316406,157.52253595987955,157.01721827189127,156.28491083780924,155.34063084920248,154.1983642578125,152.87012354532877,151.41999053955078,149.90491739908853,148.32983525594076,146.69675572713217,145.00868352254233,143.26861445109049,141.48054885864258,139.6454874674479,137.76642227172852,135.84638086954752,133.97650146484375,132.23869705200195,130.625857035319,129.12600708007812,127.73415184020996,126.4392801920573,125.23740577697754,124.11951446533203,123.08062108357747,122.11471748352051,121.21680768330891,120.38289324442546,119.60897382100423,118.89004580179851,118.2251205444336,117.60918299357097,117.0402463277181,116.51430384318034,116.03035990397136,115.58440971374512,115.17846743265788,114.81251970926921,114.4835688273112,114.19061787923177,113.92965952555339,113.69970258076985,113.49873924255371,113.32377370198567,113.17480913798015,113.04883829752605,112.95989926656087,112.92096900939941,112.93003209431966,112.98309071858723,113.0781478881836,113.21320215861003,113.38525072733562,113.59129587809245,113.83134206136067,114.10138003031413,114.36434682210286,114.58227348327637,114.7602310180664,114.90117454528809,115.00813420613606,115.0840892791748,115.13305854797363,115.15601857503255,115.15499178568523,115.13396390279134,115.07289441426595,114.95581944783528,114.78775151570638,114.57168833414714,114.31062698364258,114.00857353210449,113.66852124532063,113.29147402445476,112.88243103027344,112.44238980611165,111.9743537902832,111.48031806945801,110.96128527323405,110.41925430297852,109.85622723897298,109.27520434061687,108.6751766204834,108.05815569559734,107.42713610331218,106.7811164855957,106.12109820048015,105.45008341471355,104.76806767781575,104.07505480448405,103.37304178873698,102.66203053792317,101.94302050272624,101.21600977579753,100.48300234476726,99.74379412333171,98.99858411153157,98.24807929992676,97.49277178446452,96.7331657409668,95.96956062316895,95.20225588480632,94.4317512512207,93.65814717610677,92.88194338480632,92.10324223836263,91.3224385579427,90.53963534037273,89.75503412882487,88.968931833903,88.18152936299641,87.39292844136556,86.60322697957356,85.81272506713867,85.0214246114095,84.22952334086101,83.43712298075359,82.64432271321614,81.85122426350911,81.0579210917155,80.26462173461914,79.47122192382812,78.67792256673177,77.88472112019856,77.09172248840332,76.2990239461263,75.50672340393066,74.71472358703613,73.92322413126628,73.13212458292644,72.34162521362305,71.55162620544434,70.76232846577962,69.97362836201985,69.18552843729655,68.3982302347819,67.61163075764973,66.82573254903157,66.04063415527344,65.25623385111491,64.47273635864258,63.6900364557902,62.90813763936361,62.1270383199056,61.34684054056803,60.567541440327965,59.78914260864258,59.01154327392578,58.23484420776367,57.45914649963379,56.68424701690674,55.91024875640869,55.13724994659424,54.3651507695516,53.59395249684652,52.82365290323893,52.05425516764323,51.28585624694824,50.518357276916504,49.75185934702555,48.986159324645996,48.2214609781901,47.45776240030924,46.69496377309164,45.93306509653727,45.17206637064616,44.41206709543864,43.65296904246012,42.894869804382324,42.137670834859215,41.381372133890785,40.62597370147705,39.87157471974691,39.11807632446289,38.36557801564535,37.61397933959961,36.86327997843424,36.11348088582357,35.364682833353676,34.61678377787272,33.86978499094645,33.12378660837809,32.37868690490723,31.634488423665363,30.891290028889973,30.14889129002889,29.407492478688557,28.667093912760418,27.927495002746582,27.18889617919922,26.451197783152264,25.7144988377889,24.978600184122723,24.243701140085857,23.50980234146118,22.77670383453369,22.044605096181233,21.313406626383465,20.583207607269287,19.853909174601238,19.125510056813557,18.398011207580566,17.671512921651203,16.946014086405437,16.221315304438274,15.497716585795084,14.774917682011923,14.05311910311381,13.33232037226359,12.61242151260376,11.89352305730184,11.176125605901083,10.460928281148275,9.747410933176676,9.035521348317465,8.325016339619955,7.644263585408528,7.019244949022929,6.445369799931844,5.918463031450908,5.434669653574626,4.9904621839523315,4.582600275675456,4.208104411760966,3.8642449378967285,3.5485122203826904,3.2586063543955484,2.992407739162445,2.747976541519165,2.52353298664093,2.3174372712771096,2.1281895637512207,1.9544100364049275,1.7948388357957203,1.6483060816923778,1.5137519439061482,1.390186458826065,1.2767198185125987,1.1725221276283264,1.0768333772818248,0.9889627148707708,0.908269206682841,0.8341659406820933,0.7661139418681463,0.7036182979742686,0.6462250451246897,0.5935172438621521,0.5451129426558813,0.5006581693887711,0.4598329762617747,0.42233938227097195,0.38790542632341385,0.3562801480293274,0.32723656793435413,0.30056169132391614,0.27606358130772907,0.25356321906050044,0.2328986550370852,0.21391988173127174,0.1964879296720028,0.18047781164447466,0.1657735382517179,0.15226812536517778,0.13986358170708021,0.1284709187845389,0.11800615179042022,0.10839527907470863,0.09956721651057403,0.09145876889427502,0.08401114493608475,0.07717044589420159,0.07088708380858104,0.06511576194316149,0.05981458413104216,0.0549453559021155,0.050472780441244446,0.04636446262399355,0.042590905291338764,0.03912461238602797,0.035940585657954216,0.03301592916250229,0.03032934417327245,0.027861634114136297,0.025594799624135096,0.023512444458901882,0.021599768350521725,0.019842674179623526,0.018228663907696802,0.016746037794897955,0.015383997078364095,0.014132844128956398,0.012983578955754638,0.011927802581340075,0.01095791618960599,0.010066920658573508,0.009248456684872508,0.008496564735348025,0.007805845816619694,0.007171310135163367,0.0065883984401201206,0.0060528912193452316,0.005560938889781634,0.0051089918706566095,0.0046938003894562525,0.004312375172351797,0.003961966237208496,0.003640043937290708,0.0033442985344057283,0.003072590373146037,0.0028229796056014798,0.002593656477984041,0.0023829711329502365,0.002189413799593846,0.0020115846515788385,0.0018482037509481113,0.0016981113488630701,0.0015602074660516034,0.001433512312360108,0.0013171159468280773,0.0012101684405934066,0.0011119199528669317,0.0010216405062237754,0.00093870323325973,0.0008625011299348747,0.000792489333737952,0.0007281628544054305,0.0006690617738058791,0.0006147601234260947,0.0005648679604443411,0.0005190273222979158,0.0004769092532418047,0.0004382117816324656,0.0004026549383221815,0.0003699857576672609,0.0003399682682356797,0.0003123874994344078,0.000287045457904848,0.00026376118330517784,0.0002423656806058716,0.00022270798096239255,0.00020464509119240878,0.00018804803403327242,0.00017279681075403155,0.0001587844538638213,0.0001459089556495504,0.00013407733907418637,0.00012320661335252225,0.00011321677690527092,0.00010403785139108852,9.560393664287403e-05,8.785374181267495e-05,8.073227460651348e-05,7.418833956762683e-05,6.817514076828957e-05,6.26495866526966e-05,5.757217907860953e-05,5.290652431237201e-05,4.8619124754623044e-05,4.467938530675989e-05,4.105900795063159e-05,3.7732196688011754e-05,3.467515398369869e-05,3.186588188934062e-05,2.9284282694182668e-05,2.6912059941726813e-05,2.473201432925028e-05,2.2728748414616955e-05,2.088776303329117e-05,1.9195960855237597e-05,1.7641341855778592e-05,1.6212608898058534e-05,1.4899762087831428e-05,1.3693202921179667e-05,1.2584432245906404e-05,1.1565451207691998e-05,1.062906062543334e-05,9.768510835783673e-06,8.977673132903874e-06,8.250897811497756e-06,7.582985896685083e-06,6.969177510048515e-06,6.40508335436607e-06,5.886663757337374e-06,5.4102293537046835e-06,4.972380452272773e-06,4.5699874059816166e-06,4.200170527231724e-06,3.860300087884146e-06,3.5479465244255457e-06,3.2608699787791315e-06,2.9970508042727792e-06,2.7545790430849593e-06,2.531734973369263e-06,2.3269288931260235e-06,2.138700835985219e-06,1.96570102654429e-06,1.8067095481910656e-06,1.6605765627749254e-06,1.5262822140963788e-06,1.40284659740549e-06,1.2893998283895296e-06,1.1851319735948589e-06,1.089293154639866e-06,1.0012234194315777e-06,9.20266832811952e-07,8.458625112931865e-07,7.774774767691875e-07,7.146237900694056e-07,6.56854524549999e-07,6.037577170066774e-07,5.549543876289439e-07,5.100986252652243e-07,4.688704251520903e-07,4.3097583339128204e-07,3.961458882410322e-07,3.6413161789520626e-07,3.347060489507688e-07,3.076601942098023e-07,2.828000944532505e-07,2.5995075484767466e-07,2.38948196340516e-07,2.196424446765377e-07,2.0189851213103793e-07,1.8558840745678631e-07,1.7059615468421421e-07,1.5681575978495252e-07,1.441492318103125e-07,1.3250658762823755e-07,1.2180483288659616e-07,1.1196697613513606e-07,8.643155228564107e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.742482980092365,19.401511669158936,20.791117350260418,23.315719922383625,26.238722642262776,29.552324771881104,33.24912563959757,37.15692647298177,41.10732650756836,45.09962749481201,49.13302834828695,53.20682875315348,57.32012971242269,61.47243022918701,65.66283130645752,69.89073181152344,74.15533192952473,78.39263153076172,82.53953107198079,86.59793154398601,90.56943194071452,94.45583279927571,98.25863202412923,101.98003005981445,105.62003008524577,109.18103154500325,112.66503016153972,116.04903157552083,119.3090311686198,122.44903055826823,125.46902910868327,128.37202962239584,131.16102854410806,133.83602905273438,136.40102767944336,138.85602951049805,141.20402908325195,143.49502817789713,145.77602895100912,148.04703013102213,150.30902862548828,152.56202824910483,154.8040313720703,157.03702799479166,159.2590306599935,161.47203063964844,163.67403030395508,165.86103312174478,168.02803166707358,170.17603174845377,172.3040339152018,174.41303253173828,176.50403340657553,178.57703145345053,180.63203303019205,182.67002868652344,184.69203186035156,186.6880315144857,188.65103149414062,190.5800348917643,192.47803370157877,194.34403228759766,196.17903264363608,197.98303349812826,199.7580312093099,201.50303268432617,203.21903483072916,204.90703328450522,206.57003275553384,208.20703252156576,209.82003275553384,211.4080327351888,212.9740333557129,214.51703262329102,216.03803380330405,217.53803507486978,219.01803334554037,220.45403289794922,221.8220329284668,223.1250343322754,224.36403528849283,225.54003270467123,226.65503311157227,227.71003087361655,228.7080307006836,229.64803187052408,230.53303146362305,231.36203002929688,232.1340306599935,232.85003280639648,233.5110295613607,234.1180305480957,234.67203267415366,235.17503102620444,235.6270294189453,236.0290298461914,236.38203048706055,236.68802769978842,236.94602966308594,237.15902964274088,237.32702763875326,237.45002873738608,237.5310287475586,237.56902821858725,237.5650291442871,237.52102661132812,237.43802769978842,237.31502787272134,237.15402603149414,236.95602416992188,236.72102737426758,236.45002619425455,236.1440289815267,235.80402628580728,235.431027730306,235.02402369181314,234.58502451578775,234.1150245666504,233.6140276590983,233.08202616373697,232.52102533976236,231.93102391560873,231.31302642822266,230.6670239766439,229.99402364095053,229.2950210571289,228.57002385457358,227.81902186075845,227.04402287801108,226.244021097819,225.4200210571289,224.5740229288737,223.70502344767252,222.81302134195963,221.90002059936523,220.96601994832358,220.01101938883463,219.0360196431478,218.04102198282877,217.02602005004883,215.99302291870117,214.94202041625977,213.87201690673828,212.78501892089844,211.6800193786621,210.55901845296225,209.42102177937826,208.26701736450195,207.09801737467447,205.9140192667643,204.71401723225912,203.5000203450521,202.2720184326172,201.03001912434897,199.77401733398438,198.5050163269043,197.22401809692383,195.93001556396484,194.62301635742188,193.30501810709634,191.97501627604166,190.63401667277017,189.2810147603353,187.9180145263672,186.54401270548502,185.1600138346354,183.76601282755533,182.36301549275717,180.95001347859701,179.5270118713379,178.09601465861002,176.65601348876953,175.20701471964517,173.7500114440918,172.28501256306967,170.8120142618815,169.33201217651367,167.84401194254556,166.34801483154297,164.84601211547852,163.3370132446289,161.8210105895996,160.2980105082194,158.7700080871582,157.23501205444336,155.69401041666666,154.14801025390625,152.59500885009766,151.0380096435547,149.4750099182129,147.90700912475586,146.3340072631836,144.75601196289062,143.1730079650879,141.58600743611655,139.99500783284506,138.39900970458984,136.79900741577148,135.19500605265299,133.58700815836588,131.97600936889648,130.36100641886392,128.74200630187988,127.1200065612793,125.49500592549641,123.86600748697917,122.23500696818034,120.60000483194987,118.96300633748372,117.32300504048665,115.68000602722168,114.03500429789226,112.3880049387614,110.73800404866536,109.08600362141927,107.43100357055664,105.77500470479329,104.11700503031413,102.45600446065266,100.79400380452473,99.13070297241211,97.46530278523763,95.79840278625488,94.13000170389812,92.46020253499348,90.7891019185384,89.11680221557617,87.44330088297527,85.76860173543294,84.09290250142415,82.41630109151204,80.73880004882812,79.0616003672282,77.38580067952473,75.71120198567708,74.03790028889973,72.3656997680664,70.71320088704427,69.09849993387859,67.52090009053548,65.97939999898274,64.47320016225179,63.00150012969971,61.56359990437826,60.158600171407066,58.78569984436035,57.4443998336792,56.13369941711426,54.85309982299805,53.601800282796226,52.37909984588623,51.184399922688804,50.017099698384605,48.87650044759115,47.76200008392334,46.67299938201904,45.60889975229899,44.569199879964195,43.55320008595785,42.560499827067055,41.590499560038246,40.64269987742106,39.71649996439616,38.81159973144531,37.92729981740316,37.06319999694824,36.218899726867676,35.39380041758219,34.58760007222494,33.799899419148765,33.03010050455729,32.27789990107218,31.542899926503498,30.824699878692627,30.122899850209553,29.437099933624268,28.7669997215271,28.11210012435913,27.472300211588543,26.847000281016033,26.236000061035156,25.63890027999878,25.055500030517578,24.4853998819987,23.92830006281535,23.38390000661214,22.851900100708008,22.332100073496502,21.824100017547607,21.32770013809204,20.842600345611572,20.368600209554035,19.90540011723836,19.45270013809204,19.01039997736613,18.578199863433838,18.155799865722656,17.7430001894633,17.33970006306966,16.94550021489461,16.56030003229777,16.183900038401287,15.816099961598715,15.456700007120768,15.105400005976358,14.762199878692627,14.426699876785278,14.098900000254313,13.778600056966146,13.46559993426005,13.159700075785318,12.86080002784729,12.568600098292032,12.283199946085611,12.004199981689453,11.731599966684977,11.465099891026815,11.204799811045328,10.95039987564087,10.70170005162557,10.458700021107992,10.22130012512207,9.98926011721293,9.762490113576254,9.540889978408813,9.32433009147644,9.112690130869547,8.905869960784912,8.703759908676147,8.506240129470825,8.313209931055704,8.124580144882202,7.940229932467143,7.760079979896545,7.584019939104716,7.411970019340515,7.243830005327861,7.0795100927352905,6.918930013974507,6.761990030606587,6.608630021413167,6.458749969800313,6.312279979387919,6.169140021006267,6.029250065485637,5.892539978027344,5.758930087089539,5.628359953562419,5.500759919484456,5.376059929529826,5.254190007845561,5.135089993476868,5.018700003623962,4.904949943224589,4.793780008951823,4.685139973958333,4.578959981600444,4.475200017293294,4.3737899462382,4.27468999226888,4.17783002058665,4.083180030186971,3.9906699657440186,3.9002700050671897,3.811910013357798,3.725570023059845,3.6411800185839334,3.558709998925527,3.4781099756558738,3.399340013662974,3.3223499854405723,3.2471200227737427,3.1735900243123374,3.101730008920034,3.0315000216166177,2.9628599882125854,2.8957899610201516,2.8302300373713174,2.766159991423289,2.7035399874051413,2.6423499981562295,2.5825400153795877,2.524089992046356,2.4669600129127502,2.4111299912134805,2.356570025285085,2.3032400210698447,2.2511200110117593,2.2001799742380777,2.150400002797445,2.1017500162124634,2.054199993610382,2.0077299773693085,1.962309996287028,1.9179200033346813,1.8745400210221608,1.8321399887402852,1.790699988603592,1.7501999934514363,1.710619995991389,1.6719399988651276,1.6341299911340077,1.597179998954137,1.5610600213209789,1.5257699986298878,1.49127001563708,1.457559992869695,1.4246099988619487,1.3924000163873036,1.3609300057093303,1.330159991979599,1.3000999887784321,1.2707099914550781,1.2420000036557515,1.2139299909273784,1.1864899893601735,1.159679998954137,1.1334800124168396,1.1078700125217438,1.0828300019105275,1.0583700040976207,1.0344600180784862,1.011089990536372,0.9882459988196691,0.9659220029910406,0.9441030025482178,0.9227780054012934,0.9019359995921453,0.8815649996201197,0.8616560051838557,0.8421960026025772,0.8231779982646307,0.8045890033245087,0.786421000957489,0.7686639974514643,0.751309002439181,0.734345997373263,0.7177670001983643,0.7015629957119623,0.6857250034809113,0.6702460000912348,0.6551170001427332,0.6403300066788992,0.6258770028750101,0.6117510000864664,0.5979449997345606,0.5844499965508779,0.571261003613472,0.558369999130567,0.5457709928353628,0.5334559977054596,0.5214199970165888,0.5096550037463506,0.49815699954827625,0.48691900074481964,0.4759340013066928,0.46519800275564194,0.45470399657885235,0.44444800168275833,0.43442299713691074,0.4246249968806903,0.4150480007131894,0.40568800270557404,0.39653899768988293,0.3875970020890236,0.37885700166225433,0.37031400203704834,0.3619639997680982,0.35380300134420395,0.34582600245873135,0.33803000301122665,0.3304090003172557,0.3229610001047452,0.31568100303411484,0.30856499820947647,0.30160999794801074,0.2948119988044103,0.28816699981689453,0.28167200088500977,0.2753250002861023,0.2691200027863185,0.263054999212424,0.25712799777587253,0.25133399789532024,0.2456709990898768,0.24287199974060059};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.472873290379842,7.644658486048381,7.736824989318848,7.896193742752075,8.090470234553019,8.302513480186462,8.523769299189249,8.611376206080118,8.489504337310791,8.256845474243164,7.965440591176351,7.6425661245981855,7.302604873975118,6.95316485563914,6.598288615544637,6.240166425704956,5.8798545598983765,5.560949166615804,5.30641786257426,5.08513617515564,4.880735794703166,4.684692303339641,4.492545406023662,4.302013993263245,4.111921429634094,3.9217368165651956,3.731160044670105,3.5629283785820007,3.429285943508148,3.3138782183329263,3.2080203096071878,3.107122222582499,3.0087575912475586,2.9116758505503335,2.8152137200037637,2.719075858592987,2.6230806907018027,2.5443559686342874,2.492019693056742,2.4536792238553367,2.4227048754692078,2.3956087827682495,2.3705250223477683,2.3465032974878945,2.3230023781458535,2.2997819582621255,2.276701549688975,2.254419128100077,2.2333165208498635,2.212945302327474,2.193064272403717,2.1735236644744873,2.15425306558609,2.135202646255493,2.116352160771688,2.097671846548716,2.0791613260904946,2.061747988065084,2.0458746353785195,2.0308633943398795,2.016342371702194,2.002121885617574,1.9881014327208202,1.9742410977681477,1.9605108201503754,1.946890652179718,1.9333802064259846,1.9220630725224812,1.9140459696451824,1.9078235427538555,1.9026012619336445,1.8979804515838623,1.8937395513057709,1.8897691071033478,1.8860185742378235,1.8824382722377777,1.8790179193019867,1.872528612613678,1.8612985014915466,1.8477312326431274,1.833053896824519,1.8178740839163463,1.8025047878424327,1.7870845099290211,1.7716946303844452,1.7563645541667938,1.7411041259765625,1.726681371529897,1.7134391566117604,1.7007881999015808,1.6884176929791768,1.6761775016784668,1.6639874080816905,1.651817411184311,1.6396473745505016,1.6274774074554443,1.615287443002065,1.6030874649683635,1.5908774932225545,1.578657478094101,1.5664375027020772,1.5542074938615162,1.5419775048891704,1.529737522204717,1.5175074934959412,1.5052774945894878,1.4930474758148193,1.4808274706204732,1.4685974915822346,1.4563774466514587,1.4441674451033275,1.4319574137528737,1.4197573959827423,1.4075673818588257,1.3953873713811238,1.3832073509693146,1.37104727824529,1.3588972985744476,1.3467572430769603,1.334627240896225,1.3224972387154896,1.3103871742884319,1.2982871532440186,1.2862071295579274,1.2741271058718364,1.2620670596758525,1.250017027060191,1.237986981868744,1.2259669601917267,1.213966925938924,1.2019669115543365,1.1899868647257488,1.1780168513456981,1.1660667955875397,1.1541267832120259,1.1421967446804047,1.1302867035071056,1.1183866659800212,1.1065066357453663,1.094636599222819,1.0827865600585938,1.0709465444087982,1.059116502602895,1.0473064581553142,1.035516396164894,1.023736407359441,1.0119763265053432,1.0002263089021046,0.9885002573331197,0.9767852524916331,0.9650891969601313,0.9534111420313517,0.9417461107174555,0.9300950765609741,0.9184600412845612,0.9068400164445242,0.8952349672714869,0.8836459318796793,0.8720719069242477,0.8605138609806696,0.8489708304405212,0.8374437888463339,0.8259337395429611,0.8144416958093643,0.8029626707235972,0.7914966394503912,0.7800456037123998,0.7686095635096232,0.757188523809115,0.7457814961671829,0.734389454126358,0.7230134258667628,0.7116503914197286,0.7003063360850016,0.6889783143997192,0.6776622831821442,0.6663602441549301,0.6550722122192383,0.6437981724739075,0.6325391481320063,0.6212941110134125,0.6100630760192871,0.5988470415274302,0.587645004192988,0.5764569739500681,0.5652869244416555,0.55413289864858,0.5429898649454117,0.531860833366712,0.5207448055346807,0.5096437707543373,0.4985557322700818,0.4874827067057292,0.4764236609141032,0.46537862966458005,0.4543475955724716,0.44333355377117795,0.4323355183005333,0.42134949068228406,0.41037645439306897,0.3994174276789029,0.3884713922937711,0.37754035741090775,0.36662232627471286,0.35571929067373276,0.3448302522301674,0.33395522832870483,0.3230941866834958,0.31225114564100903,0.3014231075843175,0.290608083208402,0.2798050542672475,0.2690170134107272,0.25824198375145596,0.2474809450407823,0.23673491552472115,0.2260028744737307,0.21528584385911623,0.20458280916015306,0.19389776388804117,0.18322872991363207,0.1725717025498549,0.16192766651511192,0.15129862974087396,0.1406835988163948,0.13008256504933038,0.11949752519528072,0.10892649367451668,0.09837085443238418,0.0878300213565429,0.07730418257415295,0.06679773641129334,0.05632811691612005,0.04589191637933254,0.035464446836461626,0.025034591710815828,0.014595107330630222,0.006897938748200734,0.0032576546266985438,0.0015394905543265243,0.0007272248961574709,0.0003436880106164608,0.00016238442791897492,7.67505061958218e-05,3.626941073283282e-05,1.7144620263328154e-05,8.103242824593812e-06,3.830905105436007e-06,1.8109335352770965e-06,8.56255094087525e-07,4.0482699622164847e-07,1.9143888252415309e-07,3.824641462794413e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.091137985388438,1.2003816664218903,1.2826015551884968,1.393411636352539,1.515051782131195,1.6472219030062358,1.7896519005298615,1.9346518913904827,2.074781914552053,2.2101818720499673,2.3409918745358786,2.4673218528429666,2.5893218517303467,2.7071118354797363,2.8208018143971763,2.930521825949351,3.036361793677012,3.1370617548624673,3.231391708056132,3.3195117314656577,3.401591638724009,3.4778016010920205,3.548271576563517,3.6131815314292908,3.6726615031560264,3.726851463317871,3.7759114503860474,3.8203614155451455,3.8607314030329385,3.8971113562583923,3.929611325263977,3.9583113193511963,3.9833112557729087,4.0047012368837995,4.022581259409587,4.037031213442485,4.048131187756856,4.056981245676677,4.064651131629944,4.071171164512634,4.076541105906169,4.080811142921448,4.083991090456645,4.086111068725586,4.087201118469238,4.087271094322205,4.086341142654419,4.084381182988484,4.0813411474227905,4.077251036961873,4.072151064872742,4.0660810470581055,4.059070984522502,4.051160971323649,4.042370994885762,4.032731016476949,4.02229102452596,4.011090993881226,3.999211092789968,3.986670990784963,3.9734909931818643,3.9597010215123496,3.945310970147451,3.9303409655888877,3.914820969104767,3.8987709482510886,3.882210930188497,3.8653409481048584,3.8484009504318237,3.8314009308815002,3.8143309156099954,3.797230899333954,3.7801009019215903,3.7629409035046897,3.7457709113756814,3.7286009192466736,3.711440940697988,3.693980892499288,3.675930897394816,3.6573208769162497,3.638170858224233,3.618510822455088,3.598340849081675,3.5777008334795632,3.5566108425458274,3.535070816675822,3.513120790322622,3.4910008112589517,3.468960781892141,3.446980814139048,3.425070822238922,3.403220772743225,3.381430764993032,3.359700779120127,3.3380207419395447,3.3164007663726807,3.2948207457860312,3.273290733496348,3.2518107692400613,3.2303707599639893,3.2089607318242392,3.1876007517178855,3.166280726591746,3.144990702470144,3.1237406730651855,3.102520704269409,3.081340710322062,3.060190717379252,3.0390806794166565,3.01799068848292,2.996940632661184,2.9759106636047363,2.954920689264933,2.933950662612915,2.9130106965700784,2.8921006123224893,2.871220648288727,2.850360651810964,2.8295306166013083,2.8087306221326194,2.787950654824575,2.7672006090482077,2.7464806040128074,2.7257806261380515,2.7051105896631875,2.684460620085398,2.6638406117757163,2.6432405908902488,2.6226705511411033,2.602120598157247,2.5815905729929605,2.5610905289649963,2.5406105717023215,2.5201605757077536,2.4997305671374,2.479330539703369,2.4589505394299827,2.438600540161133,2.4182705084482827,2.3979605038960776,2.377680520216624,2.3574205438296,2.337180495262146,2.3169705073038735,2.296780526638031,2.276610473791758,2.2564704616864524,2.2363504568735757,2.2162604928016663,2.1962004701296487,2.1761504411697388,2.156140466531118,2.136140445868174,2.1161704063415527,2.096230467160543,2.076310416062673,2.056410471598307,2.036540389060974,2.016690452893575,1.996860424677531,1.9770603974660237,1.957290420929591,1.9375403821468353,1.917820394039154,1.8981203734874725,1.878440390030543,1.8587903678417206,1.8391603827476501,1.8195603589216869,1.7999803523222606,1.7804303467273712,1.7609003484249115,1.7413903375466664,1.7219103475411732,1.7024503350257874,1.683020333449046,1.6636103093624115,1.6442303160826366,1.6248702903588612,1.6055403053760529,1.5862302978833516,1.5669403076171875,1.5476803084214528,1.5284402867158253,1.5092202723026276,1.4900302787621815,1.4708602527777355,1.4517202476660411,1.432600239912669,1.4135002593199413,1.3944302399953206,1.375380237897237,1.3563602368036907,1.3373602330684662,1.3183802167574565,1.299430211385091,1.2805002232392628,1.2615902225176494,1.2427101929982503,1.2238401969273884,1.2050102055072784,1.1861901879310608,1.1674001812934875,1.1486301918824513,1.129890153805415,1.1111701826254528,1.0924801627794902,1.0738001664479573,1.055150141318639,1.0365201433499653,1.017910122871399,0.999331126610438,0.9807701210180918,0.9622321228186289,0.9437161187330881,0.9252231121063232,0.9067551046609879,0.8883110880851746,0.8698890954256058,0.8514900902907053,0.8331140826145808,0.8147600740194321,0.7964280744393667,0.7781190623839697,0.7598320692777634,0.741568053762118,0.7233260522286097,0.7051060448090235,0.686909039815267,0.6687350322802862,0.6505850305159887,0.6324600179990133,0.6143710166215897,0.5963300168514252,0.5783330053091049,0.5603790034850439,0.542464996377627,0.5248630146185557,0.507832000652949,0.4913560003042221,0.47541599969069165,0.45999400069316226,0.445073996980985,0.43063900123039883,0.41667299966017407,0.4031620000799497,0.3900900011261304,0.3774430031577746,0.3652070015668869,0.35336799671252567,0.3419149989883105,0.33083399881919223,0.3201120023926099,0.30973999947309494,0.2997040053208669,0.2899939964214961,0.2805989980697632,0.27151000251372653,0.26271600276231766,0.2542070001363754,0.24597500016291937,0.23800900081793466,0.23030299817522368,0.2228459989031156,0.21563199907541275,0.20865100001295409,0.20189700027306876,0.19536200041572252,0.18904000024000803,0.1829219994445642,0.17700299993157387,0.17127499853571257,0.16573399926225343,0.16037200142939886,0.15518400197227797,0.15016399944821993,0.1453070007264614,0.1406070018808047,0.1360590010881424,0.1316590023537477,0.12740199888745943,0.12328299942115943,0.11929700026909511,0.1154399998486042,0.11170799968143304,0.10809699942668279,0.10460299936433633,0.10122200039525826,0.0979502002398173,0.09478470000127952,0.09172169926265876,0.08875789927939574,0.08589000006516774,0.08311500089863937,0.0804297998547554,0.07783149927854538,0.07531730023523171,0.07288450002670288,0.07053040030101936,0.06825250138839085,0.06604829927285512,0.06391540107627709,0.061851500843962036,0.05985429976135492,0.05792179983109236,0.0560517997170488,0.05424219990770022,0.052491200156509876,0.050796799982587494,0.04915720007071892,0.04757069982588291,0.04603539997090896,0.04454970049361388,0.04311210010200739,0.04172099971522888,0.04037479994197687,0.03907210038354,0.037811500020325184,0.03659169965734085,0.03541129951675733,0.03426900009314219,0.03316369963188966,0.03209399959693352,0.031059000175446272,0.030057299882173538,0.02908799983561039,0.028150000299016636,0.027242399752140045,0.02636400004848838,0.025514000250647467,0.024691499924908083,0.023895500072588522,0.02312519991149505,0.022379799901197355,0.0216584000736475,0.020960400036225717,0.020284799858927727,0.01963110004241268,0.01899849980448683,0.01838629987711708,0.017793900178124506,0.01722059988727172,0.016665799853702385,0.016128799878060818,0.015609300074477991,0.015106400086854896,0.01461980010693272,0.014148900052532554,0.013693199958652258,0.013252199860289693,0.012825400025273362,0.012412400062506398,0.012012699929376444,0.011625900010888776,0.011251599993556738,0.010889299912378192,0.01053870003670454,0.010199500092615684,0.009871139967193207,0.00955339016703268,0.009245890037467083,0.008948299878587326,0.008660300013919672,0.008381580002605915,0.008111850048104921,0.007850809992911914,0.007598190025116007,0.007353699998930097,0.0071170999823759,0.006888119969516993,0.006666519950764875,0.006452050021228691,0.006244500012447436,0.006043640004160504,0.005849239998497069,0.005661110044457018,0.005479030078276992,0.0053028300171718,0.00513228999140362,0.00496724989109983,0.004807530087418854,0.00465294998139143,0.004503339994698763,0.004358550029185911,0.004218430064308147,0.00408281999019285,0.003951569980320831,0.0038245500375827155,0.0037016199979310236,0.0035826399883565805,0.0034674900234676898,0.0033560500014573336,0.0032481999951414764,0.0031438199803233147,0.003042800002731383,0.00294502997227634,0.0028503999734918275,0.002758819959126413,0.0026701899672237537,0.0025843999659021697,0.002501379989553243,0.002421029998610417,0.002343259984627366,0.002268000040203333,0.002195149970551332,0.002124649977001051,0.0020564200434212885,0.0019903799790578582,0.0019264699852404494,0.001864610016734029,0.001804739993531257,0.0017467900082313765,0.0016907100022460024,0.0016364299905641626,0.0015838900095938395,0.0015330500027630478,0.0014838399947620928,0.0014362100046128035,0.0013901099931293477,0.0013454899890348315,0.0013023100036662072,0.0012605200075389196,0.0012200699905709673,0.0011809199932031333,0.0011430199956521392,0.0011063499841839075,0.0010708499952064205,0.0010364900226704776,0.0010032400023192167,0.0009710560067712019,0.0009399050031788647,0.0009097550015818948,0.0008805740023187051,0.0008523299960264316,0.0008249929960584268,0.0007985339955970024,0.0007729239975257466,0.0007481380113555739,0.0007241470060156038,0.0007009260055686658,0.0006784509945039948,0.0006566979961159328,0.0006356429997443532,0.0006152639883415153,0.0005955399974482134,0.0005764480010839179,0.0005579699888282145,0.0005400840018410236,0.0005227729949789742,0.0005060170030143732,0.0004897990002064034,0.0004741019971940356,0.0004589080005340899,0.0004442019999260083,0.00042996799796431634,0.00041619000209417817,0.0004028550004780603,0.00038994699813580763,0.00037745300263244036,0.0003653609989366184,0.00035365599615033716,0.00034232699787632254,0.0003313609995529987,0.0003207469975071338,0.00031047299610994134,0.0003005290006209786,0.00029090299843422446,0.00028158700054821867,0.0002725690016328978,0.0002638399989033739,0.0002553919985075481,0.00024721400647346553,0.0002392980010578564,0.00023163600053521805,0.00022421999892685562,0.0002170409995111792,0.00021009300204847628,0.00020336700132853972,0.00019685700074963583,0.00019055599962788014,0.00018445600047319508,0.00017855199985206127,0.00017283800237540467,0.00016730600085187083,0.00016195199835541038,0.00015931799983566938};
    
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.94631751378377,28.906192779541016,29.846494674682617,30.639695803324383,31.229597568511963,31.617198308308918,31.803298791249592,31.879798730214436,31.93799877166748,31.97799889246623,31.99989938735962,32.00379912058512,31.989699363708496,31.957699457804363,31.907899697621662,31.840399901072185,31.755199909210205,31.660199483235676,31.56339963277181,31.464799722035725,31.364299774169922,31.261999766031902,31.157699584960938,31.051599820454914,30.943599541982014,30.83370002110799,30.72189998626709,30.608700116475422,30.49459966023763,30.379500071207683,30.26349973678589,30.146499792734783,30.028500080108643,29.909599939982098,29.789699872334797,29.66890001296997,29.547000249226887,29.424599806467693,29.302199999491375,29.17959992090861,29.057000001271565,28.934300263722736,28.811399936676025,28.688499927520752,28.56539996465047,28.44230016072591,28.318999926249187,28.19569985071818,28.0724999109904,27.949400107065838,27.82639980316162,27.70349995295207,27.5807998975118,27.45810031890869,27.335599899291992,27.213300069173176,27.091100215911865,26.9690998395284,26.84720007578532,26.72559992472331,26.604100068410236,26.482800165812176,26.3618000348409,26.240900198618572,26.12030013402303,25.999900023142498,25.879599889119465,25.759699821472168,25.639999866485596,25.520699977874756,25.401700019836426,25.283099969228108,25.164799849192303,25.046799818674724,24.929200172424316,24.811999956766766,24.695200125376385,24.578800042470295,24.46269989013672,24.347100257873535,24.231899897257488,24.117000102996826,24.00260019302368,23.88859971364339,23.775099913279217,23.66189988454183,23.54920021692912,23.437000274658203,23.325299898783367,23.214000066121418,23.103299776713055,22.992999871571858,22.88320016860962,22.773900190989178,22.66509993871053,22.556699911753338,22.44890038172404,22.341399987538654,22.23449977238973,22.128000100453693,22.022000312805176,21.91639995574951,21.81130011876424,21.706600030263264,21.602400461832683,21.498600006103516,21.395300070444744,21.2924002011617,21.189900080362957,21.087899843851726,20.986300309499104,20.885199705759685,20.78439998626709,20.68409999211629,20.584300359090168,20.48480002085368,20.385800043741863,20.28720013300578,20.18899981180827,20.091300010681152,19.993900140126545,19.896999994913738,19.80049991607666,19.704400380452473,19.608699798583984,19.513399600982666,19.418499787648518,19.324000040690105,19.230000336964924,19.136299928029377,19.042999903361004,18.95009994506836,18.85759989420573,18.765599886576336,18.67390012741089,18.582600116729736,18.491700172424316,18.40109984079997,18.310999870300293,18.221299807230633,18.13189999262492,18.042899926503498,17.954299608866375,17.86609999338786,17.778300285339355,17.690800348917644,17.603700002034504,17.517000198364258,17.430699984232586,17.34470017751058,17.25909996032715,17.17389980951945,17.08910020192464,17.004600048065186,16.920499960581463,16.836699803670246,16.753300189971924,16.670300324757893,16.587600072224934,16.50529972712199,16.423399766286213,16.341800053914387,16.260599931081135,16.179700056711834,16.099199930826824,16.018999973932903,15.939200003941854,15.859699885050455,15.780599991480509,15.701800028483072,15.62340005238851,15.545300006866455,15.46750013033549,15.390099922815958,15.31309994061788,15.23639996846517,15.160000085830688,15.083899974822998,15.0082000096639,14.932799895604452,14.857800006866455,14.783100128173828,14.708700021107992,14.634600003560385,14.56090005238851,14.487499952316284,14.414400021235148,14.341700156529745,14.269299983978271,14.197199980417887,14.125399827957153,14.053900082906088,13.982800086339315,13.911900202433268,13.841399987538656,13.77120010058085,13.701299985249838,13.631800174713135,13.5625,13.493599971135458,13.42489997545878,13.356600046157837,13.28849999109904,13.220800081888834,13.15339994430542,13.086199839909872,13.019399960835775,12.952900012334188,12.886699914932251,12.8207000096639,12.755100011825562,12.689800182978312,12.624699910481771,12.560000022252401,12.495499849319458,12.431300004323324,12.367400089899698,12.303900003433228,12.24049997329712,12.177499930063883,12.114799896876017,12.052300135294596,11.990100065867106,11.928200006484985,11.866599877675375,11.805300076802572,11.744200150171915,11.68340015411377,11.622900009155273,11.562699953715006,11.502700010935465,11.442999998728434,11.383599996566772,11.324600060780844,11.265899976094564,11.207500060399374,11.149499893188477,11.09179981549581,11.03439998626709,10.977300008138021,10.920499960581461,10.864000161488852,10.80779997507731,10.751799901326498,10.696199973424276,10.640900055567423,10.58589998881022,10.531099875768026,10.476699908574423,10.422499895095825,10.368600050608316,10.314999977747599,10.261699914932251,10.208700021107992,10.155900001525879,10.103399833043417,10.051199992497763,9.999300003051758,9.947640101114908,9.896249930063883,9.84512988726298,9.794280052185059,9.743690013885498,9.69336994489034,9.643320083618164,9.59353001912435,9.54399005572001,9.494720141092936,9.445709864298502,9.396950006484985,9.348449865976969,9.30020006497701,9.25220012664795,9.204460064570108,9.156959931055704,9.109710057576498,9.062710046768188,9.015959898630777,8.969450076421102,8.923180023829142,8.877159913380941,8.831369956334433,8.78582994143168,8.740520000457764,8.695450067520142,8.650620063145956,8.606019973754883,8.561650117238363,8.517509937286377,8.473600149154663,8.429929971694946,8.3864799340566,8.343259970347086,8.300259987513224,8.257489919662476,8.214939912160238,8.17261004447937,8.130499998728434,8.08861001332601,8.046939849853516,8.005489945411682,7.96425998210907,7.923240025838216,7.8824299573898315,7.841829975446065,7.80145005385081,7.761280020078023,7.721309979756673,7.681559960047404,7.642009973526001,7.602669914563497,7.563530007998149,7.524599989255269,7.485860029856364,7.447329958279927,7.409010052680969,7.370879968007405,7.332940061887105,7.295210043589274,7.257670005162557,7.220329960187276,7.183180014292399,7.1462299426396685,7.10945999622345,7.072889963785808,7.036509990692139,7.000319997469584,6.964310010274251,6.9285000165303545,6.892859975496928,6.857420007387797,6.822160045305888,6.787080089251201,6.752179980278015,6.717469930648804,6.682929992675781,6.648579994837443,6.614400068918864,6.580400029818217,6.546580036481221,6.512929916381836,6.479459961255391,6.446160038312276,6.4130399624506635,6.380079984664917,6.347299973169963,6.314689954121907,6.28223995367686,6.249969959259033,6.217859983444214,6.185920000076294,6.154149929682414,6.1225399573644,6.091090043385823,6.0598100026448565,6.028690020243327,5.997730056444804,5.966930031776428,5.9362899462382,5.905810038248698,5.875490029652913,5.845320026079814,5.815310001373291,5.785460074742635,5.755759994188945,5.7262199719746905,5.696820060412089,5.667590061823527,5.638500054677327,5.609560052553813,5.580779949824016,5.5521399974823,5.523650010426839,5.495309988657634,5.46711003780365,5.439060012499492,5.411159992218018,5.383400082588196,5.355790019035339,5.328310012817383,5.300980011622111,5.2737999359766645,5.246749957402547,5.219839970270793,5.193069974581401,5.166439930597941,5.1399500370025635,5.113600015640259,5.087380011876424,5.0612899462382,5.03534996509552,5.0095300277074175,4.983849962552388,4.958309928576152,4.932890057563782,4.9076099793116255,4.882459998130798,4.857430060704549,4.832540035247803,4.807779987653096,4.7831400235493975,4.758629997571309,4.734249909718831,4.70998998483022,4.68585999806722,4.66186002890269,4.637979984283447,4.614219983418782,4.590580066045125,4.567069967587789,4.54367999235789,4.520409981409709,4.497259934743245,4.474230011304219,4.451320052146912,4.428520043690999,4.405849973360698,4.383289972941081,4.360850016276042,4.338519970575969,4.316310008366902,4.294210036595662,4.27222998936971,4.250359972318013,4.228609999020894,4.206970016161601,4.185429970423381,4.164009968439738,4.142709970474243,4.121509989102681,4.100419958432515,4.0794399579366045,4.058559974034627,4.037799994150798,4.0171399513880415,3.9965900182724,3.9761399825414023,3.9557999968528748,3.935570021470388,3.9154399832089744,3.8954100012779236,3.8754899899164834,3.855669995148977,3.835950016975403,3.8163299759229026,3.7968199849128723,3.777399937311808,3.758089999357859,3.738879978656769,3.719760020573934,3.700740019480387,3.681820015112559,3.662999987602234,3.6442800164222717,3.6256500085194907,3.6071199973424277,3.5886799891789756,3.570340017477671,3.5520900090535483,3.533940017223358,3.515880008538564,3.4979100227355957,3.4800400137901306,3.4622599879900613,3.444570004940033,3.4269700050354004,3.4094600081443787,3.3920400142669678,3.3747199972470603,3.357480009396871,3.3403300245602927,3.32327002286911,3.3062899708747864,3.2894000013669333,3.2726099689801535,3.2558899521827698,3.239270011583964,3.2227200269699097,3.2062700192133584,3.189899981021881,3.173609991868337,3.1574100255966187,3.141289989153544,3.125250001748403,3.109289983908335,3.1013399759928384};
    
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.1404631125430266,0.14906380449732146,0.1594268245001634,0.17142481232682863,0.18508478750785193,0.20039577161272368,0.21735276530186334,0.23532275731364885,0.25367675349116325,0.2724137455224991,0.2915327375133832,0.3110307330886523,0.330904724697272,0.3511547272404035,0.3717797150214513,0.3927767102917035,0.41414570808410645,0.4356467127799988,0.4570417081316312,0.47832971066236496,0.4995117162664731,0.5205877174933752,0.5415587176879247,0.5624267111221949,0.5831897109746933,0.6038487106561661,0.6244047085444132,0.6447777052720388,0.6648877213398615,0.6847347219785055,0.7043197254339854,0.7236457169055939,0.7427127261956533,0.7615187366803488,0.7800687402486801,0.79836073021094,0.8163957347472509,0.8343867311875025,0.8525437265634537,0.8708647340536118,0.8893497089544932,0.9079967141151428,0.9268047114213308,0.9457726975282034,0.9648987104495367,0.9841817021369934,1.0036197106043498,1.0231797099113464,1.0428196787834167,1.0625396966934204,1.0823397040367126,1.102219690879186,1.1221796870231628,1.142229696114858,1.1623496810595195,1.1825496753056843,1.2028296887874603,1.2231496671835582,1.243489662806193,1.2638496657212575,1.2842196822166443,1.3046096662680309,1.3250096837679546,1.3454196751117706,1.3658496638139088,1.3862996796766918,1.4067596793174744,1.4272496700286865,1.4477896491686504,1.4683896501859028,1.4890396694342296,1.5097396572430928,1.5304996470610301,1.5513096551100414,1.5721796452999115,1.5930996636549632,1.6140696505705516,1.6349696318308513,1.6556596457958221,1.676159660021464,1.6964496473471324,1.7165396412213643,1.7364396452903748,1.7561296621958415,1.7756296594937642,1.794939657052358,1.8140496512254078,1.8329296708106995,1.851519654194514,1.8698396682739258,1.8878696660200756,1.905629684527715,1.9231196641921997,1.9403196672598522,1.9572597046693165,1.9739196797211964,1.9903096656004589,2.0064296821753183,2.022279659907023,2.0378596584002175,2.0531696875890098,2.068219701449076,2.0829996864000955,2.0975196957588196,2.1117796897888184,2.1257697145144143,2.1395097374916077,2.1529797116915383,2.166199723879496,2.179159720738729,2.1918697158495584,2.204319695631663,2.2165197134017944,2.2284597158432007,2.2401596903800964,2.251599748929342,2.262799779574076,2.273749748865763,2.2844496965408325,2.2949097553888955,2.305119733015696,2.315089762210846,2.3248197436332703,2.3342997233072915,2.3435497482617698,2.352559725443522,2.361329714457194,2.3698697884877524,2.3781697750091553,2.3862297534942627,2.394059737523397,2.4016597469647727,2.409039775530497,2.4161797960599265,2.423089782396952,2.429769774278005,2.4362297852834067,2.442459762096405,2.4484697580337524,2.454259753227234,2.459819793701172,2.465159793694814,2.4702897866566977,2.475189765294393,2.4798798163731894,2.48434978723526,2.4885997970898948,2.4926397999127707,2.4964598019917807,2.5000798304875693,2.503479778766632,2.506669819355011,2.5096498330434165,2.5124298135439553,2.5149897933006287,2.517349819342295,2.519509812196096,2.5214598178863525,2.523209830125173,2.524759809176127,2.5260998010635376,2.5272498528162637,2.5281998117764792,2.5289398431777954,2.5294998486836753,2.5298498471577964,2.5300098260243735,2.5299798448880515,2.529749850432078,2.529339830080668,2.5287298361460366,2.5279298623402915,2.526939868927002,2.5257698694864907,2.5243998169898987,2.522849897543589,2.5211198727289834,2.519199868043264,2.5170998771985373,2.514819860458374,2.5123498837153115,2.5096998810768127,2.5068798859914145,2.503879884878794,2.50068990389506,2.4973398447036743,2.493799904982249,2.490099867184957,2.4862098892529807,2.4821598728497825,2.4779298901557922,2.473529895146688,2.468959927558899,2.4642199079195657,2.4593198895454407,2.4542498787244162,2.4489999016126,2.4435998996098838,2.4380299051602683,2.4322898785273233,2.4263899525006614,2.4203298687934875,2.4141099055608115,2.407719910144806,2.401179929574331,2.3944799304008484,2.387619912624359,2.3805999159812927,2.3734299143155417,2.366099933783213,2.358619968096415,2.3509799440701804,2.3431899746259055,2.335249960422516,2.3271499276161194,2.3189099431037903,2.3105199933052063,2.3019799987475076,2.2932899594306946,2.2844499548276267,2.2754699985186257,2.266339957714081,2.2570600310961404,2.2476399540901184,2.2380799452463784,2.228379944960276,2.218529999256134,2.208549956480662,2.198419988155365,2.1881499886512756,2.1777499516805015,2.1672099828720093,2.1565399964650473,2.145740032196045,2.1348299980163574,2.1237900257110596,2.112630029519399,2.1014400124549866,2.090320030848185,2.0792500178019204,2.06824000676473,2.057289977868398,2.046400010585785,2.0355700055758157,2.0247900088628135,2.014079988002777,2.003419985373815,1.992820014556249,1.982280006011327,1.9717899958292644,1.9613599876562755,1.9509900112946827,1.9406700034936268,1.9303999940554302,1.9201999803384144,1.9100400010744731,1.8999399940172832,1.889900008837382,1.8799100021521251,1.8699699938297272,1.8600900173187256,1.8502599994341533,1.840479999780655,1.830759992202123,1.8210799992084503,1.811460018157959,1.8018899857997894,1.7923700114091237,1.7829100092252095,1.7734900017579396,1.7641200025876362,1.7548100153605144,1.7455399831136067,1.7363199989000957,1.727159986893336,1.7180399894714355,1.7089699904123943,1.699949989716212,1.690970003604889,1.6820500095685322,1.673169990380605,1.6643399794896443,1.6555599967638652,1.6468199888865154,1.638129989306132,1.6294900079568226,1.62089999516805,1.6123399933179219,1.6038400133450825,1.5953799883524578,1.5869700014591217,1.5786000192165375,1.5702699919541676,1.5619899829228718,1.5537600020567577,1.5455599824587505,1.5374100009600322,1.5293099880218506,1.5212499996026356,1.51322998603185,1.5052499969800313,1.4973199864228566,1.489430010318756,1.48157998919487,1.4737699925899506,1.466000000635783,1.4582799871762593,1.4505999982357025,1.4429500102996826,1.4353500008583069,1.427789996067683,1.4202699859937031,1.4127900004386902,1.4053499897321065,1.3979500035444896,1.390589992205302,1.383260001738866,1.3759800096352894,1.3687300086021423,1.3615299959977467,1.3543599843978882,1.3472300072511036,1.3401399850845337,1.3330800036589305,1.3260599970817566,1.3190899988015492,1.3121399978796642,1.3052400251229603,1.2983699937661488,1.2915399968624115,1.284740000963211,1.277979999780655,1.2712599833806355,1.2645700077215831,1.257910003264745,1.2512999971707661,1.2447200020154316,1.2381699979305267,1.231660008430481,1.2251800100008647,1.2187300026416779,1.2123300035794575,1.2059500118096669,1.1996100048224132,1.1933000087738037,1.187030017375946,1.1807899971803029,1.1745799978574116,1.1683999995390575,1.1622599860032399,1.1561500032742817,1.150079995393753,1.1440300047397614,1.138019988934199,1.132040003935496,1.1260899901390076,1.120169997215271,1.1142800052960713,1.1084300180276234,1.1026100019613903,1.096809983253479,1.0910499890645344,1.0853199859460194,1.0796200037002563,1.0739499827226002,1.0683100024859111,1.0626999934514363,1.0571100016434987,1.0515600144863129,1.046040008465449,1.0405500034491222,1.0350800156593323,1.0296500027179718,1.024239997069041,1.0188699960708618,1.0135200023651123,1.0081999997297924,1.002899984518687,0.997639000415802,0.9924029956261317,0.9871940016746521,0.982013002038002,0.9768589933713278,0.9717330088218054,0.9666329920291901,0.9615610043207804,0.9565159976482391,0.9514970084031423,0.9465049902598063,0.941539004445076,0.936599999666214,0.9316870073477427,0.9267990042765936,0.9219380021095276,0.9171020040909449,0.9122920036315918,0.9075080007314682,0.9027479936679205,0.8980140040318171,0.8933050086100897,0.8886210024356842,0.883962000409762,0.8793270041545233,0.8747170021136602,0.8701310058434805,0.8655699988206228,0.8610320041577021,0.8565189987421036,0.852029005686442,0.8475640018781027,0.8431209971507391,0.8387030015389124,0.834307000041008,0.8299349993467331,0.8255860010782877,0.8212600002686182,0.8169569919506708,0.8126770108938217,0.808418999115626,0.8041839996973673,0.799971009294192,0.7957800030708313,0.7916119992733002,0.7874649912118912,0.7833410054445267,0.7792380005121231,0.7751569996277491,0.771096999446551,0.767058993379275,0.7630419979492823,0.7590469966332117,0.7550719926754633,0.751119002699852,0.7471860001484553,0.743275006612142,0.7393830021222433,0.7355129967133204,0.7316630035638809,0.7278330028057098,0.7240230043729147,0.7202340016762415,0.7164639979600906,0.7127140015363693,0.7089850058158239,0.7052740057309469,0.7015839964151382,0.6979130059480667,0.6942609945933024,0.6906279971202215,0.6870149920384089,0.683420995871226,0.6798459986845652,0.6762889921665192,0.6727509995301565,0.6692320009072622,0.6657320012648901,0.6622499972581863,0.6587860037883123,0.6553410043319067,0.6519139955441157,0.6485050022602081,0.6451129963000616,0.6417399992545446,0.6383850077788035,0.635046993692716,0.6317260016997656,0.6284240037202835,0.6251379996538162,0.6218700011571249,0.6186199933290482,0.6153859893480936,0.6121689975261688,0.6089699963728586,0.6057869990666708,0.6026209990183512,0.5994710028171539,0.5963389923175176,0.5932220071554184,0.5901219993829727,0.5870390087366104,0.5839720020691553,0.5809199959039688,0.5778849969307581,0.5748660067717234,0.5718630055586497,0.5703650067249934};
    
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.223768174648285,2.4407403270403543,2.6386402448018393,2.925900320212046,3.261090338230133,3.638450344403585,4.052930335203807,4.46992031733195,4.859000364939372,5.22363034884135,5.566850423812866,5.89128041267395,6.199260354042053,6.492790420850118,6.77366046110789,7.043400327364604,7.303360382715861,7.543790419896443,7.756060481071472,7.943500439325969,8.109040260314941,8.255230585734049,8.384320338567099,8.498290379842123,8.598880370457968,8.687610387802124,8.765830437342325,8.830570379892984,8.879150390625,8.91338046391805,8.934850454330444,8.94497044881185,8.945010503133139,8.936070362726847,8.91916028658549,8.895140250523886,8.864810307820639,8.83884048461914,8.826610565185547,8.826400438944498,8.836660385131836,8.856070439020792,8.883440256118774,8.917740424474081,8.958040396372477,9.003560543060303,9.05357050895691,9.105800549189249,9.158260345458984,9.210970401763916,9.263950427373251,9.317190488179525,9.370710452397665,9.424500385920206,9.478560447692871,9.532890637715658,9.587490479151407,9.640540520350138,9.69040052096049,9.737470626831055,9.782100280125936,9.82459044456482,9.865220546722412,9.904220501581827,9.941810448964437,9.978170474370321,10.013500610987345,10.048900604248047,10.08560053507487,10.123500426610311,10.162500540415445,10.202500422795614,10.243600447972616,10.285600423812866,10.328600406646729,10.372400522232056,10.417100350062052,10.456400553385416,10.485000610351562,10.504300594329834,10.515600522359213,10.51990040143331,10.518300533294678,10.511500597000122,10.500300407409668,10.485400597254435,10.46720059712728,10.444100459416708,10.414700428644815,10.379700342814127,10.339900334676107,10.295800606409708,10.248000462849935,10.197000503540039,10.143100579579672,10.086700598398844,10.02820054690043,9.967700481414795,9.905560413996378,9.841970523198446,9.777100324630737,9.711110353469849,9.644160509109497,9.57636030515035,9.507830381393433,9.438650449117025,9.36892040570577,9.298710425694784,9.22808043162028,9.157090504964193,9.085800409317017,9.014240423838297,8.942470471064249,8.870510339736938,8.79839038848877,8.72614041964213,8.653790473937988,8.581350247065226,8.508850336074829,8.436310291290283,8.363720417022705,8.291120370229086,8.218510230382284,8.14590040842692,8.073300441106161,8.000720461209616,7.928170363108317,7.855650385220845,7.783160328865051,7.710720340410869,7.638330380121867,7.565980315208435,7.493700385093689,7.4214703639348345,7.349300344785054,7.277190327644348,7.2051602602005005,7.133180260658264,7.061280330022176,6.989450295766194,6.917690277099609,6.84600027402242,6.774390339851379,6.7028702100118,6.631420334180196,6.560050328572591,6.488770325978597,6.417570233345032,6.346450289090474,6.275420228640239,6.204480250676473,6.133620301882426,6.06285027662913,5.9921702941258745,5.921580235163371,5.851070245107015,5.78065025806427,5.710320194562276,5.6400801340738935,5.569930235544841,5.499870181083679,5.429890314737956,5.360000252723694,5.2902001937230425,5.220480283101399,5.150860230127971,5.08132020632426,5.011870265007019,4.942500154177348,4.87323013941447,4.804040193557739,4.734930237134297,4.665910204251607,4.596980174382527,4.5281301736831665,4.4593701759974165,4.390690247217814,4.322100241978963,4.253590186436971,4.185160199801127,4.116820216178894,4.0485702355702715,3.9804001450538635,3.9123101234436035,3.8443001906077066,3.776380161444346,3.708540201187134,3.6407801508903503,3.57310018936793,3.505510151386261,3.4380001227060952,3.3705701430638633,3.3032201528549194,3.2359601259231567,3.1687801678975425,3.1016701261202493,3.034650127092997,2.9677101174990335,2.9008501370747886,2.834080139795939,2.767380118370056,2.700770099957784,2.634230117003123,2.5677801171938577,2.501410106817881,2.435120105743408,2.3689001003901162,2.3027800917625427,2.2367300987243652,2.1707600951194763,2.104870080947876,2.039070109526316,1.9733500878016155,1.9077100654443104,1.8421500722567241,1.7766700784365337,1.7112700641155243,1.6459500590960185,1.580720047156016,1.5155600607395172,1.4504900475343068,1.3855000535647075,1.3206000328063965,1.2557800312836964,1.1910400291283925,1.1263800263404846,1.0618000129858653,0.9973120242357254,0.9329040249188741,0.8685800135135651,0.8043400098880132,0.7401890108982722,0.6761860052744547,0.6123700092236201,0.5487030098835627,0.48515499631563824,0.4216970006624858,0.3627149959405263,0.31198700517416,0.26835600038369495,0.230829997609059,0.19855500012636185,0.17079400271177292,0.14691699668765068,0.12637999964257082,0.10871500025192897,0.09352009991804759,0.08045040008922417,0.06920820040007432,0.05953779971847931,0.051219300366938114,0.04406370005259911,0.03790829982608557,0.03261319982508818,0.028058099870880444,0.02413949991265933,0.020768399971226852,0.01786839993049701,0.01537349990879496,0.013227100018411875,0.011380599966893593,0.00979189993813634,0.008425109942133227,0.007249190006405115,0.006237479974515736,0.0053670199898382025,0.004618099968259533,0.0039737199937614305,0.0034192999786076448,0.0029422700172290206,0.002531820035073906,0.0021786500001326203,0.0018747599873070915,0.001613280027716731,0.0013882900044942896,0.0011946799932047725,0.0010280899975138407,0.0008847390029889842,0.0007613829996747276,0.0006552330111541474,0.0005638879956677556,0.0004852820056839846,0.0004176390017770852,0.00035942799877375364,0.0003093330039215895,0.0002662230011386176,0.00022912400163477287,0.00019719600095413625,0.0001697190006476982,0.00014607299938991977,0.00012572199860490704,0.00010820699996353748,9.313340099955288e-05,8.016039949628369e-05,6.899509935465176e-05,5.9385599949261327e-05,5.11149003917429e-05,4.3996500304880705e-05,3.786979929524629e-05,3.2596599642905254e-05,2.805799992226336e-05,2.4151499928848352e-05,2.078909998696569e-05,1.7894900035268318e-05,1.5403900079036248e-05,1.325969992649334e-05,1.141410007221566e-05,9.825429894287177e-06,8.457989982465127e-06,7.280920006754362e-06,6.267719982133713e-06,5.39555999997295e-06,4.64479997693464e-06,3.9985499711292505e-06,3.442239972173411e-06,2.9633500275849656e-06,2.551110014792357e-06,2.1962399993450768e-06,1.8907499850229215e-06,1.6277699993831145e-06,1.4013700043354522e-06,1.2064800027170957e-06,1.0386899968276946e-06,8.942530058675402e-07,7.699049954605167e-07,6.628529973795594e-07,5.706909907606436e-07,4.913479993244133e-07,4.2303899997856814e-07,3.642289977771422e-07,3.135979985321076e-07,2.7000799936634695e-07,2.32478000109874e-07,2.0016700119640518e-07,1.723470018551628e-07,1.483960012649277e-07,1.2777400115737692e-07,1.1001799885927237e-07,1.6788739879795383e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834319035212198,12.709800879160563,13.17430051167806,13.909000317255655,13.865400234858194,13.179299910863241,11.96180017789205,10.601900100708008,9.421110153198242,8.387740015983582,7.475740075111389,6.6636901299158735,5.933970014254252,5.272040049235026,4.6659700473149615,4.105910023053487,3.5837300221125283,3.1186700065930686,2.7265400489171348,2.3944900035858154,2.111929992834727,1.8702000081539154,1.662150005499522,1.481900026400884,1.324590007464091,1.1862400273482006,1.0635400116443634,0.9555070151885351,0.8613140136003494,0.7785920153061548,0.7053750058015188,0.6400300016005834,0.5812130123376846,0.5278110057115555,0.47890400389830273,0.43372800201177597,0.3916580031315486,0.3537420059243838,0.32084600379069644,0.29211900383234024,0.266853004693985,0.24446400254964828,0.22446000079313913,0.20643700286746025,0.19006700068712234,0.1750720019141833,0.16122200091679892,0.1486390046775341,0.1374200036128362,0.1273300014436245,0.11818500173588593,0.10982400240997474,0.10211600239078204,0.09495070079962413,0.08823220121363799,0.08189100089172523,0.07586420079072316,0.07028279950221379,0.06525460009773572,0.0606852009271582,0.05649640100697676,0.05262360100944837,0.04901850068320831,0.04563070057580868,0.04242380087574323,0.039367799957593284,0.03643770019213358,0.03372279989222685,0.03128570023303231,0.029078100342303514,0.02706520026549697,0.025213300560911495,0.02349680041273435,0.02189210057258606,0.02037210048486789,0.018922200271238882,0.0175356005008022,0.016201700161521632,0.014911400154232979,0.013657400229324898,0.012433500261977315,0.011239900020882487,0.01007140016493698,0.00891870011885961,0.007779100211337209,0.006650540046393871,0.0055312300100922585,0.00451813005687048,0.0036903399935302636,0.003014020020297418,0.0024614600115455687,0.0020100399754786244,0.0016412800080919017,0.0013400600000750273,0.0010940300029081602,0.0008930829935707152,0.000728978993720375,0.0005949709981602306,0.000485549991329511,0.00039621200509524596,0.00032327799757088843,0.0002637419978176088,0.00021514700104792914,0.0001754869990691077,0.00014312200073618442,0.00011671200081764255,9.516550016996916e-05,7.75874996179482e-05,6.324890000541927e-05,5.155419997511975e-05,4.201679985271767e-05,3.423970004708584e-05,2.7898700106258428e-05,2.272930002315358e-05,1.8515400067068793e-05,1.5080900008494305e-05,1.228199986750648e-05,1.0001300021637386e-05,8.143069938644961e-06,6.629269970896227e-06,5.396200018973711e-06,4.391930019664869e-06,3.5741100153548664e-06,2.9081999931198275e-06,2.3660500308627284e-06,1.9247300334275983e-06,1.5655099995607695e-06,1.2731799946171425e-06,1.0352900072045184e-06,8.417479951579784e-07,6.842949981470762e-07,5.56221010583613e-07,4.5205799636960364e-07,3.673539978876761e-07,2.9848100998227284e-07,2.424880065632351e-07,1.969729979123258e-07,1.5997999488111722e-07,1.2991700515385673e-07,8.114027908826908e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8707990000645319,0.9575220743815104,1.031660074989001,1.1091500719388325,1.1896301011244457,1.2727800905704498,1.358320067326228,1.4378700753053029,1.5039700667063396,1.5581400692462921,1.6017000675201416,1.6358300844828289,1.6615700721740723,1.679840048154195,1.6914800504843395,1.6972200870513916,1.697690079609553,1.6938300728797913,1.6864700615406036,1.675950050354004,1.6625900566577911,1.6466800570487976,1.6284700433413188,1.6082000533739726,1.5860600570837657,1.5622500379880269,1.5369300444920857,1.5110400517781575,1.485420048236847,1.4600400527318318,1.4348400632540386,1.4097900291283925,1.3848700523376465,1.360040048758189,1.3353000382582347,1.3106200595696766,1.2860000332196553,1.2627800305684407,1.242180049419403,1.2239100337028503,1.2077000439167023,1.1933300495147705,1.180580049753189,1.1692800521850586,1.1592600246270497,1.1503800451755524,1.142510066429774,1.1355400482813518,1.129360059897105,1.1239100595315297,1.119100034236908,1.1148800353209178,1.1111800372600555,1.1079500516255696,1.1051500538984935,1.1027300556500752,1.1006600459416707,1.098960041999817,1.0976400474707286,1.0966600477695465,1.0959900418917339,1.0956000288327534,1.0954400499661763,1.095510055621465,1.0957800447940826,1.0962200462818146,1.0968200266361237,1.0978000462055206,1.0993500451246898,1.1014400621255238,1.1039900581041973,1.1069600383440654,1.1103300551573436,1.1140300532182057,1.1180600424607594,1.122370054324468,1.1269400417804718,1.131160060564677,1.1345200339953105,1.137110044558843,1.1390400528907776,1.140390048424403,1.1412200530370076,1.141620049873988,1.14164004723231,1.1413200497627258,1.1407100558280945,1.1395500500996907,1.1375900506973267,1.1349200308322906,1.131630043188731,1.1277900437513988,1.1234500408172607,1.1186900436878204,1.1135400434335072,1.1080400447050731,1.1022500395774841,1.0961900452772777,1.0899000366528828,1.083400050799052,1.076710045337677,1.0698600510756175,1.0628600319226582,1.0557400385538738,1.0485100547472637,1.0411800344785054,1.0337600409984589,1.0262700319290161,1.0187000532944996,1.0110800464948018,1.0034100413322449,0.99569404621919,0.9879390398661295,0.9801490406195322,0.9723300337791443,0.9644870410362879,0.9566230376561483,0.9487400352954865,0.9408420423666636,0.9329310357570648,0.9250120421250662,0.9170840432246526,0.909149040778478,0.9012090265750885,0.8932660321394602,0.885323037703832,0.8773780216773351,0.8694330304861069,0.8614900211493174,0.8535480350255966,0.845610037446022,0.8376750300327936,0.8297440310319265,0.8218200355768204,0.8138990352551142,0.8059840351343155,0.7980740318695704,0.7901700288057327,0.7822740375995636,0.7743840217590332,0.7665010243654251,0.7586250354846319,0.7507560302813848,0.7428970336914062,0.7350450307130814,0.7272010296583176,0.7193650255600611,0.7115380267302195,0.7037210265795389,0.6959120333194733,0.6881120204925537,0.6803200294574102,0.6725380222002665,0.6647660235563914,0.6570030252138773,0.6492480238278707,0.6415030211210251,0.6337670336167017,0.626042033235232,0.6183250248432159,0.6106180250644684,0.6029220223426819,0.5952340265115103,0.5875560243924459,0.5798860142628351,0.5722250193357468,0.5645750214656194,0.5569340238968531,0.5493020216623942,0.5416790147622427,0.5340650280316671,0.5264610250790914,0.5188660174608231,0.5112800200780233,0.5037030229965845,0.49613501876592636,0.4885770231485367,0.4810280129313469,0.4734880179166794,0.46595601737499237,0.45843301713466644,0.4509210189183553,0.4434170151750247,0.435922014216582,0.42843501766522724,0.4209570164481799,0.4134890139102936,0.4060300141572952,0.39857901136080426,0.3911370113492012,0.3837030157446861,0.3762790138522784,0.3688640172282855,0.36145701507727307,0.35406101246674854,0.34667301177978516,0.3392930080493291,0.3319210112094879,0.3245580121874809,0.3172050093611081,0.3098600059747696,0.30252300947904587,0.29519500583410263,0.2878750090797742,0.2805650110046069,0.27326400578022003,0.26597000658512115,0.25868501017491025,0.25140900909900665,0.24414200832446417,0.23688400660951933,0.2296340068181356,0.22239300732811293,0.21516000603636107,0.20793700590729713,0.200722003976504,0.1935160073141257,0.18631800760825476,0.17912800734241804,0.1719490041335424,0.16477800657351813,0.1576160043478012,0.1504640057682991,0.14332000414530435,0.13618400444587073,0.12905700380603471,0.12193900160491467,0.1148310024291277,0.10773100269337495,0.10064000201721986,0.09355750183264415,0.08648400008678436,0.07942790103455384,0.07239100026587646,0.06536990031599998,0.058361599842707314,0.051363300221661724,0.044816400234897934,0.03910439989219109,0.0341207996631662,0.029772700121005375,0.025978900181750458,0.022668899968266487,0.019780800056954224,0.017260999729235966,0.015062299945081273,0.013143799966201186,0.01146979994761447,0.01000920000175635,0.00873465013379852,0.007622510039558013,0.006652049953117967,0.005805209977552295,0.00506624998524785,0.004421399945082764,0.003858670029633989,0.0033676000117945173,0.0029390700122651956,0.0025650900012503066,0.0022387199957544603,0.0019539099982163557,0.0017053400030514847,0.001488409994635731,0.0012991000063872586,0.0011338700035897393,0.000989668013062328,0.0008638150029582903,0.0007539739987502495,0.0006581070047104731,0.0005744350055465475,0.0005014069975004531,0.00043766699915674206,0.0003820330020971596,0.00033347499993396923,0.0002910919987092105,0.0002540970029561625,0.00022180699913102822,0.00019362199964234605,0.0001690199993997036,0.0001475449995875048,0.00012880000091778734,0.00011243699979483306,9.815449933133398e-05,8.568679913878441e-05,7.48034005179458e-05,6.530290071774895e-05,5.700959991372656e-05,4.976989991215911e-05,4.3449999793665484e-05,3.793300008207249e-05,3.3116799992664404e-05,2.8912299967487343e-05,2.5241799903596984e-05,2.2037500305790065e-05,1.9240200041773885e-05,1.6798000009051368e-05,1.466600004581172e-05,1.2804699963453459e-05,1.1179699943871432e-05,9.761000001162756e-06,8.522409871147829e-06,7.441049926152725e-06,6.496949974158876e-06,5.672679966058543e-06,4.953029929311015e-06,4.324709948377858e-06,3.7761300291094813e-06,3.2971600300394735e-06,2.8789599847793093e-06,2.513829959601329e-06,2.195030049279012e-06,1.916669977693649e-06,1.6736199957752735e-06,1.4614099939080916e-06,1.276109998116226e-06,1.114320004565646e-06,9.73049012031879e-07,8.496940040458867e-07,7.419820112393912e-07,6.479299988389661e-07,5.65804005721778e-07,4.940909998178237e-07,4.3147099641297853e-07,3.767900030500944e-07,3.290420025336971e-07,2.873460000311449e-07,2.5093599968310326e-07,2.191409980885813e-07,1.9137699898881996e-07,1.6713100000250355e-07,1.4595800005660445e-07,1.2746800000703237e-07,1.1132099982565553e-07,2.5553145969562745e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.25285430749257404,0.2655299554268519,0.2754349733392398,0.28568598131338757,0.29605497668186825,0.30653397490580875,0.31711698075135547,0.32681697607040405,0.3347119813164075,0.340909980237484,0.34551798552274704,0.34863198548555374,0.3503429815173149,0.35073698808749515,0.3498939846952756,0.347888986269633,0.34479297945896786,0.3409759849309921,0.336783987780412,0.3322349910934766,0.3273489897449811,0.3221429909269015,0.31663298855225247,0.31083498895168304,0.30476399262746173,0.2984349901477496,0.29186198860406876,0.2852169871330261,0.278663990398248,0.2721959898869197,0.2658049960931142,0.25948599725961685,0.25323299318552017,0.24704099570711455,0.24090699230631193,0.23482599357763925,0.22879399359226227,0.2229309951265653,0.21734499310453734,0.21202099323272705,0.2069429929057757,0.20209499448537827,0.1974639929831028,0.1930369958281517,0.1888019951681296,0.184746994326512,0.18086099500457445,0.17713999624053636,0.17357899621129036,0.1701709950963656,0.16690599297483763,0.16377699499328932,0.1607769951224327,0.15789799516399702,0.15513399367531142,0.15247799456119537,0.1499249947567781,0.14747499426205954,0.14512799431880316,0.14287899558742842,0.1407219941417376,0.13865199436744055,0.1366649977862835,0.13475499426325163,0.13291799649596214,0.13114999483029047,0.1294469969968001,0.12782099470496178,0.12628299494584402,0.1248279952754577,0.12345099573334058,0.12214899497727554,0.12091699490944545,0.11975099456806977,0.11864799447357655,0.11760499514639378,0.1166179950038592,0.115659994383653,0.11470699496567249,0.11375999512771766,0.11281799525022507,0.1118819968154033,0.11095099647839864,0.1100249948600928,0.10910499468445778,0.10819099470973015,0.10728199407458305,0.1063829946021239,0.10550099549194177,0.10463299478093784,0.10377999519308408,0.10293899476528168,0.1021079955001672,0.10128899663686752,0.10047999583184719,0.09967969544231892,0.0988882960130771,0.09810529587169488,0.09733019582927227,0.09656239487230778,0.09579999558627605,0.09504409569005172,0.09429419661561649,0.09354859590530396,0.09280839624504249,0.09207319468259811,0.09134259571631749,0.09061649565895398,0.08989309581617515,0.08917369631429513,0.08845799540479977,0.08774589685102303,0.08703699459632237,0.08632989538212617,0.08562579564750195,0.08492449671030045,0.08422459724048774,0.08352729678153992,0.08283259595433871,0.0821401954938968,0.08145009602109592,0.08076079686482747,0.08007359504699707,0.07938839681446552,0.07870389583210151,0.07802119602759679,0.07734049670398235,0.07666149611274402,0.0759842973202467,0.07530729720989864,0.0746319970736901,0.07395829632878304,0.07328469678759575,0.07261269663770993,0.07194229712088902,0.07127329582969348,0.0706056971102953,0.06993809590737025,0.06927189665536086,0.06860709624985854,0.0679435965915521,0.06728149640063445,0.06661909694472949,0.06595819629728794,0.06529839647312959,0.06463859664897124,0.06398009695112705,0.06332279741764069,0.06266679801046848,0.062011997836331524,0.06135699742784103,0.06070329714566469,0.06005079702784618,0.05939809667567412,0.05874669769157966,0.05809649763007959,0.05744749711205562,0.05679959710687399,0.056151497488220535,0.055504697685440384,0.05485899715373913,0.05421439744532108,0.05357099790126085,0.052927397191524506,0.05228479796399673,0.05164349793146054,0.05100179774065813,0.05036139798661073,0.04972209750364224,0.04908389753351609,0.048446797455350556,0.0478094977637132,0.04717319800208012,0.04653809778392315,0.045902698300778866,0.04526849867155155,0.04463539831340313,0.04400339815765619,0.04337249820431074,0.04274119840313991,0.042111098455886044,0.04148209809015194,0.040852698497474194,0.04022449813783169,0.039597497942547,0.03897149860858917,0.038346498583753906,0.03772119805216789,0.037096998964746795,0.03647389790664116,0.03585189829270045,0.03523089891920487,0.034609499077002205,0.03398919912676016,0.03336989879608154,0.03275029888997475,0.032131798565387726,0.03151429879168669,0.03089789890994628,0.030282598920166492,0.02966679896538456,0.029052098902563255,0.028438498886922996,0.027824499023457367,0.027211598896731932,0.026599798972407978,0.0259889989780883,0.025379298875729244,0.024769199080765247,0.0241600990605851,0.023552099087586004,0.02294369926676154,0.0223363993378977,0.021730199300994475,0.02112499950453639,0.020520899444818497,0.019916299420098465,0.01931279944255948,0.018710399356981117,0.018108999356627464,0.01750869955867529,0.016907899640500546,0.01630809949710965,0.015709399633730452,0.015110399651651582,0.014512399677187204,0.013915499672293663,0.013319599830235044,0.012724799802526832,0.01212949980981648,0.011535299786676964,0.010942299927895268,0.010349299991503358,0.009758219976599017,0.009168889839202166,0.008581119822338223,0.007994769994790355,0.0074291300649444265,0.006903540071410437,0.00641518000823756,0.005961399991065264,0.005539760032358269,0.005147970048710704,0.004783919973609348,0.004445649993916352,0.004131320010249813,0.003839250033100446,0.0035678400114799538,0.003315649984870106,0.003081300004851073,0.002863530011381954,0.002661170030478388,0.002473130007274449,0.002298390007733057,0.00213600997813046,0.001985110002957905,0.0018448899985135843,0.0017145800035602103,0.0015934800127676378,0.0014809500038002927,0.0013763699971605092,0.0012791800157477458,0.0011888700149332483,0.0011049299985946466,0.0010269300061433266,0.0009544410034626102,0.0008870729992243772,0.0008244640048360452,0.0007662789964039499,0.0007122030025736118,0.0006619479972869158,0.0006152420003976052,0.000571834005919906,0.0005314919981174171,0.0004939980014266135,0.00045915200219800073,0.0004267660018134241,0.0003966659981718597,0.0003686919978160101,0.0003426909994838449,0.0003185260041694467,0.00029606699778620776,0.0002751919989047262,0.00025579099989651394,0.00023775799733508998,0.0002209979987431628,0.00020542000008087294,0.00019094099843641743,0.00017748400083898255,0.00016497500109835528,0.00015335000110402083,0.0001425439998759733,0.00013249999998758236,0.00012316399988776539,0.00011448699842731003,0.00010642099975181434,9.89242992848934e-05,9.195600068778731e-05,8.547890017022534e-05,7.945840116008185e-05,7.386230087528627e-05,6.86605999362655e-05,6.382549994062477e-05,5.933110029824699e-05,5.5153499791534465e-05,5.127019994688453e-05,4.766060040613714e-05,4.430529982831407e-05,4.118639996401422e-05,3.8287199762028955e-05,3.559219961365064e-05,3.308710044317801e-05,3.0758400043851e-05,2.8593799925147323e-05,2.658159989247603e-05,2.4711099892253213e-05,2.2972300030232873e-05,2.1355899965177134e-05,1.9853400165933028e-05,1.845660002193957e-05,1.7158200080302777e-05,1.5951199960303104e-05,1.4829200002471529e-05,1.3786099922678355e-05,1.2816499975087936e-05,1.1915099927743237e-05,1.1077199890981623e-05,1.0298199943766425e-05,9.57402994572476e-06,8.900830001342305e-06,8.274999951633314e-06,7.69319998047043e-06,7.152329999371432e-06,6.649520022013651e-06,6.1820800283385324e-06,5.747520011330683e-06,5.3435300439256634e-06,4.967950038311149e-06,4.618790057975275e-06,4.294190034670464e-06,3.9924099913453874e-06,3.7118600175745087e-06,3.4510400155340903e-06,3.208550007608816e-06,2.983110031588391e-06,2.7735299947077388e-06,2.578680001382357e-06,2.397519987577349e-06,2.2291100094662397e-06,2.072529980523541e-06,1.926949977359982e-06,1.7916099845175875e-06,1.6657799998635407e-06,1.5487900194936326e-06,1.4400299903627456e-06,1.3389099914699425e-06,1.2448900008621422e-06,1.1574799998470553e-06,1.0762099880897342e-06,1.000650001969916e-06,9.304020049209308e-07,8.650860034246458e-07,8.043590090286065e-07,7.478970047714029e-07,6.954009990067789e-07,6.465919947610624e-07,6.012109944701175e-07,5.590179957456106e-07,5.197869986280542e-07,4.833110054391909e-07,4.4939699961332735e-07,4.1786399644176225e-07,3.8854499706530987e-07,3.612840065632857e-07,3.359369979231512e-07,3.123700006805545e-07,2.904569977128328e-07,2.700820000238006e-07,2.5113700274914663e-07,2.335220005515263e-07,2.1714399996615916e-07,2.019140007784396e-07,1.8775399842259807e-07,1.7458700085626333e-07,1.6234400135317628e-07,1.509610001448891e-07,1.4037600119346885e-07,1.3053300070472082e-07,1.2138100125014262e-07,1.1287199974674422e-07,1.0495900030586351e-07,1.6763389491340302e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3641520043214161,1.475270003080368,1.5924500028292339,1.7038000226020813,1.8152699867884319,1.9268700083096821,2.038590004046758,2.146909991900126,2.2483100295066833,2.3427899877230325,2.4303699930508933,2.5110600193341575,2.5848799546559653,2.651829997698466,2.71192999680837,2.765189985434214,2.811619997024536,2.8543399771054587,2.896459996700287,2.937970002492269,2.9788800279299417,3.019189993540446,3.0588899850845337,3.0979899962743125,3.1364900271097818,3.174399971961975,3.211699982484182,3.248300035794576,3.284090002377828,3.3190500338872275,3.3531999985376992,3.3865399758021035,3.419060011704763,3.450760026772817,3.481660008430481,3.511750022570292,3.541029989719391,3.5696599880854287,3.597819983959198,3.625499963760376,3.6527100006739297,3.6794400016466775,3.705690026283264,3.731479982535044,3.7567999760309854,3.7816400130589805,3.8060099879900613,3.8298299908638,3.853000024954478,3.8755200107892356,3.897409955660502,3.9186399976412454,3.939240018526713,3.9592000246047974,3.9785199960072837,3.9972000320752463,4.015249967575073,4.032600045204163,4.049210071563721,4.065079967180888,4.080209970474243,4.0946000417073565,4.108240008354187,4.121149977048238,4.13333002726237,4.144759972890218,4.155460079511006,4.165499925613403,4.174949963887532,4.1838200489679975,4.192100008328755,4.199789961179097,4.206910053888957,4.213449994723002,4.21940004825592,4.224780003229777,4.229569951693217,4.234019994735718,4.238330046335856,4.242519974708557,4.246580004692078,4.250499963760376,4.254299918810527,4.257970015207927,4.261509974797566,4.264930009841919,4.268220027287801,4.271399974822998,4.274500012397766,4.277530034383138,4.280460000038147,4.283320029576619,4.286089976628621,4.288789947827657,4.291399995485942,4.293929974238078,4.296389977137248,4.298759977022807,4.301049987475078,4.303260048230489,4.305390040079753,4.307439963022868,4.309409976005554,4.311300079027812,4.313110073407491,4.314840038617452,4.316499988238017,4.31807001431783,4.319560011227925,4.320979952812195,4.322319984436035,4.323570013046265,4.324749946594238,4.325860023498535,4.326880017916362,4.327830036481221,4.328699986139934,4.329490065574646,4.330209930737813,4.330839991569519,4.331399957338969,4.331890066464742,4.332290013631185,4.332629998524983,4.332879980405171,4.333050012588501,4.333149949709575,4.3331799904505415,4.3331300020217896,4.333000024159749,4.332799951235454,4.332529942194621,4.332170049349467,4.331740021705627,4.331239978472392,4.3306600252787275,4.330010016759236,4.32928995291392,4.328489979108174,4.3276099761327105,4.326670050621033,4.325649976730347,4.3245499928792315,4.323379953702291,4.322140018145244,4.320819973945618,4.319430033365886,4.317969918251038,4.316439986228943,4.31482994556427,4.313149968783061,4.311399896939595,4.3095699946085615,4.307680010795593,4.3057100375493365,4.303670088450114,4.301560004552205,4.299379984537761,4.297129948933919,4.29479996363322,4.292410055796306,4.289939959843953,4.287400007247925,4.284799973169963,4.282119989395142,4.279369990030925,4.2765499750773115,4.273660024007161,4.270709991455078,4.267680009206136,4.264579892158508,4.261420051256816,4.258180022239685,4.254879991213481,4.25150994459788,4.248059988021851,4.244549989700317,4.2409699360529585,4.237329999605815,4.233610073725383,4.229829986890157,4.225980043411255,4.222060044606526,4.2180700699488325,4.214009920756022,4.209890007972717,4.205700039863586,4.201440056165059,4.197120030721028,4.192729949951172,4.188279986381531,4.183760046958923,4.17916997273763,4.1745100021362305,4.169789950052897,4.1650000015894575,4.160149971644084,4.155229926109314,4.150239944458008,4.1451899607976275,4.140079935391744,4.1348899602890015,4.129649957021077,4.1243399779001875,4.1189599831899,4.11351998647054,4.108020106951396,4.102450052897136,4.096809943517049,4.091120044390361,4.085349957148234,4.079530040423076,4.073640028635661,4.067689975102742,4.061670025189717,4.055600007375081,4.049450039863586,4.04324996471405,4.036979993184407,4.030649979909261,4.024249990781148,4.017800052960713,4.011280059814453,4.0047000249226885,3.9980499744415283,3.991349995136261,3.9845800201098123,3.97775000333786,3.970860004425049,3.9639099836349487,3.9569000204404197,3.9498300155003867,3.9426900347073874,3.935499986012777,3.9282400012016296,3.9209199945131936,3.913539985815684,3.9061399896939597,3.8987499872843423,3.891379992167155,3.8840200106302896,3.8766799767812095,3.869349996248881,3.8620400031407676,3.8547299901644387,3.847450017929077,3.8401800195376077,3.8329199949900308,3.8256799976030984,3.8184499939282737,3.8112300038337708,3.8040299812952676,3.7968399922053018,3.789669990539551,3.7825100223223367,3.7753600080808005,3.7682299812634787,3.761110007762909,3.7540099819501243,3.7469199895858765,3.739840010801951,3.7327799797058105,3.725730001926422,3.718690017859141,3.71167000134786,3.7046599984169006,3.697670022646586,3.690690020720164,3.683719972769419,3.676770011583964,3.669819990793864,3.662899990876516,3.6559800108273826,3.649079998334249,3.6421900192896524,3.635319987932841,3.6284600098927817,3.6216099858283997,3.6147800286610923,3.6079500118891397,3.6011499762535095,3.594350000222524,3.587570011615753,3.5807999968528748,3.5740400155385337,3.567300021648407,3.560570001602173,3.553850015004476,3.5471499959627786,3.540459990501404,3.5337799787521362,3.5271100203196206,3.520459989706675,3.513820012410482,3.507190008958181,3.5005799929300943,3.4939799706141152,3.4873900016148887,3.480809986591339,3.4742499788602195,3.467699964841207,3.4611600438753762,3.4546300172805786,3.4481199979782104,3.4416200121243796,3.435129980246226,3.4286500016848245,3.422189990679423,3.4157299995422363,3.409299989541372,3.402869999408722,3.3964499831199646,3.3900499741236367,3.3836599787076316,3.3772899905840554,3.370920022328695,3.3645700414975486,3.3582299947738647,3.3519000013669333,3.345580001672109,3.3392799894014993,3.332979996999105,3.3267000118891397,3.320430020491282,3.314179996649424,3.3079299926757812,3.301699976126353,3.2954799930254617,3.289269963900248,3.2830700278282166,3.27688999970754,3.2707200249036155,3.2645600040753684,3.2584099769592285,3.2522700230280557,3.2461399833361306,3.24002997080485,3.233930011590322,3.2278299729029336,3.221760014692942,3.215690016746521,3.209630012512207,3.203589975833893,3.1975500186284385,3.191530009110769,3.1855200131734214,3.1795300046602883,3.1735399762789407,3.167560040950775,3.1615999937057495,3.155649999777476,3.14970999956131,3.143780012925466,3.1378599802652993,3.1319499810536704,3.126049975554148,3.120169997215271,3.1142999728520713,3.1084299882253013,3.1025799910227456,3.0967399875322976,3.0909099777539573,3.085099975268046,3.0792900125185647,3.0734999974568686,3.067710002263387,3.0619399746259055,3.0561800400416055,3.0504299998283386,3.0446800192197165,3.0389599998792014,3.033240020275116,3.027530014514923,3.0218300223350525,3.0161499977111816,3.010469973087311,3.0048099954922995,2.9991599917411804,2.9935099879900613,2.987879991531372,2.98225998878479,2.9766499996185303,2.9710500041643777,2.9654599825541177,2.959890047709147,2.954319973786672,2.9487600326538086,2.9432199994723,2.9376800060272217,2.9321600198745728,2.926639974117279,2.92113995552063,2.9156399965286255,2.910160005092621,2.9046900272369385,2.8992300033569336,2.893779973189036,2.888330022493998,2.8829000194867453,2.8774800300598145,2.872069994608561,2.86667001247406,2.8612799843152366,2.855900009473165,2.850529968738556,2.8451799750328064,2.839830001195272,2.8344899813334146,2.829159955183665,2.8238399823506675,2.8185399969418845,2.8132400115331015,2.807950019836426,2.802669962247213,2.7974000374476113,2.7921500205993652,2.786900003751119,2.78165998061498,2.776429990927378,2.7712199886639914,2.766010026137034,2.7608099977175393,2.755619982878367,2.750450015068054,2.7452800075213113,2.740119993686676,2.7349700133005777,2.729830026626587,2.7246999939282737,2.7195900082588196,2.7144800225893655,2.7093799908955893,2.70429003238678,2.699209988117218,2.694139997164408,2.689079999923706,2.6840199629465737,2.678979992866516,2.6739500164985657,2.668930013974508,2.663919985294342,2.658910016218821,2.6539200146993003,2.648929993311564,2.6439599792162576,2.6389900048573813,2.6340399781862893,2.6290900111198425,2.624150017897288,2.6192299922307334,2.614310006300608,2.6094000140825906,2.6044999957084656,2.599609990914663,2.594729999701182,2.5898600021998086,2.5850000182787576,2.580140014489492,2.5753000378608704,2.570460001627604,2.5656399726867676,2.5608199636141458,2.5560099879900613,2.5512200196584067,2.546429991722107,2.5416500171025596,2.5368800163269043,2.5321099758148193,2.527359982331594,2.522619982560476,2.5178800026575723,2.513160010178884,2.5084399978319802,2.503729979197184,2.4990400075912476,2.494350016117096,2.489669998486837,2.4849900007247925,2.480330010255178,2.4756799737612405,2.4710299968719482,2.466389993826548,2.461769998073578,2.4571499824523926,2.4525400002797446,2.4502300024032593};
    
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480120619138082,4.563908735911052,4.605279207229614,4.672349214553833,4.739289244016011,4.806119322776794,4.87282919883728,4.939459244410197,5.0060493151346845,5.0725992520650225,5.139109293619792,5.205589294433594,5.272019267082214,5.338419238726298,5.404779275258382,5.471099257469177,5.537379225095113,5.603459318478902,5.669169267018636,5.734509309132894,5.7994693120320635,5.86406930287679,5.928299307823181,5.992159326871236,6.055649280548096,6.118759314219157,6.181509375572205,6.24385933081309,6.305779258410136,6.36725930372874,6.428309361139934,6.488929311434428,6.549119313557942,6.608879407246907,6.6682093143463135,6.727099378903707,6.7855693101882935,6.843229373296102,6.899709383646647,6.955029408137004,7.009169419606526,7.062129418055217,7.1139194170633955,7.164539456367493,7.213989535967509,7.2622595230738325,7.309359471003215,7.355469465255737,7.40075957775116,7.4452195564905805,7.488869547843933,7.531699538230896,7.5737195412317915,7.614909569422404,7.655289530754089,7.694839596748352,7.733579556147258,7.771169622739156,7.807259599367778,7.841869632403056,7.874979654947917,7.906599601109822,7.936729709307353,7.965369741121928,7.992519815762837,8.018179575602213,8.042349735895792,8.065629800160727,8.088639736175537,8.111379702885946,8.133829752604166,8.156009753545126,8.177909771601358,8.199539740880331,8.220889806747437,8.24196974436442,8.262759764989218,8.28335976600647,8.30381973584493,8.324159622192383,8.344359715779623,8.364439646402994,8.384379704793295,8.404199759165445,8.423879702885946,8.443429787953695,8.462859710057577,8.482149918874105,8.501309712727865,8.52031977971395,8.539199829101562,8.557949860890707,8.576559782028198,8.595029830932617,8.613359769185385,8.6315598487854,8.649619738260904,8.6675496896108,8.68533992767334,8.70298981666565,8.720509767532349,8.737889766693115,8.755129734675089,8.772229750951132,8.789199829101562,8.806039889653524,8.82272974650065,8.839289744695028,8.855719884236654,8.872009754180908,8.888159910837809,8.904169797897339,8.920049826304117,8.935799757639566,8.95139996210734,8.966869831085205,8.982209841410318,8.99740974108378,9.01246976852417,9.027389923731485,9.042180061340332,9.05683978398641,9.071359793345133,9.085739771525065,9.099979797999064,9.114089886347452,9.12805978457133,9.141899824142456,9.155599673589071,9.169159730275473,9.182589928309122,9.195879777272543,9.209039767583212,9.222059806187948,9.234939734141031,9.247689882914225,9.260299841562906,9.272779862085978,9.285120010375977,9.297319968541464,9.30938990910848,9.321329673131308,9.333120028177897,9.344779888788858,9.35630989074707,9.36769994099935,9.378949880599976,9.390069882074991,9.401049931844076,9.41189988454183,9.422609885533651,9.43317985534668,9.443620045979818,9.453919967015585,9.464089711507162,9.474119981129965,9.484009822209677,9.493770043055216,9.503399848937988,9.512889862060547,9.522240002950033,9.531459967295328,9.540539900461832,9.549489974975586,9.558299859364828,9.566969792048136,9.575509866078695,9.583919843037924,9.592179854710897,9.600319862365723,9.608309904734293,9.616179863611857,9.623899857203165,9.631489912668863,9.638949871063232,9.646269877751669,9.653449853261312,9.660499890645346,9.667419910430908,9.674199978510538,9.680840015411377,9.687339941660563,9.69372002283732,9.699949900309244,9.706049839655558,9.712019920349121,9.71785012880961,9.723549763361612,9.729109843571981,9.734530051549276,9.739820003509521,9.744979937871298,9.75,9.754879792531332,9.759630044301352,9.764249960581461,9.7687300046285,9.773070017496744,9.777279933293661,9.781349897384644,9.785289923350016,9.789089838663736,9.792760054270426,9.796290000279745,9.799690008163452,9.802949905395508,9.806079864501953,9.809069951375326,9.811929941177368,9.8146599928538,9.817239999771118,9.819689909617106,9.822010040283203,9.82420007387797,9.826249996821085,9.828160047531128,9.829939921696981,9.83157992362976,9.83309006690979,9.83446995417277,9.835699955622355,9.836810111999512,9.837779998779297,9.838610092798868,9.839310010274252,9.839879910151163,9.840310017267862,9.84060001373291,9.840760072072348,9.840789953867594,9.84067996342977,9.840439875920614,9.840059916178385,9.839550018310547,9.838899850845337,9.838119983673096,9.837199926376343,9.836219946543375,9.835229953130087,9.83424997329712,9.833269993464151,9.832280158996582,9.831299940745035,9.830320040384928,9.82932996749878,9.828349987665812,9.827370007832846,9.826390027999878,9.82539987564087,9.824419975280762,9.823439995447794,9.822460095087687,9.82146986325582,9.820489962895712,9.819509983062744,9.818530003229776,9.81754994392395,9.81656018892924,9.815580050150553,9.814599990844727,9.813620011011759,9.812639951705933,9.811659971872965,9.810679912567139,9.809689998626709,9.808710098266602,9.807729959487915,9.806750059127808,9.805769999821981,9.804790019989014,9.803809960683187,9.80282998085022,9.801850001017252,9.800869941711426,9.799889961878458,9.79891006151835,9.797930002212524,9.796950022379557,9.79596996307373,9.794989983240763,9.794010003407797,9.793030023574829,9.792050043741861,9.791069984436035,9.790090084075928,9.789120038350424,9.788139979044596,9.787160078684488,9.786180178324381,9.785200039545694,9.784219980239868,9.7832400004069,9.782270034154257,9.781290054321289,9.780309995015463,9.779329935709635,9.778349955876669,9.777379751205444,9.776400009791056,9.775420109430948,9.774440050125122,9.773470004399618,9.77248994509379,9.771510044733683,9.770529985427856,9.769559860229492,9.768580039342245,9.767600059509277,9.766630093256632,9.765649875005087,9.764669815699259,9.763700008392334,9.762720108032227,9.76173988978068,9.760770003000895,9.759790102640787,9.758820056915283,9.757839997609457,9.756869951883951,9.755889972050985,9.754910071690878,9.753940105438232,9.752959966659546,9.7519900004069,9.751010100046793,9.750039974848429,9.749059995015463,9.748089790344238,9.74711012840271,9.746139844258627,9.74515994389852,9.744189977645874,9.74321993192037,9.742239952087402,9.741269906361898,9.74029008547465,9.739319880803427,9.738339900970459,9.737369934717814,9.73639996846517,9.735420068105062,9.734450022379557,9.733479976654053,9.732499917348227,9.731530030568441,9.730559905370077,9.72957992553711,9.728610038757324,9.72763999303182,9.726670026779175,9.725690205891928,9.724720001220703,9.723750114440918,9.722779989242554,9.721800088882446,9.720830043156942,9.719859759012857,9.718889951705933,9.717920064926147,9.71694016456604,9.715969959894815,9.714999834696451,9.714030027389526,9.713059981664022,9.712089935938517,9.711120128631592,9.710140148798624,9.70917002360026,9.708199977874756,9.70723001162211,9.706259965896606,9.705289999643961,9.704319953918457,9.703349987665812,9.702380021413168,9.701410055160522,9.700439929962158,9.699470043182373,9.698499997456869,9.697530031204224,9.69655998547872,9.695590019226074,9.69461997350057,9.693650007247925,9.69267996152242,9.691709995269775,9.690739870071411,9.689769983291626,9.688810110092163,9.68784006436666,9.686870018641153,9.685900131861368,9.684930086135864,9.68396004041036,9.682989994684855,9.682029883066813,9.681060075759888,9.680089950561523,9.679120063781738,9.678150097529093,9.67718998591105,9.676219940185547,9.675249894460043,9.674280087153116,9.673319896062216,9.67234985033671,9.671380043029785,9.670409997304281,9.669450044631958,9.668479998906454,9.667510032653809,9.666550000508627,9.665579875310263,9.664609909057617,9.663649956385294,9.662680069605509,9.661709944407145,9.660749991734823,9.659779946009317,9.658819913864136,9.65785002708435,9.656889994939169,9.655919869740805,9.65494998296102,9.653989950815836,9.65302006403605,9.65206003189087,9.651090065638224,9.650129874547323,9.649159987767538,9.648200114568075,9.64722998936971,9.646269877751669,9.645299990971884,9.6443399588267,9.643380006154379,9.642409960428873,9.641450007756552,9.640479962031046,9.639520009358725,9.638550202051798,9.637589931488037,9.636630058288574,9.63566001256307,9.634699980417887,9.633740027745565,9.63277006149292,9.631809949874878,9.630849917729696,9.629879792531332,9.628919998804728,9.627960046132406,9.626999855041504,9.626030047734579,9.625069936116537,9.624109903971354,9.62315003077189,9.622179985046387,9.621220032374064,9.620259920756022,9.619300047556559,9.618330160776773,9.617369890213013,9.61641001701355,9.615449984868368,9.614489952723185,9.613530000050863,9.61256996790568,9.611599922180176,9.610639969507853,9.609680016835531,9.608720064163208,9.607759952545166,9.606799999872843,9.605839729309082,9.604880094528198,9.603919982910156,9.602959950764975,9.602000077565512,9.601040045420328,9.600080013275146,9.599119901657104,9.598159948984781,9.5971999168396,9.596239884694418,9.595759948094686};
    
    //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174915780623754,0.6330969383319219,0.643019954363505,0.6570649445056915,0.6710849404335022,0.6850789487361908,0.6990469495455424,0.7129999498526255,0.7269429415464401,0.7408789545297623,0.754803940653801,0.7687199413776398,0.7826269467671713,0.7965259452660879,0.8104169468084971,0.824299951394399,0.838173950711886,0.8520049502452215,0.8657579521338145,0.8794329464435577,0.8930299431085587,0.9065489421288172,0.9199909418821335,0.9333539406458536,0.9466379483540853,0.9598429501056671,0.9729699542125066,0.9860129455725352,0.9989649504423141,1.011829952398936,1.024599939584732,1.0372799535592396,1.0498699446519215,1.0623599588871002,1.0747699439525604,1.0870899657408397,1.099309931198756,1.1113699475924175,1.1231799523035686,1.1347399950027466,1.1460599601268768,1.157139966885249,1.1679599583148956,1.1785399615764618,1.188879946867625,1.1989599565664928,1.2087999681631725,1.218439946571986,1.2278999586900075,1.2371899684270222,1.246299962202708,1.2552499671777089,1.2640199859937031,1.2726299663384755,1.2810599605242412,1.2893199721972148,1.297399987777074,1.3052499691645305,1.3127799928188324,1.3199999928474426,1.3269099791844685,1.3334999879201253,1.339789976676305,1.3457599977652233,1.3514199753602345,1.3567599952220917,1.3617999752362568,1.3666499853134155,1.3714399735132854,1.3761699696381886,1.3808399836222331,1.385459989309311,1.3900200029214222,1.39451997478803,1.3989599744478862,1.4033499956130981,1.407669981320699,1.4119599958260853,1.4162099758783977,1.4204399784406025,1.4246399700641632,1.428819974263509,1.4329599837462108,1.4370799859364827,1.4411699871222179,1.4452399810155232,1.4492699801921844,1.4532799919446309,1.4572600026925404,1.4612199862798054,1.4651399850845337,1.46902996301651,1.472899983326594,1.4767399827639263,1.4805499811967213,1.484329988559087,1.4880799849828084,1.4917999804019928,1.495499978462855,1.499160001675288,1.5027999877929688,1.5064099828402202,1.5099799831708272,1.513530006011327,1.5170499881108601,1.5205499927202861,1.52400999267896,1.5274499952793121,1.5308599869410198,1.5342399875322978,1.537579983472824,1.5409000019232433,1.5441999832789104,1.5474599798520405,1.5506899853547413,1.55389999349912,1.5570800006389618,1.560229976971944,1.563349982102712,1.5664399862289429,1.5694999893506367,1.5725399851799011,1.5755399862925212,1.578519990046819,1.5814599792162578,1.5843799809614818,1.587270011504491,1.5901300013065338,1.5929699838161469,1.5957799851894379,1.598549981911977,1.6012999812761943,1.6040199895699818,1.6067099769910176,1.609369973341624,1.6119999885559082,1.6146099865436554,1.6171799997488658,1.6197300056616466,1.6222499807675679,1.6247399946053822,1.6272099912166595,1.6296399732430775,1.6320500075817108,1.634419987599055,1.6367700000603993,1.6390899817148845,1.6413799822330475,1.6436399916807811,1.6458700001239777,1.6480799913406372,1.65024999777476,1.6524000068505604,1.6545200049877167,1.6566099921862285,1.658679982026418,1.660709987084071,1.662720004717509,1.6646899978319805,1.6666399836540222,1.6685599784056346,1.6704499920209248,1.6723100046316783,1.6741500000158946,1.675960014263789,1.6777399977048237,1.679479996363322,1.6812099814414978,1.6828999817371368,1.6845599909623463,1.6862000028292339,1.6877999901771545,1.6893799901008606,1.6909299890200298,1.6924499968687694,1.6939499974250793,1.6954099734624226,1.6968499918778737,1.698259989420573,1.6996399958928425,1.7009899814923604,1.7023099958896637,1.7035999993483226,1.7048699955145519,1.7060999969641368,1.7073100010553997,1.7084899842739105,1.7096499900023143,1.7107699910799663,1.7118700047334034,1.7129299938678741,1.7139699856440227,1.714979996283849,1.7159599860509236,1.7169200082619984,1.7178399860858917,1.7187399963537853,1.7196100155512493,1.7204499940077465,1.7212599913279216,1.7220499912897747,1.7227999965349834,1.723529984553655,1.7242300113042195,1.72489998737971,1.725540002187093,1.726149986187617,1.7267399827639263,1.727290004491806,1.7278199990590413,1.7283299962679546,1.728800008694331,1.7292399903138478,1.7296600043773651,1.730050007502238,1.730409989754359,1.7307399809360504,1.7310400108496349,1.7313100000222523,1.7315599918365479,1.7317800025145214,1.731969992319743,1.7321299811204274,1.7322599788506825,1.7323700090249379,1.7324499984582264,1.732500006755193,1.7325199941794078,1.7325100004673004,1.7324700156847637,1.7324000000953674,1.7323099970817566,1.7321900129318237,1.7320399979750316,1.7318700055281322,1.731659988562266,1.7314299941062927,1.7311799923578899,1.7309399942557018,1.7306900123755138,1.7304400006930034,1.7301900088787079,1.7299500107765198,1.7296999891599019,1.7294500072797139,1.7292099992434184,1.7289599974950154,1.72871000568072,1.7284599939982097,1.728220005830129,1.7279699941476185,1.7277200023333232,1.7274799942970276,1.727230002482732,1.7269799908002217,1.7267400026321411,1.7264900008837383,1.7262399991353352,1.7259999910990398,1.7257499992847443,1.7254999975363414,1.7252600093682606,1.7250100175539653,1.7247699995835621,1.7245200177033742,1.7242700159549713,1.7240300079186757,1.7237799962361653,1.723529984553655,1.7232899864514668,1.7230399946371715,1.7227999965349834,1.7225500047206879,1.7222999930381775,1.7220599949359894,1.7218100031216939,1.721560001373291,1.7213199933369954,1.7210700114568074,1.720830003420512,1.7205799718697865,1.7203400035699208,1.720090001821518,1.7198399901390076,1.719600001970927,1.7193499902884166,1.7191099921862285,1.718860000371933,1.7186200022697449,1.7183700203895569,1.718130002419154,1.7178800106048584,1.7176299790541332,1.71739000082016,1.717139999071757,1.7168999910354614,1.716649999221166,1.7164100110530853,1.716159999370575,1.7159199913342793,1.715669999519984,1.715430001417796,1.7151800096035004,1.7149400115013123,1.7146899898846943,1.7144500017166138,1.7142000099023182,1.7139600018660228,1.7137100001176198,1.7134700020154316,1.7132199903329213,1.7129800021648407,1.7127300202846527,1.7124900023142497,1.7122399906317394,1.7120000024636586,1.7117599844932556,1.71150999267896,1.711270014444987,1.7110199928283691,1.710779994726181,1.7105299830436707,1.71028999487559,1.710039993127187,1.7098000049591064,1.7095600267251332,1.709309995174408,1.709069977204005,1.7088199853897095,1.708579997221629,1.7083400189876556,1.7080900073051453,1.7078500092029572,1.7075999875863392,1.7073599994182587,1.707119991381963,1.7068699995676677,1.7066300014654796,1.7063799997170765,1.7061399817466736,1.705899993578593,1.705650011698405,1.7054100036621094,1.7051699956258137,1.7049200038115184,1.7046800057093303,1.7044400076071422,1.7041900157928467,1.7039499878883362,1.7037000159422557,1.7034599880377452,1.7032199998696644,1.702969988187154,1.7027300000190735,1.7024899820486705,1.7022500038146973,1.7020000120004017,1.7017600138982136,1.7015199859937031,1.7012700041135151,1.7010299960772197,1.7007899979750316,1.700540006160736,1.700300008058548,1.7000600198904674,1.6998199721177418,1.699570010105769,1.6993300120035808,1.6990899940331776,1.6988399922847748,1.6985999941825867,1.698359986146291,1.698120007912318,1.6978699962298076,1.6976299981276195,1.6973899900913239,1.6971500118573506,1.6969000001748402,1.6966599921385448,1.6964199940363567,1.6961799959341686,1.6959299941857655,1.695690006017685,1.6954500079154968,1.6952100098133087,1.694970001777013,1.6947200000286102,1.6944800019264221,1.6942399839560192,1.6939999957879384,1.6937599976857503,1.6935099959373474,1.6932700077692668,1.6930300096670787,1.692790001630783,1.6925499836603801,1.6923000017801921,1.692060003678004,1.6918200155099232,1.6915799975395203,1.6913399994373322,1.6910999814669292,1.6908500095208485,1.6906099915504456,1.690370003382365,1.6901300052801769,1.6898899972438812,1.6896500090758007,1.6894099811712902,1.6891599893569946,1.688920001188914,1.688680003086726,1.6884400149186451,1.6882000068823497,1.6879600087801616,1.687720000743866,1.6874799927075703,1.6872299909591675,1.6869899829228718,1.6867500046888988,1.6865100065867107,1.686269998550415,1.686030000448227,1.6857900023460388,1.6855500042438507,1.6853099862734477,1.685069998105367,1.6848300099372864,1.6845900019009907,1.6843399902184804,1.6841000119845073,1.6838599940141041,1.683619995911916,1.683379997809728,1.6831399997075398,1.6828999916712444,1.6826599935690563,1.6824200054009755,1.68217999736468,1.681939999262492,1.6817000011603038,1.6814600030581157,1.6812200049559276,1.680979996919632,1.6807399988174438,1.6805000007152557,1.6802600026130676,1.680019994576772,1.6797800064086914,1.6795399983723958,1.6793000002702076,1.6790599922339122,1.6788200040658314,1.6785800059636433,1.678339997927348,1.6780999998251598,1.6778600017229717,1.6776200036207836,1.677379995584488,1.6771399974822998,1.6769000093142192,1.6766600012779236,1.676419993241628,1.6761800050735474,1.6759400069713593,1.6756999989350636,1.6754699846108754,1.6752299964427948,1.6749900082747142,1.6747500002384186,1.674510012070338,1.67427001396815,1.6740299959977467,1.6737900078296661,1.6735499997933705,1.673309991757075,1.6730700035889943,1.6728300054868062,1.6726000010967255,1.6723599930604298,1.6721200048923492,1.6718800067901611,1.6716399987538655,1.671400010585785,1.6711599826812744,1.671040008465449};
    
    //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.1819763332605362,0.18440800160169601,0.18686800077557564,0.1893090009689331,0.19174600268403688,0.1941789984703064,0.1966069998840491,0.19903100033601126,0.2014529990653197,0.20387499903639159,0.20629500225186348,0.2087130012611548,0.21112899978955588,0.21354400118192038,0.2159569983681043,0.21836800128221512,0.2207770012319088,0.22317799925804138,0.2255660022298495,0.22794099897146225,0.23030100017786026,0.2326470005015532,0.23497900118430456,0.2372990002234777,0.23960499837994576,0.2418960022429625,0.2441730002562205,0.24643600235382715,0.2486829993625482,0.25091400121649104,0.2531290004650752,0.2553269962469737,0.2575090030829112,0.2596740052103996,0.26182399690151215,0.2639579971631368,0.2660760035117467,0.268165002266566,0.27021000037590664,0.2722110003232956,0.27416900048653287,0.2760850042104721,0.2779570048054059,0.27978600064913434,0.28157100329796475,0.2833130011955897,0.28501300017038983,0.28667500366767246,0.2883070036768913,0.2899090001980464,0.29148100068171817,0.2930219992995262,0.29453299939632416,0.2960139984885852,0.2974649990598361,0.2988849977652232,0.3002759963274002,0.30162400503953296,0.3029170011480649,0.3041549970706304,0.3053379977742831,0.30646699915329617,0.30754100034634274,0.3085600013534228,0.3095240021745364,0.31043299784262973,0.3112880016366641,0.3121110002199809,0.31292300174633664,0.3137260004878044,0.3145179996887843,0.31529899686574936,0.31606999536355335,0.31683099766572315,0.3175820012887319,0.31832199543714523,0.31905200332403183,0.31977399935324985,0.3204899976650874,0.32120299835999805,0.3219119980931282,0.32261500010887784,0.32331400116284686,0.32400699704885483,0.32469500601291656,0.3253780007362366,0.3260580003261566,0.32673299809296924,0.3274019981424014,0.32806700219710666,0.3287250027060509,0.32937900225321454,0.3300280049443245,0.33067100246747333,0.3313090006510417,0.3319430003563563,0.33257300158341724,0.33319799850384396,0.3338180060187976,0.33443200091520947,0.33504099647204083,0.33564499765634537,0.33624399950106937,0.336837001144886,0.33742600679397583,0.3380089998245239,0.33858700344959897,0.3391590043902397,0.3397270043690999,0.34028899669647217,0.3408460021018982,0.3413989990949631,0.3419480000933011,0.3424919992685318,0.3430310015877088,0.3435639987389247,0.3440930073459943,0.34461600085099536,0.3451339950164159,0.3456460013985634,0.34615400185187656,0.3466560021042824,0.3471530005335808,0.34764500210682553,0.3481309985121091,0.3486130014061928,0.34908899913231534,0.3495599975188573,0.35002700239419937,0.3504909972349803,0.3509489968419075,0.3514010012149811,0.3518490021427472,0.35229100038607913,0.3527289976676305,0.3531610021988551,0.3535879999399185,0.3540089974800746,0.35442599654197693,0.35483700037002563,0.3552429998914401,0.35564399758974713,0.35603999594847363,0.35642999907334644,0.35681600123643875,0.35719700157642365,0.3575750042994817,0.3579469993710518,0.35831500341494876,0.3586769973238309,0.3590329959988594,0.35938500116268796,0.3597320020198822,0.36007299770911533,0.3604090039928754,0.36073999603589374,0.361065998673439,0.36138699700435,0.3617019976178805,0.3620129997531573,0.3623180016875267,0.36261899769306183,0.3629169960816701,0.3632089967528979,0.363496000568072,0.3637780000766118,0.3640549952785174,0.36432599773009616,0.3645930017034213,0.36485400050878525,0.36510999997456867,0.3653609976172447,0.36560699840386707,0.36584800233443576,0.3660829986135165,0.36631399889787036,0.36653900146484375,0.3667590022087097,0.36697499950726825,0.3671869958440463,0.36739499866962433,0.36759699632724124,0.3677939971288045,0.36798500021298725,0.3681719998518626,0.36835400263468426,0.3685300002495448,0.3687010010083516,0.3688669999440511,0.36902799954017,0.3691839973131816,0.36933499823013943,0.3694799989461899,0.3696209987004598,0.36975600322087604,0.3698869968454043,0.3700150003035863,0.3701369936267535,0.3702549984057744,0.37036700050036114,0.3704740007718404,0.37057600170373917,0.3706730008125305,0.37076399723688763,0.37085100015004474,0.37093299875656766,0.3710090046127637,0.3710800011952718,0.3711460009217262,0.3712070013086001,0.3712629998723666,0.37131399661302567,0.37136100480953854,0.3714040021101634,0.3714420000712077,0.3714749986926715,0.37150199959675473,0.37152499953905743,0.3715430001417796,0.3715549980600675,0.37156199912230176,0.37156499922275543,0.37156199912230176,0.3715539996822675,0.37154099841912586,0.3715229978164037,0.3714990019798279,0.37147100021441776,0.37143899748722714,0.3714030012488365,0.37136200070381165,0.37131499995787937,0.3712640007336934,0.37120800216992694,0.3711459959546725,0.37107999871174496,0.3710079987843831,0.37093399713436764,0.370859997967879,0.3707849954565366,0.37071099629004794,0.37063700209061307,0.37056299795707065,0.3704889938235283,0.37041500210762024,0.3703409979740779,0.37026700129111606,0.3701929996411006,0.37011900047461194,0.3700449988245964,0.36997099965810776,0.3698970004916191,0.3698229988416036,0.36974899967511493,0.3696750005086263,0.3696009988586108,0.36952699969212216,0.36945299804210663,0.36937900135914487,0.36930500467618305,0.3692310055096944,0.3691579947868983,0.3690840005874634,0.36900999397039413,0.3689360022544861,0.36886200060447055,0.36878900478283566,0.36871500313282013,0.36864099899927777,0.36856700231631595,0.36849399904410046,0.3684199998776118,0.3683459982275963,0.3682729999224345,0.36819900075594586,0.3681250015894572,0.36805199831724167,0.3679780016342799,0.36790499836206436,0.3678310016791026,0.36775700002908707,0.3676840017239253,0.36761000007390976,0.3675369968016942,0.36746300011873245,0.3673900042970975,0.36731599768002826,0.3672429993748665,0.36716999610265094,0.3670959994196892,0.3670229986310005,0.36694899946451187,0.3668759986758232,0.36680300533771515,0.3667289987206459,0.36665600041548413,0.3665829971432686,0.3665090004603068,0.36643599967161816,0.3663629963994026,0.36628899971644086,0.3662159964442253,0.36614299813906354,0.3660699998339017,0.3659960056344668,0.3659229949116707,0.3658500015735626,0.36577700078487396,0.3657039999961853,0.36563099920749664,0.3655580033858617,0.3654840017358462,0.3654109984636307,0.3653380001584689,0.36526499936978024,0.3651920010646184,0.3651189977924029,0.365046001970768,0.36497299869855243,0.36490000039339066,0.3648270070552826,0.36475399881601334,0.36468100051085156,0.3646079997221629,0.36453500141700107,0.3644630014896393,0.36438999821742374,0.36431699494520825,0.3642439991235733,0.36417099833488464,0.3640980025132497,0.3640250042080879,0.36395300179719925,0.3638799985249837,0.36380699773629505,0.36373400191466015,0.3636619995037715,0.3635889987150828,0.3635159954428673,0.36344299962123233,0.36337099969387054,0.3632979989051819,0.36322500308354694,0.36315300067265827,0.3630799998839696,0.3630079999566078,0.36293499916791916,0.3628619983792305,0.3627899984518687,0.36271699766318005,0.3626450002193451,0.36257199943065643,0.36249999950329465,0.3624270011981328,0.36235499382019043,0.36228200296560925,0.3622099980711937,0.3621369997660319,0.36206500232219696,0.3619929999113083,0.3619200016061465,0.36184799919525784,0.3617749984065692,0.36170299847920734,0.36163100351889926,0.3615580002466838,0.36148600031932193,0.36141400039196014,0.36134200046459836,0.3612689996759097,0.36119699974854785,0.36112500230471295,0.3610530023773511,0.36097999662160873,0.3609079991777738,0.360835999250412,0.36076400180657703,0.3606920043627421,0.36062000195185345,0.3605470036466916,0.36047500123580295,0.36040299634138745,0.3603310013810794,0.3602590039372444,0.36018699904282886,0.36011500159899396,0.3600430016716321,0.3599709967772166,0.35989899933338165,0.35982699940601987,0.359754999478658,0.35968299706776935,0.35961099962393445,0.3595389996965726,0.3594669948021571,0.35939600070317584,0.35932400077581406,0.3592519983649254,0.3591799984375636,0.35910799851020175,0.3590359960993131,0.358964999516805,0.3588930020729701,0.35882100214560825,0.3587489997347196,0.35867800066868466,0.3586059957742691,0.35853400081396103,0.35846200337012607,0.3583909993370374,0.3583189994096756,0.3582469994823138,0.35817600041627884,0.35810399800539017,0.3580320005615552,0.3579610014955203,0.3578889990846316,0.35781800001859665,0.3577460025747617,0.3576750035087268,0.3576029986143112,0.3575319970647494,0.3574599971373876,0.3573890005548795,0.3573169981439908,0.357245996594429,0.35717399915059406,0.35710299760103226,0.3570310026407242,0.3569600035746892,0.3568889995416005,0.35681699713071185,0.35674599806467694,0.35667500148216885,0.356603001554807,0.3565319975217183,0.3564609984556834,0.35638900101184845,0.35631799946228665,0.35624699542919797,0.3561760038137436,0.35610399891932804,0.35603300233681995,0.35596200078725815,0.35589099923769635,0.3558199927210808,0.3557480027278264,0.3556770036617915,0.35560599714517593,0.35553500056266785,0.35546399901310605,0.35539300243059796,0.3553219983975093,0.3552509993314743,0.35518000026543933,0.3551090011994044,0.35503800213336945,0.35496699810028076,0.3548959990342458,0.3548249999682109,0.3547540009021759,0.3546829993526141,0.35461200028657913,0.35454100122054416,0.35446999967098236,0.35439899812142056,0.3543279990553856,0.3542569975058238,0.3541869993011157,0.3541160002350807,0.35404500365257263,0.35397399961948395,0.35390300303697586,0.35383299986521405,0.3537620007991791,0.3536910017331441,0.3536199977000554,0.3535499970118205,0.3534790004293124,0.3534080038468043,0.3533379981915156,0.35326699912548065,0.35319600254297256,0.35312599937121075,0.3530550003051758,0.35302000244458515};
    //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12690700963139534,0.12775100022554398,0.1286540006597837,0.12951799978812537,0.13038100053866705,0.13124300042788187,0.13210400069753328,0.13296199838320413,0.13381999855240187,0.13467700158556303,0.1355340008934339,0.13639099895954132,0.1372460015118122,0.1381000019609928,0.1389550007879734,0.13980899999539056,0.14066100244720778,0.14151100317637125,0.1423560008406639,0.14319699878493944,0.14403199901183447,0.14486200114091238,0.14568699896335602,0.146506999929746,0.14732300117611885,0.14813299849629402,0.1489379989604155,0.1497380013267199,0.15053199728329977,0.15131999924778938,0.15210199852784476,0.15287800257404646,0.15364899983008704,0.1544130009909471,0.15517100070913634,0.15592499946554503,0.15667199964324632,0.15740800028045973,0.15812800203760466,0.15883299832542738,0.1595219982167085,0.16019499798615774,0.16085299973686537,0.16149499888221422,0.16212100038925806,0.16273200139403343,0.16332700103521347,0.16390900065501532,0.16448000073432922,0.16504000003139177,0.16558900102972984,0.16612700000405312,0.16665499905745187,0.16717100143432617,0.16767700016498566,0.1681709997355938,0.16865399976571402,0.1691220005353292,0.1695709985991319,0.1699990009268125,0.17040800054868063,0.17079699908693632,0.17116600026686987,0.1715150016049544,0.17184400061766306,0.17215399940808615,0.17244300122062364,0.1727209985256195,0.17299500231941542,0.1732660010457039,0.17353300005197525,0.17379600057999292,0.17405500014623007,0.17430999875068665,0.17456100011865297,0.17480899890263876,0.17505399882793427,0.17529499903321266,0.1755350021024545,0.17577299972375235,0.1760100002090136,0.17624399935205778,0.1764769988755385,0.1767079991598924,0.17693700020511946,0.17716499914725622,0.17738999923070273,0.17761400093634924,0.17783699929714203,0.17805699755748114,0.1782750003039837,0.17849199970563254,0.17870700110991797,0.17892100165287653,0.17913199961185455,0.179342000434796,0.17954999829332033,0.17975599939624468,0.17996099963784218,0.18016199891765913,0.18036200106143951,0.18055899813771248,0.1807550018032392,0.1809490012625853,0.18114100272456804,0.1813309999803702,0.18152000258366266,0.18170699973901114,0.1818920001387596,0.18207500005761781,0.18225600073734918,0.1824360005557537,0.18261400113503137,0.1827910008529822,0.18296500047047934,0.1831379992266496,0.1833090012272199,0.1834780015051365,0.18364499881863594,0.18381099899609885,0.18397499869267145,0.18413699915011725,0.1842979999879996,0.18445599948366484,0.18461199974020323,0.18476600075761476,0.1849179988106092,0.1850670004884402,0.18521599968274435,0.1853619987765948,0.1855070007344087,0.18564999972780546,0.18579099824031195,0.18592999875545502,0.18606799965103468,0.18620400006572405,0.18633799875775972,0.18647000193595886,0.18660100052754083,0.18672999863823256,0.18685699875156084,0.1869819996257623,0.18710600088040033,0.18722800289591154,0.18734799946347871,0.18746600051720938,0.18758299946784973,0.18769799917936325,0.18781099965174994,0.18792199964324632,0.18802999953428903,0.1881360001862049,0.18823999787370363,0.1883429984251658,0.18844399973750114,0.18854299932718277,0.18864099929730097,0.18873699878652891,0.18883099903663,0.18892299880584082,0.18901300057768822,0.18910200024644533,0.1891889994343122,0.18927399814128876,0.18935800095399222,0.18944000204404196,0.18952000265320143,0.18959800029794374,0.18967500080664954,0.18975000083446503,0.1898229978978634,0.18989400068918863,0.1899640013774236,0.1900320015847683,0.19009700044989586,0.1901600000758966,0.19022100046277046,0.19028000036875406,0.19033799692988396,0.19039400046070418,0.19044800102710724,0.1904999998708566,0.19055100033680597,0.19060000156362852,0.19064700106779733,0.1906920000910759,0.1907360019783179,0.19077799965937933,0.19081800182660422,0.19085700064897537,0.19089300061265627,0.19092899933457375,0.19096200043956438,0.19099299858013788,0.1910229983429114,0.19105199972788492,0.19107800101240477,0.1911030001938343,0.191126000136137,0.19114600121974945,0.19116400058070818,0.19117999946077666,0.1911940003434817,0.19120700160662332,0.19121799990534782,0.1912270002067089,0.1912349984049797,0.19124000271161398,0.19124399994810423,0.19124700129032135,0.1912470000485579,0.1912460004289945,0.19124300157030424,0.19123899936676025,0.1912330004076163,0.19122499972581863,0.19121499980489412,0.19120399902264276,0.19118999689817429,0.19117600098252296,0.19115899999936423,0.19114099939664206,0.19112099831302962,0.1910990004738172,0.1910749984284242,0.19104800124963126,0.19101899738113085,0.19098899761835733,0.19095700109998384,0.19092399875322977,0.19088800003131232,0.190851000448068,0.1908120003839334,0.19077200070023537,0.19072900091608366,0.19068600237369537,0.19063999876379967,0.19059300050139427,0.190546998133262,0.1904999998708566,0.19045400122801462,0.1904080001016458,0.19036100308100382,0.19031500071287155,0.1902679999669393,0.19022200256586075,0.1901759977142016,0.1901289994517962,0.1900829995671908,0.1900360013047854,0.18999000017841658,0.18994399905204773,0.1898969995478789,0.18985100090503693,0.18980500102043152,0.18975899989406267,0.18971200038989386,0.18966600050528845,0.18962000062068304,0.18957299987475076,0.18952699874838194,0.18948099886377653,0.18943499897917113,0.18938900033632913,0.18934199834863344,0.18929599970579147,0.18924999982118607,0.18920399993658066,0.1891579975684484,0.18911200016736984,0.18906600028276443,0.18901899953683218,0.18897300213575363,0.18892699976762137,0.18888099988301596,0.18883500124017397,0.1887889988720417,0.18874300022919974,0.1886969991028309,0.18865099921822548,0.1886050005753835,0.18855899944901466,0.18851299956440926,0.1884670009215673,0.18842099979519844,0.18837500115235647,0.18832899878422418,0.18828299765785536,0.18823700274030367,0.18819099788864455,0.18814600010712942,0.18809999773899713,0.18805399909615517,0.18800799796978632,0.18796199932694435,0.18791600068410239,0.18786999955773354,0.18782500053445497,0.1877789981663227,0.18773299952348074,0.18768699963887533,0.18764099975426993,0.18759599948922792,0.1875499996046225,0.1875039997200171,0.18745799859364828,0.18741300081213316,0.1873669996857643,0.18732099855939546,0.18727600201964378,0.18722999840974808,0.18718400100866953,0.1871389995018641,0.18709300210078558,0.18704700221618017,0.18700200070937475,0.1869559995830059,0.18691099931796393,0.18686499819159508,0.1868189995487531,0.1867739992837111,0.18672800188263258,0.18668300037582716,0.18663700049122176,0.18659199898441634,0.18654599909981093,0.18650100256005922,0.18645500019192696,0.1864100011686484,0.18636399880051613,0.18631899977723757,0.1862730011343956,0.18622799962759018,0.18618300060431162,0.1861369994779428,0.18609200045466423,0.18604600181182226,0.18600100154678026,0.18595600128173828,0.18590999891360602,0.1858650011320909,0.18581999838352203,0.18577399974068007,0.18572900195916495,0.18568400169412294,0.18563799932599068,0.1855929990609487,0.18554800003767014,0.18550300101439157,0.18545700112978616,0.1854119971394539,0.18536700308322906,0.1853220003346602,0.18527699882785478,0.18523099894324938,0.1851859986782074,0.18514099965492883,0.18509599938988686,0.18505100160837173,0.18500599885980287,0.18496099983652434,0.1849149987101555,0.18486999968687692,0.1848250006635984,0.18477999791502953,0.18473499889175096,0.18468999986847243,0.18464499960343042,0.18460000058015189,0.18455499907334647,0.1845100000500679,0.18446499854326248,0.18442000076174736,0.18437500049670538,0.18432999898989996,0.1842849999666214,0.18424000094334284,0.18419499943653742,0.18415000041325888,0.18410500014821687,0.18406000236670175,0.18401599923769632,0.18397100021441778,0.18392599870761236,0.1838809996843338,0.18383600066105524,0.18379100039601326,0.18374699975053468,0.18370199824372926,0.18365699922045073,0.1836120014389356,0.18356700241565704,0.18352300052841505,0.18347799902160963,0.18343300248185793,0.1833879997332891,0.18334400281310081,0.18329900006453195,0.18325399979948997,0.183208999534448,0.18316500013073286,0.1831200011074543,0.18307500084241232,0.1830310014386972,0.18298600241541862,0.18294200176994005,0.18289699902137121,0.1828519987563292,0.18280799935261408,0.18276300032933554,0.1827189972003301,0.18267399817705154,0.1826299987733364,0.18258499975005785,0.1825400007267793,0.1824959988395373,0.18245100105802217,0.18240700165430704,0.18236200014750162,0.18231799950202307,0.18227400009830794,0.18222899983326593,0.18218499918778738,0.18214000140627226,0.18209599827726683,0.1820510004957517,0.18200700109203657,0.181963000446558,0.18191799893975258,0.181873998294274,0.18182900051275888,0.18178500359257063,0.18174099798003832,0.18169600144028664,0.18165200079480806,0.1816080001493295,0.18156400074561438,0.18151900048057237,0.18147500107685724,0.1814310004313787,0.18138699978590012,0.18134199952085814,0.181298000117143,0.18125400071342787,0.18121000130971274,0.18116499980290732,0.18112100039919218,0.1810769997537136,0.18103300159176192,0.18098900094628334,0.18094500030080476,0.18090099965532622,0.18085600063204765,0.18081200247009596,0.18076800306638083,0.18072400242090225,0.18068000053366026,0.18063599864641824,0.1805919992427031,0.18054799735546112,0.18050400043527284,0.18046000227332115,0.18041600038607916,0.18037199974060059,0.180327999095122,0.18028399969140688,0.18024000028769174,0.18019600212574005,0.18015199899673462,0.18010799959301949,0.18006400018930435,0.18002000451087952,0.17997600014011064,0.1799320007363955,0.17988899971048036,0.17984499906500181,0.1798010009030501,0.17975700025757155,0.17971299961209297,0.1796689989666144,0.1796259991824627,0.179582001020511,0.17953800037503242,0.179493997246027,0.1794499990840753,0.17942800124486288};
    
    C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.28439398606618244,0.28998400022586185,0.2952809954682986,0.3013310010234515,0.30736899624268216,0.3133940001328786,0.3194090003768603,0.325413999458154,0.33141400416692096,0.33740900208552677,0.3433990031480789,0.34938499828179675,0.35536499818166095,0.3613409996032715,0.3673119992017746,0.3732779969771703,0.3792390003800392,0.38518000145753223,0.39108599970738095,0.39695799847443897,0.4027950018644333,0.4085980032881101,0.4143649985392888,0.420095997552077,0.42579300204912823,0.43145500123500824,0.43708300590515137,0.4426730026801427,0.44822200387716293,0.4537289987007777,0.459196999669075,0.46462400257587433,0.47000999997059506,0.4753569985429446,0.480663001537323,0.4859289973974228,0.491155003507932,0.4963059996565183,0.5013489996393522,0.5062839984893799,0.5111110011736552,0.5158309936523438,0.5204419990380605,0.5249459991852442,0.5293410023053488,0.5336299985647202,0.5378109912077585,0.5418999940156937,0.5459139992793401,0.5498520036538442,0.5537149955828985,0.5575030048688253,0.561215008298556,0.5648519943157831,0.5684140026569366,0.571900005141894,0.5753110001484553,0.578616996606191,0.5817860017220179,0.5848179906606674,0.5877149999141693,0.5904739946126938,0.593098004659017,0.5955850034952164,0.5979369978109995,0.6001519958178202,0.6022310008605322,0.6042290031909943,0.6062020013729731,0.6081490069627762,0.6100700050592422,0.6119659940401713,0.613836000363032,0.6156799991925558,0.61749899884065,0.6192919909954071,0.6210589955250422,0.6228080044190089,0.6245440045992533,0.6262689977884293,0.6279809971650442,0.6296809961398443,0.6313689996798834,0.6330449978510538,0.6347090055545171,0.6363610029220581,0.6380000015099844,0.6396279980738958,0.6412420024474462,0.6428439964850744,0.6444329967101415,0.646010011434555,0.6475730091333389,0.6491229931513468,0.6506610065698624,0.6521860013405482,0.653698002298673,0.6551979978879293,0.6566850046316782,0.6581589976946512,0.6596200068791708,0.6610690007607142,0.6625039974848429,0.6639269987742106,0.6653370062510172,0.6667350083589554,0.6681199967861176,0.6694919963677725,0.6708519955476125,0.672199010848999,0.6735330075025558,0.6748549987872442,0.676163007815679,0.6774589916070303,0.6787429948647817,0.6800130059321722,0.6812709867954254,0.68251700202624,0.6837500035762787,0.6849700013796488,0.686178003748258,0.6873730023701986,0.688554992278417,0.6897239983081818,0.6908810039361318,0.6920250008503596,0.6931570023298264,0.6942750016848246,0.6953819940487543,0.6964760025342306,0.6975570023059845,0.6986250032981237,0.6996810038884481,0.7007240056991577,0.7017550071080526,0.7027719964583715,0.7037780036528906,0.7047710021336874,0.7057509968678156,0.7067199995120367,0.7076749900976816,0.7086180100838343,0.7095479965209961,0.7104649941126505,0.7113700012365977,0.7122619946797689,0.7131420026222864,0.7140090068181356,0.7148640006780624,0.7157060007254282,0.7165370037158331,0.7173539946476618,0.7181589951117834,0.7189510017633438,0.7197300046682358,0.7204970071713129,0.7212519943714142,0.7219940076271693,0.7227240006128947,0.723440999786059,0.7241459985574087,0.7248379985491434,0.7255179981390635,0.7261859973271688,0.7268399943908056,0.727482000986735,0.7281119922796885,0.7287290046612421,0.7293339967727661,0.7299270033836365,0.7305070062478384,0.7310740053653717,0.7316290040810903,0.7321709940830866,0.7327010035514832,0.7332189927498499,0.7337239980697632,0.7342170029878616,0.7346979975700378,0.7351659933725992,0.7356220036745071,0.736065000295639,0.7364959965149561,0.7369140038887659,0.7373199959595998,0.73771400252978,0.7380950053532919,0.7384639978408813,0.7388199965159098,0.7391649931669235,0.7394959976275762,0.7398160050312678,0.7401239971319834,0.7404179920752844,0.7407009998957316,0.7409700006246567,0.741227999329567,0.7414730042219162,0.741706003745397,0.7419270028670629,0.7421349982420603,0.7423310031493505,0.7425139993429184,0.7426850001017252,0.7428440004587173,0.7429910053809484,0.7431250015894572,0.743247002363205,0.7433570077021917,0.7434539993604025,0.7435399939616522,0.7436130046844482,0.7436740001042684,0.7437220017115275,0.7437570045391718,0.7437810003757477,0.7437930007775625,0.7437909990549088,0.7437789986530939,0.7437540044387182,0.7437160015106201,0.743666003147761,0.7436030010382334,0.7435290018717448,0.7434420088926951,0.7433430006106695,0.7432320068279902,0.743108997742335,0.7429729998111725,0.7428259899218878,0.742666999499003,0.7424939970175425,0.7423099974791209,0.7421130041281382,0.741904005408287,0.7416830013195673,0.7414500017960867,0.7412109971046448,0.7409720023473104,0.7407330026229223,0.7404939929644266,0.740255003174146,0.7400160034497579,0.739776998758316,0.7395390023787817,0.7392999976873398,0.7390620062748591,0.7388239999612173,0.7385850052038828,0.738346998890241,0.7381089975436529,0.7378710011641184,0.737633004784584,0.7373949984709421,0.7371570020914078,0.7369189957777659,0.7366820027430853,0.7364440013964971,0.736206998427709,0.7359689921140671,0.7357319990793864,0.735494002699852,0.7352569947640101,0.7350200017293295,0.7347830086946487,0.7345459957917532,0.7343090027570724,0.7340720047553381,0.7338360051314036,0.7335989971955618,0.7333620091279348,0.7331259995698929,0.7328890015681585,0.732653001944224,0.7324170023202896,0.7321799943844477,0.7319440046946207,0.7317080050706863,0.7314719955126444,0.73123599588871,0.7310000061988831,0.7307649999856949,0.7305290003617605,0.730293000737826,0.7300580044587454,0.7298219949007034,0.729586993654569,0.7293519973754883,0.7291160027186075,0.7288810014724731,0.7286460051933924,0.7284109989802042,0.7281759977340698,0.7279410014549891,0.7277070085207621,0.7274720023075739,0.7272370109955469,0.7270030081272125,0.7267679969469706,0.7265339990456899,0.7262989977995554,0.7260649998982748,0.725831001996994,0.7255969991286596,0.7253630012273788,0.7251290033260981,0.7248950004577637,0.7246609975894293,0.7244280030330023,0.7241940100987753,0.7239599972963333,0.7237269928057989,0.7234930048386256,0.7232600003480911,0.7230269958575567,0.7227940013011297,0.7225599934657415,0.7223269989093145,0.7220939993858337,0.7218620032072067,0.7216290086507797,0.7213959991931915,0.7211629996697108,0.7209309935569763,0.7206979990005493,0.7204660028219223,0.7202329983313879,0.7200010021527609,0.7197690059741338,0.7195369998613993,0.7193049987157186,0.7190730075041453,0.7188410013914108,0.7186090052127838,0.7183769891659418,0.7181449929873148,0.7179140051205953,0.7176820039749146,0.7174509962399801,0.7172190050284067,0.7169879972934723,0.716757004459699,0.7165259917577108,0.71629399061203,0.716062992811203,0.7158319900433222,0.7156019955873489,0.7153709977865219,0.7151399950186411,0.7149090021848679,0.7146789928277334,0.7144479950269064,0.714218000570933,0.713988001147906,0.7137569983800253,0.7135269989569982,0.7132969945669174,0.7130670001109441,0.7128369957208633,0.7126069962978363,0.712377001841863,0.7121469924847285,0.7119180063406626,0.7116879969835281,0.7114590108394623,0.7112290064493815,0.710999995470047,0.7107700059811274,0.7105409999688467,0.7103119989236196,0.7100830028454462,0.7098540018002192,0.7096250057220459,0.7093959997097651,0.7091669936974844,0.7089390108982722,0.7087099999189377,0.7084809939066569,0.7082530011733373,0.7080240100622177,0.7077960024277369,0.7075679997603098,0.7073390036821365,0.7071109960476557,0.7068829983472824,0.7066550006469091,0.7064270029465357,0.7061999986569086,0.7059719959894816,0.7057439982891083,0.705516000588735,0.7052890012661616,0.7050610134998957,0.7048339992761612,0.7046069999535879,0.7043789972861608,0.7041519979635874,0.7039250036080679,0.7036979993184408,0.7034709850947062,0.7032440006732941,0.7030170013507208,0.7027909954388937,0.7025639961163203,0.7023370017608007,0.7021109958489736,0.7018840114275614,0.7016580055157343,0.701432004570961,0.7012060085932413,0.7009789993365606,0.7007530033588409,0.7005269974470139,0.7003010014692942,0.7000750005245209,0.6998499979575475,0.6996240019798279,0.6993979960680008,0.6991730034351349,0.6989469975233078,0.6987219999233881,0.6984960039456686,0.6982709914445877,0.6980459988117218,0.6978210012118021,0.6975959986448288,0.6973710010449091,0.6971459984779358,0.6969210008780161,0.6966959983110428,0.6964709957440695,0.6962469965219498,0.6960219989220301,0.6957979996999105,0.6955730020999908,0.6953490078449249,0.6951249986886978,0.6949010044336319,0.6946759968996048,0.6944519976774851,0.694228008389473,0.6940050025780996,0.6937810033559799,0.6935569991668066,0.6933329949776331,0.693110004067421,0.6928860048453013,0.6926629990339279,0.6924389998118082,0.6922159940004349,0.6919930080572764,0.6917689989010493,0.6915460030237833,0.69132299721241,0.6911000112692515,0.6908769905567169,0.6906550079584122,0.690431997179985,0.6902089963356653,0.6899860004583994,0.6897639979918798,0.6895409921805064,0.6893190145492554,0.689097007115682,0.6888740013043085,0.6886519988377889,0.688430001338323,0.6882079988718033,0.6879859964052836,0.6877640038728714,0.687541996439298,0.6873209973176321,0.6870989998181661,0.6868770023187002,0.6866559982299805,0.6864340007305145,0.6862130065759023,0.6859919975201288,0.6857699950536092,0.6855490058660507,0.6853279968102773,0.685107002655665,0.6848859985669454,0.6846649994452795,0.6844440003236135,0.6843339999516805};
    
    //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.1294374316930771,0.1327739991247654,0.13611899688839912,0.1396499996383985,0.14317300046483675,0.14668900271256766,0.15019900103410086,0.15370400001605353,0.15720600013931593,0.16070399805903435,0.1641990008453528,0.16769199818372726,0.17118199914693832,0.17466899876793227,0.1781540016333262,0.18163499856988588,0.1851150020956993,0.1885819969077905,0.19202900057037672,0.19545499856273332,0.19886100043853125,0.20224599788586298,0.20561099921663603,0.20895599822203317,0.21227999900778136,0.21558399870991707,0.21886799981196722,0.22213000059127808,0.22536800056695938,0.22858199973901114,0.2317730002105236,0.23494000112016997,0.23808400084575018,0.24120399604241052,0.2443000003695488,0.24737300102909407,0.25042200088500977,0.2534280021985372,0.25637100885311764,0.2592509960134824,0.2620689993103345,0.2648240029811859,0.26751600205898285,0.2701450015107791,0.27271099885304767,0.2752150023976962,0.2776560013492902,0.2800450026988983,0.282389002541701,0.28468799591064453,0.2869440019130707,0.2891560023029645,0.2913239970803261,0.2934490020076434,0.2955299938718478,0.2975669999917348,0.29956099887688953,0.30149300396442413,0.3033449972669284,0.30511800199747086,0.30681100239356357,0.3084249993165334,0.3099600027004878,0.31141600261131924,0.31279200315475464,0.31408900022506714,0.31530700127283734,0.31647800157467526,0.3176340013742447,0.3187740022937457,0.3199000010887782,0.3210109993815422,0.3221069996555646,0.3231879969437917,0.32425400366385776,0.325305995841821,0.32634300241867703,0.3273689995209376,0.3283869996666908,0.3293989996115367,0.33040300259987515,0.33139999955892563,0.3323900029063225,0.3333740060528119,0.33435000230868656,0.33531899998585385,0.3362800007065137,0.3372340003649394,0.3381819948554039,0.3391219998399417,0.3400529970725377,0.3409780040383339,0.34189600000778836,0.34280500064293545,0.34370799859364826,0.3446030020713806,0.3454899936914444,0.346370001633962,0.3472429985801379,0.3481080010533333,0.3489669958750407,0.3498169978459676,0.3506609996159871,0.35149699697891873,0.3523249998688698,0.3531460016965866,0.35395999997854233,0.3547650029261907,0.3555639982223511,0.3563559949398041,0.3571389988064766,0.3579159999887149,0.358684999247392,0.3594460015495618,0.3602009986837705,0.36094800134499866,0.3616870045661926,0.3624189992745717,0.3631440003712972,0.3638609970609347,0.3645700017611186,0.36527299632628757,0.3659680013855298,0.36665500452121097,0.3673360000054042,0.36800899853308994,0.36867599685986835,0.36933399985233945,0.3699849992990494,0.37062900016705197,0.3712659974892934,0.37189500282208127,0.37251700460910797,0.37313100198904675,0.37373799830675125,0.37433799852927524,0.3749299968282382,0.3755149965484937,0.376092995206515,0.37666300187508267,0.3772260049978892,0.3777820020914078,0.3783299997448921,0.37887099385261536,0.3794039984544118,0.37993000199397403,0.3804489995042483,0.38096100091934204,0.38146500289440155,0.38196199884017307,0.38245200365781784,0.38293499996264774,0.3834099993109703,0.38387800256411236,0.38433899730443954,0.38479300091664,0.38523900508880615,0.3856780007481575,0.38611000031232834,0.38653400043646496,0.3869510019818942,0.38736099749803543,0.38776300102472305,0.3881579985221227,0.3885470007856687,0.38892700026432675,0.3893000011642774,0.38966599851846695,0.3900249972939491,0.3903760015964508,0.3907209982474645,0.3910579979419708,0.3913870006799698,0.3917100007335345,0.3920259972413381,0.3923339992761612,0.3926349977652232,0.3929289976755778,0.3932160014907519,0.39349500089883804,0.39376699676116306,0.39403200149536133,0.3942900026837985,0.3945399969816208,0.39478300015131634,0.3950190047423045,0.3952480008204778,0.39546899994214374,0.3956829955180486,0.3958899999658267,0.39609000086784363,0.39628300070762634,0.39646799862384796,0.39664600044488907,0.3968170036872228,0.39698100090026855,0.39713700364033383,0.39728599786758423,0.39742899934450787,0.39756400138139725,0.3976919973889987,0.39781299978494644,0.39792700111866,0.3980330030123393,0.3981330022215843,0.39822500199079514,0.39831000318129856,0.3983880008260409,0.39845800399780273,0.3985220020016034,0.3985779931147893,0.39862699806690216,0.39866900195678073,0.39870400230089825,0.3987309957544009,0.39875200142463046,0.39876500020424527,0.3987710004051526,0.39877000202735263,0.39876200010379154,0.3987469996015231,0.3987239971756935,0.3986949995160103,0.39865799993276596,0.39861400177081424,0.3985630050301552,0.39850499977668125,0.39844100425640744,0.3983689993619919,0.3982890024781227,0.39820299794276554,0.3981099973122279,0.3980090022087097,0.3979019994537036,0.3977870022257169,0.39766500145196915,0.3975369979937871,0.3974040001630783,0.3972719932595889,0.39713900287946063,0.3970069984594981,0.39687499900658924,0.3967419962088267,0.39660999675591785,0.3964779997865359,0.39634600033362705,0.39621400088071823,0.39608199894428253,0.39594999700784683,0.39581800003846485,0.39568600058555603,0.39555400361617404,0.39542199671268463,0.39528999229272205,0.39515799780686695,0.395026999215285,0.3948949972788493,0.3947630003094673,0.3946319967508316,0.3944999997814496,0.3943690011898677,0.3942380001147588,0.3941059981783231,0.39397499958674115,0.39384300510088605,0.39371200402577716,0.39358100046714145,0.39344999690850574,0.3933190008004506,0.3931879972418149,0.3930570011337598,0.39292600005865097,0.39279500146706897,0.39266400039196014,0.39253300180037815,0.39240199824174243,0.3922709971666336,0.3921410044034322,0.39200999836126965,0.39187900225321454,0.3917489970723788,0.39161799599726993,0.3914869998892148,0.3913570021589597,0.39122699946165085,0.391095998386542,0.3909660056233406,0.390835997958978,0.3907050018509229,0.39057500163714093,0.3904450014233589,0.3903150012095769,0.39018500099579495,0.39005500078201294,0.38992500056823093,0.389795000354449,0.38966500262419385,0.3895349974433581,0.389404999713103,0.3892750044663747,0.38914599766333896,0.38901599993308383,0.3888860022028287,0.38875700036684674,0.3886270026365916,0.3884980008006096,0.38836800307035446,0.3882389987508456,0.3881089985370636,0.38797999918460846,0.3878509998321533,0.3877209971348445,0.38759200274944305,0.38746300091346103,0.38733399907747906,0.3872049997250239,0.3870760003725688,0.38694699853658676,0.3868179991841316,0.38668900231520337,0.38656000047922134,0.3864309986432393,0.3863019992907842,0.3861740007996559,0.3860450014472008,0.38591599961121875,0.3857879986365636,0.38565900176763535,0.3855299999316533,0.38540200144052505,0.3852740004658699,0.3851449986298879,0.3850170001387596,0.38488800326983136,0.38475999732812244,0.38463199883699417,0.38450399537881214,0.384375994404157,0.3842470000187556,0.38411899904410046,0.38399100055297214,0.383862999578317,0.3837360019485156,0.3836079960068067,0.3834800024827321,0.38335199902455014,0.383223998049895,0.38309600204229355,0.3829689994454384,0.38284099847078323,0.38271399835745495,0.3825859948992729,0.38245900720357895,0.3823310012618701,0.38220400114854175,0.38207599769035977,0.3819490025440852,0.38182199994723004,0.3816940014561017,0.38156700630982715,0.3814399987459183,0.3813129961490631,0.38118600100278854,0.381059005856514,0.38093200077613193,0.38080499817927677,0.3806779980659485,0.3805509979526202,0.38042400280634564,0.3802969977259636,0.380171000957489,0.38004400084416073,0.37991700569788617,0.379791001478831,0.37966400136550266,0.37953800211350125,0.3794110069672267,0.37928499778111774,0.37915800015131634,0.3790320008993149,0.3789059991637866,0.37877899905045825,0.37865299979845685,0.3785270005464554,0.3784010037779808,0.37827499707539874,0.37814799944559735,0.3780220001935959,0.3778959984580676,0.37776999920606613,0.37764499833186466,0.37751899907986325,0.3773929998278618,0.3772669980923335,0.37714099884033203,0.37701600044965744,0.376890001197656,0.3767639994621277,0.3766389985879262,0.3765129968523979,0.3763880009452502,0.37626199672619504,0.37613699833552044,0.37601199994484585,0.3758859982093175,0.3757610023021698,0.3756360014279683,0.37551099807024,0.37538599967956543,0.37526000042756397,0.37513499955336255,0.3750100036462148,0.3748850002884865,0.374759999414285,0.3746349985400836,0.3745110010107358,0.3743860001365344,0.37426100422938663,0.37413599838813144,0.3740120008587837,0.3738869975010554,0.3737619991103808,0.3736379990975062,0.37351300567388535,0.37338900069395703,0.37326400230328244,0.37314000229040784,0.37301599979400635,0.3728909989198049,0.37276699642340344,0.37264300137758255,0.37251899888118106,0.37239399800697964,0.37227000047763187,0.37214600046475727,0.37202199796835583,0.37189800043900806,0.37177400042613346,0.371649997929732,0.37152599543333054,0.37140299876530963,0.3712789962689082,0.3711550012230873,0.3710310012102127,0.3709079970916112,0.3707840020457904,0.37066100041071576,0.370537002881368,0.37041400372982025,0.37029000123341876,0.3701669971148173,0.37004299958546955,0.3699200004339218,0.3697969987988472,0.3696730012694995,0.3695500021179517,0.36942699551582336,0.36930399884780246,0.36918099721272785,0.369058000544707,0.3689349889755249,0.3688120022416115,0.36868900309006375,0.36856599648793537,0.3684429998199145,0.3683209990461667,0.3681979974110921,0.3680749982595444,0.36795199910799664,0.36782999833424884,0.3677069991827011,0.3675850008924802,0.36746200174093246,0.36733999600013095,0.3672169993321101,0.3670949985583623,0.3669719994068146,0.36684999863306683,0.3667280028263728,0.3666059995690982,0.3664839987953504,0.36636099716027576,0.36623900135358173,0.366117000579834,0.36599499980608624,0.3659340019027392};
    
    //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09223562168578307,0.09350950084626675,0.09473040016988914,0.09607270049552123,0.09741259987155597,0.09874930108586948,0.10008400057752927,0.10141600047548611,0.1027469988912344,0.1040769995500644,0.10540600058933099,0.10673399952550729,0.10806100070476532,0.10938699978093307,0.11071100023885568,0.1120350006967783,0.11335700005292892,0.11467500030994415,0.11598499988516171,0.11728699939946334,0.11858100009461243,0.1198679997275273,0.12114700116217136,0.12241800005237262,0.12368099888165791,0.12493600075443585,0.1261840003232161,0.1274220012128353,0.12865300104022026,0.1298740009466807,0.13108500093221664,0.1322889986137549,0.13348299885789552,0.13466699918111166,0.13584300006429353,0.1370089997847875,0.1381670000652472,0.1393079993625482,0.14042500158150992,0.14151799802978834,0.14258699988325438,0.14363099883000055,0.1446520003179709,0.14564799765745798,0.14661999916036925,0.1475679986178875,0.14849199851353964,0.14939599856734276,0.15028199926018715,0.15115100145339966,0.15200400104125342,0.1528399996459484,0.1536599981288115,0.1544630005955696,0.1552479974925518,0.1560169979929924,0.15676899875203767,0.15749700119098028,0.15819400052229562,0.15886100009083748,0.15949800238013268,0.16010500118136406,0.1606800009806951,0.16122599815328917,0.16173999880750975,0.16222399969895682,0.16267799958586693,0.16311400135358176,0.16354500129818916,0.16396999980012575,0.16438900058468184,0.16480100030700365,0.1652079994479815,0.16560899962981543,0.16600499923030534,0.16639499987165132,0.16678000117341676,0.1671600006520748,0.16753799840807915,0.16791299730539322,0.16828499982754389,0.16865399852395058,0.1690200020869573,0.1693830005824566,0.16974399983882904,0.1701019989947478,0.17045800015330315,0.17081199834744135,0.17116199806332588,0.17151000102361044,0.17185500139991441,0.1721970004340013,0.1725360006093979,0.1728730003039042,0.17320600152015686,0.17353699977199236,0.17386500289042792,0.1741899996995926,0.17451199889183044,0.17483200008670488,0.17514799907803535,0.17546200255552927,0.1757729984819889,0.17608099927504858,0.1763870008289814,0.1766889989376068,0.17698900029063225,0.17728600154320398,0.17758000021179518,0.17787099877993265,0.17815999935070673,0.17844499895970026,0.17872699971000353,0.17900599911808968,0.17928200090924898,0.17955500135819116,0.1798249992231528,0.18009199822942415,0.18035699799656868,0.1806190013885498,0.1808779997130235,0.18113399917880693,0.18138800064722696,0.18163799991210303,0.18188600117961565,0.18213100110491118,0.18237299968798956,0.1826129990319411,0.18284899989763895,0.18308299779891968,0.18331400180856386,0.18354199826717377,0.18376799921194711,0.18399000043670335,0.18421000242233276,0.18442700058221817,0.18464099988341331,0.18485299994548163,0.1850619986653328,0.1852670001486937,0.18547100077072778,0.1856710004309813,0.18586900333563486,0.1860629990696907,0.18625500177343687,0.18644400189320245,0.18663099904855093,0.18681499982873598,0.18699500088890395,0.1871739998459816,0.18734899908304214,0.1875210019449393,0.18769100060065588,0.18785800163944563,0.18802199885249138,0.18818399806817374,0.1883430009086927,0.1884980003039042,0.18865199759602547,0.18880200013518333,0.18895000095168749,0.18909399956464767,0.18923600018024445,0.18937399983406067,0.18950900062918663,0.18964099884033203,0.18977099905411401,0.18989799916744232,0.19002200290560722,0.1901440011958281,0.1902619997660319,0.19037800033887228,0.19049099956949553,0.1906019995609919,0.19070899859070778,0.19081399962306023,0.19091600055495897,0.19101599976420403,0.19111199925343195,0.19120600074529648,0.191296998411417,0.191386000563701,0.191471000512441,0.19155399625500044,0.19163399810592333,0.19171199947595596,0.19178599988420805,0.19185800105333328,0.19192699963847795,0.19199400146802267,0.19205699985225996,0.19211800023913383,0.19217700138688087,0.1922319990893205,0.19228500003616014,0.19233499964078268,0.19238200411200523,0.1924270006517569,0.19246900205810866,0.1925080008804798,0.1925439996023973,0.19257800032695135,0.19260800008972487,0.1926369989911715,0.19266199817260107,0.1926850030819575,0.19270500044027963,0.19272199893991152,0.19273700068394342,0.19274800022443137,0.19275800014535585,0.19276300072669983,0.1927659995853901,0.19276499996582666,0.19276199986537298,0.19275599966446558,0.19274800022443137,0.19273599733908972,0.19272200018167496,0.1927060013016065,0.19268599897623062,0.1926640011370182,0.19263900195558867,0.19261199980974197,0.19258199880520502,0.19254900018374124,0.1925130014618238,0.19247499853372574,0.19243400047222772,0.19238999982674918,0.19234300032258034,0.1922939990957578,0.192241999010245,0.19218799968560538,0.19213100026051202,0.192071000734965,0.1920079986254374,0.19194399937987328,0.19188000137607256,0.19181599964698157,0.1917520004014174,0.19168799867232642,0.1916240006685257,0.19156099980076155,0.1914970005551974,0.1914329988261064,0.19136899958054224,0.1913050003349781,0.19124199946721396,0.1911780002216498,0.19111400097608566,0.1910500004887581,0.19098699962099394,0.19092299913366637,0.19085900112986565,0.1907960002621015,0.19073200101653734,0.1906690001487732,0.19060499841968218,0.19054199879368147,0.1904779995481173,0.1904149999221166,0.19035100067655245,0.19028799856702486,0.19022400180498758,0.19016100217898688,0.19009700044989586,0.1900339995821317,0.18997100119789442,0.18990699822703996,0.18984399860103926,0.18978100021680197,0.1897179993490378,0.1896540013452371,0.18959100047747293,0.18952799960970879,0.18946500246723494,0.18940200159947077,0.18933899700641632,0.1892760011057059,0.1892119993766149,0.18914899850885072,0.18908600136637688,0.1890230029821396,0.18895999963084856,0.18889700000484785,0.18883399789532027,0.18877099951108298,0.1887089970211188,0.18864599987864494,0.18858299776911736,0.18852000186840692,0.18845699727535248,0.18839400013287863,0.1883319988846779,0.18826900298396745,0.1882060021162033,0.18814300000667572,0.18808100000023842,0.1880180003742377,0.18795500074823698,0.18789299950003624,0.1878299998740355,0.18776699900627136,0.1877050002415975,0.18764200061559677,0.18757999936739603,0.18751699849963188,0.18745500097672144,0.1873920001089573,0.18733000134428343,0.1872670017182827,0.18720500047008196,0.18714299922188124,0.18707999835411707,0.18701799834767976,0.18695499747991562,0.18689299995700517,0.18683099995056787,0.18676900242765745,0.18670600031812987,0.18664400031169256,0.18658200278878212,0.18652000029881796,0.18645800029238066,0.18639500066637993,0.18633300065994263,0.18627099941174188,0.18620900188883147,0.18614700064063072,0.18608499939242998,0.18602300062775612,0.18596100062131882,0.18589900061488152,0.1858370006084442,0.1857750006020069,0.18571300183733305,0.18565099934736887,0.18558899934093157,0.18552800143758455,0.1854659989476204,0.18540400018294653,0.18534200141827264,0.18528000017007193,0.18521899978319803,0.18515699977676073,0.18509500349561372,0.1850339981416861,0.1849719981352488,0.18490999937057495,0.18484900146722794,0.1847870002190272,0.1847250002125899,0.18466399858395258,0.18460199857751527,0.18454099943240485,0.18447899942596754,0.18441799903909364,0.18435599903265634,0.18429500112930933,0.1842329998811086,0.18417200073599815,0.18411100034912428,0.18404900034268698,0.18398799871404967,0.18392699832717577,0.18386500080426535,0.18380400041739145,0.18374300003051758,0.1836819996436437,0.18361999839544296,0.1835590017338594,0.18349799886345863,0.18343699847658476,0.1833759993314743,0.1833150014281273,0.18325300017992655,0.18319200103481612,0.1831309994061788,0.18307000026106834,0.18300899987419447,0.18294799948732057,0.18288699785868326,0.18282600119709969,0.18276499832669893,0.1827050012846788,0.18264400213956833,0.18258299926916757,0.18252199639876684,0.18246099849541983,0.18239999935030937,0.1823400010665258,0.18227899943788847,0.18221799905101457,0.18215700114766756,0.18209700162212053,0.18203600123524666,0.1819750020901362,0.18191499759753546,0.181853998452425,0.18179299930731455,0.18173300102353096,0.18167199939489365,0.18161200359463692,0.18155099948247275,0.18149099871516228,0.18142999957005182,0.1813700000445048,0.18130899965763092,0.18124899889032045,0.18118799974521002,0.1811280014614264,0.18106799945235252,0.18100700030724207,0.18094699953993162,0.1808870000143846,0.18082600086927414,0.18076599886020026,0.18070599933465323,0.18064599856734276,0.1805849994222323,0.18052499989668527,0.18046499912937483,0.18040500084559122,0.18034499883651733,0.18028499806920686,0.18022499978542328,0.1801649977763494,0.18010399863123894,0.18004400034745535,0.17998399958014488,0.1799239988128344,0.17986399804552397,0.17980499813954035,0.17974499985575676,0.1796849990884463,0.1796250008046627,0.17956500003735223,0.1795049992700418,0.17944499974449477,0.17938500021894774,0.1793259990712007,0.17926600202918053,0.1792059987783432,0.17914600173632303,0.1790869968632857,0.17902699733773866,0.17896699905395508,0.1789080003897349,0.17884799962242445,0.17878899971644083,0.17872900143265724,0.17866900066534677,0.17861000324289003,0.17855000123381615,0.17849099884430566,0.17843100056052208,0.17837200065453848,0.178311999887228,0.17825299998124441,0.17819399883349737,0.1781340017914772,0.17807499940196672,0.1780149998764197,0.1779559999704361,0.1778970000644525,0.17783800140023232,0.17777800063292185,0.1777189982434114,0.1776599995791912,0.17760100091497102,0.177541001389424,0.1774820014834404,0.17742300033569336,0.17736400042970976,0.17730500052372614,0.1772459993759791,0.1771869994699955,0.17712800080577532,0.17706900214155516,0.17701000099380812,0.17695099860429764,0.17689199869831404,0.17683299879233041,0.17677399888634682,0.1767439991235733};
    
    CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.83418210347493,82.68911806742351,83.13781229654948,83.86931228637695,84.59961191813152,85.32871309916179,86.05651219685872,86.78351147969563,87.51021194458008,88.2365125020345,88.96251169840495,89.68801180521648,90.41321182250977,91.13811302185059,91.86261240641277,92.58671188354492,93.31051254272461,94.03201293945312,94.74971199035645,95.46341196695964,96.17311159769694,96.87881151835124,97.58061281840007,98.27851104736328,98.972412109375,99.6623109181722,100.34800974527995,101.03001149495442,101.70701090494792,102.37901178995769,103.04701105753581,103.71001116434734,104.36901028951009,105.023011525472,105.67201169331868,106.31601142883301,106.95601018269856,107.58801015218098,108.2060095469157,108.81201108296712,109.40501022338867,109.9860102335612,110.55400975545247,111.10900942484538,111.65100860595703,112.18100865681966,112.69800885518391,113.2050069173177,113.70200729370117,114.19100761413574,114.67000897725423,115.1410083770752,115.60300763448079,116.05600802103679,116.50100708007812,116.93600718180339,117.36300722757976,117.77700678507487,118.17500559488933,118.55700556437175,118.92300605773926,119.27200571695964,119.60600471496582,119.92300478617351,120.22400601704915,120.50900522867839,120.77700424194336,121.03600374857585,121.29300435384114,121.54600397745769,121.7960033416748,122.04300435384114,122.2870044708252,122.5290044148763,122.76700401306152,123.0020039876302,123.23500315348308,123.4650026957194,123.69300333658855,123.92100397745769,124.14700444539388,124.37100410461426,124.59400304158528,124.81600379943848,125.03600311279297,125.25500297546387,125.47300465901692,125.6890042622884,125.90400250752766,126.11700375874837,126.32900365193684,126.5390027364095,126.74800300598145,126.95500373840332,127.16100247701009,127.36500358581543,127.56800333658855,127.77000300089519,127.97000249226888,128.1680030822754,128.3650042215983,128.5610033671061,128.75500361124674,128.94800440470377,129.1390012105306,129.32800165812174,129.5170046488444,129.70400365193686,129.8890012105306,130.07300440470377,130.255002339681,130.43600209554037,130.61599985758463,130.79300435384116,130.9700024922689,131.14500172932944,131.31900278727213,131.49100494384766,131.6610018412272,131.83100382486978,131.99800237019858,132.1650021870931,132.3300018310547,132.49300384521484,132.65500259399414,132.81500498453775,132.97400283813477,133.13200251261392,133.28800201416016,133.4420026143392,133.59500376383463,133.74700164794922,133.8970044453939,134.04600143432617,134.19300079345703,134.33900451660156,134.48300170898438,134.62600072224936,134.7670021057129,134.9070027669271,135.04500198364258,135.18200302124023,135.3180020650228,135.4520034790039,135.58399963378906,135.71600087483725,135.84499994913736,135.9730021158854,136.10000228881836,136.22500483194986,136.34900029500326,136.47100067138672,136.59200286865234,136.71200307210287,136.8300018310547,136.94600041707358,137.0610033671061,137.17400105794272,137.28700256347656,137.39700317382812,137.50600051879883,137.61400095621744,137.72000376383463,137.82500076293945,137.92800013224283,138.03000132242838,138.130002339681,138.22900263468424,138.3270034790039,138.42200088500977,138.5170021057129,138.61000315348306,138.70200220743814,138.7920010884603,138.87999979654947,138.96700159708658,139.0529988606771,139.13700103759766,139.2200024922689,139.3009999593099,139.3810017903646,139.46000162760416,139.53700002034506,139.61200205485025,139.68600209554037,139.75900395711264,139.83000055948892,139.89900080362955,139.96700286865234,140.03400039672852,140.099001566569,140.16299947102866,140.22499974568686,140.2860018412272,140.3450024922689,140.40300114949545,140.46000289916992,140.5150006612142,140.56799952189127,140.62000020345053,140.67100143432617,140.72000376383463,140.7669995625814,140.8140017191569,140.8580004374186,140.9020004272461,140.94300079345703,140.9839998881022,141.02300008138022,141.06000010172525,141.09600067138672,141.13000106811523,141.16300201416016,141.19499969482422,141.2250010172526,141.25400161743164,141.28100204467773,141.3059984842936,141.33100001017252,141.35300064086914,141.37500127156576,141.39500045776367,141.41299947102866,141.42999903361002,141.44500096638998,141.45900090535483,141.47199885050455,141.4829978942871,141.49200185139975,141.5009994506836,141.50699869791666,141.51199849446616,141.51599884033203,141.51900100708008,141.5189997355143,141.51900100708008,141.51700083414713,141.5140012105306,141.51099904378256,141.50800069173178,141.50500106811523,141.5019989013672,141.49999872843424,141.49699910481772,141.49400075276694,141.4910011291504,141.4880002339681,141.48600133260092,141.48299916585287,141.4800008138021,141.4770024617513,141.473996480306,141.47100067138672,141.46900049845377,141.46600087483725,141.4630012512207,141.46000035603842,141.45699818929037,141.45400110880533,141.4520009358724,141.44899876912436,141.4460016886393,141.4430020650228,141.44000116984049,141.43699900309244,141.43500137329102,141.4319979349772,141.42899958292642,141.4259999593099,141.42299779256186,141.4200007120768,141.41799926757812,141.41500091552734,141.41199747721353,141.40900039672852,141.40600077311197,141.4029998779297,141.4010009765625,141.39800135294595,141.39500045776367,141.3920021057129,141.3890012105306,141.3860003153483,141.38400268554688,141.38099924723306,141.37799962361655,141.3750025431315,141.37199910481772,141.37000020345053,141.36699803670248,141.3639996846517,141.36100006103516,141.3580004374186,141.3550008138021,141.35300064086914,141.3500010172526,141.34699885050455,141.34399922688803,141.34099960327148,141.3380012512207,141.33599980672201,141.3329989115397,141.33000055948892,141.32699966430664,141.32400131225586,141.3209991455078,141.31900024414062,141.31599934895834,141.31300099690756,141.31000010172525,141.30700174967447,141.30499903361002,141.30200322469076,141.29899978637695,141.2959976196289,141.29299926757812,141.29000091552734,141.2879981994629,141.28500111897787,141.28200022379556,141.27900060017905,141.27600224812826,141.27300135294595,141.2709986368815,141.26799901326498,141.26499938964844,141.26199849446616,141.25900014241537,141.25600051879883,141.25400034586588,141.2509994506836,141.24799982706705,141.24500020345053,141.24199803670248,141.2400016784668,141.23700078328451,141.23399861653647,141.23099899291992,141.22799809773764,141.22499974568686,141.22300084431967,141.21999867757162,141.21699905395508,141.2140007019043,141.21099980672201,141.2079989115397,141.20600001017252,141.20299784342447,141.20000076293945,141.1970011393229,141.19400024414062,141.19200134277344,141.1889991760254,141.18599955240884,141.1830037434896,141.18000030517578,141.1769994099935,141.17499796549478,141.171999613444,141.16899871826172,141.1660016377767,141.1630007425944,141.15999857584634,141.15799967447916,141.15499877929688,141.15200169881186,141.1489995320638,141.14600118001303,141.14400100708008,141.1410001118978,141.13799921671549,141.1349983215332,141.1320012410482,141.12900161743164,141.12700017293295,141.12399927775064,141.12100092569986,141.1179987589518,141.11499659220377,141.11199824015299,141.1099993387858,141.10699971516928,141.10400009155273,141.1010004679362,141.09799830118814,141.09599939982095,141.09299977620444,141.09000142415366,141.08700052897134,141.08399963378906,141.08100001017252,141.0789998372396,141.07599894205728,141.07299931844076,141.06999969482422,141.06699879964194,141.06499989827475,141.06199900309244,141.05899937947592,141.05600102742514,141.05300013224283,141.04999923706055,141.04800033569336,141.04499944051108,141.04199854532877,141.03900019327799,141.0359992980957,141.03299713134766,141.03100204467773,141.0279998779297,141.0249989827474,141.02199935913086,141.01900227864584,141.0169995625814,141.01399866739908,141.01100285847983,141.00800069173178,141.00499979654947,141.0020014444987,141.00000127156576,140.99699910481772,140.99400202433267,140.9909985860189,140.9880002339681,140.98600006103516,140.9830004374186,140.97999954223633,140.97699991861978,140.9739990234375,140.97099939982095,140.96900177001953,140.96599960327148,140.96299997965494,140.96000162760416,140.95699818929037,140.95500055948892,140.95199966430664,140.94900131225586,140.9459991455078,140.9430020650228,140.94000116984049,140.93799845377603,140.93499755859375,140.93200047810873,140.9289983113607,140.92600123087564,140.92300160725912,140.92099889119467,140.91799926757812,140.91499964396158,140.91199747721353,140.90899912516275,140.90699895222983,140.90400060017905,140.9010009765625,140.89799880981445,140.89500045776367,140.89299774169922,140.8900006612142,140.88699849446616,140.8839988708496,140.88099924723306,140.87800089518228,140.87600072224936,140.87299982706705,140.87000020345053,140.86700057983398,140.86400095621744,140.86199951171875,140.85900115966797,140.8560002644857,140.85300064086914,140.8499984741211,140.84699885050455,140.84500122070312,140.84199905395508,140.8390007019043,140.83600107828775,140.83300018310547,140.83100001017252,140.82800165812174,140.82500076293945,140.82199986775717,140.81899770100912,140.81599934895834,140.81500371297201};
    //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3764710525671642,1.4131700098514557,1.4504399995009105,1.4875800013542175,1.5246599912643433,1.5616600116093953,1.5985900064309437,1.6354599992434184,1.6723100046316783,1.7091299990812938,1.7459200024604797,1.7826800048351288,1.8194100161393483,1.8561000029246013,1.8927700122197468,1.9294100006421406,1.9660200079282124,2.002510001262029,2.0387800335884094,2.074840029080709,2.1106899976730347,2.1463199853897095,2.1817400256792703,2.216949999332428,2.2519400119781494,2.2867299914360046,2.3213000098864236,2.3556399941444397,2.3897300163904824,2.4235800306002298,2.4571800231933594,2.490529994169871,2.5236300230026245,2.5564800103505454,2.589079976081848,2.621439973513285,2.6535399556159973,2.685200015703837,2.7161900202433267,2.746530036131541,2.776209990183512,2.8052300016085305,2.8335899710655212,2.861289997895559,2.888330042362213,2.9147199789683023,2.940440018971761,2.9655999739964805,2.9902999997138977,3.0145399967829385,3.038320004940033,3.0616400043169656,3.084499994913737,3.1069000164667764,3.128839989503225,3.150319993495941,3.171329994996389,3.191699981689453,3.211239993572235,3.2299399773279824,3.2478100260098777,3.264840006828308,3.281049986680349,3.2964100440343223,3.310950001080831,3.3246500492095947,3.3375099698702493,3.3498899936676025,3.3620999852816262,3.3741700053215027,3.386069973309835,3.397819976011912,3.409410019715627,3.42084002494812,3.4321099718411765,3.4432299931844077,3.4541899959246316,3.4650399883588157,3.475819985071818,3.486509998639425,3.4971399903297424,3.507689952850342,3.5181599656740823,3.5285600225130715,3.53889000415802,3.54913999636968,3.559320032596588,3.5694199999173484,3.5794400175412497,3.58938999970754,3.5992600123087564,3.60904997587204,3.6187599698702493,3.628399968147278,3.6379599968592324,3.6474300225575766,3.6568300326665244,3.6661499540011087,3.6753899653752646,3.684560000896454,3.693649967511495,3.7026599844296775,3.7116000254948935,3.7204500238100686,3.7292300264040628,3.7379199862480164,3.7465400099754333,3.755089978377024,3.7635599772135415,3.7719500064849854,3.7802599668502808,3.7884899973869324,3.7966400186220803,3.8047199646631875,3.8127200404802957,3.820649961630503,3.8284899989763894,3.83625998099645,3.843950013319651,3.8515700499216714,3.859100023905436,3.8665499885876975,3.8739299972852073,3.881239970525106,3.8884699940681458,3.8956200083096824,3.902689973513285,3.909689982732137,3.9166000286738076,3.9234399795532227,3.930200000603994,3.936889966328939,3.94350000222524,3.950029989083608,3.9564899802207947,3.9628599882125854,3.96915998061498,3.975380003452301,3.981530010700226,3.987600028514862,3.993600010871887,3.9995099902153015,4.0053499937057495,4.011109987894694,4.016799966494243,4.02240006128947,4.027929981549581,4.033390045166016,4.038769880930583,4.04406996568044,4.049300034840901,4.054440021514893,4.059509992599487,4.064509908358256,4.069419980049133,4.074270009994507,4.079040010770162,4.083730022112529,4.0883400440216064,4.092870036760966,4.0973299741744995,4.101710081100464,4.106009999910991,4.110249996185303,4.114399989446004,4.11848000685374,4.122480034828186,4.1264099677403765,4.1302500168482466,4.134029944737752,4.137730002403259,4.141349991162618,4.14490004380544,4.148360053698222,4.15175998210907,4.155070026715596,4.158309976259868,4.161470015843709,4.164559960365295,4.167580008506775,4.170510013898213,4.173369963963826,4.176159977912903,4.178860028584798,4.181490023930867,4.18405004342397,4.186540007591248,4.188940008481343,4.1912699937820435,4.193530003229777,4.195700009663899,4.197800000508626,4.199829975763957,4.2017799615859985,4.203660051027934,4.205459992090861,4.2071800629297895,4.208829959233602,4.2104001839955645,4.211899956067403,4.213319977124532,4.214660008748372,4.215939998626709,4.2171400388081866,4.218260010083516,4.219299952189128,4.220269958178203,4.2211598952611284,4.221979975700378,4.2227199872334795,4.223389983177185,4.223989963531494,4.224509994188945,4.224949876467387,4.225319941838582,4.225610017776489,4.225820024808248,4.22595997651418,4.226030031840007,4.226030031840007,4.225950042406718,4.225790023803711,4.225550015767415,4.225240111351013,4.224859952926636,4.224399964014689,4.223869999249776,4.223260005315145,4.222579916318257,4.221829970677693,4.220990022023519,4.220080018043518,4.219100038210551,4.218039949735005,4.216920018196106,4.215710004170735,4.214430014292399,4.213120023409526,4.21180001894633,4.210480014483134,4.20917006333669,4.207849979400635,4.206539988517761,4.205220063527425,4.203909953435262,4.2026000420252485,4.201280037562053,4.199970006942749,4.1986600160598755,4.197349985440572,4.196039994557698,4.1947199900945025,4.1934099594752,4.1921000480651855,4.190790017445882,4.189479986826579,4.1881799300511675,4.186870018641154,4.185560027758281,4.184249997138977,4.182939887046814,4.181639949480693,4.180329958597819,4.179020047187805,4.1777199904123945,4.176409959793091,4.1751099824905396,4.173800031344096,4.172500014305115,4.171199997266133,4.1698899666468305,4.168589989344279,4.167289972305298,4.165979941685994,4.164680004119873,4.163379987080892,4.162080089251201,4.16077999273936,4.159479856491089,4.158180038134257,4.156880021095276,4.1555800040562945,4.154280026753743,4.152989983558655,4.151690045992534,4.150389989217122,4.149089972178142,4.147799968719482,4.146500031153361,4.145209948221843,4.143910050392151,4.142620126406352,4.141319950421651,4.140029986699422,4.138729929924011,4.137439926465352,4.136149962743123,4.134860038757324,4.1335599819819135,4.132269938786824,4.130979975064595,4.129690051078796,4.128400007883708,4.127110004425049,4.12582008043925,4.124529997507731,4.123240033785502,4.121959964434306,4.120670000712077,4.119380036989848,4.11808995405833,4.116810083389282,4.115520000457764,4.114230036735535,4.1129500071207685,4.111660003662109,4.110379894574483,4.109090010325114,4.107809980710347,4.1065300305684405,4.1052400668462115,4.103959997495015,4.102680047353108,4.101400017738342,4.100119988123576,4.098829944928487,4.09755003452301,4.096270004908244,4.094990015029907,4.093709985415141,4.092430035273234,4.09116001923879,4.089879989624023,4.088599920272827,4.08732008934021,4.086049993832906,4.08477000395457,4.083489974339803,4.082219998041789,4.080940047899882,4.0796700318654375,4.078390002250671,4.0771199862162275,4.075839996337891,4.0745699008305865,4.073300004005432,4.072019974390666,4.0707500378290815,4.069480021794637,4.068209966023763,4.066939830780029,4.065670013427734,4.06440003712972,4.0631299416224165,4.061860084533691,4.060589989026387,4.059319972991943,4.0580499569574995,4.056780060132344,4.05551000436147,4.054250041643779,4.052980025609334,4.05171004931132,4.050450046857198,4.049180030822754,4.047920028368632,4.0466500123341875,4.045390049616496,4.044120033582051,4.0428599913914995,4.041600028673808,4.040339986483256,4.039069930712382,4.037810047467549,4.036550005276998,4.035290042559306,4.034030000368754,4.032769997914632,4.03150999546051,4.030250032742818,4.028990030288696,4.0277299880981445,4.026469985644023,4.0252099831899,4.023949980735779,4.0226999918619795,4.021439989407857,4.020179986953735,4.018929958343506,4.0176699956258135,4.016420046488444,4.015159924825032,4.013910015424092,4.012649973233541,4.011399984359741,4.010149995485942,4.008889993031819,4.007639924685161,4.006390015284221,4.005139946937561,4.003880023956299,4.002629995346069,4.00137996673584,4.0001299778620405,3.9988799889882407,3.997630019982656,3.9963799913724265,3.995139996210734,3.9938900073369346,3.9926400184631348,3.9913900097211203,3.990150034427643,3.9888999859491983,3.9876500566800437,3.9864099820454917,3.985159993171692,3.9839199980099997,3.982669949531555,3.9814299742380777,3.9801799654960632,3.9789399902025857,3.9777000149091086,3.9764500061670938,3.9752099911371865,3.9739699363708496,3.9727300008138022,3.971489985783895,3.970240036646525,3.969000001748403,3.967759986718496,3.9665200114250183,3.965279976526896,3.964049994945526,3.962809999783834,3.9615700244903564,3.960330009460449,3.9590900341669717,3.957860012849172,3.956619997819265,3.9553799827893577,3.9541500210762024,3.95290998617808,3.951679984728495,3.950439989566803,3.949210007985433,3.9479700326919556,3.946739971637726,3.945509970188141,3.9442699948946633,3.9430399735768638,3.941810051600138,3.9405799905459085,3.9393499890963235,3.9381199876467385,3.936889966328939,3.9356600046157837,3.9344300031661987,3.9332000017166138,3.931970000267029,3.930739998817444,3.929509977499644,3.9282800356547036,3.9270600080490112,3.925829986731211,3.9245999852816262,3.9233799974123635,3.9221500158309937,3.920930008093516,3.919699966907501,3.9184800187746682,3.9172499974568686,3.916030009587606,3.914800008138021,3.913579980532328,3.9123600125312805,3.9111300110816956,3.909909983476003,3.9086899956067405,3.9074699878692627,3.90625,3.9050299922625222,3.9038100043932595,3.902590036392212,3.9013699889183044,3.9001500010490417,3.8995400269826255};
    
    SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.56845219930013,8.884455760320028,9.181387027104696,9.506616592407227,9.832676728566488,10.159606695175171,10.487306435902914,10.805805842081705,11.10480546951294,11.384405295054117,11.644604603449503,11.885404268900553,12.106803814570108,12.308803717295328,12.491403023401896,12.654602686564127,12.798402388890585,12.931802670160929,13.063602606455484,13.193902571996054,13.32260251045227,13.44980263710022,13.575502316157023,13.699602444966635,13.822102387746176,13.94320241610209,14.062602281570435,14.180202404657999,14.2957022190094,14.408902088801065,14.5199023882548,14.628802061080933,14.735502084096273,14.840001980463663,14.942301988601685,15.042401949564615,15.140401840209961,15.236601909001669,15.3317019144694,15.42540184656779,15.518001794815063,15.609301884969076,15.699301799138388,15.788201808929443,15.8758016427358,15.962101697921753,16.04720179239909,16.130901495615642,16.212801774342854,16.292901515960693,16.371301651000977,16.448001543680828,16.5229016939799,16.596101601918537,16.667601267496746,16.737301190694172,16.805201371510822,16.871301492055256,16.935301303863525,16.99730094273885,17.05720106760661,17.115001042683918,17.17080084482829,17.22450129191081,17.276201089223225,17.32580105463664,17.373301029205322,17.41900110244751,17.46310059229533,17.50550079345703,17.546300888061523,17.585501035054524,17.623000621795654,17.65890073776245,17.693100770314533,17.72570053736369,17.75670051574707,17.78670088450114,17.816300710042317,17.845600605010986,17.87450059254964,17.90310064951579,17.93130048116048,17.959200541178387,17.986700534820557,18.01390027999878,18.04070059458415,18.067200501759846,18.09350045522054,18.119600613911945,18.145500500996906,18.17110013961792,18.196500460306805,18.22170066833496,18.246700445810955,18.271400292714436,18.295900185902912,18.3202002843221,18.344300587972004,18.36810048421224,18.391700585683186,18.415200233459473,18.438300609588623,18.461300373077393,18.484000364939373,18.506500562032063,18.52880032857259,18.55090030034383,18.57270050048828,18.59440024693807,18.615800380706787,18.637000401814777,18.65790017445882,18.67870060602824,18.699200471242268,18.719500223795574,18.739500522613525,18.759400685628254,18.779000123341877,18.79840024312337,18.81760040918986,18.836600303649902,18.855300426483154,18.873900254567463,18.892200152079266,18.910300254821777,18.928100109100342,18.945800304412842,18.96320041020711,18.98040024439494,18.997400442759197,19.014100392659504,19.030700365702312,19.047000408172607,19.063100337982178,19.07900047302246,19.094600518544514,19.110100428263348,19.125300407409668,19.140300114949543,19.15510018666585,19.16960032780965,19.18400017420451,19.198100407918293,19.212000528971355,19.22570006052653,19.239100297292072,19.252400398254395,19.265399932861328,19.278200149536133,19.29080041249593,19.303100268046062,19.31530014673869,19.327200094858807,19.338900407155354,19.35040028889974,19.361700375874836,19.372700373331707,19.383599917093914,19.394200483957928,19.404600143432617,19.41480016708374,19.424700101216633,19.434500058492024,19.444000085194904,19.453300317128498,19.46240011850993,19.47130012512207,19.4799002011617,19.488300164540608,19.49660015106201,19.504600048065186,19.51229985555013,19.51990016301473,19.527199904123943,19.53440014521281,19.541300296783447,19.54800017674764,19.554500261942547,19.560700098673504,19.566800435384113,19.572600205739338,19.578200181325276,19.58360004425049,19.58880027135213,19.59369993209839,19.5985000928243,19.603000164031982,19.607300122578938,19.61139980951945,19.615300337473553,19.618899822235107,19.622400124867756,19.625600179036457,19.628600120544434,19.631400267283123,19.633999983469646,19.63629976908366,19.638500054677326,19.640399932861328,19.642100016276043,19.64359982808431,19.64490000406901,19.645999749501545,19.64680004119873,19.647499879201252,19.647899786631267,19.648100058237713,19.648099899291992,19.647900104522705,19.64739974339803,19.646800359090168,19.64590009053548,19.644800027211506,19.643500010172527,19.642000198364258,19.640299797058105,19.638399918874104,19.636200110117596,19.63380002975464,19.63129981358846,19.62849982579549,19.625400225321453,19.622199694315594,19.618799845377605,19.615099906921387,19.611200014750164,19.607199827829998,19.60290002822876,19.59839979807536,19.593600114186604,19.58869981765747,19.583499908447266,19.578199863433838,19.57259972890218,19.566799958546955,19.560800234476726,19.554699738820393,19.54859987894694,19.542500019073486,19.53640015920003,19.530200004577637,19.524099508921307,19.51799996693929,19.51189947128296,19.505900065104168,19.499799887339275,19.4936998685201,19.48760000864665,19.481499671936035,19.47539981206258,19.469299793243408,19.463199933369953,19.457100073496502,19.45109987258911,19.44499969482422,19.438899834950764,19.432799975077312,19.426799933115642,19.420699914296467,19.414599895477295,19.408599694569904,19.40249999364217,19.39640013376872,19.39040009180705,19.384299914042156,19.378300031026203,19.372199694315594,19.36619997024536,19.36009995142619,19.354100068410236,19.347999890645344,19.341999848683674,19.335899988810223,19.32989962895711,19.323800086975098,19.317799886067707,19.311799844106037,19.305699984232586,19.299699783325195,19.293699741363525,19.287599722544353,19.2815998395284,19.27559979756673,19.26959991455078,19.26349989573161,19.257500012715656,19.25149981180827,19.2454997698466,19.23949956893921,19.233499844868977,19.227500120798748,19.221499760945637,19.215399742126465,19.209399859110516,19.203400293986004,19.197399934132893,19.191399733225506,19.185400009155273,19.179500102996826,19.173500219980877,19.167499860127766,19.161500136057537,19.155499935150146,19.149499893188477,19.143500010172527,19.137499809265137,19.13159990310669,19.125600179036457,19.119600137074787,19.11359977722168,19.107699712117512,19.101699829101562,19.09570010503133,19.089799880981445,19.083799680074055,19.077800114949543,19.071899890899658,19.06590000788371,19.05999994277954,19.05399990081787,19.0479998588562,19.042099952697754,19.036099910736084,19.030200004577637,19.024299780527752,19.018299738566082,19.012399673461914,19.006400108337402,19.000500202178955,18.994499842325848,18.98859961827596,18.982699871063232,18.976699829101562,18.970799763997395,18.964900016784668,18.958999792734783,18.952999750773113,18.947099844614666,18.941200256347656,18.93530035018921,18.929399967193604,18.923499902089436,18.917500019073486,18.9115997950236,18.905699888865154,18.899799982706707,18.89390007654826,18.88799985249837,18.882099787394207,18.876200199127197,18.870299975077312,18.864399909973145,18.85849968592326,18.85260025660197,18.846699873606365,18.840799808502197,18.835000038146973,18.829099496205647,18.823200225830078,18.817299842834473,18.811399618784588,18.805599689483643,18.799700101216633,18.793799718221027,18.78789981206258,18.78209988276164,18.776199499766033,18.77030022939046,18.76449998219808,18.758599917093914,18.752700169881184,18.7468999226888,18.741000016530354,18.73519992828369,18.729300181070965,18.723499933878582,18.717599709828693,18.71179962158203,18.705899715423584,18.70009994506836,18.694199721018474,18.68839995066325,18.682499885559082,18.67669979731242,18.670899709065754,18.665000120798748,18.659199873606365,18.6533997853597,18.647499879201252,18.64169979095459,18.635899861653645,18.630099932352703,18.62429968516032,18.618399779001873,18.612599849700928,18.606799920399983,18.60099983215332,18.595199584960938,18.589399973551433,18.58360004425049,18.57769997914632,18.57189957300822,18.566099961598713,18.56029971440633,18.554499944051106,18.548700014750164,18.542899926503498,18.537199815114338,18.531399885813396,18.52559995651245,18.51979986826579,18.513999780019123,18.50819969177246,18.502399921417236,18.49659999211629,18.49089988072713,18.48509995142619,18.479299863179524,18.47349977493286,18.46779998143514,18.46199957529704,18.456199645996094,18.450500011444092,18.444700082143147,18.438900152842205,18.433199723561604,18.427399794260662,18.42170000076294,18.415900071461994,18.410099983215332,18.404400030771892,18.398600260416668,18.392899990081787,18.387099901835125,18.381400267283123,18.375699996948242,18.36989990870158,18.364199956258137,18.358399868011475,18.352699756622314,18.346999963124592,18.34119987487793,18.335500240325928,18.329799969991047,18.324100017547607,18.318299929300945,18.312599817911785,18.306900183359783,18.301200071970623,18.295400142669678,18.289700190226238,18.283999919891357,18.278299649556477,18.272600015004475,18.266900062561035,18.261199951171875,18.255499680836994,18.249799887339275,18.244099775950115,18.238399982452393,18.232699871063232,18.22700007756551,18.221299807230633,18.21560001373291,18.20989990234375,18.20419994990031,18.19849983851115,18.19279972712199,18.187100092569988,18.18150011698405,18.17580000559489,18.17009989420573,18.16439978281657,18.158699830373127,18.15310001373291,18.14739990234375,18.14169963200887,18.13609965642293,18.130399862925213,18.12469991048177,18.119099775950115,18.113399982452393,18.107699712117512,18.102100054423016,18.099300225575764} ;
    
    //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129431982835134,2.2201091249783835,2.296726663907369,2.3786463141441345,2.4580862720807395,2.5351063013076782,2.6097862919171653,2.68225626150767,2.752676248550415,2.821086267630259,2.887556274731954,2.9521362582842507,3.014866272608439,3.0758062601089478,3.1350062489509583,3.192506273587545,3.2483562231063843,3.302256166934967,3.353896141052246,3.40335613489151,3.4506860772768655,3.4959360162417092,3.539176046848297,3.580445965131124,3.6198059717814126,3.657305916150411,3.6929958264033,3.7268558541933694,3.7588557799657187,3.7890557646751404,3.817495663960775,3.8442256649335227,3.8692956368128457,3.8927455941836038,3.914615591367086,3.9349454840024314,3.9537854194641113,3.9703752597173056,3.9839651783307395,3.994645039240519,4.002484977245331,4.007584849993388,4.009994745254517,4.009794632593791,4.007064501444499,4.001864393552144,3.994264324506124,3.9847142497698465,3.9736441572507224,3.9611041148503623,3.9471240639686584,3.93176398674647,3.9150438706080117,3.8970038096110025,3.8777037064234414,3.8571536540985107,3.8353935281435647,3.811743378639221,3.785513242085775,3.756783127784729,3.7256129384040833,3.6920828421910605,3.65625270207723,3.618192513783773,3.577942411104838,3.535592337449392,3.491192181905111,3.4461022218068442,3.401652177174886,3.3578321735064187,3.314612110455831,3.271992107232412,3.2299421032269797,3.1884620587031045,3.1475220322608948,3.1071220437685647,3.0672420064608255,3.028021991252899,2.9896119634310403,2.9519819418589273,2.9151119589805603,2.8789819280306497,2.8435819149017334,2.808881938457489,2.7748618721961975,2.7415018677711487,2.7087918519973755,2.676701843738556,2.6452118357022605,2.614311854044596,2.5839717785517373,2.5541818141937256,2.5249218146006265,2.4961917996406555,2.4679617881774902,2.440231760342916,2.4129717548688254,2.3861716985702515,2.359831710656484,2.3339317242304483,2.3084516723950705,2.2833917140960693,2.2587316632270813,2.2344716588656106,2.210581660270691,2.1870716412862143,2.163921614487966,2.1411216060320535,2.11866162220637,2.096531609694163,2.07472155491511,2.0532315572102866,2.0320415695508323,2.01114155848821,1.9905315140883129,1.9702115158240001,1.95015150308609,1.9303714831670125,1.910831481218338,1.8915514647960663,1.87252144018809,1.8537214299043019,1.8351514240105946,1.816801408926646,1.798671414454778,1.7807613909244537,1.7630513608455658,1.745541363954544,1.728221356868744,1.7111013233661652,1.6941613256931305,1.6774013141791027,1.6608113050460815,1.6443912982940674,1.6281412641207378,1.61205126841863,1.5961112479368846,1.580321232477824,1.5646812319755554,1.5491912066936493,1.5338311791419983,1.518611192703247,1.5035211741924286,1.4885611534118652,1.4737311402956645,1.4590111374855042,1.4444211324055989,1.429931104183197,1.41557111342748,1.4013110995292664,1.3871510724226634,1.3731010655562084,1.359151025613149,1.3453010420004528,1.3315410315990448,1.3178710142771404,1.304291009902954,1.2908009787400563,1.2774009505907695,1.2640809615453084,1.2508409321308136,1.23767093817393,1.2245809535185497,1.2115708986918132,1.1986209054787953,1.1857508818308513,1.1729408701260884,1.160200834274292,1.147530843814214,1.1349108318487804,1.1223608056704204,1.109870821237564,1.0974408189455669,1.0850607852141063,1.0727407534917195,1.060470740000407,1.0482507248719533,1.0360907316207886,1.0239707330862682,1.0119007031122844,0.9998766829570135,0.9878986775875092,0.9759646703799566,0.9640746464331945,0.9522256503502528,0.9404176324605942,0.9286486109097799,0.916915605465571,0.9052205830812454,0.893561581770579,0.8819385717312495,0.8703495611747106,0.8587955435117086,0.8472735285758972,0.8357835163672765,0.8243245085080465,0.8128964900970459,0.8014974743127823,0.7901274611552557,0.7787854572137197,0.7674714426199595,0.7561834255854288,0.744920402765274,0.7336834122737249,0.7224713861942291,0.7112823724746704,0.7001173595587412,0.6889753441015879,0.6778543392817179,0.6667553186416626,0.6556783070166906,0.6446202993392944,0.633580282330513,0.6225592742363611,0.6115572700897852,0.6005742599566778,0.589609240492185,0.5786612331867218,0.5677312016487122,0.5568172037601471,0.5459201882282892,0.5350381731987,0.5241721620162328,0.5133221546808878,0.5024861320853233,0.4916641215483348,0.4808561181028684,0.47006310025850934,0.45928208778301877,0.44851507743199664,0.4377600625157356,0.42701805134614307,0.416289043923219,0.4055740237236023,0.3948720122377078,0.38418400039275485,0.3735079988837242,0.36298799763123196,0.352763998011748,0.3428279981017113,0.3331719959775607,0.32378799716631573,0.31466900060574216,0.3058059985438983,0.2971940040588379,0.28882399946451187,0.2806899969776471,0.2727850029865901,0.2651029999057452,0.25763800243536633,0.25038200120131177,0.2433319998284181,0.23647900049885115,0.2298199993868669,0.22334900001684824,0.21705999846259752,0.21094800035158792,0.20500800013542175,0.19923600057760874,0.19362599775195122,0.18817400063077608,0.1828760008017222,0.1777270001669725,0.17272300273180008,0.16785999884208044,0.1631339987119039,0.15854100013772646,0.15407799929380417,0.14974000056584677,0.14552500223120055,0.14142799998323122,0.13744600117206573,0.13357700034976006,0.12981699903806052,0.1261619987587134,0.12261099927127361,0.11915899999439716,0.1158050000667572,0.11254500038921833,0.10937700048089027,0.10629799962043762,0.10330600043137868,0.1003980003297329,0.09757250050703685,0.09482609915236632,0.09215700067579746,0.08956320025026798,0.0870423000305891,0.08459239949782689,0.08221150003373623,0.07989769925673802,0.07764900041123231,0.07546360107759635,0.07333969883620739,0.07127570050458114,0.06926969873408477,0.06732029840350151,0.06542570019761722,0.063584399720033,0.06179499967644612,0.060055999706188835,0.058365900069475174,0.05672339970866839,0.05512720036009947,0.05357590038329363,0.05206819996237755,0.050603000447154045,0.049179100121061005,0.047795199478665985,0.04645030045260986,0.04514320008456707,0.04387299964825312,0.04263849960019191,0.0414386996999383,0.04027269997944435,0.0391395998497804,0.03803830003986756,0.03696799992273251,0.03592790011316538,0.034917000060280166,0.03393460003038248,0.03297980005542437,0.03205189978082975,0.03115010028705001,0.03027369997774561,0.02942200005054474,0.028594200188914936,0.02778980027263363,0.027007900333652895,0.026248099903265636,0.02550969986865918,0.02479200018569827,0.024094499958058197,0.023416699841618538,0.022758000219861668,0.022117699962109327,0.02149549995859464,0.020890799971918266,0.020303199999034405,0.019731999840587378,0.019177000193546217,0.018637499927232664,0.01811319977665941,0.017603699894001085,0.017108599965771038,0.016627299909790356,0.016159599957366783,0.01570510002784431,0.015263300001000365,0.014833999952922264,0.014416700229048729,0.014011200051754713,0.013617100038876137,0.013234100071713328,0.012861899876346191,0.012500099993000427,0.012148599916448196,0.011806899992128214,0.011474799985686937,0.011152099973211685,0.010838399874046445,0.01053360003667573,0.01023729999239246,0.009949429969613751,0.009669610066339374,0.009397659994040927,0.009133369894698262,0.00887651004207631,0.008626879968990883,0.008384269972642263,0.008148479973897338,0.007919329994668564,0.007696619955822825,0.0074801799686004715,0.007269830016108851,0.007065390003845096,0.006866709950069587,0.006673609993110101,0.0064859500077242655,0.006303560027542214,0.006126310055454572,0.0059540400591989355,0.0057866200028608246,0.005623899943505724,0.005465759973352154,0.005312069978875418,0.005162709935878714,0.005017540107170741,0.004876459987523655,0.004739340045489371,0.004606089981583257,0.004476579992721478,0.004350710000532369,0.004228379965449373,0.004109499976038933,0.00399394993049403,0.003881659999024123,0.0037725200139296553,0.0036664600290047624,0.003563379985280335,0.003463190010127922,0.0033658300332414606,0.003271199995651841,0.0031792299705557525,0.0030898499729422233,0.003002980006082604,0.0029185600384759405,0.0028365099569782615,0.002756770021126916,0.0026792699936777353,0.0026039499983501932,0.002530739991925657,0.002459599985741079,0.0023904499830678105,0.0023232600069604814,0.0022579500024827817,0.002194469988656541,0.0021327799962212643,0.0020728299859911203,0.0020145600040753684,0.0019579299939020225,0.0019028999959118664,0.0018494099786039442,0.0017974200115228693,0.0017468999916066725,0.0016977900037697207,0.0016500700148753822,0.001603690005140379,0.0015586100150054942,0.0015147999996164192,0.0014722300014303376,0.0014308500006639708,0.0013906299912681182,0.001351540005998686,0.001313550000001366,0.0012766399886459112,0.0012407499986390273,0.0012058799911756068,0.001171989996995156,0.001139050010048474,0.0011070399971989293,0.0010759199988873054,0.0010456799839933713,0.0010162899949743103,0.000987732002007154,0.0009599730013481652,0.0009329940027479703,0.0009067729891588291,0.0008812889961215357,0.0008565219953500977,0.0008324510029827555,0.0008090569996663058,0.0007863200007705018,0.0007642229951064413,0.0007427459883426005,0.0007218739920062944,0.0007015880012962347,0.0006818720042550316,0.0006627100083278492,0.0006440869910875335,0.0006259880028665066,0.0006083970026035482,0.0005913010051396365,0.000574684997748894,0.000558536994503811,0.0005428420020810639,0.0005275879908973972,0.0005127629992784932,0.0004983550073423734,0.0004843520024830165,0.00047074199877291295,0.00045751500147162005,0.0004446599996299483,0.0004321659992759426,0.000420023000818522,0.00040822099981596693,0.0003967509959087086,0.0003856029992069428,0.0003747690013066555,0.0003642390001914464,0.0003540050020092167,0.00034405900320659083,0.00033439200099868077,0.0003249970007649002,0.0003158660013771926,0.00031136600106644136};
    
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11867268880208,80.86898803710938,79.52129236857097,78.11839294433594,76.66869608561198,75.17989730834961,73.65929985046387,72.11330032348633,70.54800160725911,68.96890322367351,67.38090387980144,65.78850491841634,64.19580554962158,62.60650602976481,61.024006843566895,59.451206843058266,57.890807469685875,56.34530862172445,54.8167085647583,53.30690892537435,51.81770896911621,50.350409189860024,48.90640926361084,47.48690954844157,46.09270922342936,44.724610010782875,43.38340950012207,42.069610277811684,40.78360970815023,39.52571042378744,38.29610951741537,37.09500948588053,35.92250887552897,34.77860895792643,33.66310977935791,32.576008796691895,31.517008940378826,30.48590898513794,29.482508818308514,28.506508827209473,27.55750830968221,26.63510815302531,25.738908290863037,24.868608156840008,24.0236078898112,23.203507741292317,22.407907485961914,21.63620726267497,20.887907028198242,20.162606875101726,19.4598069190979,18.778906504313152,18.11940622329712,17.48080603281657,16.862706184387207,16.264405886332195,15.685505469640097,15.125405550003052,14.58370534578959,14.059905211130777,13.553505102793375,13.064004898071289,12.590904792149862,12.13380471865336,11.69210433959961,11.265604416529337,10.853604157765707,10.455703973770142,10.071703910827637,9.700893719991049,9.343033711115519,8.997673670450846,8.664433399836222,8.342933495839437,8.032783309618631,7.733643094698588,7.445133010546367,7.166922887166341,6.898682753245036,6.640072703361511,6.390772620836894,6.150482575098674,5.918892463048299,5.695712288220723,5.480652332305908,5.27343225479126,5.069112181663513,4.867892344792684,4.674642125765483,4.48903210957845,4.3107820351918535,4.139581918716431,3.975161890188853,3.817251761754354,3.66560169061025,3.5199616154034934,3.3800915479660034,3.2457614739735923,3.1167614658673606,2.992871363957723,2.873891294002533,2.759631256262461,2.6499012311299643,2.544531206289927,2.4433311422665915,2.346151133378347,2.252831061681112,2.163211007912954,2.077141006787618,1.9944909413655598,1.9151308834552765,1.838910847902298,1.7657208343346913,1.6954407890637715,1.6279507676760356,1.5631407300631206,1.5009007155895233,1.4411406715710957,1.3837506473064423,1.328640619913737,1.2757205764452617,1.2249005734920502,1.1761105557282765,1.1292505065600078,1.084260493516922,1.041060487429301,0.9995744625727335,0.9597394416729609,0.9214894324541092,0.8847604244947433,0.8494923959175745,0.8156283696492513,0.7831113636493683,0.7518883546193441,0.7219083309173584,0.6931213239828745,0.6654803107182184,0.6389392962058386,0.6134552756945292,0.5889862775802612,0.5654912640651067,0.54293226202329,0.5212712436914444,0.500474234422048,0.48050422718127567,0.46133121351401013,0.4429212088386218,0.4252452030777931,0.40827319025993347,0.3919781818985939,0.3763321762283643,0.3613101715842883,0.34688716381788254,0.3330391546090444,0.3197431539495786,0.3069771428902944,0.2947201331456502,0.28295213480790454,0.27165412654479343,0.2608061234156291,0.2503911169866721,0.2403911128640175,0.23079010844230652,0.2215731032192707,0.21272310117880502,0.20422609522938728,0.196068091938893,0.18823608880241713,0.180717084556818,0.1734980804224809,0.16656707848111788,0.15991207336386046,0.15352307260036469,0.1473900725444158,0.1415010653436184,0.1358470618724823,0.13041905810435614,0.12520805870493254,0.12020505716403325,0.11540205404162407,0.11079105051855247,0.1063640508800745,0.10211304699381192,0.09803264650205772,0.09411514364182949,0.09035404274861018,0.08674324055512746,0.08327674058576424,0.07994863701363404,0.07675353437662125,0.07368613531192143,0.07074133430918057,0.06791413202881813,0.06519993022084236,0.06259422997633617,0.06009262831260761,0.057691026479005814,0.05538532634576162,0.0531718252847592,0.051046823461850487,0.04900672317792972,0.04704822227358818,0.04516792111098766,0.04336281990011533,0.04162981982032458,0.03996611883242925,0.03836901827404896,0.03683561738580465,0.03536361642181873,0.033950415439903736,0.03259371562550465,0.03129121412833532,0.030040814075618982,0.028840413472304743,0.027688013079265755,0.026581712532788515,0.02551951181764404,0.024499911194046337,0.023521010763943195,0.022581210515151422,0.021679010552664597,0.020812909739712875,0.019981408957391977,0.019183209010710318,0.01841680845245719,0.017681108477214973,0.016974907834082842,0.016296807831774156,0.01564590718286733,0.01502090715803206,0.014421006742243966,0.01384500654724737,0.013292106101289392,0.012761305940027038,0.012251705707361301,0.011762405590464672,0.011292805041496953,0.010841805022209883,0.010409004831065735,0.009993414704998335,0.009594454507653912,0.00921145430766046,0.00884375418536365,0.008490753903364142,0.00815186370164156,0.007826513766000668,0.007514153451969226,0.00721428341542681,0.006926393252797425,0.006650013111842175,0.006384663050994277,0.006129912915639579,0.005885332667579253,0.005650532664731145,0.005425102581890921,0.005208672412360708,0.005000892366903524,0.004801402256513636,0.00460988221069177,0.0044260020755852265,0.0042494719770426554,0.004079981939867139,0.003917251810586701,0.003761031742518147,0.003611041698604822,0.0034670316187354424,0.0033287715826494,0.003196041468375673,0.0030685914292310676,0.0029462413707127175,0.0028287613531574607,0.0027159812937801084,0.0026076912375477455,0.0025037312104056277,0.00240391114493832,0.002308071047688524,0.0022160610339293876,0.002127720993788292,0.0020429109766458473,0.0019614709017332643,0.0018832908632854621,0.0018082208504589896,0.001736150811969613,0.0016669507798117895,0.00160052075322407,0.0015367307253958036,0.0014754806858642648,0.0014166806746895115,0.0013602306329024334,0.001306020615932842,0.0012539805999646585,0.0012040105648338795,0.00115603053321441,0.001109970510394002,0.0010657405073288828,0.0010232804828168203,0.0009825114393606782,0.0009433664381504059,0.0009057824208866805,0.0008696964068803936,0.0008350493929659327,0.0008017833655079206,0.0007698433619225398,0.0007391763356281444,0.000709732334750394,0.0006814613152528182,0.0006543173076352105,0.0006282552882718543,0.0006032312958268449,0.00057920526402692,0.0005561362680358192,0.0005339872586773708,0.0005127202263489986,0.0004923012311337516,0.00047269621669935685,0.00045387121159971383,0.00043579720416649553,0.00041844319154430803,0.00040178118797484785,0.0003857821769391497,0.00037042117522408563,0.0003556721688558658,0.000341510160069447,0.0003279131560702808,0.0003148571486235596,0.0003023211417409281,0.00029028513624022406,0.00027872813370777294,0.0002676321237231605,0.00025697812331297126,0.0002467481147808333,0.0002369251111910368,0.00022749410466834283,0.00021843810100108385,0.0002097430976088314,0.00020139409510496384,0.0001933780889279054,0.0001856810861985044,0.00017829108279935704,0.00017119508023218563,0.00016438107680490552,0.00015783907413909523,0.00015155706811735095,0.0001455260680813808,0.00013973506429465488,0.00013417406201673052,0.00012883406088803895,0.00012370805598038714,0.00011878505574713927,0.00011405805283478306,0.00010952005141007248,0.00010516204868811958,7.610374632349703e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45184453328451,229.5926055908203,226.30972035725912,223.6417121887207,220.94770940144858,218.23070780436197,215.49570337931314,212.7447026570638,209.9807039896647,207.20770136515299,204.42870076497397,201.64570109049478,198.8607037862142,196.07770538330078,193.2977040608724,190.522705078125,187.7557055155436,184.99670918782553,182.2497075398763,179.5137087504069,176.79170989990234,174.0857137044271,171.39571380615234,168.72371546427408,166.06971995035806,163.4367192586263,160.82372029622397,158.23372650146484,155.66472752888998,153.120730082194,150.599733988444,148.1047388712565,145.63373947143555,143.18974431355795,140.77174377441406,138.38074747721353,136.01675033569336,133.6807518005371,131.37175496419272,129.0917599995931,126.8397610982259,124.61576588948567,122.42176882425944,120.25577227274577,118.11877504984538,116.01077842712402,113.93178176879883,111.8817850748698,109.86178779602051,107.8697903951009,105.90679359436035,103.97179667154948,102.06679916381836,100.1898021697998,98.34160550435384,96.52150980631511,94.72951253255208,92.96551577250163,91.22931671142578,89.52062034606934,87.83922449747722,86.18502553304036,84.55772844950359,82.95703188578288,81.38273493448894,79.8346373240153,78.3124402364095,76.81594212849934,75.34474563598633,73.89864921569824,72.4772497812907,71.08045323689778,69.70795567830403,68.3592586517334,67.03426106770833,65.73266474405925,64.45406436920166,63.198168436686196,61.964871088663735,60.753673235575356,59.56427510579427,58.396477381388344,57.24987983703613,56.12418270111084,55.01918411254883,53.93448797861735,52.890993436177574,51.88739426930746,50.90149688720703,49.932899157206215,48.98140048980713,48.04670206705729,47.12860361735026,46.226805686950684,45.34110736846924,44.471208572387695,43.61701043446859,42.77811241149902,41.95431359608968,41.14541530609131,40.35111713409424,39.57131830851237,38.80561955769857,38.053921381632485,37.31592241923014,36.591423988342285,35.88022549947103,35.18212731679281,34.4969285329183,33.8243293762207,33.164130528767906,32.51623217264811,31.880333423614502,31.256234804789226,30.643736044565838,30.042737007141113,29.452938238779705,28.87423912684123,28.306340217590332,27.749141534169514,27.20244264602661,26.666043758392334,26.139744758605957,25.62344566980998,25.116947174072266,24.62004788716634,24.13254912694295,23.654350121815998,23.185250918070476,22.725052038828533,22.273752848307293,21.83095359802246,21.3967547416687,20.970755259195965,20.553056399027508,20.143357117970783,19.741558074951172,19.347558975219727,18.9610595703125,18.58206033706665,18.210361162821453,17.84586191177368,17.488462607065838,17.138063271840412,16.794364134470623,16.457464536031086,16.127065499623615,15.803166230519613,15.48556669553121,15.1740673383077,14.868767976760864,14.56946873664856,14.27596926689148,13.988270044326782,13.706170479456583,13.429671049118042,13.158571561177572,12.892872333526611,12.632372776667276,12.376973231633505,12.126673857371012,11.881274382273356,11.640774885813395,11.405075470606485,11.173975706100464,10.947476545969645,10.725476741790771,10.507877190907797,10.294677495956421,10.085578203201294,9.880738735198975,9.679959058761597,9.483189423878988,9.290339787801107,9.101340134938559,8.916120608647665,8.73461103439331,8.556721369425455,8.38241179784139,8.211602210998535,8.04420248667399,7.880162874857585,7.719433228174846,7.561923623085022,7.407573898633321,7.2563241720199585,7.108124494552612,6.9629048109054565,6.820605158805847,6.681165456771851,6.544555743535359,6.410695989926656,6.279556234677632,6.15105660756429,6.025156855583191,5.901787042617798,5.780917326609294,5.662497639656067,5.5464978615442915,5.4328181346257525,5.321458339691162,5.212348580360413,5.105458776156108,5.000729044278462,4.898129304250081,4.797629475593567,4.699159701665242,4.60267988840739,4.508170127868652,4.415600339571635,4.324910521507263,4.236080646514893,4.149060885111491,4.0638110637664795,3.9803112546602883,3.898501435915629,3.8183616598447165,3.739851792653402,3.6629419724146524,3.587602138519287,3.5137823025385537,3.4414923985799155,3.3706925908724465,3.3013227581977844,3.233362893263499,3.166803022225698,3.101613144079844,3.0377333561579385,2.9751834670702615,2.913903554280599,2.85389373699824,2.7951138615608215,2.737543980280558,2.6811540722846985,2.6259242494901023,2.571824371814728,2.5188344518343606,2.4669245878855386,2.416094720363617,2.366294781366984,2.317514936129252,2.269765019416809,2.2229851285616555,2.17716521024704,2.132275342941284,2.0883053739865622,2.045255502065023,2.0030855933825173,1.9617757002512615,1.9213257730007172,1.8817158639431,1.8429159422715504,1.8049060205618541,1.767696092526118,1.7312361896038055,1.6955062647660573,1.6605363587538402,1.6262864271799724,1.5927564998467763,1.559896558523178,1.5277066330115001,1.4961866935094197,1.465326766173045,1.4351068437099457,1.405496895313263,1.3764869670073192,1.3480770389238994,1.3202671110630035,1.293027142683665,1.2663572132587433,1.2402172684669495,1.2146073182423909,1.18953737616539,1.1649774213631947,1.1409375071525574,1.1173875232537587,1.0943376024564107,1.0717476308345795,1.04959770043691,1.027917742729187,1.006687785188357,0.9858968257904053,0.9655408759911855,0.9456079254547755,0.9260899573564529,0.9069789995749792,0.8882660468419393,0.8699200848738352,0.8519361217816671,0.8343251595894495,0.8170811881621679,0.8001962304115295,0.7836632678906122,0.7674733102321625,0.7516213357448578,0.7360983788967133,0.7208984146515528,0.7060154577096304,0.6914414862791697,0.6771705051263174,0.6631965388854345,0.6495135674873987,0.6360935916503271,0.622931624452273,0.6100436498721441,0.5974226792653402,0.585064709186554,0.5729637344678243,0.5611147632201513,0.5495117803414663,0.5381508121887842,0.527024840315183,0.516130859653155,0.5054628898700079,0.495017908513546,0.4847889343897502,0.47477295249700546,0.46496497839689255,0.4553609962264697,0.4459570174415906,0.43674803773562115,0.4277300586303075,0.4189000775416692,0.4102540984749794,0.4017871121565501,0.39349612842003506,0.3853771562377612,0.377427173157533,0.36964218815167743,0.36201920360326767,0.35455422103405,0.347244235376517,0.34008725235859555,0.3330772668123245,0.3262142837047577,0.3194712921977043,0.3128483047087987,0.30636132260163623,0.3000103359421094,0.2937903528412183,0.2877003625035286,0.28173637638489407,0.2758953919013341,0.27017640074094135,0.26457641770442325,0.25909242779016495,0.253722441693147,0.24846445148189863,0.24331446240345636,0.23827247321605682,0.2333344854414463,0.22849949449300766,0.22376450523734093,0.2191275159517924,0.21458752701679865,0.2101405362288157,0.205786544829607,0.2015235535800457,0.19734856362144151,0.1932595744729042,0.1892565836509069,0.18533559143543243,0.1814965990682443,0.17773660769065222,0.17405561357736588,0.17045062283674875,0.1669196349879106,0.1634626400967439,0.16007764637470245,0.1567616524795691,0.1535156617561976,0.15033666541179022,0.14722367251912752,0.14417468011379242,0.14118968695402145,0.1382656954228878,0.13540270055333772,0.132599708934625,0.12985471139351526,0.12716571862498918,0.12453272628287475,0.1219547310223182,0.11943073632816474,0.11695874109864235,0.11453774757683277,0.112166753038764,0.1098447572439909,0.10757076181471348,0.10534476799269517,0.10316477281351884,0.10102977727850278,0.09893868242700894,0.0968911877522866,0.09488618994752566,0.09292269498109818,0.09099990005294482,0.08911690302193165,0.08727300787965457,0.08546731062233448,0.08369901527961095,0.08196731967230637,0.08027152282496293,0.07861092686653137,0.07698473085959752,0.07539213386674722,0.07383263731996219,0.0723053403198719,0.07080974367757638,0.06934514765938123,0.06791085004806519,0.06650635227560997,0.06513085526724656,0.06378385983407497,0.062464761237303414,0.06117296529312929,0.059907967535158,0.05866917036473751,0.05745597338924805,0.056267976139982544,0.05510457822432121,0.05396518142273029,0.052849483055373035,0.05175678556164106,0.05068678812434276,0.04963889097174009,0.0486126933246851,0.04760779502491156,0.04662369688351949,0.04565989971160889,0.044716100829343,0.04379180415223042,0.04288670513778925,0.04200030739108721,0.041132209512094654,0.040282211576898895,0.039449713192880154,0.0386344138532877,0.037836017087101936,0.037054117769002914,0.03628841942797104,0.0355386221781373,0.03480432306726774,0.03408512442062298,0.033380926586687565,0.032691228513916336,0.03201582903663317,0.03135433063531915,0.030706632416695356,0.030072233950098354,0.02945103496313095,0.028842636694510777,0.028246837978561718,0.02766333908463518,0.02709194039925933,0.0265324415328602,0.02598444263761242,0.025447743944823742,0.024922144909699757,0.0244074462292095,0.023903347551822662,0.023409748449921608,0.022926349348078173,0.022452850515643757,0.02198925195261836,0.021535152414192755,0.021090553452571232,0.020655054443826277,0.02022855542600155,0.019810956437140703,0.019401957280933857,0.019001358188688755,0.018609059198449057,0.01822495988259713,0.017848660548528034,0.017480261468638975,0.017119362174222868,0.016766063092897337,0.016419963911175728,0.016081064629058044,0.01574916540024181,0.015424066067983707,0.015105766554673513,0.014793967440103492,0.014488667094459137,0.014189677235359946,0.014041687594726682};
    
    CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452964782715,71.41004117329915,70.57014656066895,69.81614112854004,69.06634203592937,68.32144101460774,67.58154042561848,66.84703954060872,66.1182409922282,65.39523951212566,64.67823918660481,63.96743965148926,63.26283836364746,62.56453800201416,61.87253761291504,61.187037785847984,60.5080369313558,59.83543745676676,59.169236501057945,58.5094362894694,57.85613600413004,57.209235191345215,56.568634668986,55.934434254964195,55.30653349558512,54.68503379821777,54.06973425547282,53.46063359578451,52.85773277282715,52.26103274027506,51.67033290863037,51.08583164215088,50.50723203023275,49.93473116556803,49.368030865987144,48.80733076731364,48.25243059794108,47.70333035786947,47.15992959340414,46.62232971191406,46.09032917022705,45.56402842203776,45.043228467305504,44.528029123942055,44.018327713012695,43.5139274597168,43.01502704620361,42.521427154541016,42.03312683105469,41.550126711527504,41.072325706481934,40.599626223246254,40.13212617238363,39.66962464650472,39.21222496032715,38.759724934895836,38.312124252319336,37.86952431996664,37.4317242304484,36.99862321217855,36.570423444112144,36.14682388305664,35.72792307535807,35.31362247467041,34.904022534688316,34.4988218943278,34.09822209676107,33.70202159881592,33.31022103627523,32.92282168070475,32.53972085316976,32.161020596822105,31.786420504252117,31.416120211283367,31.050020058949787,30.68801975250244,30.330119768778484,29.97621949513753,29.626419226328533,29.280519008636475,28.938618342081707,28.600518703460693,28.266318480173748,27.936017990112305,27.60941791534424,27.286617437998455,26.967517693837483,26.65201727549235,26.340216954549152,26.031916936238606,25.727216720581055,25.426016489664715,25.12821610768636,24.833916028340656,24.543015638987224,24.255415598551433,23.971215565999348,23.690215587615967,23.412514686584473,23.13791497548421,22.86661497751872,22.598414580027264,22.33321460088094,22.0712145169576,21.812114397684734,21.556114037831623,21.303013801574707,21.052913983662922,20.80561367670695,20.56121301651001,20.31971327463786,20.080913066864014,19.84491268793742,19.61171277364095,19.381112416585285,19.153312524159748,18.928012053171795,18.705411911010742,18.485412120819092,18.26791175206502,18.053011576334637,17.840511798858643,17.63051160176595,17.423011620839436,17.21791124343872,17.015111287434895,16.814710934956867,16.616710821787517,16.420910676320393,16.22751061121623,16.03631051381429,15.847310384114584,15.660510301589966,15.475910266240438,15.29351011912028,15.113109827041626,14.93490974108378,14.758809645970663,14.584709405899048,14.412709395090738,14.242609341939291,14.074609200159708,13.908509095509848,13.744308869043985,13.582108815511068,13.42180879910787,13.26330860455831,13.106708447138468,12.952008485794067,12.79900828997294,12.647808313369751,12.498408238093058,12.350807984670004,12.204907973607382,12.060707966486612,11.91820764541626,11.7774076461792,11.63820767402649,11.500607570012411,11.364707549413046,11.230407317479452,11.097607215245565,10.966407219568888,10.83670703570048,10.708606878916422,10.582006772359213,10.456806898117065,10.33320665359497,10.211006800333658,10.090206623077393,9.970866362253824,9.852916320164999,9.736366351445517,9.621186256408691,9.507366418838501,9.394885937372843,9.28372589747111,9.173885901769003,9.065335909525553,8.9580659866333,8.852065801620483,8.747315724690756,8.643795649210611,8.541505575180054,8.440425475438436,8.340535402297974,8.241825262705484,8.144275188446045,8.047885338465372,7.952635169029236,7.858505169550578,7.76549506187439,7.673575043678284,7.582754929860433,7.493004997571309,7.404314835866292,7.3166747490564985,7.230064749717712,7.144494652748108,7.059924562772115,6.976364533106486,6.893794496854146,6.812194466590881,6.731564283370972,6.6518943309783936,6.573164264361064,6.495374282201131,6.41849418481191,6.342534144719441,6.267474134763082,6.193304061889648,6.120014071464539,6.047593990961711,5.976033926010132,5.905313849449158,5.83544385433197,5.766393740971883,5.698173721631368,5.6307536363601685,5.564143657684326,5.498323639233907,5.4332735141118365,5.3690034945805865,5.305503447850545,5.242753426233928,5.180743416150411,5.119473377863566,5.058933297793071,4.999113281567891,4.940003275871277,4.881593227386475,4.8238831758499146,4.766853133837382,4.710503101348877,4.654823025067647,4.59980305035909,4.5454429388046265,4.491732915242513,4.438652873039246,4.3862128257751465,4.3343929052352905,4.2831928332646685,4.232592821121216,4.182602763175964,4.133212725321452,4.0844026406606035,4.036182641983032,3.9885226090749106,3.9414325952529907,3.894912540912628,3.8489325046539307,3.8035024801890054,3.7586124539375305,3.7142624258995056,3.670432388782501,3.627122402191162,3.5843223333358765,3.5420323411623635,3.5002523263295493,3.4589622616767883,3.418162206808726,3.3778421878814697,3.3380021452903748,3.2986321250597634,3.2597321271896362,3.221302111943563,3.1833121180534363,3.1457820534706116,3.1086920301119485,3.0720419883728027,3.0358219742774963,3.000041981538137,2.9646719098091125,2.9297319253285727,2.8952019214630127,2.861081858476003,2.827361822128296,2.7940417925516763,2.7611217896143594,2.7285817861557007,2.6964317560195923,2.664661725362142,2.6332716743151345,2.602251708507538,2.5715916951497397,2.541301707426707,2.511371652285258,2.48179163535436,2.452561597029368,2.42367160320282,2.3951315879821777,2.3669315377871194,2.3390515049298606,2.31151149670283,2.2842915058135986,2.257401466369629,2.2308214704195657,2.204561491807302,2.17861145734787,2.1529613733291626,2.127621372540792,2.1025713880856833,2.0778313279151917,2.0533713499704995,2.029201328754425,2.00532129406929,1.98172128200531,1.9584012826283772,1.935361256202062,1.912591238816579,1.8900812268257141,1.8678512175877888,1.845871200164159,1.8241511782010396,1.8026911715666454,1.7814911703268688,1.7605311473210652,1.7398211359977722,1.719361126422882,1.6991411248842876,1.6791510879993439,1.659411072731018,1.639891078074773,1.6206110616525014,1.6015510360399883,1.5827210346857707,1.564111014207204,1.545721024274826,1.527550995349884,1.5095909933249156,1.4918409784634907,1.4743009805679321,1.4569709599018097,1.4398409326871235,1.4229209224383037,1.406200925509135,1.3896708985169728,1.3733408947785695,1.357190877199173,1.3412508765856426,1.3254808485507965,1.3099108636379242,1.2945208450158436,1.2793008387088776,1.2642708122730255,1.24942081173261,1.234740803639094,1.220230797926585,1.2059007982412975,1.1917307674884796,1.1777307490507762,1.163900762796402,1.1502307554086049,1.1367207169532776,1.1233707467714946,1.110170731941859,1.0971307158470154,1.084250698486964,1.0715206960837047,1.0589306851228077,1.0465006828308105,1.0342106719811757,1.0220706562201183,1.0100706617037456,0.9982096503178278,0.9864906370639801,0.9749096284310023,0.963464617729187,0.9521546264489492,0.9409776081641515,0.9299326042334238,0.9190176030000051,0.9082305828730265,0.8975705852111181,0.8870365768671036,0.8766265710194906,0.8663385659456253,0.8561715632677078,0.846124549706777,0.8361965417861938,0.8263845294713974,0.8166885326306025,0.8071065247058868,0.7976365139087042,0.7882785101731619,0.7790305018424988,0.7698915004730225,0.7608604927857717,0.7519354919592539,0.7431144813696543,0.7343984742959341,0.7257844706376394,0.7172724554936091,0.7088594635327657,0.700546458363533,0.6923304498195648,0.6842114428679148,0.6761884440978368,0.6682584335406622,0.6604224294424057,0.65267942349116,0.6450264205535253,0.6374634156624476,0.6299904038508733,0.6226043999195099,0.6153054038683573,0.6080923974514008,0.6009633938471476,0.5939193914333979,0.5869573801755905,0.5800773749748865,0.5732783675193787,0.5665593594312668,0.5599193572998047,0.5533573577801386,0.5468723575274149,0.5404633581638336,0.5341303547223409,0.527871330579122,0.5216863503058752,0.5155733426411947,0.5095323324203491,0.5035623262325922,0.4976623207330704,0.49183232088883716,0.48607031504313153,0.48037631313006085,0.4747483084599177,0.46918730437755585,0.4636913016438484,0.45826029529174167,0.45289329687754315,0.4475882922609647,0.44234628478686017,0.4371652826666832,0.43204627682765323,0.42698627958695096,0.42198627442121506,0.4170442670583725,0.4121612658103307,0.4073352615038554,0.40256526072820026,0.39785226186116535,0.3931942582130432,0.3885902514060338,0.3840412497520447,0.37954524904489517,0.37510224680105847,0.37071124215920764,0.3663712367415428,0.36208323389291763,0.35784423102935153,0.35365622738997143,0.34951722125212353,0.34542622168858844,0.3413832212487857,0.33738821744918823,0.33344022184610367,0.3295382137099902,0.32568121204773587,0.32187021027008694,0.31810420254866284,0.31438220540682477,0.31070319811503094,0.3070681964357694,0.3034751961628596,0.29992519319057465,0.2964161957303683,0.2929481938481331,0.289521187543869,0.2861351892352104,0.282788189748923,0.27948017915089923,0.276211179792881,0.2729801783959071,0.2697871724764506,0.26663217196861905,0.2635131726662318,0.2604321713248889,0.2573861628770828,0.2543761655688286,0.251401166121165,0.2484621616701285,0.24555615584055582,0.24268517022331557,0.24125803510348};
    
    CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297699451446533,16.274217287699383,16.217710494995117,16.178108374277752,16.132907549540203,16.083006540934246,16.02880605061849,15.970905065536499,15.909904400507608,15.846003929773966,15.77980351448059,15.711503187815348,15.641302665074667,15.569702386856079,15.496702194213867,15.422601779301962,15.347601572672525,15.271801392237345,15.195301373799643,15.118301232655844,15.040800968805948,14.963000933329264,14.885000785191854,14.806700468063354,14.728400548299154,14.65000057220459,14.571600516637167,14.493200381596884,14.414900302886963,14.336700359980265,14.258600155512491,14.180700143178305,14.103000243504843,14.025500218073526,13.94830028216044,13.87120016415914,13.79450019200643,13.718000173568726,13.641800085703531,13.565900087356567,13.49020012219747,13.414899984995523,13.339900096257528,13.265199899673462,13.190900087356567,13.11680014928182,13.043200016021729,12.969799995422363,12.89679996172587,12.824099858601889,12.751800060272217,12.679800033569336,12.608100096384684,12.536799987157186,12.46590002377828,12.39520009358724,12.325000127156576,12.255100091298422,12.185500065485636,12.116300026575724,12.047399997711182,11.978900035222372,11.910800059636435,11.843000014623007,11.775499900182089,11.708400090535482,11.641600131988525,11.575200080871582,11.509100039800009,11.443400065104166,11.377999941507975,11.312999963760376,11.248300075531006,11.183900038401285,11.119900226593018,11.05620002746582,10.992899894714355,10.92989993095398,10.867299954096476,10.804999987284342,10.743099927902222,10.681399981180826,10.620199998219809,10.559200048446655,10.498600085576376,10.438299973805746,10.378400007883707,10.31879997253418,10.25949994723002,10.200499931971232,10.141899983088175,10.083599964777628,10.025600035985311,9.96798006693522,9.910649935404459,9.85362990697225,9.796939929326376,9.740559895833334,9.684499899546305,9.628740072250366,9.573300043741861,9.51816995938619,9.463350057601929,9.40884002049764,9.35462999343872,9.30071989695231,9.247119983037313,9.193809986114502,9.140810092290243,9.08810019493103,9.035680055618286,8.983570019404093,8.931740045547485,8.880210002263388,8.828960100809732,8.778000036875406,8.727330048878988,8.676950136820475,8.626850048700968,8.577029943466187,8.52748998006185,8.478229999542236,8.429250001907349,8.380539973576864,8.332110087076822,8.283960103988647,8.236069838205973,8.188459952672323,8.141110102335611,8.094029823939005,8.04722007115682,8.000669956207275,7.954390048980713,7.908370018005371,7.8626099824905396,7.817110021909078,7.771870017051697,7.726879994074504,7.68215008576711,7.637670000394185,7.593449989954631,7.549470067024231,7.505750060081482,7.462280035018921,7.419049938519795,7.376070062319438,7.333330035209656,7.290839950243632,7.248580018679301,7.206569989522298,7.164800047874451,7.123270034790039,7.08197005589803,7.04091997941335,7.000090042750041,6.959499955177307,6.919139981269836,6.879009962081909,6.839110016822815,6.799440026283264,6.760000030199687,6.72078005472819,6.681789954503377,6.643020033836365,6.604480028152466,6.566149950027466,6.528049985567729,6.49015998840332,6.452499985694885,6.415040016174316,6.377810041109721,6.340789953867595,6.303980032602946,6.267379999160767,6.230999946594238,6.194819966952006,6.158860007921855,6.12309996287028,6.087540030479431,6.052199999491374,6.01705002784729,5.982109904289246,5.947369972864787,5.912829955418904,5.8784999052683515,5.844359954198201,5.810409982999166,5.776670058568318,5.743120034535726,5.7097599903742475,5.676600019137065,5.643629988034566,5.610850016276042,5.578260103861491,5.545859972635905,5.513650019963582,5.481629967689514,5.449790000915527,5.418130040168762,5.386660019556682,5.355379978815715,5.324270049730937,5.293350060780843,5.262609998385112,5.232040007909139,5.201649983723958,5.171440045038859,5.141409993171692,5.111549973487854,5.081870079040527,5.052349964777629,5.023010015487671,4.993849992752075,4.964850028355916,4.936019976933797,4.907360037167867,4.878870010375977,4.850540002187093,4.822379986445109,4.794379949569702,4.766550024350484,4.738879998524983,4.71136999130249,4.6840200026830034,4.656839966773987,4.629810015360515,4.602939963340759,4.576230009396871,4.549670020739238,4.523270010948181,4.497030019760132,4.470930020014445,4.445000052452087,4.419210076332092,4.393579999605815,4.368090073267619,4.342759966850281,4.317570010821025,4.292530020078023,4.267639994621277,4.242899974187215,4.218299984931946,4.193850000699361,4.169539968172709,4.145380020141602,4.121350010236104,4.0974700053532915,4.073730031649272,4.050120035807292,4.026660044987996,4.0033299922943115,3.9801400105158486,3.9570900003115335,3.9341700275739035,3.9113800128300986,3.888729989528656,3.8662100036938987,3.8438300093015036,3.8215699791908264,3.7994500199953714,3.777449985345205,3.755580027898153,3.733840028444926,3.7122300267219543,3.6907400091489158,3.669379969437917,3.648150006930033,3.6270400285720825,3.6060499946276345,3.5851799845695496,3.5644400119781494,3.543809990088145,3.5233099857966104,3.5029300252596536,3.4826600551605225,3.4625199834505715,3.4424900015195212,3.4225799838701882,3.402780016263326,3.3831000328063965,3.363540013631185,3.344090004762014,3.324750006198883,3.305519998073578,3.2864099939664206,3.2674099802970886,3.248519996802012,3.229740023612976,3.2110700408617654,3.1925100286801658,3.174049973487854,3.1556999683380127,3.1374699473381042,3.1193300088246665,3.101300001144409,3.0833800037701926,3.065559983253479,3.0478499929110208,3.030230005582174,3.0127300222714744,2.995319982369741,2.9780099987983704,2.9608099659283957,2.9436999956766763,2.926700015862783,2.9097899794578552,2.8929800192515054,2.876270035902659,2.859659969806671,2.843139966328939,2.8267200191815696,2.810389975706736,2.794159988562266,2.778029998143514,2.7619899908701577,2.7460400064786277,2.730180005232493,2.7144200007120767,2.6987499992052713,2.6831700205802917,2.667680005232493,2.652270019054413,2.6369600097338357,2.621739983558655,2.6066100001335144,2.5915600260098777,2.5765999952952066,2.5617300271987915,2.5469499826431274,2.5322499871253967,2.517639994621277,2.5031100114186606,2.4886600176493325,2.474299987157186,2.4600300590197244,2.445830007394155,2.4317199985186257,2.4176899989446006,2.4037399888038635,2.3898800214131675,2.3760899901390076,2.362380027770996,2.3487599889437356,2.3352100253105164,2.321739991505941,2.3083500067392984,2.2950299978256226,2.2818000117937722,2.2686399817466736,2.255559980869293,2.242549995581309,2.2296199798583984,2.216759999593099,2.203980008761088,2.1912699540456138,2.1786399682362876,2.1660800178845725,2.1535900235176086,2.1411699851353965,2.1288300156593323,2.1165600021680198,2.1043600042661033,2.0922300020853677,2.080169995625814,2.068179984887441,2.0562600096066794,2.044409990310669,2.032629986604055,2.0209099849065146,2.0092699925104776,1.9976900120576222,1.9861800173918407,1.9747300048669179,1.9633500079313915,1.9520399967829387,1.9407999813556671,1.929610013961792,1.9184999863306682,1.9074399967988331,1.8964599867661793,1.8855299949645996,1.8746699889500935,1.863869994878769,1.853139986594518,1.8424600064754486,1.8318500022093456,1.8212999900182087,1.8108100195725758,1.8003800014654796,1.7900200188159943,1.7797100047270458,1.7694600025812786,1.7592700123786926,1.7491400142510731,1.7390700081984203,1.729059984286626,1.719099998474121,1.7092099984486897,1.6993699967861176,1.689580003420512,1.6798599859078724,1.6701900164286296,1.660570005575816,1.6510100066661835,1.6415099998315175,1.6320599913597107,1.6226699848969777,1.6133299867312114,1.6040500005086262,1.5948200126489003,1.5856399933497112,1.5765100121498108,1.567440003156662,1.5584200223286946,1.5494499901930492,1.5405399998029072,1.5316799978415172,1.522860010464986,1.514100005229314,1.5053899983565013,1.4967299898465474,1.4881199995676677,1.4795599679152172,1.4710499942302704,1.4625899990399678,1.4541800022125244,1.4458100100358326,1.4375000099341075,1.429229994614919,1.421010007460912,1.4128399888674419,1.4047100047270458,1.3966400027275085,1.3886000116666157,1.3806199928124745,1.3726800084114075,1.364789992570877,1.356940011183421,1.3491399884223938,1.3413799901803334,1.3336699903011322,1.3260000149408977,1.3183799982070923,1.3107999861240387,1.3032699922720592,1.2957799931367238,1.2883300085862477,1.2809199889500935,1.2735599875450134,1.2662400106589,1.2589599986871083,1.2517299950122833,1.2445300022761028,1.2373799979686737,1.2302699983119965,1.2232000132401784,1.2161699930826824,1.2091799974441528,1.2022400001684825,1.1953300038973491,1.1884600122769673,1.1816299955050151,1.1748400032520294,1.1680899957815807,1.161380002895991,1.1547099947929382,1.148080011208852,1.1414799988269806,1.134930004676183,1.1284099817276,1.1219300031661987,1.1154799958070118,1.1090799967447917,1.102709988753001,1.096370001633962,1.0900799930095673,1.0838200052579243,1.0775899787743886,1.0714100102583568,1.065249999364217,1.059139996767044,1.0530500014623005,1.0470100045204163,1.0409999787807465,1.0350200136502583,1.032039999961853};
    
    CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.460016568501791,8.488823334376017,8.531164328257242,8.575854221979776,8.618204037348429,8.658293883005777,8.696223815282186,8.73206353187561,8.76590347290039,8.79779346783956,8.827833334604898,8.856073220570883,8.882592916488647,8.907452980677286,8.930712779362997,8.952422698338827,8.972662607828775,8.991462469100952,9.008902390797934,9.025012095769247,9.039842287699381,9.053452173868815,9.065882126490274,9.07717196146647,9.087381839752197,9.096531788508097,9.104671716690063,9.111841837565104,9.118061621983847,9.12339154879252,9.127851645151773,9.131461461385092,9.134281396865845,9.13633139928182,9.137631495793661,9.138211409250895,9.13810125986735,9.137341181437174,9.135951121648153,9.133940935134888,9.131341139475504,9.12817088762919,9.124460935592651,9.120230913162231,9.115490674972534,9.110270977020264,9.104590892791748,9.098460753758749,9.09191083908081,9.084940671920776,9.07758084932963,9.069830576578775,9.061730782190958,9.053280512491861,9.044490575790405,9.035380681355795,9.025960604349772,9.01624059677124,9.006240447362265,8.995960632960001,8.985430479049683,8.974640528361002,8.963610331217447,8.952350378036499,8.940860430399576,8.929160356521606,8.91726040840149,8.905170520146688,8.892900387446085,8.8804403146108,8.867820501327515,8.855030377705893,8.842080354690552,8.82899022102356,8.815750360488892,8.802380243937174,8.788880427678427,8.775260289510092,8.761530240376791,8.747690280278524,8.73373015721639,8.719670295715332,8.705520153045654,8.691280285517374,8.676940282185873,8.662529945373535,8.64670991897583,8.629550059636435,8.612419923146566,8.595320065816244,8.57825001080831,8.5612100760142,8.54420002301534,8.527229944864908,8.510279973347982,8.493369976679483,8.47648000717163,8.459630012512207,8.44281005859375,8.42601990699768,8.409259875615438,8.392539978027344,8.375839869181315,8.359170118967691,8.3425399462382,8.325929959615072,8.309360027313232,8.29281997680664,8.276309967041016,8.259819904963175,8.243369897206625,8.22694993019104,8.210570017496744,8.194209893544516,8.177880048751831,8.161580006281534,8.145310004552206,8.129079977671305,8.11287005742391,8.096690018971762,8.080549955368042,8.064429918924967,8.048350016276041,8.032290061314901,8.016270160675049,8.000269929567972,7.984309911727905,7.968379974365234,7.952469984690349,7.936599969863892,7.920749982198079,7.9049400091171265,7.889159957567851,7.87340001265208,7.857679963111877,7.84197998046875,7.8263200124104815,7.810680111249288,7.7950799862543745,7.7795000076293945,7.763959964116414,7.748439947764079,7.73294993241628,7.717489997545878,7.702069958051045,7.686669985453288,7.671299934387207,7.655959963798523,7.6406499942143755,7.625369946161906,7.610120018323262,7.594900012016296,7.579710006713867,7.5645400285720825,7.549410065015157,7.534310022989909,7.519229968388875,7.504180113474528,7.489169955253601,7.474179983139038,7.4592199722925825,7.4442899624506635,7.429389993349711,7.414520025253296,7.399679978688558,7.384859999020894,7.37008003393809,7.355319976806641,7.34059997399648,7.3258999188741045,7.311230023701985,7.296590010325114,7.281979997952779,7.267390012741089,7.252840002377828,7.238309939702352,7.223819971084595,7.209350069363912,7.194909969965617,7.180500070254008,7.166109919548035,7.1517600218455,7.13742999235789,7.123140017191569,7.108869989713033,7.094619989395142,7.0804100433985395,7.0662299791971845,7.0520700216293335,7.03793998559316,7.023839990297954,7.0097700754801435,6.995730042457581,6.981709957122803,6.967720031738281,6.953759948412578,6.9398299853007,6.9259300629297895,6.912049969037374,6.898199995358785,6.884379982948303,6.870589971542358,6.8568300406138105,6.8430899779001875,6.829380035400391,6.815700054168701,6.802039980888367,6.788419922192891,6.774820009867351,6.761249979337056,6.747699936230977,6.734180013338725,6.7206999858220415,6.707230011622111,6.693800052007039,6.680390000343323,6.6670100291570025,6.65366001923879,6.640329996744792,6.62703005472819,6.613759994506836,6.600519975026448,6.587300022443135,6.57411007086436,6.560949921607971,6.547809958457947,6.534700036048889,6.521619915962219,6.508560021718343,6.495529969533284,6.482530037562053,6.469549973805745,6.456599990526835,6.443679968516032,6.430789987246196,6.417920033137004,6.405070066452026,6.392259955406189,6.3794699509938555,6.3666999737421675,6.353969971338908,6.341260035832723,6.328570008277893,6.315919955571492,6.303289930025737,6.290679971377055,6.27810005346934,6.265549977620442,6.25301996866862,6.240520000457764,6.228039940198262,6.215590039889018,6.20317006111145,6.1907700300216675,6.178399999936421,6.16605003674825,6.153730034828186,6.141429980595906,6.129159967104594,6.116910020510356,6.104689995447795,6.092489918073018,6.080320080121358,6.068170030911763,6.056049982706706,6.043960054715474,6.031880021095276,6.019829988479614,6.007809956868489,5.99580995241801,5.983839988708496,5.971889972686768,5.959960023562114,5.948059995969136,5.9361900091171265,5.924329956372579,5.912499984105428,5.900699973106384,5.888919989267985,5.877159992853801,5.865429917971293,5.85372006893158,5.8420400222142534,5.830380002657573,5.818740010261536,5.807129939397176,5.795539975166321,5.78396999835968,5.772430022557576,5.760909954706828,5.749410072962443,5.7379400332768755,5.726489941279094,5.715069969495137,5.7036599318186445,5.692279974619548,5.680929978688558,5.669589996337891,5.65828001499176,5.6470000346501665,5.635729988416036,5.624490022659302,5.613270004590352,5.60208002726237,5.59089994430542,5.579749981562297,5.56863001982371,5.557520031929016,5.546440084775289,5.535380045572917,5.524340033531189,5.513320128122966,5.50232994556427,5.491359909375508,5.480410019556682,5.469489932060242,5.458580017089844,5.447700023651123,5.4368399779001875,5.4259999593098955,5.415190021197001,5.404389977455139,5.393620014190674,5.382869998613994,5.372140010197957,5.361430048942566,5.350750048955281,5.34008002281189,5.329439997673035,5.318819920221965,5.308219989140828,5.29764990011851,5.287090023358663,5.276550014813741,5.266040047009786,5.255549987157186,5.24507995446523,5.234630028406779,5.224200010299683,5.213789979616801,5.203409989674886,5.193040053049724,5.182700037956238,5.172370036443074,5.162069996198018,5.151790022850037,5.141529997189839,5.131290038426717,5.121069987614949,5.110870003700256,5.100690086682637,5.090529998143514,5.080399990081787,5.070279995600383,5.060179948806763,5.050110061963399,5.040050029754639,5.030019958813985,5.020000060399373,5.0100100835164385,5.000029961268107,4.990079959233602,4.980150103569031,4.970229943593343,4.9603400230407715,4.950460036595662,4.940609971682231,4.9307799736658735,4.920959989229838,4.91117000579834,4.901390035947164,4.8916399876276655,4.881899952888489,4.872189958890279,4.862490018208821,4.852820038795471,4.843160033226013,4.83351993560791,4.823899984359741,4.814299980799357,4.80472997824351,4.795169989267985,4.785630067189534,4.776099960009257,4.766599973042806,4.757119973500569,4.747659961382548,4.738209962844849,4.728790044784546,4.719379981358846,4.70999002456665,4.700620015462239,4.6912699937820435,4.681940038998921,4.672630071640015,4.663340012232463,4.654060085614522,4.6448100010554,4.635570049285889,4.626350045204163,4.617150108019511,4.6079699993133545,4.598809997240703,4.589660008748372,4.58053998152415,4.571429928143819,4.562340021133423,4.553270022074382,4.544220010439555,4.535180012385051,4.526170015335083,4.517169992129008,4.508190035820007,4.499229987462361,4.4902799526850385,4.4813599189122515,4.472449938456218,4.463560024897258,4.454690019289653,4.445839961369832,4.437000075976054,4.428179979324341,4.419379989306132,4.410599946975708,4.4018300374348955,4.393089969952901,4.384360035260518,4.375640034675598,4.366949995358785,4.358269969622294,4.349610090255737,4.340969999631246,4.332350055376689,4.323740005493164,4.315149982770284,4.306580026944478,4.298019965489705,4.289479970932007,4.280959963798523,4.272460023562114,4.2639700174331665,4.2554999987284345,4.247050007184346,4.238609949747722,4.23019007841746,4.2217899560928345,4.213409940401713,4.205040017763774,4.196690082550049,4.1883500417073565,4.180029988288879,4.171729962031047,4.163449962933858,4.155180056889852,4.146930019060771,4.138699968655904,4.13047997156779,4.12227996190389,4.114090045293172,4.105920076370239,4.097770015398662,4.089640021324158,4.081520001093547,4.07342000802358,4.065329988797505,4.057259996732076,4.049199978510539,4.041170001029968,4.03314991792043,4.025140047073364,4.017150004704793,4.009179989496867,4.001219987869263,3.993279993534088,3.985349973042806,3.9774399995803833,3.96954999367396,3.96167000134786,3.953809996445974,3.945959985256195,3.938129981358846,3.9303200244903564,3.922520021597544,3.914739986260732,3.9069700042406716,3.903090000152588};
    
    CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192209879557,514.5848439534506,508.81994374593097,504.2629114786784,499.6569112141927,495.0159149169922,490.35291798909503,485.6789093017578,481.00290934244794,476.3329086303711,471.67291768391925,467.0299123128255,462.4079132080078,457.8089141845703,453.2379150390625,448.6949183146159,444.1829147338867,439.7039159138997,435.2579116821289,430.846918741862,426.46991475423175,422.1299184163411,417.8249155680339,413.5569203694661,409.32591756184894,405.13192494710285,400.9749221801758,396.85492451985675,392.7719243367513,388.72692616780597,384.7179260253906,380.7459233601888,376.80992889404297,372.91092681884766,369.04793039957684,365.22193145751953,361.43092346191406,357.6759338378906,353.9559326171875,350.27193450927734,346.6229298909505,343.0089340209961,339.4289372762044,335.8839340209961,332.37293752034503,328.8959325154622,325.4519348144531,322.0419387817383,318.66493733723956,315.32093811035156,312.0089391072591,308.72994232177734,305.48394266764325,302.26894124348956,299.08594512939453,295.93394724527997,292.8129475911458,289.7229410807292,286.6639455159505,283.63594309488934,280.6369400024414,277.668950398763,274.7299448649089,271.81994374593097,268.939946492513,266.08894602457684,263.26694742838544,260.4729461669922,257.7069447835286,254.96994654337564,252.25995254516602,249.57794952392578,246.9239501953125,244.29595057169595,241.69595082600912,239.121950785319,236.5749537150065,234.05295181274414,231.55795415242514,229.0889549255371,226.64595413208008,224.22695668538412,221.83395767211914,219.46595764160156,217.12295786539713,214.803955078125,212.50895818074545,210.23895899454752,207.99295934041342,205.76995849609375,203.56995900472006,201.3939577738444,199.23996098836264,197.1089604695638,194.99996058146158,192.912961324056,190.84796015421549,188.80496088663736,186.78296407063803,184.78296279907227,182.80296198527017,180.84496307373047,178.9069620768229,176.9889653523763,175.0919647216797,173.2149658203125,171.35696665445963,169.51896540323892,167.70096715291342,165.9019686381022,164.12096532185873,162.35996882120767,160.6169687906901,158.8919677734375,157.18596903483072,155.4979680379232,153.82697041829428,152.1749699910482,150.53997039794922,148.92196909586588,147.32097498575845,145.73696899414062,144.17097091674805,142.6199722290039,141.0859718322754,139.568972269694,138.06697463989258,136.58197148640951,135.11197408040366,133.6579704284668,132.2189712524414,130.7959747314453,129.3869743347168,127.99397404988606,126.61597379048665,125.25197410583496,123.90297571818034,122.5679759979248,121.24697621663411,119.93997637430827,118.64797528584798,117.3689759572347,116.1029764811198,114.85197639465332,113.61297671000163,112.38797696431477,111.17597834269206,109.97697766621907,108.78997866312663,107.61697832743327,106.45597902933757,105.30697758992513,104.16997909545898,103.04597854614258,101.93397903442383,100.8339786529541,99.74507904052734,98.66818046569824,97.60278065999348,96.54887962341309,95.50628089904785,94.47488149007161,93.45448048909505,92.44508171081543,91.44648170471191,90.45858192443848,89.48138173421223,88.51458231608073,87.55828221638997,86.61218070983887,85.67628288269043,84.75038401285808,83.83448282877605,82.92848269144694,82.03218332926433,81.14558347066243,80.26848411560059,79.40078417460124,78.54248364766438,77.69348335266113,76.85358428955078,76.02268473307292,75.20078659057617,74.38778432210286,73.58348592122395,72.78788503011067,72.00088564554851,71.22238540649414,70.45228513081868,69.6904862721761,68.93698565165202,68.19148699442546,67.45418612162273,66.72478675842285,66.00318654378255,65.28948656717937,64.58348655700684,63.88508733113607,63.19428730010986,62.510987281799316,61.8349879582723,61.16638787587484,60.504987716674805,59.850687980651855,59.2035878499349,58.563387870788574,57.93018786112467,57.30388832092285,56.6842877070109,56.071388244628906,55.46518898010254,54.8655891418457,54.27238845825195,53.685688972473145,53.10538864135742,52.531289418538414,51.9634895324707,51.40178934733073,50.846190452575684,50.296689669291176,49.753089904785156,49.21538988749186,48.68349011739095,48.1574904123942,47.63709100087484,47.12239042917887,46.61329046885172,46.109691301981606,45.61159070332845,45.11889108022054,44.631491343180336,44.14949099222819,43.67259089152018,43.200990994771324,42.73449103037516,42.27309195200602,41.81659094492594,41.36519209543864,40.918691635131836,40.47699165344238,40.04009246826172,39.607991536458336,39.18059221903483,38.75789260864258,38.33969211578369,37.926093101501465,37.51699288686117,37.11239242553711,36.71209176381429,36.316192944844566,35.92459265391032,35.53719266255697,35.15409278869629,34.77509276072184,34.400193214416504,34.02939319610596,33.66259320576986,33.29979260762533,32.94089412689209,32.585893630981445,32.23479334513346,31.8874937693278,31.543893814086914,31.20399347941081,30.86789385477702,30.535393873850506,30.206393877665203,29.881094137827557,29.559193929036457,29.240894317626953,28.925994237263996,28.614494164784748,28.30639425913493,28.00159438451131,27.7000945409139,27.401894410451252,27.106794675191242,26.81499433517456,26.526394685109455,26.24079465866089,25.95839484532674,25.67899497350057,25.402595202128094,25.129295031229656,24.858794689178467,24.591294765472412,24.32669512430827,24.064995129903156,23.806095123291016,23.5498948097229,23.296595096588135,23.045995235443115,22.79799524943034,22.55279541015625,22.310195604960125,22.070295492808025,21.832895755767822,21.598095734914143,21.365795771280926,21.13609568277995,20.908795833587646,20.683995723724365,20.461595853169758,20.24159590403239,20.023996035257976,19.808696269989014,19.595695972442627,19.385095914204914,19.176695982615154,18.970595995585125,18.766696294148762,18.564996242523193,18.36549647649129,18.168096383412678,17.97279628117879,17.779696623484295,17.58859618504842,17.399696350097656,17.212696711222332,17.027796586354572,16.844796816507976,16.663896719614666,16.484796682993572,16.307796796162922,16.132596492767334,15.959296544392904,15.787896951039633,15.61829686164856,15.450596888860067,15.284596999486288,15.120496988296509,14.958096981048584,14.797496954600016,14.638597091039022,14.481396993001303,14.325896978378296,14.172097126642862,14.019997199376425,13.869397242863974,13.720497131347656,13.573297262191772,13.427597284317017,13.283397356669107,13.14079737663269,12.999797503153482,12.860297282536825,12.722297430038452,12.585697491963705,12.450697501500448,12.317097663879395,12.184897581736246,12.054097414016724,11.924797614415487,11.796897570292154,11.670297702153524,11.545097589492798,11.421197652816772,11.298697789510092,11.177497784296671,11.057597796122232,10.938997824986776,10.82169771194458,10.705597798029581,10.590797980626425,10.477197885513306,10.364797830581665,10.253697872161865,10.1436980565389,10.034898042678833,9.927327950795492,9.820878187815348,9.715577999750773,9.611418008804321,9.508368174235025,9.406428098678589,9.305588006973267,9.205838123957315,9.107148170471191,9.009528239568075,8.912958224614462,8.81742819150289,8.722918272018433,8.629428148269653,8.536948204040527,8.445458253224691,8.354948361714682,8.265418450037638,8.176848411560059,8.089228391647339,8.00255835056305,7.9168083270390825,7.831988414128621,7.748078465461731,7.66506842772166,7.582958499590556,7.501718560854594,7.4213584661483765,7.34186855951945,7.263218522071838,7.185428539911906,7.108468572298686,7.032328565915425,6.957018693288167,6.882508595784505,6.808808604876201,6.735888640085856,6.663758635520935,6.592408696810405,6.52181871732076,6.451988736788432,6.382908741633098,6.314568797747294,6.246958772341411,6.180078744888306,6.113918741544087,6.048478762308757,5.983728885650635,5.919678807258606,5.8563187917073565,5.793628811836243,5.731618841489156,5.670278827349345,5.6095889409383135,5.549558957417806,5.490168929100037,5.431418935457866,5.37329888343811,5.315798918406169,5.25891896088918,5.202648997306824,5.1469889879226685,5.09191898504893,5.037439028422038,4.983548919359843,4.930238962173462,4.877498944600423,4.825319091478984,4.7737090190251665,4.722639123598735,4.672129074732463,4.622159083684285,4.572719057401021,4.523819049199422,4.475439071655273,4.427569150924683,4.380229036013286,4.333389123280843,4.2870490948359175,4.241209149360657,4.19585919380188,4.1509891748428345,4.106609145800273,4.062709132830302,4.019269148508708,3.976299206415812,3.9337892532348633,3.8917392094930015,3.8501392205556235,3.8089892665545144,3.7682692209879556,3.7279892762502036,3.6881492336591086,3.6487292448679605,3.609729250272115,3.5711492896080017,3.532989283402761,3.495229264100393,3.4578793048858643,3.4209293325742087,3.3843793074289956,3.348209321498871,3.3124393423398337,3.2770493427912393,3.242029368877411,3.207399368286133,3.173129379749298,3.1392293771107993,3.105699360370636,3.072519381841024,3.039699375629425,3.0072293877601624,2.9751093784968057,2.943329373995463,2.9118894139925637,2.8807897766431174,2.8653196891148887};
    
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.924455324808754,40.0504789352417,40.463297843933105,38.15205796559652,39.96598211924235,41.81497351328532,43.669609705607094,44.340972900390625,43.69656213124593,42.93773873647054,42.17096710205078,41.40322621663412,40.635425885518394,39.86764780680338,39.09989579518636,38.332204818725586,37.564175605773926,36.83346207936605,36.144012769063316,35.45814768473307,34.77253023783366,34.086945215861,33.401318073272705,32.71587642033895,32.030145009358726,31.344854195912678,30.65860939025879,30.09734853108724,29.67474635442098,29.264404296875,28.854838371276855,28.445366382598877,28.035938103993733,27.626497109731037,27.216943899790447,26.807860215504963,26.397313594818115,26.191075801849365,26.211204528808594,26.251752535502117,26.29319667816162,26.335055669148762,26.37683169047038,26.41864236195882,26.460339069366455,26.502137660980225,26.54394229253133,26.584761142730713,26.624469598134358,26.664067268371582,26.70366859436035,26.743267218271892,26.782966295878094,26.822569211324055,26.86216402053833,26.9017817179362,26.941315333048504,26.995335896809895,27.065516312917072,27.137154420216877,27.208733399709065,27.28044335047404,27.352137565612793,27.423842589060467,27.49543571472168,27.56716299057007,27.63873052597046,27.74347178141276,27.885205268859863,28.0301996866862,28.1753347714742,28.320673783620197,28.465850671132404,28.611064434051514,28.75626262029012,28.901516278584797,29.047008355458576,29.107361952463787,29.07300090789795,29.030068238576252,28.986850420633953,28.943318367004395,28.90001630783081,28.856542110443115,28.81320110956828,28.769700686136883,28.726520856221516,28.637986342112224,28.498716513315838,28.355112234751385,28.211214383443195,28.067315578460693,27.9234135945638,27.779516379038494,27.6355144182841,27.491615136464436,27.347713629404705,27.203816413879395,27.059814929962158,26.91591501235962,26.772014141082764,26.62811581293742,26.484115918477375,26.340213616689045,26.196316401163738,26.05231539408366,25.9084153175354,25.764514287312824,25.62061595916748,25.47661542892456,25.33271551132202,25.18881432215373,25.044916311899822,24.900915781656902,24.757015228271484,24.613114674886067,24.469216187795002,24.325215816497803,24.18131430943807,24.037416299184162,23.893415927886963,23.749515215555828,23.60561513900757,23.461716334025066,23.317715962727863,23.17381525039673,23.02991485595703,22.886016368865967,22.742016156514484,22.59811528523763,22.454215208689373,22.31031592686971,22.16631619135539,22.022414684295654,21.878516515096027,21.734515984853108,21.590615113576252,21.446715354919434,21.30281639099121,21.15881649653117,21.014915307362873,20.871015071868896,20.727116584777832,20.583116849263508,20.439215024312336,20.295316696166992,20.15131680170695,20.007415294647217,19.8635155359904,19.719616731007893,19.57561683654785,19.431715329488117,19.287816047668457,19.143916606903076,18.999917189280193,18.85601536432902,18.712116082509358,18.56821648279826,18.424217383066814,18.280314922332764,18.136416753133137,17.992417335510254,17.84851574897766,17.70461622873942,17.560716311136883,17.416717290878296,17.272815227508545,17.128916422526043,16.98501642545064,16.841017961502075,16.697115500768025,16.553216854731243,16.409316539764404,16.265318314234417,16.121415217717487,15.977517445882162,15.833517471949259,15.689615646998087,15.545716921488443,15.401816606521606,15.257818142573038,15.113914966583252,14.970017512639364,14.82611600557963,14.682118892669678,14.538214921951294,14.39431897799174,14.250316143035889,14.106417576471964,13.962515354156494,13.818618615468344,13.67461665471395,13.530717452367147,13.386815627415976,13.242918491363525,13.098916927973429,12.95501701037089,12.811116139094034,12.66721804936727,12.523217837015787,12.379315932591757,12.235418637593588,12.09141731262207,11.947517474492392,11.803616205851236,11.65971851348877,11.515717347462973,11.371817191441854,11.227916479110718,11.084018230438232,10.94001809755961,10.796116352081299,10.652218500773111,10.508217891057333,10.364317099253336,10.220417022705078,10.076517661412558,9.932557900746664,9.788627465566,9.644707600275675,9.50077772140503,9.356847604115805,9.21292773882548,9.068997859954834,8.925067663192749,8.781147877375284,8.63721787929535,8.493287881215414,8.34936773777008,8.205438335736593,8.061507225036621,7.9175896644592285,7.773653109868367,7.629740953445435,7.485772609710693,7.341975291570027,7.19767959912618,7.118584911028544,7.1116943359375,7.111275275548299,7.111185232798259,7.111204465230306,7.111196716626485,7.111199855804443,7.111198504765828,7.111199140548706,7.1111988226572675,7.111198941866557,7.111198941866557,7.111198941866557,7.1111988226572675,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.667385617891948,6.884202678998311,6.587661902109782,6.592206875483195,6.597232540448506,6.602039774258931,6.606398582458496,6.610019326210022,6.612889210383098,6.615399400393168,6.617649396260579,6.619699438412984,6.621559580167134,6.623249491055806,6.624789595603943,6.62619952360789,6.627419948577881,6.6272908846537275,6.625340819358826,6.622480948766072,6.619030912717183,6.615111072858174,6.610771099726359,6.606061021486918,6.601011236508687,6.595640858014424,6.590001503626506,6.582892378171285,6.573932250340779,6.564152240753174,6.553892215092977,6.543252269426982,6.532302260398865,6.521072030067444,6.5095824003219604,6.497851252555847,6.4859243631362915,6.467778007189433,6.441687226295471,6.413227041562398,6.383986671765645,6.354426463445027,6.324686090151469,6.2948358456293745,6.264865358670552,6.23481551806132,6.20470376809438,6.177321712176005,6.1535515785217285,6.130941271781921,6.108811020851135,6.086950659751892,6.065290331840515,6.04381004969279,6.022499918937683,6.001338879267375,5.98034143447876,5.953704595565796,5.91978391011556,5.883933385213216,5.847622950871785,5.811272382736206,5.775001962979634,5.7388414939244585,5.7028108437856035,5.666891256968181,5.6310966809590655,5.604650656382243,5.590150753657023,5.579120794932048,5.569210569063823,5.559770425160726,5.5506203174591064,5.541690230369568,5.532969991366069,5.52442987759908,5.5160893201828,5.50903848807017,5.503578424453735,5.498678366343181,5.494038263956706,5.489558219909668,5.485228061676025,5.481027960777283,5.47695791721344,5.472997943560283,5.469137827555339,5.465427716573079,5.461797714233398,5.458157658576965,5.454477667808533,5.450747569402059,5.446967601776123,5.443147619565328,5.439287543296814,5.435377478599548,5.431447466214498,5.427477399508159,5.4234773715337115,5.419447461764018,5.415387392044067,5.411307295163472,5.407207290331523,5.403077284495036,5.398937225341797,5.394777258237203,5.3905971844991045,5.386407097180684,5.382197101910909,5.377987066904704,5.373757044474284,5.36950699488322,5.3652669588724775,5.36100693543752,5.356736858685811,5.352466861406962,5.348176717758179,5.343886812527974,5.339596748352051,5.335296670595805,5.330996712048848,5.32668662071228,5.322376569112142,5.318066517512004,5.313746531804402,5.30941637357076,5.305096467336019,5.300766388575236,5.296436429023743,5.2921063502629595,5.287776271502177,5.2834462722142534,5.279106259346008,5.274766167004903,5.270426114400228,5.266086101531982,5.2617461284001665,5.257405996322632,5.253056009610494,5.248715877532959,5.244365851084392,5.2400258382161455,5.2356858253479,5.231345733006795,5.227015733718872,5.222675681114197,5.218355655670166,5.214025537172954,5.209705551465352,5.205385446548462,5.201065500577291,5.1967553695042925,5.192435383796692,5.1881353457768755,5.183825254440308,5.179525216420491,5.175225218137105,5.170935193697612,5.166635115941365,5.162345091501872,5.1580650806427,5.153774976730347,5.149495005607605,5.145215034484863,5.140934944152832,5.136664907137553,5.132394949595134,5.1281247933705645,5.123854796091716,5.119594732920329,5.115324695905049,5.111064592997233,5.106804609298706,5.102554559707642,5.098294496536255,5.094044486681621,5.089784383773804,5.085534373919169,5.081284364064534,5.077044328053792,5.072794278462728,5.068544228871663,5.064304232597351,5.060054183006287,5.055814107259114,5.051574071248372,5.047324061393738,5.043083945910136,5.038843949635823,5.034603953361511,5.030363917350769,5.026123881340027,5.021873752276103,5.01763379573822,5.013393759727478,5.009153763453166,5.004913687705994,5.000673611958821,4.99643353621165,4.992183526357015,4.98793351650238,4.983693520228068,4.979443430900574,4.975203434626262,4.970953305562337,4.966703295707703,4.962453285853068,4.958203196525574,4.953943133354187,4.94968314965566,4.945433100064595,4.9411730368932085,4.9369131326675415,4.932643016179402,4.928382992744446,4.924112836519877,4.919842878977458,4.915562868118286,4.911292791366577,4.9070128202438354,4.902732729911804,4.898452639579773,4.894162654876709,4.889872590700786,4.885582605997722,4.881282528241475,4.876982569694519,4.872672359148662,4.868372440338135,4.864052375157674,4.859742482503255,4.8554917971293134,4.852421124776204,4.850771069526672,4.8495010534922285,4.848321080207825,4.847180803616841,4.846540530522664,4.84652058283488,4.846660494804382,4.846860567728679,4.847070574760437,4.847290595372518,4.847520510355632,4.847750544548035,4.847980499267578,4.848200559616089,4.8484305540720625,4.8486606280008955,4.848890542984009,4.849110563596089,4.849330544471741,4.849560538927714,4.849770545959473,4.849990566571553,4.850210547447205,4.850420554478963,4.850630521774292,4.85084052880605,4.851050496101379,4.851250529289246,4.851460576057434,4.85166056950887,4.851860523223877,4.852050542831421,4.852250417073567,4.852440516153972,4.852630535761516,4.852820475896199,4.853010535240173,4.853200554847717,4.853390534718831,4.853570540746053,4.853750507036845,4.853930513064067,4.8541105190912885,4.8542905648549395,4.854470570882161,4.854640523592631,4.854820489883423,4.854990601539612,4.855160474777222,4.855330506960551,4.855500499407451,4.85567061106364,4.855840524037679,4.856000542640686,4.856170574824016,4.856330553690593,4.856500546137492,4.856660564740499,4.856820623079936,4.856980641682942,4.85714050134023,4.8573005596796675,4.857460538546245,4.857620596885681,4.857770562171936,4.857930580774943,4.858080546061198,4.858240485191345,4.85839056968689,4.8585405349731445,4.858700513839722,4.858850479125977,4.859000563621521,4.859150568644206,4.859300533930461,4.859450538953145,4.859600464502971,4.8597506284713745,4.859890500704448,4.860040545463562,4.860190550486247,4.8603304624557495,4.860480586687724,4.860620617866516,4.860760529836019,4.8609104951222735,4.861050566037496,4.861190557479858,4.861340562502543,4.861480553944905,4.861620585123698,4.86176057656606,4.8619004885355634,4.862040638923645,4.862180590629578,4.86232058207194,4.862460494041443,4.862600604693095,4.862730622291565,4.862870573997498,4.86301056543986,4.863140503565471,4.863280653953552,4.8634205261866255,4.863550543785095,4.863690535227458,4.863820552825928,4.86396062374115,4.86409056186676,4.86422061920166,4.864360531171163,4.8644905885060625,4.864620645840962,4.8647604783376055,4.8648905754089355,4.865020593007405,4.865150531133016,4.865280628204346,4.865410606066386,4.865540623664856,4.865670522054036,4.865800658861796,4.865930517514546,4.8660606145858765,4.866190592447917,4.866320689519246,4.866450548171997,4.866580645243327,4.8667105833689375,4.866840600967407,4.8669605652491255,4.867090503374736,4.867220560709636,4.867350538571675,4.867470582326253,4.867600599924724,4.867730577786763,4.867850581804912,4.867980480194092,4.868100603421529,4.868230581283569,4.868350466092427,4.8684806029001875,4.868600567181905,4.8687305847803755,4.868850588798523,4.868980606396993,4.869100570678711,4.869230588277181,4.869350552558899,4.869470516840617,4.869600574175517,4.869720617930095,4.869840582211812,4.86996054649353,4.87009060382843,4.870210607846578,4.870330611864726,4.870450536410014,4.870580514272054,4.870700518290202,4.87082056204478,4.870940566062927,4.871060570081075,4.871190627415975,4.871310551961263,4.8714306354522705,4.871550559997559,4.871670564015706,4.8717905680338545,4.871910611788432,4.87203053633372,4.872150540351868,4.8722706238428755,4.872390588124593,4.872510592142741,4.872630596160889,4.872750520706177,4.8728706041971845,4.872990449269612,4.87311053276062,4.873230576515198,4.873340566953023,4.873460610707601,4.873580574989319,4.873700539271037,4.8738105694452925,4.87393061319987,4.874050617218018,4.874160607655843,4.874280492464702,4.874400536219279,4.874510566393535,4.874630610148112,4.874740521113078,4.874860604604085,4.874980489412944,4.875090519587199,4.875210563341777,4.875320553779602,4.875430544217427,4.875550548235576,4.87566061814626,4.8757805824279785,4.875890612602234,4.876000603040059,4.876120567321777,4.876230597496033,4.876340587933858,4.876460591952006,4.8765705823898315,4.8766805330912275,4.876790563265483,4.876900553703308,4.877020597457886,4.877130627632141,4.877240538597107,4.877350529034932,4.8774605592091875,4.877570589383443,4.877680540084839,4.877790570259094,4.8779005606969195,4.878010670344035,4.878120581309001,4.878230611483256,4.878340562184651,4.878450592358907,4.878560582796733,4.878670533498128,4.8787806034088135,4.878890514373779,4.879000544548035,4.87911053498586,4.879220565160115,4.879320581754048,4.879430532455444,4.8795405626297,4.879650553067525,4.879760543505351,4.879860560099284,4.8799705902735395,4.880080540974935,4.880180597305298,4.880290548006694,4.8804006179173784,4.880500515302022,4.8806105852127075,4.880720575650533,4.880820631980896,4.880930582682292,4.881030599276225,4.881090680758159};
    
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219188809394836,2.6039251486460366,2.036679267883301,1.6561220089594524,1.3474896450837452,1.0966252932945888,0.8928839216629664,0.7271318435668945,0.5922794391711553,0.4824977194269498,0.39312732468048733,0.3203510915239652,0.2610804575184981,0.2128000110387802,0.17346721390883127,0.14141720905900002,0.11530036230882008,0.0940207423021396,0.07669228067000707,0.0625671533246835,0.05106140331675609,0.04167018923908472,0.034022477765878044,0.02777074712018172,0.022682186371336382,0.01851749901349346,0.015127854033683738,0.012352086914082369,0.01009009669845303,0.008238396568534275,0.006727890305531521,0.005492581753060222,0.00448409141972661,0.003659953324434658,0.0029869243735447526,0.0024371862915965417,0.0019882723960715034,0.0016216729224349062,0.0013223049851755302,0.0010778902311964582,0.0008783939944502587,0.0007155849161790684,0.000582793383121801,0.0004744495987930956,0.00038617152070704225,0.00031414103189793724,0.0002555382913366581,0.00020770705911369683,0.00016886072504955033,0.00013715456589125097,0.0001114336682803696,2.555816414921234e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8469696044922,563.0193583170573,558.0248311360677,559.9354756673177,560.9950205485026,561.7300872802734,562.3235321044922,562.7938944498698,563.1521148681641,563.4582163492838,563.7322998046875,563.9823608398438,564.2114308675131,564.4204661051432,564.6145222981771,564.7915395100912,564.9506683349609,565.0320027669271,565.0032704671224,564.8994496663412,564.7366231282552,564.5217539469401,564.2618764241537,563.9609883626302,563.6221211751302,563.2491556803385,562.8443857828776,562.2989807128906,561.5693817138672,560.7495320638021,559.8746846516927,558.956797281901,558.0028991699219,557.0179646809896,556.0041249593099,554.9639790852865,553.9026540120443,552.3388315836588,550.1151326497396,547.6623687744141,545.1245727539062,542.5486195882162,539.9516754150391,537.3397165934244,534.7167205810547,532.0838216145834,529.4435831705729,527.0166168212891,524.8860117594401,522.8668772379557,520.8977508544922,518.9596913655599,517.0446217854818,515.1495590209961,513.2725423177084,511.4133580525716,509.57083384195965,507.27686818440753,504.3760732014974,501.2891337076823,498.15228271484375,495.00822194417316,491.87221272786456,488.7471745808919,485.6341069539388,482.53521219889325,479.449457804362,477.0971501668294,475.7181752522786,474.66401926676434,473.7285970052083,472.8476206461589,471.9994532267253,471.17743428548175,470.3773371378581,469.59930928548175,468.8411636352539,468.18971252441406,467.6724217732747,467.20837656656903,466.77227783203125,466.354248046875,465.9531885782878,465.56617228190106,465.1921157836914,464.8310852050781,464.4820505777995,464.1479949951172,463.82698313395184,463.50499725341797,463.1780090332031,462.8470204671224,462.5110397338867,462.17005157470703,461.82506052652997,461.4750747680664,461.12208302815753,460.7651011149089,460.4041061401367,460.0411148071289,459.6741231282552,459.3051300048828,458.9341405232747,458.5601450602214,458.1841506958008,457.80615997314453,457.42615509033203,457.04516347249347,456.6621627807617,456.27917226155597,455.89317830403644,455.5071767171224,455.11918385823566,454.7311833699544,454.3421910603841,453.95118459065753,453.56119028727215,453.169189453125,452.7771987915039,452.3841959635417,451.99119059244794,451.5971984863281,451.20320383707684,450.80920155843097,450.41420491536456,450.01919809977215,449.6242039998372,449.22820536295575,448.8322016398112,448.4362030029297,448.04020436604816,447.64420318603516,447.24720764160156,446.85020701090497,446.4532063802083,446.0562006632487,445.6592076619466,445.26220957438153,444.8652089436849,444.46720631917316,444.07020568847656,443.67320251464844,443.2762095133464,442.8792088826497,442.4832026163737,442.0872039794922,441.6922073364258,441.29620361328125,440.90120188395184,440.5071970621745,440.1122080485026,439.7181930541992,439.32519785563153,438.93119557698566,438.53919219970703,438.1461944580078,437.75418345133465,437.36219278971356,436.9701894124349,436.5791829427083,436.18818918863934,435.7971928914388,435.40718332926434,435.0171864827474,434.62718454996747,434.2381820678711,433.84918212890625,433.4601821899414,433.07118733723956,432.6821797688802,432.29417673746747,431.9061787923177,431.51818084716797,431.1311747233073,430.7441813151042,430.3561833699544,429.96917215983075,429.5821787516276,429.1961720784505,428.8091761271159,428.4231694539388,428.0371780395508,427.6511713663737,427.2651774088542,426.87917073567706,426.49317677815753,426.107172648112,425.72118123372394,425.33516693115234,424.9501775105794,424.56416575113934,424.1791814168294,423.79316965738934,423.4081751505534,423.0221684773763,422.63717397054035,422.2511749267578,421.86517333984375,421.4801762898763,421.09417724609375,420.70817311604816,420.3221740722656,419.93617248535156,419.55017344156903,419.16417185465497,418.7781804402669,418.39117431640625,418.0051752726237,417.6181818644206,417.2311757405599,416.8441747029622,416.4571762084961,416.0691782633464,415.6821746826172,415.29417673746747,414.9061813354492,414.51817830403644,414.12918345133465,413.7401809692383,413.35118865966797,412.9621887207031,412.57218678792316,412.1821823120117,411.7921854654948,411.4011866251628,411.0101903279622,410.6191914876302,410.22718556722003,409.83519490559894,409.4431788126628,409.05022684733075,408.66305287679035,408.3965428670247,408.27827707926434,408.20423634847003,408.14221954345703,408.08617401123047,408.05806732177734,408.06300099690753,408.0799865722656,408.1009775797526,408.12298075358075,408.1459706624349,408.1699727376302,408.19397735595703,408.2179768880208,408.24197642008465,408.2649739583333,408.28897349039715,408.31297302246094,408.33697509765625,408.35997772216797,408.38297271728516,408.40597279866535,408.42897542317706,408.4519780476888,408.4739812215169,408.49597930908203,408.51798248291016,408.53998311360675,408.5619812011719,408.5829823811849,408.6039810180664,408.62497965494794,408.64598337809247,408.66697947184247,408.6869888305664,408.70698801676434,408.7269922892253,408.74698130289715,408.7669855753581,408.7859878540039,408.80498758951825,408.8249867757161,408.843989054362,408.8629887898763,408.88099161783856,408.8999888102214,408.91798909505206,408.9369862874349,408.95499420166016,408.9729919433594,408.9909947713216,409.0089925130208,409.02699279785156,409.0439961751302,409.0619888305664,409.07899983723956,409.09599049886066,409.1139958699544,409.13099670410156,409.1479975382487,409.1649907430013,409.18199920654297,409.19799041748047,409.21499888102215,409.2309977213542,409.2480010986328,409.2639923095703,409.28099822998047,409.29699961344403,409.31300099690753,409.3289972941081,409.3449961344401,409.36100006103516,409.3769938151042,409.3929977416992,409.40899658203125,409.4239959716797,409.4399922688802,409.4560038248698,409.4709981282552,409.4870020548503,409.5020014444987,409.5169982910156,409.5329945882161,409.5480016072591,409.56300099690753,409.57799530029297,409.59299723307294,409.60799916585285,409.6229960123698,409.6380030314128,409.6529998779297,409.6679941813151,409.6830012003581,409.6969985961914,409.71199798583984,409.7270024617513,409.74100494384766,409.7560043334961,409.7700017293294,409.7849985758464,409.7990010579427,409.81400299072266,409.8280029296875,409.84200286865234,409.8560028076172,409.8709996541341,409.88500213623047,409.8990020751953,409.9130045572917,409.927001953125,409.9410044352214,409.9550069173177,409.96900431315106,409.9830067952474,409.99700419108075,410.01100158691406,410.0249989827474,410.0390040079753,410.0530039469401,410.06600189208984,410.0800018310547,410.09400177001953,410.1080067952474,410.1210021972656,410.13500722249347,410.14801025390625,410.16200764973956,410.17500559488934,410.18899790445965,410.20200602213544,410.21600341796875,410.22900644938153,410.24299875895184,410.2560068766276,410.27000681559247,410.2830123901367,410.29600524902344,410.30900319417316,410.32300567626953,410.3360087076823,410.3490041097005,410.3620096842448,410.3760019938151,410.3890075683594,410.4020004272461,410.4150085449219,410.4280039469401,410.4410044352214,410.4540049235026,410.4670054117839,410.4800033569336,410.4930063883464,410.50600179036456,410.5190073649089,410.5320078531901,410.5449981689453,410.5580062866211,410.57100677490234,410.5840098063151,410.59700266520184,410.61000569661456,410.6220067342122,410.635004679362,410.64800516764325,410.6610056559245,410.6740086873372,410.6860046386719,410.6990051269531,410.71199798583984,410.7250111897786,410.73700459798175,410.75000762939453,410.7630081176758,410.77500406901044,410.7880045572917,410.80101013183594,410.81300354003906,410.8260091145833,410.83800252278644,410.85100809733075,410.8630091349284,410.87600962320965,410.88800557454425,410.90100860595703,410.9130147298177,410.92501068115234,410.93800862630206,410.95001220703125,410.9630076090495,410.9750111897786,410.9870122273763,410.99901072184247,411.0120086669922,411.0240071614583,411.0360107421875,411.0480092366536,411.0600102742513,411.07200113932294,411.0850067138672,411.0970102945964,411.10900624593097,411.12100474039715,411.1330108642578,411.14500935872394,411.1570053100586,411.1690088907878,411.1810073852539,411.19300842285156,411.2050094604492,411.2160135904948,411.22801208496094,411.24001057942706,411.2520065307617,411.26400502522785,411.27601114908856,411.2870051066081,411.2990086873372,411.3110097249349,411.32301076253253,411.3340148925781,411.3460006713867,411.35801696777344,411.36901092529297,411.3810068766276,411.39201100667316,411.40400950113934,411.416010538737,411.42700958251953,411.4390055338542,411.4500096638997,411.4620056152344,411.47301228841144,411.48500569661456,411.4960123697917,411.5080057779948,411.5190200805664,411.5300114949544,411.54201253255206,411.5530064900716,411.5640106201172,411.5760091145833,411.5870107014974,411.5980046590169,411.6100082397461,411.62101491292316,411.6320037841797,411.6430079142253,411.65500895182294,411.66601816813153,411.67700958251953,411.6880137125651,411.69901275634766,411.7050298055013};
    
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.438020785649618,9.76319154103597,10.082878192265829,9.161208391189575,9.149718602498373,9.143699963887533,9.137394984563192,9.133248011271158,9.131289879480997,9.129511197408041,9.127750953038534,9.125990708669027,9.124231259028116,9.122470458348593,9.120712200800577,9.118948539098104,9.11718463897705,9.107065121332804,9.087830305099487,9.067838191986084,9.047789017359415,9.027738571166992,9.007678747177124,8.987618605295816,8.96756879488627,8.947508255640665,8.927459319432577,8.905834992726644,8.882508039474487,8.859037637710571,8.835557619730631,8.81206750869751,8.78858749071757,8.765106995900473,8.741628805796305,8.718134244283041,8.6946648756663,8.65245262781779,8.589850266774496,8.52554178237915,8.461105505625406,8.39665404955546,8.332204500834147,8.267754435539246,8.203303972880045,8.138855457305908,8.07439120610555,8.01887838045756,7.973070065180461,7.928084850311279,7.883162260055542,7.838243405024211,7.793322841326396,7.748402913411458,7.7034833033879595,7.65856146812439,7.613657553990682,7.551741321881612,7.471346100171407,7.389386057853699,7.307321826616923,7.225238680839539,7.143160303433736,7.061079502105713,6.978999416033427,6.8969210386276245,6.814832766850789,6.763354380925496,6.7451934814453125,6.729832251866658,6.714669426282247,6.699547330538432,6.684412320454915,6.669285535812378,6.654143412907918,6.639014879862468,6.623883287111918,6.612439115842183,6.6050117413202925,6.597914179166158,6.590842326482137,6.5837836265563965,6.5767126480738325,6.5696433782577515,6.562582770983378,6.555512984593709,6.548453092575073,6.541213830312093,6.533803939819336,6.526373942693074,6.51893397172292,6.511504054069519,6.504073858261108,6.496644020080566,6.4892040093739825,6.481774012247722,6.47434385617574,6.466914017995198,6.459473967552185,6.452043930689494,6.444613893826802,6.437183976173401,6.429743925730388,6.422313928604126,6.414883971214294,6.4074539343516035,6.400014003117879,6.392583847045898,6.385153889656067,6.377723932266235,6.370283921559651,6.362853924433391,6.3554238478342695,6.347993850708008,6.340553879737854,6.333123842875163,6.325693806012471,6.318253874778748,6.310823877652486,6.3033937613169355,6.295963803927104,6.288523872693379,6.281093756357829,6.273663719495137,6.266233762105306,6.258803764979045,6.25136383374532,6.2439338366190595,6.236503799756368,6.229073723157247,6.221633791923523,6.214203755060832,6.20677371819814,6.199343800544739,6.191903710365295,6.184473792711894,6.177043716112773,6.169603745142619,6.162173748016357,6.1547437111536665,6.147313714027405,6.139873743057251,6.132443745930989,6.125013709068298,6.117583711942037,6.110143701235454,6.102713664372762,6.09528374671936,6.087853709856669,6.0804136991500854,6.072983622550964,6.065553704897563,6.058123668034871,6.050683697064717,6.043253660202026,6.035823623339335,6.028393665949504,6.020953734715779,6.013523618380229,6.006093700726827,5.998663624127706,5.991223653157552,5.983793616294861,5.976363619168599,5.968933622042338,5.9614936510721845,5.954063534736633,5.946633577346802,5.93920361995697,5.931763609250386,5.924333532651265,5.916903575261434,5.909473538398743,5.902033567428589,5.894603570302327,5.887173573176066,5.8797435363133745,5.872303605079651,5.86487352848053,5.857443571090698,5.850013454755147,5.8425735632578535,5.835143526395162,5.827713489532471,5.820283492406209,5.812843481699626,5.805413484573364,5.797983447710673,5.790553530057271,5.783113479614258,5.775683442751567,5.768253405888875,5.760823488235474,5.75338339805603,5.745953480402629,5.738523443539937,5.731093446413676,5.723653356234233,5.716223438580831,5.708793481190999,5.701363444328308,5.693923393885295,5.686493396759033,5.6790633996327715,5.671633402506511,5.664193391799927,5.656763434410095,5.6493334372838335,5.641903360684712,5.634463389714559,5.627033352851868,5.619603315989177,5.612173438072205,5.604733387629191,5.5973033507664995,5.589873234430949,5.582443316777547,5.575003425280253,5.5675733884175616,5.5601433118184405,5.5527132749557495,5.545273343722026,5.537843267122905,5.530413309733073,5.5229833126068115,5.515543222427368,5.508113304773967,5.500683307647705,5.493253231048584,5.48581326007843,5.478383223215739,5.4709532260894775,5.4635231494903564,5.456083337465922,5.448652942975362,5.441223820050557,5.433791875839233,5.429749608039856,5.4294127225875854,5.429394205411275,5.429393569628398,5.429383913675944,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383834203084,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225354830423992,24.526807467142742,24.887507279713947,25.254507223765057,25.639607588450115,26.03780746459961,26.444907506306965,26.822307586669922,27.137307167053223,27.397807121276855,27.610507329305012,27.78150701522827,27.880606810251873,27.882206598917644,27.80130624771118,27.650806109110516,27.4420059521993,27.1528058052063,26.76480547587077,26.29480520884196,25.75750478108724,25.16600449879964,24.531304359436035,23.863404115041096,23.17070420583089,22.46070369084676,21.739703337351482,21.009803295135498,20.272802988688152,19.533603032430012,18.796502749125164,18.065102736155193,17.34250243504842,16.63120237986247,15.933502356211344,15.251102050145468,14.585301955540976,13.937201897303263,13.307501872380575,12.696701606114706,12.105501651763916,11.534301360448202,10.983201424280802,10.4522012869517,9.941461245218912,9.450671037038168,8.979641119639078,8.52812115351359,8.095821062723795,7.682370940844218,7.287330985069275,6.910230875015259,6.5505607922871905,6.207770784695943,5.881310701370239,5.570590694745381,5.275050640106201,4.993930657704671,4.7264905373255415,4.472240606943767,4.230640570322673,4.001200497150421,3.7834004561106362,3.5767604311307273,3.3807804187138877,3.195000390211741,3.018950363000234,2.852200369040171,2.694350302219391,2.5449703335762024,2.403670291105906,2.270050287246704,2.1437203089396157,2.0243202447891235,1.9115002353986104,1.8049102028210957,1.7042202254136403,1.6091302037239075,1.5193501710891724,1.4345701734224956,1.3545301755269368,1.2789801557858784,1.2076601485411327,1.1403501530488331,1.0768101414044697,1.0168501486380894,0.9624301294485728,0.914397140343984,0.871219128370285,0.8323631385962168,0.7973561336596807,0.7657781342665354,0.7372521311044693,0.7114451279242834,0.6880561312039694,0.6668231338262558,0.6475101312001547,0.6299061377843221,0.6138251274824142,0.5990991195042928,0.5855811287959417,0.573135127623876,0.5616471221049627,0.5510111252466837,0.5411351223786672,0.531935120622317,0.5233361124992371,0.5152741173903147,0.5076871166626612,0.500526120265325,0.493744117518266,0.4872991169492404,0.4811551148692767,0.47527911017338437,0.46964211016893387,0.46421510974566144,0.458978109061718,0.45391010741392773,0.44899410754442215,0.4442121038834254,0.43955010920763016,0.43499510486920673,0.43053410202264786,0.4261591037114461,0.42186110466718674,0.417631097137928,0.4134620974461238,0.4093471020460129,0.40528009583552677,0.4012591019272804,0.3972770969072978,0.3933320914705594,0.3894180928667386,0.3855340927839279,0.3816740959882736,0.37783809502919513,0.37402409315109253,0.37023008863131207,0.3664540921648343,0.3626940871278445,0.35895008593797684,0.3552170892556508,0.3514970913529396,0.34778908640146255,0.34409308433532715,0.3404070834318797,0.33673108120759326,0.33306408176819485,0.3294030850132306,0.32575108110904694,0.3221070816119512,0.318470078210036,0.3148410792152087,0.31121807793776196,0.30760207772254944,0.30399007598559064,0.3003840719660123,0.29678506900866825,0.2931910678744316,0.2896030719081561,0.28602106869220734,0.2824430664380391,0.27886906762917835,0.2753010739882787,0.27173706392447156,0.2681790664792061,0.26462506502866745,0.26107706626256305,0.25753306597471237,0.25399206082026166,0.2504550615946452,0.24692405884464583,0.24339705953995386,0.2398740549882253,0.2363570568462213,0.23284305507938066,0.22933205341299376,0.2258260523279508,0.22232405096292496,0.2188260518014431,0.21533305322130522,0.2118450477719307,0.2083600473900636,0.20487804959217706,0.2014000490307808,0.19792604570587477,0.1944570429623127,0.19099204490582147,0.1875320424636205,0.18407504136363664,0.1806210403641065,0.17717003946503004,0.17372404038906097,0.17028303816914558,0.1668450372914473,0.16341203699509302,0.15998303517699242,0.15655503422021866,0.15313203384478888,0.1497140328089396,0.14629903311530748,0.1428890290359656,0.13948002954324087,0.1360760306318601,0.1326760289569696,0.12928002700209618,0.1258890274912119,0.12250102559725444,0.11911802428464095,0.11573602445423603,0.11235902334252994,0.10898602132995923,0.1056170209000508,0.10225302105148633,0.09889202006161213,0.09553551860153675,0.09218091703951359,0.08883061632514,0.08548451587557793,0.08214261382818222,0.07880481394628684,0.07547121184567611,0.07214171253144741,0.06881411125262578,0.06549081020057201,0.06217170848200718,0.05885690823197365,0.055546307315429054,0.052239906353255115,0.04893770565589269,0.045637404546141624,0.042341603276630245,0.039053003303706646,0.03577340176949898,0.032501301262527704,0.02923540010427435,0.0259744996825854,0.022907300076136988,0.020202499969551962,0.017817200161516666,0.01571369986049831,0.013858700015892586,0.012222800015782317,0.010780200051764647,0.009507920049751798,0.008385900097588697,0.007396379990192751,0.006523689992415409,0.005754039972089231,0.005075239964450399,0.004476569981003801,0.003948569996282458,0.0034828700008802116,0.0030721400010709963,0.002709869993850589,0.002390350001708915,0.002108530005595336,0.001859949998712788,0.0016406899958383292,0.0014472999998057883,0.0012767100027607132,0.0011262400075793266,0.0009935199923347682,0.0008764450079373395,0.0007731739945787316,0.0006820770019354919,0.0006017199921188876,0.00053083499854741,0.00046830400242470205,0.0004131440073251724,0.0003644839962362312,0.00032155799999600276,0.00028368999968127656,0.0002502840009886616,0.00022081400068903653,0.00019481499960723644,0.00017187900084536523,0.00015164500049043758,0.00013379399873277484,0.00011804500051463644,8.768540222566419e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050124168395996,22.259799162546795,22.131099383036297,22.135399341583252,22.11329936981201,22.069499333699543,22.008199373881023,21.914899349212646,21.77769947052002,21.604999383290608,21.403999487559002,21.180699666341145,20.919599533081055,20.608099301656086,20.25649944941203,19.87399959564209,19.468299706776936,19.02679983774821,18.53909969329834,18.016099611918133,17.46709982554118,16.899999777475994,16.321499824523926,15.737199942270914,15.151899735132853,14.569599866867065,13.993399858474731,13.42419981956482,12.862699826558432,12.311099847157797,11.771399895350138,11.244800011316935,10.732699871063232,10.23579994837443,9.754819949467977,9.290159861246744,8.842100143432617,8.410640080769857,7.9957098960876465,7.597210009892781,7.214959939320882,6.848719994227092,6.498179992039998,6.1629899342854815,5.8427499532699585,5.537050008773804,5.245460033416748,4.967519998550415,4.702809969584147,4.450869997342427,4.2112399737040205,3.9834500352541604,3.767039974530538,3.56155002117157,3.366510013739268,3.1814799904823303,3.0060199896494546,2.839649975299835,2.6818900307019553,2.5323700110117593,2.3906899889310202,2.2564900120099387,2.129419982433319,2.00914000471433,1.8953100045522053,1.7876299917697906,1.6857899924119313,1.5894900063673656,1.4984899858633678,1.412500003973643,1.331270009279251,1.2545700073242188,1.182149996360143,1.1137999991575878,1.0492899815241497,0.9884230047464371,0.9310069928566614,0.8768570025761923,0.8257929980754852,0.777648001909256,0.7322639922300974,0.6894840002059937,0.649165004491806,0.6111720005671183,0.5753769924243292,0.5416570007801056,0.5104419887065887,0.48159100115299225,0.45442300538221997,0.4288389980792999,0.4047440042098363,0.3820509960254033,0.3606799965103467,0.34055399646361667,0.32159700493017834,0.30374399820963544,0.28693099816640216,0.2710929984847705,0.2561769982179006,0.24212899804115295,0.22889499987165132,0.21642799923817316,0.2046869993209839,0.19362700109680495,0.18320799991488457,0.17339399953683218,0.16414900124073029,0.1554389980932077,0.14723199854294458,0.1394999995827675,0.13221700116991997,0.1253529998163382,0.11888700040678184,0.11279399879276752,0.10705199961860974,0.10164099931716919,0.09654229879379272,0.09173529967665672,0.08720289977888267,0.08293119817972183,0.07890499879916509,0.07510759867727757,0.07152769900858402,0.06815269899864991,0.06496809981763363,0.06196290006240209,0.05912859924137592,0.056455399530629315,0.05393129959702492,0.05154989939182997,0.04930289927870035,0.0471798994888862,0.04517359907428423,0.04327949943641821,0.04149099998176098,0.03979939998437961,0.03820139914751053,0.036691498942673206,0.03526209884633621,0.03391079977154732,0.03263289947062731,0.03142179952313503,0.030273499432951212,0.029186599577466648,0.028157499463607866,0.027180399745702744,0.026254599603513878,0.025377099867910147,0.0245424994888405,0.023748399534573156,0.02299479969466726,0.02227909956127405,0.021596799604594707,0.020948299517234165,0.020331499477227528,0.019742299647380907,0.01918129933377107,0.018646799493581057,0.01813489959264795,0.017644299970318873,0.017175999625275534,0.016728699517746765,0.01629889973749717,0.01588769940038522,0.015494199702516198,0.015114899724721909,0.014748899654174844,0.014397899620234966,0.014060899692897996,0.013734699692577124,0.013420999671022097,0.013119199701274434,0.012826099681357542,0.012543499702587724,0.012270899799962839,0.01200529964019855,0.011746299608300129,0.01149579967993001,0.011253399852042397,0.011016099713742733,0.010786099592223763,0.01056299963966012,0.01034389971755445,0.010128599824383855,0.009919239828983942,0.00971550983376801,0.009514689911156893,0.009318969600523511,0.0091280498697112,0.008939289798339209,0.008754919826363524,0.008574679726734757,0.008395969790096084,0.008218729790921012,0.008045199560001493,0.007875179794306556,0.007706109783612192,0.007540289817067484,0.007377529866062105,0.0072152997987965746,0.00705358983638386,0.006894709814029436,0.006738499893496434,0.006582459822917978,0.006428939872421324,0.006277779815718532,0.006126509901757042,0.005975149843531351,0.0058260498335585,0.00567907983592401,0.005531779839657247,0.005386529839597642,0.005243199838635822,0.005099339837518831,0.0049573399204139905,0.004817089919621746,0.004676149925217032,0.004534569879372914,0.004394739866256714,0.004256579947347443,0.004117629995259146,0.003980309915884088,0.003844509929573784,0.003707819909323007,0.0035702899525252483,0.0034343399262676635,0.0032998699656066797,0.0031644599706244967,0.0030305299636286995,0.002897979982662946,0.0027643999783322215,0.0026322199846617877,0.0025014499745642147,0.002369759992385904,0.0022371899685822427,0.0021061499525482454,0.001976510015083477,0.0018504900120509167,0.0017325200024060905,0.0016220799880102277,0.0015186899884914358,0.0014218899984067928,0.0013312699932915468,0.0012464399818175782,0.0011670199940757204,0.0010926599982970704,0.0010230499901808798,0.000957883006776683,0.0008968690041607866,0.0008397469985842084,0.0007862680067773908,0.0007361989943698669,0.0006893230020068586,0.0006454350029040749,0.0006043439983235052,0.0005658730030215035,0.0005298540005848432,0.0004961300001014024,0.0004645559990118879,0.00043499299984735745,0.00040731400076765567,0.0003813980025976586,0.00035713200001434114,0.00033441299698703614,0.0003131399959481011,0.00029322199649565545,0.0002745730016613379,0.00025711100170155987,0.00024076000045170076,0.0002254510012183649,0.00021111600047637089,0.0001976930010035479,0.00018512500052262718,0.00017335700007000318,0.0001623370020145861,0.00015201900168904103,0.00014235699927667156,0.00013330999960696013,0.0001248380000712738,0.00011690599967550952,0.00010947800061937112,8.590302483450311e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.69485219319662,237.7288449605306,241.00387318929037,243.55890274047852,245.43492380777994,246.79493459065756,247.7639923095703,247.69807052612305,246.14810180664062,243.5561294555664,240.25714111328125,236.50619252522787,231.79726282755533,225.7802848815918,218.92230478922525,211.57730356852213,204.00834528605142,195.7624028523763,186.52441279093424,176.7304204305013,166.7024180094401,156.67940775553384,146.8333943684896,137.28537877400717,128.11735916137695,119.38333829243977,111.11332321166992,103.26530774434407,95.80158996582031,88.74277242024739,82.0982551574707,75.86733818054199,70.04262034098308,64.61190573374431,59.55949115753174,54.86767768859863,50.51766395568848,46.48905245463053,42.761839866638184,39.316829681396484,36.13531939188639,33.199610233306885,30.49230146408081,27.997193972269695,25.698886076609295,23.582779089609783,21.635372797648113,19.843966960906982,18.19676160812378,16.682756503423054,15.291651964187622,14.014047702153524,12.840943574905396,11.764140208562216,10.775836706161499,9.869203805923462,9.037550926208496,8.27461838722229,7.574656128883362,6.932613929112752,6.3438219626744585,5.804000059763591,5.309168418248494,4.8556768496831255,4.440165400505066,4.059534152348836,3.71090296904246,3.3916918635368347,3.099490841229757,2.832089920838674,2.587429086367289,2.3636182943979898,2.1589175860087075,1.971736917893092,1.8006063501040142,1.6441757877667744,1.5011952916781108,1.370544840892156,1.2511644164721172,1.1421140134334564,1.0424936811129253,0.9515123764673868,0.8684190760056177,0.7925388117631277,0.7232555647691091,0.6600003292163213,0.6025501141945521,0.5503789385159811,0.5026787668466568,0.45905961592992145,0.41919347643852234,0.3827803507447243,0.34951923539241153,0.3191081260641416,0.29132603108882904,0.2659439394871394,0.24275385960936546,0.2215627854069074,0.20219871525963148,0.18452765171726546,0.16840359568595886,0.15366354708870253,0.14018749818205833,0.12789145360390344,0.11667341428498428,0.10643937687079112,0.09710254582266013,0.08858521468937397,0.0808156890173753,0.07370166542629401,0.06718584150075912,0.061242820074160896,0.05582269995162884,0.0508795827627182,0.04637176636606455,0.04226115128646294,0.03851283838351568,0.03509512605766455,0.031978914514184,0.02913790491099159,0.026547795937707026,0.02418668707832694,0.02203437949841221,0.020072372319797676,0.018284165921310585,0.016654360108077526,0.015168955006326238,0.013815249859665832,0.012581645355870327,0.01145764160901308,0.010433337651193142,0.009500174627949795,0.008649951312690973,0.00787537859287113,0.007169756029422085,0.006526993704028428,0.005941511636289458,0.005408239589693646,0.004922557893830041,0.004480226314626634,0.004077414904410641,0.003710603496680657,0.003376592299900949,0.0030724812337818244,0.0027955901847841838,0.0025435192704511187,0.002314038419475158,0.0021051377213249602,0.0019149870204273611,0.0017419163777958602,0.0015843957953620702,0.0014410352838846545,0.001310564800708865,0.0011918543993184965,0.001083823968656361,0.0009855306222258757,0.0008961012984703606,0.0008147399979255473,0.0007407247273173804,0.0006733944804485267,0.0006121492576009283,0.0005564430563633019,0.0005057768648839556,0.0004596976965937453,0.0004177925463106173,0.00037968640147785965,0.00034503527664734673,0.00031352916509301093,0.0002848840522347018,0.00025884096006241936,0.00023516487150724666,0.0002136427901859861,0.00019407871877774596,0.000176296655505818,0.00016013459511062442,0.00014544553899516663,0.00013209648993021497,0.00011996544526482467,0.00010894240464646525,4.2343278740493893e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527326901753745,3.5471805731455484,3.4357604583104453,3.3270504673322043,3.216910481452942,3.106050491333008,2.9951104521751404,2.8846304615338645,2.7750904162724814,2.6668904423713684,2.560370405515035,2.455820401509603,2.3534804383913674,2.253540337085724,2.1561803420384726,2.061500370502472,1.969610333442688,1.8805703123410542,1.794430325428645,1.7112102905909221,1.630920281012853,1.5535602867603302,1.4791002770264943,1.4075202544530232,1.3387702405452728,1.2728002270062764,1.2095702191193898,1.1489902138710022,1.0910201966762543,1.0355801979700725,0.9825901935497919,0.9319871763388315,0.8836901734272639,0.8376241574684778,0.7937111457188925,0.7518721520900726,0.7120301425457001,0.6741111278533936,0.6380371252695719,0.6037361174821854,0.5711341053247452,0.5401610980431238,0.5107470974326134,0.4828250954548518,0.45632708817720413,0.431190088391304,0.4073530857761701,0.3847580775618553,0.36334507415692013,0.34305906544129056,0.3238460645079613,0.30565406382083893,0.28843605766693753,0.2721420576175054,0.25672704974810284,0.24214604745308557,0.2283590460817019,0.21532504260540009,0.20300504316886267,0.19136304035782814,0.1803650384147962,0.16997603327035904,0.16016403461496034,0.1508990302681923,0.1421530283987522,0.13389802972475687,0.12610802613198757,0.11875802526871364,0.11182402384777863,0.10528402092556159,0.09911571939786275,0.09329851965109508,0.0878145198027293,0.08264491831262906,0.07777181640267372,0.07318021543323994,0.06885441516836484,0.06477791319290797,0.060936913515130676,0.05732031166553497,0.05391401114563147,0.050704910419881344,0.047684310004115105,0.04484040973087152,0.04216210885594288,0.03964100840191046,0.03735420728723208,0.03527500697722038,0.033308506943285465,0.031447606471677624,0.029685805551707745,0.02801680580402414,0.026434805088986952,0.024951905012130737,0.02354440496613582,0.02220770437270403,0.020954603950182598,0.019762604342152674,0.018627803772687912,0.017564103628198307,0.016567003292342026,0.015632403005535405,0.01473890314809978,0.01388400288609167,0.01308270264416933,0.012331502434487144,0.011627502351378402,0.010967602099602422,0.01034900212349991,0.009751792221019665,0.009174601950993141,0.00863360178967317,0.008126521715894341,0.007651241573815544,0.007205761464623113,0.00678822142072022,0.006396881382291515,0.006030081266847749,0.005686281171316902,0.005364061139213542,0.005062051001004875,0.0047789910264934106,0.0045136807796855765,0.0042650307683895035,0.004014550941064954,0.0037623708291600146,0.0035260107445841036,0.0033044907031580806,0.0030968806822784245,0.002902300659722338,0.002719940598277996,0.002549030565811942,0.0023888405218409994,0.0022387204808183014,0.0020980204571969807,0.0019661604116360345,0.0018425904078564297,0.0017267703854789336,0.0016182303370442241,0.0015165003424044698,0.0014211703188872586,0.001331820278816546,0.0012480902757185202,0.0011696202661066006,0.0010960802319459617,0.001027160227143516,0.0009625732200220227,0.0009020441939355806,0.000845318179926835,0.0007921581709524617,0.0007423391604485611,0.0006956511448758343,0.0006518991431221366,0.0006108961339729527,0.0005724711275737112,0.0005364621223028129,0.0005027171088537822,0.00047109410418973613,0.0004414580956411858,0.0004136870920774527,0.00038766108385364834,0.0003632730755877371,0.0003404180727860269,0.00031900006676247966,0.00029892906604800373,0.00028012106486130506,0.0002624950575409457,0.00024597905333697173,0.00023050105179815242,0.00021599704632535577,0.00020240504575970894,0.00018966804054798558,0.00017773203702139048,0.00016654803766869009,0.00015606703163939528,0.00014624503213174952,0.00013704103063597964,0.0001284170284634456,0.00012033502631917752,0.00011276202470374604,0.00010566502290506226,3.372199777610755e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.284417708714803,3.2989591161410012,3.3043991724650064,3.3077792127927146,3.3092092474301658,3.308759252230326,3.306549290815989,3.302659293015798,3.297179321448008,3.2901893655459085,3.2817593614260354,3.271989425023397,3.2609294255574546,3.2486594518025718,3.235239485899607,3.22074947754542,3.2052395145098367,3.188759525616964,3.171389559904734,3.153159578641256,3.1341295639673867,3.114349603652954,3.093869606653849,3.072739621003469,3.0509896278381348,3.028679668903351,3.0058396657307944,2.9825096925099692,2.9587196906407676,2.9345196882883706,2.909929653008779,2.8849997321764627,2.8597397208213806,2.834189772605896,2.8083797295888266,2.7823297580083213,2.7560798128445945,2.729639768600464,2.703039805094401,2.676299790541331,2.6494498252868652,2.6224997838338218,2.595469812552134,2.568389813105265,2.541269858678182,2.514119863510132,2.486969828605652,2.4598198731740317,2.4326998194058738,2.4056098659833274,2.3785699009895325,2.351589878400167,2.3246898651123047,2.297869861125946,2.2711498936017356,2.244529942671458,2.2180199027061462,2.1916398803393045,2.165389915307363,2.1392698884010315,2.1132999062538147,2.087489902973175,2.0618399182955423,2.036349892616272,2.011029918988546,1.9858899315198262,1.960929940144221,1.9361599286397297,1.9115799367427826,1.887189934651057,1.86299995581309,1.8390199144681294,1.81523992617925,1.7916699548562367,1.7683099607626598,1.7451599438985188,1.7222299476464589,1.6995199422041576,1.6770199636618297,1.6547499597072601,1.6326899528503418,1.6108599702517192,1.58925994237264,1.5678699711958568,1.546709954738617,1.5257799824078877,1.5043099919954936,1.4823299845059712,1.4606499870618184,1.4392700095971425,1.4181699852148693,1.3973700106143951,1.3768499791622162,1.3566199839115143,1.3366600076357524,1.316959987084071,1.2975399990876515,1.2783999939759572,1.2595299979050953,1.2409199674924214,1.2225599884986877,1.2044600049654643,1.1866300106048584,1.1690399944782257,1.151699999968211,1.1346099774042766,1.1177599827448528,1.101129988829295,1.0847599903742473,1.0686299800872803,1.0527200003465016,1.0370199978351593,1.0215700070063274,1.0063400020202,0.9913360029459,0.9765379925568899,0.9619419872760773,0.9475640008846918,0.9334000001351038,0.919446994860967,0.9057030032078425,0.8921450028816859,0.8787690053383509,0.8655939946571986,0.8526149938503901,0.8398300061623255,0.8272370000680288,0.814831996957461,0.8026130000750223,0.7905759960412979,0.7787199864784876,0.7670209954182307,0.7554780046145121,0.7441080013910929,0.7329080055157343,0.7218760053316752,0.7110099991162618,0.7003059933582941,0.6897630045811335,0.6793780028820038,0.6691489915053049,0.6590730051199595,0.6491489956776301,0.6393729945023855,0.6297440032164255,0.6202599952618281,0.6109189987182617,0.6017179985841116,0.5926550030708313,0.5837289939324061,0.5749359975258509,0.5662759989500046,0.557747001449267,0.5493249942859014,0.5410110006729761,0.5328219930330912,0.5247559994459152,0.5168120066324869,0.5089870045582453,0.5012810006737709,0.49368999898433685,0.48621400197347003,0.47885099798440933,0.471599002679189,0.4644559994339943,0.4574200039108594,0.45049099375804263,0.4436669995387395,0.43694600214560825,0.4303259973724683,0.42380600174268085,0.41738400359948474,0.41106000045935315,0.4048309996724129,0.39869600037733716,0.3926540017127991,0.3867029969890912,0.3808419977625211,0.3750699982047081,0.3693850040435791,0.3637859995166461,0.3582720011472702,0.3528409997622172,0.3474930003285408,0.34222499281167984,0.3370369995633761,0.33192799985408783,0.3268959994117419,0.32193999985853833,0.3170590003331502,0.3122519999742508,0.30751799295345944,0.3028559982776642,0.298265000184377,0.29374299943447113,0.28928900013367337,0.2849030022819837,0.2805839975674947,0.27633000165224075,0.2721400037407875,0.26801399638255435,0.26395099610090256,0.2599490011731784,0.25600800414880115,0.2521269967158635,0.24830499912301698,0.24453999971350035,0.240832998106877,0.2371820012728373,0.23358700051903725,0.2300459990898768,0.2265590007106463,0.22312499831120172,0.21974300096432367,0.2164119966328144,0.2131320002178351,0.20990200092395148,0.20672100161512694,0.2035880001882712,0.20050299912691116,0.19746500005324683,0.19447200000286102,0.19152599945664406,0.18862399831414223,0.18576599781711897,0.18295200044910112,0.18018000076214472,0.1774509996175766,0.1747630015015602,0.1721160002052784,0.16950900107622147,0.16694199790557226,0.16441400100787482,0.16192400207122168,0.15947199861208597,0.15705699970324835,0.15468000123898187,0.15233800063530603,0.15003200123707452,0.1477610021829605,0.1455250009894371,0.14332299927870432,0.1411539986729622,0.1390179991722107,0.13691499829292297,0.13484399765729904,0.1328039988875389,0.13079500074187914,0.12881699949502945,0.1268689992527167,0.12495000039537747,0.12306100067993005,0.12119999900460243,0.1193680011977752,0.11756300056974094,0.11578599984447162,0.11403600002328555,0.1123120008657376,0.11061500012874603,0.10894299981494744,0.10729700016478698,0.10567500007649262,0.10407799979050954,0.10250600054860115,0.10095700000723203,0.0994316004216671,0.09792950004339218,0.09645009972155094,0.09499319891134898,0.09355829966564973,0.09214520019789536,0.09075350066026051,0.08938289992511272,0.08803299938639005,0.08670360036194324,0.08539440048237641,0.0841049998998642,0.08283509997030099,0.08158440018693607,0.08035269938409328,0.07913969891766708,0.0779450008024772,0.07676839890579383,0.07560960079232852,0.07446840032935143,0.07334440015256405,0.07223749905824661,0.07114730030298233,0.07007359961668651,0.06901619893809159,0.06797469966113567,0.06694910116493702,0.06593889929354191,0.06494399967292945,0.06396419927477837,0.06299920007586479,0.062048899941146374,0.06111279968172312,0.0601910005013148,0.05928310006856918,0.05838890032221874,0.05750830036898454,0.056640900361041226,0.05578669967750708,0.05494539967427651,0.05411680073787769,0.05330080011238655,0.052497099774579205,0.05170549980054299,0.05092590022832155,0.05015809958179792,0.04940190011014541,0.048657200609644256,0.04792359999070565,0.04720119976749023,0.04648969974368811,0.045788999957342945,0.04509879990170399,0.04441909988721212,0.04374960002799829,0.04309030001362165,0.04244089964777231,0.04180129989981651,0.041171400186916195,0.04055099996427695,0.039940000201265015,0.03933819973220428,0.03874549983690182,0.038161699970563255,0.03758680013318857,0.03702050012846788,0.03646279995640119,0.03591360027591387,0.035372600269814335,0.03483980055898428,0.0343149999777476,0.03379819976786772,0.03328909973303477,0.032787799214323364,0.032293999257187046,0.031807600520551205,0.031328700172404446,0.030856899917125702,0.030392300182332594,0.029934599995613098,0.02948389993980527,0.029039999935775995,0.028602800021568935,0.028172200080007315,0.027748000031958025,0.027330299839377403,0.026918900044014055,0.026513700063029926,0.026114599779248238,0.02572149969637394,0.0253343996591866,0.02495309989899397,0.024577499988178413,0.02420760008196036,0.023843300218383472,0.023484499969830114,0.023131099995225668,0.0227831001393497,0.022440199895451467,0.02210260011876623,0.021770000147322815,0.021442500098297994,0.021119900047779083,0.020802199995766085,0.02048919986312588,0.020181000232696533,0.019877399938801926,0.019578400067985058,0.019283900347848732,0.018993799885114033,0.018708199728280306,0.018426799681037664,0.01814969986056288,0.017876699722061556,0.017607799886415403,0.01734309984991948,0.017082300037145615,0.016825399827212095,0.016572399841000635,0.016323199961334467,0.01607779987777273,0.015836000132064026,0.015597900298113624,0.015363400025914112,0.01513250001395742,0.014904999950279793,0.014680899990101656,0.014460200055812797,0.014242900069803,0.014028800030549368,0.0138178999380519,0.01361020002514124,0.013405699981376529,0.013204199960455298,0.013005800001944104,0.012810300026709834,0.01261779999670883,0.012428199872374535,0.012241400079801679,0.012057499960064888,0.011876299977302551,0.011697900015860796,0.011522100074216723,0.011349000114326676,0.011178499863793453,0.011010600021108985,0.010845199925825,0.010682200004036227,0.010521799869214496,0.010363700023541847,0.010207999963313341,0.010054700154190263,0.009903700013334552,0.009754950103039542,0.00960845003525416,0.009464139972502986,0.009322010135898987,0.009182020012910167,0.00904413009993732,0.008908319907883802,0.008774550010760626,0.00864279999708136,0.00851303005280594,0.008385209987560907,0.008259309999023875,0.008135310063759485,0.008013179913784066,0.007892880084303519,0.007774389969805877,0.007657680000799398,0.007542729998628299,0.007429510005749762,0.00731798994820565,0.0072081500353912515,0.007099960038127999,0.006993390037678182,0.006888440034041802,0.00678505003452301,0.006683230089644591,0.00658292998559773,0.006484140021105607,0.006386840017512441,0.00629100005608052,0.00619660996987174,0.006103629983651142,0.006012050008090834,0.005921840085648,0.0058330000611022115,0.0057454799534752965,0.005659290007315576,0.005574389981726806,0.005490759969688952,0.005408389959484339,0.005327269978200396,0.005247359978966415,0.005168649988869826,0.005091119984475275,0.0050147599540650845,0.004939550029424329,0.00486546002017955,0.004792489965135853,0.00472062003488342,0.0046498300119613605,0.00458010002815475,0.0045114200717459125,0.004443770002884169,0.004377129992159705,0.004311500078377624,0.004246849993554254,0.004183180048130453,0.004120460012927651,0.004058679992643495,0.003997830053170522,0.003937899949960411,0.0038788599583009877,0.0038207200317022703,0.003763440006878227,0.0037070300119618573,0.0036514600118001304,0.003596730006393045,0.003569570001369963};
    
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261276473601659,0.4188620348771413,0.4108480264743169,0.4034990246097247,0.396085021396478,0.388622023165226,0.3811250180006027,0.3736110255122185,0.3660910228888194,0.35857802132765454,0.35108302036921185,0.3436160186926524,0.3361860116322835,0.32880201439062756,0.32147301981846493,0.3142050156990687,0.30700600892305374,0.2998790144920349,0.29283201446135837,0.2858690122763316,0.2789950097600619,0.27221200863520306,0.2655250107248624,0.25893601030111313,0.25244900956749916,0.24606500814358392,0.23978800947467485,0.2336180085937182,0.2275560088455677,0.22160500784715018,0.2157650093237559,0.21003600706656775,0.2044190081457297,0.19891400635242462,0.19352000703414282,0.1882380060851574,0.1830690068503221,0.1780110038816929,0.17306300376852354,0.1682250052690506,0.16349700341622034,0.15887600431839624,0.15436200549205145,0.1499540035923322,0.14565100272496542,0.1414510024090608,0.13735400264461836,0.13335600246985754,0.12945900236566862,0.12565800237158933,0.12195400334894657,0.11834400333464146,0.11482700146734715,0.11140000199278195,0.10806300180653731,0.10481500253081322,0.10165300158162911,0.0985761017849048,0.09558180222908656,0.09266840231915315,0.08983440138399601,0.08707790200908978,0.08439840190112591,0.08179440225164096,0.07926310102144878,0.07680310122668743,0.07441290219624837,0.0720901017387708,0.06983340034882228,0.06764140166342258,0.06551310109595458,0.06344720162451267,0.061441500981648765,0.05949390151848396,0.05760330085953077,0.055768901482224464,0.05398850173999866,0.05226150124023358,0.05058690067380667,0.048962900415062904,0.04738770052790642,0.04585930115232865,0.044377400229374565,0.0429413008193175,0.04154930046449105,0.0401998000840346,0.03880030009895563,0.037357100285589695,0.035967399987081684,0.03462919996430477,0.033340600319206715,0.03209970022241274,0.030904899972180527,0.029754499749590952,0.028646700084209442,0.027579999528825283,0.02655289974063635,0.025563899738093216,0.024611700015763443,0.023694800212979317,0.022811999699721735,0.02196189993992448,0.021143500072260697,0.020355400008459885,0.019596599663297336,0.01886610019331177,0.01816259991998474,0.01748539988572399,0.016833300081392128,0.01620550003523628,0.015601000050082803,0.015018999964619676,0.014458600043629607,0.013919099777316054,0.013399700013299784,0.012899599969387054,0.012418100067103902,0.011954600069050988,0.011508299969136715,0.011078599995623032,0.010664900066331029,0.010266699905817708,0.009883239942913255,0.009514090061808625,0.009158700006082654,0.008816550020128489,0.008487149995441238,0.00817002992456158,0.00786473990107576,0.007570819968047242,0.007287859955492119,0.007015460054390132,0.006753209978342056,0.006500749965198338,0.00625769995773832,0.006023719945612053,0.0057984699960798025,0.005581630005811651,0.005372869976175328,0.005171910083542268,0.0049784500151872635,0.0047922199591994286,0.004612930002622306,0.00444033994184186,0.004274199988382558,0.004114260043328007,0.003960289992392063,0.0038120799775545797,0.0036694000009447336,0.003532060014549643,0.0033998399740085006,0.0032725700293667614,0.003150059977391114,0.003032120002899319,0.0029185899960187576,0.0028093099826946855,0.002704109977154682,0.0026028499899742505,0.002505369969488432,0.0024115400350031755,0.0023212199836658933,0.0022342800123927495,0.0021505900270616016,0.0020700300228782,0.0019924900261685252,0.0019178500030344974,0.001845999979802097,0.001776839984813705,0.0017102599861876417,0.0016461800162990887,0.0015845000064776589,0.0015251299870821338,0.001467980007873848,0.0014129700139164925,0.0013600199890788645,0.0013090499948399763,0.0012600000094001491,0.0012127800049105038,0.0011673200157626222,0.001123570012471949,0.0010814599906249593,0.001040929996330912,0.0010019099960724513,0.0009643569937907159,0.0009282109967898577,0.0008934179980618259,0.0008599290013080463,0.0008276950005286684,0.000796668988186866,0.0007668059988645837,0.0007380620033169786,0.0007103950047167018,0.0006837649998487905,0.0006581330041323478,0.0006334619926443944,0.0006097149986696119,0.000586859003912347,0.0005648600053973496,0.0005436849896796048,0.0005233039943656573,0.0005036879932352653,0.0004848060004102687,0.0004666330011483903,0.00044914099999004975,0.00043230500402084243,0.0004160999984984907,0.0004005030035235298,0.0003854899963092369,0.00037104100435196113,0.00035713299924585346,0.00034374700286813703,0.0003308630039100535,0.00031846199757031474,0.00030652600010701764,0.00029503699867442873,0.0002839800023745435,0.0002733370007869477,0.0002630930005883177,0.0002532340004108846,0.00024374400042385483,0.00023460999970363142,0.00022581899975193664,0.0002173569967756824,0.00020921300044089244,0.00020137399891003346,0.00019382900184912918,0.00018656699830899015,0.0001795780008251313,0.00017285000042951046,0.00016637500084470958,0.000160143001266988,0.0001541439984672858,0.00014837000101882344,0.00014281300173024647,0.00013746400266730538,0.0001323160007207965,0.00012736100082596144,0.00012259200047992636,0.00011800099976729446,0.00011358300071151461,0.00010933099959705335,0.00010523799877167524,8.46822519330696e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1795934041341,329.0759760538737,329.7849756876628,330.54097239176434,331.3019765218099,332.0679753621419,332.83897399902344,333.61597696940106,334.3979721069336,335.18597412109375,335.97997792561847,336.77897389729816,337.5829772949219,338.3929723103841,339.2079722086589,340.02897389729816,340.85497029622394,341.68297322591144,342.50997161865234,343.33597056070965,344.15997314453125,344.98397064208984,345.80697377522785,346.6279703776042,347.448974609375,348.26797739664715,349.08697509765625,349.9009730021159,350.70797475179035,351.50897216796875,352.3019739786784,353.0889714558919,353.86797587076825,354.64097849527997,355.406977335612,356.1659749348958,356.91897837320965,357.66297403971356,358.3959732055664,359.1179784138997,359.82897694905597,360.5299758911133,361.219975789388,361.8989715576172,362.56797281901044,363.2269744873047,363.8749745686849,364.51097869873047,365.1329803466797,365.74097951253253,366.33497619628906,366.91497802734375,367.4809799194336,368.03397369384766,368.5729802449544,369.09897867838544,369.61097717285156,370.1059748331706,370.5819778442383,371.03797403971356,371.47497812906903,371.89098358154297,372.28897857666016,372.66698201497394,373.02698008219403,373.3669738769531,373.68898010253906,373.9949773152669,374.28597768147785,374.56398010253906,374.8289794921875,375.0799789428711,375.31798299153644,375.54197947184247,375.7529780069987,375.9509760538737,376.13698323567706,376.30997975667316,376.46998341878253,376.61898040771484,376.7559814453125,376.8809814453125,376.99398549397785,377.09598032633465,377.1859842936198,377.2639795939128,377.3319803873698,377.39198048909503,377.4509811401367,377.5079803466797,377.56297556559247,377.61498260498047,377.66598256429035,377.7149836222331,377.76298268636066,377.80798085530597,377.85098520914715,377.89298248291016,377.93298594156903,377.97098541259766,378.0079828898112,378.04198201497394,378.0749867757161,378.1059799194336,378.13597869873047,378.1629816691081,378.18898010253906,378.2139841715495,378.2369791666667,378.2579803466797,378.2769826253255,378.2949803670247,378.31097920735675,378.32598368326825,378.3389841715495,378.34998321533203,378.35998280843097,378.36798095703125,378.3749821980794,378.38097890218097,378.3839823404948,378.3869806925456,378.3869806925456,378.38698323567706,378.3849843343099,378.38097890218097,378.37598419189453,378.36997985839844,378.36198170979816,378.35298411051434,378.34198506673175,378.3299814860026,378.3169860839844,378.3019765218099,378.2859853108724,378.26898193359375,378.2499821980794,378.22998046875,378.20898183186847,378.1869812011719,378.16298421223956,378.1379877726237,378.1109873453776,378.083984375,378.05498758951825,378.0249837239583,377.99298095703125,377.9609832763672,377.9269841512044,377.89198048909503,377.8559824625651,377.8189875284831,377.7809829711914,377.7409845987956,377.7009811401367,377.6589864095052,377.61598205566406,377.5719807942708,377.5269826253255,377.48097737630206,377.43298085530597,377.3849843343099,377.3359832763672,377.2849833170573,377.2339833577474,377.1809819539388,377.1279805501302,377.0729802449544,377.0179799397786,376.9609832763672,376.9039815266927,376.84498341878253,376.7859853108724,376.72497812906903,376.66398366292316,376.60098520914715,376.5379816691081,376.47398376464844,376.4089838663737,376.3429819742839,376.27598063151044,376.2079823811849,376.1389795939128,376.06898498535156,375.99898529052734,375.92798614501953,375.854985555013,375.78197987874347,375.7079849243164,375.63297780354816,375.55798594156903,375.4809824625651,375.4039840698242,375.3259785970052,375.24698638916016,375.16697947184247,375.0869852701823,375.00598398844403,374.9239807128906,374.8409907023112,374.7569808959961,374.67298380533856,374.5879847208659,374.5019836425781,374.4149805704753,374.32798258463544,374.239990234375,374.1509831746419,374.0619812011719,373.97197977701825,373.8809814453125,373.78897857666016,373.69698333740234,373.6039861043294,373.51098378499347,373.416987101237,373.32198333740234,373.22598520914715,373.1299794514974,373.0329818725586,372.9359868367513,372.8369776407878,372.7389831542969,372.6389846801758,372.5389811197917,372.4389826456706,372.3369878133138,372.23598225911456,372.1329828898112,372.02998606363934,371.9269790649414,371.8219807942708,371.7179819742839,371.6119842529297,371.5069834391276,371.39998118082684,371.29297892252606,371.1859817504883,371.0799814860026,370.97498321533203,370.8709894816081,370.76698303222656,370.6649805704753,370.56297810872394,370.4619827270508,370.3619791666667,370.2629852294922,370.16398366292316,370.06598409016925,369.96898651123047,369.87298583984375,369.7779795328776,369.6829783121745,369.5889841715495,369.49598439534503,369.4039840698242,369.31197865804035,369.2209828694661,369.1309865315755,369.04198201497394,368.9529800415039,368.864985148112,368.7779846191406,368.6909815470378,368.60498046875,368.5199839274089,368.4349822998047,368.3509801228841,368.2679799397786,368.1859766642253,368.1039861043294,368.02198028564453,367.94198354085285,367.8619842529297,367.7829818725586,367.70398712158203,367.62597910563153,367.54798380533856,367.4719874064128,367.39498138427734,367.31998443603516,367.24497985839844,367.1699803670247,367.09698486328125,367.02298227945965,366.95098368326825,366.8789825439453,366.8069814046224,366.7359848022461,366.6659851074219,366.59598541259766,366.52698516845703,366.4579823811849,366.3899841308594,366.32299041748047,366.2559814453125,366.1889826456706,366.12298075358075,366.0579833984375,365.99298604329425,365.92798105875653,365.864985148112,365.8009847005208,365.7379837036133,365.67598215738934,365.6139856974284,365.552978515625,365.4919789632161,365.4309794108073,365.37198130289715,365.3119862874349,365.2529881795247,365.19497934977215,365.1369857788086,365.07898203531903,365.021977742513,364.96497599283856,364.9089838663737,364.8529790242513,364.79798634847003,364.7429835001628,364.6889826456706,364.6349792480469,364.5809834798177,364.5279846191406,364.4759801228841,364.42298380533856,364.37198638916016,364.3199818929036,364.2689844767253,364.2179819742839,364.16798146565753,364.11798604329425,364.0689875284831,364.0199839274089,363.97098541259766,363.92298634847003,363.8749821980794,363.82798767089844,363.78098551432294,363.7339859008789,363.68798573811847,363.64198303222656,363.59598541259766,363.55098724365234,363.5059865315755,363.4619852701823,363.41798400878906,363.3739827473958,363.3309834798177,363.2869873046875,363.24498494466144,363.2019856770833,363.1599858601888,363.11898040771484,363.07698313395184,363.0359802246094,362.99597930908203,362.9549789428711,362.91498311360675,362.8749821980794,362.8359832763672,362.79698689778644,362.7579854329427,362.71998087565106,362.6819814046224,362.6439895629883,362.6059799194336,362.56898244222003,362.53197987874347,362.49497985839844,362.458984375,362.42298634847003,362.3869857788086,362.3519821166992,362.3169809977214,362.281982421875,362.24698130289715,362.2129821777344,362.1789830525716,362.14498138427734,362.11198170979816,362.07798258463544,362.0459798177083,362.0129877726237,361.97998809814453,361.9479802449544,361.91598256429035,361.8849843343099,361.85298411051434,361.8219858805339,361.7909800211589,361.760986328125,361.72998301188153,361.6999816894531,361.66998291015625,361.64098103841144,361.6109873453776,361.5819803873698,361.552983601888,361.52498118082684,361.49597930908203,361.4679819742839,361.4399770100911,361.41198984781903,361.38497670491535,361.3579839070638,361.3299814860026,361.3039830525716,361.2769826253255,361.25098419189453,361.22398630777997,361.19798278808594,361.17298126220703,361.14698282877606,361.12198130289715,361.09697977701825,361.07198333740234,361.0469792683919,361.021977742513,360.9979782104492,360.97398376464844,360.9499816894531,360.92598215738934,360.9029820760091,360.8799819946289,360.8559824625651,360.8329798380534,360.8109817504883,360.7879867553711,360.7659861246745,360.7439829508464,360.7219874064128,360.69998423258465,360.67798614501953,360.65697987874347,360.6349817911784,360.6139831542969,360.59298451741535,360.57298787434894,360.5519841512044,360.5309829711914,360.51098378499347,360.4909845987956,360.47098032633465,360.4509811401367,360.4319814046224,360.4119822184245,360.3929799397786,360.37398529052734,360.35498809814453,360.33598073323566,360.3179880777995,360.29898325602215,360.28098551432294,360.2629852294922,360.24498494466144,360.2269821166992,360.20898691813153,360.1919860839844,360.17398325602215,360.15697987874347,360.1399841308594,360.1229832967122,360.1059799194336,360.08897654215497,360.07298533121747,360.05598704020184,360.03998311360675,360.0239791870117,360.0079828898112,359.99198150634766,359.9759826660156,359.9609858194987,359.9449818929036,359.9299799601237,359.9149805704753,359.8999786376953,359.8849817911784,359.86998494466144,359.85498301188153,359.8409830729167,359.8259785970052,359.8119812011719,359.79798380533856,359.78998311360675};
    
    
}

void set_concs_ssp370() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.827517522,9.927611468,10.02770541,10.12779936,10.2278933,10.27385939,10.31982547,10.36579156,10.41175765,10.45772373,10.50368982,10.5496559,10.59562199,10.64158807,10.68755416,10.71943753,10.7513209,10.78320427,10.81508764,10.84697101,10.87885438,10.91073775,10.94262112,10.97450449,11.00638786,11.00032026,10.99425266,10.98818506,10.98211747,10.97604987,10.96998227,10.96391467,10.95784707,10.95177947,10.94571187,10.90930242,10.87289297,10.83648352,10.80007406,10.76366461,10.72725516,10.6908457,10.65443625,10.6180268,10.58161735,10.54384315,10.50606895,10.46829475,10.43052055,10.39274635,10.35497215,10.31719795,10.27942376,10.24164956,10.20387536,10.15959503,10.1153147,10.07103437,10.02675404,9.982473712,9.938193383,9.893913053,9.849632724,9.805352395,9.761072065,9.729928673,9.698785281,9.667641889,9.636498497,9.605355105,9.574211713,9.543068321,9.511924929,9.480781537,9.449638145,9.415197624,9.380757102,9.34631658,9.311876058,9.277435536,9.242995015,9.208554493,9.174113971,9.139673449,9.105232927,9.055633152,9.006033376,8.956433601,8.906833826,8.85723405,8.807634275,8.758034499,8.708434724,8.658834948,8.609235173,8.559635398,8.510035622,8.460435847,8.410836071,8.361236296,8.311636521,8.262036745,8.21243697,8.162837194,8.113237419,8.063637643,8.014037868,7.964438093,7.914838317,7.865238542,7.815638766,7.766038991,7.716439215,7.66683944,7.617239665,7.567639889,7.518040114,7.468440338,7.418840563,7.369240788,7.319641012,7.270041237,7.220441461,7.170841686,7.12124191,7.071642135,7.02204236,6.972442584,6.922842809,6.873243033,6.823643258,6.774043482,6.724443707,6.674843932,6.625244156,6.575644381,6.526044605,6.47644483,6.426845055,6.377245279,6.327645504,6.278045728,6.228445953,6.178846177,6.129246402,6.079646627,6.030046851,5.980447076,5.9308473,5.881247525,5.831647749,5.782047974,5.732448199,5.682848423,5.633248648,5.583648872,5.534049097,5.484449322,5.434849546,5.385249771,5.335649995,5.28605022,5.236450444,5.186850669,5.137250894,5.087651118,5.038051343,4.988451567,4.938851792,4.889252017,4.839652241,4.790052466,4.74045269,4.690852915,4.641253139,4.591653364,4.542053589,4.492453813,4.442854038,4.393254262,4.343654487,4.294054711,4.244454936,4.194855161,4.145255385,4.09565561,4.046055834,3.996456059,3.946856284,3.897256508,3.847656733,3.798056957,3.748457182,3.698857406,3.649257631,3.599657856,3.55005808,3.500458305,3.450858529,3.401258754,3.351658978,3.302059203,3.252459428,3.202859652,3.153259877,3.103660101,3.054060326,3.004460551,2.954860775,2.905261,2.855661224,2.806061449,2.756461673,2.706861898,2.657262123,2.607662347,2.558062572,2.508462796,2.458863021,2.409263245,2.35966347,2.310063695,2.260463919,2.210864144,2.161264368,2.111664593,2.062064818,2.012465042,1.962865267,1.913265491,1.863665716,1.81406594,1.764466165,1.71486639,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614,1.665266614};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,34.96487173,35.18371923,35.40256673,35.62141423,35.84026173,36.00451055,36.16875937,36.33300819,36.497257,36.66150582,36.82575464,36.99000346,37.15425228,37.3185011,37.48274991,37.56389761,37.6450453,37.72619299,37.80734069,37.88848838,37.96963607,38.05078377,38.13193146,38.21307915,38.29422685,38.30272664,38.31122643,38.31972622,38.32822601,38.3367258,38.34522559,38.35372538,38.36222517,38.37072496,38.37922475,38.2955354,38.21184605,38.12815669,38.04446734,37.96077799,37.87708863,37.79339928,37.70970993,37.62602057,37.54233122,37.44419061,37.34605,37.24790939,37.14976878,37.05162817,36.95348755,36.85534694,36.75720633,36.65906572,36.56092511,36.46048262,36.36004012,36.25959763,36.15915513,36.05871264,35.95827015,35.85782765,35.75738516,35.65694266,35.55650017,35.47585854,35.39521692,35.3145753,35.23393367,35.15329205,35.07265043,34.9920088,34.91136718,34.83072556,34.75008393,34.64991121,34.54973849,34.44956576,34.34939304,34.24922032,34.1490476,34.04887487,33.94870215,33.84852943,33.7483567,33.61937906,33.49040142,33.36142379,33.23244615,33.10346851,32.97449087,32.84551323,32.71653559,32.58755795,32.45858031,32.32960267,32.20062503,32.07164739,31.94266975,31.81369211,31.68471448,31.55573684,31.4267592,31.29778156,31.16880392,31.03982628,30.91084864,30.781871,30.65289336,30.52391572,30.39493808,30.26596044,30.13698281,30.00800517,29.87902753,29.75004989,29.62107225,29.49209461,29.36311697,29.23413933,29.10516169,28.97618405,28.84720641,28.71822877,28.58925113,28.4602735,28.33129586,28.20231822,28.07334058,27.94436294,27.8153853,27.68640766,27.55743002,27.42845238,27.29947474,27.1704971,27.04151946,26.91254182,26.78356419,26.65458655,26.52560891,26.39663127,26.26765363,26.13867599,26.00969835,25.88072071,25.75174307,25.62276543,25.49378779,25.36481015,25.23583251,25.10685488,24.97787724,24.8488996,24.71992196,24.59094432,24.46196668,24.33298904,24.2040114,24.07503376,23.94605612,23.81707848,23.68810084,23.5591232,23.43014557,23.30116793,23.17219029,23.04321265,22.91423501,22.78525737,22.65627973,22.52730209,22.39832445,22.26934681,22.14036917,22.01139153,21.8824139,21.75343626,21.62445862,21.49548098,21.36650334,21.2375257,21.10854806,20.97957042,20.85059278,20.72161514,20.5926375,20.46365986,20.33468222,20.20570459,20.07672695,19.94774931,19.81877167,19.68979403,19.56081639,19.43183875,19.30286111,19.17388347,19.04490583,18.91592819,18.78695055,18.65797291,18.52899528,18.40001764,18.27104,18.14206236,18.01308472,17.88410708,17.75512944,17.6261518,17.49717416,17.36819652,17.23921888,17.11024124,16.9812636,16.85228597,16.72330833,16.59433069,16.46535305,16.33637541,16.20739777,16.07842013,15.94944249,15.82046485,15.69148721,15.56250957,15.43353193,15.30455429,15.17557666,15.04659902,14.91762138,14.78864374,14.6596661,14.53068846,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082,14.40171082};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,100.3373652,99.90356338,99.46976158,99.03595978,98.60215798,98.66409788,98.72603779,98.78797769,98.8499176,98.9118575,98.97379741,99.03573731,99.09767722,99.15961712,99.22155703,99.25649291,99.29142879,99.32636467,99.36130055,99.39623643,99.43117231,99.46610819,99.50104407,99.53597995,99.57091583,99.59160932,99.6123028,99.63299628,99.65368977,99.67438325,99.69507673,99.71577022,99.7364637,99.75715718,99.77785066,99.3883552,98.99885973,98.60936426,98.21986879,97.83037333,97.44087786,97.05138239,96.66188692,96.27239145,95.88289599,95.48012293,95.07734987,94.67457681,94.27180376,93.8690307,93.46625764,93.06348459,92.66071153,92.25793847,91.85516541,91.40996425,90.96476308,90.51956192,90.07436075,89.62915959,89.18395842,88.73875726,88.29355609,87.84835493,87.40315376,87.0244613,86.64576884,86.26707637,85.88838391,85.50969145,85.13099899,84.75230653,84.37361406,83.9949216,83.61622914,83.06934404,82.52245895,81.97557385,81.42868875,80.88180365,80.33491855,79.78803346,79.24114836,78.69426326,78.14737816,77.64255137,77.13772457,76.63289778,76.12807098,75.62324419,75.11841739,74.6135906,74.1087638,73.60393701,73.09911021,72.59428342,72.08945662,71.58462983,71.07980304,70.57497624,70.07014945,69.56532265,69.06049586,68.55566906,68.05084227,67.54601547,67.04118868,66.53636188,66.03153509,65.52670829,65.0218815,64.5170547,64.01222791,63.50740111,63.00257432,62.49774752,61.99292073,61.48809393,60.98326714,60.47844034,59.97361355,59.46878675,58.96395996,58.45913316,57.95430637,57.44947957,56.94465278,56.43982598,55.93499919,55.43017239,54.9253456,54.4205188,53.91569201,53.41086521,52.90603842,52.40121162,51.89638483,51.39155803,50.88673124,50.38190444,49.87707765,49.37225085,48.86742406,48.36259726,47.85777047,47.35294367,46.84811688,46.34329008,45.83846329,45.33363649,44.8288097,44.32398291,43.81915611,43.31432932,42.80950252,42.30467573,41.79984893,41.29502214,40.79019534,40.28536855,39.78054175,39.27571496,38.77088816,38.26606137,37.76123457,37.25640778,36.75158098,36.24675419,35.74192739,35.2371006,34.7322738,34.22744701,33.72262021,33.21779342,32.71296662,32.20813983,31.70331303,31.19848624,30.69365944,30.18883265,29.68400585,29.17917906,28.67435226,28.16952547,27.66469867,27.15987188,26.65504508,26.15021829,25.64539149,25.1405647,24.6357379,24.13091111,23.62608431,23.12125752,22.61643072,22.11160393,21.60677713,21.10195034,20.59712354,20.09229675,19.58746995,19.08264316,18.57781636,18.07298957,17.56816278,17.06333598,16.55850919,16.05368239,15.5488556,15.0440288,14.53920201,14.03437521,13.52954842,13.02472162,12.51989483,12.01506803,11.51024124,11.00541444,10.50058765,9.995760852,9.490934057,8.986107262,8.481280467,7.976453672,7.471626877,6.966800082,6.461973287,5.957146492,5.452319697,4.947492903,4.442666108,3.937839313,3.433012518,2.928185723,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928,2.423358928};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,157.6274132,159.7343764,161.8413396,163.9483028,166.055266,166.4177496,166.7802332,167.1427167,167.5052003,167.8676839,168.2301675,168.5926511,168.9551347,169.3176182,169.6801018,169.8017791,169.9234563,170.0451336,170.1668109,170.2884881,170.4101654,170.5318426,170.6535199,170.7751972,170.8968744,170.7927894,170.6887045,170.5846195,170.4805345,170.3764496,170.2723646,170.1682796,170.0641947,169.9601097,169.8560247,169.2194097,168.5827947,167.9461797,167.3095647,166.6729496,166.0363346,165.3997196,164.7631046,164.1264896,163.4898745,162.8844177,162.2789609,161.673504,161.0680472,160.4625903,159.8571335,159.2516766,158.6462198,158.0407629,157.4353061,156.8149896,156.1946732,155.5743567,154.9540403,154.3337238,153.7134073,153.0930909,152.4727744,151.852458,151.2321415,150.9156029,150.5990643,150.2825257,149.9659871,149.6494486,149.33291,149.0163714,148.6998328,148.3832942,148.0667556,147.7049968,147.343238,146.9814792,146.6197203,146.2579615,145.8962027,145.5344439,145.1726851,144.8109263,144.4491674,143.6232763,142.7973852,141.9714941,141.145603,140.3197119,139.4938209,138.6679298,137.8420387,137.0161476,136.1902565,135.3643654,134.5384743,133.7125832,132.8866921,132.060801,131.2349099,130.4090188,129.5831277,128.7572366,127.9313455,127.1054544,126.2795633,125.4536722,124.6277811,123.80189,122.9759989,122.1501078,121.3242167,120.4983256,119.6724345,118.8465434,118.0206523,117.1947612,116.3688701,115.542979,114.7170879,113.8911968,113.0653057,112.2394146,111.4135235,110.5876324,109.7617413,108.9358502,108.1099591,107.284068,106.4581769,105.6322858,104.8063947,103.9805036,103.1546125,102.3287214,101.5028303,100.6769392,99.85104812,99.02515703,98.19926593,97.37337483,96.54748373,95.72159263,94.89570153,94.06981043,93.24391934,92.41802824,91.59213714,90.76624604,89.94035494,89.11446384,88.28857274,87.46268165,86.63679055,85.81089945,84.98500835,84.15911725,83.33322615,82.50733506,81.68144396,80.85555286,80.02966176,79.20377066,78.37787956,77.55198846,76.72609737,75.90020627,75.07431517,74.24842407,73.42253297,72.59664187,71.77075078,70.94485968,70.11896858,69.29307748,68.46718638,67.64129528,66.81540418,65.98951309,65.16362199,64.33773089,63.51183979,62.68594869,61.86005759,61.0341665,60.2082754,59.3823843,58.5564932,57.7306021,56.904711,56.0788199,55.25292881,54.42703771,53.60114661,52.77525551,51.94936441,51.12347331,50.29758222,49.47169112,48.64580002,47.81990892,46.99401782,46.16812672,45.34223562,44.51634453,43.69045343,42.86456233,42.03867123,41.21278013,40.38688903,39.56099794,38.73510684,37.90921574,37.08332464,36.25743354,35.43154244,34.60565134,33.77976025,32.95386915,32.12797805,31.30208695,30.47619585,29.65030475,28.82441366,27.99852256,27.17263146,26.34674036,25.52084926,24.69495816,23.86906706,23.04317597,22.21728487,21.39139377,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267,20.56550267};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,65.97180535,66.66390756,67.35600977,68.04811198,68.7402142,69.30189134,69.86356849,70.42524563,70.98692278,71.54859993,72.11027707,72.67195422,73.23363137,73.79530851,74.35698566,74.73542397,75.11386229,75.4923006,75.87073892,76.24917723,76.62761554,77.00605386,77.38449217,77.76293049,78.1413688,78.39863212,78.65589544,78.91315876,79.17042208,79.42768539,79.68494871,79.94221203,80.19947535,80.45673867,80.71400199,80.89995626,81.08591054,81.27186481,81.45781909,81.64377336,81.82972764,82.01568191,82.20163619,82.38759046,82.57354474,82.65804713,82.74254951,82.8270519,82.91155429,82.99605667,83.08055906,83.16506145,83.24956383,83.33406622,83.41856861,83.44386368,83.46915875,83.49445382,83.5197489,83.54504397,83.57033904,83.59563412,83.62092919,83.64622426,83.67151934,83.89975244,84.12798554,84.35621864,84.58445174,84.81268484,85.04091794,85.26915104,85.49738415,85.72561725,85.95385035,86.18930321,86.42475607,86.66020893,86.89566179,87.13111465,87.36656751,87.60202037,87.83747324,88.0729261,88.30837896,88.15961771,88.01085645,87.8620952,87.71333395,87.56457269,87.41581144,87.26705019,87.11828894,86.96952768,86.82076643,86.67200518,86.52324393,86.37448267,86.22572142,86.07696017,85.92819892,85.77943766,85.63067641,85.48191516,85.33315391,85.18439265,85.0356314,84.88687015,84.73810889,84.58934764,84.44058639,84.29182514,84.14306388,83.99430263,83.84554138,83.69678013,83.54801887,83.39925762,83.25049637,83.10173512,82.95297386,82.80421261,82.65545136,82.50669011,82.35792885,82.2091676,82.06040635,81.9116451,81.76288384,81.61412259,81.46536134,81.31660008,81.16783883,81.01907758,80.87031633,80.72155507,80.57279382,80.42403257,80.27527132,80.12651006,79.97774881,79.82898756,79.68022631,79.53146505,79.3827038,79.23394255,79.0851813,78.93642004,78.78765879,78.63889754,78.49013628,78.34137503,78.19261378,78.04385253,77.89509127,77.74633002,77.59756877,77.44880752,77.30004626,77.15128501,77.00252376,76.85376251,76.70500125,76.55624,76.40747875,76.2587175,76.10995624,75.96119499,75.81243374,75.66367248,75.51491123,75.36614998,75.21738873,75.06862747,74.91986622,74.77110497,74.62234372,74.47358246,74.32482121,74.17605996,74.02729871,73.87853745,73.7297762,73.58101495,73.4322537,73.28349244,73.13473119,72.98596994,72.83720869,72.68844743,72.53968618,72.39092493,72.24216367,72.09340242,71.94464117,71.79587992,71.64711866,71.49835741,71.34959616,71.20083491,71.05207365,70.9033124,70.75455115,70.6057899,70.45702864,70.30826739,70.15950614,70.01074489,69.86198363,69.71322238,69.56446113,69.41569987,69.26693862,69.11817737,68.96941612,68.82065486,68.67189361,68.52313236,68.37437111,68.22560985,68.0768486,67.92808735,67.7793261,67.63056484,67.48180359,67.33304234,67.18428109,67.03551983,66.88675858,66.73799733,66.58923608,66.44047482,66.29171357,66.14295232,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106,65.99419106};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,229.2001635,231.1555076,233.1108518,235.0661959,237.0215401,237.9864507,238.9513613,239.9162719,240.8811825,241.8460931,242.8110036,243.7759142,244.7408248,245.7057354,246.670646,247.090167,247.509688,247.929209,248.34873,248.7682509,249.1877719,249.6072929,250.0268139,250.4463349,250.8658559,251.3807211,251.8955863,252.4104515,252.9253166,253.4401818,253.955047,254.4699122,254.9847774,255.4996426,256.0145078,255.6309221,255.2473364,254.8637507,254.4801651,254.0965794,253.7129937,253.3294081,252.9458224,252.5622367,252.178651,251.7006005,251.22255,250.7444995,250.2664489,249.7883984,249.3103479,248.8322974,248.3542469,247.8761963,247.3981458,246.8005105,246.2028751,245.6052398,245.0076044,244.409969,243.8123337,243.2146983,242.617063,242.0194276,241.4217923,240.8072834,240.1927744,239.5782655,238.9637566,238.3492476,237.7347387,237.1202298,236.5057208,235.8912119,235.276703,234.5409363,233.8051696,233.069403,232.3336363,231.5978696,230.862103,230.1263363,229.3905696,228.654803,227.9190363,226.7517103,225.5843843,224.4170583,223.2497323,222.0824063,220.9150803,219.7477543,218.5804283,217.4131023,216.2457763,215.0784503,213.9111243,212.7437983,211.5764723,210.4091463,209.2418203,208.0744943,206.9071683,205.7398423,204.5725163,203.4051903,202.2378643,201.0705383,199.9032123,198.7358863,197.5685603,196.4012343,195.2339083,194.0665823,192.8992563,191.7319303,190.5646043,189.3972783,188.2299523,187.0626263,185.8953003,184.7279743,183.5606483,182.3933223,181.2259963,180.0586703,178.8913443,177.7240183,176.5566923,175.3893663,174.2220403,173.0547143,171.8873883,170.7200623,169.5527363,168.3854103,167.2180843,166.0507583,164.8834323,163.7161063,162.5487803,161.3814543,160.2141283,159.0468023,157.8794763,156.7121503,155.5448243,154.3774983,153.2101723,152.0428463,150.8755203,149.7081943,148.5408683,147.3735423,146.2062163,145.0388903,143.8715643,142.7042383,141.5369123,140.3695863,139.2022603,138.0349343,136.8676083,135.7002823,134.5329563,133.3656303,132.1983043,131.0309782,129.8636522,128.6963262,127.5290002,126.3616742,125.1943482,124.0270222,122.8596962,121.6923702,120.5250442,119.3577182,118.1903922,117.0230662,115.8557402,114.6884142,113.5210882,112.3537622,111.1864362,110.0191102,108.8517842,107.6844582,106.5171322,105.3498062,104.1824802,103.0151542,101.8478282,100.6805022,99.51317624,98.34585024,97.17852424,96.01119824,94.84387224,93.67654624,92.50922024,91.34189423,90.17456823,89.00724223,87.83991623,86.67259023,85.50526423,84.33793823,83.17061223,82.00328623,80.83596023,79.66863423,78.50130823,77.33398223,76.16665623,74.99933023,73.83200423,72.66467823,71.49735223,70.33002623,69.16270023,67.99537423,66.82804823,65.66072223,64.49339622,63.32607022,62.15874422,60.99141822,59.82409222,58.65676622,57.48944022,56.32211422,55.15478822,53.98746222,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622,52.82013622};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9326985677083,1851.5941670735676,1874.5094502766926,1889.791280110677,1905.450948079427,1921.4410196940105,1937.7410278320312,1954.3710835774739,1971.4010823567708,1988.7910970052083,2006.5111389160156,2024.5311584472656,2042.8211568196614,2061.371134440104,2080.1512247721353,2099.1412150065103,2118.3211669921875,2137.5512084960938,2156.701171875,2175.7611694335938,2194.751180013021,2213.6611531575522,2232.501180013021,2251.271199544271,2269.9711710611978,2288.5912068684897,2307.151163736979,2325.6511840820312,2344.1011555989585,2362.51123046875,2380.8711547851562,2399.191162109375,2417.4611612955728,2435.691162109375,2453.8711547851562,2472.0011596679688,2490.0811767578125,2508.18115234375,2526.3411865234375,2544.5511881510415,2562.8211466471353,2581.1311848958335,2599.4811808268228,2617.8611857096353,2636.2612101236978,2654.6911824544272,2673.1312255859375,2691.6112060546875,2710.1212158203125,2728.6812337239585,2747.26123046875,2765.8712565104165,2784.5012410481772,2803.1412556966147,2821.8012084960938,2840.4512736002603,2859.1112467447915,2877.791219075521,2896.5212605794272,2915.291259765625,2934.0812784830728,2952.9112345377603,2971.7512817382812,2990.6113077799478,3009.4812622070312,3028.3512573242188,3047.2212931315103,3065.9612426757812,3084.4612426757812,3102.7312215169272,3120.7811686197915,3138.6211547851562,3156.251220703125,3173.701212565104,3190.97119140625,3208.0711669921875,3225.0111694335938,3241.8011881510415,3258.4811401367188,3275.0411580403647,3291.4811401367188,3307.8311564127603,3324.0611572265625,3340.2011515299478,3356.2411295572915,3372.18115234375,3388.031005859375,3402.6807861328125,3415.0906778971353,3425.4506022135415,3433.8904825846353,3440.5804036458335,3445.6503295898438,3449.220255533854,3451.4101765950522,3452.3401082356772,3452.10009765625,3450.789998372396,3448.499959309896,3445.3199259440103,3441.2998860677085,3436.5298665364585,3431.0798543294272,3424.989786783854,3418.329793294271,3411.1397705078125,3403.4797159830728,3395.389689127604,3386.8996785481772,3378.0596923828125,3368.9096883138022,3359.4595947265625,3349.7496134440103,3339.8095906575522,3329.6695963541665,3319.32958984375,3308.839599609375,3298.1995849609375,3287.4295654296875,3276.549560546875,3265.5695597330728,3254.509562174479,3243.3795776367188,3232.1795450846353,3220.9395548502603,3209.6595865885415,3198.3495483398438,3187.009562174479,3175.6595458984375,3164.28955078125,3152.9195556640625,3141.5495402018228,3130.1895751953125,3118.8394978841147,3107.499552408854,3096.1695556640625,3084.869588216146,3073.5895385742188,3062.3295288085938,3051.0995279947915,3039.8995157877603,3028.7295735677085,3017.5895792643228,3006.479532877604,2995.4095458984375,2984.3695475260415,2973.3695271809897,2962.4095662434897,2951.479532877604,2940.5895385742188,2929.7295532226562,2918.9195556640625,2908.1395874023438,2897.3995564778647,2886.6996053059897,2876.029541015625,2865.3995564778647,2854.809529622396,2844.249552408854,2833.729532877604,2823.2496134440103,2812.799560546875,2802.3895670572915,2792.009562174479,2781.6695760091147,2771.3595987955728,2761.089558919271,2750.8395792643228,2740.6295776367188,2730.4495646158853,2720.3095703125,2710.1895548502603,2700.1095581054688,2690.049519856771,2680.0296020507812,2670.029581705729,2660.0695597330728,2650.129597981771,2640.2195434570312,2630.32958984375,2620.4795735677085,2610.6395670572915,2600.839558919271,2591.0595499674478,2581.299560546875,2571.569539388021,2561.859578450521,2552.1695963541665,2542.509562174479,2532.8695678710938,2523.2495320638022,2513.6495564778647,2504.0795694986978,2494.519571940104,2484.9895629882812,2475.4696044921875,2465.9795735677085,2456.4995727539062,2447.0395711263022,2437.5995483398438,2428.1795857747397,2418.7795613606772,2409.3895670572915,2400.0195515950522,2390.6595662434897,2381.319580078125,2371.9995320638022,2362.6895751953125,2353.3895670572915,2344.1095581054688,2334.8495890299478,2325.5895792643228,2316.359578450521,2307.1295572916665,2297.9195353190103,2288.7195638020835,2279.53955078125,2270.3595581054688,2261.1995442708335,2252.0495808919272,2242.9095458984375,2233.7895711263022,2224.6696166992188,2215.5695597330728,2206.4695638020835,2197.3895263671875,2188.3195597330728,2179.2495727539062,2170.1995239257812,2161.1595458984375,2152.1195678710938,2143.0895792643228,2134.079549153646,2125.0695597330728,2116.0695597330728,2107.069539388021,2098.089640299479,2089.4796752929688,2081.5897013346353,2074.3397013346353,2067.69970703125,2061.5997924804688,2055.989786783854,2050.849812825521,2046.119852701823,2041.7798665364583,2037.7798767089844,2034.109883626302,2030.7198994954426,2027.6099039713542,2024.7299296061199,2022.0799255371094,2019.6299336751301,2017.3699442545574,2015.2799580891926,2013.3399861653645,2011.5399576822917,2009.8799743652344,2008.3299967447917,2006.8799947102864,2005.5399881998699,2004.290018717448,2003.1199849446614,2002.019999186198,2000.9900207519531,2000.030008951823,1999.1200256347656,1998.260009765625,1997.4500325520833,1996.6900126139324,1995.9600219726562,1995.2700093587239,1994.6200154622395,1993.9900004069011,1993.3900146484375,1992.8200276692708,1992.2700297037761,1991.7400309244792,1991.2300313313801,1990.7400512695312,1990.260030110677,1989.800028483073,1989.3500569661458,1988.9200337727864,1988.4900410970051,1988.0800374348958,1987.6700236002605,1987.2800598144531,1986.8900451660156,1986.5100402832031,1986.1400248209636,1985.7700500488281,1985.4100240071614,1985.0500386555989,1984.7000325520833,1984.3500467936199,1984.010030110677,1983.6700439453125,1983.3300476074219,1983.0000406901042,1982.6700439453125,1982.3400370279949,1982.020039876302,1981.7000528971355,1981.3800252278645,1981.0600687662761,1980.7500406901042,1980.4300333658855,1980.1200459798176,1979.8100484212239,1979.5000406901042,1979.2000528971355,1978.8900349934895,1978.5900472005208,1978.2900492350261,1977.9900410970051,1977.6900634765625,1977.3900451660156,1977.0900268554688,1976.7900492350261,1976.5000406901042,1976.2000528971355,1975.9100443522136,1975.6200358072917,1975.3300476074219,1975.040059407552,1974.7500508626301,1974.4600423177083,1974.1700439453125,1973.8900451660156,1973.6000671386719,1973.3200378417969,1973.0300394694011,1972.7500610351562,1972.4700317382812,1972.1800435384114,1971.9000549316406,1971.6200459798176,1971.3500264485676,1971.0700378417969,1970.7900288899739,1970.5100402832031,1970.2400410970051,1969.9600524902344,1969.6900329589844,1969.4200337727864,1969.1400451660156,1968.8700358072917,1968.6000467936199,1968.3300476074219,1968.0600484212239,1967.7900492350261,1967.520039876302,1967.260030110677,1966.9900512695312,1966.7300415039062,1966.4600423177083,1966.2000528971355,1965.9300435384114,1965.6700439453125,1965.4100545247395,1965.1500142415364,1964.8900451660156,1964.6300557454426,1964.3700459798176,1964.1100463867188,1963.8600463867188,1963.6000569661458,1963.3500162760417,1963.0900472005208,1962.8400472005208,1962.5800476074219,1962.3300374348958,1962.0800476074219,1961.830057779948,1961.5800374348958,1961.3300374348958,1961.0800374348958,1960.8300476074219,1960.5900573730469,1960.3400370279949,1960.0900573730469,1959.8500264485676,1959.6100463867188,1959.3600362141926,1959.1200358072917,1958.8800354003906,1958.6400553385417,1958.4000447591145,1958.1600443522136,1957.9200541178386,1957.6800231933594,1957.4400634765625,1957.2100321451824,1956.9700622558594,1956.7400512695312,1956.5000406901042,1956.2700602213542,1956.030049641927,1955.8000590006511,1955.570048014323,1955.3400573730469,1955.1100463867188,1954.8800354003906,1954.6500447591145,1954.4200337727864,1954.2000630696614,1953.9700520833333,1953.7400614420574,1953.5200602213542,1953.2900492350261,1953.0700378417969,1952.8500366210938,1952.6300455729167,1952.4000549316406,1952.1800638834636,1951.9600423177083,1951.7400410970051,1951.5200500488281,1951.3100484212239,1951.0900370279949,1950.8700561523438,1950.6600646972656,1950.4400329589844,1950.2300516764324,1950.0100606282551,1949.8000386555989,1949.5900472005208,1949.3700663248699,1949.1600646972656,1948.9500325520833,1948.7400309244792,1948.5300598144531,1948.320048014323,1948.1100362141926,1947.9100240071614,1947.7000528971355,1947.4900817871094,1947.2900390625,1947.0800476074219,1946.8800455729167,1946.6800537109375,1946.4700520833333,1946.270039876302,1946.0700581868489,1945.8700663248699,1945.6700439453125,1945.4700419108074,1945.2700500488281,1945.0700378417969,1944.8700561523438,1944.6700439453125,1944.4800516764324,1944.2800598144531,1944.0900573730469,1943.8900655110676,1943.7000528971355,1943.5000508626301,1943.31005859375,1943.1200358072917,1942.9300638834636,1942.7400614420574,1942.540059407552,1942.3500467936199,1942.1700337727864,1941.9800618489583,1941.790059407552,1941.6000569661458,1941.4100545247395,1941.2300516764324,1941.040059407552,1940.8600362141926,1940.6700541178386,1940.4900512695312,1940.300069173177,1940.1200561523438,1939.9400634765625,1939.7600504557292,1939.580057779948,1939.3900655110676,1939.2100524902344,1939.030049641927,1938.8600362141926,1938.6800638834636,1938.5000610351562,1938.4100545247395};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9484380086263,403.1169662475586,405.8129628499349,408.8319574991862,411.94596099853516,415.1549555460612,418.4609603881836,421.8429590861003,425.28295644124347,428.7839533487956,432.3469518025716,435.9749501546224,439.6699473063151,443.43195088704425,447.262944539388,451.16395060221356,455.1359507242839,459.1659469604492,463.24194590250653,467.36494700113934,471.53894297281903,475.76494852701825,480.0449447631836,484.3799463907878,488.7719421386719,493.220942179362,497.73093668619794,502.2919464111328,506.9009424845378,511.55694580078125,516.2639414469401,521.0209401448568,525.8299357096354,530.6919352213541,535.6089426676432,540.5809377034506,545.6099395751953,550.6909383138021,555.8219350179037,561.0039265950521,566.2389373779297,571.5259399414062,576.867919921875,582.2659403483073,587.7189381917318,593.2299397786459,598.7979329427084,604.4239349365234,610.1069386800131,615.846934000651,621.6469319661459,627.5049285888672,633.4229329427084,639.4019317626953,645.4419301350912,651.5439300537109,657.7079315185547,663.9339294433594,670.221923828125,676.5719350179037,682.9849446614584,689.460927327474,696.0019276936849,702.6059265136719,709.2749277750651,716.0079294840494,722.8079325358073,729.6789296468099,736.6289215087891,743.6569315592448,750.7639312744141,757.9509226481119,765.2159271240234,772.5609334309896,779.9839223225912,787.4879201253256,795.0699157714844,802.7359161376953,810.4889221191406,818.3279113769531,826.2539215087891,834.2669169108073,842.3669179280599,850.5539245605469,858.8289133707682,867.19091796875,875.6399129231771,884.1099141438802,892.5329132080078,900.9109191894531,909.2469126383463,917.5409291585287,925.7929178873698,934.0049235026041,942.1769104003906,950.3079274495443,958.3969268798828,966.4449208577474,974.4519297281901,982.4159240722656,990.3369293212891,998.2139231363932,1006.0499267578125,1013.8399302164713,1021.5799357096354,1029.2699279785156,1036.9199320475261,1044.5199076334636,1052.0799458821614,1059.5799255371094,1067.0299173990886,1074.4399312337239,1081.7899271647136,1089.0899454752605,1096.3299255371094,1103.5299275716145,1110.669942220052,1117.7499389648438,1124.7799479166667,1131.7599385579426,1138.669942220052,1145.5299173990886,1152.3399454752605,1159.0799357096355,1165.7699279785156,1172.3999430338542,1178.959940592448,1185.4699401855469,1191.9199625651042,1198.3099365234375,1204.6299540201824,1210.8899536132812,1217.0899556477864,1223.2299499511719,1229.2999267578125,1235.3199666341145,1241.2599487304688,1247.1499430338542,1252.9699300130208,1258.7399597167969,1264.449951171875,1270.0999450683594,1275.699951171875,1281.2299702962239,1286.6999613444011,1292.1099548339844,1297.4699300130208,1302.7599487304688,1307.9899597167969,1313.1599527994792,1318.2599589029949,1323.3099466959636,1328.2899475097656,1333.2099507649739,1338.0699462890625,1342.8699544270833,1347.5999654134114,1352.2699584960938,1356.8799540201824,1361.4199625651042,1365.8999532063801,1370.3199564615886,1374.6699625651042,1378.9599609375,1383.1799621582031,1387.3399658203125,1391.4399515787761,1395.4699605305989,1399.429951985677,1403.3299662272136,1407.1599731445312,1410.9299825032551,1414.6399637858074,1418.2699584960938,1421.8499755859375,1425.3499654134114,1428.7999674479167,1432.1699625651042,1435.4799702962239,1438.719970703125,1441.8999735514324,1445.0099690755208,1448.0499776204426,1451.0299784342449,1453.939961751302,1456.7899780273438,1459.5699768066406,1462.2799682617188,1464.9199625651042,1467.499979654948,1470.0099690755208,1472.459981282552,1474.8299865722656,1477.1399637858074,1479.3899637858074,1481.5599772135417,1483.6699829101562,1485.719991048177,1487.6899922688801,1489.5999959309895,1491.4399820963542,1493.219970703125,1494.9199930826824,1496.5599873860676,1498.1399943033855,1499.6399841308594,1501.0799763997395,1502.4499816894531,1503.7599792480469,1504.9900004069011,1506.1599934895833,1507.259989420573,1508.2999979654949,1509.269999186198,1510.1699727376301,1510.9999898274739,1511.7699890136719,1512.4700012207031,1513.0999959309895,1513.6699930826824,1514.1700032552083,1514.6000061035156,1514.9700012207031,1515.2699890136719,1515.4999898274739,1515.6600036621094,1515.7599995930989,1515.7899983723958,1515.760009765625,1515.6600036621094,1515.489990234375,1515.2500101725261,1514.9499918619792,1514.5799967447917,1514.1499837239583,1513.6499938964844,1513.0799967447917,1512.4799906412761,1511.8899943033855,1511.2899983723958,1510.6900024414062,1510.1000061035156,1509.5,1508.8899943033855,1508.2899983723958,1507.6800231933594,1507.0799967447917,1506.469991048177,1505.8600056966145,1505.239990234375,1504.6299947102864,1504.010009765625,1503.3899841308594,1502.769999186198,1502.1500040690105,1501.5299886067708,1500.8999837239583,1500.280029296875,1499.6599833170574,1499.0299987792969,1498.3999837239583,1497.7799886067708,1497.1499938964844,1496.519999186198,1495.8900044759114,1495.2699890136719,1494.6400146484375,1494.0099995930989,1493.3799947102864,1492.75,1492.1199951171875,1491.5,1490.8699951171875,1490.2399800618489,1489.6199747721355,1488.990010579427,1488.3600056966145,1487.739990234375,1487.1099955240886,1486.4900004069011,1485.8599955240886,1485.240010579427,1484.6100056966145,1483.990010579427,1483.3700052897136,1482.75,1482.1199849446614,1481.4999898274739,1480.8800048828125,1480.260009765625,1479.6400044759114,1479.0200093587239,1478.4000040690105,1477.7899983723958,1477.1700032552083,1476.5500081380208,1475.9400024414062,1475.3199971516926,1474.709981282552,1474.0899963378906,1473.480000813802,1472.8700052897136,1472.25,1471.6399943033855,1471.0299987792969,1470.4200032552083,1469.8099975585938,1469.1999918619792,1468.5900065104167,1467.980000813802,1467.3800048828125,1466.769999186198,1466.1600036621094,1465.5599975585938,1464.9500020345051,1464.3499959309895,1463.739990234375,1463.1399943033855,1462.5399983723958,1461.9299825032551,1461.3299865722656,1460.730000813802,1460.1300048828125,1459.530008951823,1458.9299926757812,1458.3400065104167,1457.7400004069011,1457.1399943033855,1456.5399881998699,1455.9500122070312,1455.3499959309895,1454.759989420573,1454.1599934895833,1453.5699971516926,1452.9800109863281,1452.3900044759114,1451.7899983723958,1451.2000020345051,1450.6100260416667,1450.0199890136719,1449.4300028483074,1448.8500061035156,1448.2599792480469,1447.6699930826824,1447.0899963378906,1446.5,1445.9100138346355,1445.3300069173176,1444.75,1444.1600036621094,1443.5800170898438,1443.0,1442.4199930826824,1441.8400065104167,1441.259989420573,1440.6800028483074,1440.0999857584636,1439.519999186198,1438.9399820963542,1438.3699951171875,1437.7899881998699,1437.2099914550781,1436.6400146484375,1436.0600077311199,1435.489990234375,1434.9200032552083,1434.3499959309895,1433.7700093587239,1433.1999918619792,1432.6300048828125,1432.0599975585938,1431.4900004069011,1430.9200134277344,1430.3599955240886,1429.7899881998699,1429.219991048177,1428.6600036621094,1428.0899861653645,1427.5299886067708,1426.9600016276042,1426.4000142415364,1425.8400065104167,1425.2799987792969,1424.709981282552,1424.1499938964844,1423.5899861653645,1423.030008951823,1422.480000813802,1421.9199829101562,1421.3599853515625,1420.7999979654949,1420.25,1419.6899820963542,1419.1399943033855,1418.5799865722656,1418.030008951823,1417.4799906412761,1416.9200032552083,1416.3699951171875,1415.8199971516926,1415.2699890136719,1414.7200012207031,1414.1699930826824,1413.6299947102864,1413.0800170898438,1412.5299886067708,1411.9799906412761,1411.4399820963542,1410.8899943033855,1410.3499959309895,1409.8100077311199,1409.260009765625,1408.719991048177,1408.1799926757812,1407.6400044759114,1407.0999959309895,1406.5599873860676,1406.0199788411458,1405.4799906412761,1404.9399820963542,1404.4100036621094,1403.8700052897136,1403.3300069173176,1402.7999979654949,1402.260009765625,1401.730000813802,1401.2000122070312,1400.6599934895833,1400.1300150553386,1399.5999857584636,1399.0699869791667,1398.5400085449219,1398.009989420573,1397.4799906412761,1396.9500122070312,1396.4300028483074,1395.8999938964844,1395.3700052897136,1394.8499959309895,1394.3200073242188,1393.7999979654949,1393.2799987792969,1392.7499898274739,1392.230000813802,1391.7100016276042,1391.1900024414062,1390.6699829101562,1390.1500040690105,1389.6300048828125,1389.1100158691406,1388.5999959309895,1388.0799967447917,1387.5599975585938,1387.0500081380208,1386.5299987792969,1386.0200093587239,1385.5000101725261,1384.990010579427,1384.480000813802,1383.9700012207031,1383.4499918619792,1382.9399922688801,1382.4299926757812,1381.9300028483074,1381.4199930826824,1380.9100036621094,1380.4000040690105,1379.8899943033855,1379.3899943033855,1378.8800048828125,1378.3799947102864,1377.8699951171875,1377.3700052897136,1376.8699951171875,1376.3599955240886,1375.8599955240886,1375.3600056966145,1374.8600260416667,1374.3599853515625,1373.8600056966145,1373.3599955240886,1372.8699849446614,1372.3699951171875,1371.8699849446614,1371.3800048828125,1371.1300048828125};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.754984617233276,21.18809429804484,23.484392801920574,27.654491901397705,32.42229096094767,37.76749038696289,43.67028967539469,49.88598918914795,56.17848873138428,62.54588921864828,68.9858881632487,75.4966869354248,82.07608731587727,88.72248649597168,95.43378575642903,102.20798619588216,109.0439847310384,115.89598655700684,122.71898587544759,129.5139840443929,136.2829844156901,143.02598571777344,149.74398549397787,156.43998591105142,163.11198298136392,169.7619832356771,176.3919817606608,182.97798538208008,189.49998092651367,195.95998255411783,202.3609822591146,208.70398330688477,214.9899813334147,221.22298304239908,227.40298461914062,233.5329818725586,239.61298116048178,245.61798222859701,251.52198028564453,257.3299814860026,263.0439809163411,268.66698201497394,274.20298767089844,279.6539815266927,285.02298227945965,290.312983194987,295.5269826253255,300.66898345947266,305.7439829508464,310.7549794514974,315.7029800415039,320.59098052978516,325.4199803670247,330.19197845458984,334.9089762369792,339.5719807942708,344.18298085530597,348.74997965494794,353.2809778849284,357.77697499593097,362.2389729817708,366.66697692871094,371.06297810872394,375.4269841512044,379.760981241862,384.0649770100911,388.33897908528644,392.57297770182294,396.7549769083659,400.88798268636066,404.9719721476237,409.00697326660156,412.9949773152669,416.9359766642253,420.8319727579753,424.6839777628581,428.49097951253253,432.2659734090169,436.0179748535156,439.7479756673177,443.45597585042316,447.14198048909503,450.80696868896484,454.4499740600586,458.0719757080078,461.6729736328125,465.2529780069987,468.69897715250653,471.9029719034831,474.86897532145184,477.6029764811198,480.1089782714844,482.39398193359375,484.46297454833984,486.3219757080078,487.9759826660156,489.42997487386066,490.68997446695965,491.76197814941406,492.6499760945638,493.36098225911456,493.8989741007487,494.2689793904622,494.4769770304362,494.5279769897461,494.4259796142578,494.1759770711263,493.78397878011066,493.2539774576823,492.58997599283856,491.79698181152344,490.8789800008138,489.8409779866536,488.68697865804035,487.4209849039714,486.0459849039714,484.5669809977214,482.9879786173503,481.31298065185547,479.54397837320965,477.6849848429362,475.7409845987956,473.7129847208659,471.6059850056966,469.42298126220703,467.16598256429035,464.83797963460285,462.44298299153644,459.9839833577474,457.4619827270508,454.8799819946289,452.24198150634766,449.5489781697591,446.80398813883465,444.0089848836263,441.16598256429035,438.2779820760091,435.3459828694661,432.37398529052734,429.36098225911456,426.3109817504883,423.22498575846356,420.104985555013,416.9529851277669,413.76898701985675,410.5569839477539,407.31697845458984,404.04998779296875,400.7589874267578,397.44398498535156,394.1069869995117,390.74798583984375,387.36998494466144,383.97298940022785,380.5589879353841,377.1269887288411,373.68098704020184,370.218989054362,366.7439905802409,363.25699106852215,359.75699106852215,356.24698638916016,352.72598520914715,349.1949869791667,345.6559880574544,342.1079915364583,338.55298614501953,334.9919891357422,331.42398834228516,327.84999084472656,324.27198537190753,320.68799082438153,317.1009928385417,313.50999450683594,309.9159876505534,306.3189875284831,302.7199935913086,299.11999257405597,295.5169957478841,291.9139912923177,288.3089904785156,284.70399220784503,281.09898630777997,277.49398549397785,273.88999430338544,270.2859929402669,266.68299102783203,263.08098856608075,259.4799982706706,255.8809954325358,252.28399276733398,248.68799209594727,245.0949935913086,241.5039939880371,237.91499201456705,234.32899602254233,230.7449951171875,227.16399256388345,223.58599344889322,220.0119972229004,216.43999481201172,212.87099583943686,209.30599466959634,205.74399439493814,202.18499628702799,198.6309954325358,195.0789934794108,191.53099568684897,187.98699569702148,184.4469960530599,180.90999348958334,177.37699762980142,173.84799448649088,170.32199478149414,166.80099614461264,163.28299713134766,159.76899592081705,156.2599957784017,152.75399907430014,149.2509969075521,145.75299708048502,142.25899505615234,138.76899846394858,135.28199768066406,131.7989985148112,128.32099787394205,124.84599685668945,121.37499936421712,117.9069995880127,114.44399897257487,110.98399988810222,107.5279992421468,104.07599957784016,100.62800025939941,97.18289947509766,93.74179967244466,90.30439949035645,86.93129984537761,83.68120002746582,80.54980087280273,77.53319994608562,74.62750053405762,71.82880020141602,69.13339869181316,66.53769938151042,64.03820006052653,61.63139979044596,59.31409994761149,57.08300050099691,54.9350004196167,52.86710007985433,50.87650012969971,48.9603001276652,47.115699768066406,45.340200424194336,43.631199518839516,41.986300468444824,40.40300019582113,38.87920061747233,37.4127000172933,36.001200358072914,34.64280001322428,33.335400899251304,32.07719977696737,30.866400082906086,29.701199690500896,28.579799969991047,27.50060002009074,26.46209987004598,25.462800184885662,24.500999927520752,23.575599988301594,22.68499994277954,21.82800006866455,21.00339984893799,20.209800084431965,19.446199893951416,18.711300055185955,18.004200140635174,17.32380024592082,16.669099807739258,16.039100011189777,15.432799895604452,14.849499940872192,14.28820006052653,13.747999986012777,13.228300015131632,12.72819995880127,12.247000058492025,11.783900022506714,11.33840004603068,10.909599939982096,10.497100035349527,10.100200096766153,9.718220074971518,9.35069990158081,8.99706999460856,8.656800111134848,8.329380114873251,8.014340003331503,7.711210052172343,7.419529994328816,7.1388799746831255,6.86883004506429,6.60899003346761,6.358969887097676,6.118409991264343,5.886929988861084,5.664210041364034,5.449910044670105,5.243710001309712,5.0453100601832075,4.854399998982747,4.6707199811935425,4.493980050086975,4.323920051256816,4.160300056139628,4.002859989802043,3.8513799905776978,3.705619970957438,3.5653799970944724,3.430449982484182,3.3006100257237754,3.175690015157064,3.055489977200826,2.939839998881022,2.828560014565786,2.7214900056521096,2.6184799671173096,2.5193600058555603,2.423989991346995,2.332229971885681,2.243939995765686,2.158989985783895,2.0772500236829123,1.9986099700133007,1.9229400058587391,1.8501399954160054,1.7800900042057037,1.7126900056997936,1.647839993238449,1.5854500035444896,1.5254200100898743,1.467659999926885,1.4120800097783406,1.3586099743843079,1.3071700036525726,1.257670005162557,1.2100400030612946,1.164220005273819,1.1201299925645192,1.0777100125948589,1.0368900001049042,0.9976250032583872,0.9598420063654581,0.9234899977842966,0.8885129988193512,0.8548609962066015,0.8224829932053884,0.791331003109614,0.7613589962323507,0.7325209975242615,0.7047749906778336,0.6780789891878763,0.6523950000603994,0.6276829987764359,0.6039059907197952,0.5810300062100092,0.5590199927488962,0.5378439972798029,0.5174700071414312,0.49786699811617535,0.4790060023466746,0.4608600015441577,0.44340099891026813,0.4266029993693034,0.41044199963410694,0.39489199966192245,0.3799319962660472,0.36553800106048584,0.3516890009244283,0.33836500098307926,0.3255450005332629,0.31321100393931073,0.30134400228659314,0.28992699831724167,0.2789420038461685,0.26837300260861713,0.25820500155289966,0.24842099845409393,0.2390089991192023,0.22995299970110258,0.22124000142018,0.21285699928800264,0.2047909994920095,0.19703099876642227,0.1895660012960434,0.18238300209244093,0.17547200123469034,0.16882300128539404,0.16242500146230063,0.15627100070317587,0.150348998606205,0.14465200155973434,0.13916999970873198,0.1338970015446345,0.12882299845417342,0.12394100055098534,0.11924399932225545,0.11472600015501182,0.11037799964348476,0.10619499968985717,0.10217100009322166,0.09829909975330035,0.09457399944464366,0.09099000009397666,0.08754180061320464,0.08422430045902729,0.08103250029186408,0.0779617006580035,0.07500720024108887,0.07216460009415944,0.06942979991436005,0.06679870126148064,0.06426720072825749,0.06183159941186508,0.059488399885594845,0.05723389952133099,0.05506489984691143,0.05297810025513172,0.05097030010074377,0.049038700138529144,0.04718019968519608,0.04539220004032055,0.04367189947515726,0.04201689983407656,0.04042449966073036,0.03889250010251999,0.03741859986136357,0.036000500433146954,0.03463610013326009,0.033323499684532486,0.03206059988588095,0.030845599869887035,0.029676600048939388,0.028551900293678045,0.027469899971038103,0.02642880007624626,0.025427200210591156,0.024463600013405085,0.023536500055342913,0.022644500248134136,0.021786299844582874,0.020960699766874313,0.020166300081958372,0.019402099928508203,0.01866680011153221,0.017959400080144405,0.017278799942384165,0.016623900116731722,0.015994000093390543,0.015387800056487322,0.01480470000145336,0.014243600036328038,0.01370390000132223,0.01318450008208553,0.012684900080785155,0.012204200106983384,0.011741699961324533,0.011296700065334639,0.010868599948783716,0.010456799995154142,0.010060500043133894,0.009679249953478575,0.009312450032060346,0.008959560034175714,0.008620039947951833,0.00829338988599678,0.007979120050246516,0.007676760006385545,0.0073858499915028615,0.007105979913224776,0.006836709954465429,0.006577640112179021,0.006328389941093822,0.006206179969012737};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76873016357422,90.27674547831218,96.15281359354655,101.12263425191243,106.07874488830566,111.01973342895508,115.94567743937175,120.59212239583333,124.71738878885905,128.35975710550943,131.5551643371582,134.33561197916666,136.73210271199545,138.7726287841797,140.48219680786133,141.88477579752603,143.00241216023764,143.93621953328451,144.7761090596517,145.5299924214681,146.2018814086914,146.79878362019858,147.32468795776367,147.78459803263345,148.181516011556,148.52043533325195,148.80436833699545,149.08238983154297,149.40045293172201,149.75349553426108,150.14053853352866,150.55757776896158,151.00261942545572,151.47265116373697,151.96568171183267,152.47970962524414,153.01373418172201,153.5497283935547,154.07471338907877,154.58769353230795,155.08967971801758,155.58166631062826,156.06365331013998,156.53563944498697,156.99863052368164,157.4536158243815,157.89960606892905,158.35763295491537,158.84367497762045,159.35771306355795,159.89574178059897,160.45677439371744,161.03880055745444,161.64082717895508,162.25984827677408,162.8948720296224,163.54389190673828,164.23496627807617,164.9910570780436,165.80913798014322,166.68221028645834,167.60828272501627,168.5813420613607,169.60040918986002,170.66045888264975,171.75851186116537,172.89255650838217,174.06561152140299,175.28167215983072,176.53672409057617,177.82877604166666,179.15281422932944,180.5078582763672,181.8898900349935,183.29692586263022,184.72595342000326,186.17698542277017,187.65602747599283,189.17007700602213,190.71711858113608,192.2941576639811,193.89919662475586,195.52822621663412,197.18025588989258,198.8532854715983,200.54431788126627,202.2523307800293,203.85309219360352,205.23078028361002,206.39650344848633,207.36423619588217,208.14599100748697,208.75275421142578,209.19453557332358,209.48333104451498,209.62613677978516,209.63395818074545,209.51578903198242,209.2776311238607,208.92948277791342,208.4783452351888,207.93021774291992,207.29209645589194,206.56998570760092,205.7698834737142,204.89778518676758,203.95869827270508,202.95661417643228,201.89653778076172,200.78346506754556,199.62039947509766,198.41234079996744,197.16228739420572,195.87423451741537,194.55018742879233,193.19314448038736,191.80710474650064,190.39306767781576,188.95503616333008,187.4950065612793,186.01397959391275,184.51495488484701,182.99993515014648,181.46991348266602,179.92589569091797,178.3708839416504,176.80587005615234,175.23185857137045,173.64984766642252,172.06083806355795,170.46682993570963,168.86782455444336,167.26482137044272,165.65881474812826,164.05081431070963,162.44081115722656,160.8298110961914,159.21881103515625,157.6078109741211,155.9978116353353,154.38781356811523,152.77981440226236,151.17381795247397,149.56982040405273,147.96882502237955,146.36982854207358,144.77483367919922,143.18183390299478,141.59284337361655,140.0068448384603,138.42485173543295,136.84685643513998,135.2728614807129,133.7028694152832,132.13687388102213,130.57487996419272,129.01788520812988,127.46489143371582,125.91589609781902,124.37090174357097,122.8309097290039,121.29491424560547,119.7639217376709,118.23692639668782,116.71493339538574,115.19593620300293,113.68294715881348,112.17294692993164,110.66795794169109,109.16695976257324,107.66996828715007,106.17797533671062,104.68897819519043,103.20498593648274,101.72498766581218,100.24899673461914,98.7765998840332,97.30820528666179,95.84381103515625,94.38321685791016,92.9263203938802,91.47312482198079,90.02353032430013,88.57763608296712,87.13524119059245,85.69624519348145,84.26075045267741,82.82855542500813,81.39975929260254,79.9741636912028,78.55176798502605,77.13257217407227,75.71647707621257,74.30338096618652,72.89318339029948,71.48608716328938,70.08179219563802,68.6802978515625,67.28160031636556,65.88570404052734,64.49240716298421,63.10181109110514,61.71381409962972,60.32831732432047,58.94532044728597,57.564724604288735,56.18652820587158,54.810730934143066,53.43723392486572,52.06603686014811,50.69704023996989,49.3302427927653,47.965545972188316,46.60294882456461,45.24245103200277,43.88395436604818,42.52755641937256,41.172959645589195,39.82036209106445,38.46956411997477,37.120667139689125,35.77366924285889,34.42827129364014,33.084774335225426,31.742876211802166,30.40267848968506,29.064181009928387,27.727283000946045,26.39188512166341,25.05818732579549,23.725889046986897,22.395191351572674,21.06589349110921,19.738094965616863,18.41169786453247,17.086796760559082,15.763204654057821,14.49300773938497,13.324155807495117,12.248574256896973,11.259090503056845,10.34879438082377,9.511601686477661,8.74163031578064,8.033592621485392,7.382558027903239,6.783997615178426,6.233731587727864,5.727890412012736,5.262914419174194,4.835544308026631,4.442749977111816,4.081762154897054,3.750010848045349,3.4451564947764077,3.1650091807047525,2.907589296499888,2.67106693983078,2.453742345174154,2.254055678844452,2.0705971916516623,1.9020468990008037,1.7471950352191925,1.6049317121505737,1.4742370148499806,1.354171097278595,1.2438740034898121,1.1425458788871765,1.0494667887687683,0.9639598280191422,0.885415052374204,0.8132635056972504,0.7469872832298279,0.6861074268817902,0.6301859964927038,0.578819011648496,0.5316355476776758,0.48829563707113266,0.4484873165686925,0.4119216079513232,0.37833554297685623,0.3474871714909871,0.31915150086085003,0.29312555988629657,0.26922136048475903,0.2472649378081163,0.22709831098715463,0.20857648427287737,0.19156348581115404,0.1759383206566175,0.16158600772420564,0.1484055556356907,0.13629897559682527,0.12517928332090378,0.11496648502846558,0.10558658527831237,0.09697199861208598,0.08905982909103234,0.08179298291603725,0.07511876647671063,0.06898898755510648,0.06335925031453371,0.05818875723828872,0.05344001576304436,0.04907872807234526,0.04507319908589125,0.041394531105955444,0.03801592874030272,0.03491309378296137,0.032063328816245,0.029446136361608904,0.027042518990735214,0.02483497823898991,0.02280761720612645,0.02094573558618625,0.019235736845682066,0.017665321628252666,0.016223091321686905,0.014898647166167697,0.013682190096005797,0.012565021558354298,0.011539142346009612,0.010596953021983305,0.009731634830435118,0.00893697856614987,0.00820720405317843,0.007536993051568667,0.006921505439095199,0.0063562620198354125,0.00583717308472842,0.005360459132740895,0.0049226706226666766,0.004520627941625814,0.004151411393346886,0.0038123412523418665,0.0035009579150937498,0.0032150015661803386,0.0029523924846823015,0.0027112408618753157,0.002489766882111629,0.0022863908282791576,0.0020996228364917138,0.0019281030011673768,0.0017705915573363502,0.0016259485855698586,0.001493114201972882,0.0013711385739346345,0.0012591217431084563,0.001156253876009335,0.0010617849766276777,0.0009750342045056944,0.0008953705740471681,0.0008222141817289715,0.0007550340960733593,0.0006933423574082553,0.0006366900245969495,0.0005846651474712417,0.0005368917724505687,0.0004930199332496462,0.00045273368596099317,0.0004157380390097387,0.0003817650431301445,0.0003505677135156778,0.0003219200856013534,0.00029561218252638355,0.00027145402661214274,0.00024926964033511467,0.00022889904357725754,0.0002101912408155234,0.00019301326877515143,0.0001772391248474984,0.00016275383071236624,0.00014945139385721026,0.00013723683635665415,0.00012602015400868064,0.00011572037025568231,0.00010626148165708098,9.757650817239967e-05,8.960094358675026e-05,8.22773102602999e-05,7.555209837543468e-05,6.93765286996495e-05,6.370569493204432e-05,5.849840969555468e-05,5.371667126989147e-05,4.932568905739269e-05,4.529366409163534e-05,4.159120059436342e-05,3.819130051851971e-05,3.5069368702049054e-05,3.220260653809722e-05,2.957011611215421e-05,2.7152801218714256e-05,2.4933062528968247e-05,2.2894802593024604e-05,2.102322332575568e-05,1.930452541879883e-05,1.772631154987418e-05,1.627718180922481e-05,1.4946438871750919e-05,1.3724582989501263e-05,1.2602515046940729e-05,1.1572236492914575e-05,1.0626147892859686e-05,9.75738036383215e-06,8.959654299663574e-06,8.227140597227844e-06,7.554519849387968e-06,6.936882641639386e-06,6.369729400527528e-06,5.848950801616108e-06,5.370747165519181e-06,4.931638917090216e-06,4.5284264539683745e-06,4.1581801042411826e-06,3.818210094171566e-06,3.506026852543679e-06,3.219370626084128e-06,2.956151661237527e-06,2.714450166270884e-06,2.492506249988461e-06,2.2887102962461845e-06,2.101582348738399e-06,1.929752585283495e-06,1.771961194663163e-06,1.6270782718189973e-06,1.4940439522585318e-06,1.3718883546213572e-06,1.259711533900069e-06,1.156713703191296e-06,1.0621348470370624e-06,9.752900732943697e-07,8.955454688930331e-07,8.223200988292471e-07,7.550830218860938e-07,6.933432956657271e-07,6.366509760861542e-07,5.845951089137694e-07,5.367947437662224e-07,4.929039173854713e-07,4.5260066391013726e-07,4.155930308039994e-07,3.8161203264053256e-07,3.504087094559812e-07,3.217570849756157e-07,2.954481862123733e-07,2.7129102875278477e-07,2.491086460073196e-07,2.2873904370612763e-07,2.100362503180501e-07,1.9286227370685083e-07,1.770931336390428e-07,1.6261283638148902e-07,1.4931640516617031e-07,1.3710784330100978e-07,1.2589716528547493e-07,1.1560237744845381e-07,1.0615049224801017e-07,1.6655923455270265e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.743229468663532,19.401511351267498,20.73361603418986,23.086318333943684,25.72521988550822,28.644521872202557,31.838222980499268,35.20372327168783,38.640723864237465,42.14782555898031,45.723825772603355,49.367326418558754,53.07722695668539,56.85222816467285,60.69112904866537,64.59282938639323,68.55612881978352,72.5718313852946,76.63113149007161,80.7330322265625,84.87693214416504,89.06203397115071,93.28743362426758,97.55233573913574,101.85603586832683,106.19803682963054,110.57703717549641,114.97803688049316,119.38603846232097,123.80003865559895,128.22103945414224,132.64904022216797,137.0820401509603,141.52204004923502,145.96803919474283,150.42004267374674,154.87704213460287,159.3210423787435,163.73104349772134,168.1080436706543,172.45404179890951,176.76804224650064,181.0520451863607,185.30504353841147,189.53004455566406,193.72604624430338,197.89304478963217,202.04004669189453,206.17204666137695,210.29104868570963,214.39604695638022,218.4880485534668,222.5670483907064,226.6320482889811,230.68504842122397,234.72604751586914,238.75404739379883,242.77205022176108,246.78205108642578,250.78404998779297,254.77704874674478,258.76305135091144,262.74105072021484,266.71205139160156,270.67405192057294,274.6290537516276,278.5760548909505,282.5050532023112,286.40405019124347,290.2740529378255,294.1140492757161,297.9260559082031,301.7090555826823,305.4640528361003,309.19105529785156,312.8910547892253,316.5630569458008,320.2140579223633,323.8500569661458,327.47105407714844,331.0770543416341,334.66905466715497,338.2460581461589,341.80806223551434,345.35505930582684,348.88805898030597,352.4060567220052,355.84605662027997,359.14505767822266,362.30505625406903,365.3270568847656,368.21405537923175,370.96605173746747,373.5870539347331,376.0770543416341,378.43905385335285,380.67505137125653,382.7860565185547,384.7760543823242,386.64505259195965,388.3960494995117,390.0300547281901,391.5510533650716,392.96004994710285,394.258051554362,395.44905344645184,396.53404998779297,397.51404571533203,398.39305369059247,399.1710484822591,399.85204823811847,400.43605041503906,400.9270528157552,401.3250452677409,401.63204701741535,401.852045694987,401.98404184977215,402.03204345703125,401.9970448811849,401.88004302978516,401.68404388427734,401.41104380289715,401.06104278564453,400.6370442708333,400.1410420735677,399.5730438232422,398.936040242513,398.23104095458984,397.4600423177083,396.62504323323566,395.7260386149089,394.7650400797526,393.74403889973956,392.66503651936847,391.52803802490234,390.3350346883138,389.0870361328125,387.7860336303711,386.4330342610677,385.02903238932294,383.57603454589844,382.0750376383464,380.52603403727215,378.93203989664715,377.2930374145508,375.6100387573242,373.8850351969401,372.11903381347656,370.31203206380206,368.4660339355469,366.58203125,364.66103108723956,362.70304107666016,360.7100321451823,358.68302663167316,356.62303415934247,354.53003184000653,352.405029296875,350.249028523763,348.0640284220378,345.8490295410156,343.6070251464844,341.3360290527344,339.0390319824219,336.7160237630208,334.36802927652997,331.9950230916341,329.5980275472005,327.1780293782552,324.7350209554036,322.2710240681966,319.78502655029297,317.2790222167969,314.7520243326823,312.20602162679035,309.6420211791992,307.0590235392253,304.4580256144206,301.84002176920575,299.2050196329753,296.5550231933594,293.88801829020184,291.20601654052734,288.51001993815106,285.79901631673175,283.0740203857422,280.33602142333984,277.58502197265625,274.8210194905599,272.0450134277344,269.25801849365234,266.45801544189453,263.6480127970378,260.82801818847656,257.9960199991862,255.1550153096517,252.30501429239908,249.4440129597982,246.57501220703125,243.6980120340983,240.8110148111979,237.91701126098633,235.015012105306,232.1050148010254,229.1880111694336,226.26401011149088,223.33301289876303,220.3960100809733,217.4520123799642,214.5030059814453,211.5470085144043,208.58600997924805,205.62001037597656,202.64800771077475,199.67100779215494,196.69000879923502,193.70300674438477,190.71300633748373,187.7180061340332,184.71900685628256,181.71600468953451,178.7100067138672,175.70000330607095,172.68600463867188,169.66900507609049,166.6490046183268,163.62700271606445,160.60100428263345,157.57200368245444,154.54100545247397,151.50700251261392,148.47100194295248,145.43300120035806,142.39299901326498,139.34999974568686,136.30599975585938,133.2599983215332,130.24599965413412,127.29799969991048,124.414000193278,121.5930004119873,118.8350003560384,116.1369997660319,113.49899991353352,110.91899998982747,108.39699935913086,105.93099975585938,103.52099990844727,101.16399955749512,98.85989952087402,96.60779889424641,94.4063008626302,92.25429979960124,90.15089988708496,88.09499994913737,86.08550135294597,84.12149874369304,82.20190111796062,80.3257999420166,78.49219957987468,76.70029894510905,74.94890022277832,73.23740005493164,71.56470108032227,69.93010012308757,68.33260091145833,66.77150026957194,65.2459004720052,63.75500075022379,62.2980006535848,60.87429968516032,59.48289998372396,58.12329991658529,56.79469966888428,55.49630037943522,54.22760009765625,52.98780028025309,51.776299476623535,50.59239991505941,49.43550046284994,48.30500030517578,47.200300216674805,46.12080001831055,45.06600030263265,44.035200119018555,43.02800019582113,42.043800354003906,41.08210055033366,40.14229996999105,39.22400029500326,38.326599756876625,37.44980017344157,36.59289995829264,35.75570011138916,34.93759950002035,34.13819948832194,33.35700035095215,32.59369977315267,31.847800254821777,31.11900011698405,30.406800111134846,29.710999965667725,29.0310001373291,28.36650021870931,27.717299938201904,27.082900047302246,26.463000297546387,25.857199827829998,25.265399932861328,24.686999797821045,24.1218999226888,23.569700082143147,23.03010018666585,22.50280014673869,21.98770014444987,21.484300136566162,20.992400010426838,20.511699835459392,20.042099793752033,19.583200136820476,19.13479995727539,18.69660011927287,18.268500169118244,17.850200176239014,17.441399892171223,17.04199981689453,16.651700019836426,16.270400047302246,15.897800048192343,15.533699909845987,15.177899837493896,14.830299933751425,14.490599950154623,14.158700068791708,13.834399859110514,13.517500003178915,13.207899967829386,12.905399878819784,12.609699964523315,12.320899963378906,12.038700024286905,11.762900034586588,11.49340001742045,11.23009999593099,10.972800016403198,10.721499999364218,10.475799878438314,10.23580002784729,10.001299937566122,9.772180080413818,9.548290014266968,9.329519828160604,9.115760087966919,8.906890074412027,8.702809969584147,8.503400007883707,8.308559974034628,8.11817995707194,7.932149926821391,7.75039005279541,7.572789986928304,7.39926000436147,7.229700048764546,7.064030011494954,6.90215003490448,6.743969957033793,6.589420040448506,6.4384100039800005,6.290860056877136,6.146690050760905,6.005819996198018,5.8681700229644775,5.7336799303690595,5.602269967397054,5.473880012830098,5.348420023918152,5.22583011786143,5.106060028076172,4.989029963811238,4.874680002530416,4.76295002301534,4.653780023256938,4.547110001246135,4.442879994710286,4.341040054957072,4.24153999487559,4.144320011138916,4.049319942792256,3.956500013669332,3.865809977054596,3.7771899700164795,3.6906099915504456,3.6060099999109902,3.5233500003814697,3.442580004533132,3.3636600176493325,3.2865599592526755,3.2112199664115906,3.137600004673004,3.0656699935595193,2.995399991671244,2.92672997713089,2.859630008538564,2.7940799792607627,2.730019986629486,2.6674399773279824,2.60629004240036,2.5465399821599326,2.4881499807039895,2.4311099847157798,2.375380019346873,2.320919990539551,2.267710030078888,2.215720017751058,2.1649200518925986,2.115290025870005,2.0668000181516013,2.019409994284312,1.9731099903583527,1.9278799891471863,1.8836799959341686,1.8404900133609772,1.7982900142669678,1.757070004940033,1.716779996951421,1.6774200002352397,1.6389599839846294,1.60139000415802,1.5646699965000153,1.5288000007470448,1.4937500059604645,1.4594999849796295,1.42603999376297,1.3933399816354115,1.3614000082015991,1.3301799992720287,1.2996900180975597,1.2698899904886882,1.240770012140274,1.212330013513565,1.184529999891917,1.157370001077652,1.130840003490448,1.1049099961916606,1.0795799891153972,1.0548300047715504,1.0306399861971538,1.0070100078980129,0.983924999833107,0.961366002758344,0.9393249998490015,0.917789007226626,0.8967470029989878,0.8761870016654333,0.8560990045468012,0.8364710013071696,0.8172930032014847,0.798555001616478,0.7802470028400421,0.7623580098152161,0.7448800007502238,0.7278030018011729,0.7111170093218485,0.6948130031426748,0.6788839995861053,0.6633190015951792,0.6481119990348816,0.6332529981931051,0.6187349955240885,0.6045500040054321,0.5906900018453598,0.5771480003992716,0.5639160027106603,0.5509879936774572,0.5383570045232773,0.5260139952103297,0.5139550020297369,0.5021730040510496,0.4906600018342336,0.4794119993845622,0.4684220030903816,0.4576830019553502,0.4471909950176875,0.4369389961163203,0.4269229993224144,0.42197200159231824};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473873655001323,7.644769748051961,7.675466020901998,7.679547429084778,7.670038183530171,7.653460065523784,7.633288621902466,7.551548043886821,7.3779200712839765,7.156467874844869,6.9100520213445025,6.6504156192143755,6.383626659711202,6.112817128499349,5.839595198631287,5.5648205280303955,5.288856307665507,5.056444923082988,4.891088167826335,4.760454018910726,4.647631764411926,4.543886820475261,4.444628874460856,4.347516099611918,4.25130307674408,4.155376374721527,4.0594108899434405,3.9797688722610474,3.9251266519228616,3.883536994457245,3.8486544489860535,3.817198932170868,3.787435988585154,3.7584747076034546,3.7298242648442588,3.7012343406677246,3.672584354877472,3.644492487112681,3.6173006097475686,3.5905001163482666,3.5638298988342285,3.5371400515238443,3.5103602409362793,3.4834705789883933,3.4564307729403176,3.4292315244674683,3.401871065298716,3.3779499530792236,3.3593983252843223,3.3436644474665322,3.3293515841166177,3.3157406051953635,3.302440027395884,3.2892698844273887,3.276099900404612,3.262870272000631,3.2495698730150857,3.2399179538091025,3.2359455823898315,3.234961668650309,3.2355283300081887,3.2368973096211753,3.238636533419291,3.240546405315399,3.242506265640259,3.2444563706715903,3.24635640780131,3.249013841152191,3.2528812487920127,3.2573007345199585,3.261950135231018,3.2666502793629966,3.271310329437256,3.275890588760376,3.2803707917531333,3.284731149673462,3.288981258869171,3.294646362463633,3.3025715152422586,3.311640202999115,3.3212787906328836,3.3311687707901,3.341138402620951,3.351108650366465,3.3610385855038962,3.3708975513776145,3.3806795676549277,3.3825670282046,3.3722405433654785,3.355142335096995,3.33421927690506,3.311073342959086,3.2865758538246155,3.261227468649546,3.235308587551117,3.2089993556340537,3.182409882545471,3.1556203365325928,3.1286606391270957,3.1015908320744834,3.0744409759839377,3.047231078147888,3.019991139570872,2.992741127808889,2.965511123339335,2.938291072845459,2.911110977331797,2.88397083679835,2.856900672117869,2.829890549182892,2.8029603560765586,2.7761101921399436,2.749339997768402,2.7226697405179343,2.6960995395978293,2.66961932182312,2.643259028593699,2.616998811562856,2.5908485452334085,2.5648082892100015,2.5388680696487427,2.5130577882130942,2.4873475631078086,2.461757262547811,2.4362870256106057,2.410916785399119,2.3856665094693503,2.3605262835820517,2.3354960481325784,2.3105857570966086,2.285785496234894,2.261085311571757,2.236495018005371,2.2120147943496704,2.187634547551473,2.163364311059316,2.139194071292877,2.1151338617006936,2.091163625319799,2.067293385664622,2.043513208627701,2.019832988580068,1.9962527354558308,1.9727625747521718,1.949362337589264,1.9260521531105042,1.9028219481309254,1.879681756099065,1.8566315372784932,1.8336613774299622,1.8107711970806122,1.7879609962304432,1.7652308245499928,1.7425706684589386,1.719990462064743,1.697480320930481,1.6750501294930775,1.6526899834473927,1.6303998132546742,1.6081796785195668,1.5860195259253185,1.5639293491840363,1.5419092277685802,1.519939124584198,1.49803892771403,1.4761988123257954,1.454418659210205,1.4326985379060109,1.411038378874461,1.3894382615884144,1.3678881327311199,1.346388041973114,1.3249478737513225,1.3035478095213573,1.2822076479593914,1.2609175542990367,1.2396873831748962,1.2184973259766896,1.1973472038904827,1.176247109969457,1.1551969647407532,1.1341869036356609,1.113226741552353,1.0923067033290863,1.0714265902837117,1.050586501757304,1.0297863880793254,1.009026323755582,0.9883052110671997,0.9676261196533839,0.9469820360342661,0.9263749519983927,0.9058018823464712,0.885263795653979,0.8647637069225311,0.8442986259857813,0.8238645493984222,0.8034614821275076,0.783090407649676,0.7627503275871277,0.7424412568410238,0.7221651673316956,0.7019201169411341,0.681701049208641,0.6615099757909775,0.6413459132115046,0.621208851536115,0.6011027693748474,0.581023707985878,0.5609676589568456,0.540936604142189,0.5209295352300009,0.5009464770555496,0.48098741968472797,0.461055355767409,0.4411473075548808,0.42126025011142093,0.40139420330524445,0.3815491497516632,0.3617260952790578,0.3419260357817014,0.32214898119370144,0.3023899445931117,0.28264889617760974,0.26292784512043,0.24322580049435297,0.2235417552292347,0.2038796991109848,0.1842376527686914,0.16461161648233733,0.14500156790018082,0.12540954040984312,0.10583345654110114,0.08627692051231861,0.06673837763567765,0.04721494329472383,0.027704331713418167,0.013266104506328702,0.006342573440633714,0.0030319815462765596,0.0014478040005390842,0.0006911888849572279,0.00032969493137594935,0.00015722561571844076,7.492675952865586e-05,3.569866369919813e-05,1.6999006447804277e-05,8.09294158443663e-06,3.851087020242024e-06,1.832262123950083e-06,8.713942776239492e-07,4.14363796608086e-07,1.9696823490752044e-07,4.819495498982936e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911712447802226,1.2003816664218903,1.2800614635149639,1.3833015064398448,1.4924715757369995,1.6073916753133137,1.7279016772905986,1.8495916724205017,1.9682416915893555,2.0839216709136963,2.196731686592102,2.306771695613861,2.4141116937001548,2.518841723601023,2.6210416754086814,2.720781703790029,2.81814173857371,2.913021683692932,3.005341728528341,3.0951716899871826,3.1825817028681436,3.267631689707438,3.350401679674784,3.4309417406717935,3.509321709473928,3.585601727167765,3.659831702709198,3.73233171304067,3.803391714890798,3.873051722844442,3.9413517117500305,4.008321781953176,4.07401172320048,4.138441761334737,4.2016518115997314,4.2636717557907104,4.32453175385793,4.383391817410787,4.439441680908203,4.492761731147766,4.543431679407756,4.591511607170105,4.637081702550252,4.680211702982585,4.7209616502126055,4.759401559829712,4.795591553052266,4.82975161075592,4.862081567446391,4.892651597658793,4.9214915831883745,4.948641538619995,4.974161624908447,4.9980915784835815,5.020461519559224,5.041311581929524,5.060691595077515,5.078921556472778,5.09632150332133,5.112911581993103,5.128701567649841,5.143731514612834,5.1580015023549395,5.171531518300374,5.184351483980815,5.19646139939626,5.207881490389506,5.2186814943949384,5.228891611099243,5.238541444142659,5.247621496518453,5.256151556968689,5.264151453971863,5.271611491839091,5.278541485468547,5.284971515337626,5.290891448656718,5.296451449394226,5.301801482836406,5.306941469510396,5.311861435572307,5.31658148765564,5.321091492970784,5.325401425361633,5.329501549402873,5.333401481310527,5.337101459503174,5.340131441752116,5.341991464296977,5.3426915009816485,5.3422614733378095,5.3406914075215655,5.338001410166423,5.334211508433024,5.329351305961609,5.323421359062195,5.31645139058431,5.308451334635417,5.299461364746094,5.289491335550944,5.278571367263794,5.266721328099568,5.25395127137502,5.24031130472819,5.225791295369466,5.21044127146403,5.194281299908956,5.177321195602417,5.159601251284282,5.141131281852722,5.1219412088394165,5.102041244506836,5.081461191177368,5.0602312088012695,5.038361191749573,5.015881220499675,4.992801149686177,4.969151139259338,4.944951176643372,4.92021111647288,4.894951105117798,4.869201103846232,4.842971086502075,4.816281080245972,4.789151032765706,4.761601010958354,4.733631094296773,4.705281019210815,4.6765410502751665,4.647441069285075,4.618001023928325,4.588231086730957,4.558140993118286,4.527741074562073,4.497060934702556,4.46609099706014,4.434860944747925,4.403380990028381,4.371660947799683,4.33971095085144,4.307540973027547,4.275160908699036,4.24259090423584,4.2098308801651,4.176890850067139,4.14379088083903,4.1105209191640215,4.077110926310222,4.043550888697307,4.009860833485921,3.976050853729248,3.942120830217997,3.9080708424250283,3.873930811882019,3.839680810769399,3.8053508003552756,3.7709407409032187,3.7364407777786255,3.7018807331720986,3.6672407587369285,3.6325507164001465,3.5978007117907205,3.5630006988843284,3.528160730997721,3.493270695209503,3.4583506981531777,3.4233906666437783,3.3884106874465942,3.353400707244873,3.3183706601460776,3.283320645491282,3.2482606371243796,3.2131906350453696,3.178110639254252,3.1430306235949197,3.1079405744870505,3.072860598564148,3.0377805829048157,3.0027005672454834,2.9676305651664734,2.932570517063141,2.897530515988668,2.862500548362732,2.8274805148442588,2.7924905021985373,2.757510503133138,2.722560485204061,2.6876304745674133,2.6527204314867654,2.6178404688835144,2.582980453968048,2.548160433769226,2.5133604208628335,2.478590428829193,2.443860431512197,2.4091503818829856,2.374480366706848,2.3398403922716775,2.3052403926849365,2.2706703543663025,2.2361403107643127,2.201650341351827,2.1671902934710183,2.1327703396479287,2.098390301068624,2.064050257205963,2.029740273952484,1.9954702655474346,1.961250255505244,1.9270602564016979,1.8929102619489033,1.858800232410431,1.8247302174568176,1.7907002369562786,1.756720205148061,1.7227701842784882,1.6888601779937744,1.6549901763598125,1.6211601595083873,1.5873801708221436,1.553630143404007,1.519920140504837,1.4862601359685261,1.4526301225026448,1.4190401136875153,1.3854901095231373,1.3519800901412964,1.3185100952784221,1.2850800553957622,1.2516900499661763,1.2183400392532349,1.1850200394789379,1.1517500380674999,1.118510017792384,1.0853000084559123,1.0521399974822998,1.0190099974473317,0.9864170004924139,0.9548349976539612,0.924235999584198,0.894595002134641,0.8658840010563532,0.838074987133344,0.8111430009206136,0.7850610017776489,0.7598049988349279,0.7353499929110209,0.7116720030705134,0.6887470036745071,0.6665520121653875,0.6450649996598562,0.6242639968792597,0.6041280080874761,0.584636002779007,0.5657690018415451,0.5475059996048609,0.5298289954662323,0.5127190003792444,0.49615900218486786,0.48013099531332654,0.4646179974079132,0.44960400213797885,0.43507400155067444,0.4210110033551852,0.4074010004599889,0.3942290047804515,0.38148200015227,0.3691460018356641,0.3572079986333847,0.34565500169992447,0.3344749982158343,0.32365499436855316,0.3131839980681737,0.3030519982179006,0.2932470018664996,0.2837580020229022,0.27457599838574726,0.26568999886512756,0.2570920040210088,0.24877099692821503,0.24071899925669035,0.23292700201272964,0.22538800040880838,0.21809099987149239,0.21103099981943765,0.20419899995128313,0.19758799920479456,0.19119100024302801,0.18499999990065893,0.17901000007987022,0.17321300134062767,0.167603999376297,0.16217700019478798,0.15692499900857607,0.15184199810028076,0.14692499985297522,0.14216599985957146,0.1375609996418158,0.13310599823792776,0.1287940007944902,0.1246219997604688,0.1205850001424551,0.11667899911602338,0.1128990004460017,0.1092410000662009,0.10570199973881245,0.10227799850205581,0.09896380081772804,0.09575730003416538,0.09265460011859734,0.08965230050186317,0.08674729987978935,0.08393630137046178,0.08121629990637302,0.07858430035412312,0.07603759877383709,0.07357339995602767,0.07118900120258331,0.06888180039823055,0.06664929973582427,0.06448900078733762,0.06239879969507456,0.06037630016605059,0.05841919997086128,0.056525600142776966,0.05469329934567213,0.052920300203065075,0.051204800295333065,0.0495448000729084,0.04793869983404875,0.046384500029186405,0.04488069967677196,0.04342570000638565,0.042017699840168156,0.040655399983127914,0.039337199491759144,0.038061799481511116,0.036827699902156986,0.03563350004454454,0.03447809970627228,0.03336010004083315,0.03227829995254675,0.031231599859893322,0.03021879990895589,0.029238799742112558,0.028290600050240755,0.027373199972013634,0.026485399963955086,0.02562649982670943,0.024795300016800564,0.023991199986388285,0.023212999881555636,0.022460200047741335,0.021731700127323467,0.02102680007616679,0.02034479969491561,0.019684900374462206,0.019046399897585314,0.018428600238015253,0.017830800109853346,0.01725239974136154,0.016692700019727152,0.0161512002038459,0.0156272998234878,0.015120399960627159,0.014629799872636795,0.01415519998408854,0.01369599997997284,0.013251700050507983,0.012821799997861186,0.012405799857030312,0.012003299857800206,0.011613899997125069,0.011237100077172121,0.010872499939675132,0.010519699892029166,0.010178400048365196,0.009848180071761211,0.009528639959171414,0.009219470201060176,0.008920330088585615,0.008630890166386962,0.00835083999360601,0.008079869827876488,0.007817689989072582,0.0075640199550737934,0.0073185700457543135,0.007081089968172212,0.006851309988026817,0.006628989979314308,0.006413879959533612,0.006205740035511553,0.006004359961176912,0.005809509971489509,0.005620990026121338,0.00543858006130904,0.0052620799979195,0.005091320024803281,0.004926090012304485,0.004766230044576029,0.004611549976592262,0.004461890086531639,0.004317089954080681,0.004176980039725701,0.004041419946588576,0.003910259945162882,0.0037833599878164628,0.0036605699957969287,0.0035417700031151376,0.0034268200009440384,0.003315600003891935,0.0032079999994797013,0.0031038800176853933,0.003003139999539902,0.0029056699907717607,0.002811369971216967,0.002720119974886378,0.002631839985648791,0.0025464200104276338,0.0024637700019714734,0.0023838000100416443,0.002306429979701837,0.0022315700189210474,0.002159139975750198,0.0020890600474861762,0.0020212600162873664,0.0019556599921391657,0.001892180007416755,0.0018307699938304722,0.001771339981739099,0.0017138500018821408,0.0016582199993232887,0.0016044000221882015,0.0015523299904695402,0.0015019399870652705,0.0014531899845072378,0.0014060199998008709,0.0013603900054780145,0.00131622997772259,0.0012735099880956113,0.0012321700050961226,0.0011921800032723695,0.0011534799996297807,0.001116039997820432,0.001079819999479999,0.0010447699848252039,0.001010860006014506,0.000978050001625282,0.0009463040041737258,0.0009155890002148226,0.0008858710013252372,0.0008571169989105935,0.0008292970014736056,0.0008023800037335604,0.0007763360093425339,0.0007511379953939468,0.0007267580028080071,0.0007031689892755821,0.0006803460031126937,0.000658264005323872,0.0006368980054200316,0.0006162260057559857,0.0005962249997537583,0.0005768730043200776,0.0005581500008702278,0.0005400339966096605,0.0005225060012890026,0.0005055469955550507,0.0004891389932405824,0.0004732630040962249,0.00045790199995584163,0.00044304000281651196,0.00042866100314616534,0.00041474800430781517,0.0004012870025083733,0.0003882630019991969,0.0003756619989871979,0.00036346899772373337,0.0003516729945355716,0.00034025900095002726,0.0003292160011672725,0.00031853099790168926,0.0003081929971813224,0.00029819099775825936,0.00028851299672775593,0.0002837539990044509};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.946349143981934,28.906192779541016,29.84339475631714,30.62699604034424,31.20109748840332,31.56669855117798,31.724599202473957,31.77099911371867,31.80199893315633,31.81739902496338,31.817299524943035,31.80199925104777,31.771299521128338,31.725399017333984,31.66439978281657,31.588199774424236,31.49709955851237,31.397799809773762,31.297399520874023,31.19589964548747,31.09309959411621,30.989199956258137,30.88409964243571,30.777900060017902,30.67039982477824,30.561800003051758,30.45199998219808,30.341199556986492,30.229700088500977,30.11739985148112,30.004499753316242,29.89079999923706,29.776299953460693,29.661100069681805,29.545199712117512,29.428500016530354,29.311100006103516,29.193299929300945,29.075500011444092,28.95769993464152,28.839999834696453,28.72219975789388,28.604399998982746,28.486699899037678,28.368899822235107,28.251099745432537,28.1332000096639,28.01549990971883,27.898100058237713,27.7809001604716,27.664000034332275,27.54730002085368,27.43080012003581,27.314600149790447,27.198599974314373,27.082900047302246,26.967300256093342,26.852099895477295,26.737199783325195,26.622700214385986,26.50860007603963,26.39489984512329,26.28150002161662,26.168400128682453,26.055699825286865,25.943399906158447,25.83140007654826,25.71969985961914,25.608399868011475,25.49750010172526,25.386899948120117,25.276700178782146,25.16689984003703,25.057400067647297,24.948200066884358,24.839399655659992,24.730900287628174,24.622700373331707,24.51480007171631,24.407300154368084,24.30010000864665,24.19319995244344,24.08660014470418,23.980300108591717,23.874300003051758,23.76859998703003,23.663200219472248,23.558099905649822,23.453500270843506,23.349299907684326,23.245500087738037,23.14199988047282,23.038899898529053,22.93620014190674,22.833800156911213,22.73169994354248,22.62999979654948,22.528500080108643,22.42739995320638,22.326599915822346,22.226200262705486,22.125999927520752,22.026099999745686,21.92650016148885,21.827199935913086,21.72820011774699,21.629499912261963,21.531099637349445,21.432999928792317,21.335100015004475,21.237600167592365,21.14040009180705,21.043400287628174,20.946699778238933,20.85039981206258,20.754299958546955,20.658499876658123,20.563000202178955,20.46779998143514,20.372899850209553,20.278300126393635,20.18399985631307,20.08999999364217,19.996299902598064,19.902899901072185,19.809800306955974,19.716999848683674,19.624500115712483,19.532299995422363,19.44039996465047,19.34879986445109,19.257500171661377,19.166600068410236,19.075900236765545,18.985599835713703,18.895500024159748,18.80580012003581,18.716400146484375,18.62730010350545,18.53849983215332,18.45010010401408,18.361900329589844,18.274099985758465,18.18660020828247,18.09939972559611,18.012500286102295,17.925900141398113,17.83970006306966,17.75379991531372,17.668199857076008,17.582899888356526,17.497999986012776,17.413300037384033,17.328999837239582,17.245000044504803,17.161399841308594,17.077999750773113,16.995000044504803,16.912299791971844,16.830000082651775,16.74790032704671,16.666199843088787,16.584800084431965,16.50369993845622,16.4229998588562,16.342600345611572,16.262499809265137,16.182699998219807,16.10330041249593,16.024200042088825,15.94539999961853,15.866899967193604,15.788799921671549,15.710899909337362,15.633400122324625,15.556300004323324,15.479400078455607,15.402900060017904,15.32669997215271,15.250799973805746,15.17520006497701,15.099999984105429,15.025000095367432,14.95039987564087,14.876199881235758,14.802200078964233,14.72849996884664,14.655199925104776,14.582200050354004,14.50950002670288,14.437100092569986,14.365099986394247,14.29330007235209,14.22189998626709,14.150800069173178,14.080000003178915,14.00950002670288,13.939299980799357,13.869499921798706,13.79990005493164,13.730699936548868,13.661799907684326,13.593200047810873,13.524800062179565,13.456799983978271,13.389100074768066,13.321700096130371,13.254700104395548,13.187899986902872,13.121400038401285,13.055200020472208,12.989300012588501,12.923799991607666,12.858499924341837,12.793499946594238,12.72890011469523,12.664499759674072,12.60039989153544,12.53659995396932,12.473100105921427,12.409900108973185,12.346999883651733,12.28440006573995,12.222100098927816,12.160099903742472,12.098300059636435,12.03689988454183,11.97570006052653,11.91480008761088,11.854300022125244,11.79390001296997,11.73390007019043,11.674200057983398,11.614700078964233,11.55560008684794,11.496699968973795,11.437999884287516,11.37970002492269,11.321599960327148,11.263699928919474,11.20610006650289,11.14869999885559,11.091599941253662,11.034800052642822,10.97819995880127,10.921799898147583,10.865800142288208,10.81000010172526,10.7543998559316,10.699099858601889,10.644100030263266,10.589399894078573,10.534899870554606,10.480699936548868,10.42679993311564,10.373100121816,10.319700082143148,10.266500075658163,10.213599999745687,10.1610000928243,10.10859990119934,10.05649995803833,10.004699945449829,9.953119993209839,9.90179991722107,9.85074003537496,9.79994010925293,9.749399979909262,9.69911003112793,9.649080117543539,9.599299987157186,9.549779971440634,9.500500043233236,9.451480070749918,9.40271004041036,9.354180097579956,9.305909951527914,9.257870038350424,9.210089921951294,9.16254989306132,9.115249872207642,9.068190018335978,9.021369934082031,8.974799950917562,8.928460041681925,8.882359902064005,8.836490074793497,8.790860017140707,8.745460033416748,8.700300057729086,8.655369997024536,8.610659996668497,8.566189924875895,8.521949927012125,8.477929989496866,8.434139966964722,8.390570084253946,8.347220102945963,8.304100036621094,8.261199951171875,8.218520005544027,8.17606004079183,8.133820056915283,8.091790040334066,8.049980163574219,8.008389949798584,7.9670000076293945,7.925829966862996,7.884879986445109,7.844129999478658,7.803589979807536,7.763260006904602,7.723140041033427,7.683220028877258,7.643510023752849,7.604010025660197,7.56470004717509,7.525600035985311,7.486700018246968,7.447999993960063,7.409500002861023,7.37120000521342,7.33309006690979,7.295180002848308,7.2574699719746905,7.219950000445048,7.182620008786519,7.1454799969991045,7.108539978663127,7.07177996635437,7.0352199872334795,6.9988400141398115,6.962649941444397,6.926650007565816,6.890829960505168,6.855199893315633,6.81974999109904,6.784480055173238,6.7493899663289385,6.714490016301473,6.679760018984477,6.645219961802165,6.610849976539612,6.57665999730428,6.542639970779419,6.5087999900182085,6.4751399755477905,6.441639979680379,6.40831995010376,6.3751799662907915,6.342199961344401,6.30938998858134,6.27675998210907,6.244289994239807,6.211979985237122,6.179849982261658,6.147879997889201,6.116069992383321,6.084430019060771,6.0529599984486895,6.021640062332153,5.990489999453227,5.959490021069844,5.928659995396932,5.897989948590596,5.867470026016235,5.837109963099162,5.806910037994385,5.776869932810466,5.746969978014628,5.71724001566569,5.687659978866577,5.658219973246257,5.6289500792821245,5.599819978078206,5.570839921633403,5.542009949684143,5.513339996337891,5.484810034434001,5.456419984499614,5.428189992904663,5.400090018908183,5.3721500635147095,5.344350020090739,5.31669004758199,5.289170026779175,5.2618000109990435,5.234570066134135,5.2074800332387285,5.1805299917856855,5.153719981511434,5.1270400285720825,5.100510001182556,5.0741099913914995,5.047850012779236,5.0217199722925825,4.99573000272115,4.969870050748189,4.944150010744731,4.918560067812602,4.893099983533223,4.867779970169067,4.842580000559489,4.817519982655843,4.792580008506775,4.767770012219747,4.743100047111511,4.718540032704671,4.694119970003764,4.669820070266724,4.645649989446004,4.621599952379863,4.5976799329121905,4.573880036671956,4.5502099593480425,4.526650031407674,4.503220001856486,4.479910055796306,4.456720034281413,4.433649977048238,4.410700082778931,4.387870033582051,4.365150014559428,4.342559973398845,4.320079962412517,4.297720034917195,4.275469938913981,4.253339966138204,4.231319983800252,4.209409952163696,4.1876200040181475,4.165949980417888,4.14438001314799,4.122929970423381,4.101580063501994,4.080350001653035,4.0592299699783325,4.038209994633992,4.01730998357137,3.9965100089708963,3.9758299787839255,3.955239991346995,3.9347700277964273,3.9143999814987183,3.8941400051116943,3.873980005582174,3.8539199829101562,3.833969990412394,3.8141199747721353,3.794380009174347,3.774740000565847,3.7552000085512796,3.735759993394216,3.716419994831085,3.697179992993673,3.678040007750193,3.658999959627787,3.640060007572174,3.6212199926376343,3.6024700005849204,3.583820025126139,3.5652700066566467,3.5468100110689798,3.5284499724706015,3.510190010070801,3.492019991079966,3.4739399751027427,3.4559600353240967,3.438069979349772,3.4202699859937034,3.4025699893633523,3.3849500020345054,3.3674299915631614,3.349999984105428,3.3326600193977356,3.315410037835439,3.2982500195503235,3.2811699708302817,3.2641900181770325,3.247289995352427,3.2304800152778625,3.2137599984804788,3.1971299846967063,3.1805800199508667,3.164110004901886,3.155899981657664};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.14046627407272658,0.14906380449732146,0.15918883929649988,0.17047482977310816,0.1829508145650228,0.1966107984383901,0.21144679312904677,0.22710878401994705,0.2432467763622602,0.25985777129729587,0.27694376558065414,0.2944997549057007,0.3125237549344699,0.3310137465596199,0.34996873637040454,0.36938473333915073,0.3892597258090973,0.40958471596241,0.4303497125705083,0.45155470569928485,0.47319569687048596,0.4952706918120384,0.5177776863177618,0.540715679526329,0.5640806704759598,0.5878726691007614,0.612088660399119,0.6366996566454569,0.6616796453793844,0.687025636434555,0.712734634677569,0.7388046334187189,0.7652376194794973,0.7920296142498652,0.8191796094179153,0.8466856082280477,0.8745436072349548,0.9026875992616018,0.9310485869646072,0.9596275935570399,0.9884215841690699,1.0174295703570049,1.046649565299352,1.0760895709196727,1.1057495673497517,1.1356095572312672,1.1656795640786488,1.1959695518016815,1.2264895538489025,1.2572395205497742,1.2882095475991566,1.31940953930219,1.3508395552635193,1.3824795285860698,1.4143495361010234,1.4464395145575206,1.4787495235602062,1.5112995008627574,1.544099509716034,1.5771594842274983,1.6104694803555806,1.6440294881661732,1.6778394877910614,1.7118994692961376,1.7462094724178314,1.780759463707606,1.8155594666798909,1.8505894641081493,1.8858294586340587,1.9212794502576191,1.9569394290447235,1.992799441019694,2.0288694302241006,2.065149466196696,2.101629455884298,2.138309379418691,2.17518945535024,2.212279419104258,2.249609410762787,2.2871594031651816,2.324929396311442,2.362929383913676,2.4011493921279907,2.4395894010861716,2.4782594045003257,2.517129381497701,2.5562293330828347,2.595169405142466,2.6335894068082175,2.6714794039726257,2.7088393767674765,2.7456893920898438,2.782009402910868,2.8178094029426575,2.853089372316996,2.8878494103749595,2.9220994313557944,2.9558194080988565,2.989039440949758,3.0217394630114236,3.053919474283854,3.085599402586619,3.1167694330215454,3.1474194725354514,3.1775794625282288,3.2072294553120932,3.2363794644673667,3.265019476413727,3.2931694785753884,3.3208194573720298,3.347979426383972,3.374649484952291,3.4008194406827292,3.4265094796816506,3.451699515183767,3.476419528325399,3.5006494919459024,3.524399518966675,3.547669529914856,3.5704694986343384,3.5927895307540894,3.6146395206451416,3.636019508043925,3.656929532686869,3.6773694952329,3.697359561920166,3.7168795466423035,3.7359395623207092,3.754549523194631,3.772699554761251,3.7903995712598166,3.807649612426758,3.824449578921,3.840799570083618,3.8567195534706116,3.8721895615259805,3.8872196078300476,3.901809573173523,3.9159796039263406,3.929709573586782,3.943009614944458,3.95587956905365,3.968319614728292,3.980349600315094,3.9919496377309165,4.003129601478577,4.013899604479472,4.02424959341685,4.034199595451355,4.043729583422343,4.052849690119426,4.061569650967916,4.069879651069641,4.077799677848816,4.085309664408366,4.092429677645366,4.099149703979492,4.105479717254639,4.111419717470805,4.116969625155131,4.122139652570088,4.126919706662496,4.1313298145929975,4.135349631309509,4.138989686965942,4.1422596375147505,4.1451497077941895,4.147679726282756,4.149839758872986,4.151619752248128,4.15304974714915,4.154099782307942,4.154799739519755,4.155149777730306,4.155129750569661,4.1547597249348955,4.154039740562439,4.152959744135539,4.151539762814839,4.14976982275645,4.147659778594971,4.14519989490509,4.142399748166402,4.139269789059957,4.135789752006531,4.131979823112488,4.127839763959249,4.123369773228963,4.1185697714487715,4.113439838091533,4.10798982779185,4.102209766705831,4.096109787623088,4.08968981107076,4.082949837048848,4.075899879137675,4.0685298045476275,4.060849825541179,4.052849809328715,4.044549783070882,4.035949905713399,4.027029911677043,4.01781980196635,4.008299867312114,3.9984798630078635,3.9883598486582437,3.9779399037361145,3.9672398765881858,3.956239898999532,3.944939911365509,3.9333598812421164,3.921489894390106,3.9093299309412637,3.8968799312909446,3.884159882863363,3.8711499174435935,3.8578699032465615,3.844299932320913,3.8304599126180015,3.816339910030365,3.801949918270111,3.7872899572054544,3.7723599870999656,3.757159948348999,3.74168994029363,3.725949982802073,3.709959924221039,3.6936999559402466,3.677179972330729,3.6603999535242715,3.643359959125519,3.6260599891344705,3.6085099975268045,3.590710004170736,3.5726600090662637,3.554349978764852,3.535800019900004,3.5171599785486856,3.4985999862353006,3.4801299969355264,3.461740016937256,3.443440020084381,3.42521995306015,3.4070900082588196,3.389039993286133,3.3710800210634866,3.3532100121180215,3.3354300061861673,3.3177300294240317,3.3001299699147544,3.28260999917984,3.2651700178782144,3.247830013434092,3.2305699785550437,3.213399966557821,3.1963200171788535,3.179329991340637,3.1624200145403543,3.145599981149038,3.1288700103759766,3.1122299830118814,3.0956700245539346,3.0791899959246316,3.0628099838892617,3.046500007311503,3.0302899877230325,3.0141500433286033,2.9981099565823874,2.982139984766642,2.966260015964508,2.95046999057134,2.934749980767568,2.9191200335820517,2.903570016225179,2.888099988301595,2.8727199832598367,2.8574100335439048,2.8421899875005088,2.827049990495046,2.8119800090789795,2.797000010808309,2.7820900082588196,2.7672699888547263,2.7525200049082437,2.73785001039505,2.72325998544693,2.708739976088206,2.6942999561627707,2.6799399852752686,2.6656599839528403,2.6514500180880227,2.637310008207957,2.6232500076293945,2.6092599829037986,2.5953500270843506,2.5815200209617615,2.567750016848246,2.5540600419044495,2.5404399832089744,2.52688999970754,2.513419985771179,2.5000100135803223,2.486679971218109,2.473420004049937,2.460230012734731,2.4471099972724915,2.434060017267863,2.4210700194040933,2.4081600109736123,2.3953199783960977,2.382539987564087,2.369829992453257,2.357189973195394,2.344610015551249,2.3321099877357483,2.319660007953644,2.307289977868398,2.294979989528656,2.2827400167783103,2.2705599864323935,2.2584399978319802,2.2463900248209634,2.234410027662913,2.2224799593289695,2.2106199661890664,2.19883002837499,2.1870999932289124,2.1754200061162314,2.163819988568624,2.1522699991861978,2.140779991944631,2.12936004002889,2.117990036805471,2.106689989566803,2.095450003941854,2.0842600067456565,2.07314000527064,2.0620699922243753,2.0510700345039368,2.04012002547582,2.0292299588521323,2.018400033315023,2.007630010445913,1.996909995873769,1.9862500131130219,1.9756500124931335,1.9651000102361043,1.954610009988149,1.9441799918810527,1.9337999920050304,1.9234700004259746,1.9132000009218852,1.9029900133609772,1.8928300142288208,1.8827200035254161,1.8726699948310852,1.8626699944337208,1.8527299960454304,1.8428399960199993,1.8329999943574269,1.8232099910577138,1.8134800096352894,1.803790012995402,1.794160008430481,1.7845799922943115,1.7750499844551086,1.7655700047810872,1.7561499973138173,1.7467699845631917,1.7374399900436401,1.72815998395284,1.7189300159613292,1.7097599804401398,1.7006199955940247,1.6915399928887684,1.682509998480479,1.6735199987888336,1.6645900110403697,1.6557000080744426,1.6468600034713745,1.6380599836508434,1.629310021797816,1.620609998703003,1.6119500001271565,1.6033499936262767,1.594780017932256,1.586269994576772,1.5777900119622548,1.5693700015544891,1.5609799722830455,1.552649994691213,1.544349988301595,1.5361100037892659,1.5279000004132588,1.5197400053342183,1.5116199851036072,1.503550002972285,1.495519995689392,1.4875300029913585,1.4795799851417542,1.4716799954573314,1.4638200004895527,1.455999990304311,1.4482199748357136,1.4404899974664052,1.4327900211016338,1.425139993429184,1.4175300101439159,1.4099599917729695,1.4024299879868825,1.3949299852053325,1.3874800006548564,1.3800700008869171,1.3727000057697296,1.3653700053691864,1.3580699861049652,1.3508199950059254,1.3436000049114227,1.3364300032456715,1.3292899827162425,1.3221899966398876,1.315120001633962,1.308100014925003,1.3011099894841511,1.294159968694051,1.28725000222524,1.2803700069586437,1.2735299865404766,1.2667300005753834,1.259959985812505,1.2532300055027008,1.2465400099754333,1.2398800055185955,1.2332500120004017,1.22667000691096,1.2201099892457326,1.2136000096797943,1.2071100076039631,1.2006600002447765,1.1942500074704487,1.1878699858983357,1.1815299987792969,1.1752100189526875,1.168940007686615,1.1626900136470795,1.1564799944559734,1.150299996137619,1.1441600024700165,1.1380499800046284,1.1319700082143147,1.1259200274944305,1.1199099918206532,1.1139200031757355,1.1079699993133545,1.102050006389618,1.0961700081825256,1.0903100073337555,1.0844900111357372,1.0786900023619335,1.0729300181070964,1.0672000050544739,1.0615000029404957,1.0558300117651622,1.0501900017261505,1.0445800026257832,1.0390000144640605,1.0334499975045521,1.0279300212860107,1.0224400063355763,1.0169799824555714,1.0115499993165333,1.00614000360171,1.0007699926694233,0.9954239974419276,0.9901069949070612,0.9848180015881857,0.9795579959948858,0.9743260045846304,0.9691219925880432,0.9639449963967005,0.9587970028320948,0.9536760002374649,0.9485819985469183,0.9435150027275085,0.9384760061899821,0.935962994893392};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2239372928937278,2.4407403667767844,2.6266002853711448,2.8790802558263144,3.1593303084373474,3.46379025777181,3.789330303668976,4.117210328578949,4.4311502774556475,4.732960383097331,5.024230360984802,5.306350270907084,5.580510377883911,5.847760399182637,6.109020312627156,6.365070382754008,6.616610407829285,6.863950332005818,7.107390443483989,7.347410400708516,7.584450403849284,7.8188804388046265,8.051010449727377,8.28113047281901,8.509470462799072,8.736240466435751,8.961610476175943,9.184610605239868,9.404340585072836,9.621220509211222,9.835570573806763,10.047700564066568,10.257900635401407,10.46630048751831,10.673200686772665,10.878600597381592,11.082900524139404,11.283100605010986,11.47700055440267,11.665300687154135,11.848700761795044,12.027800639470419,12.203100601832071,12.375100692113241,12.544200499852499,12.71060061454773,12.874800682067871,13.037400643030802,13.199000676472982,13.359700679779053,13.519600550333658,13.678800662358602,13.837400515874227,13.99540082613627,14.152800718943277,14.309700727462769,14.466100772221884,14.623000780741373,14.781100670496622,14.940400838851929,15.100600798924765,15.261600653330484,15.423300743103027,15.585500637690226,15.74820081392924,15.911300738652548,16.07460101445516,16.23710076014201,16.3978009223938,16.556700547536213,16.713900566101074,16.869700749715168,17.02400080362956,17.1769011815389,17.328500747680664,17.47900104522705,17.62830098470052,17.777201016743977,17.92660093307495,18.076300779978435,18.22620089848836,18.376200993855793,18.526100953420002,18.67600107192993,18.825800736745197,18.975300788879395,19.12460120519002,19.256200631459553,19.354601224263508,19.423300902048748,19.46570110321045,19.484501202901203,19.482401212056477,19.46160093943278,19.42430067062378,19.372200806935627,19.307100931803387,19.230300903320312,19.143300851186115,19.047200520833332,18.94300079345703,18.831700960795086,18.71410083770752,18.591100533803303,18.463200569152832,18.331100940704346,18.195400555928547,18.05650043487549,17.91480080286662,17.770700613657635,17.624601046244305,17.47680075963338,17.327600479125977,17.177100499471027,17.025700728098553,16.87350066502889,16.72070089975993,16.56740077336629,16.41390069325765,16.260101000467937,16.106200695037842,15.952300707499186,15.798500776290894,15.644800662994385,15.491400559743246,15.338200569152832,15.185400565465292,15.03290065129598,14.880800565083822,14.729200681050619,14.578000545501709,14.427300612131754,14.277000665664673,14.127300500869751,13.978200515111288,13.829500675201416,13.681400616963705,13.533800601959229,13.386800607045492,13.240400632222494,13.094500462214151,12.949200550715128,12.80440060297648,12.660200595855713,12.516500473022461,12.373300552368164,12.230700492858887,12.088700453440348,11.947100480397543,11.806100606918335,11.665600538253784,11.525600671768188,11.38610045115153,11.247100512186686,11.108500639597574,10.970500389734903,10.832900444666544,10.695800383885702,10.55910038948059,10.422900517781576,10.287200450897217,10.151800314585367,10.016900539398193,9.882410367329916,9.748320500055948,9.614630381266275,9.481340328852335,9.348440567652384,9.215920448303223,9.083770275115967,8.951990365982056,8.820560455322266,8.68949023882548,8.558760404586792,8.428370396296183,8.298310279846191,8.168580373128256,8.039170225461325,7.910070379575093,7.781290372212728,7.652800401051839,7.524610320727031,7.396710316340129,7.269100308418274,7.1417603095372515,7.014700333277385,6.887900312741597,6.761370301246643,6.635100285212199,6.509080211321513,6.383300185203552,6.25777022043864,6.132480223973592,6.0074102481206255,5.882580280303955,5.757980267206828,5.633590261141459,5.509420235951741,5.385470191637675,5.261720220247905,5.138180216153462,5.014830231666565,4.891680200894673,4.768730203310649,4.645960211753845,4.523380080858867,4.400980154673259,4.27875022093455,4.156700174013774,4.034820159276326,3.9131001830101013,3.791560153166453,3.6701701283454895,3.548940141995748,3.4278701146443686,3.3069501320521035,3.1861801544825235,3.0655500888824463,2.9450801412264505,2.8247401316960654,2.7045401136080423,2.584480067094167,2.4645500977834067,2.344750086466471,2.225080053011576,2.1055400570233664,1.9861200451850891,1.866830050945282,1.7476400434970856,1.6285800337791443,1.5096400380134583,1.390800009171168,1.272080014149348,1.1534700095653534,1.034969985485077,0.9165730029344559,0.7982819924751917,0.6881480018297831,0.5931220004955927,0.5111509958902994,0.44045399874448776,0.37949400146802265,0.3269369999567668,0.2816319987177849,0.24258400003115335,0.2089339978992939,0.17993799845377603,0.15495600178837776,0.1334339982519547,0.1148950004329284,0.09892630018293858,0.08517289968828361,0.07332830006877582,0.06312830032159884,0.05434509987632433,0.04678219991425673,0.040270499574641384,0.03466410003602505,0.0298373995659252,0.02568210009485483,0.02210490017508467,0.01902559989442428,0.01637490000575781,0.014093200055261454,0.012129199923947453,0.010438699973747134,0.00898374003979067,0.0077314199491714435,0.006653569949169953,0.005725910033409794,0.004927519980507593,0.004240409975561003,0.0036490599741227925,0.0031401499873027205,0.0027021799663392207,0.0023252800068197152,0.0020009300011831024,0.0017217999945084255,0.0014815999893471599,0.0012749000064407785,0.0010970199946314096,0.000943960995452168,0.0008122469977630923,0.0006989060057094321,0.0006013769937756782,0.0005174539910512976,0.0004452390009343314,0.0003830999946027684,0.0003296320016185443,0.0002836239994697583,0.00024403599915482724,0.00020997200044803321,0.000180661998456344,0.00015544299822067842,0.00013374300033319741,0.0001150720011840652,9.900689959370841e-05,8.518430028440586e-05,7.329100056570799e-05,6.305800009916614e-05,5.425339986686595e-05,4.667790017265361e-05,4.01600991608575e-05,3.4552099956878614e-05,2.9727099748318626e-05,2.557579970622707e-05,2.2004099870779708e-05,1.893110008192404e-05,1.6287199969156063e-05,1.401249998404334e-05,1.2055400020472007e-05,1.0371600031551983e-05,8.9229500493578e-06,7.676599958964895e-06,6.604320030116166e-06,5.681790033425689e-06,4.888100041474293e-06,4.20526998823334e-06,3.617799980778121e-06,3.112400008831173e-06,2.6775799900254547e-06,2.303510029832978e-06,1.9816799958031575e-06,1.7048199936198216e-06,1.4666200058854884e-06,1.2617099969247647e-06,1.0854200051350442e-06,9.33755994007394e-07,8.032830010051839e-07,6.910379966029723e-07,5.944750019655961e-07,5.114040012207018e-07,4.3994000028154307e-07,3.7846000348433034e-07,3.255710036379848e-07,2.80073000643218e-07,2.409309978190777e-07,2.0725999879308196e-07,1.7829300228792513e-07,1.5337500040383625e-07,1.319379983044655e-07,1.1349800151568464e-07,3.419102334589752e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834507067998251,12.709800879160563,13.159700552622477,13.852500200271606,13.745100259780884,12.978800137837728,11.670699914296469,10.231200059254965,8.997730096181234,7.933380126953125,7.007880051930745,6.196370085080464,5.478399991989136,4.837220112482707,4.259050011634827,3.732580045859019,3.248519996802012,2.821810007095337,2.4647600054740906,2.1649800340334573,1.912300020456314,1.6983500123023987,1.5162800053755443,1.360430012146632,1.2261600097020466,1.109660009543101,1.007780020435651,0.9186840107043585,0.8408420085906982,0.7722660054763159,0.7113160192966461,0.656644011537234,0.6071410129467646,0.561899001399676,0.5201659997304281,0.4813140059510867,0.44483400384585065,0.41147000590960187,0.38183900713920593,0.3552870030204455,0.33127200106779736,0.3093410034974416,0.2891260012984276,0.270323005815347,0.25268300498525303,0.23599700505534807,0.2200970028837522,0.20533200105031332,0.19199300309022269,0.17983200152715048,0.16864300270875296,0.1582570026318232,0.14853300154209137,0.1393550025920073,0.13062200074394545,0.12225700169801712,0.1141990019629399,0.10666600055992603,0.0998350027948618,0.0935839017232259,0.08781270124018192,0.08243880172570546,0.07739320149024327,0.07261940029760201,0.0680701012412707,0.06370640111466248,0.05950140114873648,0.05556150060147047,0.0519755007699132,0.04868840084721645,0.04564910102635622,0.042815600211421646,0.04015280089030663,0.03763180070867141,0.03522860072553158,0.032923300129671894,0.03069940038646261,0.028532900537053745,0.02640920039266348,0.024321300443261862,0.022263300449897844,0.020230400376021862,0.018223900347948074,0.01623969990760088,0.014268999841685096,0.012310000058884421,0.01036110008135438,0.008583449991419911,0.007110189995728433,0.005889130057767034,0.004877069965004921,0.00403827001961569,0.0033430999998624125,0.0027670200021627047,0.002289699992009749,0.0018942599805692832,0.001566720010790353,0.0012954699923284352,0.0010708900032720219,0.0008849949954310432,0.0007311539908793444,0.000603875999028484,0.0004986029938057376,0.00041155600047204643,0.0003395989988348447,0.000280134995894817,0.00023101000018262616,0.00019043800178527212,0.00015694100026545735,0.00012929500007885508,0.00010648400105613594,8.766920048704681e-05,7.21555000685233e-05,5.936780022845293e-05,4.883059985634949e-05,4.015079988069677e-05,3.300320016326926e-05,2.7119400177374093e-05,2.227749973826576e-05,1.829429993449594e-05,1.5018599924587761e-05,1.2325499938015128e-05,1.0112299984636289e-05,8.293899971552795e-06,6.800430014664016e-06,5.574199993437408e-06,4.567709993352764e-06,3.74184999903567e-06,3.064399985911829e-06,2.5088699923495974e-06,2.053460017729473e-06,1.6807399939959093e-06,1.3757899921529315e-06,1.1258599859805447e-06,9.210840090645434e-07,7.5334700966323e-07,6.15990998653615e-07,5.035449935538357e-07,4.1151700950573894e-07,3.362220037198919e-07,2.7463198648547404e-07,2.242680020951108e-07,1.830939950764332e-07,1.4944300611811437e-07,1.2194601180700224e-07,5.227322930068112e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708427498737971,0.9575240612030029,1.028480052947998,1.0967500607172649,1.1626000603040059,1.2262900869051616,1.2880400816599529,1.3439800540606182,1.3906900684038799,1.429240067799886,1.4605600933233898,1.4854800601800282,1.5047200520833333,1.5189400613307953,1.5286900500456493,1.5344900786876678,1.536780059337616,1.537180056174596,1.5371300478776295,1.536670058965683,1.5358400642871857,1.5346600612004597,1.5331700642903645,1.5314000844955444,1.5293600658575695,1.527070055405299,1.5245600541432698,1.5225400527318318,1.521650065978368,1.5217700600624084,1.5227700769901276,1.5245400667190552,1.527000069618225,1.5300600628058116,1.533640056848526,1.5376800696055095,1.542130062977473,1.5467100540796916,1.5511600573857625,1.555510054032008,1.559750070174535,1.5639100670814514,1.567970057328542,1.5719500581423442,1.5758500695228577,1.57968008518219,1.5834400554498036,1.5874300599098206,1.5919200778007507,1.5968600610891979,1.6021800637245178,1.6078400711218517,1.6138100822766621,1.6200400690237682,1.62649005651474,1.633150080839793,1.6399900615215302,1.6474000811576843,1.6557600498199463,1.6649500528971355,1.6748800873756409,1.685470054546992,1.6966400841871898,1.7083200812339783,1.7204600671927135,1.7329900761445363,1.7458800574143727,1.759180059035619,1.7729600667953491,1.7871400614579518,1.8016800781091054,1.8165200650691986,1.8316300710042317,1.8469700813293457,1.8625100751717885,1.878200074036916,1.894040087858836,1.910140077273051,1.926620066165924,1.9434300859769185,1.9605300923188527,1.9778700868288677,1.9954300820827484,2.013170083363851,2.0310600797335305,2.0490800937016806,2.0672000845273337,2.083510100841522,2.096280058224996,2.10586009422938,2.1125600735346475,2.1166900793711343,2.118480106194814,2.118190069993337,2.116020083427429,2.11216006676356,2.106800119082133,2.100070079167684,2.0921400785446167,2.083120067914327,2.0731201171875,2.062260111172994,2.050640066464742,2.038320084412893,2.0254001021385193,2.011940062046051,1.9980000654856365,1.983640064795812,1.9689100682735443,1.9538600941499074,1.9385300874710083,1.9229500691095989,1.9071700771649678,1.8912000755469005,1.8750800589720409,1.858830064535141,1.842480073372523,1.8260400692621868,1.8095300495624542,1.7929700712362926,1.7763600647449493,1.7597400744756062,1.7430900832017262,1.7264400521914165,1.7097900807857513,1.6931500534216564,1.6765300631523132,1.6599400540192921,1.6433700720469158,1.6268300414085388,1.6103400687376659,1.5938800573349,1.5774700542291005,1.5611100594202678,1.544800062974294,1.5285300612449646,1.512320061524709,1.4961600601673126,1.4800600409507751,1.4640100697676341,1.4480200409889221,1.432090034087499,1.4162100553512573,1.4003900587558746,1.3846300542354584,1.3689200381437938,1.3532700439294179,1.337680051724116,1.3221400678157806,1.306650052467982,1.291220058997472,1.2758500377337139,1.2605300446351368,1.245260049899419,1.230040043592453,1.2148800492286682,1.1997600495815277,1.1847000618775685,1.1696800390879314,1.1547200282414753,1.1398000419139862,1.1249300340811412,1.1101000408331554,1.095320055882136,1.080580045779546,1.0658900539080303,1.051240046819051,1.0366300543149312,1.0220700403054555,1.0075400273005168,0.993058035771052,0.978612040479978,0.9642050315936407,0.9498360256354014,0.9355050375064214,0.9212080339590708,0.9069480250279108,0.8927230288585027,0.8785340289274851,0.8643780301014582,0.8502530256907145,0.8361620257298151,0.8221030284961065,0.8080760290225347,0.7940790404876074,0.7801110247770945,0.7661730299393336,0.7522640327612559,0.7383810331424078,0.724528024593989,0.7107010285059611,0.6969020316998163,0.6831300208965937,0.6693820208311081,0.6556590348482132,0.6419610331455866,0.6282880157232285,0.6146400173505148,0.6010120163361231,0.5874080260594686,0.5738270084063212,0.5602670212586721,0.5467280149459839,0.5332110126813253,0.5197150111198425,0.5062400251626968,0.4927830174565315,0.4793470154205958,0.46592901398738223,0.45253101736307144,0.4391520122687022,0.4257890159885089,0.4124450162053108,0.3991180161635081,0.38580701251824695,0.37251301606496173,0.3592350135246913,0.34597500910361606,0.33273101101318997,0.31950000921885174,0.30628500630458194,0.2930860072374344,0.27990201115608215,0.26673200726509094,0.25357500712076825,0.2404320053756237,0.2273040053745111,0.21418900539477667,0.20108700171113014,0.18799700339635214,0.17492000137766203,0.16185600434740385,0.14880200227101645,0.13576100145777067,0.12273199980457623,0.10971499979496002,0.09670990022520225,0.08452329970896244,0.07386290033658345,0.06453949989130099,0.05638690044482549,0.04925930003325144,0.04302879981696606,0.03758319995055596,0.03282430053999027,0.02866600003714363,0.02503289996335904,0.021858999816079933,0.019086400046944618,0.016664700272182625,0.014549499998490015,0.012702300058056911,0.011089199998726448,0.009680569870397449,0.00845060000816981,0.007376679956602554,0.006439039949327707,0.005620440041335921,0.004905789974145591,0.00428190000820905,0.003737280028872192,0.0032618599749791124,0.002846869989298284,0.002484639970740924,0.0021684500000750027,0.001892479999999826,0.0016515999935412158,0.001441370016740014,0.0012578799990781893,0.0010977300019779552,0.0009579639930355673,0.0008359839994227514,0.0007295280035274724,0.0006366220040945336,0.0005555430010038739,0.00048478599880278733,0.0004230369983512598,0.0003691500047959077,0.00032212500082096085,0.00028108800082312274,0.00024527800148158957,0.0002140279987846346,0.0001867580006849797,0.00016296200071034642,0.00014219700096873567,0.00012407699978211895,0.00010826500025965895,9.446799958823249e-05,8.242859985330142e-05,7.192320056977526e-05,6.275640043895692e-05,5.4757600385831516e-05,4.777809984564859e-05,4.168789989004532e-05,3.637389969905295e-05,3.173719930297617e-05,2.769129999554328e-05,2.4161099948590465e-05,2.108090014492821e-05,1.8393299797025975e-05,1.6048199919775168e-05,1.4002100063711017e-05,1.2216800011325782e-05,1.0658999978356102e-05,9.29990013294931e-06,8.114030000191027e-06,7.079350022346868e-06,6.176579972816398e-06,5.388919930737757e-06,4.701680002957194e-06,4.102060036833184e-06,3.5789100062781167e-06,3.122460005518709e-06,2.7242200152007476e-06,2.376759975201518e-06,2.0735999820923703e-06,1.8091100078739448e-06,1.5783499994389179e-06,1.377019979524145e-06,1.2013700067351845e-06,1.048120007377899e-06,9.144119938279497e-07,7.977610039233696e-07,6.959879973085966e-07,6.071970091170442e-07,5.297319916053311e-07,4.621480016453461e-07,4.031850006451047e-07,3.5174400162910996e-07,3.068650045179311e-07,2.6771099944274585e-07,2.3355300034684964e-07,2.0375199838440494e-07,1.777530004668885e-07,1.5507100078101152e-07,1.3528299902532126e-07,1.180199996989965e-07,7.018874015329857e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.252859881768624,0.26552996039390564,0.2750229810674985,0.2840619782606761,0.29246698319911957,0.30027897904316586,0.3075319801767667,0.3138199845949809,0.31876497715711594,0.322450985511144,0.3249589850505193,0.3263629873593648,0.3267329881588618,0.32613198459148407,0.3246229862173398,0.32225998491048813,0.31909698992967606,0.31550098955631256,0.3118149861693382,0.3080429856975873,0.30418798824151355,0.3002539922793706,0.2962459897001584,0.29216499129931134,0.2880159914493561,0.28380099435647327,0.2795239935318629,0.27530398964881897,0.2712549865245819,0.2673649912079175,0.2636229892571767,0.260019987821579,0.25654498984416324,0.25318998595078784,0.24994699036081633,0.24680799121658006,0.24376599118113518,0.2408179926375548,0.23796499272187552,0.23519798989097276,0.23251298939188322,0.22990199302633604,0.22736199075977007,0.22488799194494882,0.22247299179434776,0.22011499106884003,0.21780899167060852,0.21557699392239252,0.2134389914572239,0.21138999114433923,0.20942198857665062,0.2075309914847215,0.20571199183662733,0.203959991534551,0.20226899161934853,0.2006369928518931,0.19905899340907732,0.19755799074967703,0.1961549917856852,0.19484499469399452,0.19362099220355353,0.19247699280579886,0.19140899057189623,0.19041099026799202,0.18947899341583252,0.18860899284482002,0.18779699256022772,0.18704399218161902,0.18635299305121103,0.18572099258502325,0.18514099096258482,0.18461199228962263,0.1841299906373024,0.1836909924944242,0.18329298992951712,0.18293199439843497,0.18260599176088968,0.18232399225234985,0.1820929894844691,0.18190999204913774,0.18177098905046782,0.18167498956123987,0.18161699300011,0.18159599229693413,0.18160799145698547,0.18165199334422746,0.1817259912689527,0.18176999191443124,0.18173199271162352,0.18161399041612944,0.18141899133721986,0.1811509927113851,0.18081299091378847,0.18040899435679117,0.17994199320673943,0.17941499253114065,0.17883199080824852,0.1781939926246802,0.1775059923529625,0.17677099133531252,0.17598899205525717,0.17516499136885008,0.17429999262094498,0.17339899390935898,0.1724619915088018,0.1714919942120711,0.17049199094374975,0.16946199287970862,0.16840399305025736,0.16732199117541313,0.1662169930835565,0.16508999218543371,0.16394399354855219,0.16277999058365822,0.1615969923635324,0.1603999932607015,0.15918899327516556,0.15796499078472456,0.15672699362039566,0.1554789940516154,0.15422199293971062,0.15295599400997162,0.15168199315667152,0.15040099248290062,0.14911399284998575,0.1478199933966001,0.14652199298143387,0.14521999408801398,0.14391499385237694,0.14260699724157652,0.1412969926993052,0.1399849938849608,0.13866999372839928,0.1373549960553646,0.13603999217351279,0.13472499325871468,0.13340999558568,0.13209599504868189,0.1307819957534472,0.12946999569733939,0.12815999488035837,0.12685099616646767,0.1255429939677318,0.12423699473341306,0.1229339949786663,0.12163299508392811,0.12033399567008018,0.11903899535536766,0.11774599490066369,0.11645499492685,0.11516699567437172,0.11388399451971054,0.11260199422637622,0.11132399551570415,0.11004999590416749,0.10877799615263939,0.1075099961211284,0.10624599518875281,0.10498499435683091,0.10372599586844444,0.10247099585831165,0.10121999494731426,0.09997149556875229,0.09872699591020744,0.09748649659256141,0.09624849694470565,0.09501299634575844,0.09378149546682835,0.09255389558772247,0.09132879662017028,0.09010749558607738,0.08889009679357211,0.08767489716410637,0.08646359605093797,0.0852559966345628,0.08405049641927083,0.0828473965326945,0.0816478965183099,0.08045199699699879,0.07925819667677085,0.07806799684961636,0.07688119697074096,0.07569629574815433,0.07451349621017773,0.07333409786224365,0.07215799763798714,0.07098379731178284,0.06981279700994492,0.0686449973533551,0.06747889829178651,0.06631589742998283,0.06515599663058917,0.0639975977440675,0.06284079793840647,0.06168699792275826,0.06053609742472569,0.0593865979462862,0.058239997985462345,0.057096097618341446,0.05595359827081362,0.05481239749739567,0.05367389755944411,0.05253799818456173,0.051403398315111794,0.050271298425892987,0.04914179816842079,0.048013298151393734,0.046885898957649864,0.0457608982299765,0.04463839841385683,0.04351679918666681,0.04239759842554728,0.04128069834162792,0.04016459888468186,0.03905079855273167,0.037939099284509815,0.03682809881865978,0.03571789960066477,0.03460979927331209,0.03350389904032151,0.0323984989275535,0.031295199412852526,0.030193899447719257,0.02909319909910361,0.02799289921919505,0.026894699316471815,0.025798399622241657,0.024702499620616436,0.0236085996342202,0.02251639977718393,0.021424599767973024,0.020334600005298853,0.019246299906323355,0.01815830000365774,0.01707059998686115,0.01598469998377065,0.014900399915253123,0.013853900056953231,0.012880000052973628,0.011973900021985173,0.011130900122225285,0.01034669989409546,0.009617289993911982,0.008938940164322654,0.008308109904949864,0.0077215200290083885,0.007176110055297613,0.006669019969801108,0.006197590031661093,0.005759329961923261,0.005351940014710029,0.004973259987309575,0.004621280007995665,0.004294120046931009,0.003990060048333059,0.0037074700036707022,0.003444840006219844,0.003200779998830209,0.0029739600140601397,0.002763189976879706,0.002567319975545009,0.002385320006093631,0.002216199995018542,0.0020590399702390036,0.0019130200089421123,0.0017773400080235053,0.0016512700046102207,0.0015341299974049132,0.0014252900242960702,0.0013241700071375817,0.0012302099882314603,0.0011429099928742896,0.0010618000039054702,0.0009864479895137872,0.000916433995977665,0.0008513870028158029,0.000790952006354928,0.0007348050033518424,0.0006826400058344007,0.0006341770009991402,0.0005891509984697526,0.0005473210039781407,0.0005084589987139528,0.00047235399930893135,0.00043881199720393244,0.00040765100372179103,0.00037870099913561717,0.00035180600146607804,0.0003268199967957723,0.00030360800155904144,0.0002820429993638148,0.00026200999855063856,0.00024339899876698232,0.00022610900001988435,0.00021004699859380102,0.00019512499905734634,0.00018126299740591398,0.00016838600034437454,0.00015642299937705198,0.00014530899958723845,0.0001349850014473001,0.00012539399843565965,0.00011648400080351469,0.00010820699996353748,0.0001005180007875121,9.337529869905363e-05,8.673979997790109e-05,8.057570024296486e-05,7.484949977272966e-05,6.953010051802266e-05,6.458859994988113e-05,5.9998199806917306e-05,5.573390020193377e-05,5.177260057583529e-05,4.809270042945476e-05,4.467430001871738e-05,4.1498799873807e-05,3.8548999630923696e-05,3.580879971802157e-05,3.326329988340149e-05,3.089870006078854e-05,2.870210028049769e-05,2.6661600107521128e-05,2.476620011293562e-05,2.3005500224826392e-05,2.1369899968703976e-05,1.9850600134911172e-05,1.84392000240526e-05,1.7128200094399897e-05,1.5910299983564375e-05,1.477909995628579e-05,1.3728200049930214e-05,1.2752000126662702e-05,1.1845299998943423e-05,1.1002999902605856e-05,1.022049999240456e-05,9.493740056617147e-06,8.818609937103853e-06,8.191479992092354e-06,7.608940071198352e-06,7.06781001251026e-06,6.565160030428767e-06,6.098250006895493e-06,5.664539988477675e-06,5.261659983564944e-06,4.887439937798869e-06,4.539820035157997e-06,4.216919933242025e-06,3.916979987176698e-06,3.6383800079420325e-06,3.379579993634252e-06,3.1391900089753713e-06,2.9158999647430997e-06,2.7084799967269646e-06,2.515819990852227e-06,2.3368499834456693e-06,2.170620026239097e-06,2.0162099948114096e-06,1.8727800087011322e-06,1.739549986723432e-06,1.6157999975045338e-06,1.500849994802896e-06,1.3940800063968102e-06,1.2948999975985014e-06,1.2027800077400268e-06,1.1172100092456578e-06,1.0377200112543505e-06,9.638909877670205e-07,8.953130029946502e-07,8.316129983162076e-07,7.724440015029662e-07,7.174849988208128e-07,6.66435994389758e-07,6.190180054469844e-07,5.74972996029525e-07,5.340620011414406e-07,4.960619956288307e-07,4.607650012644626e-07,4.279790033479003e-07,3.9752599908145686e-07,3.6923899671137406e-07,3.4296500217578796e-07,3.1856000030453896e-07,2.958920006790322e-07,2.748369993810229e-07,2.5527900267737397e-07,2.3711400013818698e-07,2.2024000045917091e-07,2.0456800105724446e-07,1.900100012145837e-07,1.7648799873389484e-07,1.639289995599332e-07,1.5226299865389592e-07,1.414270004810684e-07,1.31362998700979e-07,1.2201400068079238e-07,1.1333100028802316e-07,1.0526599917663286e-07,1.6801068388379765e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.364031861225764,1.4751599927743275,1.5928400059541066,1.705350011587143,1.818750003973643,1.933060000340144,2.0482499500115714,2.1639700134595237,2.279849966367086,2.3958800037701926,2.512059986591339,2.6283899943033853,2.7448800007502236,2.861519972483317,2.978309988975525,3.0952500104904175,3.21234001715978,3.32942001024882,3.446340024471283,3.5631100138028464,3.6797099908192954,3.796150028705597,3.9124199946721396,4.028540015220642,4.144490043322246,4.260280092557271,4.375909964243571,4.4912099440892534,4.6060099601745605,4.720330039660136,4.834150075912476,4.94747006893158,5.060309926668803,5.172659993171692,5.284510016441345,5.395879944165547,5.506749987602234,5.6172700723012285,5.727590084075928,5.8377000490824384,5.94760000705719,6.057289918263753,6.1667799949646,6.276060024897258,6.385119994481404,6.493979970614116,6.602639993031819,6.711119969685872,6.81948999563853,6.927740017573039,7.035869995752971,7.1438900629679365,7.251789967219035,7.359570026397705,7.46724005540212,7.574789961179097,7.682210008303325,7.789569973945618,7.896909991900126,8.004220048586527,8.111519893010458,8.218800067901611,8.326049963633219,8.433289925257364,8.540510018666586,8.647700071334839,8.754870017369589,8.862160046895346,8.969689925511679,9.07748007774353,9.1855099995931,9.293790022532145,9.40231998761495,9.511079947153727,9.620100021362305,9.729349931081137,9.838849941889444,9.948669910430908,10.058900117874146,10.169600009918213,10.28060007095337,10.392100095748901,10.504000107447306,10.616300106048584,10.728999932607016,10.842100063959757,10.955600023269653,11.068700075149536,11.180699825286865,11.291599988937378,11.401299873987833,11.509800036748251,11.617300033569336,11.723599910736084,11.828699906667074,11.932799895604452,12.035699923833212,12.137399911880493,12.238099892934164,12.337600151697794,12.436099847157797,12.533400058746338,12.629500071207682,12.724600076675415,12.818600018819174,12.911399920781454,13.003200054168701,13.093800067901611,13.18339999516805,13.271799882253012,13.35919992129008,13.44539999961853,13.530599991480509,13.614700078964233,13.69760004679362,13.779500007629395,13.860400040944418,13.940099954605103,14.018699884414673,14.096299886703491,14.172799905141195,14.248199939727783,14.32260004679362,14.395900011062622,14.468099991480509,14.539300044377645,14.609400033950806,14.678400119145712,14.746399958928427,14.813399950663248,14.879199981689453,14.94409998257955,15.007799943288168,15.070600112279257,15.13230005900065,15.192900021870932,15.252499977747599,15.311100085576376,15.368699868520102,15.42520006497701,15.480700095494589,15.535100062688192,15.588499943415323,15.640900055567423,15.692300081253052,15.742700099945068,15.79199997584025,15.840399980545044,15.887700001398722,15.933999935785929,15.979300022125244,16.023600101470947,16.06689993540446,16.10919984181722,16.150500138600666,16.190800031026203,16.23009983698527,16.268399874369305,16.305699825286865,16.342000166575115,16.377299944559734,16.41170008977254,16.44510014851888,16.477500120798748,16.508899847666424,16.539300282796223,16.56879997253418,16.597300052642822,16.624799887339275,16.65139977137248,16.677000204722088,16.701600074768066,16.725299835205078,16.748000144958496,16.76979986826579,16.790599822998047,16.810499986012776,16.829400380452473,16.8472998936971,16.86430009206136,16.880399862925213,16.895500024159748,16.9096999168396,16.9229998588562,16.93530003229777,16.946699778238933,16.95709975560506,16.966599941253662,16.975199858347576,16.982899983723957,16.989699999491375,16.9954997698466,17.000399907430012,17.00439993540446,17.00749985376994,17.009599685668945,17.010900179545086,17.011200110117596,17.01069990793864,17.00920025507609,17.006800015767414,17.003599961598713,16.999399820963543,16.994400024414062,16.988399823506672,16.981499989827473,16.97380002339681,16.9652001063029,16.955699761708576,16.945299943288166,16.93399985631307,16.921799818674724,16.90879996617635,16.89490016301473,16.880099932352703,16.864399909973145,16.847900072733562,16.83050012588501,16.81219991048177,16.793100039164226,16.773099899291992,16.75230010350545,16.730600039164226,16.70799986521403,16.684600194295246,16.66029977798462,16.635200023651123,16.60919984181722,16.582300027211506,16.55470021565755,16.52620013554891,16.49679962793986,16.466599941253662,16.43559996287028,16.40369987487793,16.370999654134113,16.33749993642171,16.303500016530354,16.269700209299724,16.235899766286213,16.202199935913086,16.168599764506023,16.1349999109904,16.101500034332275,16.068099816640217,16.034800052642822,16.001500209172566,15.968299945195517,15.935099999109903,15.902000109354654,15.86899987856547,15.836100021998087,15.803200006484985,15.770399888356527,15.73769998550415,15.705100138982138,15.672499974568685,15.639899969100952,15.607500076293945,15.57510002454122,15.542799949645996,15.510500033696493,15.478299935658773,15.446199973424276,15.414099931716919,15.382200082143148,15.350200017293295,15.318400065104166,15.286600033442179,15.254900058110556,15.22320000330607,15.19159992535909,15.16010014216105,15.128699938456217,15.097299973169962,15.065900166829428,15.034700075785318,15.00349990526835,14.972300052642822,14.94130007425944,14.91029977798462,14.879299958546957,14.84850001335144,14.817600011825562,14.786900043487549,14.756200075149536,14.725600004196167,14.695000012715658,14.664599816004435,14.634100039800009,14.60379989941915,14.573499997456869,14.543200016021729,14.513000011444092,14.482899983723959,14.452899932861328,14.422900040944418,14.39300004641215,14.363100051879883,14.333300034205118,14.303599993387857,14.273900111516317,14.244300047556559,14.21470014254252,14.185199975967407,14.155799945195517,14.126399993896484,14.097099860509237,14.067899942398071,14.038700103759766,14.009499867757162,13.980499982833862,13.951499938964844,13.922500054041544,13.89360006650289,13.864799976348877,13.836100021998087,13.807300011316935,13.77869995435079,13.750099976857504,13.72160005569458,13.693100055058798,13.664700110753378,13.636399984359741,13.608100016911825,13.579800128936768,13.551700115203857,13.523599942525228,13.495500087738037,13.46750013033549,13.439600070317587,13.411699930826822,13.383900006612143,13.356099923451742,13.328400055567423,13.300699949264526,13.273099978764852,13.245599826176962,13.218099991480509,13.190700054168701,13.163400014241537,13.135999997456869,13.108800013860067,13.081599950790405,13.054500023523966,13.027400016784668,13.000399907430014,12.973399957021078,12.946499983469645,12.919600089391073,12.892800092697144,12.866099993387857,12.839399973551432,12.81279993057251,12.786199967066446,12.759699980417887,12.733200073242188,12.706800063451132,12.680399974187216,12.654100020726522,12.627900044123331,12.601700146993002,12.575599908828735,12.549499988555908,12.523499886194864,12.497499942779541,12.471599896748861,12.4457000096639,12.419900019963583,12.394100109736124,12.36840001742045,12.34279998143514,12.317199945449829,12.291599988937378,12.266200065612793,12.240700085957846,12.21530000368754,12.18999989827474,12.164700031280518,12.13949990272522,12.114300012588501,12.089199940363565,12.06410002708435,12.039100090662638,12.01420005162557,11.989200115203857,11.964400053024292,11.939599990844727,11.914800008138021,11.890100081761679,11.86549997329712,11.84090002377828,11.8163001537323,11.791800022125244,11.76739994684855,11.742999951044718,11.718599955240885,11.694300095240274,11.67010005315145,11.645899931589762,11.621699968973795,11.597600062688192,11.573599974314371,11.54960004488627,11.525599956512451,11.501800060272217,11.4778999487559,11.454100052515665,11.430399894714355,11.406700054804483,11.382999897003174,11.359399875005087,11.335899829864502,11.312399943669638,11.288899978001913,11.265499909718832,11.242200056711832,11.218900124231974,11.195600112279257,11.172399918238321,11.14930001894633,11.126199881235758,11.103099902470907,11.080099821090698,11.057099978129068,11.034200112024942,11.011299848556519,10.988499959309896,10.965700070063273,10.942999998728434,10.920300086339315,10.89769991238912,10.875100056330362,10.852599859237671,10.830100059509277,10.807599941889444,10.785200119018555,10.762900034586588,10.740600029627482,10.718300104141235,10.696099917093912,10.67389996846517,10.651800076166788,10.629799922307333,10.607699950536093,10.585700035095215,10.56380009651184,10.541899998982748,10.520099957784018,10.498300075531006,10.476500034332275,10.454799969991049,10.433199961980185,10.411500056584677,10.390000104904175,10.368399937947592,10.346999963124594,10.325500011444092,10.304100036621094,10.282800118128458,10.261500040690104,10.240199963251749,10.218999862670898,10.197800000508627,10.176700194676718,10.15560015042623,10.134600003560385,10.113599936167398,10.092700084050497,10.071699937184652,10.050899902979532,10.030099948247274,10.009299914042154,9.98856004079183,9.967870076497396,9.947220007578531,9.92662000656128,9.906059980392456,9.885540088017782,9.865060011545816,9.844629923502604,9.8242400487264,9.803900321324667,9.783590078353882,9.763329982757568,9.753209988276163};
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480093280474345,4.563908735911052,4.607269128163655,4.680299162864685,4.757189035415649,4.837939063707988,4.922539075215657,5.007649183273315,5.089899142583211,5.169289151827495,5.245819290479024,5.319489240646362,5.39030925432841,5.458269278208415,5.523369391759236,5.585619290669759,5.6450194120407104,5.702069401741028,5.757289449373881,5.81067951520284,5.862239400545756,5.9119694630304975,5.959879517555237,6.0059494972229,6.050199508666992,6.09261957804362,6.133209625879924,6.17229962348938,6.210219542185466,6.24696958065033,6.282549659411113,6.316959619522095,6.350189606348674,6.382259686787923,6.41314971446991,6.442879676818848,6.471439719200134,6.499029715855916,6.525879740715027,6.551979700724284,6.577319661776225,6.601919571558635,6.625769734382629,6.648869752883911,6.6712197462717695,6.692819714546204,6.713679750760396,6.7339097658793134,6.753669738769531,6.772949775060018,6.791749795277913,6.810069799423218,6.827899773915608,6.84525986512502,6.862139741579692,6.878539840380351,6.894459843635559,6.909979740778605,6.925199866294861,6.940109809239705,6.9547098477681475,6.969009796778361,6.982999841372172,6.996679862340291,7.010049859682719,7.023119846979777,7.035879810651143,7.0482198397318525,7.059999863306682,7.071249882380168,7.081949869791667,7.092099825541179,7.101709882418315,7.110769947369893,7.119289954503377,7.127259890238444,7.134689927101135,7.141849915186564,7.148999969164531,7.156149943669637,7.163309892018636,7.170459906260173,7.177609920501709,7.184759895006816,7.191909948984782,7.199059923489888,7.206209897994995,7.213329911231995,7.220399936040242,7.227419932683309,7.234379927317302,7.241289933522542,7.248139937718709,7.254949927330017,7.261699875195821,7.268389860788981,7.275039951006572,7.281629920005798,7.288159926732381,7.2946499188741045,7.301079948743184,7.307459870974223,7.313789923985799,7.320059895515442,7.326269904772441,7.33243993918101,7.338549892107646,7.3446199496587115,7.350619951883952,7.356569886207581,7.362469871838887,7.368319908777873,7.374119877815247,7.379859924316406,7.385549942652385,7.391179958979289,7.396769920984904,7.402289907137553,7.4077699184417725,7.413199941317241,7.418569962183635,7.423879941304524,7.429149905840556,7.434359947840373,7.439519921938579,7.444629907608032,7.449679931004842,7.4546800057093305,7.459619959195455,7.46451993783315,7.469359914461772,7.474149902661641,7.478879928588867,7.483559966087341,7.4881900151570635,7.492769956588745,7.497289975484212,7.501759966214498,7.50616991519928,7.5105399290720625,7.514849940935771,7.519109924634297,7.5233099063237505,7.527469952901204,7.531569957733154,7.5356099208196,7.539609909057617,7.54354993502299,7.547440012296041,7.55127998193105,7.555059949556987,7.558789968490601,7.562459905942281,7.566089868545532,7.569659908612569,7.5731799602508545,7.5766399304072065,7.580049912134807,7.583409945170085,7.5867200295130415,7.589979966481526,7.593179941177368,7.596329927444458,7.599419991175334,7.602459987004598,7.605449954668681,7.608389933904012,7.611280043919881,7.614109953244527,7.616889993349711,7.619610031445821,7.622289856274922,7.62490991751353,7.627479990323384,7.629999915758769,7.632459918657939,7.634869972864787,7.637229959170024,7.639529903729756,7.64178999265035,7.643979986508687,7.646129926045735,7.648219982783,7.650270064671834,7.652259945869446,7.654189984003703,7.656069874763489,7.6579000155131025,7.6596799691518145,7.661410013834636,7.663079937299092,7.66470996538798,7.666269977887471,7.667790015538533,7.669250011444092,7.670659939448039,7.672019958496094,7.673319896062215,7.674570004145305,7.675769925117493,7.6769200166066485,7.6780199607213335,7.679060022036235,7.680050015449524,7.68098000685374,7.681869983673096,7.682699998219808,7.6834800243377686,7.684199968973796,7.684879978497823,7.685499906539917,7.686069965362549,7.686590035756429,7.687049984931946,7.68746002515157,7.687829971313477,7.688129981358846,7.688389976819356,7.688589930534363,7.688740015029907,7.688829978307088,7.68887996673584,7.688869953155518,7.688809951146443,7.688690026601155,7.688530087471008,7.688309987386067,7.688040018081665,7.687720020612081,7.687339981396993,7.686920007069905,7.686440070470174,7.685900052388509,7.685319979985555,7.684679985046387,7.683990001678467,7.683250069618225,7.682479937871297,7.681709965070088,7.680950005849202,7.680180033047994,7.679409980773926,7.678640007972717,7.677869995435079,7.677109917004903,7.6763399839401245,7.675570050875346,7.674799958864848,7.674040079116821,7.673269987106323,7.672500054041545,7.671729922294617,7.6709699630737305,7.670199990272522,7.669429937998454,7.668670018513997,7.667899966239929,7.667129993438721,7.666369915008545,7.665599981943767,7.664829969406128,7.664070010185242,7.663300037384033,7.662529985109965,7.661770025889079,7.660999933878581,7.660239974657695,7.659470001856486,7.658699989318848,7.657940030097961,7.6571699778238935,7.656409939130147,7.6556399663289385,7.654869953791301,7.6541099945704145,7.653340021769206,7.65258002281189,7.651810010274251,7.6510500113169355,7.650279998779297,7.6495199998219805,7.648749987284343,7.647989948590596,7.647220055262248,7.646459937095642,7.645689964294434,7.644929965337117,7.644170006116231,7.643399953842163,7.642639994621277,7.641869982083638,7.641110022862752,7.640340010325114,7.639579971631368,7.638819972674052,7.638049960136414,7.637290000915527,7.636529962221782,7.635759949684143,7.635000030199687,7.634230017662048,7.633469978968303,7.632709980010986,7.631939967473348,7.6311800082524615,7.630419969558716,7.62966005007426,7.628890077273051,7.628129959106445,7.627369999885559,7.626599947611491,7.625840067863464,7.625080029169719,7.624319990475972,7.623549977938334,7.622789939244588,7.622030019760132,7.621269981066386,7.620510061581929,7.619740009307861,7.618980010350545,7.618219931920369,7.617460052172343,7.616700013478597,7.615930000940959,7.615169962247212,7.614409923553467,7.613650004069011,7.612890005111694,7.6121299266815186,7.6113700071970625,7.610610008239746,7.609839955965678,7.609080036481221,7.608320037523906,7.607559998830159,7.606799999872844,7.606040000915527,7.605280001958211,7.6045200030008955,7.603760004043579,7.603000005086263,7.602240006128947,7.601479967435201,7.6007200082143145,7.599960009256999,7.599200010299683,7.598440011342366,7.597679972648621,7.596919973691304,7.596160014470418,7.5954000155131025,7.594640016555786,7.59388001759847,7.593119978904724,7.592360019683838,7.591599980990092,7.590839982032776,7.59008002281189,7.5893300374348955,7.58857003847758,7.5878099997838335,7.587049961090088,7.586290001869202,7.585530002911885,7.5847699244817095,7.584009925524394,7.583260019620259,7.582499980926514,7.581740061442058,7.580979943275452,7.580219944318135,7.579469998677571,7.578709959983826,7.57794992129008,7.577189962069194,7.576430042584737,7.5756800174713135,7.574920058250427,7.5741599798202515,7.573400060335795,7.572649955749512,7.5718899965286255,7.571129997571309,7.570379972457886,7.5696200132369995,7.568859974543254,7.5680999755859375,7.5673500299453735,7.566589951515198,7.5658299922943115,7.565080006917317,7.564320047696431,7.563569982846578,7.562810023625691,7.562049984931946,7.561300039291382,7.560540000597636,7.559780081113179,7.5590299765268965,7.55826997756958,7.557519992192586,7.5567600329717,7.556009968121846,7.55525004863739,7.5544900099436445,7.55373998483022,7.552980025609334,7.552230000495911,7.551470001538594,7.550720016161601,7.549960056940715,7.549209992090861,7.548449953397115,7.547700087229411,7.546939969062805,7.546190023422241,7.545430024464925,7.5446799993515015,7.543930093447368,7.543170015017192,7.542420029640198,7.5416600704193115,7.540910045305888,7.540150006612142,7.539400021235148,7.538649996121724,7.5378899574279785,7.5371400117874146,7.53639002641042,7.535629987716675,7.534879962603251,7.534119923909505,7.533369978268941,7.532620072364807,7.531859993934631,7.531110008557637,7.530359943707784,7.52960999806722,7.5288500388463335,7.52809997399648,7.527350028355916,7.52658994992574,7.525839964548747,7.525089939435323,7.524340033531189,7.523579994837443,7.522830049196879,7.522080024083455,7.521330038706462,7.520579973856608,7.519819935162862,7.519070029258728,7.5183199644088745,7.51756997903188,7.516820073127747,7.516059994697571,7.515310009320577,7.514559984207153,7.513810038566589,7.513059973716736,7.512309988339742,7.511559963226318,7.510809977849324,7.510049978892009,7.5092999537785845,7.508549968401591,7.507800022761027,7.507049997647603,7.50630001227061,7.505550026893616,7.504800081253052,7.504050016403198,7.503299951553345,7.502550045649211,7.501799901326497,7.501049995422363,7.500300049781799,7.499549984931946,7.498800039291382,7.498049974441528,7.497300028800964,7.496550003687541,7.4957999388376875,7.495049953460693,7.494670033454895};
    //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174860149621964,0.6330969432989756,0.6434359351793925,0.6587299307187399,0.6748299400011698,0.6917389283577601,0.7094549338022867,0.727274939417839,0.7444949448108673,0.7611169368028641,0.7771389484405518,0.7925629516442617,0.8073879480361938,0.8216139574845632,0.8352419435977936,0.8482709576686224,0.8607009599606196,0.8726409624020258,0.8841969668865204,0.8953689684470495,0.9061579704284668,0.916562964518865,0.9265849590301514,0.936223973830541,0.9454789658387502,0.9543509731690089,0.9628409544626871,0.9710159699122111,0.9789459705352783,0.9866289695103964,0.9940669735272726,1.0012599726517994,1.0082099934418995,1.0149099826812744,1.0213699738184612,1.0275799830754597,1.0335399806499481,1.0393099784851074,1.044919987519582,1.0503699779510498,1.0556599795818329,1.0607999960581462,1.0657800038655598,1.0705999831358592,1.075269987185796,1.0797799825668335,1.0841299891471863,1.0883500079313915,1.092469980319341,1.0964899957180023,1.100409984588623,1.104229986667633,1.1079499920209248,1.1115699807802837,1.115089972813924,1.118509978055954,1.1218199928601582,1.1250599920749664,1.1282299955685933,1.131329983472824,1.1343699892361958,1.137349973122279,1.1402599811553955,1.1431099871794383,1.1458899875481923,1.1486099759737651,1.1512599686781566,1.1538299719492595,1.1562799910704296,1.1586099763711293,1.160840004682541,1.1629499991734822,1.1649399797121684,1.166819989681244,1.1685899992783864,1.1702399849891663,1.1717799802621205,1.1732599834601085,1.1747399866580963,1.1762199898560841,1.1777099867661793,1.1791900197664897,1.1806699832280476,1.1821500062942505,1.1836300094922383,1.1851100027561188,1.1865899960199993,1.1880599757035573,1.1895199914773305,1.1909800072511036,1.1924200157324474,1.1938499808311462,1.1952599982420604,1.196669985850652,1.198069989681244,1.1994499762852986,1.200819989045461,1.2021900117397308,1.2035399874051411,1.204879989226659,1.2061999936898549,1.2075199981530507,1.2088299989700317,1.2101200024286907,1.2114000022411346,1.2126800119876862,1.2139399846394856,1.2151899933815002,1.2164300084114075,1.2176600098609924,1.2188699940840404,1.2200799882411957,1.2212699949741364,1.2224599917729695,1.223630001147588,1.2247899770736694,1.2259399990240734,1.2270800073941548,1.2282000084718068,1.2293199598789215,1.2304200033346813,1.231520007054011,1.2326000034809113,1.2336699962615967,1.2347299953301747,1.235780010620753,1.236819992462794,1.23785001039505,1.2388599812984467,1.2398699919382732,1.24085999528567,1.2418499986330669,1.2428199748198192,1.2437800069650014,1.244729995727539,1.2456600069999695,1.246589998404185,1.247510015964508,1.2484099964300792,1.2492999931176503,1.2501799861590068,1.251059999068578,1.2519100109736125,1.2527599930763245,1.2535999914010365,1.2544299960136414,1.2552399933338165,1.2560500005880992,1.2568400005499523,1.2576300104459126,1.258399983247121,1.259160002072652,1.2599099973837535,1.2606399953365326,1.2613700131575267,1.2620899975299835,1.2627899944782257,1.2634800175825756,1.2641700108846028,1.2648399968942006,1.2654999991257985,1.2661500076452892,1.2667900025844574,1.2674100001653035,1.2680299977461498,1.2686299979686737,1.2692299981911976,1.269810010989507,1.2703799903392792,1.2709400057792664,1.2714899877707164,1.2720300058523815,1.2725600004196167,1.2730800012747447,1.273579994837443,1.2740700046221416,1.2745600044727325,1.275029997030894,1.2754899660746257,1.2759400010108948,1.2763799925645192,1.276810000340144,1.2772200107574463,1.2776299913724263,1.2780199944972992,1.2784099976221721,1.2787799835205078,1.2791399955749512,1.2794899940490723,1.2798299888769786,1.2801600098609924,1.2804799874623616,1.2807799975077312,1.281079997618993,1.2813599904378254,1.281640003124873,1.2818999985853832,1.2821499903996785,1.2823899885018666,1.2826199928919475,1.2828399936358135,1.2830400069554646,1.2832400004069011,1.28343000014623,1.2836000124613445,1.2837600111961365,1.2839199999968212,1.2840599815050762,1.2841899891694386,1.2843000292778015,1.284410019715627,1.2845100164413452,1.2845899959405263,1.2846699953079224,1.2847299873828888,1.2847799956798553,1.2848299940427144,1.2848600049813588,1.284880002339681,1.2848899960517883,1.2848800122737885,1.2848700086275737,1.2848499914010365,1.2848099966843922,1.284770001967748,1.2847099900245667,1.284639984369278,1.2845599949359894,1.2844699919223785,1.2843699951966603,1.2842599948247273,1.2841400106747944,1.2839999894301097,1.2838599880536397,1.2836999992529552,1.2835299869378407,1.2833500107129414,1.2831699947516124,1.2829900085926056,1.2827999989191692,1.2826200028260548,1.2824400067329407,1.2822499970595043,1.2820700109004974,1.2818900048732758,1.2817099789778392,1.2815199891726177,1.2813400129477184,1.2811599969863892,1.2809699873129528,1.280790001153946,1.2806100050608318,1.2804199953873951,1.2802400092283885,1.2800600032011669,1.2798799971739452,1.2796900073687236,1.2795100212097168,1.2793299853801727,1.2791399856408436,1.2789599895477295,1.2787800033887227,1.2785999874273937,1.2784100075562794,1.2782300015290577,1.2780500054359436,1.277869999408722,1.2776799897352855,1.2774999837080638,1.277319997549057,1.2771400014559429,1.2769500116507213,1.276769995689392,1.2765900095303853,1.2764099935690563,1.2762200037638347,1.2760400176048279,1.2758599917093914,1.275679995616277,1.275499979654948,1.2753099997838337,1.2751299838225048,1.2749499877293904,1.2747700015703838,1.2745800018310547,1.2744000057379405,1.2742199997107189,1.2740399936834972,1.2738599975903828,1.2736699879169464,1.2734900017579396,1.273309995730718,1.2731300095717113,1.2729499737421672,1.272760013739268,1.2725799977779388,1.2723999917507172,1.272219995657603,1.2720400094985962,1.271859993537267,1.271669993797938,1.2714899977048237,1.2713100016117096,1.2711300055185955,1.2709499994913738,1.270769993464152,1.2705800036589305,1.2703999976317089,1.2702200015385945,1.2700399855772655,1.2698599994182587,1.2696800033251445,1.2695000072320302,1.2693099876244862,1.269129991531372,1.268949995438258,1.2687700192133586,1.2685900231202443,1.2684099972248077,1.2682300011316936,1.2680500050385792,1.2678599953651428,1.2676799992720287,1.267499993244807,1.2673199971516926,1.2671400010585785,1.2669600049654643,1.2667799989382427,1.2666000227133434,1.2664199968179066,1.2662400106589,1.2660500009854634,1.2658700148264568,1.2656899988651276,1.2655099928379059,1.2653299967447917,1.2651500006516774,1.2649700045585632,1.2647899985313416,1.2646099925041199,1.2644299964110057,1.2642500003178914,1.2640700042247772,1.2638899981975555,1.2637099921703339,1.2635300159454346,1.2633400062719982,1.2631600002447765,1.2629799942175548,1.262800008058548,1.2626199920972188,1.2624400059382122,1.2622599999109905,1.2620799938837688,1.261900007724762,1.2617200016975403,1.2615399956703186,1.2613600095113118,1.26118000348409,1.2609999974568684,1.2608200013637543,1.2606400052706401,1.2604599992434184,1.2602799932161968,1.26010000705719,1.2599200010299683,1.2597399950027466,1.2595599989096324,1.259380002816518,1.2591999967892964,1.2590200006961823,1.258840004603068,1.2586599985758464,1.2584799925486247,1.258300006389618,1.2581200003623962,1.2579399943351746,1.2577600081761677,1.257580002148946,1.2573999961217244,1.2572200000286102,1.257040003935496,1.2568600177764893,1.2566799819469452,1.2565099795659382,1.2563299934069316,1.2561499973138173,1.2559700012207031,1.255790005127589,1.2556099891662598,1.2554299930731456,1.2552499969800313,1.2550699909528096,1.254890004793803,1.2547099987665813,1.254529982805252,1.2543499966462452,1.254170000553131,1.2539899945259094,1.2538199921449025,1.2536400059858959,1.2534599900245667,1.2532799939314525,1.2530999978383381,1.252920001745224,1.2527400056521099,1.2525600095589955,1.2523800134658813,1.2522000074386597,1.2520299851894379,1.2518500089645386,1.2516700128714244,1.25149001677831,1.251309980948766,1.2511299947897594,1.2509500086307526,1.2507700026035309,1.250600020090739,1.2504200041294098,1.2502400080362956,1.2500599920749664,1.2498799959818523,1.2496999899546306,1.249519983927409,1.2493499914805095,1.2491699953873951,1.248989999294281,1.2488100032011669,1.2486300071080525,1.248450020949046,1.2482800086339314,1.2481000026067097,1.2479200065135956,1.247739980618159,1.247560014327367,1.2473800083001454,1.2472100059191387,1.247029980023702,1.2468499938646953,1.246670017639796,1.2464900116125743,1.2463199893633525,1.2461400032043457,1.2459600071112316,1.2457799911499023,1.2456000049908955,1.2454300026098888,1.245249996582667,1.2450700004895527,1.2448899845282237,1.2447099884351094,1.24453999598821,1.2443600098292034,1.244180013736089,1.24399999777476,1.243829995393753,1.243649999300639,1.2434699932734172,1.2432899872461955,1.2431100110212963,1.2429399987061818,1.2427600026130676,1.2425799866517384,1.2424000104268391,1.2422299981117249,1.2420500020186107,1.241869995991389,1.2416899899641674,1.2415199875831604,1.2413399914900463,1.241159995396932,1.2409899930159252,1.2408100068569183,1.2406300008296967,1.2404500047365825,1.2402800023555756,1.2401000062624614,1.239920010169347,1.239749977986018,1.2395700017611186,1.239389995733897,1.2392099996407826,1.2390400071938832,1.2388600011666615,1.2386800050735474,1.2385900020599365};
    //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194267277916273,0.18438099945584932,0.18694199994206429,0.18960299963752428,0.1924040007094542,0.1953470011552175,0.19843100135525069,0.2015330009162426,0.20452999820311865,0.20742200190822283,0.210207998752594,0.21289000163475671,0.21546600138147673,0.2179370013376077,0.22030300026138624,0.22256400187810263,0.22471999997893968,0.22678999975323677,0.22879299893975258,0.2307290012637774,0.23259600003560385,0.23439600070317587,0.2361299991607666,0.23779600113630295,0.23939399917920431,0.2409259999791781,0.24239000057180723,0.24379999935626984,0.24516599997878075,0.24648799871404967,0.24776799976825714,0.24900499979654947,0.25019900128245354,0.251350000500679,0.2524559994538625,0.25352099786202115,0.2545430014530818,0.2555289988716443,0.2564869945247968,0.2574179992079735,0.25832200050354004,0.25919799755016965,0.26004499693711597,0.26086599628130597,0.26165899634361267,0.262423999607563,0.2631620019674301,0.2638759985566139,0.26457300037145615,0.2652530024449031,0.26591600229342777,0.26656100153923035,0.267186996837457,0.26779600232839584,0.26838600138823193,0.2689589982231458,0.2695140019059181,0.27005400011936825,0.2705849955479304,0.27110300461451214,0.27160999923944473,0.27210699766874313,0.2725920006632805,0.27306600163380307,0.27352800220251083,0.2739780048529307,0.2744180013736089,0.2748430023590724,0.2752469951907794,0.27563100059827167,0.2759939953684807,0.27633699774742126,0.2766609986623128,0.2769649997353554,0.2772490009665489,0.27751300235589343,0.2777559980750084,0.277988001704216,0.2782209987441699,0.2784540007511775,0.27868599941333133,0.2789189989368121,0.2791510025660197,0.27938399960597354,0.27961599826812744,0.27984899779160816,0.28008100390434265,0.2803120017051697,0.28054000437259674,0.2807670036951701,0.2809930021564166,0.28121600300073624,0.2814370021224022,0.2816559970378876,0.28187400102615356,0.2820889999469121,0.28230200211207074,0.2825139984488487,0.2827240005135536,0.28293099999427795,0.28313600023587543,0.2833399996161461,0.283541997273763,0.28374199817578,0.28393899897734326,0.28413499891757965,0.28432899961868924,0.2845210035641988,0.28470999995867413,0.2848979979753494,0.2850850000977516,0.28526900211970013,0.2854510024189949,0.285631000995636,0.2858099987109502,0.2859859988093376,0.28616000215212506,0.2863320012887319,0.2865029995640119,0.2866710002223651,0.28683699915806454,0.28700200219949085,0.28716499855120975,0.2873259981473287,0.28748400261004764,0.2876409987608592,0.2877959956725438,0.28794900079568225,0.2880999992291133,0.2882489984234174,0.2883960008621216,0.2885419974724452,0.28868399808804196,0.28882500032583874,0.28896499673525494,0.28910300383965176,0.28923799842596054,0.28937100370724994,0.2895030006766319,0.28963300089041394,0.2897600010037422,0.2898859977722168,0.2900099977850914,0.2901320084929466,0.2902510066827138,0.2903690015276273,0.29048600047826767,0.2905999993284543,0.2907120039065679,0.29082200676202774,0.29093100130558014,0.2910369982322057,0.29114100088675815,0.2912430018186569,0.2913450027505557,0.29144299527009326,0.2915390034516652,0.29163400332132977,0.2917279948790868,0.2918189962704976,0.2919069975614548,0.2919930045803388,0.2920770024259885,0.2921599994103114,0.29224100212256116,0.29231900225083035,0.2923960015177727,0.2924709990620613,0.29254400233427685,0.2926140030225118,0.29268300036589306,0.292751004298528,0.29281600068012875,0.29287899782260257,0.29294000566005707,0.2930000002185504,0.29305800298849743,0.29311300069093704,0.29316700001557666,0.2932189976175626,0.29326899846394855,0.29331599920988083,0.29336199909448624,0.29340599725643796,0.29344899704058963,0.29348800083001453,0.29352599879105884,0.29356300085783005,0.2935980012019475,0.2936299964785576,0.2936599999666214,0.2936890001098315,0.2937160034974416,0.29373999685049057,0.2937629943092664,0.2937849958737691,0.29380399733781815,0.29382000118494034,0.29383599758148193,0.29384999970595044,0.2938609992464383,0.2938699995477994,0.2938770006100337,0.29388399918874103,0.2938869968056679,0.29388899852832157,0.29388900101184845,0.2938870017727216,0.2938830032944679,0.2938769956429799,0.2938690011699994,0.2938599983851115,0.29384800295035046,0.29383400082588196,0.29381900032361347,0.29380200306574505,0.293783001601696,0.2937609975536664,0.2937380025784175,0.293713999291261,0.29368699342012405,0.29365800072749454,0.2936270038286845,0.29359500110149384,0.29356099913517636,0.29352400203545886,0.29348499824603397,0.29344600190718967,0.293404000500838,0.2933590014775594,0.29331299662590027,0.2932659983634949,0.2932160000006358,0.2931639974315961,0.29311000059048337,0.2930560012658437,0.2929980034629504,0.29294000069300336,0.29288100202878314,0.292823001742363,0.29276400059461594,0.29270600030819577,0.29264699916044873,0.2925880054632823,0.29252999772628147,0.2924709965785344,0.29241299877564114,0.29235400011142093,0.29229600230852765,0.2922380045056343,0.29217899839083356,0.2921210005879402,0.2920619994401932,0.2920040041208267,0.2919450004895528,0.2918869952360789,0.29182899991671246,0.2917699987689654,0.2917119984825452,0.2916540006796519,0.2915950020154317,0.2915370042125384,0.2914789964755376,0.29142000029484433,0.2913619975248973,0.29130400468905765,0.2912460019191106,0.29118699828783673,0.2911289955178897,0.29107099771499634,0.29101299742857617,0.2909550021092097,0.2908960034449895,0.29083799570798874,0.2907800003886223,0.2907220001022021,0.2906640022993088,0.29060600449641544,0.2905469958980878,0.2904890055457751,0.2904310077428818,0.2903729975223541,0.29031500220298767,0.2902569994330406,0.29019899914662045,0.2901410013437271,0.29008299857378006,0.2900250007708867,0.28996700048446655,0.2899090001980464,0.28985099494457245,0.289792999625206,0.28973499685525894,0.2896770015358925,0.2896190012494723,0.289561003446579,0.2895030006766319,0.28944599876801175,0.2893880009651184,0.28933000067869824,0.2892720028758049,0.28921399513880414,0.2891559948523839,0.28909799953301746,0.289041002591451,0.2889830047885577,0.28892500201861065,0.28886699428160983,0.28880900144577026,0.2887520020206769,0.28869400173425674,0.2886359964807828,0.2885779986778895,0.2885209992527962,0.28846300144990283,0.2884049986799558,0.2883480017383893,0.28828999896844226,0.2882319986820221,0.2881750042239825,0.2881170039375623,0.28805900116761524,0.28800200174252194,0.2879440039396286,0.28788699706395465,0.2878289942940076,0.287771999835968,0.28771399706602097,0.2876560017466545,0.28759899735450745,0.2875409970680873,0.28748400261004764,0.28742599735657376,0.2873689979314804,0.28731200098991394,0.2872540007034938,0.28719699879487354,0.2871390034755071,0.2870820040504138,0.28702400128046673,0.28696699688831967,0.2869099974632263,0.28685199469327927,0.2867949977517128,0.28673699994881946,0.2866799980401993,0.2866230035821597,0.28656500081221264,0.2865079964200656,0.2864510044455528,0.2863939975698789,0.2863360047340393,0.28627900034189224,0.28622199843327206,0.286164994041125,0.28610700368881226,0.2860499968131383,0.285992997388045,0.2859360029300054,0.2858790010213852,0.28582099825143814,0.28576400379339856,0.2857069994012515,0.28564999749263126,0.28559299806753796,0.2855359986424446,0.285479004184405,0.2854209989309311,0.28536399950583774,0.28530699759721756,0.2852499981721242,0.2851929987470309,0.28513599932193756,0.2850789974133174,0.2850220004717509,0.2849649985631307,0.2849079966545105,0.28485099971294403,0.2847940002878507,0.2847370008627574,0.28468000143766403,0.2846229945619901,0.2845670059323311,0.284510001540184,0.28445299963156384,0.2843959977229436,0.28433900078137714,0.28428199887275696,0.2842249969641368,0.28416800250609714,0.28411199649175006,0.2840549995501836,0.28399800260861713,0.28394100318352383,0.28388399879137677,0.2838279977440834,0.2837710032860438,0.28371399889389676,0.2836570019523303,0.2836010009050369,0.28354399899641675,0.2834869970877965,0.28343099852403003,0.28337399909893674,0.2833169996738434,0.2832609936594963,0.2832039992014567,0.28314700225989026,0.2830910012125969,0.2830339993039767,0.28297700236241025,0.2829210013151169,0.2828639994064967,0.2828080008427302,0.28275099893411,0.2826949978868167,0.28263800342877704,0.28258199989795685,0.2825250029563904,0.282469001909097,0.28241200000047684,0.28235599398612976,0.282299002011617,0.2822430009643237,0.28218599657217663,0.28212999800841015,0.2820729985833168,0.28201700498660404,0.28196100145578384,0.2819040020306905,0.2818480009833972,0.28179099907477695,0.28173500051101047,0.28167899946371716,0.2816219975550969,0.28156599899133045,0.28150999794403714,0.2814530034859975,0.2813970024387042,0.2813409964243571,0.28128500034411746,0.281228003402551,0.2811719998717308,0.2811160037914912,0.28106000522772473,0.2810030033191045,0.2809469997882843,0.2808910012245178,0.28083500266075134,0.28077900409698486,0.2807230030496915,0.2806659961740176,0.28061000009377796,0.28055400401353836,0.28049800048271817,0.2804419994354248,0.2803860008716583,0.28033000230789185,0.2802740012605985,0.280218002696832,0.2801620016495387,0.28010599811871845,0.28004999955495197,0.2799940009911855,0.2799379999438922,0.2798819988965988,0.27982600033283234,0.279769999285539,0.2797140007217725,0.2796579996744792,0.2796020011107127,0.27954600006341934,0.27949000149965286,0.2794340004523595,0.2793780043721199,0.2793219983577728,0.2792670006553332,0.27921099960803986,0.2791550010442734,0.27909899999698,0.27904300143321353,0.27898800124724704,0.27893200019995373,0.27887600163618725,0.2788200030724208,0.27879200130701065};
    //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12689302240808806,0.1277389998237292,0.12867999946077666,0.1296249988178412,0.13062099864085516,0.13166699931025505,0.13276400168736777,0.13386699929833412,0.13493300105134645,0.13596000025669733,0.13694899901747704,0.137899998575449,0.13881300017237663,0.13968800008296967,0.14052600165208182,0.14132499819000563,0.142085999250412,0.142815999686718,0.14352100094159445,0.14420299852887788,0.14485999941825867,0.14549299950400987,0.14610200002789497,0.14668700223167738,0.14724599942564964,0.1477809982995192,0.14829100047548613,0.14878199870387712,0.1492569980521997,0.14971599852045378,0.15015999972820282,0.15058800081411997,0.1509999968111515,0.15139800061782202,0.15177900095780691,0.15214500079552332,0.15249500051140785,0.15283300106724104,0.15316000084082285,0.15347899869084358,0.15378699948390326,0.154084000736475,0.15437100206812224,0.15464899813135466,0.15491700048247972,0.15517500042915344,0.1554219995935758,0.15566200017929077,0.1558960018058618,0.1561220002671083,0.15634299938877425,0.1565569986899694,0.15676499779025713,0.15696599831183752,0.1571609986325105,0.15734999751051268,0.15753200029333433,0.15770799914995828,0.157880999147892,0.1580490010480086,0.15821400036414465,0.1583739990989367,0.15853100145856538,0.1586829995115598,0.15883099908630052,0.15897599856058756,0.15911500031749407,0.1592499961455663,0.1593769999841849,0.15949599941571554,0.1596089998881022,0.15971400092045465,0.15981299926837286,0.1599029985566934,0.15998600050807,0.16006299977501234,0.16013200084368387,0.16019700095057487,0.16026299943526587,0.16032900164524713,0.16039500012993813,0.16046000147859255,0.16052599996328354,0.1605920009315014,0.1606569985548655,0.16072299952308336,0.1607890004913012,0.16085400059819221,0.16091900194684663,0.1609830011924108,0.16104599833488464,0.1611079995830854,0.1611699995895227,0.16123099873463312,0.16129099826018015,0.16135099778572717,0.1614099989334742,0.1614679992198944,0.1615259995063146,0.16158300141493478,0.1616390012204647,0.16169399892290434,0.1617479994893074,0.16180099919438362,0.16185500100255013,0.1619069998462995,0.1619589999318123,0.16200900077819824,0.16205900038282076,0.1621090012292067,0.16215799873073897,0.1622060015797615,0.1622529998421669,0.16229999934633574,0.16234599923094115,0.16239100073774657,0.16243600100278854,0.16247999916474024,0.16252299894889197,0.16256500035524368,0.16260699927806854,0.16264799982309341,0.1626890003681183,0.16272799794872603,0.16276700297991434,0.16280599931875864,0.1628439985215664,0.16288000096877417,0.16291599969069162,0.16295199965437254,0.16298699999849,0.16302100072304407,0.16305400306979814,0.1630869967242082,0.1631180023153623,0.1631490004559358,0.16318000108003616,0.16320900122324625,0.16323800012469292,0.1632660006483396,0.1632940024137497,0.1633210008343061,0.16334699963529906,0.16337299967805544,0.16339699923992157,0.16342100128531456,0.1634450008471807,0.1634680007894834,0.16349000111222267,0.16351100181539854,0.1635309991737207,0.16355100149909654,0.16357100009918213,0.16358899821837744,0.16360700006286302,0.1636239985624949,0.16363999992609024,0.16365600004792213,0.16367100179195404,0.1636860010524591,0.16369899859031042,0.16371199985345206,0.1637250011165937,0.16373600189884505,0.1637469989558061,0.1637569988767306,0.16376599917809168,0.16377399861812592,0.16378199929992357,0.16379000122348467,0.16379600142439207,0.1638019991417726,0.16380600134531656,0.1638110006848971,0.16381500040491423,0.1638180029888948,0.16381999850273132,0.16382199774185816,0.16382299860318503,0.16382300108671188,0.16382299984494844,0.1638210006058216,0.16381899764140448,0.1638170008858045,0.16381399830182394,0.16380999982357025,0.1638059988617897,0.16380000238617262,0.1637940009435018,0.1637880007425944,0.16378099968036017,0.16377300024032593,0.1637639986972014,0.16375400250156721,0.16374300171931586,0.1637319984535376,0.16372100015481314,0.1637079988916715,0.16369500011205673,0.16368099922935167,0.1636670008301735,0.16365200032790503,0.16363600020607313,0.1636190004646778,0.16360100110371908,0.16358400136232376,0.16356600200136504,0.163546002159516,0.163526002317667,0.16350500037272772,0.1634840009113153,0.16346199934681258,0.16343999778230986,0.16341599822044373,0.16339199741681418,0.1633670007189115,0.16334200029571852,0.16331600149472555,0.16328900183240572,0.16326100006699562,0.16323300078511238,0.1632050002614657,0.16317499925692877,0.16314500073591867,0.1631140001118183,0.16308199986815453,0.16304900124669075,0.16301599889993668,0.16298199941714606,0.1629479999343554,0.16291199872891107,0.16287600000699362,0.1628400000433127,0.16280200084050497,0.16276499877373377,0.16272600119312605,0.16268600150942802,0.16264599934220314,0.1626069980363051,0.16256699959437051,0.16252699991067251,0.16248799860477448,0.16244799892107645,0.16240799923737845,0.16236899917324385,0.16232899824778238,0.16228999942541122,0.1622499997417132,0.16221100091934204,0.1621709999938806,0.16213099906841913,0.16209199776252112,0.1620519980788231,0.1620129980146885,0.1619729995727539,0.1619339995086193,0.16189399858315787,0.16185500100255013,0.1618150013188521,0.16177599877119064,0.16173600032925606,0.16169700026512146,0.16165800020098686,0.16161800175905228,0.16157900045315424,0.16153900076945624,0.16150000194708505,0.1614609993994236,0.16142099971572557,0.16138200337688127,0.16134199996789297,0.16130299990375838,0.16126399983962378,0.16122400015592575,0.16118500009179115,0.1611459975441297,0.1611070024470488,0.16106700027982393,0.16102799897392592,0.16098899766802788,0.16094900046785673,0.16091000040372214,0.16087100033958754,0.16083199779192606,0.1607920005917549,0.16075299680233002,0.16071399797995886,0.16067499915758768,0.16063599909345308,0.16059700027108192,0.1605570005873839,0.1605180005232493,0.16047899797558784,0.1604399991532167,0.1604009990890821,0.1603620002667109,0.1603230002025763,0.1602830005188783,0.16024400169650713,0.16020500039060911,0.16016600032647452,0.16012700026233992,0.16008799895644188,0.16004900013407072,0.16001000006993613,0.15997100124756494,0.1599319986999035,0.15989299987753233,0.15985400105516115,0.15981499974926314,0.15977599968512854,0.15973700334628424,0.1596979983150959,0.15965900321801504,0.15961999942859015,0.15958099936445555,0.15954199930032095,0.1595029979944229,0.15946500251690546,0.159425999969244,0.15938700114687285,0.15934799859921137,0.15930900474389395,0.1592699997127056,0.15923100089033446,0.15919299920399985,0.1591539978981018,0.15911499907573065,0.15907600025335947,0.15903700018922487,0.15899899726112685,0.15896000092228255,0.15892100085814795,0.15888200079401335,0.1588439978659153,0.158805001527071,0.15876600022117296,0.15872700015703836,0.1586889997124672,0.15864999840656915,0.15861100206772485,0.1585730016231537,0.15853400031725565,0.15849500025312105,0.15845700105031332,0.15841799974441528,0.15837899843851724,0.15834099923570952,0.15830200165510178,0.15826300034920374,0.158225001146396,0.15818599984049797,0.1581479993959268,0.15810900057355562,0.1580710013707479,0.1580320013066133,0.15799300000071526,0.1579549970726172,0.15791599825024605,0.15787800028920174,0.15783900022506714,0.15780099978049597,0.15776200219988823,0.15772399927179018,0.15768499796589217,0.15764700000484785,0.15760899831851324,0.15757000197966894,0.15753200029333433,0.15749300147096315,0.15745499978462854,0.15741600220402083,0.15737800051768622,0.15734000379840532,0.15730100000898042,0.1572630008061727,0.1572249991198381,0.1571859990557035,0.15714799985289574,0.15711000065008798,0.15707100058595339,0.15703300138314566,0.1569949984550476,0.15695599963267645,0.1569180004298687,0.15688000122706094,0.15684200078248978,0.15680299823482832,0.15676500151554743,0.1567269985874494,0.1566890006264051,0.1566499980787436,0.1566120001176993,0.15657399967312813,0.15653600171208382,0.15649800126751265,0.15646000082294145,0.15642100075880686,0.15638299907247225,0.15634500111142793,0.15630699942509332,0.15626899898052216,0.15623100101947784,0.15619300057490668,0.15615499888857207,0.15611600130796432,0.15607799837986627,0.15603999917705855,0.1560019999742508,0.15596400201320648,0.15592599908510843,0.15588799864053726,0.15585000067949295,0.15581200271844864,0.1557739997903506,0.15573599934577942,0.15569799890120825,0.15566000094016394,0.15562200297911963,0.15558400005102158,0.1555459996064504,0.15550800040364265,0.1554709995786349,0.15543299789230028,0.15539499993125597,0.1553569994866848,0.15531899904211363,0.15528099983930588,0.15524300063649812,0.15520500019192696,0.1551669997473558,0.15512999892234802,0.15509199971954027,0.1550539992749691,0.15501599883039793,0.15497799962759018,0.15494100004434586,0.1549030008415381,0.15486500163873038,0.15482699871063232,0.154789000749588,0.15475199992458025,0.15471400072177252,0.15467600151896477,0.15463900193572044,0.15460100149114928,0.15456300104657808,0.15452499811848006,0.15448800226052603,0.15444999809066454,0.15441199764609337,0.15437499806284904,0.15433700134356818,0.15429899841547012,0.1542619988322258,0.15422399962941805,0.15418700004617372,0.154149000843366,0.1541109991570314,0.15407399957378706,0.15403599912921587,0.15399899954597154,0.15396099910140038,0.15392399951815605,0.15388599907358488,0.15384799987077713,0.15381099904576936,0.15377299984296164,0.15373600025971731,0.15369799981514612,0.1536610002319018,0.15362400064865747,0.15358600144584975,0.15354900062084198,0.15351100265979767,0.1534740005930265,0.1534360001484553,0.15339900056521097,0.15336100136240324,0.15332399929563204,0.15328700095415115,0.15324900050957999,0.15321199844280878,0.15317499761780104,0.15313699965675673,0.15311900029579797};
    C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.2843420207500458,0.28995800018310547,0.2954619973897934,0.302055003742377,0.308998001118501,0.3162899961074193,0.3239319920539856,0.33161700268586475,0.33904099961121875,0.34620199849208194,0.3531020035346349,0.3597410023212433,0.36611799895763397,0.37223399927218753,0.3780889982978503,0.3836810017625491,0.3890129973491033,0.39413200070460636,0.3990819975733757,0.4038640037178993,0.408479002614816,0.41292699923117954,0.4172079985340436,0.42131999880075455,0.42526500175396603,0.4290429974595706,0.4326540008187294,0.43612799793481827,0.4394960055748622,0.44275499631961185,0.44590599834918976,0.4489499976237615,0.4518880024552345,0.4547180011868477,0.4574420054753621,0.4600579962134361,0.46256600071986514,0.46498699982961017,0.46734000494082767,0.46962299942970276,0.47183799743652344,0.4739840005834897,0.47606200476487476,0.47807099918524426,0.4800109962622325,0.48188300182422,0.48368599514166516,0.48543299982945126,0.48713599890470505,0.4887950047850609,0.4904099976023038,0.49198000133037567,0.4935059994459152,0.4949890002608299,0.4964280004302661,0.49782299747069675,0.49917299548784894,0.5004870121677717,0.50177401304245,0.503031998872757,0.5042619953552882,0.5054640024900436,0.5066380053758621,0.5077830056349436,0.5088999966780344,0.5099879950284958,0.5110489974419276,0.5120700051387151,0.5130419979492823,0.513965000708898,0.514836996793747,0.5156589994827906,0.5164309988419215,0.5171539982159933,0.5178269992272059,0.5184510002533594,0.5190249979496002,0.5195740063985189,0.5201229949792227,0.5206710000832876,0.5212200085322062,0.5217679937680563,0.5223160088062286,0.5228639990091324,0.5234119941790899,0.5239600042502085,0.524507001042366,0.5250520010789236,0.5255930026372274,0.5261280089616776,0.5266580035289129,0.527184009552002,0.527703990538915,0.5282190044720968,0.5287300000588099,0.5292350053787231,0.5297360022862753,0.5302309989929199,0.5307220021883646,0.5312069853146871,0.5316879997650782,0.5321629991134008,0.5326340049505234,0.5330989956855774,0.5335600127776464,0.5340160032113394,0.5344669967889786,0.5349119951327642,0.5353529949982961,0.5357890079418818,0.5362199991941452,0.5366459985574087,0.5370679944753647,0.5374850034713745,0.5378970007101694,0.538303996125857,0.5387059996525446,0.5391039997339249,0.539495994647344,0.5398829976717631,0.5402659972508749,0.5406429966290792,0.5410160074631373,0.5413839916388193,0.5417460004488627,0.5421039958794912,0.5424570043881735,0.5428050061066946,0.5431480010350546,0.5434859891732534,0.543819010257721,0.544146994749705,0.5444700022538503,0.5447889963785807,0.5451019952694575,0.5454110006491343,0.5457140058279037,0.5460139860709509,0.5463090091943741,0.5465980023145676,0.5468830019235611,0.5471629947423935,0.5474389940500259,0.5477090130249659,0.5479740103085836,0.5482339958349863,0.5484899977842966,0.5487409979104996,0.5489859928687414,0.5492270042498907,0.5494629989067713,0.5496939917405447,0.5499200026194254,0.5501420050859451,0.55035799741745,0.5505690028270086,0.550775999824206,0.5509779999653498,0.5511750131845474,0.551366999745369,0.5515539993842443,0.5517359922329584,0.5519140064716339,0.552087997396787,0.5522559980551401,0.552419995268186,0.552578995625178,0.5527329991261164,0.5528820008039474,0.553026000658671,0.553166002035141,0.5533000032107035,0.5534300009409586,0.5535550018151602,0.5536750008662542,0.5537900080283483,0.5538999934991201,0.5540050019820532,0.5541060020526251,0.5542020003000895,0.5542930016915003,0.5543790012598038,0.5544599990049998,0.5545360048611959,0.5546080023050308,0.5546739995479584,0.5547359883785248,0.5547939985990524,0.5548470119635264,0.5548949937025706,0.5549389918645223,0.5549780080715815,0.5550109992424647,0.5550399969021479,0.5550640026728312,0.5550839950640997,0.5550980021556219,0.5551079958677292,0.5551130026578903,0.5551129976908366,0.5551079909006754,0.5550990055004755,0.5550839900970459,0.5550649911165237,0.5550410101811091,0.5550119976202647,0.5549789915482203,0.5549400001764297,0.5548970053593317,0.5548490037520727,0.5547960003217062,0.5547390033801397,0.5546769946813583,0.554610992471377,0.5545399934053421,0.5544640074173609,0.5543829947710037,0.554297998547554,0.5542079955339432,0.5541130055983862,0.5540129989385605,0.5539089938004812,0.5537989983956019,0.5536850094795227,0.5535660038391749,0.5534429997205734,0.5533140103022257,0.5531809975703558,0.5530429929494858,0.5529000063737234,0.5527529964844385,0.5526000012954077,0.5524429976940155,0.552281990647316,0.5521149983008703,0.5519439925750097,0.5517680048942566,0.5515900005896887,0.5514119962851206,0.5512340019146601,0.5510560025771459,0.5508779982725779,0.5507009973128637,0.5505229930082957,0.5503449986378351,0.5501680076122284,0.5499909967184067,0.5498129973808924,0.5496359964211782,0.5494590004285177,0.5492810060580572,0.5491039951642355,0.5489269942045212,0.5487500031789144,0.5485729972521464,0.5483960012594858,0.5482190002997717,0.5480419943730036,0.5478660017251968,0.5476890057325363,0.5475119998057684,0.5473360021909078,0.5471590061982473,0.5469829986492792,0.5468060026566187,0.5466300050417582,0.5464539974927902,0.5462769965330759,0.5461009939511617,0.5459250013033549,0.5457489887873331,0.5455729961395264,0.5453969836235046,0.5452209959427515,0.5450450032949448,0.5448689957459768,0.5446939965089163,0.544517993927002,0.5443420012791952,0.5441670020421346,0.5439910044272741,0.543815995256106,0.5436399976412455,0.5434649934371313,0.5432899991671244,0.5431150048971176,0.5429390023152033,0.5427640080451965,0.5425889988740286,0.542413999636968,0.5422390003999075,0.5420640011628469,0.5418900003035864,0.541714996099472,0.5415399968624115,0.5413649926582972,0.5411910017331442,0.5410160024960836,0.540842001636823,0.5406669974327087,0.540493001540502,0.5403189907471339,0.5401439964771271,0.5399699906508127,0.5397959997256597,0.5396220038334528,0.5394480029741923,0.539273997147878,0.5391000012556711,0.5389259954293569,0.5387519945700964,0.5385789920886358,0.5384050061305364,0.5382309953371683,0.5380580027898153,0.5378840068976084,0.5377109944820404,0.5375369985898336,0.5373640010754267,0.5371899952491125,0.5370169927676519,0.53684401512146,0.536671002705892,0.5364980002244314,0.5363250027100245,0.5361520002285639,0.5359790076812109,0.5358060002326965,0.535632997751236,0.5354599952697754,0.5352879961331686,0.535114993651708,0.5349420011043549,0.534770001967748,0.5345970094203949,0.5344249953826269,0.53425299624602,0.5340799937645594,0.5339079896608988,0.5337360054254532,0.5335640013217926,0.5333920121192932,0.5332199980815252,0.533048003911972,0.5328760047753652,0.5327040006717046,0.5325320015350977,0.5323599974314371,0.5321890016396841,0.5320169925689697,0.5318449934323629,0.5316740026076635,0.5315020034710566,0.5313310076793035,0.5311590035756429,0.5309879978497823,0.5308170020580292,0.5306459963321686,0.5304749955733618,0.5303029914697012,0.5301320006450018,0.5299609949191412,0.5297909925381342,0.5296200017134348,0.5294489959875742,0.5292780051628748,0.529107004404068,0.5289370069901148,0.5287659962972006,0.5285959939161936,0.5284249981244405,0.5282550007104874,0.5280839949846268,0.5279139975706736,0.527743990222613,0.5275729944308599,0.5274030069510142,0.5272330045700073,0.5270630021890005,0.5268929998079935,0.5267230023940405,0.5265529950459799,0.5263840059439341,0.5262140035629272,0.5260439962148666,0.525874008735021,0.5257050096988678,0.5255349973837534,0.525366003314654,0.5251960059007009,0.5250270068645477,0.5248579978942871,0.5246879905462265,0.5245189915100733,0.5243500024080276,0.5241809984048208,0.5240120043357214,0.5238430003325144,0.5236740112304688,0.5235049972931544,0.5233359982570013,0.5231669992208481,0.5229980001846949,0.5228299895922343,0.5226609955231348,0.5224930097659429,0.5223240007956823,0.5221560001373291,0.5219870110352834,0.5218190054098765,0.5216499964396158,0.5214820057153702,0.5213140000899633,0.5211459994316101,0.5209780037403107,0.5208100030819575,0.5206420024236044,0.52047398686409,0.5203059961398443,0.5201379954814911,0.5199700097242991,0.5198030024766922,0.519635001818339,0.5194669961929321,0.5192999939123789,0.5191319982210795,0.5189650058746338,0.5187979986270269,0.5186300029357275,0.518463005622228,0.518295998374621,0.5181290010611216,0.5179620087146759,0.5177949965000153,0.5176280041535696,0.5174610018730164,0.5172939896583557,0.51712699731191,0.5169599999984106,0.5167929977178574,0.5166270037492117,0.5164600014686584,0.516293004155159,0.5161270002524058,0.5159599979718527,0.5157939990361532,0.5156280001004537,0.5154610027869543,0.5152950038512548,0.5151289900143942,0.5149630010128021,0.5147969971100489,0.5146309981743494,0.51446499923865,0.5142990003029505,0.5141329964001974,0.5139670024315516,0.5138010034958521,0.5136359930038452,0.5134700040022532,0.5133040100336075,0.5131389945745468,0.5129730006059011,0.5128079950809479,0.5126419961452484,0.5124769955873489,0.5123120099306107,0.5121460010608038,0.5119809955358505,0.5118160049120585,0.5116509993871053,0.5114859938621521,0.51132100323836,0.5111560026804606,0.5109909921884537,0.5108270049095154,0.5106619894504547,0.5104970037937164,0.510332003235817,0.5101680060227712,0.5100030104319254,0.5098390032847723,0.509673997759819,0.5095100104808807,0.5093460033337275,0.5092630038658778};
    //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12939750775694847,0.1327460010846456,0.13622500250736871,0.14007199928164482,0.14412199954191843,0.14837600042422613,0.1528329998254776,0.15731599802772203,0.16164499893784523,0.16582300141453743,0.1698480024933815,0.173720000932614,0.17744099845488867,0.18100899954636893,0.18442600096265474,0.18769000098109245,0.19080199922124544,0.19378899907072386,0.1966789998114109,0.1994709993402163,0.20216500262419382,0.20476199934879938,0.20726099982857704,0.20966300119956335,0.21196700011690459,0.21417499954501787,0.21628399938344955,0.21831400195757547,0.2202829991777738,0.22218899801373482,0.22403200094898543,0.2258130001525084,0.2275309997300307,0.22918800016244253,0.23078100134929022,0.2323130009075006,0.2337809999783834,0.23519899944464365,0.23657800008853277,0.23791600142916045,0.23921299974123636,0.24047099923094115,0.2416880006591479,0.2428669979174932,0.2440049983561039,0.24510300159454346,0.246159998079141,0.24718499928712845,0.24818499883015951,0.24915799871087074,0.2501060056189696,0.25102900216976803,0.2519260024031003,0.2527970050772031,0.2536429986357689,0.25446299960215885,0.2552580013871193,0.25603100657463074,0.2567880004644394,0.25752900044123334,0.2582540015379588,0.2589609995484352,0.2596520086129506,0.2603269964456558,0.26098600526650745,0.26162800441185635,0.2622540021936099,0.26285700251658756,0.26343100269635517,0.26397600024938583,0.2644920026262601,0.2649789998928706,0.2654380028446515,0.26586699734131497,0.26626699914534885,0.26663800328969955,0.26698100318511325,0.2673090025782585,0.2676369994878769,0.2679639980196953,0.26829200734694797,0.26861999680598575,0.26894700278838474,0.2692749996980031,0.2696020007133484,0.2699289992451668,0.27025700112183887,0.2705820028980573,0.27090400209029514,0.2712239995598793,0.2715420002738635,0.2718560000260671,0.27216699967781705,0.2724750017126401,0.27278000116348267,0.2730820005138715,0.2733820031086604,0.2736790006359418,0.2739730005462964,0.27426299701134366,0.27455100417137146,0.274837002158165,0.27511899669965106,0.27539899448553723,0.2756749987602234,0.275948998828729,0.27622000128030777,0.276488999525706,0.2767540042599042,0.2770159989595413,0.27727499852577847,0.2775310004750888,0.2777850031852722,0.2780359983444214,0.2782840033372243,0.27852799991766614,0.27876999974250793,0.27900999784469604,0.2792470008134842,0.2794800003369649,0.27971099813779193,0.279939000805219,0.28016399840513867,0.2803869942824046,0.2806060016155243,0.2808230022589366,0.28103599945704144,0.28124599903821945,0.2814550002415975,0.281660000483195,0.2818620006243388,0.2820609932144483,0.28225699812173843,0.2824520021677017,0.28264300525188446,0.2828310007850329,0.2830150028069814,0.2831979940334956,0.2833779975771904,0.2835550010204315,0.2837290018796921,0.2838989968101184,0.28406700243552524,0.2842319955428441,0.2843949993451436,0.28455500056346256,0.2847120016813278,0.28486500183741253,0.2850159953037898,0.2851650019486745,0.2853110035260518,0.285452996691068,0.2855930030345917,0.2857300043106079,0.28586499641338986,0.2859959974884987,0.28612500180800754,0.28625000019868213,0.2863729993502299,0.286492998401324,0.2866099973519643,0.286724994579951,0.28683599829673767,0.28694500029087067,0.2870510046680768,0.28715399901072186,0.28725499908129376,0.28735200067361194,0.2874469980597496,0.2875379944841067,0.2876270040869713,0.287712998688221,0.2877970015009244,0.28787700086832047,0.28795500099658966,0.2880300010244052,0.28810200095176697,0.28817200164000195,0.2882379988829295,0.2883019944032033,0.2883629997571309,0.28842199593782425,0.28847699612379074,0.28853000203768414,0.2885790020227432,0.28862599780162174,0.28866999844710034,0.28871199985345203,0.2887510011593501,0.28878600150346756,0.28881900012493134,0.28884900112946826,0.2888769954442978,0.2889019971092542,0.28892399619023007,0.28894199679295224,0.28895899653434753,0.28897299865881604,0.2889840006828308,0.2889920026063919,0.28899699697891873,0.2889980028072993,0.2889980028072993,0.28899499773979187,0.28898899505535763,0.2889799972375234,0.2889679993192355,0.2889540021618207,0.2889380032817523,0.28891800592343014,0.28889500349760056,0.2888690009713173,0.28884099920590717,0.28881099820137024,0.28877799957990646,0.28874099751313526,0.28870200365781784,0.2886589964230855,0.28861399988333386,0.2885669991374016,0.28851700325806934,0.288463997344176,0.2884080037474632,0.2883490001161893,0.2882879972457886,0.2882239992419879,0.28815700113773346,0.2880870004494985,0.2880149980386098,0.28794099887212116,0.28786300371090573,0.2877830018599828,0.28769900153080624,0.28761200110117596,0.2875230014324188,0.2874320025245349,0.2873380010326703,0.28724199781815213,0.2871459995706876,0.2870509997010231,0.28695499897003174,0.2868590032060941,0.286763995885849,0.2866679976383845,0.28657299528519314,0.2864769995212555,0.28638200213511783,0.28628599892059964,0.2861909990509351,0.2860949983199437,0.28599999845027924,0.28590499858061474,0.2858090003331502,0.28571399797995883,0.2856190005938212,0.2855240007241567,0.28542900333801907,0.2853330026070277,0.28523799777030945,0.2851430003841718,0.2850480005145073,0.2849530006448428,0.28485800325870514,0.28476300090551376,0.28466800103584927,0.2845740045110385,0.2844789996743202,0.28438399732112885,0.2842889999349912,0.2841940000653267,0.2840999960899353,0.2840050011873245,0.28390999883413315,0.28381599734226864,0.28372100243965787,0.2836270009477933,0.28353199859460193,0.28343800206979114,0.28334299971659976,0.28324900070826214,0.2831540033221245,0.2830600043137868,0.2829649994770686,0.2828710004687309,0.2827769989768664,0.28268300493558246,0.28258800009886426,0.2824939986069997,0.2823999995986621,0.2823059981067975,0.2822119990984599,0.2821180075407028,0.28202400108178455,0.28192999710639316,0.28183599809805554,0.28174200157324475,0.28164799759785336,0.2815539985895157,0.281459999581178,0.2813669989506404,0.2812730049093564,0.2811789984504382,0.2810849994421005,0.28099199881156284,0.28089799731969833,0.28080399831136066,0.2807110051314036,0.28061699867248535,0.28052400052547455,0.28043000400066376,0.2803369959195455,0.28024300187826157,0.28014999876419705,0.28005700061718625,0.2799629991253217,0.27986999849478406,0.27977700034777325,0.2796829988559087,0.2795900031924248,0.27949700504541397,0.27940400689840317,0.27931100130081177,0.27921799818674725,0.27912500500679016,0.27903199444214505,0.27893900374571484,0.27884599566459656,0.27875300248463947,0.27865999937057495,0.27856700122356415,0.27847399562597275,0.27838100244601566,0.27828799933195114,0.27819600452979404,0.27810299893220264,0.2780099958181381,0.2779180034995079,0.2778249979019165,0.2777320022384326,0.2776399999856949,0.2775470018386841,0.2774549995859464,0.27736200392246246,0.27726999670267105,0.27717799693346024,0.2770850012699763,0.2769930015007655,0.2769009992480278,0.2768079986174901,0.27671600381533307,0.2766239990790685,0.27653199930985767,0.27643899867932004,0.2763469989101092,0.2762549991408984,0.2761629968881607,0.2760709971189499,0.27597899983326596,0.27588700006405514,0.27579499781131744,0.27570299804210663,0.2756109982728958,0.2755190034707387,0.2754280020793279,0.27533599734306335,0.27524399757385254,0.2751520052552223,0.2750609988967578,0.27496899912754696,0.27487699687480927,0.27478600293397903,0.2746940031647682,0.2746029992898305,0.2745109920700391,0.27441999812920886,0.27432799835999805,0.2742369994521141,0.2741450021664302,0.27405400077501935,0.27396300186713535,0.2738709996143977,0.2737800007065137,0.27368899683157605,0.27359800040721893,0.2735060006380081,0.2734150017301242,0.27332399785518646,0.27323299646377563,0.2731420000394185,0.2730509986480077,0.27295999725659686,0.2728690008322398,0.2727780019243558,0.272687000532945,0.27259599914153415,0.2725049977501233,0.27241499970356625,0.27232400079568225,0.2722329994042714,0.2721419980128606,0.27205199748277664,0.2719610035419464,0.27186999718348187,0.27177999913692474,0.2716889977455139,0.2715989996989568,0.27150799830754596,0.2714180052280426,0.27132699886957806,0.27123699833949405,0.2711460043986638,0.271056001385053,0.270966000854969,0.2708750019470851,0.2707849939664205,0.2706950008869171,0.27060400446256,0.27051399896542233,0.2704240009188652,0.27033399790525436,0.2702439973751704,0.27015400181214017,0.27006400128205615,0.2699739982684453,0.26988400022188824,0.26979399969180423,0.26970400164524716,0.26961400111516315,0.2695240005850792,0.26943400005499524,0.2693449979027112,0.26925499737262726,0.2691650042931239,0.2690749987959862,0.26898599912722904,0.26889600108067196,0.2688059980670611,0.268716998398304,0.26862700283527374,0.2685380006829898,0.26844799766937893,0.2683590079347293,0.26826899747053784,0.2681800027688344,0.26809099564949673,0.2680009976029396,0.26791200041770935,0.2678230032324791,0.26773299525181454,0.267644003033638,0.26755499839782715,0.2674659937620163,0.26737700154383975,0.2672879993915558,0.26719799886147183,0.2671090041597684,0.2670200044910113,0.2669309973716736,0.26684199770291644,0.26675299803415936,0.2666650017102559,0.26657599955797195,0.2664869998892148,0.26639800022045773,0.2663089955846469,0.2662209967772166,0.26613199959198636,0.2660430024067561,0.2659540002544721,0.2658660014470418,0.2657770017782847,0.2656889980038007,0.26560000081857044,0.26551200201114017,0.2654229973753293,0.26533499856789905,0.2652459964156151,0.2651579976081848,0.26506900042295456,0.2649809991319974,0.26489300032456714,0.26480400065581006,0.2647159993648529,0.26462800055742264,0.2645399992664655,0.2644960011045138};
    //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09222223547597726,0.09350150016446908,0.09477110020816326,0.09623500021795432,0.09777720086276531,0.09939770090083282,0.10109599928061168,0.1028049997985363,0.10445400017003219,0.10604399939378102,0.10757699919243653,0.10905000008642673,0.11046500007311504,0.11182199915250142,0.11312099980811278,0.11436099993685882,0.11554200078050296,0.11667600087821484,0.11777199991047382,0.11883099998037021,0.11985199960569541,0.12083599964777629,0.12178200048704942,0.1226910005013148,0.12356200193365414,0.1243969996770223,0.12519300046066442,0.1259589989980062,0.12670099983612695,0.12742000197370848,0.1281139999628067,0.1287850004931291,0.1294310006002585,0.1300530011455218,0.13065200050671896,0.13122600068648657,0.13177699719866118,0.13230800131956735,0.13282199949026108,0.13332200050354004,0.1338069997727871,0.1342760001619657,0.13473099966843924,0.1351690006752809,0.13559199993809065,0.1359999986986319,0.1363929994404316,0.13677299891908964,0.13714300096035004,0.1375030018389225,0.1378530003130436,0.13819400096933046,0.138524000843366,0.13884600127736726,0.1391570009291172,0.13945699979861578,0.139748003333807,0.14003200083971024,0.14030900225043297,0.14058000097672144,0.14084399864077568,0.14110200107097626,0.14135299871365228,0.1415990007420381,0.1418389988442262,0.14207199960947037,0.14229800055424371,0.142515999575456,0.14272200192014375,0.14291799813508987,0.1431019976735115,0.14327599853277206,0.14343799899021784,0.14358900114893913,0.1437279979387919,0.14385700225830078,0.14397499958674112,0.14408699919780096,0.14419900129238764,0.1443109984199206,0.14442400137583414,0.14453600098689398,0.14464799935619035,0.14476000145077705,0.14487200106183687,0.14498399943113327,0.14509600152571997,0.14520700027545294,0.14531700064738592,0.14542600139975548,0.14553499842683473,0.14564199994007745,0.14574700221419334,0.14585099990169206,0.1459550013144811,0.1460579993824164,0.14615899821122488,0.14625899866223335,0.14635799825191498,0.14645699908336005,0.1465539994339148,0.14665000016490617,0.14674499879280725,0.14683799942334494,0.14693100129564604,0.14702300106485686,0.14711300283670425,0.14720199753840765,0.14729000255465508,0.1473770005007585,0.1474629988272985,0.14754800125956535,0.14763199910521507,0.14771499981482825,0.147797000904878,0.14787800113360086,0.14795699963967004,0.14803499976793924,0.14811299865444502,0.14818899830182394,0.14826399957140288,0.1483369991183281,0.1484100023905436,0.14848199859261513,0.14855300014217696,0.14862199996908507,0.14869100227952003,0.1487590012451013,0.14882600059111914,0.14889100069801012,0.1489539990822474,0.14901799956957498,0.14908000081777573,0.14914099996288618,0.14920099824666977,0.14925899977485338,0.1493160016834736,0.14937299862504005,0.1494289996723334,0.1494829977552096,0.1495360011855761,0.14958900089065233,0.14964000011483827,0.14969000096122423,0.14973900218804678,0.14978700007001558,0.14983400081594786,0.14988000070055327,0.14992400258779526,0.14996700113018355,0.15001000091433525,0.15005099897583327,0.1500919982790947,0.1501310020685196,0.15016900127132735,0.15020699799060822,0.150243000437816,0.1502779982984066,0.15031100064516068,0.15034399926662445,0.15037600075205168,0.15040700137615204,0.15043599903583527,0.1504640020430088,0.15049100170532861,0.150518000125885,0.150543000549078,0.15056700259447098,0.15058900167544684,0.1506109982728958,0.15063200145959854,0.15065200005968413,0.1506699981788794,0.15068799878160158,0.1507049985229969,0.15072099988659224,0.15073500076929727,0.1507480007906755,0.15075999995072684,0.15077200159430504,0.15078199903170267,0.15079100181659064,0.15079800287882486,0.15080500021576881,0.1508110004166762,0.15081599727272987,0.15081899985671043,0.15082199995716414,0.15082399795452753,0.15082500129938126,0.1508240004380544,0.15082199995716414,0.15081899985671043,0.15081599851449332,0.15081100165843964,0.15080499897400537,0.15079700077573457,0.15078900009393692,0.1507799985508124,0.15076999987165132,0.15075899908939996,0.15074699992934862,0.150733998666207,0.15071900188922882,0.15070399890343347,0.15068699916203818,0.15066900104284286,0.15065100168188414,0.1506309981147448,0.15060999865333238,0.1505879983305931,0.15056500087181726,0.1505410000681877,0.15051599964499474,0.15049000084400177,0.15046300118168196,0.15043499817450842,0.15040599927306175,0.15037500113248825,0.15034399926662445,0.15031099940339723,0.15027800078193346,0.15024399881561598,0.1502080000936985,0.15017099802692732,0.150133000065883,0.1500940000017484,0.15005499993761381,0.15001299853126207,0.14997200046976408,0.1499289982020855,0.14988499879837036,0.14984000101685524,0.149793000270923,0.14974600076675415,0.14969800040125847,0.14964899917443594,0.14959900205334029,0.1495489999651909,0.14949999873836836,0.14944999913374582,0.14940000077088675,0.1493499999245008,0.14929999907811484,0.14925100157658258,0.1492009994884332,0.1491510011255741,0.14910099903742471,0.14905200029412904,0.14900200068950653,0.14895200232664743,0.14890299985806146,0.1488529990116755,0.14880300064881644,0.14875400066375732,0.14870399981737137,0.14865500231583914,0.14860500022768974,0.14855600272615752,0.14850599939624468,0.1484569994111856,0.14840699856479964,0.14835799982150397,0.14830800021688142,0.14825900023182234,0.14820899938543639,0.14816000064214072,0.1481110006570816,0.1480610010524591,0.14801199982563654,0.14796300108234087,0.1479129989941915,0.14786400025089583,0.14781500150760016,0.14776499941945076,0.14771599943439165,0.14766699944933256,0.14761799946427345,0.14756900072097778,0.14751900111635527,0.1474699986477693,0.14742099990447363,0.14737200116117796,0.147322998692592,0.14727399870753288,0.1472249999642372,0.14717599749565125,0.14712700123588243,0.14707799876729646,0.1470290000240008,0.14698000252246857,0.1469310000538826,0.14688200255235037,0.1468330000837644,0.14678399885694185,0.14673499763011932,0.1466860013703505,0.14663700014352798,0.14658800015846887,0.1465390014151732,0.14649000143011412,0.14644199733932814,0.14639299983779588,0.14634400109450021,0.14629500110944113,0.14624599988261858,0.1461979995171229,0.14614900077382723,0.14610000078876814,0.14605200042327246,0.1460029991964499,0.14595399921139082,0.14590599884589514,0.14585700010259947,0.14580799887577692,0.14575999851028124,0.145711001008749,0.14566299940148988,0.14561400065819421,0.14556600029269853,0.14551700154940286,0.14546900242567062,0.1454199987153212,0.14537200083335242,0.14532299960652986,0.14527499924103418,0.1452260004977385,0.14517800013224283,0.1451300010085106,0.14508099978168806,0.1450330006579558,0.1449840006728967,0.14493599782387415,0.14488800118366876,0.14484000081817308,0.144791000833114,0.14474300046761832,0.14469499761859575,0.14464699973662695,0.1445979985098044,0.14454999814430872,0.14450200150410333,0.1444539986550808,0.14440599953134856,0.14435799916585287,0.14430900166432062,0.14426099881529808,0.14421300093332926,0.14416500180959702,0.14411700144410133,0.14406900107860565,0.14402099947134653,0.1439730003476143,0.1439249999821186,0.14387700085838637,0.14382900049289069,0.14378100261092186,0.14373299852013588,0.14368500063816705,0.14363800113399824,0.14358999952673912,0.14354200040300688,0.1434940000375112,0.14344600091377893,0.1433980017900467,0.143350999802351,0.14330299819509187,0.14325500031312308,0.1432069999476274,0.14316000044345856,0.14311200131972632,0.1430639997124672,0.14301600058873495,0.14296900232632956,0.142920999477307,0.14287399997313818,0.14282599836587906,0.14277799924214682,0.14273099973797798,0.1426829993724823,0.14263600235184035,0.14258800074458122,0.14254099999864897,0.1424929996331533,0.142445998887221,0.1423980010052522,0.14235100150108337,0.1423030011355877,0.14225600038965544,0.14220800126592317,0.14216099803646406,0.14211399977405867,0.142065999408563,0.14201899990439415,0.14197200164198875,0.14192400127649307,0.14187699804703394,0.14183000102639198,0.14178199817736944,0.14173499991496405,0.1416880004107952,0.14164099966486296,0.1415930005411307,0.141545998553435,0.1414989990492662,0.1414520007868608,0.1414050000409285,0.14135800177852312,0.14131100103259087,0.14126300190885863,0.14121599992116293,0.14116899917523065,0.14112199967106184,0.141075000166893,0.14102799942096075,0.14098099991679192,0.14093400041262308,0.14088700215021768,0.14084000140428543,0.14079299941658974,0.1407459999124209,0.14070000251134238,0.14065300052364668,0.14060600101947784,0.1405590002735456,0.1405119982858499,0.1404650000234445,0.1404179980357488,0.14037200063467026,0.14032499864697456,0.14027800286809602,0.14023099963863692,0.14018499851226807,0.14013800024986267,0.14009099950393042,0.14004399875799814,0.13999800259868303,0.13995100061098734,0.13990399862329164,0.13985799749692282,0.13981099799275398,0.13976499934991202,0.13971800108750662,0.13967199871937433,0.13962499921520552,0.13957799971103668,0.13953199858466783,0.13948500032226244,0.13943899795413017,0.13939199969172478,0.1393460010488828,0.13929999992251396,0.1392529991765817,0.13920699805021286,0.13915999854604402,0.1391140011449655,0.1390679987768332,0.1390209992726644,0.13897499814629555,0.13892899950345358,0.13888199999928474,0.13883600011467934,0.13879000147183737,0.1387430007259051,0.13869699959953627,0.13865099971493086,0.13860499983032545,0.13855900118748346,0.1385120004415512,0.1384660005569458,0.13841999943057695,0.1383739970624447,0.13832799966136614,0.13828199977676073,0.1382360023756822,0.13819000124931335,0.13814400136470795,0.13809699937701225,0.1380510007341703,0.13800500084956488,0.1379589984814326,0.13791299983859062,0.13786799957354864,0.1378219984471798,0.13777600104610124,0.13775299862027168};
    CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.83400344848633,82.68911743164062,83.15111478169759,83.9226131439209,84.71961339314778,85.54191462198894,86.3897139231364,87.2420145670573,88.07791264851888,88.89731407165527,89.70041338602702,90.48711268107097,91.25731213887532,92.0112133026123,92.74861081441243,93.46971257527669,94.17431131998698,94.86551094055176,95.54621124267578,96.21641095479329,96.87610944112141,97.5252119700114,98.16391054789226,98.79210980733235,99.4097105662028,100.0170103708903,100.61400985717773,101.20201047261556,101.78300921122234,102.3580093383789,102.92500877380371,103.48700841267903,104.04100926717122,104.58900896708171,105.13000869750977,105.66400973002116,106.19200897216797,106.71400833129883,107.23100852966309,107.74500846862793,108.25400861104329,108.75900840759277,109.25900777180989,109.75500806172688,110.24700864156087,110.7350082397461,111.21800740559895,111.69800758361816,112.17500750223796,112.64900779724121,113.12000719706218,113.58900833129883,114.05500793457031,114.51800855000813,114.97800827026367,115.43600845336914,115.89100774129231,116.34400749206543,116.7950070699056,117.24400838216145,117.69100761413574,118.13700739542644,118.5800069173177,119.02200762430827,119.46300760904948,119.90100797017415,120.33800760904948,120.77200698852539,121.20300801595052,121.63100687662761,122.05600865681966,122.47800763448079,122.89600626627605,123.31200790405273,123.72400728861491,124.13300768534343,124.53900655110677,124.9440066019694,125.34800656636556,125.7530066172282,126.15700721740723,126.56100654602051,126.96600659688313,127.37000783284505,127.7750072479248,128.1790065765381,128.58300654093424,128.98600641886392,129.3870086669922,129.7840092976888,130.1790033976237,130.5710080464681,130.96100616455078,131.34700647989908,131.73100789388022,132.11300786336264,132.49100494384766,132.86700439453125,133.24000549316406,133.61000696818033,133.9780044555664,134.3430061340332,134.70500564575195,135.06500625610352,135.4220059712728,135.77600479125977,136.12700525919595,136.47500610351562,136.82100550333658,137.16500600179037,137.50500615437826,137.8430061340332,138.17800521850586,138.51000467936197,138.84000523885092,139.16600545247397,139.49100621541342,139.81200663248697,140.1310043334961,140.44700495402017,140.76000467936197,141.07000478108725,141.37800470987955,141.68300247192383,141.9860051472982,142.28500493367514,142.58200454711914,142.87700525919595,143.16800689697266,143.45700454711914,143.74300384521484,144.02600479125977,144.30700174967447,144.58500544230142,144.86000315348306,145.1320037841797,145.4020029703776,145.66900507609049,145.93400446573892,146.19500478108725,146.45400365193686,146.71000544230142,146.96400451660156,147.21400578816733,147.46200561523438,147.70800399780273,147.95000457763672,148.19000498453775,148.4270044962565,148.66200383504233,148.89300155639648,149.12200291951498,149.34900538126627,149.57200495402017,149.79300181070963,150.01100413004556,150.22600682576498,150.4390017191569,150.64900334676108,150.85600153605142,151.06100463867188,151.26300303141275,151.46200307210287,151.65800348917642,151.85200373331705,152.0430030822754,152.23100407918295,152.41600290934244,152.59900410970053,152.77900314331055,152.95700454711914,153.1310017903646,153.30300267537436,153.47200139363608,153.6390012105306,153.8030039469401,153.9640032450358,154.12200419108072,154.27800369262695,154.43100357055664,154.58100001017252,154.72800318400064,154.87300237019858,155.0150006612142,155.15400187174478,155.29100036621094,155.4250030517578,155.55600102742514,155.68500264485678,155.81000264485678,155.93300247192383,156.0540033976237,156.17100143432617,156.2860018412272,156.39800008138022,156.50799942016602,156.61500295003256,156.71900049845377,156.82000223795572,156.91899998982748,157.0140012105306,157.10799916585287,157.1980005900065,157.28600438435873,157.37100092569986,157.45299784342447,157.5330022176107,157.61000188191733,157.68400192260742,157.75500106811523,157.8240000406901,157.88999938964844,157.953000386556,158.0140012105306,158.07199986775717,158.1270014444987,158.1790008544922,158.2290013631185,158.2760009765625,158.31999969482422,158.36199951171875,158.40100224812826,158.4370002746582,158.47100067138672,158.5009994506836,158.52900187174478,158.55500030517578,158.57699966430664,158.59700139363608,158.61400095621744,158.62900034586588,158.6410001118978,158.64999771118164,158.65599950154623,158.65999857584634,158.65999857584634,158.65900039672852,158.65500132242838,158.65200169881186,158.6489995320638,158.64600118001303,158.64299901326498,158.63999938964844,158.6360003153483,158.63299942016602,158.62999979654947,158.62700017293295,158.62400182088217,158.62099965413412,158.61700057983398,158.61400095621744,158.61100133260092,158.6079978942871,158.6050008138021,158.6010004679362,158.5980021158854,158.59499867757162,158.59199905395508,158.5890007019043,158.58599853515625,158.5819994608561,158.57900110880533,158.5760014851888,158.5730005900065,158.56999969482422,158.56699879964194,158.5629997253418,158.56000010172525,158.55699920654297,158.55399958292642,158.55100123087564,158.5479990641276,158.54400126139322,158.54099909464517,158.5380007425944,158.5349998474121,158.53200149536133,158.52900060017905,158.52499771118164,158.52200063069662,158.5189997355143,158.51599884033203,158.51300175984701,158.5099983215332,158.50600306193033,158.50300089518228,158.49999872843424,158.49700037638345,158.4939982096354,158.4910011291504,158.48699951171875,158.48400115966797,158.4810002644857,158.47800064086914,158.47499974568686,158.47099939982095,158.46800104777017,158.4650026957194,158.4619992574056,158.45900090535483,158.45600128173828,158.4520009358724,158.44900131225586,158.4459991455078,158.44300079345703,158.43999989827475,158.4370002746582,158.43300120035806,158.42999903361002,158.427001953125,158.4239985148112,158.4210001627604,158.41799799601236,158.41399765014648,158.41100056966147,158.40800094604492,158.40499877929688,158.40199915568033,158.3989995320638,158.39499791463217,158.3919995625814,158.38900248209634,158.3860003153483,158.38300196329752,158.38000106811523,158.37600072224936,158.37299982706705,158.37000020345053,158.36699930826822,158.36399841308594,158.36100006103516,158.35699844360352,158.35400263468424,158.35099919637045,158.34800084431967,158.34499994913736,158.34200159708658,158.33800252278647,158.33499908447266,158.3319994608561,158.32899729410806,158.32600021362305,158.32299931844076,158.31900024414062,158.31599807739258,158.3129997253418,158.30999883015951,158.30700174967447,158.3040033976237,158.3000005086263,158.29700088500977,158.29400126139322,158.2910016377767,158.28799947102866,158.2849998474121,158.28099950154623,158.2779998779297,158.27500025431314,158.27200190226236,158.26900227864584,158.2660001118978,158.2619997660319,158.2590014139811,158.25599797566733,158.25299962361655,158.25000127156576,158.24700037638345,158.2429987589518,158.24000040690103,158.23700078328451,158.23399861653647,158.23099772135416,158.22800064086914,158.22399775187174,158.22099939982095,158.21800104777017,158.2150001525879,158.2120018005371,158.20900090535483,158.20500055948892,158.20199839274088,158.19900258382162,158.1959991455078,158.19299952189127,158.19000244140625,158.1860008239746,158.18299992879233,158.17999903361002,158.1769994099935,158.17399978637695,158.1710001627604,158.16799799601236,158.16399892171225,158.1609992980957,158.15800094604492,158.15500259399414,158.15199661254883,158.1490020751953,158.14500172932944,158.14200083414713,158.13899993896484,158.13599904378256,158.13300196329752,158.12999979654947,158.1259994506836,158.12300237019858,158.12000020345053,158.11700312296549,158.11400095621744,158.11100133260092,158.10700225830078,158.10399754842123,158.10099919637045,158.09800084431967,158.09499994913736,158.09199905395508,158.0880012512207,158.08500035603842,158.0819994608561,158.0789998372396,158.07600021362305,158.07299931844076,158.06900024414062,158.06600062052408,158.06300354003906,158.06000010172525,158.05700174967447,158.0540008544922,158.05100123087564,158.04700215657553,158.04399998982748,158.04099909464517,158.0379981994629,158.03499857584634,158.03199895222983,158.02799860636392,158.0249989827474,158.02200063069662,158.0189997355143,158.0160001118978,158.01299921671549,158.0089988708496,158.00599924723306,158.00299962361655,157.99999872843424,157.99700164794922,157.99399948120117,157.98999786376953,157.98699951171875,157.9839998881022,157.9810002644857,157.97800064086914,157.9749984741211,157.97200139363608,157.96799850463867,157.9650001525879,157.9619992574056,157.95900090535483,157.95600001017252,157.953000386556,157.9490000406901,157.9459991455078,157.94299952189127,157.93999989827475,157.9370002746582,157.93400065104166,157.93000030517578,157.92700068155924,157.92399724324545,157.92099889119467,157.9180005391439,157.91500091552734,157.9109992980957,157.90799840291342,157.90500005086264,157.9020004272461,157.89900080362955,157.89600118001303,157.89299901326498,157.88899993896484,157.8860003153483,157.88300069173178,157.87999979654947,157.87700017293295,157.8740030924479,157.87200037638345};
        //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761536876360576,1.4129000107447307,1.4511200090249379,1.4903099834918976,1.5308100084463756,1.5725900133450825,1.6156600018342335,1.6589599947134654,1.7014000018437703,1.742979993422826,1.78371000289917,1.8235999941825867,1.862619976202647,1.900799999634425,1.9381199876467388,1.974590003490448,2.0101999739805856,2.0451200008392334,2.079490005970001,2.113309999306997,2.146580000718435,2.1792999505996704,2.2114800413449607,2.243100027243296,2.274179975191752,2.3047099709510803,2.334689994653066,2.3642300367355347,2.393400013446808,2.4222300052642822,2.4507000048955283,2.478819986184438,2.506589968999227,2.533999979496002,2.5610600113868713,2.5877699653307595,2.6141300201416016,2.640190005302429,2.666030009587606,2.691640019416809,2.717020014921824,2.7421800096829734,2.7671000162760415,2.791790008544922,2.816259980201721,2.84049000342687,2.8644999861717224,2.888319969177246,2.912000000476837,2.9355299870173135,2.958899974822998,2.98212997118632,3.005210002263387,3.0281400084495544,3.050920009613037,3.0735600193341575,3.096049984296163,3.118410031000773,3.1406799952189126,3.1628499825795493,3.1849199533462524,3.2069000005722046,3.2287800113360086,3.250559985637665,3.27224999666214,3.293839971224467,3.3153300285339355,3.3366899887720742,3.357890009880066,3.378910005092621,3.3997700214385986,3.4204700191815696,3.4409899512926736,3.4613500038782754,3.4815500179926553,3.501570006211599,3.521429975827535,3.5412000020345054,3.5609700282414756,3.5807300011316934,3.600480020046234,3.62022997935613,3.6399700045585632,3.6597099701563516,3.6794300079345703,3.6991599599520364,3.718870004018148,3.7385199864705405,3.7580100099245706,3.777359982331594,3.7965699831644693,3.81563001871109,3.8345499634742737,3.853319982687632,3.871940016746521,3.8904199798901877,3.908749997615814,3.9269399642944336,3.944980005423228,3.962879995505015,3.9806400140126548,3.998249967892965,4.015719930330913,4.0330400466918945,4.050219972928365,4.06724997361501,4.084139982859294,4.100879987080892,4.117479960123698,4.133939981460571,4.150240063667297,4.166409929593404,4.182440002759297,4.1983199914296465,4.2140499750773115,4.229640007019043,4.245089968045552,4.260390082995097,4.275550007820129,4.290559967358907,4.305430014928182,4.320159991582234,4.334740002950032,4.3491800626118975,4.363469998041789,4.377629995346069,4.391639908154805,4.405499974886577,4.419220010439555,4.432800014813741,4.446239948272705,4.459530035654704,4.472679972648621,4.4856800238291425,4.498540043830872,4.5112599929173784,4.523829976717631,4.536260008811951,4.548550009727478,4.560700019200643,4.572700023651123,4.584559996922811,4.596279939015706,4.607859969139099,4.619289994239807,4.63057005405426,4.641719977060954,4.652720014254252,4.663580060005188,4.674299955368042,4.684870044390361,4.695309956868489,4.705599983533223,4.715750018755595,4.725760022799174,4.735619982083638,4.74533998966217,4.75491992632548,4.764359951019287,4.773650089899699,4.782810012499492,4.791819969813029,4.8006900151570635,4.8094199895858765,4.8180099328358965,4.826450069745381,4.8347500165303545,4.842909971872966,4.8509299755096436,4.858809987703959,4.86653991540273,4.874140024185181,4.881589929262797,4.88890000184377,4.896070043245952,4.90310005346934,4.909980058670044,4.916729966799418,4.923340042432149,4.929799993832906,4.93612003326416,4.942300041516622,4.948340018590291,4.954240004221599,4.95998998483022,4.965609987576802,4.97108006477356,4.976420044898987,4.981610020001729,4.986670017242432,4.991580009460449,4.996350010236104,5.000980059305827,5.005469997723897,5.009819984436035,5.0140299797058105,5.018100023269653,5.022029956181844,5.02581000328064,5.029459993044536,5.032969991366069,5.036340037981669,5.039570013682048,5.042649944623311,5.045599977175395,5.048410018285115,5.051069974899292,5.053600033124288,5.055990020434062,5.05823000272115,5.06033996740977,5.062300006548564,5.064130028088887,5.065820097923279,5.0673699378967285,5.068770011266072,5.070040027300517,5.071170012156169,5.072160005569458,5.073009967803955,5.0737199783325195,5.074289957682292,5.074719945589702,5.075019955635071,5.075170040130615,5.07518994808197,5.07506000995636,5.0747999747594195,5.074399987856547,5.073859969774882,5.073180039723714,5.072359999020894,5.071400006612142,5.070299983024597,5.06905996799469,5.067689935366313,5.06616997718811,5.064589977264404,5.063000003496806,5.061420043309529,5.059840043385823,5.058259963989258,5.056679964065552,5.055100003878276,5.05352000395457,5.051940004030864,5.050360004107158,5.0487799644470215,5.047210017840068,5.045629978179932,5.044050017992656,5.042479991912842,5.040899952252706,5.039330045382182,5.037750045458476,5.036180059115092,5.034600019454956,5.033029913902283,5.031460126241048,5.029890060424805,5.028320034344991,5.026739994684855,5.025170048077901,5.023600021998088,5.022029995918274,5.02045996983846,5.018899957338969,5.017330050468445,5.015760024388631,5.014189998308818,5.012630025545756,5.011059999465942,5.0094899733861284,5.007930000623067,5.006360014279683,5.004799962043762,5.003239989280701,5.001670002937317,5.0001100699106855,4.998550017674764,4.996990005175273,4.995420018831889,4.9938600063323975,4.992299993832906,4.990739981333415,4.989179968833923,4.987629969914754,4.986069957415263,4.984510024388631,4.98295001188914,4.981389959653218,4.979840000470479,4.9782800277074175,4.976729989051819,4.975170016288757,4.973620017369588,4.972060004870097,4.970510005950928,4.968959927558899,4.9673999945322675,4.965850035349528,4.9642999569574995,4.96274999777476,4.961199998855591,4.959649999936421,4.958099961280823,4.9565500020980835,4.955000042915344,4.953450004259746,4.951910058657329,4.950360059738159,4.94880998134613,4.947269996007283,4.945719997088115,4.944169998168945,4.942629973093669,4.941090027491252,4.939539988835652,4.938000043233235,4.936450004577637,4.93490993976593,4.933369994163513,4.931830008824666,4.93029002348582,4.9287499984105425,4.927209973335266,4.925670027732849,4.924130002657573,4.922590096791585,4.9210500319798784,4.919510006904602,4.917979995409648,4.916439930597941,4.914910038312276,4.91336993376414,4.911829988161723,4.910299976666768,4.908769965171814,4.907230019569397,4.905700008074443,4.904169956843059,4.902630011240642,4.9010999997456866,4.899569988250732,4.898039976755778,4.896510004997253,4.8949800332387285,4.893449982007344,4.89191997051239,4.890389959017436,4.888859987258911,4.8873400290807085,4.885809977849324,4.88427996635437,4.8827600081761675,4.881229917208354,4.879710078239441,4.8781799872716265,4.8766599496205645,4.8751299778620405,4.873609979947408,4.872090021769206,4.870570063591003,4.869040012359619,4.867519974708557,4.8660000165303545,4.8644799788792925,4.862959980964661,4.861439943313599,4.859919905662537,4.858399987220764,4.856890042622884,4.855370004971822,4.85385000705719,4.852330048878987,4.850819985071818,4.849300026893616,4.847790042559306,4.846270004908244,4.844759980837504,4.843240022659302,4.841729998588562,4.840219934781392,4.838709910710652,4.837189952532451,4.83568000793457,4.834169983863831,4.832659999529521,4.831149935722351,4.829639991124471,4.828129927317302,4.826619982719421,4.825119972229004,4.823609987894694,4.822099963823955,4.820599953333537,4.819090008735657,4.817580024401347,4.81608001391093,4.81456998984019,4.813070019086202,4.811570008595784,4.8100599845250445,4.808560013771057,4.80705992380778,4.805550058682759,4.804049928983052,4.802549958229065,4.801050146420796,4.79954997698466,4.798049966494243,4.796550035476685,4.795050024986267,4.793560028076172,4.792059977849324,4.790560007095337,4.789059956868489,4.787569999694824,4.786070028940837,4.784579952557881,4.783079942067464,4.781589945157369,4.780089974403381,4.778600017229716,4.777110020319621,4.775610009829204,4.774120012919108,4.772630016009013,4.771140019098918,4.769649982452393,4.768159945805867,4.766669988632202,4.765179991722107,4.763689994812012,4.762200037638347,4.760710000991821,4.759230017662048,4.757740020751953,4.756250023841858,4.754770000775655,4.75328000386556,4.751800020535787,4.750309983889262,4.748829960823059,4.747340043385823,4.745859980583191,4.744379957516988,4.742889960606893,4.74140997727712,4.739929993947347,4.738450050354004,4.7369699875513716,4.735490004221599,4.734010020891826,4.732529997825623,4.7310499747594195,4.729570031166077,4.728099981943767,4.7266199588775635,4.72514009475708,4.723659952481587,4.722190022468567,4.720709999402364,4.719239989916484,4.71776008605957,4.71628999710083,4.714820027351379,4.713340004285176,4.711869994799296,4.7103999853134155,4.708930015563965,4.707460006078084,4.705979943275452,4.70451005299886,4.70304008324941,4.70156995455424,4.700109998385112,4.698639988899231,4.69717001914978,4.695700009663899,4.694230039914449,4.692770004272461,4.691299955050151,4.689839959144592,4.6883699496587115,4.687639991442363};
    
        SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.56844687461853,8.884455919265747,9.182497024536133,9.511056661605835,9.842686812082926,10.177406787872314,10.515106916427612,10.854906956354776,11.19560702641805,11.537206808725992,11.879806915918985,12.22340703010559,12.567906856536865,12.913306951522827,13.259706974029541,13.607006947199503,13.955307006835938,14.304006973902384,14.652907053629557,15.001707077026367,15.350707054138184,15.69970711072286,16.048707008361816,16.397806962331135,16.746906916300457,17.0962069829305,17.445407072703045,17.794307072957356,18.142206986745197,18.489306926727295,18.835407257080078,19.18070697784424,19.525006771087646,19.868506749471027,20.211106936136883,20.552706559499104,20.89350700378418,21.233806769053142,21.57400671641032,21.914206663767498,22.254206657409668,22.594106674194336,22.93400700887044,23.273806889851887,23.61350679397583,23.953106721242268,24.292606830596924,24.632206916809082,24.971906820933025,25.311906655629475,25.65200662612915,25.99230686823527,26.332806905110676,26.67340660095215,27.014206886291504,27.355206807454426,27.696407000223797,28.037906964619953,28.37990665435791,28.72240702311198,29.065306822458904,29.40870714187622,29.75250705083211,30.09680716196696,30.441606839497883,30.7869070370992,31.132607142130535,31.479207356770832,31.82700713475545,32.17610740661621,32.52640724182129,32.87800661722819,33.230807304382324,33.584906895955406,33.94030729929606,34.296807289123535,34.65470790863037,35.0140069325765,35.37510744730631,35.73790772755941,36.10250695546468,36.46880785624186,36.83680788675944,37.2067076365153,37.578207651774086,37.951507568359375,38.3266077041626,38.7011079788208,39.073007583618164,39.442108154296875,39.80860710144043,40.172407468159996,40.53340689341227,40.89180692036947,41.247507095336914,41.60040728251139,41.950706481933594,42.2983071009318,42.64320659637451,42.98540655771891,43.32490666707357,43.661706606547035,43.9958070119222,44.3272066116333,44.65590604146322,44.98200670878092,45.30530611673991,45.626006762186684,45.94400596618652,46.25930658976237,46.571906089782715,46.88190619150797,47.18910598754883,47.493707021077476,47.79560565948486,48.09480635325114,48.391306241353355,48.6852060953776,48.97640609741211,49.264905293782554,49.550705909729004,49.83380540211996,50.11430517832438,50.39210573832194,50.66730499267578,50.93970584869385,51.2095053990682,51.47660541534424,51.74110476175944,52.00290552775065,52.26200517018636,52.518405278523765,52.77220503489176,53.02330493927002,53.271805127461754,53.51760482788086,53.760704358418785,54.001104990641274,54.239004135131836,54.47410456339518,54.70660432179769,54.936405181884766,55.163604418436684,55.3881041208903,55.61000378926595,55.82920424143473,56.04570325215658,56.25960445404053,56.47090435028076,56.67940425872803,56.88540426890055,57.088704109191895,57.28930409749349,57.487303733825684,57.68270365397135,57.875404040018715,58.06540393829346,58.25280316670736,58.43760395050049,58.61970361073812,58.799203872680664,58.976003646850586,59.150203704833984,59.32180372873942,59.49070326487223,59.6570037206014,59.82060305277506,59.98160330454508,60.140003522237144,60.29570325215658,60.44880294799805,60.599303245544434,60.7471030553182,60.892302831014,61.034902572631836,61.17490291595459,61.31220277150472,61.446902910868324,61.578902880350746,61.70830217997233,61.8351027170817,61.95930194854736,62.08090305328369,62.19980239868164,62.316102027893066,62.42980225880941,62.54090245564779,62.649301846822105,62.75510215759277,62.858302434285484,62.95890235900879,63.05690256754557,63.15230147043864,63.24500242869059,63.33510080973307,63.42260265350342,63.507500648498535,63.58980178833008,63.669500986735024,63.7466017405192,63.82100137074789,63.89290110270182,63.96210257212321,64.02869987487793,64.09280204772949,64.15420055389404,64.21300061543782,64.26920064290364,64.32280095418294,64.37380027770996,64.42220052083333,64.46800104777019,64.51120122273763,64.5518004099528,64.58980051676433,64.62520027160645,64.65810139973958,64.68830172220866,64.71590042114258,64.74089940388997,64.76340103149414,64.78320058186848,64.80040168762207,64.81509971618652,64.82719993591309,64.83669853210449,64.8435001373291,64.84779993693034,64.84960047403972,64.84869893391927,64.84520022074382,64.83920097351074,64.83059946695964,64.81939951578777,64.80559984842937,64.78919982910156,64.77029927571614,64.75000063578288,64.72979927062988,64.70959981282552,64.68929862976074,64.66909853617351,64.64889971415202,64.62870025634766,64.60850016276042,64.58830006917317,64.56819979349773,64.54799906412761,64.52779960632324,64.50769933064778,64.4875005086263,64.46740023295085,64.44719950358073,64.42709922790527,64.40689913431804,64.38679885864258,64.36669921875,64.3466002146403,64.32649993896484,64.30639966328938,64.28629938761394,64.26619974772136,64.24610010782878,64.22609965006511,64.20600001017253,64.18589973449707,64.16589991251628,64.14579995473225,64.12579981486003,64.10569953918457,64.08569876352946,64.06569925944011,64.0456994374593,64.02569897969563,64.00569947560628,63.98569901784261,63.96569983164469,63.94569969177246,63.92569955190023,63.90569909413656,63.88580004374186,63.86579958597819,63.84579944610596,63.82589975992838,63.806000073750816,63.78599993387858,63.76609992980957,63.74619960784912,63.72619946797689,63.706299463907875,63.68639945983887,63.66649977366129,63.646599451700844,63.626800219217934,63.606899897257485,63.586999575297035,63.56709957122803,63.54730033874512,63.52739969889323,63.50759983062744,63.48769982655843,63.46789964040121,63.448099772135414,63.428199768066406,63.40839958190918,63.38859907786051,63.36879952748617,63.348999977111816,63.32919947306315,63.30940024058024,63.28960005442301,63.26989936828613,63.25009981791178,63.23029931386312,63.21059958140055,63.190799395243324,63.1710999806722,63.15130011240641,63.13159942626953,63.11189969380697,63.092199643452965,63.07239945729574,63.05269972483317,63.032999674479164,63.013299306233726,62.99369970957438,62.97399934132894,62.95429929097494,62.93459955851237,62.91499932607015,62.89529959360758,62.8756996790568,62.85599994659424,62.83640003204346,62.81669998168945,62.79709974924723,62.77750015258789,62.757899602254234,62.73830000559489,62.71869913736979,62.69909922281901,62.67949962615967,62.659899393717446,62.640299479166664,62.62069924672445,62.601200103759766,62.58159955342611,62.562100092569985,62.54249986012777,62.52299976348877,62.50339984893799,62.483899434407554,62.464399337768555,62.444899559020996,62.42539978027344,62.40579922993978,62.38629945119222,62.36689980824789,62.34739971160889,62.32789993286133,62.30839920043945,62.288899739583336,62.26949946085612,62.25,62.23059940338135,62.21109994252523,62.19169902801514,62.17229970296224,62.15279960632324,62.13339932759603,62.11400000254313,62.09459940592448,62.07519976298014,62.05579948425293,62.036399841308594,62.01699924468994,61.99769973754883,61.97829977671305,61.95889949798584,61.93959935506185,61.920199712117515,61.90089956919352,61.88149960835775,61.862199783325195,61.84279982248942,61.82349967956543,61.80419953664144,61.784899393717446,61.76559925079346,61.74629910786947,61.726999282836914,61.707699139912926,61.68839963277181,61.669199307759605,61.64989916483561,61.63059997558594,61.61139965057373,61.59209950764974,61.57290013631185,61.55359967549642,61.534399350484215,61.51519934336344,61.49599997202555,61.47669919331869,61.457499504089355,61.43829917907715,61.41909980773926,61.39989948272705,61.38079992930094,61.361599604288735,61.34239959716797,61.3231995900472,61.30409971872965,61.28489971160889,61.26580015818278,61.246599197387695,61.227499643961586,61.20839913686117,61.189199129740395,61.17009957631429,61.15099938710531,61.13189951578776,61.112799962361656,61.09369977315267,61.07459990183512,61.05549971262614,61.036499977111816,61.01739978790283,60.99829928080241,60.97929986317953,60.96019967397054,60.94119962056478,60.92209974924723,60.90310001373291,60.88409932454427,60.86499913533529,60.8459997177124,60.8269993464152,60.80799929300944,60.788999239603676,60.7699998219808,60.750999450683594,60.73200003306071,60.713099797566734,60.69409974416097,60.675100008646645,60.65619977315267,60.63719971974691,60.61829980214437,60.59929974873861,60.580400149027504,60.56149927775065,60.54259936014811,60.52359962463379,60.50469938913981,60.48579947153727,60.4668992360433,60.44799963633219,60.42909971872965,60.41029930114746,60.39139938354492,60.372499783833824,60.35370000203451,60.33479976654053,60.31589984893799,60.29709974924723,60.27829933166504,60.25939973195394,60.240599632263184,60.22180016835531,60.20299975077311,60.18409983317057,60.16529973347982,60.146499951680504,60.12779966990153,60.10899988810221,60.09019978841146,60.0713996887207,60.052599589029946,60.033898989359535,60.0150998433431,59.996399879455566,59.977599143981934,59.95889949798584,59.940100034077965,59.930800120035805};
        //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129462401072184,2.2204294006029763,2.2993571162223816,2.389066974322001,2.4813172022501626,2.576047400633494,2.673187255859375,2.7685371239980063,2.8580069740613303,2.941766858100891,3.0199766755104065,3.0927865306536355,3.1603463888168335,3.2228062947591147,3.2802961468696594,3.3329560359319053,3.3809359471003213,3.4249258041381836,3.4656357367833457,3.5031556288401284,3.537565549214681,3.5689554611841836,3.59740541378657,3.622995297114054,3.6458152135213218,3.665925085544586,3.683405061562856,3.698704977830251,3.7122549613316855,3.724104861418406,3.7343048254648843,3.742894768714905,3.749924679597219,3.755424658457438,3.759454607963562,3.76203453540802,3.763224482536316,3.76328444480896,3.7625044186909995,3.7608944376309714,3.7584943175315857,3.755304296811422,3.7513542771339417,3.7466742595036826,3.7412742177645364,3.7351741592089334,3.728394110997518,3.721104105313619,3.7134740948677063,3.705514113108317,3.6972240209579468,3.6886239846547446,3.6797139843304953,3.6705039540926614,3.6609939336776733,3.6512139042218528,3.6411439379056296,3.6309138933817544,3.6206038991610208,3.6102339029312134,3.5997938315073648,3.58928382396698,3.5787238081296286,3.568103810151418,3.5574137767155967,3.546663781007131,3.535863757133484,3.524873753388723,3.5135536789894104,3.5019036730130515,3.489953656991323,3.477703591187795,3.4651535550753274,3.452323536078135,3.439213494459788,3.425833523273468,3.412193477153778,3.3986035188039145,3.3853734731674194,3.3724935054779053,3.359953502813975,3.3477535247802734,3.3358734846115112,3.3243034879366555,3.3130335410435996,3.302063465118408,3.2913835048675537,3.2807234724362693,3.269793430964152,3.2586233814557395,3.247213383515676,3.2355533639589944,3.2236733039220176,3.2115533153216043,3.199223260084788,3.1866632302602134,3.173903206984202,3.1609332164128623,3.147763172785441,3.134403189023336,3.120853145917257,3.1071231365203857,3.093203067779541,3.0791131059328714,3.064853072166443,3.050433079401652,3.0358530084292092,3.0211129983266196,3.006232957045237,2.991192956765493,2.9760229190190635,2.9607128699620566,2.945262869199117,2.9296928445498147,2.9139928420384726,2.8981728156407676,2.8822328050931296,2.866172750790914,2.8500027457873025,2.8337327043215432,2.817362685998281,2.800882637500763,2.784312625726064,2.767642597357432,2.750882625579834,2.7340425848960876,2.7171125411987305,2.7000925143559775,2.683002551396688,2.665822525819143,2.6485824584960938,2.6312624414761863,2.6138723691304526,2.5964223742485046,2.5789023439089456,2.5613123377164206,2.5436723232269287,2.525972306728363,2.5082122683525085,2.4903922279675803,2.472532252470652,2.4546121756235757,2.4366421699523926,2.418632169564565,2.400572121143341,2.3824621041615806,2.3643221259117126,2.346132059892019,2.32790199915568,2.3096419970194497,2.2913319865862527,2.2730019887288413,2.2546319365501404,2.2362219095230103,2.2177918950716653,2.1993218461672464,2.1808318297068277,2.162311851978302,2.1437618136405945,2.125181794166565,2.106581767400106,2.087961733341217,2.069311738014221,2.050641655921936,2.031951646010081,2.0132416685422263,1.9945215980211894,1.9757715861002605,1.9570015668869019,1.9382215440273285,1.9194215039412181,1.9006114900112152,1.8817814588546753,1.862931450208028,1.844081421693166,1.8252113858858745,1.806321382522583,1.7874313394228618,1.7685213188330333,1.7496013045310974,1.7306812802950542,1.7117412785689037,1.6927912533283234,1.6738412181536357,1.6548811892668407,1.6359011630217235,1.6169211566448212,1.5979411204655964,1.578951100508372,1.5599510769049327,1.5409410496552784,1.5219310224056244,1.502911001443863,1.4838909804821014,1.4648609658082326,1.4458309312661488,1.4268009165922801,1.407760888338089,1.388710876305898,1.369670828183492,1.3506208161513011,1.3315607905387878,1.3125107785065968,1.2934507429599762,1.2743907272815704,1.2553306818008423,1.2362706661224365,1.2172006567319233,1.1981406410535176,1.1790706018606822,1.1600005825360615,1.1409305731455486,1.1218605438868205,1.1027805109818776,1.0837105015913646,1.064640462398529,1.0455604394276936,1.0264904101689656,1.0074204007784526,0.9883443713188171,0.9692703535159429,0.9501983324686686,0.9311243096987406,0.9120492786169052,0.8929762542247772,0.873905231555303,0.8548332154750824,0.8357631911834081,0.8166951636473337,0.7976261327664057,0.7785561184088389,0.759489099184672,0.7404240667819977,0.7213580459356308,0.7022920250892639,0.6832280059655508,0.6641669968763987,0.6453740000724792,0.627110997835795,0.6093620012203852,0.5921129981676737,0.5753509898980459,0.5590620090564092,0.5432330022255579,0.5278510053952535,0.5129029949506124,0.4983770027756691,0.48426199704408646,0.4705459997057915,0.457217996319135,0.4442670022447904,0.4316820055246353,0.419453002512455,0.4075700019796689,0.3960230027635892,0.38480400045712787,0.37390099714199704,0.36330699920654297,0.35301299889882404,0.34301100422938663,0.33329200247923535,0.3238480016589165,0.31467099487781525,0.30575399845838547,0.29709000140428543,0.28867099930842716,0.2804909994204839,0.27254199981689453,0.26481900612513226,0.25731400152047473,0.25002199908097583,0.2429360014696916,0.23605099817117056,0.2293609989186128,0.22286099816362062,0.21654499818881354,0.21040800089637438,0.20444499949614206,0.19864999875426292,0.19301999857028326,0.1875500020881494,0.1822340004146099,0.17706899965802828,0.1720499967535337,0.16717400153477988,0.16243599727749825,0.15783199792106947,0.15335799877842268,0.1490119993686676,0.1447880007326603,0.1406839999059836,0.13669699927171072,0.13282199949026108,0.12905699759721756,0.12539900094270706,0.12184500073393185,0.11839100035528342,0.11503600080808003,0.1117749996483326,0.10860700036088626,0.10552800012131532,0.10253700117270152,0.09963040053844452,0.09680629956225555,0.09406229915718238,0.09139600085715453,0.08880529925227165,0.08628800076742967,0.08384210057556629,0.08146549885471661,0.07915619947016239,0.07691240062316258,0.07473219993213813,0.07261379932363828,0.07055539948244889,0.06855539915462334,0.06661210084954898,0.06472380024691422,0.0628890994315346,0.061106299671034016,0.05937409990777572,0.057691000401973724,0.05605560044447581,0.054466599908967815,0.05292260025938352,0.05142230043808619,0.04996459993223349,0.04854820047815641,0.04717200001080831,0.045834699645638466,0.044535400035480656,0.04327290039509535,0.04204620017359654,0.040854200099905334,0.039696100167930126,0.03857069959243139,0.03747730019191901,0.03641489986330271,0.035382600190738835,0.03437949996441603,0.0334049000715216,0.03245789961268505,0.031537700134019055,0.030643700156360865,0.02977489974970619,0.028930799880375464,0.02811070003857215,0.027313699945807457,0.026539400064696867,0.025787000078707933,0.025055999867618084,0.024345700008173782,0.023655499952534836,0.022984799928963184,0.022333199934413035,0.021700100352366764,0.021084900324543316,0.020487099885940552,0.01990629980961482,0.019341999820123117,0.018793599990506966,0.018260799814015627,0.017743100101749103,0.01724010007455945,0.01675129992266496,0.016276399915417034,0.015814999816939235,0.015366599972670278,0.01493099999303619,0.014507699913034836,0.014096400002017617,0.013696699946497878,0.013308400055393577,0.012931100092828274,0.012564500017712513,0.012208300099397698,0.011862199908743301,0.01152589994793137,0.011199099943041801,0.0108815998925517,0.010573099988202253,0.010273399918029705,0.00998208997771144,0.009699089995895823,0.009424109943211079,0.009156930027529597,0.008897319979344806,0.008645079952354232,0.008399979987492165,0.008161830094953379,0.007930439974491795,0.007705599962112804,0.00748713993622611,0.007274869984636704,0.007068620063364506,0.006868219973209004,0.006673489968913297,0.006484290002845228,0.0063004600039372844,0.0061218299670144916,0.005948270011382799,0.005779630038887262,0.005615770001895726,0.005456560019714137,0.0053018600059052306,0.005151540040969849,0.005005489996013542,0.004863580067952474,0.004725689999759197,0.004591709972980122,0.004461530091551443,0.004335039954942961,0.004212140028054516,0.004092720026771228,0.003976690000854433,0.003863940015435219,0.003754389976772169,0.00364794999283428,0.003544529996967564,0.003444040000128249,0.0033463999667825797,0.003251519985496998,0.003159339966562887,0.0030697700179492435,0.002982739999424666,0.0028981700112732747,0.00281600997550413,0.0027361700194887817,0.0026585999876260757,0.002583219980200132,0.002509990008547902,0.0024388199866128466,0.0023696799956572554,0.002302499992462496,0.002237220003735274,0.0021737899902897575,0.0021121699828654528,0.0020522800041362643,0.0019941000112642846,0.0019375699921511114,0.0018826299929060042,0.0018292599997948855,0.0017774000007193536,0.0017270099876138072,0.0016780500009190291,0.0016304700014491875,0.0015842500045740355,0.0015393300078964482,0.0014956900073836248,0.0014532900143725176,0.0014120900013949722,0.0013720499797879409,0.0013331599960414071,0.0012953600089531392,0.0012586399971041828,0.0012229499989189208,0.0011882800026796758,0.001154590000320847,0.0011218600169134636,0.001090060007603218,0.0010591500031296164,0.0010291300034926583,0.0009999500083116193,0.0009716010002496963,0.0009440560000560557,0.0009172920011527216,0.0008912870010438686,0.0008660189972336715,0.000841467990539968,0.0008176120075707635,0.0007944329991005361,0.0007719109999015927,0.0007500279947028806,0.0007287649981056651,0.0007081049940704057,0.000688029991579242,0.0006685249973088503,0.0006495720008388162,0.0006311569983760515,0.0006132649965972329,0.0005958790037160119,0.0005789860054695358,0.0005625720077659935,0.0005466240011931708,0.0005311280013605332,0.0005234910010282571};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11866696675618,80.86898740132649,79.52149200439453,78.11889394124348,76.66949653625488,75.1811974843343,73.66110038757324,72.11549949645996,70.55040168762207,68.97130266825359,67.38310432434082,65.79030545552571,64.19690577189128,62.60670598347982,61.023006757100426,59.44890785217285,57.88690789540609,56.33960819244385,54.80900859832764,53.297109285990395,51.80550893147787,50.33590952555338,48.889309565226235,47.46710968017578,46.07011000315348,44.69920984903971,43.35500971476237,42.03800996144613,40.748809496561684,39.48770968119303,38.25480969746908,37.05040963490804,35.874509493509926,34.727109591166176,33.60820960998535,32.51750946044922,31.455109119415283,30.420508861541748,29.41360886891683,28.434008757273357,27.48140811920166,26.555508136749268,25.655808130900066,24.78190803527832,23.9334077835083,23.109907627105713,22.31080722808838,21.535707155863445,20.784107208251953,20.055607000986736,19.34950653711955,18.665506680806477,18.002906322479248,17.361306190490723,16.740205764770508,16.139106035232544,15.5575057665507,14.994805574417114,14.450605312983194,13.924305200576782,13.415605147679647,12.923804918924967,12.448604822158813,11.989504734675089,11.545904556910196,11.117504358291626,10.703804095586142,10.304404020309448,9.918873945871988,9.546733776728312,9.187613725662231,8.841103474299112,8.506823460261026,8.184373378753662,7.873393257459004,7.573513150215149,7.284373005231221,7.005632996559143,6.7369528611501055,6.4779927333196,6.228452603022258,5.9880024989446,5.75634245077769,5.533182342847188,5.318232258160909,5.1112122138341265,4.9071822961171465,4.706332246462504,4.513542175292969,4.328502019246419,4.15089197953542,3.9804318944613137,3.8168318470319114,3.6598417361577353,3.5091916918754578,3.364621639251709,3.225911537806193,3.0928114851315818,2.9651214480400085,2.8426013588905334,2.7250713308652244,2.6123212973276773,2.504161218802134,2.4004011154174805,2.3008811275164285,2.20543106396993,2.113870998223623,2.026061018308004,1.9418509403864543,1.8610909084479015,1.7836408813794453,1.7093708217144012,1.6381507913271587,1.5698507726192474,1.504370739062627,1.4415907164414723,1.3813906610012054,1.3236706455548604,1.2683406074841816,1.2152905861536663,1.1644405821959178,1.115690549214681,1.0689505239327748,1.0241505205631256,0.9812124818563461,0.9400524546702703,0.9005994449059168,0.8627854337294897,0.8265424072742462,0.7918053865432739,0.7585143744945526,0.7266093591849009,0.6960333536068598,0.6667313277721405,0.6386513213316599,0.6117422978083292,0.5859572937091192,0.5612492760022482,0.5375742564598719,0.5148882518212,0.4931522433956464,0.47232523560523987,0.45237122227748233,0.4332532087961833,0.41493620723485947,0.39738719910383224,0.38057518750429153,0.364469180504481,0.3490391746163368,0.33425716559092206,0.3200971608360608,0.3065321519970894,0.2935381457209587,0.2810911387205124,0.2691691319147746,0.25774812946716946,0.2468091237048308,0.23633112013339996,0.2262951135635376,0.21668210749824843,0.2074761042992274,0.19865810126066208,0.1902120957771937,0.18212409069140753,0.17437708750367165,0.16695808246731758,0.15985308090845743,0.1530490778386593,0.14653207237521806,0.1402920683224996,0.13431606690088907,0.12859306360284486,0.12311306223273277,0.11786505952477455,0.11284005704025428,0.10802805485824744,0.10342105167607467,0.09900854962567489,0.09478384753068288,0.09073864544431369,0.08686534191171329,0.08315674153467019,0.07960573956370354,0.07620573788881302,0.07295043642322223,0.06983363504211108,0.06684943412741025,0.06399233266711235,0.061256930542488895,0.05863792976985375,0.05613062810152769,0.05373012709120909,0.05143192627777656,0.04923172481358051,0.04712532367557287,0.04510882248481115,0.04317832148323456,0.04133022017776966,0.03956092055886984,0.03786721918731928,0.03624581762899955,0.034693717335661255,0.03320781669269005,0.03178541595116258,0.03042381505171458,0.02912041467304031,0.027872714214026928,0.026678313345958788,0.025535112867752712,0.02444071260591348,0.023393111769109964,0.022390311118215322,0.02143051087235411,0.020511710395415623,0.019632209713260334,0.018790409434586763,0.017984609274814527,0.017213408835232258,0.016475108296920855,0.015768507961183786,0.015092207584530115,0.014444807389130196,0.013825106900185347,0.013232006691396236,0.012664406405140957,0.012121006147935987,0.011601005913689733,0.011103205615654588,0.010626805402959386,0.01017080519037942,0.009734384870777527,0.009316664654761553,0.008916864637285471,0.00853420429242154,0.008167964173480868,0.007817433952974776,0.007481953827664256,0.007160863645064334,0.006853563478216529,0.0065594533225521445,0.006277963208655517,0.0060085729928687215,0.005750732923236986,0.005503972798275451,0.005267802703504761,0.005041762565573056,0.004825432396804293,0.004618392325937748,0.004420232182989518,0.004230572143569589,0.004049062030389905,0.0038753319531679153,0.0037090618667813637,0.0035499317843156555,0.0033976317111713192,0.003251861645064006,0.00311234158774217,0.0029788215178996325,0.0028510214760899544,0.002728701375114421,0.0026116413064301014,0.0024996012604484954,0.0023923612122113505,0.002289731152510891,0.0021915010875090957,0.0020974810662058494,0.002007501005815963,0.0019213809670569997,0.001838950925351431,0.0017600608892583598,0.0016845608479343355,0.0016122908370258908,0.001543120772112161,0.0014769307454116642,0.0014135707072758426,0.001352930684030677,0.0012948906611806403,0.0012393406068440527,0.001186170595853279,0.0011352905809568863,0.0010865905399744709,0.001039980532368645,0.0009953634968648355,0.0009526644765477007,0.0009117974647476027,0.000872684443796364,0.0008352484243611494,0.0007994184027969217,0.0007651263828544567,0.0007323043731351694,0.0007008913574585071,0.0006708253398149585,0.000642049330053851,0.0006145073081521938,0.0005881472898181528,0.0005629182802901292,0.000538771278418911,0.0005156602564966306,0.0004935402515305517,0.000472370236821007,0.00045210723086105037,0.0004327142160036601,0.0004141522100932586,0.00039638720045331866,0.0003793841873023969,0.0003631111831055023,0.0003475351719923007,0.00033262816820448887,0.00031836015841690823,0.0003047041512521294,0.00029163414728827775,0.00027912514148435247,0.0002671521287993528,0.00025569313099064556,0.00024472612494719215,0.0002342281186429318,0.00022418211301555857,0.00021456610920722596,0.00020536310573030883,0.00019655409778351896,0.00018812309644999914,0.0001800540934103386,0.00017233208927791566,0.0001649400825651052,0.0001578650796242679,0.00015109407710648762,0.0001446140740881674,0.00013841106920153834,0.00013247506649349816,0.00012679306140247112,0.00012135506040067412,0.00011615005860221572,0.00011116805520335522,0.0001064000546951623,9.351018949625238e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45189793904623,229.59260686238608,226.3097178141276,223.64271036783853,220.94971084594727,218.23470815022787,215.4997075398763,212.74970245361328,209.98670450846353,207.2137018839518,204.4337018330892,201.6497014363607,198.86370086669922,196.0787010192871,193.29570134480795,190.51670455932617,187.7457046508789,184.98170598347983,182.22870635986328,179.48670959472656,176.7587102254232,174.0447120666504,171.3467114766439,168.66571553548178,166.00371805826822,163.36072158813477,160.73772303263345,158.13572311401367,155.55572509765625,152.99973169962564,150.46673329671225,147.95773442586264,145.47373580932617,143.01474126180014,140.58174260457358,138.17574564615884,135.79574584960938,133.44275283813477,131.11775588989258,128.81975873311362,126.54976081848145,124.30776405334473,122.09376589457194,119.90776952107747,117.75077311197917,115.62277666727702,113.52277819315593,111.45078150431316,109.40878550211589,107.39378801981609,105.40879122416179,103.45079358418782,101.52279726664226,99.62180074055989,97.74930381774902,95.90490659077962,94.08840878804524,92.29961268107097,90.53831481933594,88.80451838175456,87.09782028198242,85.41822242736816,83.76532554626465,82.13893000284831,80.53893216451009,78.96503448486328,77.41703796386719,75.89463996887207,74.39754295349121,72.92554601033528,71.4783484141032,70.05575116475423,68.6574535369873,67.28315607706706,65.93265787760417,64.60556030273438,63.30156326293945,62.0205659866333,60.762167612711586,59.52607091267904,58.31197261810303,57.11957518259684,55.94867738087972,54.79897944132487,53.670081774393715,52.56178506215414,51.49499098459879,50.46839205423991,49.45969422658285,48.468695958455406,47.49499797821045,46.53859996795654,45.59920120239258,44.67660331726074,43.77060508728027,42.88080660502116,42.00730927785238,41.149609883626304,40.3077122370402,39.481213887532554,38.67001438140869,37.87391630808512,37.092617988586426,36.32591978708903,35.573621114095054,34.83542251586914,34.11122417449951,33.40082613627116,32.70392640431722,32.02042849858602,31.350029786427815,30.6925311088562,30.047632535298664,29.41533374786377,28.795335292816162,28.1874361038208,27.591437657674152,27.00713872909546,26.434340000152588,25.872841517130535,25.32254234949748,24.78304322560628,24.254344781239826,23.73624610900879,23.22844711939494,22.730947812398274,22.243349075317383,21.765550295511883,21.29745101928711,20.838852246602375,20.38955307006836,19.94935417175293,19.518255074818928,19.095855871836346,18.682156880696613,18.276957511901855,17.88005828857422,17.49135939280192,17.110660076141357,16.737860838572185,16.372761726379395,16.015262524286907,15.665263414382935,15.322564204533895,14.98696494102478,14.658365726470947,14.336766481399536,14.021867036819458,13.713567813237509,13.411768356959024,13.116369167963663,12.827169815699259,12.544170300165812,12.267071088155111,11.995871623357138,11.730472167332968,11.470772902170816,11.216573397318522,10.967773993810018,10.724274555842081,10.486075162887573,10.252975622812906,10.02487619717916,9.801626523335775,9.583227157592773,9.369537671407064,9.160458246866861,8.955888668696085,8.755759159723917,8.559969584147135,8.368419885635376,8.181040366490683,7.997740864753723,7.818421284357707,7.643011728922526,7.471432050069173,7.303612510363261,7.139452934265137,6.97890321413676,6.82188359896342,6.6682939529418945,6.5180743137995405,6.371174693107605,6.227494955062866,6.086975375811259,5.949555675188701,5.815175970395406,5.683756232261658,5.555236577987671,5.429556926091512,5.30666712919871,5.18650750319163,5.069017648696899,4.954148014386495,4.84181825319926,4.731978456179301,4.624578833580017,4.519589106241862,4.416939377784729,4.316569526990254,4.218449751536052,4.122520009676616,4.02873017390569,3.9370404283205667,3.847400665283203,3.7597808639208474,3.6741210420926413,3.5903712709744773,3.508511463801066,3.4285016457239785,3.3502918680508933,3.273852050304413,3.199132223924001,3.126102387905121,3.0547125736872354,2.9849327206611633,2.916722893714905,2.8500430385271707,2.7848732074101767,2.721173365910848,2.6588935256004333,2.59804368019104,2.538583815097809,2.4804539481798806,2.423634111881256,2.368114193280538,2.3138543168703714,2.2608144680658975,2.208984593550364,2.158334712187449,2.1088348428408303,2.060474952061971,2.013215104738871,1.9670251806577046,1.921895295381546,1.8777853945891063,1.834685504436493,1.7925655841827393,1.751405696074168,1.7111858030160267,1.6718758940696716,1.6334859828154247,1.5959660808245342,1.5593061745166779,1.5234762728214264,1.4884563783804576,1.4542464415232341,1.420826494693756,1.3881465792655945,1.3562366863091786,1.3250767687956493,1.2946068147818248,1.264836887518565,1.2357569634914398,1.2073270281155903,1.179547091325124,1.1524071594079335,1.125897228717804,1.100007305542628,1.0746973653634389,1.049957424402237,1.025787482659022,1.0021875351667404,0.9791275958220164,0.9565886457761129,0.9345517009496689,0.9130277633666992,0.8920048127571741,0.8714708636204401,0.8514149039983749,0.831803947687149,0.8126279960076014,0.7938980460166931,0.7756040891011556,0.7577351282040278,0.7402821779251099,0.7232352197170258,0.7065632541974386,0.6902583042780558,0.6743323355913162,0.6587763826052347,0.6435834219058355,0.6287434548139572,0.6142484843730927,0.6000905185937881,0.5862615605195364,0.5727545867363611,0.5595406144857407,0.5466126551230749,0.5339856793483099,0.5216517100731531,0.5096057405074438,0.4978387753168742,0.4863468036055565,0.47512082755565643,0.4641568611065547,0.4534478858113289,0.4429879089196523,0.43277093519767124,0.4227919603387515,0.4130449866255124,0.4035240064064662,0.3942040205001831,0.3850790510574977,0.37616707384586334,0.36746109773715335,0.35895811518033344,0.35065313676993054,0.3425421590606372,0.33461817105611164,0.32688019176324207,0.31932121018568677,0.31193823367357254,0.3047262455026309,0.2976832687854767,0.2908032809694608,0.2840842977166176,0.2775203138589859,0.27110933264096576,0.26484834651152295,0.2587323561310768,0.25275838126738864,0.2469243916372458,0.24122540776928267,0.23565841962893805,0.23022143294413885,0.22491144637266794,0.21972446019450823,0.21465747182567915,0.20970948413014412,0.20487549404303232,0.20015450939536095,0.19554351891080538,0.1910395324230194,0.18664053827524185,0.1823225480814775,0.1780835563937823,0.1739425684014956,0.16989857951800028,0.1659475862979889,0.16208959743380547,0.15832060699661574,0.1546396166086197,0.15104462454716364,0.14753263319532076,0.14410264045000076,0.14075264955560365,0.13748066003123918,0.13428366680939993,0.13116167361537615,0.12811268121004105,0.12513468911250433,0.12222569684187572,0.11938370391726494,0.116608710338672,0.11389771786828835,0.11124972440302372,0.10866373094419639,0.10613773639003436,0.10367074112097423,0.10126074838141601,0.098906555523475,0.09660736036797364,0.09436176593104999,0.09216827029983203,0.0900258757174015,0.08793318209548791,0.08588928605119388,0.08389279246330261,0.08194289728999138,0.08003820230563481,0.0781778059899807,0.07636071058611076,0.0745859146118164,0.07285231910645962,0.07115902317066987,0.06950522710879643,0.06788973261912663,0.06631193682551384,0.06477073828379314,0.06326534350713094,0.06179504686345657,0.06035895055780808,0.05895615338037411,0.0575860571116209,0.05624776054173708,0.05494056393702825,0.05366386597355207,0.052416770408550896,0.051198672813673816,0.05000887562831243,0.04884677845984697,0.047711681885023914,0.0466029845799009,0.04552008708318075,0.04446239024400711,0.043429192466040455,0.042420094522337116,0.04143439761052529,0.04047170002013445,0.03953130170702934,0.03861280406514803,0.03771560608098904,0.036839308217167854,0.03598341097434362,0.03514741330097119,0.034330815076828,0.03353321645408869,0.03275411917517582,0.03199312090873718,0.031249822893490393,0.030523924467464287,0.02981472589696447,0.029122127685695887,0.02844562955821554,0.02778483120103677,0.027139332766334217,0.026508934174974758,0.02589313577239712,0.025291637362291414,0.02470413890356819,0.02413024039318164,0.023569741441557806,0.023022342938929796,0.02248754445463419,0.021965245716273785,0.021455046565582354,0.02095674832041065,0.020469948804626863,0.01999455053980152,0.01953015150502324,0.01907655301814278,0.018633453796307247,0.018200754808882873,0.017778055897603433,0.017365157138556242,0.016961857831726473,0.01656795898452401,0.016183259741713602,0.015807360721131165,0.015440361729512611,0.015081762724245587,0.014731563550109664,0.01438946439884603,0.014055365153277913,0.013728966005146503,0.013410166759664813,0.013098767648140589,0.012794668320566416,0.012497568891073266,0.012207369785755873,0.011923970576996604,0.011647071068485578,0.011376671803494295,0.011112572470058998,0.010854573066656789,0.01060257370894154,0.010356374240169922,0.010115974970782796,0.009881125530228019,0.009651736123487353,0.00942766658651332,0.009208817112570008,0.008995037603502473,0.008786238264292479,0.008582278775672117,0.008383059330905477,0.008188469801098108,0.007998400212575993,0.007812740669275323,0.007631401065737009,0.007454261532984674,0.007281241977276902,0.007112252331959705,0.006947172728056709,0.006785933122349282,0.006628443603403866,0.0064746039764334755,0.006324334380527337,0.006177564733661711,0.006034195112685363,0.005894155435574551,0.005757375814331074,0.005623765561419229,0.005493270078053077,0.005428784643299878};
        CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452328999837,71.41004117329915,70.57024574279785,69.81634140014648,69.06674067179362,68.32203992207845,67.58244132995605,66.84813944498698,66.11943944295247,65.3964392344157,64.67943890889485,63.96834023793539,63.2634391784668,62.56473859151205,61.872237841288246,61.18603769938151,60.50603771209717,59.83243719736735,59.165136655171715,58.50403626759847,57.84923585255941,57.20073541005453,56.5585355758667,55.922435442606606,55.292535146077476,54.66883405049642,54.05123360951742,53.43973318735758,52.83423296610514,52.23473294576009,51.64113203684489,51.05343246459961,50.4717321395874,49.89573129018148,49.325531005859375,48.76103083292643,48.20223045349121,47.64902973175049,47.10142993927002,46.55942980448405,46.02282969156901,45.491628646850586,44.965928395589195,44.445427894592285,43.930328051249184,43.42042795817057,42.91582775115967,42.41632684071859,41.9219274520874,41.43252722422282,40.94822629292806,40.468926111857094,39.99452590942383,39.52502568562826,39.06042607625326,38.60052522023519,38.145425160725914,37.69512494405111,37.249424616495766,36.8083241780599,36.371923764546715,35.94002374013265,35.51262346903483,35.08972358703613,34.67122300465902,34.2571226755778,33.84742228190104,33.44202168782552,33.04082171122233,32.64392217000326,32.251221338907875,31.86272128423055,31.478321075439453,31.098020712534588,30.721720536549885,30.34942038853963,29.981220245361328,29.616820017496746,29.25641965866089,28.899819215138752,28.547119140625,28.198219140370686,27.853018919626873,27.511618773142498,27.173818588256836,26.839818159739178,26.509318033854168,26.18241786956787,25.859217643737793,25.539417425791424,25.22311766942342,24.9104167620341,24.601016998291016,24.295116901397705,23.992716630299885,23.69351641337077,23.39781602223714,23.105315844217937,22.816215833028156,22.530315399169922,22.247715791066486,21.96831512451172,21.69211546579997,21.419014930725098,21.14911460876465,20.882314523061115,20.61851437886556,20.357914129892986,20.100214163462322,19.845614115397137,19.5939138730367,19.34511359532674,19.099313418070476,18.85641320546468,18.616313139597576,18.37911319732666,18.144712607065838,17.913012345631916,17.684112707773846,17.458012262980144,17.234512329101562,17.01371208826701,16.795612176259358,16.580111980438232,16.367111682891846,16.156811396280926,15.948911428451538,15.743611176808676,15.540811141331991,15.340511083602905,15.142510811487833,14.94701067606608,14.753910541534424,14.563210487365723,14.374710241953531,14.188610076904297,14.004810333251953,13.823210000991821,13.643909692764282,13.466809749603271,13.29190969467163,13.119109392166138,12.948509454727173,12.780009269714355,12.613609075546265,12.449209054311117,12.286909023920694,12.12670866648356,11.968408584594727,11.812108516693115,11.657808542251587,11.50540828704834,11.354908148447672,11.206308046976725,11.059608141581217,10.914707899093628,10.771707773208618,10.630507548650106,10.491007645924887,10.353307406107584,10.217407464981079,10.083207289377848,9.950677315394083,9.819857041041056,9.690697113672892,9.563177108764648,9.437286853790283,9.313006718953451,9.190306663513184,9.069186687469482,8.94960649808248,8.831566333770752,8.715036392211914,8.599996169408163,8.486436208089193,8.374346176783243,8.263686021169027,8.154455979665121,8.04663602511088,7.940205812454224,7.835155765215556,7.731455683708191,7.629095673561096,7.5280655225118,7.428345441818237,7.329905430475871,7.2327553033828735,7.136865297953288,7.042215188344319,6.948805093765259,6.856605013211568,6.765605012575786,6.675784945487976,6.58714485168457,6.499654769897461,6.413314779599507,6.328104615211487,6.2439945936203,6.160994529724121,6.079084515571594,5.998244404792786,5.91845428943634,5.8397243420283,5.7620242436726885,5.685334165891011,5.60966416200002,5.5349840720494585,5.461284001668294,5.388553977012634,5.316783905029297,5.245963891347249,5.176073789596558,5.107103784879048,5.039043704668681,4.971883654594421,4.905603567759196,4.840213576952617,4.775673548380534,4.712003509203593,4.649163405100505,4.58716340859731,4.525973359743754,4.465603311856587,4.406033317248027,4.347253163655599,4.289253155390422,4.232023239135742,4.175543109575908,4.119823098182678,4.064842939376831,4.010602970918019,3.957072913646698,3.904252906640371,3.852142850557963,3.8007328510284424,3.749992827574412,3.699942727883657,3.6505526900291443,3.6018226544062295,3.553752621014913,3.5063226024309793,3.4595225850741067,3.4133525292078652,3.3678024808565774,3.322862446308136,3.278512418270111,3.2347623705863953,3.191602369149526,3.149012327194214,3.1069923043251038,3.0655322670936584,3.024632235368093,2.984272221724192,2.9444621801376343,2.905172129472097,2.8664121627807617,2.8281721075375876,2.790442089239756,2.7532120744387307,2.7164820233980813,2.6802420218785605,2.644481976826986,2.609201947848002,2.5743918816248574,2.5400518774986267,2.5061618288358054,2.47273180882136,2.439741830031077,2.407191753387451,2.3750817577044168,2.3434017499287925,2.3121416767438254,2.2812917033831277,2.250861644744873,2.220841646194458,2.1912116408348083,2.1619815826416016,2.133141577243805,2.1046915650367737,2.0766115387280784,2.048911472161611,2.021581490834554,1.994611491759618,1.9680114388465881,1.941761424144109,1.915851394335429,1.8903014063835144,1.865081379810969,1.8402113616466522,1.815661331017812,1.7914413313070934,1.767551302909851,1.7439712782700856,1.7207113007704418,1.697761247555415,1.6751112341880798,1.6527712245782216,1.630721201499303,1.6089711884657543,1.5875111818313599,1.5663411418596904,1.5454411605993907,1.5248311161994934,1.504491110642751,1.4844310879707336,1.4646310607592266,1.4450910687446594,1.4258210559686024,1.406801054875056,1.3880410293738048,1.3695310056209564,1.3512609998385112,1.3332409759362538,1.3154609600702922,1.297910988330841,1.2806009352207184,1.2635209361712139,1.24667090177536,1.230050911506017,1.2136408885320027,1.1974608699480693,1.1814908683300018,1.1657308836778004,1.150180846452713,1.1348508497079213,1.1197108527024586,1.1047808130582173,1.0900508066018422,1.0755107800165813,1.0611707766850789,1.0470207730929058,1.033050775527954,1.0192807614803314,1.0056907435258229,0.99227574467659,0.9790437271197637,0.9659887154897054,0.9531077047189077,0.9403986980517706,0.9278586904207865,0.915486678481102,0.9032796720663706,0.8912346561749777,0.8793516506751379,0.8676266421874365,0.8560576339562734,0.8446436276038488,0.8333816180626551,0.8222696135441462,0.8113065958023071,0.800489584604899,0.7898165782292684,0.7792865633964539,0.7688965698083242,0.758645569284757,0.7485305468241373,0.738551547129949,0.7287055402994156,0.7189905295769373,0.709404523173968,0.6999475161234537,0.690616508324941,0.6814095079898834,0.6723254919052124,0.6633624881505966,0.6545194884141287,0.6457944810390472,0.6371854692697525,0.6286914646625519,0.620311458905538,0.6120424568653107,0.6038844386736552,0.595834438999494,0.5878924230734507,0.5800564289093018,0.5723244200150172,0.5646964212258657,0.5571694175402323,0.5497434039910635,0.5424154003461202,0.5351864000161489,0.5280533830324808,0.5210153857866923,0.5140713850657145,0.5072203775246938,0.5004603813091913,0.4937903607885043,0.48720936477184296,0.4807163526614507,0.47431034594774246,0.46798934290806454,0.46175234764814377,0.4555993303656578,0.4495273381471634,0.44353731721639633,0.43762734284003574,0.43179527670145035,0.4260413820544879,0.42036420851945877,0.4147634481390317,0.4092361181974411,0.40378352254629135,0.3984030435482661,0.3930955504377683,0.38785703231890994,0.38269050419330597,0.3775910933812459,0.37256042162577313,0.36759616682926816,0.36269933730363846,0.3578672260046005,0.3530992865562439,0.34839524577061337,0.34375325590372086,0.339174248278141,0.3346562460064888,0.3301972448825836,0.32579924166202545,0.3214592436949412,0.31717723111311596,0.3129522328575452,0.3087832232316335,0.30467023452123004,0.3006122062603633,0.29660724848508835,0.29265716423590976,0.28875929365555447,0.2849131027857463,0.28111834575732547,0.2773740366101265,0.27367938061555225,0.27003402014573413,0.266438364982605,0.2628900458415349,0.2593883102138837,0.25593409687280655,0.2525262435277303,0.24916314209500948,0.24584520484010378,0.24257116640607515,0.23934118325511614,0.23615317046642303,0.23300917446613312,0.22990616783499718,0.22684516881903014,0.22382416451970735,0.22084416449069977,0.21790315955877304,0.2150021605193615,0.2121401553352674,0.20931516215205193,0.20652813588579497,0.20377917711933455,0.20106510445475578,0.19838920732339224,0.19574705883860588,0.19314124683539072,0.1905700204273065,0.18803326661388078,0.18553001309434572,0.18306024993459383,0.18062303587794304,0.17821920663118362,0.17584707587957382,0.17350616678595543,0.17119710271557173,0.16891814023256302,0.16666911294062933,0.164451123525699,0.16226211935281754,0.1601031186679999,0.15797211478153864,0.1558691163857778,0.15379511440793672,0.15174811333417892,0.14972810943921408,0.1477361060678959,0.14577010894815126,0.14383010069529215,0.14191611732045809,0.14002708718180656,0.1381641315917174,0.13632506132125854,0.13451114917794862,0.1327220437427362,0.13183302183945975};
        CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297694365183514,16.274217287699383,16.217710336049397,16.17810869216919,16.133007367451984,16.083006381988525,16.028905550638836,15.971004883448282,15.910004456837973,15.846204121907553,15.779903570810953,15.711603085199991,15.641402880350748,15.569702386856079,15.496702194213867,15.422501802444458,15.3474014600118,15.271401405334473,15.194801330566406,15.117601156234741,15.040000995000204,14.962000687917074,14.883700847625732,14.80530071258545,14.726700703303019,14.648000399271647,14.569300333658854,14.490600347518921,14.411900281906128,14.333400328954061,14.254900296529135,14.176600217819214,14.098400274912516,14.020500183105469,13.942700147628784,13.865200201670328,13.787800073623657,13.710800170898438,13.633900006612143,13.557400147120157,13.481100082397461,13.405100107192993,13.329299926757812,13.2538001537323,13.178700049718222,13.103800058364868,13.029200077056885,12.95490018526713,12.88100004196167,12.807300090789795,12.73389999071757,12.660900115966797,12.58810011545817,12.515600124994913,12.44349996248881,12.371700048446655,12.300100008646647,12.22890011469523,12.157999992370605,12.08740003903707,12.017100016276041,11.947200059890747,11.877499977747599,11.80809998512268,11.739099899927774,11.670300006866455,11.601900100708008,11.533799966176352,11.46590002377828,11.398400068283081,11.331199963887533,11.264300028483072,11.197699944178263,11.13129997253418,11.065300067265829,10.999599933624268,10.934199968973795,10.869100014368692,10.80430006980896,10.739800055821737,10.675599972407023,10.611599842707315,10.54800001780192,10.484700043996176,10.421599944432577,10.35890007019043,10.29640007019043,10.23419984181722,10.172300020853678,10.110799868901571,10.049500147501627,9.988450050354004,9.927730083465576,9.867299874623617,9.807170073191324,9.747330029805502,9.687780062357584,9.628519852956137,9.569550037384033,9.51087999343872,9.452509959538778,9.394420146942139,9.33663010597229,9.279129902521769,9.221930027008057,9.165020068486532,9.108400106430054,9.052070140838623,8.996039946873983,8.940299908320108,8.884850104649862,8.829689979553223,8.774829943974813,8.720249970753988,8.665969928105673,8.611969947814941,8.55826989809672,8.504850228627523,8.451719999313354,8.398890018463135,8.346330006917318,8.29406992594401,8.242089986801147,8.19038995107015,8.138980070749918,8.087860027949015,8.037009954452515,7.986450115839641,7.936170021692912,7.886169950167338,7.836460034052531,7.787019968032837,7.737860043843587,7.688970009485881,7.640370051066081,7.5920400222142534,7.543980002403259,7.49620000521342,7.448690017064412,7.401449958483378,7.354489962259929,7.3077900012334185,7.261369943618774,7.21520992120107,7.169319987297058,7.123699943224589,7.07833997408549,7.033250013987224,6.988419969876607,6.943849960962932,6.899539987246196,6.855499943097432,6.811710000038147,6.768180052439372,6.724910060564677,6.681899984677632,6.6391399304072065,6.596629977226257,6.5543800592422485,6.512380003929138,6.470630009969075,6.429129997889201,6.387880007425944,6.3468799988428755,6.306120038032532,6.2656099398930865,6.225340008735657,6.185320019721985,6.145539959271749,6.105990052223206,6.066689968109131,6.027630011240642,5.988809943199158,5.950219949086507,5.911870002746582,5.8737499713897705,5.835869948069255,5.798210024833679,5.76078999042511,5.723599990208943,5.6866399844487505,5.649910012880961,5.613400022188823,5.577119946479797,5.541060050328572,5.505220095316569,5.4696100155512495,5.43422003587087,5.399049957593282,5.364100019137065,5.329360008239746,5.29485007127126,5.260539968808492,5.226449966430664,5.1925801038742065,5.158920009930928,5.125470042228699,5.092230041821797,5.059190034866333,5.02636996905009,4.993750015894572,4.961340030034383,4.929129958152771,4.897129972775777,4.86532998085022,4.8337299426396685,4.802330056826274,4.771130005518596,4.740119973818461,4.709320028622945,4.678709983825684,4.648290038108826,4.618070085843404,4.588039954503377,4.558209975560506,4.528560042381287,4.499110062917073,4.469840010007222,4.440760016441345,4.41186002890269,4.383150100708008,4.354630033175151,4.326289971669515,4.298129955927531,4.2701499462127686,4.24235999584198,4.214740037918091,4.187299927075704,4.160039981206258,4.132949988047282,4.106039961179097,4.079300006230672,4.052740057309468,4.026350061098735,4.0001200040181475,3.9740699927012124,3.948189993699392,3.9224800268809,3.896939992904663,3.871559997399648,3.8463499943415322,3.821299970149994,3.7964199781417847,3.7717000246047974,3.7471399704615274,3.7227500279744468,3.698510011037191,3.674430012702942,3.65050999323527,3.6267399986584983,3.6031299829483032,3.579670011997223,3.556369960308075,3.5332199732462564,3.5102199713389077,3.4873699943224588,3.464670022328695,3.442109982172648,3.419710020224253,3.397450029850006,3.3753300110499063,3.3533599972724915,3.3315399885177612,3.309849997361501,3.2883099714914956,3.2668999830881753,3.24563999970754,3.2245100339253745,3.203530013561249,3.182679990927378,3.161960005760193,3.14137997229894,3.120930016040802,3.1006200512250266,3.0804399847984314,3.0603900154431662,3.040470004081726,3.020680010318756,3.001019994417826,2.9814900159835815,2.962090015411377,2.9428100188573203,2.9236600200335183,2.9046299854914346,2.8857200145721436,2.866939961910248,2.8482800324757895,2.8297500014305115,2.811330040295919,2.7930299838383994,2.7748600244522095,2.7567999958992004,2.738860011100769,2.721029977003733,2.70332000652949,2.685730000336965,2.668250024318695,2.6508900125821433,2.633640011151632,2.6165000001589456,2.5994699994723,2.5825499892234802,2.565750022729238,2.549049993356069,2.5324599941571555,2.515979985396067,2.4996100068092346,2.483340005079905,2.4671799739201865,2.451129992802938,2.4351799885431924,2.4193299810091653,2.4035900235176086,2.3879499236742654,2.37241001923879,2.3569699923197427,2.3416300217310586,2.326389968395233,2.311260004838308,2.296219984690348,2.281269987424215,2.2664300203323364,2.251679996649424,2.237029949824015,2.222479999065399,2.208009978135427,2.1936499873797097,2.1793700059254966,2.165190021197001,2.151110033194224,2.1371099948883057,2.123200019200643,2.1093900005022683,2.09566996494929,2.0820299983024597,2.0684799949328103,2.0550299684206643,2.0416599909464517,2.0283700029055276,2.015179991722107,2.0020600060621896,1.9890399972597759,1.9760999977588654,1.963239997625351,1.950470010439555,1.9377799828847249,1.9251700043678284,1.9126499990622203,1.9002100030581157,1.887850006421407,1.8755600055058796,1.8633599877357483,1.8512399991353352,1.839199999968211,1.8272299865881603,1.8153500060240428,1.8035399913787842,1.791810005903244,1.7801499962806702,1.7685699760913849,1.757069985071818,1.7456399897734325,1.7342800100644429,1.7229999899864197,1.7117999990781148,1.700659990310669,1.689600000778834,1.6786100069681804,1.6676899989446003,1.6568499902884166,1.646069993575414,1.6353600025177002,1.624730000893275,1.614159991343816,1.603659987449646,1.5932299892107646,1.5828700164953868,1.5725799997647603,1.5623500049114227,1.5521899958451588,1.5420999924341838,1.5320699910322826,1.522099991639455,1.5122100015481312,1.502369999885559,1.4926000038782756,1.4829000035921733,1.4732500116030376,1.4636699954668682,1.4541600048542023,1.4446999927361805,1.4353100061416626,1.4259700079758961,1.4166999856630962,1.4074899951616924,1.3983399868011475,1.389249990383784,1.3802099923292797,1.3712400098641713,1.3623299996058147,1.353469987710317,1.3446699976921082,1.3359299898147583,1.3272400101025899,1.318610002597173,1.310040016969045,1.3015199899673462,1.2930599947770436,1.2846599916617076,1.2763000130653381,1.2680100003878276,1.259770005941391,1.2515799899895985,1.2434400022029877,1.2353599866231282,1.2273299992084503,1.219350000222524,1.2114199995994568,1.203549991051356,1.1957300305366516,1.1879600087801616,1.1802299916744232,1.1725599964459736,1.1649399995803833,1.157370001077652,1.1498499910036724,1.1423800090948741,1.1349499821662903,1.1275800168514252,1.1202500065167744,1.1129700044790904,1.1057300170262654,1.0985500117142994,1.0914099911848705,1.0843199988206227,1.0772699912389119,1.0702699919541676,1.06332000096639,1.0564099848270416,1.0495400031407673,1.0427199800809224,1.0359499951203663,1.0292199949423473,1.0225299994150798,1.0158900022506714,1.0092800060908,1.0027300119400024,0.9962130039930344,0.9897400041421255,0.9833099991083145,0.9769219954808553,0.9705750048160553,0.9642699956893921,0.9580060044924418,0.9517820030450821,0.9455989996592203,0.9394570092360178,0.9333540052175522,0.9272910008827845,0.9212680011987686,0.9152829945087433,0.9093379974365234,0.9034319967031479,0.8975630054871241,0.8917339990536371,0.8859419922033945,0.8801869998375574,0.8744710038105646,0.868790994087855,0.8631489972273508,0.8575429966052374,0.8519739955663681,0.8464410056670507,0.8409440020720164,0.8354829996824265,0.8300570001204809,0.8246669967969259,0.8193110078573227,0.813991000254949,0.8087049971024195,0.8034540067116419,0.7982370009024938,0.79305399954319,0.7879039992888769,0.782789001862208,0.7802390058835348};
        CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.460016886393229,8.488823413848877,8.531164328257242,8.575854221979776,8.618204116821289,8.65830397605896,8.696233908335367,8.732083717981974,8.765923500061035,8.797823429107666,8.827853202819824,8.856093088785807,8.882613182067871,8.90746291478475,8.930702765782675,8.952402591705322,8.972622712453207,8.991402546564737,9.008822361628214,9.02490234375,9.03970217704773,9.053272167841593,9.065662066141764,9.076922098795572,9.087071816126505,9.096181790033976,9.10427188873291,9.111371676127115,9.117531617482504,9.122791608174643,9.127171595891317,9.130701382954916,9.13344152768453,9.135391314824423,9.13659143447876,9.137071291605631,9.136861165364584,9.135981241861979,9.134461164474487,9.132320960362753,9.129591226577759,9.126270850499472,9.122411012649536,9.118010997772217,9.113110939661661,9.107710917790731,9.10184089342753,9.095520893732706,9.08876077334086,9.081580638885498,9.073990742365519,9.06601063410441,9.057660659154257,9.048960447311401,9.03990070025126,9.030520677566528,9.020810524622599,9.01080052057902,9.00049058596293,8.989900588989258,8.97903060913086,8.967900594075521,8.956520398457846,8.94489041964213,8.933030287424723,8.920940478642782,8.908650477727255,8.896140257517496,8.883440256118774,8.870550314585367,8.857470512390137,8.844220399856567,8.830800294876099,8.81721027692159,8.803470452626547,8.789580345153809,8.775550365447998,8.761380354563395,8.747090339660645,8.732670227686564,8.718130270640055,8.703460137049357,8.688690106074015,8.673810164133707,8.658830165863037,8.643750031789144,8.627260049184164,8.609399954477945,8.591559966405233,8.573729991912842,8.555920044581095,8.538129965464273,8.520359992980957,8.502600193023682,8.484869956970215,8.46715005238851,8.449450016021729,8.431770165761312,8.414109945297241,8.396459976832071,8.37883989016215,8.361239830652872,8.34365995724996,8.326099952061972,8.308560053507486,8.291040023167929,8.273550033569336,8.256070057551065,8.238619963328043,8.221189975738525,8.203789949417114,8.186400016148886,8.169039805730185,8.151710033416748,8.134389956792196,8.11709992090861,8.09984008471171,8.082599957784018,8.065380096435547,8.048189957936605,8.031020005544027,8.013880014419556,7.996759970982869,7.97966996828715,7.962599953015645,7.945559978485107,7.928540070851644,7.911550045013428,7.8945900201797485,7.877650022506714,7.860740025838216,7.843850016593933,7.826990048090617,7.810160001118978,7.793359994888306,7.776579976081848,7.759829958279927,7.743099967638652,7.726400017738342,7.70973002910614,7.693090001742045,7.6764800151189165,7.659890015920003,7.643330017725627,7.626799980799357,7.610300064086914,7.5938200155893965,7.577370047569275,7.560950001080831,7.544560035069783,7.528199990590413,7.5118699471155805,7.495560050010681,7.4792799949646,7.463030020395915,7.4468099276224775,7.430620034535726,7.4144599835077925,7.398329933484395,7.382220029830933,7.3661500215530396,7.350100000699361,7.334090034166972,7.318099935849507,7.3021399974823,7.286210020383199,7.270309964815776,7.254440069198608,7.238599975903829,7.222789963086446,7.20700991153717,7.191260019938151,7.175540010134379,7.159850041071574,7.144179979960124,7.128549973169963,7.1129500071207685,7.097379962603251,7.081829984982808,7.066319982210795,7.0508400201797485,7.035380005836487,7.019960006078084,7.004570086797078,6.989200035730998,6.973869959513347,6.958570043245952,6.943299969037374,6.9280500411987305,6.912839929262797,6.897660096486409,6.8825100262959795,6.867389996846517,6.852300047874451,6.837240020434062,6.822210033734639,6.807210048039754,6.792239983876546,6.777300000190735,6.762390057245891,6.747510035832723,6.732660015424092,6.717840035756429,6.703060030937195,6.688299973805745,6.673569957415263,6.658879995346069,6.644210020701091,6.629579981168111,6.614969968795776,6.600399931271871,6.585850079854329,6.571340004603068,6.556859970092773,6.542399962743123,6.527980009714763,6.5135899384816485,6.4992300271987915,6.4848999579747515,6.470599929491679,6.456329941749573,6.442090034484863,6.427879969278972,6.413699984550476,6.399550000826518,6.385430018107097,6.371349930763245,6.357289989789327,6.343259970347087,6.329270005226135,6.315299987792969,6.301360011100769,6.287459969520569,6.273579994837443,6.259739955266316,6.245929996172587,6.232139945030212,6.218390027681987,6.204660018285115,6.1909700234731035,6.177310029665629,6.1636799573898315,6.15008004506429,6.136509935061137,6.12296998500824,6.109460075696309,6.095980008443196,6.08252998193105,6.069109996159871,6.055719931920369,6.042360027631124,6.029030044873555,6.015730023384094,6.00246000289917,5.98920996983846,5.976000070571899,5.962820053100586,5.949659983317058,5.936540007591248,5.923439979553223,5.910380005836487,5.8973400592803955,5.884329994519551,5.871350010236104,5.858399987220764,5.845470031102498,5.832580010096232,5.81970997651418,5.806879917780559,5.794069925944011,5.781290014584859,5.768539945284526,5.755809982617696,5.743120034535726,5.73044999440511,5.717810074488322,5.705199956893921,5.692610025405884,5.680059989293416,5.667529980341594,5.655030012130737,5.642549991607666,5.630110025405884,5.617690046628316,5.6053000291188555,5.59293003877004,5.5806000630060835,5.568290074666341,5.556009968121846,5.543749968210856,5.531529903411865,5.519330024719238,5.507150053977966,5.495009978612264,5.4828899304072065,5.470789988835652,5.4587299426396685,5.446689923604329,5.434670011202495,5.4226899941762285,5.4107299248377485,5.398790001869202,5.3868900537490845,5.375010013580322,5.363149960835774,5.351319988568624,5.33952001730601,5.327739993731181,5.315990050633748,5.304269989331563,5.292569994926453,5.280899961789449,5.26925003528595,5.257629990577698,5.2460399468739825,5.234470049540202,5.222920020421346,5.211410005887349,5.199909965197246,5.18845001856486,5.176999966303508,5.165589928627014,5.154190023740132,5.142830053965251,5.1314899524052935,5.120169997215271,5.108879963556926,5.097609996795654,5.08637003103892,5.075160066286723,5.063959956169128,5.052799940109253,5.041659990946452,5.030540029207866,5.019439935684204,5.008379936218262,4.997329990069072,4.986309965451558,4.975319981575012,4.9643499453862505,4.9533999760945635,4.942480007807414,4.931580026944478,4.92071004708608,4.909860094388326,4.8990300099054975,4.888230045636495,4.877450108528137,4.8666999737421675,4.85597010453542,4.84525998433431,4.834580024083455,4.823920051256816,4.813280026117961,4.802670001983643,4.792080005009969,4.7815200090408325,4.7709700266520185,4.760449965794881,4.7499600648880005,4.7394899527231855,4.729040066401164,4.718610008557637,4.708209991455078,4.697829961776733,4.687470038731893,4.67714003721873,4.666830023129781,4.656539956728618,4.64628005027771,4.636029918988545,4.625809987386067,4.615619977315267,4.605440020561218,4.595289985338847,4.58516001701355,4.575050036112468,4.564970056215922,4.554909944534302,4.544870018959045,4.534850001335144,4.524850010871887,4.514879941940308,4.504930019378662,4.495000004768372,4.485089977582295,4.475200057029724,4.46533997853597,4.45550000667572,4.445679982503255,4.435880025227864,4.426099975903829,4.41635004679362,4.406620065371196,4.396909991900126,4.387210011482239,4.377550045649211,4.367899974187215,4.358270088831584,4.34866992632548,4.339079976081848,4.329520026842753,4.3199799458185835,4.3104599714279175,4.300960024197896,4.291489998499553,4.282029986381531,4.2725900411605835,4.263179977734883,4.253780007362366,4.244409958521525,4.235060056050618,4.225730021794637,4.216419974962871,4.207129955291748,4.1978600025177,4.188610037167867,4.179380019505818,4.170170029004415,4.160980025927226,4.151809970537822,4.1426699956258135,4.133539954821269,4.124429980913798,4.115350008010864,4.106280008951823,4.097229957580566,4.088210105895996,4.0791999499003095,4.070219993591309,4.061250011126201,4.052300016085307,4.04337998231252,4.034469922383626,4.025579929351807,4.016709923744202,4.007869998613994,3.9990400671958923,3.9902299841245017,3.981440007686615,3.972670018672943,3.963920017083486,3.9551899830500283,3.9464800159136453,3.9377899765968323,3.9291100104649863,3.9204599857330322,3.911829968293508,3.903210004170736,3.8946100076039634,3.8860400120417276,3.8774799903233848,3.868940015633901,3.860419968763987,3.851920008659363,3.8434300223986306,3.834969997406006,3.8265299598375955,3.8180999755859375,3.809690018494924,3.80130002895991,3.792930006980896,3.7845799922943115,3.7762499849001565,3.767930010954539,3.7596399982770285,3.751359979311625,3.7431000471115112,3.7348600228627524,3.726629992326101,3.718429962793986,3.7102399865786233,3.702069958051046,3.6939199964205423,3.685790002346039,3.677680015563965,3.669580022493998,3.661500016848246,3.653439998626709,3.6453999876976013,3.637370010217031,3.629360020160675,3.621380011240641,3.6134000420570374,3.6054499745368958,3.601480007171631};
        CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192006429037,514.5848337809244,508.82093811035156,504.26490783691406,499.65891520182294,495.01991017659503,490.3589045206706,485.68591054280597,481.0109151204427,476.3409144083659,471.680908203125,467.0369135538737,462.4119110107422,457.81091054280597,453.2349141438802,448.6879196166992,444.16991424560547,439.6839116414388,435.22991434733075,430.80891672770184,426.4229202270508,422.07191975911456,417.7559229532878,413.47491963704425,409.22991943359375,405.0219243367513,400.8489176432292,396.71192677815753,392.6109263102214,388.5459264119466,384.5159225463867,380.5229263305664,376.5639241536458,372.6419270833333,368.75392659505206,364.9009272257487,361.08292897542316,357.29892985026044,353.5499318440755,349.8339309692383,346.1529286702474,342.5039291381836,338.88893127441406,335.3069305419922,331.7579345703125,328.2409311930339,324.7569351196289,321.304931640625,317.8839365641276,314.4949417114258,311.1369400024414,307.80993906656903,304.5139389038086,301.24893951416016,298.0139389038086,294.8089370727539,291.63294728597003,288.4879379272461,285.3719431559245,282.2849400838216,279.22694142659503,276.1969451904297,273.1969451904297,270.2239405314128,267.2799428304036,264.3629455566406,261.4739456176758,258.61194610595703,255.77794901529947,252.96994654337564,250.18894704182944,247.4349479675293,244.70694732666016,242.00494893391928,239.32895151774088,236.67895126342773,234.0539525349935,231.45495223999023,228.88095219930014,226.33095169067383,223.8059514363607,221.30595270792642,218.8299560546875,216.37795384724936,213.94995625813803,211.54595565795898,209.16495641072592,206.80795669555664,204.47495778401694,202.16395823160806,199.87595748901367,197.60995737711588,195.36696116129556,193.1469586690267,190.9489606221517,188.7729581197103,186.61896133422852,184.48596064249674,182.37596003214517,180.2869618733724,178.21896362304688,176.17296091715494,174.14696248372397,172.14296213785806,170.15996424357095,168.19696299235025,166.25496419270834,164.3329645792643,162.43096542358398,160.5489641825358,158.6869659423828,156.84496434529623,155.02296574910483,153.21996434529623,151.43596649169922,149.67096837361655,147.92496871948242,146.19796752929688,144.4899673461914,142.79996744791666,141.1279665629069,139.47497177124023,137.83897145589194,136.22197087605795,134.62196985880533,133.03897094726562,131.47397232055664,129.92597325642905,128.39496930440268,126.88097254435222,125.38397153218587,123.90297317504883,122.43897310892741,120.99097379048665,119.55897394816081,118.14297294616699,116.74297459920247,115.35797500610352,113.9889742533366,112.6359748840332,111.29797554016113,109.97397549947102,108.66597429911296,107.37197748819987,106.09297561645508,104.82897567749023,103.57897694905598,102.34297752380371,101.12097676595052,99.91307703653972,98.71887715657552,97.53827794392903,96.37127876281738,95.21757888793945,94.07717895507812,92.94977887471516,91.83537928263347,90.73377990722656,89.64497884114583,88.56857999165852,87.5046812693278,86.45308113098145,85.41368103027344,84.3862813313802,83.37078094482422,82.36718050638835,81.37518056233723,80.39468193054199,79.4255822499593,78.46788152058919,77.5212828318278,76.58578300476074,75.66128158569336,74.74748357137044,73.84448305765788,72.9519837697347,72.07008361816406,71.19848442077637,70.33708318074544,69.48588562011719,68.64478365580241,67.81348419189453,66.99208450317383,66.18028450012207,65.3781852722168,64.58548482259114,63.80228487650553,63.02828598022461,62.2634859085083,61.50778611501058,60.760985692342125,60.02318572998047,59.29408645629883,58.573686599731445,57.861887296040855,57.15848731994629,56.46358744303385,55.776987393697105,55.09848817189535,54.42818737030029,53.76588789621989,53.11158720652262,52.46498807271322,51.8262882232666,51.195188204447426,50.57158883412679,49.95558834075928,49.34688822428385,48.74558893839518,48.15148893992106,47.564589500427246,46.98478921254476,46.41189002990723,45.845889727274574,45.28678957621256,44.734389305114746,44.188689867655434,43.649590492248535,43.11708958943685,42.5908899307251,42.07119051615397,41.55769062042236,41.050390561421715,40.54929065704346,40.054291089375816,39.565290451049805,39.082191467285156,38.60499127705892,38.13359133402506,37.66789150238037,37.2078914642334,36.753491719563804,36.30459181467692,35.861191749572754,35.42319202423096,34.99059200286865,34.56319204966227,34.140992164611816,33.723992665608726,33.312092781066895,32.90529251098633,32.5033925374349,32.10649220148722,31.71439282099406,31.32709280649821,30.94459279378255,30.5666929880778,30.193492889404297,29.824793338775635,29.460593223571777,29.10089349746704,28.745593229929607,28.394593556722004,28.047993501027424,27.705493450164795,27.36729367574056,27.033193747202557,26.703193823496502,26.377193609873455,26.05509392420451,25.737094084421795,25.4228941599528,25.112494150797527,24.805994351704914,24.50309419631958,24.203994433085125,23.908594449361164,23.616694768269856,23.328394571940105,23.043594519297283,22.762394587198894,22.48449484507243,22.209994633992512,21.938895225524902,21.671095371246338,21.4065949122111,21.14529514312744,20.887195428212483,20.632195313771565,20.380395253499348,20.131595452626545,19.885895252227783,19.643195788065594,19.403395493825276,19.166595617930096,18.93259557088216,18.70149580637614,18.47329568862915,18.247795899709065,18.02509609858195,17.805095831553142,17.587695916493733,17.373095989227295,17.160995960235596,16.95159610112508,16.744695981343586,16.54029639561971,16.338396231333416,16.1389962832133,15.941996415456137,15.747396310170492,15.555296341578165,15.36539657910665,15.177896658579508,14.992596626281738,14.809596618016561,14.628896554311117,14.450396617253622,14.273996750513712,14.099796930948893,13.927696625391642,13.757696866989136,13.589796861012777,13.423996925354004,13.260196924209595,13.098296960194906,12.938497066497803,12.780597050984701,12.624597152074179,12.47059710820516,12.318397363026937,12.167997201283773,12.019597133000692,11.872897227605185,11.727997382481893,11.58489727973938,11.4434974193573,11.303897301355997,11.165897607803345,11.02969733874003,10.895097494125366,10.762097517649332,10.630797624588013,10.501097440719604,10.372897624969482,10.246397654215494,10.121397654215494,9.99784771601359,9.875857830047607,9.75535774230957,9.636327902475992,9.518747727076212,9.402607917785645,9.287887891133627,9.174567937850952,9.062627871831259,8.95205807685852,8.842837889989218,8.734947999318441,8.62837807337443,8.523108005523682,8.419128179550171,8.316418091456095,8.214958111445108,8.11473806699117,8.015738089879354,7.917948126792908,7.8213582038879395,7.725938240687053,7.631688237190247,7.538588245709737,7.446628292401631,7.3557883103688555,7.2660584052403765,7.177428364753723,7.08987828095754,7.003388325373332,6.917958378791809,6.833578427632649,6.750228444735209,6.667888442675273,6.58655846118927,6.506218512852986,6.42685854434967,6.348478515942891,6.271048545837402,6.194558580716451,6.119008620580037,6.044378678003947,5.970658659934998,5.897838632265727,5.825908740361531,5.754858652750651,5.6846786340077715,5.615348696708679,5.546868681907654,5.479228734970093,5.412408749262492,5.346398790677388,5.281208753585815,5.216808795928955,5.1531888246536255,5.090348879496257,5.0282788674036665,4.966968854268392,4.906398852666219,4.84657895565033,4.787478923797607,4.729108929634094,4.671448906262715,4.614488999048869,4.558228969573975,4.502648989359538,4.447758952776591,4.393529017766316,4.3399589856465655,4.287049015363057,4.23478905359904,4.183158993721008,4.132159034411113,4.081789096196492,4.0320290724436445,3.982879082361857,3.934319098790487,3.886359135309855,3.8389891187349954,3.792189101378123,3.7459691762924194,3.700309137503306,3.65519917011261,3.6106491684913635,3.5666391849517822,3.5231691797574363,3.4802291989326477,3.4378092288970947,3.3959091703097024,3.354519267876943,3.3136292099952698,3.2732492486635842,3.2333592971165976,3.193949262301127,3.1550292571385703,3.116579254468282,3.0785993138949075,3.041079302628835,3.004019320011139,2.9674193461736045,2.9312593142191568,2.895539343357086,2.8602593739827475,2.8253993590672812,2.790979345639547,2.756969372431437,2.72337943315506,2.6901893814404807,2.6574193636576333,2.6250394185384116,2.5930593808492026,2.5614594221115112,2.5302594105402627,2.499429404735565,2.46897945801417,2.4388994574546814,2.409189462661743,2.3798394401868186,2.350849449634552,2.3222094575564065,2.293929477532705,2.265979508558909,2.238379498322805,2.211119532585144,2.1841795444488525,2.157579481601715,2.1312995155652366,2.105339527130127,2.0796994964281716,2.054369548956553,2.0293495257695517,2.004629542430242,1.980219542980194,1.956099549929301,1.9322795569896698,1.908739556868871,1.8854995568593342,1.8625395894050598,1.8398595650990803,1.8174495995044708,1.7953195869922638,1.7734596033891041,1.7518595953782399,1.7305295964082081,1.7094596425692241,1.6886496047178905,1.6680895785490673,1.6477798720200856,1.6376798053582509};
        //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.88396962483724,40.042534828186035,40.477243741353355,36.82063706715902,37.68098386128744,38.58034165700277,39.47893524169922,39.752062479654946,39.328728675842285,38.844716707865395,38.35651779174805,37.86792818705241,37.37916787465414,36.89059607187907,36.40164025624593,35.91345421473185,35.423667907714844,35.111459732055664,34.996373335520424,34.898529370625816,34.801768938700356,34.70519161224365,34.60866641998291,34.51211595535278,34.41540733973185,34.31915680567423,34.221959908803306,34.22516361872355,34.33964093526205,34.46386750539144,34.588716983795166,34.71363162994385,34.83862860997518,34.963621616363525,35.08855024973551,35.21346855163574,35.33859586715698,35.423354625701904,35.46326605478922,35.49909702936808,35.53482834498087,35.57041645050049,35.60611836115519,35.64172522226969,35.677303632100426,35.712973276774086,35.748443285624184,35.828499952952065,35.95804182688395,36.09203783671061,36.226287841796875,36.36061159769694,36.494899113972984,36.62920951843262,36.76348718007406,36.8978640238444,37.031776110331215,37.22856648763021,37.49485683441162,37.7675142288208,38.04042116800944,38.31347242991129,38.58634503682455,38.85935910542806,39.13234774271647,39.40537071228027,39.67828369140625,39.972168604532875,40.28940010070801,40.60866038004557,40.92801888783773,41.24744415283203,41.56692663828532,41.88634045918783,42.205729484558105,42.52514807383219,42.84447002410889,43.18513456980387,43.54927635192871,43.91563288370768,44.281989097595215,44.64851919809977,45.014899253845215,45.381409645080566,45.74781862894694,46.11373519897461,46.48163350423177,46.56477578481039,46.330323219299316,46.06859302520752,45.80491256713867,45.54101308186849,45.27701314290365,45.01311206817627,44.749213536580406,44.48521296183268,44.22131093343099,43.95741367340088,43.6934118270874,43.42951361338297,43.165513356526695,42.901611328125,42.63771375020345,42.37371349334717,42.10981146494547,41.84591420491537,41.58191331227621,41.31801160176595,41.054113705952965,40.79011313120524,40.526211738586426,40.26231447855631,39.99831295013428,39.73441378275553,39.470413525899254,39.206512133280434,38.942614237467446,38.6786142985026,38.41471195220947,38.150814056396484,37.88681411743164,37.62291304270426,37.35901387532552,37.09501425425211,36.831112225850426,36.56721464792887,36.30321375528971,36.03931395212809,35.77531464894613,35.51141246159872,35.247514724731445,34.98351494471232,34.71961307525635,34.45571438471476,34.1917150815328,33.9278130531311,33.663914362589516,33.39991442362467,33.136013984680176,32.87201468149821,32.608113288879395,32.34421475728353,32.08021481831869,31.81631342569987,31.552415370941162,31.28841511408488,31.024513721466064,30.76061487197876,30.496615727742512,30.232713222503662,29.968815326690674,29.70481522878011,29.440914630889893,29.176916122436523,28.913013617197674,28.649115403493244,28.38511578241984,28.121214071909588,27.85731569925944,27.593315919240315,27.329413890838623,27.065515836079914,26.80151605606079,26.537614186604817,26.27371597290039,26.009716033935547,25.74581480026245,25.481817086537678,25.21791410446167,24.95401620864868,24.690016110738117,24.426113923390705,24.162216027577717,23.898216883341473,23.63431437810262,23.370416164398193,23.10641638437907,22.842514991760254,22.57851775487264,22.314613819122314,22.050716876983643,21.78671646118164,21.522814909617107,21.258916695912678,20.994917233784992,20.7310152053833,20.467116355895996,20.203117211659748,19.93921438852946,19.675318082173664,19.411315441131592,19.147417068481445,18.8834171295166,18.619515260060627,18.3556170463562,18.091617107391357,17.827715317408245,17.563817421595257,17.299817164738972,17.03591561317444,16.77201755841573,16.508017381032307,16.244115352630615,15.980218331019083,15.71621592839559,15.452317714691162,15.18831753730774,14.924415826797485,14.660517772038778,14.396517594655355,14.13261596361796,13.868717829386393,13.60471773147583,13.340815941492716,13.076918284098307,12.812917073567709,12.549017906188965,12.285017967224121,12.021116256713867,11.757217963536581,11.493218104044596,11.229316393534342,10.965418259302774,10.701418161392212,10.437516927719116,10.173618078231812,9.909648180007935,9.645708004633585,9.381767511367798,9.117838621139526,8.853896737098694,8.589971423149109,8.326019048690796,8.062112013498941,7.798093159993489,7.534396529197693,7.269795894622803,7.124750256538391,7.112112124760945,7.111345489819844,7.111173788706462,7.111208995183309,7.111194849014282,7.11120065053304,7.11119822661082,7.1111992200215655,7.1111988226572675,7.1111990213394165,7.1111988226572675,7.111198941866557,7.111198902130127,7.111198941866557,7.111198862393697,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
        CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666919310887654,6.884193102518718,6.612607518831889,6.674074093500773,6.745414813359578,6.819554328918457,6.894375880559285,6.9219997723897295,6.889102458953857,6.83940311272939,6.784991939862569,6.729251305262248,6.673080285390218,6.6167298555374146,6.56026828289032,6.503699064254761,6.447014331817627,6.398238182067871,6.359598795572917,6.3236381610234575,6.288257638613383,6.252897183100383,6.217386643091838,6.181706428527832,6.145835479100545,6.109786033630371,6.0735528866449995,6.042359193166097,6.017689387003581,5.99475900332133,5.972218791643779,5.9496885140736895,5.927068114280701,5.904317895571391,5.881447434425354,5.858447710673015,5.835315545399983,5.815802852312724,5.800993005434672,5.787452737490336,5.774202664693196,5.760972420374553,5.747682293256124,5.734302123387654,5.720831831296285,5.707271893819173,5.693620761235555,5.681849400202434,5.672529339790344,5.663859248161316,5.655309160550435,5.646729032198588,5.638088941574097,5.629378795623779,5.620598673820496,5.61172874768575,5.60277791817983,5.595087091128032,5.589017033576965,5.583366950352986,5.577797015508016,5.572196841239929,5.56654687722524,5.560836672782898,5.555056691169739,5.549216349919637,5.543307344118754,5.535168608029683,5.524158438046773,5.512248277664185,5.499988118807475,5.48757799466451,5.475037892659505,5.46240774790446,5.4496976137161255,5.436897913614909,5.4240158796310425,5.415233294169108,5.411743243535359,5.40972359975179,5.408063332239787,5.406463543574016,5.4048335154851275,5.4031535387039185,5.401423454284668,5.399633606274922,5.397793531417847,5.395863652229309,5.393693844477336,5.391143957773845,5.388243993123372,5.385004083315532,5.3814741770426435,5.377694169680278,5.373684326807658,5.369474371274312,5.365094383557637,5.360564390818278,5.3559145132700605,5.3511544068654375,5.346284548441569,5.341344515482585,5.336334506670634,5.331264495849609,5.326154430707295,5.321004430452983,5.315824429194133,5.310624440511067,5.305414438247681,5.300204396247864,5.294984340667725,5.289764404296875,5.28456433614095,5.279364228248596,5.274194320042928,5.269034266471863,5.263904293378194,5.258794228235881,5.2537141640981035,5.248664180437724,5.243644118309021,5.238654096921285,5.233704129854838,5.228794137636821,5.22391406695048,5.219074010848999,5.214284022649129,5.209523955980937,5.204803903897603,5.200123866399129,5.195493896802266,5.190893888473511,5.186343749364217,5.181833783785502,5.177363753318787,5.17293377717336,5.168553630510966,5.16421365737915,5.159913579622905,5.155653635660808,5.151443600654602,5.1472634474436445,5.143133521080017,5.1390334367752075,5.134983420372009,5.13097341855367,5.126993378003438,5.123063325881958,5.119163274765015,5.1153033177057905,5.111483295758565,5.10770324865977,5.1039531628290815,5.100243171056111,5.0965730746587115,5.092933098475139,5.089333136876424,5.085763057072957,5.082233031590779,5.078733007113139,5.075262983640035,5.071832935015361,5.068433006604512,5.065062920252482,5.061732888221741,5.058422843615214,5.055152813593547,5.051902850468953,5.04869278271993,5.045502742131551,5.042352755864461,5.039222677548726,5.036132613817851,5.033062696456909,5.030022660891215,5.027002612749736,5.024012645085652,5.021052598953247,5.018122553825378,5.015212575594584,5.012322465578715,5.009462475776672,5.006632447242737,5.003822485605876,5.001032431920369,4.9982722997665405,4.995532353719075,4.992812275886536,4.990122278531392,4.987442175547282,4.984792311986287,4.982162197430928,4.9795522292455034,4.976972182591756,4.974402189254761,4.971852103869121,4.969332059224446,4.966822028160095,4.964332024256389,4.961861968040466,4.959412058194478,4.9569820165634155,4.954572081565857,4.9521719217300415,4.94979194800059,4.947431882222493,4.945091923077901,4.942761937777202,4.940451820691426,4.938151876131694,4.935871839523315,4.933611869812012,4.931361754735311,4.929121772448222,4.926901698112488,4.924701730410258,4.922511736551921,4.920341690381368,4.918171644210815,4.91603155930837,4.913891553878784,4.911771655082703,4.909661650657654,4.907561580340068,4.9054815371831255,4.903411507606506,4.901351571083069,4.899301489194234,4.897271354993184,4.895241379737854,4.893231471379598,4.891221324602763,4.889231324195862,4.887251377105713,4.885271350542705,4.8833112716674805,4.881381352742513,4.8792615334192915,4.876951336860657,4.874761303265889,4.872721234957377,4.870851238568624,4.869131167729695,4.8675611813863116,4.866111119588216,4.864781101544698,4.863561034202576,4.862441062927246,4.861400882403056,4.860450903574626,4.859570860862732,4.858770887056987,4.858020901679993,4.857330799102783,4.8567008177439375,4.85611077149709,4.855570832888286,4.855060736338298,4.854590733846028,4.854160825411479,4.853760719299316,4.853380759557088,4.853030721346538,4.852700710296631,4.852400779724121,4.852110664049785,4.851840694745381,4.851590633392334,4.851350744565328,4.851120670636495,4.850910743077596,4.85071074962616,4.850520690282186,4.850340684254964,4.850170572598775,4.850000699361165,4.849840680758159,4.8496906359990435,4.849550644556682,4.849410732587178,4.849280595779419,4.8491506179173784,4.849020640055339,4.8489006360371905,4.848790645599365,4.848670641581218,4.848560651143392,4.8484606345494585,4.848350604375203,4.84825058778127,4.848150650660197,4.848050673802693,4.847960631052653,4.84786069393158,4.847770651181539,4.8476806084314985,4.847590605417888,4.847510615984599,4.847420573234558,4.847340703010559,4.847260634104411,4.847180724143982,4.847090641657512,4.847020665804545,4.846940636634827,4.846860647201538,4.84678069750468,4.846710602442424,4.8466406265894575,4.846560597419739,4.8464906215667725,4.846420645713806,4.84635059038798,4.846280614535014,4.846210638682048,4.8461406628290815,4.846070607503255,4.846010684967041,4.845940550168355,4.845880627632141,4.845810651779175,4.845750570297241,4.845690647761027,4.845620632171631,4.845560630162557,4.845500667889913,4.845440626144409,4.845380624135335,4.8453205823898315,4.845260580380757,4.845210591952006,4.845150709152222,4.845090587933858,4.845040639241536,4.844980676968892,4.844930609067281,4.844880660374959,4.844820578893025,4.844770669937134,4.8447206020355225,4.844670653343201,4.8446206251780195,4.844570676485698,4.844520688056946,4.8444706201553345,4.844420671463013,4.844370603561401,4.844330668449402,4.8442806005477905,4.844230572382609,4.8441905577977495,4.84415070215861,4.844100634256999,4.844060659408569,4.84402064482371,4.8439706563949585,4.8439306418101,4.84389066696167,4.843850612640381,4.843810637791951,4.843770623207092,4.843730529149373,4.843700647354126,4.843660632769267,4.843620618184407,4.8435806433359785,4.843550642331441,4.843510627746582,4.843480626742045,4.843450625737508,4.843410611152649,4.843380610148112,4.843350609143575,4.843310594558716,4.843280673027039,4.843250632286072,4.843220631281535,4.843190630276998,4.843160589536031,4.843130588531494,4.843110640843709,4.843080639839172,4.843050718307495,4.843020598093669,4.843000610669454,4.842970569928487,4.842950542767842,4.842920660972595,4.8429005940755205,4.842880646387736,4.8428506056467695,4.842830657958984,4.84281059106191,4.8427906433741255,4.842770616213481,4.842740615208943,4.842720588048299,4.842700560887654,4.842690706253052,4.842670599619548,4.8426506121953325,4.842630624771118,4.842610597610474,4.842600663503011,4.842580596605937,4.842560648918152,4.84255063533783,4.8425306876500445,4.842520515124003,4.842500686645508,4.842490593592326,4.842480580012004,4.842460632324219,4.842450658480327,4.842440565427144,4.842430671056111,4.84242057800293,4.842410564422607,4.842400630315145,4.842390656471252,4.8423806031545,4.842370589574178,4.842360615730286,4.842350602149963,4.842340548833211,4.842340588569641,4.8423307339350385,4.842320601145427,4.842320640881856,4.842310627301534,4.842310547828674,4.842300573984782,4.8423006137212115,4.842290600140889,4.842290600140889,4.842290639877319,4.842280666033427,4.8422807057698565,4.842280626296997,4.842280626296997,4.842270612716675,4.842270652453105,4.842270612716675,4.842270652453105,4.842270572980245,4.842270652453105,4.842270612716675,4.842270612716675,4.842280666033427,4.842280666033427,4.842280666033427,4.842280666033427,4.842290639877319,4.842290639877319,4.842290600140889,4.842300573984782,4.842300653457642,4.842300573984782,4.842310627301534,4.842310667037964,4.842320640881856,4.842330574989319,4.842330574989319,4.842340588569641,4.842350602149963,4.842350522677104,4.842360695203145,4.842370589574178,4.84238064289093,4.84238064289093,4.842390656471252,4.842400630315145,4.842410524686177,4.84242061773936,4.842430671056111,4.842440565427144,4.842450658480327,4.842460592587789,4.842470645904541,4.842490553855896,4.842500646909078,4.84251054128011,4.842520594596863,4.842530608177185,4.84255063533783,4.84255055586497};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219178477923074,2.6039250095685325,2.0359680155913034,1.6536800463994343,1.3429876168568928,1.0901534656683605,0.8847505201896032,0.7179091026385626,0.5826493004957835,0.4729319488008817,0.38394080599149066,0.3117417295773824,0.25315916538238525,0.20561674982309341,0.16702893003821373,0.1357009205967188,0.11026697792112827,0.08961177493135135,0.07284252159297466,0.05921663033465544,0.04815406631678343,0.03915542736649513,0.0318529037758708,0.025904720183461905,0.021080750972032547,0.017146961530670524,0.013957120245322585,0.01135532969298462,0.009244501202677688,0.007523829001002014,0.006126005163726707,0.00498733875186493,0.004061272057394187,0.003307198639959097,0.0026934672302256026,0.002193751841938744,0.0017868897994048893,0.0014556259072075288,0.0011859695174886535,0.00096641206376565,0.0007876103967040157,0.0006419940085227912,0.0005233488579203064,0.00042672003716385615,0.00034792893469178426,0.00028378061930804205,0.00023141481263640648,0.00018880885666779554,0.00015398419297222668,0.0001256642644875683,6.413006182507767e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8295237223307,563.0184326171875,558.953867594401,563.0249328613281,566.6924743652344,570.2189381917318,573.7017059326172,575.2236633300781,574.1700388590494,572.2970733642578,570.1644846598307,567.9466145833334,565.6996459960938,563.438720703125,561.1686350504557,558.889882405599,556.6004231770834,554.6528727213541,553.1580963134766,551.7919972737631,550.4519755045573,549.1060180664062,547.7440643310547,546.3631439208984,544.963144938151,543.5433247884115,542.1050618489584,540.8810882568359,539.9485677083334,539.1004943847656,538.2704823811849,537.4345194498698,536.5885416666666,535.7286020914713,534.8546040852865,533.9667358398438,533.0635274251302,532.3407084147135,531.8652496337891,531.4631958007812,531.0791676839193,530.6941935221354,530.3012135823568,529.8992513020834,529.4882659912109,529.0663299560547,528.6342519124349,528.2699432373047,527.9987589518229,527.7527770996094,527.5087687174479,527.258799235026,527.0008188883463,526.7338460286459,526.4588623046875,526.1739095052084,525.8798777262369,525.6326599121094,525.451520284017,525.2865422566732,525.1225331624349,524.9535598754883,524.7775802612305,524.5935948689779,524.4026285807291,524.2036285400391,523.9967575073242,523.6672999064127,523.1726633707682,522.6137186686198,522.0258153279623,521.4188435872396,520.7978846232096,520.1659164428711,519.5219497680664,518.8670043945312,518.2028757731119,517.7050857543945,517.4326426188151,517.2286376953125,517.0415623982748,516.8556162516276,516.6636123657227,516.4656372070312,516.2606531778971,516.0486602783203,515.8297653198242,515.5003280639648,515.0056508382162,514.4238586425781,513.7830022176107,513.0971221923828,512.3732172648112,511.6183115641276,510.8353754679362,510.0284423828125,509.2005030314128,508.3545557657878,507.4925944010417,506.6186294555664,505.732660929362,504.8376871744792,503.9346974690755,503.0257161458333,502.1117350260417,501.19373830159503,500.27274322509766,499.35075124104816,498.42775472005206,497.5037536621094,496.5807418823242,495.6597391764323,494.73973592122394,493.8217290242513,492.9067204793294,491.99471282958984,491.08670806884766,490.1816864013672,489.2816747029622,488.38466389973956,487.49364980061847,486.6066385904948,485.72462209065753,484.8466084798177,483.97458902994794,483.1085789998372,482.2465591430664,481.3905436197917,480.54052480061847,479.6955159505208,478.8554941813151,478.02247619628906,477.1934636433919,476.3704477945964,475.5534261067708,474.7424138387044,473.9363962809245,473.13538360595703,472.3403600056966,471.55134836832684,470.7663345336914,469.9883092244466,469.2153040568034,468.44628651936847,467.68427022298175,466.92625935872394,466.1732432047526,465.4262237548828,464.68321482340497,463.94519805908203,463.2121861775716,462.48417409261066,461.76115163167316,461.0431416829427,460.3291320800781,459.6191151936849,458.9141031901042,458.2140833536784,457.51807403564453,456.82606506347656,456.13805135091144,455.4550374348958,454.7760264078776,454.1010157267253,453.4300003051758,452.76299540201825,452.0989812215169,451.4399693806966,450.7849578857422,450.13294728597003,449.4849370320638,448.8399251302083,448.19891357421875,447.56190490722656,446.9278971354167,446.29688771565753,445.6698760986328,445.0458679199219,444.4248580932617,443.8078435262044,443.1928405761719,442.58182525634766,441.9738184611003,441.3688100179036,440.76680755615234,440.1667887369792,439.57078552246094,438.9767761230469,438.3857727050781,437.7977600097656,437.2127507527669,436.62975311279297,436.0497283935547,435.4727325439453,434.89672088623047,434.32471720377606,433.7547124226888,433.1866989135742,432.62169138590497,432.0586929321289,431.49767812093097,430.93968200683594,430.3826675415039,429.8286641438802,429.27665456136066,428.72764587402344,428.17964426676434,427.6336390177409,427.0896301269531,426.5486246744792,426.0086212158203,425.47061920166016,424.93460845947266,424.40060170491535,423.8676020304362,423.3365936279297,422.8075892130534,422.28057861328125,421.7555796305339,421.23156992594403,420.7095692952474,420.1885681152344,419.6695607503255,419.1525522867839,418.63655344645184,418.12154897054035,417.6085459391276,417.0965398152669,416.58653513590497,416.07752482096356,415.5705286661784,415.0635248819987,414.55851491292316,414.0555165608724,413.55250295003253,413.05153401692706,412.55342356363934,412.13805135091144,411.8378143310547,411.58573659261066,411.36266072591144,411.1606089274089,410.9755630493164,410.8055140177409,410.6504720052083,410.50744374593097,410.37640889485675,410.25538635253906,410.14435323079425,410.04232533772785,409.9483057657878,409.8612823486328,409.78127034505206,409.7072575887044,409.6392364501953,409.5762227376302,409.51820882161456,409.46420033772785,409.41318766276044,409.3671696980794,409.3241704305013,409.2831548055013,409.2461446126302,409.2111409505208,409.1781361897786,409.14713287353516,409.11812591552734,409.09112040201825,409.0661163330078,409.04211171468097,409.0191065470378,408.99710337320965,408.9771016438802,408.9571024576823,408.9390920003255,408.9210968017578,408.90509033203125,408.8880971272786,408.8730824788411,408.8580856323242,408.84407806396484,408.830083211263,408.81707763671875,408.80408477783203,408.79108174641925,408.7790807088216,408.76707712809247,408.7560780843099,408.7450764973958,408.7340723673503,408.7230758666992,408.71307373046875,408.7030715942383,408.69307200113934,408.68307240804035,408.6730702718099,408.66407267252606,408.65507253011066,408.64607493082684,408.6370671590169,408.62807210286456,408.61906178792316,408.61106872558594,408.6020685831706,408.5940653483073,408.58606974283856,408.5770670572917,408.5690638224284,408.5620651245117,408.55406697591144,408.5460713704427,408.53806559244794,408.53106689453125,408.52306874593097,408.5160624186198,408.5090688069661,408.5010630289714,408.4940592447917,408.48706309000653,408.48006439208984,408.4730631510417,408.4670639038086,408.46007029215497,408.45306396484375,408.44706471761066,408.4400583902995,408.43406168619794,408.42706298828125,408.42105865478516,408.4150644938151,408.4090576171875,408.40306599934894,408.3960545857747,408.3910598754883,408.3850631713867,408.3790562947591,408.37306213378906,408.3670603434245,408.362060546875,408.35605875651044,408.35105895996094,408.3450622558594,408.3400599161784,408.3350652058919,408.32905832926434,408.32405853271484,408.3190638224284,408.3140589396159,408.3090540568034,408.3040593465169,408.29905700683594,408.29505666097003,408.29005940755206,408.2850596110026,408.28106180826825,408.2760594685872,408.27205657958984,408.26705678304035,408.26305135091144,408.2590560913086,408.2550557454427,408.25005594889325,408.2460530598958,408.24205525716144,408.2380549112956,408.2340596516927,408.2300542195638,408.22705078125,408.2230580647786,408.2190577189128,408.21605173746747,408.2120539347331,408.2090530395508,408.20505777994794,408.2020517985026,408.19805908203125,408.19504801432294,408.19205474853516,408.18904876708984,408.18605550130206,408.1830520629883,408.1800486246745,408.1770553588867,408.17405954996747,408.1710561116536,408.1680552164714,408.165044148763,408.1630579630534,408.16004689534503,408.1580556233724,408.1550521850586,408.15305582682294,408.15004475911456,408.1480534871419,408.1450449625651,408.14305369059247,408.1410497029622,408.13904825846356,408.1370493570964,408.1350504557292,408.133051554362,408.1310577392578,408.1290512084961,408.1270472208659,408.1250483194987,408.123046875,408.12204996744794,408.1200536092122,408.11804453531903,408.11705017089844,408.11504618326825,408.1140492757161,408.11205037434894,408.11104583740234,408.1100489298503,408.1080500284831,408.1070505777995,408.10604604085285,408.1050440470378,408.10404713948566,408.1030451456706,408.10204060872394,408.1010487874349,408.1000467936198,408.0990498860677,408.0980478922526,408.09704844156903,408.0960439046224,408.0960439046224,408.09504954020184,408.0940450032552,408.0940475463867,408.0930455525716,408.0930480957031,408.092046101888,408.09204355875653,408.09104410807294,408.09104410807294,408.09104410807294,408.0900421142578,408.09004465738934,408.0900395711263,408.09004465738934,408.09004465738934,408.09004465738934,408.0900395711263,408.0900395711263,408.0900395711263,408.0900395711263,408.09004465738934,408.09004465738934,408.09004465738934,408.09004465738934,408.0910415649414,408.09104410807294,408.0910390218099,408.09204355875653,408.09204355875653,408.0930404663086,408.0930430094401,408.0940348307292,408.0940475463867,408.09503682454425,408.0950444539388,408.0960388183594,408.0970408121745,408.09704335530597,408.0980453491211,408.09904225667316,408.10003662109375,408.1010462443034,408.1010487874349,408.10203806559247,408.10304005940753,408.1040395100911,408.10504659016925,408.10604095458984,408.10704294840497,408.10904184977215,408.11004638671875,408.1110356648763,408.11204528808594,408.11303965250653,408.1150385538737,408.1160430908203,408.11704508463544};
        //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.448237737019857,9.763489564259848,10.08242662747701,9.470903873443604,9.678422768910727,9.891692320505777,10.105006217956543,10.14895518620809,10.008438666661581,9.852510452270508,9.69538958867391,9.538158098856607,9.380917151769003,9.223679701487223,9.066434065500895,8.909204959869385,8.751946051915487,8.620591719945272,8.517394622166952,8.416551113128662,8.315898617108664,8.215259432792664,8.11461865901947,8.01397963364919,7.913337190945943,7.812702655792236,7.712061524391174,7.627991875012715,7.561939835548401,7.49741546312968,7.432993173599243,7.368593851725261,7.304183483123779,7.2397838433583575,7.175382812817891,7.110975344975789,7.046569228172302,6.992770949999492,6.950509508450826,6.909224192301433,6.868011991182963,6.826802889506022,6.785592397054036,6.74439263343811,6.703182299931844,6.661973357200623,6.6207601229349775,6.586335261662801,6.559281309445699,6.5328448216120405,6.506452997525533,6.480063756306966,6.453683376312256,6.427293618520101,6.40091331799825,6.374523917833964,6.348142147064209,6.326105912526448,6.308806975682576,6.291909535725911,6.275037924448649,6.258168776830037,6.241298278172811,6.2244285345077515,6.207558433214824,6.190688133239746,6.173829754193624,6.150943040847778,6.121514956156413,6.091531316439311,6.061513662338257,6.031492193539937,6.001463055610657,5.971442421277364,5.941412806510925,5.911382953325908,5.881360451380412,5.865065336227417,5.863699793815613,5.863597710927327,5.863581498463948,5.863585948944092,5.863582730293274,5.863585114479065,5.8635832866032915,5.86358368396759,5.863584399223328,5.8622597853342695,5.859501679738362,5.856611609458923,5.853721578915914,5.850831667582194,5.847931583722432,5.845041672388713,5.842141628265381,5.839251637458801,5.83635167280833,5.83346160252889,5.830561717351277,5.8276716868082685,5.824771682421367,5.821881612141927,5.818981607755025,5.8160916566848755,5.8131916125615435,5.810301502545674,5.8074116706848145,5.804511586825053,5.801621635754903,5.798721671104431,5.795831680297852,5.79293163617452,5.790041605631511,5.787141521771749,5.784251570701599,5.781351645787557,5.778461575508118,5.775561650594075,5.772671540578206,5.769781629244487,5.766881585121155,5.763991554578145,5.761091510454814,5.758201559384664,5.755301554997762,5.752411603927612,5.749511639277141,5.746621568997701,5.743721564610799,5.740831613540649,5.737931569417317,5.735041499137878,5.732141613960266,5.729251543680827,5.726361592610677,5.723461548487346,5.7205716371536255,5.717671513557434,5.714781562487285,5.711881597836812,5.708991567293803,5.706091562906901,5.703201532363892,5.70030152797699,5.69741153717041,5.694511532783508,5.691621422767639,5.688731590906779,5.685831546783447,5.6829415162404375,5.680041511853536,5.677151600519816,5.674251556396484,5.671361486117045,5.668461521466573,5.665571530659993,5.662671645482381,5.6597814957300825,5.656881491343181,5.65399154027303,5.651091615358989,5.648201425870259,5.645301620165507,5.642411510149638,5.639521400133769,5.636621435483296,5.633731484413147,5.630831480026245,5.627941528956096,5.625041524569194,5.622151414553325,5.619251569112142,5.616361419359843,5.613461534182231,5.610571503639221,5.607671499252319,5.60478142897288,5.60189151763916,5.598991513252258,5.596101403236389,5.593201518058777,5.590311408042908,5.587411483128865,5.584521452585856,5.581621527671814,5.578731536865234,5.575831413269043,5.5729414621988935,5.570041497548421,5.567151387532552,5.564261436462402,5.56136139233907,5.558471481005351,5.555571397145589,5.55268148581187,5.5497814019521075,5.546891530354817,5.543991367022197,5.541101455688477,5.538201371828715,5.535311381022136,5.532411456108093,5.529521465301514,5.526621421178182,5.523731350898743,5.520841479301453,5.517941355705261,5.515051444371541,5.51215132077535,5.50926140944163,5.506361365318298,5.503471374511719,5.500571449597676,5.497681458791097,5.494781414667766,5.491891384124756,5.488991419474284,5.486101349194844,5.483211358388265,5.480311354001363,5.477421482404073,5.474521478017171,5.471631368001302,5.4687312841415405,5.46584137280782,5.462941408157349,5.46005133787791,5.457151412963867,5.454261302947998,5.451361417770386,5.448471387227376,5.445571422576904,5.442681392033895,5.439781427383423,5.436891277631124,5.434001604715983,5.431100845336914,5.429526011149089,5.429403305053711,5.429393966992696,5.429393768310547,5.429383794466655,5.429383754730225,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225419680277508,24.5268071492513,24.882307052612305,25.234007358551025,25.59500741958618,25.961607456207275,26.330307165781658,26.667807420094807,26.94620720545451,27.173306941986084,27.35590712229411,27.500006993611652,27.575006643931072,27.55570650100708,27.456806182861328,27.291006247202557,27.069705804189045,26.769505500793457,26.371005376180012,25.891504923502605,25.346004962921143,24.747604370117188,24.1078044573466,23.43620427449544,22.741503715515137,22.03110345204671,21.311103502909344,20.58470328648885,19.85420306523641,19.124302864074707,18.398902893066406,17.681302547454834,16.97440258661906,16.28030260403951,15.60100237528483,14.937902053197226,14.29220207532247,13.66530179977417,13.05800175666809,12.470801591873169,11.903801679611206,11.357101519902548,10.83060129483541,10.32400131225586,9.837271213531494,9.369921207427979,8.921601215998331,8.491880973180136,8.0802610317866,7.6862709522247314,7.3093909819920855,6.949110786120097,6.6048808097839355,6.276180823644002,5.962440729141235,5.663140734036763,5.37773060798645,5.105680545171102,4.846480488777161,4.599600553512573,4.364550431569417,4.140830556551616,3.9279504815737405,3.725460429986318,3.5328903992970786,3.3498103817303977,3.175800323486328,3.0103803475697837,2.8531203468640647,2.7036402821540833,2.561610301335653,2.42667027314504,2.298520306746165,2.176830232143402,2.061300218105316,1.9516402284304302,1.8475902080535889,1.7488601903120677,1.6552201906840007,1.56642018755277,1.48222017288208,1.40239014228185,1.3267301519711812,1.2550301551818848,1.1870901485284169,1.1227201422055562,1.0639301538467407,1.011610135436058,0.9642591377099355,0.9213581333557764,0.8824381430943807,0.847083126505216,0.8149221291144689,0.7856221298376719,0.7588861336310705,0.7344481299320856,0.7120731274286906,0.6915471206108729,0.6726801246404648,0.655300130446752,0.6392561246951421,0.6244091192881266,0.6106361250082651,0.5978301217158636,0.5858911176522573,0.574730118115743,0.5642691204945246,0.5544371157884598,0.5451671133438746,0.5364061146974564,0.5281011164188385,0.5202081203460693,0.512684111793836,0.505494107802709,0.4986051047841708,0.4919831107060115,0.4856061140696208,0.47945010910431546,0.47349410752455395,0.46771810948848724,0.4621051028370857,0.4566401019692421,0.45130710552136105,0.44609710574150085,0.44099710136651993,0.4359991004069646,0.43109409759442013,0.42627110083897907,0.42152510086695355,0.4168501024444898,0.41224109133084613,0.4076920946439107,0.40319809317588806,0.39875609427690506,0.3943590944012006,0.39000709106524784,0.3856960932413737,0.38142309089501697,0.3771870930989583,0.3729840914408366,0.3688130850593249,0.36467008541027707,0.36055508504311246,0.3564670855800311,0.3524050811926524,0.348366084198157,0.3443510855237643,0.34035708010196686,0.3363830844561259,0.3324280728896459,0.32849307854970294,0.3245760773619016,0.3206780751546224,0.31679607679446536,0.3129320740699768,0.3090810750921567,0.3052450666824977,0.30142507205406827,0.297619067132473,0.2938280676801999,0.29005106290181476,0.2862870668371518,0.28253306945164997,0.278793066740036,0.2750650644302368,0.27134906500577927,0.26764506101608276,0.2639520640174548,0.260271059970061,0.2565980652968089,0.2529360627134641,0.24928505470355353,0.24564405779043832,0.24201305955648422,0.23839205503463745,0.2347810554007689,0.23117605596780777,0.22758105273048082,0.2239950547615687,0.2204180508852005,0.2168500485519568,0.2132900506258011,0.20973904927571616,0.20619304850697517,0.20265504717826843,0.19912604739268622,0.19560404370228449,0.19208904604117075,0.1885820428530375,0.1850830428302288,0.18158804376920065,0.17810004328687987,0.174619040141503,0.171144038438797,0.1676770361761252,0.16421503573656082,0.1607600376009941,0.1573090354601542,0.15386503438154855,0.15042603264252344,0.14699303234616914,0.14356603100895882,0.14014202977220216,0.13672402873635292,0.13331202790141106,0.12990502764781317,0.12650302611291409,0.12310702602068584,0.11971502440671127,0.11632602413495381,0.11294202382365863,0.10956302161018054,0.10618902121980985,0.1028200201690197,0.09945451902846496,0.09609381854534149,0.09273521726330121,0.08938091682891051,0.08603101658324401,0.08268531411886215,0.07934361385802428,0.07600591331720352,0.07267201195160548,0.06933960939447086,0.06601121090352535,0.0626866091042757,0.05936560779809952,0.056048307878275715,0.052734406354526676,0.04942390539993843,0.046114504958192505,0.04280860380580028,0.0395061019808054,0.036206901694337525,0.03291080115983883,0.029617799911648035,0.026327800160894792,0.023230400246878464,0.02049509979163607,0.01808010010669629,0.015948099782690406,0.014066300044457117,0.012405699972684184,0.010940299990276495,0.009647310012951493,0.008506650027508536,0.007500449971606334,0.006612920008289318,0.005830139969475567,0.0051398000214248896,0.004531020065769553,0.003994199990605314,0.0035208499951598546,0.0031035099915849664,0.0027355599837998548,0.0024111599777825177,0.002125189988873899,0.001873079997797807,0.0016508500072328995,0.0014549600115666788,0.0012822799908462912,0.0011300799960736185,0.0009959330006192129,0.0008776939988213902,0.0007734819907151783,0.00068163401253211,0.0006006859960810592,0.0005293439947611963,0.00046647100437742967,0.0004110610000983191,0.00036222899992329377,0.00031919499694292125,0.00028127200494054705,0.00024785200124218437,0.00021840100089320913,0.00019244799962810552,0.00016957799986509295,0.00014942399987679286,0.00013166500017784225,0.00011601599908317439,6.957744578054796e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050151189168293,22.259799003601074,22.128499031066895,22.12489938735962,22.090399265289307,22.030299186706543,21.948999404907227,21.834698994954426,21.677599271138508,21.48639949162801,21.26819944381714,21.029099305470783,20.753599484761555,20.428899606068928,20.06559944152832,19.672799428304035,19.25809971491496,18.80839951833089,18.312899748484295,17.782899856567383,17.22749948501587,16.654799620310467,16.07159972190857,15.483399868011475,14.895099639892578,14.310499906539917,13.732799768447876,13.163399934768677,12.60290002822876,12.053599993387857,11.517299969991049,10.995300054550171,10.488699913024902,9.998200019200643,9.524319887161255,9.067409912745157,8.627609968185425,8.20505984624227,7.799789945284526,7.4115599393844604,7.040059924125671,6.684929966926575,6.345750013987224,6.022079944610596,5.713430047035217,5.419290026028951,5.139169971148173,4.872529943784078,4.618849992752075,4.3776200612386065,4.14831002553304,3.9304400086402893,3.723489999771118,3.5269999901453652,3.3404799501101174,3.163479963938395,2.9955599904060364,2.8362900217374167,2.6852500240008035,2.5420599778493247,2.4063300093015036,2.277679979801178,2.1557799776395163,2.040279984474182,1.930860012769699,1.8272099892298381,1.7290399968624115,1.636050005753835,1.5479599833488464,1.4645199875036876,1.3854900101820629,1.310640017191569,1.2397599915663402,1.1726399958133698,1.1090799967447917,1.0488999982674916,0.9919329881668091,0.9380040069421133,0.8869550029436747,0.8386369943618774,0.7929080029328665,0.749627004067103,0.7086680084466934,0.6699089954296747,0.6332370042800903,0.5985410014788309,0.5662649969259897,0.5362870047489802,0.5079390108585358,0.4811279997229576,0.4557649989922841,0.4317700018485387,0.4090690016746521,0.38759200026591617,0.36726799855629605,0.3480389987428983,0.329844002922376,0.3126249959071477,0.29633300254742306,0.2809169987837474,0.26632799456516904,0.2525230000416438,0.23946099976698557,0.22710400074720383,0.21540999909241995,0.20434699952602386,0.19388199970126152,0.18397999927401543,0.1746109997232755,0.16574900100628534,0.15736699973543486,0.14943699911236763,0.14193599919478098,0.13484299927949905,0.12813199932376543,0.12178600020706654,0.11578499960402648,0.11010699967543285,0.10473699929813544,0.09965770008663337,0.09485529859860738,0.09031179919838905,0.08601570005218188,0.08195329954226811,0.07810959902902444,0.07447259997328122,0.07103339893122514,0.06778109880785148,0.06470309942960739,0.06179209922750791,0.059038899218042694,0.05643249892940124,0.05396469961851835,0.0516301995764176,0.04942169971764088,0.04732959934820732,0.04534999933093786,0.04347639996558428,0.04170079932858547,0.040019799334307514,0.03842819947749376,0.036918699741363525,0.035486599430441856,0.03412979965408643,0.03284429976095756,0.03162349946796894,0.03046619954208533,0.02936869968349735,0.028325399694343407,0.027333099395036697,0.026391299751897652,0.02549719934662183,0.024645599847038586,0.02383649970094363,0.023067399859428406,0.022333699588974316,0.021635799513508875,0.020971599655846756,0.020336799478779238,0.019729599667092163,0.019150999529908102,0.01859919959679246,0.01807029964402318,0.01756539971878131,0.017083099422355492,0.01661979981387655,0.016174299487223227,0.01574789957764248,0.015339699573814869,0.014945999641592303,0.01456859971707066,0.014206399753068885,0.0138561997252206,0.013519599723319212,0.013195899703229466,0.012881999757761756,0.012577299727126956,0.012283599625031153,0.012000399641692638,0.011724499752745032,0.011457999780153235,0.011200399758915106,0.010948699666187167,0.010702599848931035,0.010464099701493979,0.010232899881278476,0.010006099784125885,0.009785779829447469,0.009571649599820375,0.009360979699219266,0.009155899751931429,0.008956109639257193,0.008758939880256852,0.008564249922831854,0.008374249873061975,0.0081886798919489,0.008004919781039158,0.007825229743806025,0.007649369809466104,0.0074747698769594235,0.007301379887697597,0.0071314698628460365,0.006964849929014842,0.006798979826271534,0.006636169855482876,0.006476239805730681,0.0063166798402865725,0.006157489842735231,0.006000989815220237,0.005847039865329862,0.005693129884699981,0.005541619883539776,0.005392379903544982,0.005242919937397043,0.005095619902325173,0.004950349917635322,0.004804659828854104,0.0046585598805298405,0.004514459947434564,0.004372219981936117,0.004229399880083899,0.004088399892983337,0.00394908986830463,0.003809039966048052,0.003668309946078807,0.003529289950771878,0.0033918899522783854,0.003253649939627697,0.003116999966247628,0.002981829942048838,0.0028457099882264933,0.0027110699641828737,0.0025778000126592815,0.002443499998965611,0.002308219962287694,0.0021743900142610073,0.0020419099795011184,0.0019130199992408354,0.0017921599986342092,0.0016788399952929467,0.0015725999934754025,0.001473020005505532,0.0013796899972173076,0.0012922100043700386,0.0012102400069124997,0.0011334300118808944,0.0010614600032567978,0.000994039000943303,0.0009308709947314734,0.000871696999335351,0.0008162669885981207,0.0007643450080649927,0.00071571299728627,0.0006701629948414242,0.0006275029930596551,0.0005875490023754537,0.0005501309933606535,0.0005150899960426614,0.00048227500277183327,0.000451545000638968,0.0004227699998106497,0.0003958240001035544,0.00037059199773163226,0.0003469660005066544,0.00032484399950286996,0.0003041299933101982,0.00028473400258614373,0.00026657399818456423,0.00024957099958555773,0.000233650998173592,0.0002187449984679309,0.0002047889999327405,0.00019172300138355544,0.00017948899888627542,0.00016803500087310871,0.00015731200134420456,0.00014727200080718225,0.0001378720007778611,0.00012907200046659759,0.00012083399875943239,0.00011311999999937446,0.00010589899951204036,3.377092131510532e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.6953557332357,237.72884623209634,240.96188100179037,243.3929125467936,245.07293574015299,246.1749496459961,246.83200709025064,246.44208145141602,244.59511057535806,241.73414103190103,238.19415028889975,234.2322006225586,229.3392702738444,223.16629028320312,216.1813112894694,208.73430887858072,201.08934783935547,192.78440602620444,183.498415629069,173.6694196065267,163.62241872151694,153.59440739949545,143.75839487711588,134.2353744506836,125.10435612996419,116.41933631896973,108.20831807454427,100.43230438232422,93.05358568827312,86.09246762593587,79.55525016784668,73.4390328725179,67.73441696166992,62.42730172475179,57.500386238098145,52.93457190195719,48.709659258524574,44.80604648590088,41.20403512318929,37.883124669392906,34.82351462046305,32.006405671437584,29.413596947987873,27.02838929494222,24.834781964619953,22.817875385284424,20.963969548543293,19.26016362508138,17.694358507792156,16.255653699239094,14.933749437332153,13.719345410664877,12.603741804758707,11.578938404719034,10.637535254160563,9.772792100906372,8.978439569473267,8.248777190844217,7.578525026639302,6.96284294128418,6.397281130154927,5.87774936358134,5.400487860043843,4.962046305338542,4.559265057245891,4.189233819643657,3.8492727080980935,3.536881665388743,3.249760707219442,2.9858698646227517,2.743329028288523,2.5203983585039773,2.315507650375366,2.1271770199139914,1.9540964563687642,1.795015941063563,1.6488054792086284,1.5144350131352742,1.390954613685608,1.2774742345015209,1.173193911711375,1.0773735741774242,0.9893252948919932,0.9084170162677765,0.8340757787227631,0.7657735298077265,0.7033183177312216,0.6462221393982569,0.5937019685904185,0.5453798025846481,0.5009386613965034,0.46008452276388806,0.42252740263938904,0.38797029356161755,0.35619719078143436,0.32698308924833935,0.30011900266011554,0.27541792144378024,0.25270284960667294,0.23184177527825037,0.21268571416536966,0.19506865863998732,0.17886660248041153,0.1639935535689195,0.15034150953094164,0.13781146705150604,0.12631242784361044,0.11576239267985027,0.10608336329460144,0.09717683307826519,0.08898130680123965,0.08146557956933975,0.07457425693670909,0.06825643529494603,0.0624652144809564,0.057157497542599835,0.052293480994800724,0.04783696557084719,0.04375415233274301,0.04001443926244974,0.03658952719221512,0.03345321615537008,0.030581706824402016,0.02795289767285188,0.025546889286488295,0.02334488198782007,0.021329874948908884,0.01948636832336585,0.017799962777644396,0.01625745720230043,0.014846852282062173,0.013556947776426872,0.012377543762947122,0.011299440171569586,0.010314036548758546,0.009413473308086395,0.008590530526513854,0.007838627827974657,0.007151725352741778,0.006524293256613116,0.00595124124083668,0.005427929378735523,0.004950107734960814,0.004513856101160248,0.004115614768428107,0.0037521234480664134,0.0034203822530495622,0.003117651193557928,0.002841430250555277,0.002589419348320613,0.002359538533103963,0.0021498477435670793,0.0019586071042188755,0.0017842064359380554,0.0016251858808876325,0.0014801953511778265,0.0013480248744599521,0.0012275444557114195,0.0011177340444798272,0.0010176537034567446,0.0009264513694991668,0.0008433530601905659,0.0007676427873472372,0.0006986715355499958,0.0006358433165587485,0.0005786191128815213,0.0005265019232562432,0.00047904075230083737,0.000435823591639443,0.00039647444888638955,0.0003606513176540223,0.00032803919990935054,0.0002983540956241389,0.0002713349992215323,0.00024674490608352545,0.00022436682411353104,0.00020400474750204012,0.00018547668150858954,0.00016861961921676993,0.00015328456477921767,0.00013933451312671727,0.0001266454679959376,0.00011510442527651321,0.00010460838590612791,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527326901753745,3.5471805731455484,3.4357704718907676,3.3270804484685264,3.216950456301371,3.106110473473867,2.995190461476644,2.884720424811045,2.7751904328664145,2.6669804056485495,2.5604504545529685,2.4558804035186768,2.353520393371582,2.253550370534261,2.1561403473218284,2.061410347620646,1.9694603284200032,1.880370318889618,1.7941603064537048,1.7108702957630157,1.6305202941099803,1.5530802706877391,1.4785602589448292,1.4069002668062847,1.338080237309138,1.2720402379830678,1.2087302207946777,1.1480802297592163,1.0900401969750722,1.0345301926136017,0.9814761877059937,0.9308091749747595,0.8824491699536642,0.8363231619199117,0.792352149883906,0.7504581461350123,0.7105641414721807,0.6725951333840688,0.6364741226037344,0.6021271099646887,0.5694831162691116,0.5384710977474848,0.5090211058656374,0.4810640960931778,0.4545350894331932,0.42937008539835614,0.4055080811182658,0.38289107630650204,0.36145907392104465,0.34115506956974667,0.32192806154489517,0.30372605969508487,0.2864980523784955,0.2701990579565366,0.25478005533417064,0.24019904807209969,0.22641304632027945,0.21338304380575815,0.2010700429479281,0.18943703919649124,0.17844903593262038,0.16807303701837858,0.15827403217554092,0.1490260325372219,0.14029802878697714,0.1320620266099771,0.12429302682479222,0.1169650238007307,0.11005402232209842,0.10353902168571949,0.09739561999837558,0.09160471893846989,0.08614801863829295,0.08100641705095768,0.07616191481550534,0.07159951453407605,0.06730351472894351,0.06325721275061369,0.05944671264539162,0.0558609114959836,0.05248561097929875,0.049307710491120815,0.04631840996444225,0.043505809580286346,0.04085890855640173,0.03836900802950064,0.0361134068419536,0.03406510688364506,0.03212910673270623,0.030298506220181782,0.02856650622561574,0.026927005654821794,0.025374305279304583,0.02392030491804083,0.022541404701769352,0.021232804438720148,0.020007503995050985,0.01884300432478388,0.017735303690036137,0.016698303477217753,0.015727603031943243,0.014818902981157104,0.013950803006688753,0.013120902779822549,0.012344202802826961,0.0116171024274081,0.01093670236878097,0.01029990209887425,0.009703991934657097,0.009128892018149296,0.008573321780810753,0.008053461710611979,0.007567021568926672,0.007111891522072256,0.00668604140325139,0.006287621334195137,0.005914861219935119,0.005566121079027653,0.005239871175338824,0.004934670946871241,0.004649150961389144,0.00438207093005379,0.004132230766117573,0.0038985408027656376,0.0036625308566726744,0.0034243907624234757,0.0032016607195449374,0.002993350673932582,0.0027985306029828885,0.0026163405661160746,0.0024459605532077453,0.0022866305274267993,0.002137630460007737,0.00199830046040006,0.0018680204132882257,0.0017462004034314305,0.0016322903781353186,0.00152578034127752,0.001426190302784865,0.0013330902923674632,0.001246030277494962,0.0011646402708720416,0.001088550256099552,0.0010174202325288206,0.0009509112181452414,0.0008887391983686636,0.0008306181892597427,0.0007762851746520028,0.0007254951633512974,0.0006780181574868038,0.000633637139496083,0.0005921531410422176,0.0005533761286642402,0.0005171311252828067,0.00048325310975390795,0.000451588098561236,0.0004219910964214553,0.0003943290891281019,0.00036847608134848997,0.00034431207556432736,0.00032172907231142744,0.0003006240658578463,0.00028089906360643607,0.00026246505876770243,0.00024523805526162806,0.00022913905316575742,0.00021409404992785616,0.00020003504444806217,0.00018689604257815517,0.00017461903917137533,0.00016314603756958,0.0001524260345225533,0.00014240803405603705,0.00013304803239104027,0.00012430102712338945,0.00011612802578990038,0.00010849202408280689,6.832991311966907e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844176292419434,3.2989591360092163,3.304409146308899,3.307799200216929,3.30922923485438,3.3087992866834006,3.306599259376526,3.302719295024872,3.297249356905619,3.2902593413988748,3.2818293968836465,3.2720394134521484,3.2609594464302063,3.2486594518025718,3.2352094451586404,3.2206694881121316,3.2051095366477966,3.1885695258776345,3.171119530995687,3.1528095801671348,3.133689602216085,3.113809605439504,3.0932196180025735,3.0719696283340454,3.050089657306671,3.02763960758845,3.0046496589978537,2.981149673461914,2.957189679145813,2.9328096906344094,2.9080296754837036,2.882889707883199,2.857419768969218,2.8316497206687927,2.8055997490882874,2.779299775759379,2.752789795398712,2.726079781850179,2.6991997957229614,2.672169804573059,2.6449997822443643,2.6177298029263816,2.5903698007265725,2.5629398226737976,2.535459836324056,2.5079498489697776,2.480409840742747,2.4528698523839316,2.425339857737223,2.3978298703829446,2.370369831720988,2.34294984738032,2.3155899047851562,2.288309892018636,2.2611098686854043,2.2340099016825357,2.2070098916689553,2.1801199118296304,2.1533498962720237,2.1267098983128867,2.100209911664327,2.073849896589915,2.0476399064064026,2.021589994430542,1.995709906021754,1.96998992562294,1.944449911514918,1.919089913368225,1.8939099311828613,1.8689199487368267,1.8441199362277985,1.819519927104314,1.7951099475224812,1.7709099352359772,1.7469099561373393,1.7231299380461376,1.699549953142802,1.6761899590492249,1.653039942185084,1.6300999621550243,1.6073899666468303,1.5848899682362874,1.562619944413503,1.540559967358907,1.5187299748261769,1.4971199929714203,1.474970002969106,1.4523099760214488,1.4299599925676982,1.40789998571078,1.3861300150553386,1.3646500011285145,1.3434699773788452,1.322579989830653,1.3019700050354004,1.2816200057665508,1.2615499993165333,1.2417799929777782,1.2222799956798553,1.2030500173568726,1.184089998404185,1.16539000471433,1.1469700038433075,1.1288000047206879,1.110889991124471,1.093249996503194,1.0758499801158905,1.0586999853452046,1.0418099959691365,1.0251700083414714,1.0087699989477794,0.9925920019547144,0.9766659835974375,0.9609839916229248,0.9455420027176539,0.9303169995546341,0.9153069953123728,0.9005290071169535,0.8859779983758926,0.8716529955466589,0.8575500001509985,0.8436459948619207,0.8299379994471868,0.8164439996083578,0.8031609952449799,0.7900849878787994,0.7772130022446314,0.7645440051952997,0.7520729899406433,0.7397980044285456,0.727715993920962,0.7158049990733465,0.7040629982948303,0.6925050020217896,0.6811310003201166,0.6699369996786118,0.6589209934075674,0.6480790028969446,0.6374100049336752,0.6269109894831976,0.6165799995263418,0.6064129968484243,0.59640900293986,0.5865650027990341,0.5768789996703466,0.5673479984203974,0.557969997326533,0.5487429946660995,0.5396639953056971,0.530730997522672,0.5219430029392242,0.5132959932088852,0.5047889898220698,0.49640000114838284,0.4881269956628482,0.4799869979421298,0.4719800030191739,0.46410299837589264,0.45635399719079334,0.4487309977412224,0.44123200327157974,0.43385499715805054,0.42659800002972287,0.4194600035746892,0.4124390011032422,0.40553199996550876,0.398738997677962,0.39205600321292877,0.3854829967021942,0.37901799629131955,0.37265899777412415,0.3664050002892812,0.3602530012528102,0.354203000664711,0.34825199842453003,0.3423989986379941,0.3366429979602496,0.33098100622495014,0.3254129985968272,0.31993699570496875,0.3145519991715749,0.30925599733988446,0.30404700835545856,0.2989250024159749,0.29388799766699475,0.28893399735291797,0.2840620030959447,0.2792709991335869,0.27455999950567883,0.2699270000060399,0.26537200063467026,0.26089199632406235,0.2564860035975774,0.25215499848127365,0.24789499988158545,0.24370599910616875,0.23958799863855043,0.23553799962004027,0.23155500118931135,0.22763999799887338,0.22378999988238016,0.22000399976968765,0.21628200138608614,0.21262199928363165,0.2090230012933413,0.20548399910330772,0.20200500016411146,0.19858500237266222,0.19522200028101602,0.19191499799489975,0.18866400172313055,0.18546700105071068,0.1823250005642573,0.17923500016331673,0.1761969986061255,0.17320999999841055,0.17027399813135466,0.16738699997464815,0.16454900056123734,0.16175800065199533,0.1590149998664856,0.15631799896558127,0.15366699919104576,0.15106000130375227,0.14849700033664703,0.14597800249854723,0.143500999857982,0.14106599862376848,0.1386719991763433,0.13631900027394295,0.1340059998134772,0.13173200065890947,0.12949599822362265,0.12729799871643385,0.12513799779117107,0.1230139999339978,0.12092599955697854,0.1188730001449585,0.11685600007573764,0.1148720004906257,0.11292299938698609,0.11100599976877372,0.10912299963335197,0.10727100012203057,0.10544999813040097,0.10366100072860718,0.10190199998517831,0.10017300024628639,0.09847320057451725,0.09680239980419476,0.09515989944338799,0.0935454008479913,0.09195820055902004,0.09039809989432494,0.08886439974109332,0.08735670025149982,0.08587469967703025,0.08441779948771,0.08298559921483199,0.08157780021429062,0.08019380023082097,0.07883339934051037,0.07749599901338418,0.07618139994641145,0.07488899988432725,0.07361859952410062,0.07236979963878791,0.0711421010394891,0.06993530007700126,0.0687489000459512,0.06758270102242629,0.06643630005419254,0.06530929977695148,0.06420150026679039,0.06311240047216415,0.0620418998102347,0.060989500023424625,0.0599548996736606,0.05893789945791165,0.05793819949030876,0.056955400543908276,0.05598930021127065,0.05503959984829029,0.05410599956909815,0.05318820010870695,0.0522859999909997,0.05139920022338629,0.050527299754321575,0.049670299825568996,0.04882779996842146,0.04799959994852543,0.04718540081133445,0.04638510011136532,0.04559830048431953,0.04482490010559559,0.04406460002064705,0.04331720030556122,0.042582499794662,0.04186029980580012,0.041150299832224846,0.04045230026046435,0.03976619988679886,0.03909170006712278,0.038428700218598046,0.037776900455355644,0.03713620019455751,0.03650640013317267,0.03588720038533211,0.035278600019713245,0.034680200119813286,0.03409200037519137,0.033513800241053104,0.03294549975544214,0.032386700001855694,0.031837400048971176,0.031297500090052686,0.03076670008401076,0.030244899913668633,0.029731999927510817,0.029227800201624632,0.028732100035995245,0.028244799779107172,0.02776580008988579,0.02729500023027261,0.02683210000395775,0.02637699960420529,0.025929699807117384,0.025490000067899626,0.025057699996978045,0.0246327999047935,0.02421509986743331,0.0238044997677207,0.023400799836963415,0.023004000075161457,0.022613900092740852,0.02223040008296569,0.021853500045835972,0.02148289994026224,0.02111860007668535,0.020760499872267246,0.020408499985933304,0.020062499834845465,0.019722299960752327,0.01938790005321304,0.019059100188314915,0.018736000017573435,0.018418299810340006,0.018106000187496345,0.0177990001005431,0.017497200053185225,0.01720060020064314,0.016908900036166113,0.01662219998737176,0.016340400092303753,0.016063400233785313,0.015791000022242468,0.015523299962903062,0.015260199938590327,0.015001399985825023,0.014747099950909615,0.01449710006515185,0.0142512999009341,0.014009700001527866,0.013772199939315518,0.013538800102348128,0.013309199983874956,0.013083600051080188,0.012861800147220492,0.012643800039465228,0.012429500076298913,0.012218799985324344,0.012011699999372164,0.011807999884088835,0.011607899951438109,0.011411100005110105,0.011217700007061163,0.011027600072945157,0.010840700007975101,0.010656900005415082,0.010476299949611226,0.010298699994261066,0.0101241998684903,0.009952559989566604,0.009783879931395253,0.009618050030743083,0.009455039942016205,0.009294799994677305,0.009137269963199893,0.008982419967651367,0.008830190092946092,0.008680540136992931,0.00853342997531096,0.008388820104300976,0.008246659999713302,0.008106899991010627,0.00796951997714738,0.007834470054755608,0.0077017099829390645,0.007571200064073007,0.007442909991368651,0.00731679005548358,0.007192810027239223,0.007070930014985303,0.0069511099718511105,0.006833329990816613,0.006717550025011103,0.006603729949953656,0.006491840002126992,0.006381849913547437,0.006273720025395353,0.006167430003794531,0.0060629399958997965,0.005960220005363226,0.005859239997031788,0.005759970013362666,0.0056623900309205055,0.005566460041639705,0.005472160022084911,0.0053794600535184145,0.0052883299843718605,0.00519874005112797,0.005110680009238422,0.005024100032945474,0.004939000005833805,0.004855330024535458,0.00477308997263511,0.004692240036092699,0.004612759958642225,0.004534629988484085,0.004457820012855033,0.004382310008319716,0.0043080900407706695,0.004235120063337187,0.004163389947886269,0.0040928799426183105,0.004023559973575175,0.0039554099785164,0.0038884199651268623,0.0038225700069839754,0.003757830010727048,0.003694190022846063,0.0036316299811005592,0.0035701300172756114,0.0035096799644331136,0.003450240008533001,0.003391820025475075,0.0033343799877911806,0.00327792001189664,0.0032224099850282073,0.003167849984796097,0.0031142100148523846,0.003061479985869179,0.003009639990826448,0.0029586799792014062,0.002908589997484038,0.0028593400105213127,0.002810929979508122,0.00276333997802188,0.00271655999434491,0.0026705700050418577,0.0026253499866773686,0.002580910009176781,0.0025372099868642786,0.002494260009067754,0.0024520399941441915,0.002410529957463344,0.0023697200037228563,0.0023296099582997463,0.0022901700382741788,0.002251409983728081,0.002213299992339065,0.002175829994181792,0.0021389999892562628,0.0021027999852473536,0.002067209997524818,0.002032219994968424,0.0019978199852630496,0.0019640100363176316,0.0019307699888789405,0.001898090005852282,0.0018659699999261647,0.0018343900058728952,0.0018033500042899202,0.0017728300008457154,0.0017428300246441115,0.0017279500316362828};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261276225248973,0.4188620373606682,0.4108490248521169,0.40350202719370526,0.3960900257031123,0.3886290242274602,0.3811350191632907,0.3736230209469795,0.36610501756270725,0.3585920160015424,0.3510950158039729,0.3436260173718135,0.3361920192837715,0.32880301773548126,0.32146801551183063,0.3141920144359271,0.3069830189148585,0.29984601338704425,0.2927880138158798,0.2858130137125651,0.2789250115553538,0.2721280058224996,0.26542600989341736,0.2588210105895996,0.2523170088728269,0.24591600894927979,0.23962001005808511,0.23343100771307945,0.22735000774264336,0.2213790069023768,0.21551900853713354,0.20976800844073296,0.20412900671362877,0.19860200583934784,0.19318600619832674,0.18788200865189233,0.1826890061299006,0.17760800446073213,0.17263600354393324,0.16777500386039415,0.16302200655142465,0.1583770029246807,0.1538390045364698,0.14940600345532098,0.1450780046482881,0.1408540035287539,0.13673100372155508,0.13271000236272812,0.12878800431887308,0.12496300352116425,0.12123400283356507,0.11760000449915727,0.11405900306999683,0.11060900365312894,0.10724900228281815,0.10397800306479137,0.10079300155242284,0.09769440193970998,0.09467870183289051,0.09174440056085587,0.08888990183671315,0.08611350071926911,0.08341470112403233,0.08079190117617448,0.0782424012819926,0.07576480135321617,0.07335770130157471,0.07101850087443988,0.068746001770099,0.06653900134066741,0.06439630128443241,0.06231660054375728,0.06029790143171946,0.058337802067399025,0.05643540093054374,0.054589900809029736,0.05279910067717234,0.05106230018039545,0.049378600902855396,0.04774610077341398,0.04616300047685703,0.044627600659926735,0.04313910069564978,0.04169720131903887,0.04029990080744028,0.03894589996586243,0.03754249991228183,0.0360962999984622,0.03470440053691467,0.03336490038782358,0.032075799691180386,0.030835400025049847,0.02964189974591136,0.028493499848991632,0.027388599856446188,0.026325700028489035,0.025303100235760212,0.024319299962371588,0.023373099820067484,0.022462899951885145,0.021587399921069544,0.02074540002892415,0.01993569980065028,0.019156899768859148,0.018407899886369705,0.017687800029913586,0.016995299917956192,0.0163294003965954,0.015689099750791986,0.015073600069930157,0.014481800065065423,0.013912800000980496,0.013365799949193994,0.012840000058834752,0.012334499973803759,0.011848699999973178,0.011381700014074644,0.010932800049583117,0.010501299984753132,0.010086699932192763,0.009688139970724782,0.009305139848341545,0.00893708000270029,0.00858336997528871,0.008243479998782277,0.007916869944892824,0.007603029953315854,0.007301470031961799,0.007011729991063476,0.006733339939576884,0.006465870072133839,0.006208900013007224,0.005962010007351637,0.005724839904966454,0.005496989974441628,0.005278099949161212,0.005067839946908255,0.0048658600232253475,0.004671839997172356,0.004485480021685362,0.0043064800556749105,0.004134539980441332,0.003969400015193969,0.003810800010493646,0.0036584599680888155,0.0035121600182416537,0.0033716500426332154,0.003236719989217818,0.003107129984224836,0.0029826899990439415,0.0028631800087168813,0.0027484200157535574,0.002638220030348748,0.002532409989119818,0.0024307999992743134,0.002333229989744723,0.0022395499981939793,0.0021496100234799087,0.002063240002219876,0.0019803200072298446,0.0019007099908776581,0.0018242699831413727,0.0017508900006456922,0.0016804300054597359,0.001612790006523331,0.001547860010759905,0.0014855199939726542,0.00142567998652036,0.0013682300050277263,0.0013130799925420433,0.0012601399697208155,0.0012093200057279319,0.0011605399971206982,0.0011137100130630035,0.0010687700026513387,0.0010256199942280848,0.000984208988181005,0.0009444600000279024,0.0009063080118115371,0.0008696879958733916,0.0008345410072555145,0.0008008070047556733,0.0007684289982231954,0.0007373539895828193,0.0007075299993933489,0.0006789069933195909,0.0006514359993161634,0.0006250719986079881,0.0005997700015238175,0.0005754880063856641,0.0005521849961951375,0.000529820991990467,0.0005083599971840158,0.00048776499897940084,0.00046799999836366624,0.00044903399975737557,0.0004308339994167909,0.00041336800253096345,0.00039660899589459103,0.00038052600090547156,0.0003650940003960083,0.0003502850037572595,0.0003360760019859299,0.00032244099808546406,0.0003093570000298011,0.0002968029972786705,0.00028475699946284294,0.0002731990025495179,0.0002621080032743824,0.0002514670001498113,0.0002412570005011124,0.00023146000118382895,0.0002220599963038694,0.00021304199981386773,0.00020438800129340962,0.00019608600026307008,0.0001881199981047151,0.00018047699995804578,0.00017314400126148635,0.00016610900032295225,0.0001593589986441657,0.00015288299740253328,0.00014667000020078072,0.00014070899972769743,0.0001349889971606899,0.0001295020010729786,0.0001242379997468864,0.00011918800009880215,0.00011434299995016772,0.00010969400015407398,0.0001052350004708084,7.610849267318069e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.17952219645184,329.0759760538737,329.7909749348958,330.5649719238281,331.3559748331706,332.1639760335286,332.98897043863934,333.82997639973956,334.68397267659503,335.5519714355469,336.4319763183594,337.3269755045573,338.2339680989583,339.1539713541667,340.08797454833984,341.03396860758465,341.99297587076825,342.96296946207684,343.9409688313802,344.92797597249347,345.9239730834961,346.927973429362,347.94097391764325,348.9619725545247,349.990971883138,351.02896881103516,352.0749740600586,353.1279754638672,354.1869710286458,355.25297292073566,356.32496643066406,357.4029719034831,358.4869740804036,359.5769678751628,360.6739756266276,361.7759704589844,362.88397216796875,363.9979731241862,365.11597442626953,366.23797098795575,367.3639729817708,368.4949722290039,369.62997182210285,370.7699737548828,371.91297403971356,373.0609715779622,374.2119649251302,375.3679707845052,376.52797444661456,377.6909713745117,378.85797119140625,380.02797444661456,381.2029673258464,382.3799743652344,383.56197357177734,384.7469711303711,385.93496958414715,387.12696838378906,388.3219680786133,389.5199712117513,390.7209701538086,391.92397054036456,393.13096872965497,394.3409678141276,395.55296325683594,396.7689692179362,397.9869689941406,399.2079671223958,400.43397267659503,401.66297149658203,402.89697265625,404.1339696248372,405.3749643961589,406.6199696858724,407.8679682413737,409.1199671427409,410.37596893310547,411.63597106933594,412.89796956380206,414.1649653116862,415.43397013346356,416.7069676717122,417.98197174072266,419.26097361246747,420.5439707438151,421.82896677652997,423.1169687906901,424.3999710083008,425.6689707438151,426.9249725341797,428.16597239176434,429.3939717610677,430.6079737345378,431.80897013346356,432.99596913655597,434.1699701944987,435.3309733072917,436.4789733886719,437.6139729817708,438.73597208658856,439.8459701538086,440.9419682820638,442.02696990966797,443.0989710489909,444.15797424316406,445.20597585042316,446.240971883138,447.26497141520184,448.2759730021159,449.2759730021159,450.26397196451825,451.23997497558594,452.20497131347656,453.15797170003253,454.1009699503581,455.0309753417969,455.9509735107422,456.85997772216797,457.75797271728516,458.6449737548828,459.5209732055664,460.38697306315106,461.24097442626953,462.08597564697266,462.91997782389325,463.7439778645833,464.5569814046224,465.35997517903644,466.15297444661456,466.93697357177734,467.70997365315753,468.4729766845703,469.22697194417316,469.9709777832031,470.7059733072917,471.4309768676758,472.1459782918294,472.8519744873047,473.5489730834961,474.23697662353516,474.91597239176434,475.58497365315753,476.24597422281903,476.8979721069336,477.5409749348958,478.1749750773112,478.7999725341797,479.41697184244794,480.02598063151044,480.6259765625,481.2169774373372,481.8009796142578,482.37597910563153,482.9419759114583,483.50097401936847,484.0519790649414,484.594975789388,485.1289774576823,485.65597279866535,486.1759745279948,486.68697357177734,487.19097900390625,487.6869761149089,488.1759770711263,488.65797932942706,489.1309763590495,489.5979766845703,490.0569814046224,490.50997670491535,490.9549814860026,491.3929799397786,491.82298533121747,492.2469762166341,492.66397857666016,493.0749791463216,493.4779764811198,493.8749771118164,494.2649790445964,494.6479771931966,495.0249786376953,495.3949788411458,495.7589747111003,496.11597442626953,496.4679819742839,496.81197357177734,497.1509831746419,497.4829813639323,497.8099772135417,498.1299769083659,498.44397735595703,498.7519810994466,499.0539779663086,499.3509775797526,499.64097849527997,499.9259770711263,500.20497639973956,500.4789810180664,500.74598185221356,501.0079803466797,501.2649790445964,501.51598103841144,501.76198323567706,502.0019836425781,502.23698170979816,502.4669774373372,502.6909764607747,502.90997823079425,503.1239776611328,503.3329798380534,503.53698476155597,503.73598225911456,503.9299850463867,504.1179835001628,504.30198160807294,504.4809850056966,504.6559804280599,504.8249791463216,504.98998260498047,505.1499837239583,505.3049825032552,505.4559809366862,505.6019821166992,505.74298095703125,505.8809814453125,506.0129801432292,506.14098103841144,506.26498158772785,506.3849792480469,506.4999821980794,506.6109848022461,506.71697998046875,506.81998443603516,506.91797892252606,507.0119806925456,507.1019821166992,507.187983194987,507.26998138427734,507.34998321533203,507.4289805094401,507.50697835286456,507.58497619628906,507.6619822184245,507.7389831542969,507.81497955322266,507.88998158772785,507.96497853597003,508.03897857666016,508.11298116048175,508.1859842936198,508.25797780354816,508.3299789428711,508.40198008219403,508.4719772338867,508.54298400878906,508.61198170979816,508.6819788614909,508.74997965494794,508.81798553466797,508.88597869873047,508.95298258463544,509.0189793904622,509.08498128255206,509.1509780883789,509.21598561604816,509.27998606363934,509.34398396809894,509.40797932942706,509.46998087565106,509.5329818725586,509.59498596191406,509.6559829711914,509.71698506673175,509.7779820760091,509.83797963460285,509.896977742513,509.9559783935547,510.01498158772785,510.07298278808594,510.1299819946289,510.187983194987,510.24398040771484,510.30098215738934,510.3569819132487,510.41197713216144,510.4669774373372,510.52098083496094,510.5749791463216,510.6289825439453,510.6819814046224,510.7349853515625,510.7879816691081,510.8399887084961,510.89098103841144,510.9419860839844,510.9929784138997,511.04298146565753,511.09297943115234,511.1429799397786,511.19198354085285,511.24098205566406,511.2889811197917,511.3369776407878,511.3849817911784,511.4319814046224,511.4789784749349,511.5259831746419,511.57198333740234,511.61798095703125,511.6629816691081,511.7079823811849,511.75298563639325,511.79698435465497,511.8409779866536,511.8849817911784,511.92797597249347,511.97098032633465,512.0139745076498,512.0559743245443,512.0979868570963,512.1389846801758,512.1809895833334,512.2219874064127,512.2619832356771,512.302978515625,512.3429768880209,512.3819834391276,512.4219767252604,512.4609832763672,512.4999847412109,512.5379842122396,512.5759836832682,512.6139831542969,512.6519724527994,512.6889801025391,512.7259826660156,512.7629852294922,512.7989807128906,512.8349812825521,512.8709869384766,512.906972249349,512.9419860839844,512.9769846598307,513.0119984944662,513.0459798177084,513.0799763997396,513.1139780680338,513.1479899088541,513.1809844970703,513.2149861653646,513.2469838460287,513.2799784342448,513.3119812011719,513.3439890543619,513.375986735026,513.4079793294271,513.4389801025391,513.4699859619141,513.5009816487631,513.5319773356119,513.5619812011719,513.5929768880209,513.6229807535807,513.6519775390625,513.6819814046224,513.7109731038412,513.7399851481119,513.7689819335938,513.7969868977865,513.8259785970052,513.8539835611979,513.8819732666016,513.9099833170573,513.9369812011719,513.9639790852865,513.9909820556641,514.0179799397787,514.0449879964193,514.0709788004557,514.0979817708334,514.1239776611328,514.1489715576172,514.1749776204427,514.2009836832682,514.2259775797526,514.2509816487631,514.2759857177734,514.2999827067057,514.3249715169271,514.3489786783854,514.3729807535807,514.3969777425131,514.4209747314453,514.4449818929037,514.4679768880209,514.4909820556641,514.5139770507812,514.5369822184244,514.5599924723307,514.5819753011068,514.60498046875,514.6269887288412,514.6489868164062,514.6709849039713,514.6919911702474,514.7139790852865,514.7349853515625,514.7559865315756,514.7769826253256,514.7979787190756,514.8189798990885,514.8399759928385,514.8599853515625,514.8799896240234,514.8999837239584,514.9199778238932,514.9399871826172,514.9599812825521,514.9789835611979,514.9989878336588,515.0179748535156,515.0369771321615,515.0559844970703,515.0739695231119,515.0929768880209,515.1119842529297,515.1299794514974,515.1479797363281,515.1659749348959,515.1839853922526,515.2019805908203,515.219980875651,515.2369689941406,515.2549896240234,515.2719879150391,515.2889811197916,515.3059844970703,515.3229777018229,515.3399759928385,515.3569793701172,515.3729807535807,515.3899739583334,515.4059753417969,515.4219818115234,515.4379730224609,515.4539845784506,515.4699910481771,515.4859873453776,515.5009816487631,515.5169932047526,515.531982421875,515.5469818115234,515.5619862874349,515.5769755045573,515.5919799804688,515.6069793701172,515.6219736735026,515.6369832356771,515.6509857177734,515.6649831136068,515.6799875895182,515.6939849853516,515.7079823811849,515.7219848632812,515.7359924316406,515.7499796549479,515.7629801432291,515.7769826253256,515.7899780273438,515.8039906819662,515.8169759114584,515.8299865722656,515.8429819742838,515.8559773763021,515.8689778645834,515.8819834391276,515.8949839274088,515.906992594401,515.9199778238932,515.9319915771484,515.9449768066406,515.9569803873698,515.9689890543619,515.9809926350912,515.9929758707682,516.0049896240234,516.0109914143881};
}

void set_concs_ssp434() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.78215876,9.836893944,9.891629127,9.946364311,10.00109949,9.948060418,9.895021341,9.841982265,9.788943189,9.735904112,9.682865036,9.629825959,9.576786883,9.523747807,9.47070873,9.39545743,9.32020613,9.24495483,9.169703529,9.094452229,9.019200929,8.943949629,8.868698329,8.793447028,8.718195728,8.597430638,8.476665548,8.355900458,8.235135368,8.114370278,7.993605188,7.872840099,7.752075009,7.631309919,7.510544829,7.424306512,7.338068196,7.25182988,7.165591564,7.079353248,6.993114931,6.906876615,6.820638299,6.734399983,6.648161667,6.602461246,6.556760825,6.511060404,6.465359983,6.419659562,6.37395914,6.328258719,6.282558298,6.236857877,6.191157456,6.13475292,6.078348384,6.021943848,5.965539311,5.909134775,5.852730239,5.796325702,5.739921166,5.68351663,5.627112094,5.526632366,5.426152639,5.325672912,5.225193185,5.124713458,5.024233731,4.923754004,4.823274276,4.722794549,4.622314822,4.534801113,4.447287404,4.359773695,4.272259986,4.184746276,4.097232567,4.009718858,3.922205149,3.83469144,3.747177731,3.731596014,3.716014298,3.700432582,3.684850865,3.669269149,3.653687433,3.638105716,3.622524,3.606942284,3.591360568,3.575778851,3.560197135,3.544615419,3.529033702,3.513451986,3.49787027,3.482288553,3.466706837,3.451125121,3.435543404,3.419961688,3.404379972,3.388798255,3.373216539,3.357634823,3.342053106,3.32647139,3.310889674,3.295307958,3.279726241,3.264144525,3.248562809,3.232981092,3.217399376,3.20181766,3.186235943,3.170654227,3.155072511,3.139490794,3.123909078,3.108327362,3.092745645,3.077163929,3.061582213,3.046000496,3.03041878,3.014837064,2.999255348,2.983673631,2.968091915,2.952510199,2.936928482,2.921346766,2.90576505,2.890183333,2.874601617,2.859019901,2.843438184,2.827856468,2.812274752,2.796693035,2.781111319,2.765529603,2.749947886,2.73436617,2.718784454,2.703202738,2.687621021,2.672039305,2.656457589,2.640875872,2.625294156,2.60971244,2.594130723,2.578549007,2.562967291,2.547385574,2.531803858,2.516222142,2.500640425,2.485058709,2.469476993,2.453895276,2.43831356,2.422731844,2.407150128,2.391568411,2.375986695,2.360404979,2.344823262,2.329241546,2.31365983,2.298078113,2.282496397,2.266914681,2.251332964,2.235751248,2.220169532,2.204587815,2.189006099,2.173424383,2.157842666,2.14226095,2.126679234,2.111097518,2.095515801,2.079934085,2.064352369,2.048770652,2.033188936,2.01760722,2.002025503,1.986443787,1.970862071,1.955280354,1.939698638,1.924116922,1.908535205,1.892953489,1.877371773,1.861790056,1.84620834,1.830626624,1.815044908,1.799463191,1.783881475,1.768299759,1.752718042,1.737136326,1.72155461,1.705972893,1.690391177,1.674809461,1.659227744,1.643646028,1.628064312,1.612482595,1.596900879,1.581319163,1.565737446,1.55015573,1.534574014,1.518992298,1.503410581,1.487828865,1.472247149,1.456665432,1.441083716,1.425502,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283,1.409920283};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,35.02706045,35.30809667,35.58913289,35.87016911,36.15120534,36.24536023,36.33951513,36.43367003,36.52782492,36.62197982,36.71613472,36.81028961,36.90444451,36.99859941,37.09275431,37.08198566,37.07121702,37.06044837,37.04967973,37.03891108,37.02814244,37.01737379,37.00660515,36.9958365,36.98506786,36.7765987,36.56812954,36.35966038,36.15119122,35.94272206,35.7342529,35.52578374,35.31731458,35.10884542,34.90037626,34.71437037,34.52836447,34.34235858,34.15635269,33.9703468,33.78434091,33.59833502,33.41232912,33.22632323,33.04031734,33.0837645,33.12721167,33.17065883,33.21410599,33.25755316,33.30100032,33.34444748,33.38789465,33.43134181,33.47478898,33.37335302,33.27191707,33.17048112,33.06904517,32.96760922,32.86617327,32.76473732,32.66330137,32.56186542,32.46042947,31.89254305,31.32465664,30.75677022,30.18888381,29.62099739,29.05311097,28.48522456,27.91733814,27.34945173,26.78156531,26.31666716,25.851769,25.38687085,24.9219727,24.45707455,23.99217639,23.52727824,23.06238009,22.59748193,22.13258378,22.07784786,22.02311194,21.96837602,21.9136401,21.85890419,21.80416827,21.74943235,21.69469643,21.63996051,21.58522459,21.53048867,21.47575275,21.42101684,21.36628092,21.311545,21.25680908,21.20207316,21.14733724,21.09260132,21.0378654,20.98312948,20.92839357,20.87365765,20.81892173,20.76418581,20.70944989,20.65471397,20.59997805,20.54524213,20.49050622,20.4357703,20.38103438,20.32629846,20.27156254,20.21682662,20.1620907,20.10735478,20.05261887,19.99788295,19.94314703,19.88841111,19.83367519,19.77893927,19.72420335,19.66946743,19.61473152,19.5599956,19.50525968,19.45052376,19.39578784,19.34105192,19.286316,19.23158008,19.17684416,19.12210825,19.06737233,19.01263641,18.95790049,18.90316457,18.84842865,18.79369273,18.73895681,18.6842209,18.62948498,18.57474906,18.52001314,18.46527722,18.4105413,18.35580538,18.30106946,18.24633355,18.19159763,18.13686171,18.08212579,18.02738987,17.97265395,17.91791803,17.86318211,17.8084462,17.75371028,17.69897436,17.64423844,17.58950252,17.5347666,17.48003068,17.42529476,17.37055884,17.31582293,17.26108701,17.20635109,17.15161517,17.09687925,17.04214333,16.98740741,16.93267149,16.87793558,16.82319966,16.76846374,16.71372782,16.6589919,16.60425598,16.54952006,16.49478414,16.44004823,16.38531231,16.33057639,16.27584047,16.22110455,16.16636863,16.11163271,16.05689679,16.00216088,15.94742496,15.89268904,15.83795312,15.7832172,15.72848128,15.67374536,15.61900944,15.56427353,15.50953761,15.45480169,15.40006577,15.34532985,15.29059393,15.23585801,15.18112209,15.12638617,15.07165026,15.01691434,14.96217842,14.9074425,14.85270658,14.79797066,14.74323474,14.68849882,14.63376291,14.57902699,14.52429107,14.46955515,14.41481923,14.36008331,14.30534739,14.25061147,14.19587556,14.14113964,14.08640372,14.0316678,13.97693188,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596,13.92219596};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,98.25516759,95.73916821,93.22316882,90.70716943,88.19117004,86.52797596,84.86478187,83.20158779,81.5383937,79.87519962,78.21200553,76.54881145,74.88561736,73.22242328,71.55922919,69.94742429,68.33561938,66.72381448,65.11200957,63.50020467,61.88839976,60.27659486,58.66478995,57.05298504,55.44118014,53.83624569,52.23131123,50.62637678,49.02144233,47.41650788,45.81157343,44.20663897,42.60170452,40.99677007,39.39183562,38.55227859,37.71272156,36.87316453,36.0336075,35.19405047,34.35449344,33.51493641,32.67537939,31.83582236,30.99626533,30.48486674,29.97346815,29.46206956,28.95067097,28.43927238,27.92787379,27.4164752,26.90507661,26.39367802,25.88227943,25.48770651,25.09313359,24.69856067,24.30398775,23.90941483,23.5148419,23.12026898,22.72569606,22.33112314,21.93655022,21.68777599,21.43900176,21.19022754,20.94145331,20.69267908,20.44390485,20.19513063,19.9463564,19.69758217,19.44880795,19.29017308,19.13153822,18.97290336,18.8142685,18.65563363,18.49699877,18.33836391,18.17972905,18.02109419,17.86245932,17.75347159,17.64448386,17.53549613,17.4265084,17.31752066,17.20853293,17.0995452,16.99055747,16.88156974,16.772582,16.66359427,16.55460654,16.44561881,16.33663107,16.22764334,16.11865561,16.00966788,15.90068015,15.79169241,15.68270468,15.57371695,15.46472922,15.35574149,15.24675375,15.13776602,15.02877829,14.91979056,14.81080282,14.70181509,14.59282736,14.48383963,14.3748519,14.26586416,14.15687643,14.0478887,13.93890097,13.82991324,13.7209255,13.61193777,13.50295004,13.39396231,13.28497458,13.17598684,13.06699911,12.95801138,12.84902365,12.74003591,12.63104818,12.52206045,12.41307272,12.30408499,12.19509725,12.08610952,11.97712179,11.86813406,11.75914633,11.65015859,11.54117086,11.43218313,11.3231954,11.21420767,11.10521993,10.9962322,10.88724447,10.77825674,10.669269,10.56028127,10.45129354,10.34230581,10.23331808,10.12433034,10.01534261,9.90635488,9.797367148,9.688379416,9.579391684,9.470403951,9.361416219,9.252428487,9.143440755,9.034453023,8.925465291,8.816477559,8.707489827,8.598502095,8.489514362,8.38052663,8.271538898,8.162551166,8.053563434,7.944575702,7.83558797,7.726600238,7.617612506,7.508624773,7.399637041,7.290649309,7.181661577,7.072673845,6.963686113,6.854698381,6.745710649,6.636722917,6.527735184,6.418747452,6.30975972,6.200771988,6.091784256,5.982796524,5.873808792,5.76482106,5.655833328,5.546845595,5.437857863,5.328870131,5.219882399,5.110894667,5.001906935,4.892919203,4.783931471,4.674943739,4.565956006,4.456968274,4.347980542,4.23899281,4.130005078,4.021017346,3.912029614,3.803041882,3.69405415,3.585066417,3.476078685,3.367090953,3.258103221,3.149115489,3.040127757,2.931140025,2.822152293,2.713164561,2.604176828,2.495189096,2.386201364,2.277213632,2.1682259,2.059238168,1.950250436,1.841262704,1.732274972,1.623287239,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507,1.514299507};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,154.986724,154.4529979,153.9192719,153.3855458,152.8518198,151.340033,149.8282463,148.3164596,146.8046728,145.2928861,143.7810994,142.2693126,140.7575259,139.2457392,137.7339524,135.9564589,134.1789653,132.4014717,130.6239782,128.8464846,127.0689911,125.2914975,123.5140039,121.7365104,119.9590168,118.0144811,116.0699454,114.1254098,112.1808741,110.2363384,108.2918027,106.3472671,104.4027314,102.4581957,100.51366,99.23982649,97.96599293,96.69215937,95.41832581,94.14449225,92.87065869,91.59682513,90.32299157,89.04915801,87.77532445,86.84120657,85.90708869,84.97297082,84.03885294,83.10473506,82.17061718,81.23649931,80.30238143,79.36826355,78.43414567,77.41168546,76.38922525,75.36676504,74.34430483,73.32184462,72.29938441,71.2769242,70.25446399,69.23200378,68.20954357,67.04895831,65.88837306,64.7277878,63.56720254,62.40661728,61.24603203,60.08544677,58.92486151,57.76427625,56.603691,55.54169519,54.47969939,53.41770358,52.35570778,51.29371197,50.23171616,49.16972036,48.10772455,47.04572875,45.98373294,45.7964459,45.60915885,45.4218718,45.23458475,45.0472977,44.86001065,44.6727236,44.48543655,44.2981495,44.11086245,43.9235754,43.73628835,43.5490013,43.36171425,43.1744272,42.98714015,42.7998531,42.61256605,42.425279,42.23799195,42.0507049,41.86341785,41.6761308,41.48884375,41.3015567,41.11426965,40.9269826,40.73969555,40.5524085,40.36512145,40.1778344,39.99054735,39.80326031,39.61597326,39.42868621,39.24139916,39.05411211,38.86682506,38.67953801,38.49225096,38.30496391,38.11767686,37.93038981,37.74310276,37.55581571,37.36852866,37.18124161,36.99395456,36.80666751,36.61938046,36.43209341,36.24480636,36.05751931,35.87023226,35.68294521,35.49565816,35.30837111,35.12108406,34.93379701,34.74650996,34.55922291,34.37193586,34.18464881,33.99736176,33.81007472,33.62278767,33.43550062,33.24821357,33.06092652,32.87363947,32.68635242,32.49906537,32.31177832,32.12449127,31.93720422,31.74991717,31.56263012,31.37534307,31.18805602,31.00076897,30.81348192,30.62619487,30.43890782,30.25162077,30.06433372,29.87704667,29.68975962,29.50247257,29.31518552,29.12789847,28.94061142,28.75332437,28.56603732,28.37875027,28.19146322,28.00417618,27.81688913,27.62960208,27.44231503,27.25502798,27.06774093,26.88045388,26.69316683,26.50587978,26.31859273,26.13130568,25.94401863,25.75673158,25.56944453,25.38215748,25.19487043,25.00758338,24.82029633,24.63300928,24.44572223,24.25843518,24.07114813,23.88386108,23.69657403,23.50928698,23.32199993,23.13471288,22.94742583,22.76013878,22.57285173,22.38556468,22.19827763,22.01099059,21.82370354,21.63641649,21.44912944,21.26184239,21.07455534,20.88726829,20.69998124,20.51269419,20.32540714,20.13812009,19.95083304,19.76354599,19.57625894,19.38897189,19.20168484,19.01439779,18.82711074,18.63982369,18.45253664,18.26524959,18.07796254,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549,17.89067549};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,66.0504185,66.82113386,67.59184922,68.36256459,69.13327995,69.87493937,70.61659879,71.35825821,72.09991763,72.84157705,73.58323647,74.32489589,75.06655531,75.80821473,76.54987415,77.24198086,77.93408756,78.62619427,79.31830098,80.01040768,80.70251439,81.3946211,82.08672781,82.77883451,83.47094122,84.0452245,84.61950777,85.19379105,85.76807432,86.3423576,86.91664088,87.49092415,88.06520743,88.63949071,89.21377398,89.56742939,89.9210848,90.27474021,90.62839562,90.98205103,91.33570644,91.68936185,92.04301725,92.39667266,92.75032807,93.10187025,93.45341243,93.80495461,94.15649678,94.50803896,94.85958114,95.21112331,95.56266549,95.91420767,96.26574985,96.55284902,96.83994819,97.12704736,97.41414653,97.7012457,97.98834487,98.27544404,98.56254321,98.84964238,99.13674155,99.11150115,99.08626075,99.06102035,99.03577995,99.01053956,98.98529916,98.96005876,98.93481836,98.90957796,98.88433756,98.62288081,98.36142407,98.09996732,97.83851057,97.57705382,97.31559707,97.05414032,96.79268357,96.53122682,96.26977007,96.18402694,96.09828381,96.01254067,95.92679754,95.84105441,95.75531128,95.66956814,95.58382501,95.49808188,95.41233874,95.32659561,95.24085248,95.15510934,95.06936621,94.98362308,94.89787995,94.81213681,94.72639368,94.64065055,94.55490741,94.46916428,94.38342115,94.29767802,94.21193488,94.12619175,94.04044862,93.95470548,93.86896235,93.78321922,93.69747609,93.61173295,93.52598982,93.44024669,93.35450355,93.26876042,93.18301729,93.09727415,93.01153102,92.92578789,92.84004476,92.75430162,92.66855849,92.58281536,92.49707222,92.41132909,92.32558596,92.23984283,92.15409969,92.06835656,91.98261343,91.89687029,91.81112716,91.72538403,91.6396409,91.55389776,91.46815463,91.3824115,91.29666836,91.21092523,91.1251821,91.03943896,90.95369583,90.8679527,90.78220957,90.69646643,90.6107233,90.52498017,90.43923703,90.3534939,90.26775077,90.18200764,90.0962645,90.01052137,89.92477824,89.8390351,89.75329197,89.66754884,89.5818057,89.49606257,89.41031944,89.32457631,89.23883317,89.15309004,89.06734691,88.98160377,88.89586064,88.81011751,88.72437438,88.63863124,88.55288811,88.46714498,88.38140184,88.29565871,88.20991558,88.12417245,88.03842931,87.95268618,87.86694305,87.78119991,87.69545678,87.60971365,87.52397051,87.43822738,87.35248425,87.26674112,87.18099798,87.09525485,87.00951172,86.92376858,86.83802545,86.75228232,86.66653919,86.58079605,86.49505292,86.40930979,86.32356665,86.23782352,86.15208039,86.06633726,85.98059412,85.89485099,85.80910786,85.72336472,85.63762159,85.55187846,85.46613532,85.38039219,85.29464906,85.20890593,85.12316279,85.03741966,84.95167653,84.86593339,84.78019026,84.69444713,84.608704,84.52296086,84.43721773,84.3514746,84.26573146,84.17998833,84.0942452,84.00850207,83.92275893,83.8370158,83.75127267,83.66552953,83.5797864,83.49404327,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013,83.40830013};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,227.8836549,228.5224904,229.161326,229.8001615,230.4389971,231.1577172,231.8764374,232.5951575,233.3138777,234.0325978,234.751318,235.4700381,236.1887583,236.9074784,237.6261986,238.2759745,238.9257504,239.5755263,240.2253022,240.8750781,241.524854,242.1746299,242.8244058,243.4741817,244.1239576,243.7341923,243.3444271,242.9546618,242.5648966,242.1751313,241.7853661,241.3956009,241.0058356,240.6160704,240.2263051,239.3712748,238.5162445,237.6612142,236.8061839,235.9511536,235.0961232,234.2410929,233.3860626,232.5310323,231.676002,231.4865695,231.297137,231.1077045,230.918272,230.7288395,230.539407,230.3499745,230.160542,229.9711095,229.781677,228.5403115,227.2989459,226.0575803,224.8162147,223.5748491,222.3334836,221.092118,219.8507524,218.6093868,217.3680212,214.1385084,210.9089957,207.6794829,204.4499701,201.2204573,197.9909445,194.7614317,191.5319189,188.3024061,185.0728933,182.4608496,179.8488058,177.2367621,174.6247183,172.0126746,169.4006309,166.7885871,164.1765434,161.5644996,158.9524559,158.1549797,157.3575035,156.5600273,155.7625511,154.9650749,154.1675987,153.3701225,152.5726463,151.7751701,150.9776939,150.1802177,149.3827415,148.5852653,147.7877891,146.9903129,146.1928367,145.3953605,144.5978843,143.8004081,143.0029319,142.2054557,141.4079795,140.6105033,139.8130271,139.015551,138.2180748,137.4205986,136.6231224,135.8256462,135.02817,134.2306938,133.4332176,132.6357414,131.8382652,131.040789,130.2433128,129.4458366,128.6483604,127.8508842,127.053408,126.2559318,125.4584556,124.6609794,123.8635032,123.066027,122.2685508,121.4710746,120.6735984,119.8761222,119.078646,118.2811698,117.4836936,116.6862174,115.8887412,115.091265,114.2937888,113.4963126,112.6988364,111.9013603,111.1038841,110.3064079,109.5089317,108.7114555,107.9139793,107.1165031,106.3190269,105.5215507,104.7240745,103.9265983,103.1291221,102.3316459,101.5341697,100.7366935,99.93921729,99.1417411,98.3442649,97.5467887,96.74931251,95.95183631,95.15436011,94.35688391,93.55940772,92.76193152,91.96445532,91.16697913,90.36950293,89.57202673,88.77455054,87.97707434,87.17959814,86.38212194,85.58464575,84.78716955,83.98969335,83.19221716,82.39474096,81.59726476,80.79978856,80.00231237,79.20483617,78.40735997,77.60988378,76.81240758,76.01493138,75.21745518,74.41997899,73.62250279,72.82502659,72.0275504,71.2300742,70.432598,69.6351218,68.83764561,68.04016941,67.24269321,66.44521702,65.64774082,64.85026462,64.05278843,63.25531223,62.45783603,61.66035983,60.86288364,60.06540744,59.26793124,58.47045505,57.67297885,56.87550265,56.07802645,55.28055026,54.48307406,53.68559786,52.88812167,52.09064547,51.29316927,50.49569307,49.69821688,48.90074068,48.10326448,47.30578829,46.50831209,45.71083589,44.9133597,44.1158835,43.3184073,42.5209311,41.72345491,40.92597871,40.12850251,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632,39.33102632};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9212646484375,1851.59423828125,1875.3197021484375,1893.0016276041667,1912.5613098144531,1933.8615417480469,1956.7713521321614,1979.1009623209636,1998.7708841959636,2015.990743001302,2030.920654296875,2043.7305603027344,2054.5804036458335,2063.5903523763022,2070.9202677408853,2076.6701863606772,2080.960245768229,2084.900349934896,2089.5404052734375,2094.8204549153647,2100.7104695638022,2107.1705322265625,2114.1704915364585,2121.6705729166665,2129.6505330403647,2138.0606282552085,2146.8905639648438,2155.850545247396,2164.6605428059897,2173.340576171875,2181.9105224609375,2190.3705240885415,2198.7405598958335,2207.0205078125,2215.2205200195312,2223.350545247396,2231.4204711914062,2239.3404541015625,2247.030476888021,2254.5004679361978,2261.7604777018228,2268.8504638671875,2275.7604370117188,2282.510457356771,2289.1204223632812,2295.5904337565103,2301.950398763021,2308.1203816731772,2314.0603841145835,2319.7904052734375,2325.310343424479,2330.6503702799478,2335.8203735351562,2340.8303019205728,2345.7003173828125,2350.4403076171875,2355.0602823893228,2359.4002482096353,2363.3202514648438,2366.8602091471353,2370.030232747396,2372.8701782226562,2375.400146484375,2377.650187174479,2379.6301472981772,2381.3701375325522,2382.880086263021,2383.9800618489585,2384.490030924479,2384.4400024414062,2383.8899739583335,2382.8499348958335,2381.3798828125,2379.4998982747397,2377.2398681640625,2374.6398722330728,2371.7098388671875,2368.5098470052085,2365.08984375,2361.4698486328125,2357.6598307291665,2353.6797892252603,2349.5397745768228,2345.2697957356772,2340.859822591146,2336.3297729492188,2331.7097981770835,2327.099812825521,2322.6298014322915,2318.2798461914062,2314.0497843424478,2309.9398193359375,2305.9298095703125,2302.0198364257812,2298.1998087565103,2294.4698689778647,2290.819864908854,2287.2398681640625,2283.7298583984375,2280.2898559570312,2276.909871419271,2273.589884440104,2270.3298543294272,2267.10986328125,2263.9398600260415,2260.819864908854,2257.7298787434897,2254.6798299153647,2251.669881184896,2248.6898600260415,2245.7399088541665,2242.8198852539062,2239.9298706054688,2237.0598958333335,2234.2198689778647,2231.389892578125,2228.589884440104,2225.799845377604,2223.0298868815103,2220.2798665364585,2217.5398559570312,2214.8198852539062,2212.109903971354,2209.409912109375,2206.7198689778647,2204.0498657226562,2201.3798828125,2198.7198689778647,2196.069864908854,2193.419881184896,2190.7799072265625,2188.1498819986978,2185.5098876953125,2182.8698933919272,2180.2298990885415,2177.5798543294272,2174.9298706054688,2172.2698771158853,2169.599894205729,2166.9198608398438,2164.2298583984375,2161.5198974609375,2158.7999267578125,2156.069864908854,2153.3098958333335,2150.5498860677085,2147.7598876953125,2144.949910481771,2142.1298828125,2139.2798461914062,2136.409912109375,2133.5198567708335,2130.60986328125,2127.6698608398438,2124.7298380533853,2121.7598470052085,2118.7798665364585,2115.7798665364585,2112.7598673502603,2109.7298380533853,2106.6798706054688,2103.609822591146,2100.5098673502603,2097.3998209635415,2094.2698364257812,2091.119832356771,2087.9498697916665,2084.7598673502603,2081.5498657226562,2078.309855143229,2075.059814453125,2071.7798665364585,2068.4898478190103,2065.1698201497397,2061.8298136393228,2058.4597981770835,2055.079803466797,2051.6798400878906,2048.249827067057,2044.7998555501301,2041.339823404948,2037.8498229980469,2034.3498128255208,2030.8398132324219,2027.3098042805989,2023.7698364257812,2020.2198181152344,2016.6498006184895,2013.0797932942708,2009.4998168945312,2005.9098103841145,2002.309834798177,1998.7097981770833,1995.0998128255208,1991.4898071289062,1987.8698018391926,1984.2498067220051,1980.6298116048176,1976.9998168945312,1973.3698018391926,1969.7398071289062,1966.1098022460938,1962.4698181152344,1958.8398030598958,1955.1998087565105,1951.559814453125,1947.9197896321614,1944.2797953287761,1940.6497904459636,1937.009785970052,1933.3698120117188,1929.7298075358074,1926.0898132324219,1922.4597981770833,1918.8197937011719,1915.1797993977864,1911.5498046875,1907.9197998046875,1904.279805501302,1900.6498006184895,1897.0198059082031,1893.3898010253906,1889.7598063151042,1886.1297912597656,1882.5098063151042,1878.8798014322917,1875.2597961425781,1871.6397908528645,1868.0097757975261,1864.3897806803386,1860.769795735677,1857.1597900390625,1853.5398050944011,1849.9197998046875,1846.3097839355469,1842.6897989908855,1839.0797932942708,1835.5898335774739,1832.319844563802,1829.2698567708333,1826.4198303222656,1823.7498779296875,1821.2598876953125,1818.9299011230469,1816.7498881022136,1814.7099202473958,1812.8099060058594,1811.0299275716145,1809.3599243164062,1807.7999165852864,1806.3499247233074,1804.9999287923176,1803.7399495442708,1802.5699361165364,1801.4699401855469,1800.4499409993489,1799.4999491373699,1798.6199442545574,1797.7899373372395,1797.0299682617188,1796.3099670410156,1795.6499532063801,1795.0299682617188,1794.4499613444011,1793.9099731445312,1793.4199727376301,1792.9499918619792,1792.5199686686199,1792.1199747721355,1791.739990234375,1791.3999837239583,1791.0699869791667,1790.7699686686199,1790.489990234375,1790.2400004069011,1789.9900004069011,1789.7699890136719,1789.5599873860676,1789.3699849446614,1789.1899820963542,1789.0199890136719,1788.8699849446614,1788.7299906412761,1788.5900065104167,1788.469991048177,1788.3599853515625,1788.249979654948,1788.1500040690105,1788.0599975585938,1787.9799906412761,1787.8999837239583,1787.8299967447917,1787.759989420573,1787.7000020345051,1787.6400044759114,1787.5899963378906,1787.5399881998699,1787.499979654948,1787.4500122070312,1787.4199930826824,1787.3800150553386,1787.3499959309895,1787.3200073242188,1787.2899780273438,1787.2599792480469,1787.2400004069011,1787.2200012207031,1787.1999918619792,1787.1799825032551,1787.1600138346355,1787.1499938964844,1787.1300150553386,1787.1199747721355,1787.0999959309895,1787.0899861653645,1787.0799967447917,1787.0699971516926,1787.0599975585938,1787.0600077311199,1787.0500081380208,1787.0399983723958,1787.0299886067708,1787.0299987792969,1787.0199890136719,1787.0199890136719,1787.0099995930989,1787.0099995930989,1787.0,1787.0000101725261,1787.0000101725261,1786.989990234375,1786.990010579427,1786.989990234375,1786.9800109863281,1786.9800109863281,1786.980000813802,1786.9799906412761,1786.9700113932292,1786.9700012207031,1786.969991048177,1786.9700012207031,1786.969991048177,1786.9600016276042,1786.959981282552,1786.959981282552,1786.9600118001301,1786.9599914550781,1786.9499918619792,1786.9500020345051,1786.9500122070312,1786.9500020345051,1786.9500122070312,1786.9400024414062,1786.9399922688801,1786.9400024414062,1786.9399922688801,1786.9300130208333,1786.9300028483074,1786.9300028483074,1786.9299926757812,1786.9300028483074,1786.9200134277344,1786.9199930826824,1786.9199930826824,1786.9199930826824,1786.9099934895833,1786.9100036621094,1786.9099833170574,1786.9000040690105,1786.9000142415364,1786.9000040690105,1786.8999938964844,1786.8899841308594,1786.8900044759114,1786.8900146484375,1786.8799947102864,1786.8799947102864,1786.8800048828125,1786.8700052897136,1786.8700052897136,1786.8700052897136,1786.8599955240886,1786.8599955240886,1786.8600056966145,1786.8499959309895,1786.8499959309895,1786.8499959309895,1786.8400166829426,1786.8400065104167,1786.8300069173176,1786.8300069173176,1786.8299865722656,1786.8199971516926,1786.8200174967449,1786.8200073242188,1786.8099873860676,1786.8099975585938,1786.8000183105469,1786.7999877929688,1786.7899983723958,1786.790018717448,1786.7899983723958,1786.780008951823,1786.7799987792969,1786.7700093587239,1786.7700093587239,1786.7599995930989,1786.7599792480469,1786.7500305175781,1786.75,1786.740010579427,1786.739990234375,1786.7300109863281,1786.730000813802,1786.7200012207031,1786.7200012207031,1786.7100016276042,1786.7099914550781,1786.7000020345051,1786.7000020345051,1786.6900126139324,1786.6900024414062,1786.6799926757812,1786.6700032552083,1786.6700236002605,1786.6600036621094,1786.6600036621094,1786.6500142415364,1786.6500040690105,1786.6399841308594,1786.6299947102864,1786.6300048828125,1786.6199951171875,1786.6199849446614,1786.6099955240886,1786.5999959309895,1786.5999857584636,1786.5900065104167,1786.5800069173176,1786.5800069173176,1786.5699971516926,1786.5599873860676,1786.5599975585938,1786.5500081380208,1786.5400085449219,1786.5399881998699,1786.5299886067708,1786.5200093587239,1786.510009765625,1786.5100199381511,1786.4999898274739,1786.490010579427,1786.480000813802,1786.4799906412761,1786.4700113932292,1786.4599914550781,1786.4500020345051,1786.4499816894531,1786.4400126139324,1786.4299926757812,1786.4200032552083,1786.4100036621094,1786.4000244140625,1786.4000040690105,1786.3900146484375,1786.3800048828125,1786.3700154622395,1786.3600158691406,1786.3499755859375,1786.3399963378906,1786.3299967447917,1786.3199971516926,1786.3100077311199,1786.2999877929688,1786.2899983723958,1786.2799987792969,1786.269999186198,1786.2599995930989,1786.25,1786.2400004069011,1786.2299906412761,1786.2200113932292,1786.2099914550781,1786.2000122070312,1786.1799926757812,1786.1799926757812};
        CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9493179321289,403.11696370442706,405.7429707845052,408.5569661458333,411.33996327718097,414.10095977783203,416.8429641723633,419.54396565755206,422.18196360270184,424.7629623413086,427.29095967610675,429.7689615885417,432.19896697998047,434.584966023763,436.9269663492839,439.22596740722656,441.4839604695638,443.6879653930664,445.8269627888997,447.90296681722003,449.9169616699219,451.8709716796875,453.7659734090169,455.6029764811198,457.3829650878906,459.1069742838542,460.77696990966797,462.38597106933594,463.9269714355469,465.4019724527995,466.81297302246094,468.15897878011066,469.4419759114583,470.66197967529297,471.8199768066406,472.91698455810547,473.9519780476888,474.94597880045575,475.91697947184247,476.8629837036133,477.78397878011066,478.67698669433594,479.54398345947266,480.3819859822591,481.19098409016925,481.97198486328125,482.7219823201497,483.4469858805339,484.1469904581706,484.82398986816406,485.47499084472656,486.09998830159503,486.69899495442706,487.2719904581706,487.8169937133789,488.33399200439453,488.8240000406901,489.2669982910156,489.64599863688153,489.96300252278644,490.21799723307294,490.41299692789715,490.54600016276044,490.62000274658203,490.63499959309894,490.59100341796875,490.48800404866535,490.3100001017253,490.0450032552083,489.69200388590497,489.2550099690755,488.7330067952474,488.1280059814453,487.4410095214844,486.67200724283856,485.82301076253253,484.8930130004883,483.89001210530597,482.81701405843097,481.67501576741535,480.4640121459961,479.18401590983075,477.8350092569987,476.4180145263672,474.9330139160156,473.3810119628906,471.7610143025716,470.12801361083984,468.53101348876953,466.9640172322591,465.42601013183594,463.9130147298177,462.42201741536456,460.95201619466144,459.50001525878906,458.0650177001953,456.64601643880206,455.2420171101888,453.85101826985675,452.4720153808594,451.1050109863281,449.74901326497394,448.4040171305339,447.06701914469403,445.7400131225586,444.4210154215495,443.1100158691406,441.80601755777997,440.50901794433594,439.2200113932292,437.9360173543294,436.65901438395184,435.3870162963867,434.12101491292316,432.86001841227215,431.60501352945965,430.35401153564453,429.10801696777344,427.8660176595052,426.62901814778644,425.39601643880206,424.1670150756836,422.9430185953776,421.7210108439128,420.50401814778644,419.29001871744794,418.0800145467122,416.8930130004883,415.749018351237,414.6430180867513,413.57501220703125,412.5430145263672,411.54601287841797,410.58301544189453,409.6530125935872,408.75301361083984,407.885014851888,407.04801686604816,406.24401092529297,405.47200775146484,404.73101298014325,404.02101135253906,403.3400115966797,402.6880060831706,402.0650100708008,401.47001393636066,400.9030075073242,400.3630091349284,399.8500111897786,399.3630116780599,398.9020029703776,398.4670054117839,398.0570068359375,397.67201232910156,397.3130060831706,396.9780095418294,396.6690088907878,396.3830057779948,396.1220016479492,395.88500722249347,395.67200469970703,395.4830067952474,395.31700388590497,395.1740086873372,395.0540059407552,394.9570058186849,394.8820063273112,394.8310038248698,394.8009999593099,394.7940038045247,394.8090006510417,394.84700266520184,394.906000773112,394.9869969685872,395.08899688720703,395.21299997965497,395.35900115966797,395.5059992472331,395.63600158691406,395.75099690755206,395.8529968261719,395.9440002441406,396.0250015258789,396.0959981282552,396.1579945882161,396.21300252278644,396.26099650065106,396.3029963175456,396.33799997965497,396.36899820963544,396.3939971923828,396.4149983723958,396.43099721272785,396.4439977010091,396.45300038655597,396.45799509684247,396.4600016276042,396.4600016276042,396.4560012817383,396.4499994913737,396.44200134277344,396.4310048421224,396.41800181070965,396.4029998779297,396.38600158691406,396.3670018513997,396.3459981282552,396.3240025838216,396.2999954223633,396.2739969889323,396.2479960123698,396.21899668375653,396.1900049845378,396.1589991251628,396.12699635823566,396.093999226888,396.05899810791016,396.0239995320638,395.9880015055339,395.9500020345052,395.91200002034503,395.8719991048177,395.8320007324219,395.79100036621094,395.7489980061849,395.7059961954753,395.66300201416016,395.6179936726888,395.572998046875,395.5269953409831,395.48099517822266,395.4330012003581,395.38500213623047,395.3370005289714,395.28700256347656,395.2369969685872,395.18700408935547,395.13499959309894,395.08299509684247,395.02999623616535,394.97599538167316,394.9220021565755,394.86600494384766,394.80999755859375,394.7519989013672,394.6939977010091,394.63600158691406,394.5760014851888,394.51599884033203,394.4559961954753,394.39600372314453,394.33499908447266,394.2740020751953,394.21399943033856,394.15299733479816,394.0929997762044,394.0320002237956,393.9720001220703,393.91099548339844,393.8510004679362,393.7909978230794,393.73100026448566,393.6709976196289,393.61100006103516,393.552001953125,393.49300384521484,393.4340006510417,393.37500254313153,393.31599680582684,393.2579981486003,393.1990025838216,393.14100392659503,393.08399963378906,393.0260009765625,392.968999226888,392.91099802652997,392.85500081380206,392.7980016072591,392.74099985758465,392.6850001017253,392.6290028889974,392.573003133138,392.51800537109375,392.4620005289714,392.4070002237956,392.3519973754883,392.29699961344403,392.2429962158203,392.18800099690753,392.1340026855469,392.0799967447917,392.02699788411456,391.9729995727539,391.9189961751302,391.8659973144531,391.81299845377606,391.75999959309894,391.70799763997394,391.6549987792969,391.6029993693034,391.5500005086263,391.4980010986328,391.4459991455078,391.39499918619794,391.3429997762044,391.29199473063153,391.239995320638,391.18899790445965,391.13800048828125,391.0870005289714,391.03699747721356,390.9860026041667,390.93599700927734,390.88499704996747,390.83500417073566,390.7849985758464,390.73500061035156,390.6850001017253,390.63500213623047,390.5860010782878,390.53600056966144,390.4870020548503,390.43799845377606,390.38899993896484,390.3400014241536,390.29100036621094,390.24199930826825,390.19300333658856,390.14500427246094,390.0959981282552,390.0479990641276,390.00000254313153,389.9509989420573,389.9029998779297,389.8549982706706,389.80799611409503,389.760004679362,389.71200307210285,389.66400146484375,389.6169967651367,389.5690002441406,389.5220031738281,389.4749984741211,389.42799886067706,389.3809992472331,389.33399709065753,389.28700256347656,389.24000040690106,389.1929982503255,389.146001180013,389.1000010172526,389.05299886067706,389.0069986979167,388.95999399820965,388.9140040079753,388.8680013020833,388.82200113932294,388.7760009765625,388.7299982706706,388.68399810791016,388.6379979451497,388.5920003255208,388.5460027058919,388.5010019938151,388.4550043741862,388.4100062052409,388.36399841308594,388.3190053304036,388.2740020751953,388.2279993693034,388.18299865722656,388.1380030314128,388.0929997762044,388.0479965209961,388.0029983520508,387.95799763997394,387.9139989217122,387.8690007527669,387.8240025838216,387.7799987792969,387.73499806722003,387.6909993489583,387.64599863688153,387.6019999186198,387.5580012003581,387.51300048828125,387.46900177001953,387.4250005086263,387.38099670410156,387.3370005289714,387.2929992675781,387.2489954630534,387.2049967447917,387.16100056966144,387.11799875895184,387.0740025838216,387.0299936930339,386.9869969685872,386.9429982503255,386.8999989827474,386.8559977213542,386.81300354003906,386.76999918619794,386.7269999186198,386.6830012003581,386.64000193277997,386.5969975789388,386.55399831136066,386.51099904378253,386.4679997762044,386.4250030517578,386.38200124104816,386.33999888102215,386.29699961344403,386.2540003458659,386.2119954427083,386.16900126139325,386.12699635823566,386.08399963378906,386.04199981689453,385.9990005493164,385.95699818929035,385.91500091552734,385.8719991048177,385.82999928792316,385.78800201416016,385.7459971110026,385.7040023803711,385.66199747721356,385.6200002034505,385.57800038655597,385.53599548339844,385.4940007527669,385.4519958496094,385.41099802652997,385.3690007527669,385.3269958496094,385.28599802652997,385.2440007527669,385.20299530029297,385.16099802652997,385.1200002034505,385.07800038655597,385.03699747721356,384.9960021972656,384.95399983723956,384.9129994710286,384.8720016479492,384.8310012817383,384.79000091552734,384.7489954630534,384.70800526936847,384.66699473063153,384.62599690755206,384.5849965413411,384.5439987182617,384.5029983520508,384.46300252278644,384.4220021565755,384.3809992472331,384.34099833170575,384.3000030517578,384.2590026855469,384.218999226888,384.1780014038086,384.13800048828125,384.0979970296224,384.05699920654297,384.0169982910156,383.9769973754883,383.93599700927734,383.896001180013,383.85600026448566,383.81599680582684,383.77600351969403,383.7360026041667,383.6959991455078,383.656000773112,383.61599985758465,383.5760014851888,383.53599802652997,383.4959996541341,383.45599873860675,383.41600036621094,383.37699635823566,383.3570048014323};
        HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.757368167241413,21.18809429804484,23.277894179026287,26.835993607838947,30.601293404897053,34.56809266408285,38.73089345296224,42.75589370727539,46.31979433695475,49.43779436747233,52.12449518839518,54.39349555969238,56.25829601287842,57.73139572143555,58.82489617665609,59.550697008768715,59.91999753316244,60.06399726867676,60.110297520955406,60.061997731526695,59.922498067220054,59.694698333740234,59.38149897257487,58.985597928365074,58.50979868570963,57.95639864603678,57.32789866129557,56.64209874471029,55.916199366251625,55.15129884084066,54.3482993443807,53.50829887390137,52.631998697916664,51.720499992370605,50.7744992574056,49.79499912261963,48.78249931335449,47.770599365234375,46.79130013783773,45.84369945526123,44.92659982045492,44.0389986038208,43.17989953358968,42.34829966227213,41.543399492899574,40.76419925689697,40.00999959309896,39.27919960021973,38.5705992380778,37.883499463399254,37.21709950764974,36.5707000096639,35.94379870096842,35.33559926350912,34.74549929300944,34.1729990641276,33.617499351501465,33.07779916127523,32.55269972483317,32.041699727376304,31.544299761454266,31.060199578603108,30.588799476623535,30.129899501800537,29.682899634043377,29.247599442799885,28.82349952061971,28.4108993212382,28.010099411010742,27.620799382527668,27.242499510447185,26.874899705251057,26.517699241638184,26.17049964269002,25.833199501037598,25.50539954503377,25.18679936726888,24.877299308776855,24.57659975687663,24.28459930419922,24.000999609629314,23.72559928894043,23.458099683125813,23.198399384816486,22.94619957605998,22.7012996673584,22.463499704996746,22.231099446614582,22.002599398295086,21.77779944737752,21.556499640146892,21.33889929453532,21.12459961573283,20.91369930903117,20.70609966913859,20.501699447631836,20.300399621327717,20.102099577585857,19.90679947535197,19.714299201965332,19.52459955215454,19.33759943644206,19.15329949061076,18.971599578857422,18.792299270629883,18.61549965540568,18.441099484761555,18.268999576568604,18.09909947713216,17.931299368540447,17.765699863433838,17.60219939549764,17.440699418385822,17.281099796295166,17.12339973449707,16.96749973297119,16.813499291737873,16.661099433898926,16.510499636332195,16.361499468485516,16.214099884033203,16.068299452463787,15.92389965057373,15.780999501546225,15.639599561691284,15.499499718348185,15.360799551010132,15.223399718602499,15.087199846903482,14.95229975382487,14.818499644597372,14.68589965502421,14.554399569829306,14.423999547958374,14.294699589411417,14.166299740473429,14.038899580637613,13.912399689356485,13.78689972559611,13.66219965616862,13.538299640019735,13.41529949506124,13.292999664942423,13.171499649683634,13.05079960823059,12.930699666341146,12.811299562454224,12.692599693934122,12.574399709701538,12.456899563471476,12.339999596277872,12.223599751790365,12.107799768447876,11.992499669392904,11.877699613571167,11.763399839401245,11.649499734242758,11.536099751790365,11.423199733098349,11.31059980392456,11.19849975903829,11.086699644724527,10.975299835205078,10.864299774169922,10.753599882125854,10.64329981803894,10.533199707667032,10.423499902089437,10.314099709192911,10.204999685287476,10.096199830373129,9.987579663594564,9.879259665807089,9.771179914474487,9.663349707921347,9.55575974782308,9.448379755020142,9.341229915618896,9.23427971204122,9.127539793650309,9.020999749501547,8.91465973854065,8.808509906133017,8.702549854914347,8.596789836883545,8.491209904352823,8.385809898376465,8.28059991200765,8.175559838612875,8.070709784825643,7.96602996190389,7.861519813537598,7.757189830144246,7.653029839197795,7.549039880434672,7.445209860801697,7.341549873352051,7.238049864768982,7.13470987478892,7.031529863675435,6.928509910901387,6.825649817784627,6.722949941953023,6.620389898618062,6.517989873886108,6.4157399733861284,6.313649972279866,6.211699883143107,6.109899878501892,6.008239944775899,5.906729896863301,5.805369933446248,5.704149961471558,5.603069980939229,5.502129952112834,5.401339888572693,5.300679922103882,5.200159947077434,5.099779884020488,4.999539891878764,4.89942987759908,4.799459973971049,4.699619968732198,4.59991995493571,4.500359932581584,4.400919953982036,4.301620006561279,4.202439943949382,4.103399991989136,4.004479964574178,3.9057000080744424,3.807040015856425,3.7085099617640176,3.6100999315579734,3.5118199984232583,3.413659989833832,3.31563001871109,3.219060023625692,3.1252599954605103,3.034130016962687,2.9456299940745034,2.859659989674886,2.7761699557304382,2.6950900157292685,2.616349975268046,2.5398799777030945,2.465629994869232,2.393520017464956,2.323509991168976,2.255529999732971,2.1895199616750083,2.1254300276438394,2.063199977080027,2.002789984146754,1.9441400070985158,1.8871899942557018,1.8319099843502045,1.7782300114631653,1.7261299987634022,1.6755500038464863,1.6264399985472362,1.5787700017293294,1.5324900150299072,1.4875699877738953,1.4439599911371868,1.4016200105349224,1.36053000887235,1.3206399977207184,1.2819200058778126,1.244329998890559,1.2078400055567424,1.1724199950695038,1.1380399962266285,1.1046599944432576,1.072270005941391,1.0408200025558472,1.0103000104427338,0.9806700100501379,0.9519099990526835,0.9239929914474487,0.8968949963649114,0.8705909997224808,0.8450590074062347,0.8202760020891825,0.7962200045585632,0.7728690008322397,0.7502039968967438,0.7282029986381531,0.7068480054537455,0.6861190050840378,0.6659980068604151,0.6464679886897405,0.627510999639829,0.6091090043385824,0.591248000661532,0.5739109963178635,0.5570819973945618,0.5407469968001047,0.524891992410024,0.5095010052124659,0.4945620000362396,0.48006200045347214,0.4659860009948413,0.45232400049765903,0.4390629976987839,0.42619000126918155,0.4136950025955836,0.4015669996539752,0.3897949953873952,0.37836800267299014,0.36727600047985715,0.3565090000629425,0.3460589994986852,0.3359139983852704,0.32606800148884457,0.3165099968512853,0.3072329983115196,0.2982269997398059,0.28948599596818286,0.2810009966293971,0.2727650006612142,0.2647710020343463,0.2570109988252322,0.24947899828354517,0.24216699848572412,0.2350700000921885,0.22818100079894066,0.2214950000246366,0.2150039995710055,0.20870300134023032,0.20258799940347672,0.19665100052952766,0.1908889984091123,0.18529600029190382,0.17986599976817766,0.17459599922100702,0.1694799984494845,0.16451499983668327,0.1596950019399325,0.15501600007216135,0.15047400072216988,0.14606600006421408,0.14178700000047684,0.13763299956917763,0.1336010011533896,0.12968700006604195,0.12588799931108952,0.12220000041027863,0.11862099977831046,0.11514600118001302,0.11177299916744232,0.10849899984896183,0.10532099939882755,0.1022360014418761,0.09924149947861831,0.09633480136593182,0.09351330064237118,0.09077439891795318,0.08811590013404687,0.08553519969185193,0.08303019901116689,0.08059849962592125,0.0782380998134613,0.07594689913094044,0.07372290020187695,0.07156400009989738,0.06946830078959465,0.06743409981330235,0.06545939979453881,0.06354270006219546,0.06168210040777922,0.05987589992582798,0.05812280004223188,0.056420900548497833,0.05476900034894546,0.05316540009031693,0.05160879995673895,0.050097800170381866,0.04863109967360894,0.047207300240794815,0.04582529949645201,0.04448370014627775,0.04318140012522539,0.04191729985177517,0.040690199782450996,0.03949900002529224,0.03834279999136925,0.03722040013720592,0.036130900184313454,0.03507320024073124,0.03404659995188316,0.03304999973624945,0.03208270048101743,0.03114359996592005,0.030232099971423548,0.029347199946641922,0.028488300119837124,0.02765450021252036,0.02684509987011552,0.02605939997980992,0.025296800148983795,0.024556399943927925,0.023837799672037363,0.023140199948102236,0.022462999913841486,0.02180559995273749,0.02116750009978811,0.020548099807153147,0.019946799613535404,0.019363099864373606,0.01879649981856346,0.01824650013198455,0.01771260021875302,0.0171944002310435,0.016691299931456644,0.01620290009304881,0.01572879993667205,0.015268600080162287,0.014821900054812431,0.014388299935186902,0.013967299989114204,0.013558699982240796,0.013161999949564537,0.012776999967172742,0.01240319999245306,0.012040300061926246,0.011688100018848976,0.011346199937785665,0.011014299932867289,0.01069210011822482,0.0103792999094973,0.010075700003653765,0.009780980258559188,0.009494880059113106,0.009217159977803627,0.008947560020412007,0.008685849995041886,0.008431800020237764,0.008185189993431171,0.007945790110776821,0.0077133899709830684,0.007487799972295761,0.00726881002386411,0.007056229980662465,0.006849870008106033,0.00664953999997427,0.006455080001614988,0.006266309996135533,0.006083060017166038,0.0059051700324441,0.005732490060230096,0.005564860029456516,0.0054021299971888466,0.005244169966317713,0.005090820059801142,0.004941970071134468,0.0047974600456655025,0.004657190021437903,0.0045210199896246195,0.0043888300424441695,0.004260510012196998,0.004135939991101623,0.0040150199783965945,0.0038976299886902175,0.0037836799941336117,0.0036730600016502044,0.003565679983391116,0.003461430004487435,0.0033602399829154215,0.003262010014926394,0.0031666499950612583,0.0030740700118864575,0.0029842099950959287,0.0028969800138535597,0.002812290001505365,0.0027300800235631564,0.0026502799980031946,0.0025728100445121527,0.0024976099763686457,0.0024246000296746693,0.002353729990621408,0.0022849400023308894,0.00221814999046425,0.0021533200051635504,0.0020903799838076034,0.0020593799999915063};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.77318127950032,90.2767276763916,95.80338541666667,99.75606791178386,103.07928085327148,105.8205025990804,108.02476946512859,109.55875714619954,110.2976754506429,110.29369036356609,109.59376398722331,108.243896484375,106.28609275817871,103.75832239786784,100.69663174947102,97.13432502746582,93.10384941101074,88.93626340230306,84.94064966837566,81.10414568583171,77.41554641723633,73.86362648010254,70.43839581807454,67.13025029500325,63.930294036865234,60.83012326558431,57.82184982299805,54.93182786305746,52.18412431081136,49.56809647878011,47.07375876108805,44.69180711110433,42.41394551595052,40.23217328389486,38.13939126332601,36.128698666890465,34.19390296936035,32.35795132319132,30.64211829503377,29.038264592488606,27.53870439529419,26.13653326034546,24.82495403289795,23.59786621729533,22.449671268463135,21.37506914138794,20.3690603574117,19.42724593480428,18.54542589187622,17.719600359598797,16.946069558461506,16.221434831619263,15.54239551226298,14.905952215194702,14.30930503209432,13.749754587809244,13.225101073582968,12.732944250106812,12.27118468284607,11.838022708892822,11.431458075841268,11.049891630808512,10.691622495651245,10.355251789093018,10.039278666178385,9.742494265238443,9.463648160298666,9.202442328135172,8.958605686823526,8.7310471534729,8.518757740656534,8.320786635080973,8.136234641075134,7.964291493097941,7.804157177607219,7.655131975809733,7.516505837440491,7.387709021568298,7.268141269683838,7.157262921333313,7.054533680280049,6.959473967552185,6.871603488922119,6.790502667427063,6.715751012166341,6.646969199180603,6.58380647500356,6.524029533068339,6.4655611117680865,6.408342679341634,6.352294246355693,6.297355731328328,6.24347722530365,6.190598527590434,6.138649821281433,6.087600946426392,6.037392059961955,5.987973213195801,5.939304192860921,5.891345103581746,5.844056089719136,5.797386844952901,5.751317620277405,5.705808401107788,5.660819013913472,5.616329709688823,5.572310447692871,5.528741041819255,5.485571543375651,5.442801992098491,5.400402506192525,5.358353018760681,5.316633462905884,5.275223811467488,5.234094262123108,5.193244695663452,5.152644872665405,5.112285256385803,5.0721555550893145,5.032245834668477,4.992526133855184,4.952996373176575,4.9136466185251875,4.8744568427403765,4.835417032241821,4.796537280082703,4.757787386576335,4.7191576560338335,4.680657744407654,4.642257849375407,4.603968024253845,4.565758069356282,4.527638236681621,4.489588300387065,4.451598326365153,4.413658459981282,4.3757684628168745,4.337928533554077,4.300118605295817,4.262328664461772,4.224568645159404,4.186828692754109,4.149098714192708,4.111368656158447,4.073648691177368,4.035918712615967,3.998188773790995,3.9604587157567344,3.9227087100346885,3.884938657283783,3.8471586306889853,3.8093586365381875,3.771538575490316,3.733688533306122,3.695818523565928,3.6579285065333047,3.6199983954429626,3.5820484161376953,3.5440683563550315,3.5060583353042603,3.4680182735125222,3.4299482504526773,3.391848166783651,3.353728195031484,3.3155681093533835,3.2773780822753906,3.239158034324646,3.2009080052375793,3.1626279751459756,3.1243178844451904,3.0859779119491577,3.0476078391075134,3.0092177987098694,2.9707977970441184,2.9323477347691855,2.8938777248064675,2.855377654234568,2.816857635974884,2.7783175905545554,2.7397575974464417,2.7011875907580056,2.6625975569089255,2.6239975094795227,2.5853874882062278,2.546777526537577,2.5081575314203897,2.4695474902788797,2.4309375286102295,2.3923275073369346,2.353727559248606,2.3151475389798484,2.276567538579305,2.237997551759084,2.1994476119677224,2.160917659600576,2.1223976413408914,2.083897670110067,2.0454277197519937,2.006967693567276,1.9685377776622772,1.9301377932230632,1.8917478223641713,1.8533978859583538,1.8150678873062134,1.7767679591973622,1.738508015871048,1.7002680401007335,1.662058065334956,1.6238781213760376,1.5857381423314412,1.5476182003815968,1.5095382432142894,1.4714982906977336,1.433498352766037,1.3955283959706624,1.3575884501139324,1.319688489039739,1.2818185289700825,1.2439985970656078,1.2061986327171326,1.1684487064679463,1.1307287414868672,1.0930487910906475,1.0554088254769642,1.0177988857030869,0.9802349458138148,0.9427069872617722,0.9052170465389887,0.8677671005328497,0.8303551524877548,0.7929832140604655,0.7556512504816055,0.7183583229780197,0.681104357043902,0.6438914388418198,0.6067174126704534,0.5695846130450567,0.5336348911126455,0.49993619571129483,0.468348890542984,0.43874257057905197,0.4109960347414017,0.38499236355225247,0.360624539355437,0.3377915844321251,0.31639650215705234,0.29635129620631534,0.277569979429245,0.25997356325387955,0.24349004526933035,0.22804742927352586,0.21358073378602663,0.20002995183070502,0.18733609095215797,0.17544616386294365,0.16430816302696863,0.15387710804740587,0.14410698786377907,0.13495581348737082,0.12638458299140135,0.11835731007158756,0.11083898569146793,0.10379762264589469,0.09720321682592233,0.09102737531065941,0.08524369696776073,0.07982708637913068,0.07475444426139195,0.0700039720783631,0.06555527510742347,0.061389051377773285,0.05748760451873144,0.05383393416802088,0.05041244377692541,0.04720833276708921,0.04420780390501022,0.04139805802454551,0.03876679545889298,0.036302718333899975,0.03399532660841942,0.031834521951774754,0.02981110553567608,0.02791627651701371,0.026141937046001356,0.024480387413253386,0.022924428184827168,0.021467359581341345,0.020102882757782936,0.018825198368479807,0.017628706836452086,0.01650830792884032,0.015459102656071385,0.014476591565956673,0.013556574626515308,0.012694952621435126,0.011888225562870502,0.011132693771893779,0.01042515792263051,0.009762687763820091,0.009142283583059907,0.008561316256721815,0.008017285571744045,0.00750782146739463,0.007030754699371755,0.006584004925874372,0.006165642834578951,0.005773878229471545,0.005407011369243264,0.005063462459171812,0.0047417515112708015,0.004440488837038477,0.004158364259637892,0.003894168223875264,0.003646770550403744,0.0034150914483082793,0.003198131084597359,0.0029949593784598014,0.00280470661042879,0.0026265327275420227,0.0024596878211013973,0.002303441889428844,0.0021571251563727856,0.0020201075046012797,0.0018917891138698906,0.0017716299820070465,0.0016591001282601308,0.001553719659568742,0.001455038591908912,0.001362626925886919,0.0012760847554697345,0.0011950420642582078,0.0011191389154798042,0.001048065343638882,0.0009815103500538196,0.0009191799860370035,0.0008608082571299747,0.0008061441913014278,0.0007549528236268088,0.0007070131444682678,0.0006621192102708543,0.0006200760011173164,0.0005807025590911508,0.0005438308920323228,0.0005093010113341734,0.00047696393448859453,0.0004466806713026017,0.0004183202302859475,0.0003917616292407426,0.00036688887485070154,0.0003435969847487286,0.00032178295077756047,0.0003013547951316771,0.0002822235279988187,0.0002643071420607157,0.00024752865404783125,0.00023181607199755186,0.0002171004004291414,0.0002033196457584078,0.0001904128075693734,0.0001783269047640109,0.00016700792305831177,0.00015640688313093656,0.00014647977877757512,0.00013718261713317284,0.0001284754034713842,0.00012032113954774104,0.00011268483043143836,0.00010553347541038723,9.883537859423086e-05,9.256284708195987e-05,8.668857602363762e-05,8.118717353985024e-05,7.60349369860099e-05,7.120977473581054e-05,6.669088179478422e-05,6.245886379474541e-05,5.8495421399129555e-05,5.478355615196051e-05,5.130737038901619e-05,4.805176407292796e-05,4.5002739170740824e-05,4.2147297184177056e-05,3.947303836563757e-05,3.696856462435486e-05,3.4622975969493076e-05,3.242627462896053e-05,3.036896032426739e-05,2.8442233997338917e-05,2.6637696919351583e-05,2.4947749352577375e-05,2.336499210287002e-05,2.1882726135421155e-05,2.049455103284951e-05,1.919436848159724e-05,1.7976778356872575e-05,1.6836381291795988e-05,1.576837773124377e-05,1.476816782997048e-05,1.383135243789487e-05,1.2954031490153284e-05,1.2132305679794323e-05,1.1362775088249085e-05,1.0642040024322341e-05,9.967040947837328e-06,9.334858077636454e-06,8.742791427115057e-06,8.188291379459164e-06,7.668958308689374e-06,7.182572214029885e-06,6.727043379820922e-06,6.300411807084553e-06,5.900847895645711e-06,5.526621634999174e-06,5.176143228406242e-06,4.847892834429028e-06,4.540460546801721e-06,4.252526537129597e-06,3.98286086541096e-06,3.730303603788343e-06,3.4937549457936257e-06,3.272214958845628e-06,3.064733637832736e-06,2.8704012038360815e-06,2.688397614747373e-06,2.517932974418121e-06,2.3582873988440647e-06,2.208760880269741e-06,2.0687234799273333e-06,1.9375552729646492e-06,1.8147163984849612e-06,1.6996667587439636e-06,1.5919064916640007e-06,1.4909855868457573e-06,1.3964541002072413e-06,1.3079320998106898e-06,1.2250095551280538e-06,1.1473565848518774e-06,1.074623147208816e-06,1.0064992750358215e-06,9.426940058195518e-07,8.829364143518129e-07,8.269684646696381e-07,7.745481790758882e-07,7.254516039741551e-07,6.794687503012634e-07,6.364006424064428e-07,5.96062278646059e-07,5.582816839933002e-07,5.228968831261227e-07,4.897548559294288e-07,4.587146567776775e-07,4.2964128018259845e-07,4.0241173356510746e-07,3.769080313039315e-07,3.530211903542598e-07,3.3064820333568906e-07,3.096930925039487e-07,2.90066860012909e-07,2.7168452021442135e-07,2.5446806972695413e-07,2.383415231103451e-07,2.2323788565851524e-07,2.0909215810623513e-07,1.958423538894749e-07,1.8343247276675356e-07,1.718095200923623e-07,1.6092249784567988e-07,1.5072541851660995e-07,1.4117528124302225e-07,1.322300834753302e-07,1.2385184078311795e-07,1.160045481896077e-07,1.0865521341922128e-07,7.697860304745063e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.744486888249714,19.401511351267498,20.625413576761883,22.65611473719279,24.764015197753906,26.94791555404663,29.20671510696411,31.39221413930257,33.35881265004476,35.11101245880127,36.6528107325236,37.988509813944496,39.121809323628746,40.056708335876465,40.79690647125244,41.346006075541176,41.70770581563314,41.950605392456055,42.14230537414551,42.283904711405434,42.37650489807129,42.4211041132609,42.41870371500651,42.37020460764567,42.27660338083903,42.138803482055664,41.9576031366984,41.74040253957113,41.49450270334879,41.22040208180746,40.91850217183431,40.58930238087972,40.23320198059082,39.85080178578695,39.44240156809489,39.0084015528361,38.54930146535238,38.082801818847656,37.62610117594401,37.17910130818685,36.74150149027506,36.31310176849365,35.893801053365074,35.483201026916504,35.08130137125651,34.68790086110433,34.302601178487144,33.92530155181885,33.55550161997477,33.193100929260254,32.83790111541748,32.48980108896891,32.148601373036705,31.814101219177246,31.48630126317342,31.16490125656128,30.84990119934082,30.540601412455242,30.23660151163737,29.93760124842326,29.643601258595783,29.35440142949422,29.070001284281414,28.79030132293701,28.515101114908855,28.244301319122314,27.97800127665202,27.716101328531902,27.458901246388752,27.206201394399006,26.95790147781372,26.713900725046795,26.474201520284016,26.23870086669922,26.007201194763184,25.779701391855877,25.556201140085857,25.33660125732422,25.120901107788086,24.909101168314617,24.701001167297363,24.49670139948527,24.296000957489014,24.09890127182007,23.905401070912678,23.715301513671875,23.528701146443684,23.344601313273113,23.162200927734375,22.981401284535725,22.80220127105713,22.624701182047527,22.448701063791912,22.27420123418172,22.101301352183025,21.929901123046875,21.760001182556152,21.59160089492798,21.424601395924885,21.259000937143963,21.094901084899902,20.932101249694824,20.77070140838623,20.61060110727946,20.451801141103108,20.294401168823242,20.138201077779133,19.983201026916504,19.829501152038574,19.677000999450684,19.52570120493571,19.375600973765057,19.226600964864094,19.078801155090332,18.932101090749104,18.78640127182007,18.64190101623535,18.498401006062824,18.35590108235677,18.21450122197469,18.0740008354187,17.934601147969563,17.7961007754008,17.65860080718994,17.52200110753377,17.386301040649414,17.251601219177246,17.117700735727947,16.984700838724773,16.852500756581623,16.721200784047443,16.59070078531901,16.46100091934204,16.332100868225098,16.203900973002117,16.07650105158488,15.94990070660909,15.823900779088339,15.698700666427612,15.574100812276205,15.450200716654459,15.326900800069174,15.204300800959269,15.082300821940104,14.960900863011679,14.840100765228271,14.719900767008463,14.600300709406534,14.48120085398356,14.362600723902384,14.244600613911947,14.127000649770102,14.010000705718994,13.893500725428263,13.777400493621826,13.661900599797567,13.546700636545816,13.432100693384806,13.317800680796305,13.204000552495321,13.090600570042929,12.977600495020548,12.86500064531962,12.752800544102987,12.641000588734945,12.529500563939413,12.418400526046753,12.307700475056967,12.197300354639689,12.08720072110494,11.977500518163046,11.86810048421224,11.759000619252523,11.650200446446737,11.54170044263204,11.433600425720215,11.325700521469116,11.218100468317667,11.110700527826944,11.003700415293375,10.896900335947672,10.790300448735556,10.68410054842631,10.578100363413492,10.47230052947998,10.366800467173258,10.261600335439047,10.15660031636556,10.05180033047994,9.947320302327475,9.843050479888916,9.739020347595215,9.635220289230347,9.531650384267172,9.42831047375997,9.325200319290161,9.222310304641724,9.119650284449259,9.017210324605307,8.914990425109863,8.81298025449117,8.711180369059244,8.609600305557251,8.508230209350586,8.407060305277506,8.30611022313436,8.205360253651937,8.1048002243042,8.00445012251536,7.904300212860107,7.804350217183431,7.704590201377869,7.605020205179851,7.505650122960408,7.406460126241048,7.307470162709554,7.208660085995992,7.110030134518941,7.011590123176575,6.913330078125,6.815250118573506,6.717350045839946,6.619630018870036,6.522080103556315,6.4247099955876665,6.327510118484497,6.230480035146077,6.133620063463847,6.036930004755656,5.940400044123332,5.844039996465047,5.747850060462952,5.651820023854573,5.555950045585632,5.460240006446838,5.364699999491374,5.269310037295024,5.174829959869385,5.081990043322246,4.990779995918274,4.901170015335083,4.813129981358846,4.726639986038208,4.641669988632202,4.558200041453044,4.476209998130798,4.395670056343079,4.316560069719951,4.238859971364339,4.162530024846395,4.087570110956828,4.0139400362968445,3.9416199922561646,3.8705999851226807,3.8008500138918557,3.7323400179545083,3.665059983730316,3.5989799896876016,3.5340900222460427,3.4703699747721353,3.407790025075277,3.346330006917318,3.2859700123469033,3.226700007915497,3.1685000459353128,3.1113399863243103,3.055209994316101,3.000090003013611,2.945959985256195,2.8928099870681763,2.840620001157125,2.7893699606259665,2.7390399972597756,2.689610004425049,2.6410799622535706,2.5934200088183084,2.5466299851735434,2.5006799896558127,2.4555499951044717,2.4112400015195212,2.3677300214767456,2.325010041395823,2.2830499609311423,2.2418499986330667,2.2014000018437705,2.161679963270823,2.1226699550946555,2.0843699971834817,2.0467600226402283,2.00982998808225,1.9735600153605144,1.9379500051339467,1.9029900133609772,1.868649999300639,1.834939996401469,1.8018300036589305,1.7693200012048085,1.7373999953269958,1.7060499986012776,1.6752699812253316,1.6450499892234802,1.6153700053691864,1.5862300097942352,1.5576200087865193,1.5295199950536091,1.5019200146198273,1.4748299916585286,1.4482299983501434,1.422100007534027,1.396450012922287,1.371259977420171,1.3465300103028615,1.3222400049368541,1.2983900010585785,1.27496999502182,1.2519800066947937,1.2293999989827473,1.2072199980417888,1.1854499975840251,1.1640700002511342,1.1430799861749013,1.1224599877993267,1.1022199889024098,1.0823400219281514,1.0628300110499065,1.0436599949995677,1.024839997291565,1.0063599894444148,0.9882150044043859,0.9703959971666336,0.9528980006774267,0.9357170015573502,0.9188450028498968,0.9022779961427053,0.8860100011030833,0.8700359960397085,0.8543500006198883,0.8389469981193542,0.8238219966491064,0.8089699993530909,0.7943859994411469,0.780064990123113,0.7660029977560043,0.7521940072377523,0.7386350035667419,0.7253199964761734,0.7122449974219004,0.6994059880574545,0.6867989947398504,0.6744199991226196,0.6622640043497086,0.6503269970417023,0.6386049936215082,0.6270949989557266,0.6157920062541962,0.604693998893102,0.5937959949175516,0.5830939958492914,0.572584996620814,0.562265987197558,0.5521329989035925,0.5421830068031946,0.5324120074510574,0.522817999124527,0.5133960048357645,0.5041449988881747,0.4950599993268649,0.48614000529050827,0.47738000502189,0.4687780017654101,0.4603309979041417,0.4520369991660118,0.4438920021057129,0.43589400003353757,0.4280400002996127,0.4203280011812846,0.4127550000945727,0.4053189953168233,0.39801599582036334,0.39084600160519284,0.38380399843056995,0.376890001197656,0.370099996527036,0.36343300094207126,0.35688599944114685,0.3504570002357165,0.34414300074179965,0.3379439984758695,0.33185700327157974,0.32587899764378864,0.3200089981158574,0.31424499799807865,0.30858400215705234,0.3030259981751442,0.2975680008530617,0.2922079960505168,0.28694500029087067,0.2817770019173622,0.2767019992073377,0.2717190037171046,0.26682500292857486,0.2620200018088023,0.2573009977738063,0.2526669998963674,0.2481170011063417,0.243648000061512,0.23926100134849548,0.2349520002802213,0.23072100058197975,0.2265659992893537,0.22248700012763342,0.21847999965151152,0.21454599996407828,0.21068299934267998,0.20688899978995323,0.20316400130589804,0.1995059996843338,0.19591400027275085,0.19238600134849548,0.1889219991862774,0.18552100161711374,0.18218099822600684,0.17890099932750067,0.1756800003349781,0.17251699914534888,0.16941099986433983,0.1663610003888607,0.16336600109934807,0.16042499989271164,0.15753700087467828,0.1547010007003943,0.1519160009920597,0.14918200050791106,0.14649600038925806,0.1438590002556642,0.141270000487566,0.13872699936230978,0.1362299993634224,0.13377800211310387,0.13137000054121017,0.12900499999523163,0.12668300171693167,0.12440300111969312,0.12216400044659774,0.11996500007808208,0.11780599939326446,0.11568600001434486,0.11360400107999642,0.1115590004871289,0.10955199971795082,0.10757999991377194,0.10564400007327397,0.10374299995601177,0.10187600056330363,0.10004300127426784,0.09824220029016335,0.09647430044909318,0.09473829964796703,0.09303350063661735,0.09135939925909042,0.08971550005177657,0.08810119951764743,0.08651590098937352,0.0849592008938392,0.08343059880038102,0.08192939994235833,0.0804553007086118,0.07900770070652167,0.07758619946738084,0.07619030028581619,0.074819499005874,0.07347340012590091,0.07215160069366296,0.0708535003165404,0.0695787997295459,0.06832709970573585,0.06709790043532848,0.06589079834520817,0.06470550162096818,0.0635413999358813,0.06239840015769005,0.06127590003112952,0.060173699942727886,0.05909120012074709,0.0580282990510265,0.05750170070677996};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.475295742352803,7.644586165746053,7.582157532374064,7.351792613665263,7.034193277359009,6.670862197875977,6.283046285311381,5.877943277359009,5.457773884137471,5.0261274973551435,4.585345268249512,4.1370328068733215,3.6823724508285522,3.2222707867622375,2.7574670910835266,2.288631876309713,1.8161840438842773,1.4367404480775197,1.2031207581361134,1.0479251046975453,0.9347550421953201,0.84410659968853,0.7654581864674886,0.6931386739015579,0.6240681807200114,0.5565806478261948,0.4897514382998149,0.4327146237095197,0.3905603438615799,0.3564837649464607,0.3267456218600273,0.2993108183145523,0.27305768926938373,0.2473778873682022,0.22193123400211334,0.1965340462823709,0.17107773572206497,0.15083506455024084,0.13882328694065413,0.13142721789578596,0.1266071709493796,0.123230770851175,0.12066425134738286,0.11854947792987029,0.11668402142822742,0.11495678685605526,0.11330563575029373,0.11177032440900803,0.11037801764905453,0.10906290573378404,0.10778982068101566,0.10653779158989589,0.10529377870261669,0.10405277460813522,0.1028107771029075,0.10156579005221526,0.10031578938166301,0.0991527009755373,0.09812729991972446,0.09717879196008046,0.09627210224668185,0.09539076251288255,0.09452233898142974,0.09365644119679928,0.09279043848315875,0.0919232467810313,0.09105374105274677,0.09030513775845368,0.08975200665493806,0.08931025303900242,0.0889276247471571,0.08858126898606618,0.08825462808211644,0.08793841302394867,0.08762730409701665,0.08731521293520927,0.08700559784968694,0.08672002516686916,0.08647124096751213,0.0862474013119936,0.08603468164801598,0.08582876808941364,0.08562696104248364,0.08542805475493272,0.08523443900048733,0.08504113120337327,0.08484864607453346,0.0845763273537159,0.08417697499195735,0.08370510240395863,0.08319217587510745,0.08265641704201698,0.08210823871195316,0.08155345109601815,0.08099535666406155,0.08043595775961876,0.07987625648578008,0.07931675699849923,0.07875775483747323,0.07819945365190506,0.07764185095826785,0.07708485051989555,0.07652844799061616,0.07597274892032146,0.07541754345099132,0.0748629489292701,0.07430535120268662,0.07374954596161842,0.07319494461019833,0.07264124353726704,0.07208804103235404,0.07153524085879326,0.0709827405711015,0.07043043834467728,0.06987843848764896,0.06932653797169526,0.06877483862141769,0.06822323674956958,0.06767173608144124,0.06712023665507634,0.06656883532802264,0.06601743710537751,0.06546603639920552,0.06491453448931377,0.06436313843975465,0.06380834430456161,0.06325493815044562,0.06270223918060462,0.062149837613105774,0.06159743759781122,0.06104473893841108,0.060491339613993965,0.05993734238048395,0.05938244331628084,0.0588268448288242,0.05827024765312672,0.05771284891913334,0.057154450876017414,0.05659525251636902,0.056035054847598076,0.05547385662794113,0.05491175906111797,0.05434875997404257,0.05378486340244611,0.053216674054662384,0.052649068335692085,0.0520813704157869,0.0515132707854112,0.05094457262506088,0.05037527345120907,0.049805275785426296,0.049234576212863125,0.04866317845880985,0.04809108003973961,0.047518380296727024,0.04694498206178347,0.0463709831237793,0.04579638441403707,0.045221285273631416,0.04464568663388491,0.04406968783587217,0.04349308833479881,0.0429160896067818,0.042335400357842445,0.04175579144308964,0.041176495142281055,0.04059749220808347,0.040018294006586075,0.03943909301112095,0.0388597942267855,0.038280293655892215,0.037700594402849674,0.03712079394608736,0.03654089445869128,0.03596089438845714,0.035380794356266655,0.034800694634517036,0.03422059491276741,0.03364049425969521,0.03306059384097656,0.0324777044976751,0.03189669114847978,0.031316895658771195,0.03073808814709385,0.030159990458438795,0.02958278652901451,0.029006185475736856,0.02843028384571274,0.02785498198742668,0.027280380328496296,0.026706379217406113,0.026132977412392695,0.025560276738057535,0.024988173817594845,0.024416773580014706,0.023846070437381666,0.023275871916363638,0.022706465640415747,0.022137570815781753,0.02156607247889042,0.020996667134265106,0.02042866436143716,0.01986186159774661,0.019295959888647,0.018730757602800924,0.018166456061104935,0.01760275491202871,0.017039752875765164,0.016477451504518587,0.015915749905010063,0.015354748349636793,0.014794346876442432,0.014234645136942467,0.013675544022892913,0.013117141555994749,0.012559441228707632,0.012002337413529554,0.011445840199788412,0.010886743975182375,0.01032963728842636,0.009774074812109271,0.009219602293645343,0.008666030364111066,0.008113278541713953,0.007561246942107876,0.007009925204329193,0.006459273708363374,0.005909282132051885,0.0053599605259175105,0.004811289060550432,0.004263267347899576,0.0037158961640670896,0.0031691736270052693,0.0026231045679499707,0.0020776764722540975,0.001532922430972879,0.0009887763008009642,0.0005606411965951944,0.0003176460789594178,0.0001799574056349229,0.00010190416166248421,5.7695448352509025e-05,3.2654549613653217e-05,1.847851315991041e-05,1.0453810091348714e-05,5.912975211685989e-06,3.3438213714968392e-06,1.890651304847779e-06,1.0688103297222067e-06,6.041261310466931e-07,3.414212557117935e-07,1.9292936670467498e-07,7.949021944379335e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0912282864252727,1.2003816366195679,1.2754012942314148,1.3648312191168468,1.4513312081495922,1.5350211958090465,1.616001119216283,1.6902110477288563,1.7537009418010712,1.8067708611488342,1.8496807714303334,1.8827206989129384,1.906130611896515,1.9201705157756805,1.9250804384549458,1.921110341946284,1.9084703226884205,1.8908803164958954,1.8719502985477448,1.8517202734947205,1.8302302559216816,1.807510217030843,1.7836102346579235,1.7585402031739552,1.7323501706123352,1.7050601541996002,1.6766901512940724,1.6477501193682353,1.6187101205190022,1.589570124944051,1.560330092906952,1.5309800903002422,1.501520077387492,1.471950074036916,1.442260056734085,1.4124600489934285,1.3825300534566243,1.352930059035619,1.3240800499916077,1.2959600587685902,1.2685400446256,1.2418200472990673,1.2157500783602397,1.1903400619824727,1.165550063053767,1.1413600345452626,1.1177700559298198,1.094750036795934,1.072280039389928,1.0503600339094799,1.0289700428644817,1.0080800453821819,0.9876900513966879,0.9677810370922089,0.9483390400807062,0.9293510367472967,0.9108030448357264,0.8926840474208196,0.8749810407559077,0.8576830377181371,0.840778037905693,0.8242540409167608,0.8081020365158716,0.7923110375801722,0.7768720388412476,0.7617730349302292,0.7470070372025172,0.7325720340013504,0.7184650301933289,0.704678033788999,0.6912020345528921,0.6780290355285009,0.6651520232359568,0.6525620420773824,0.6402530272801717,0.6282170315583547,0.6164480348428091,0.6049430320660273,0.5936990330616633,0.5827100376288096,0.5719690322875977,0.5614710400501887,0.551210030913353,0.5411800295114517,0.5313760389884313,0.5217930277188619,0.5124250402053198,0.5032640397548676,0.4943010285496712,0.4855320329467456,0.4769550288716952,0.46856402854124707,0.4603540276487668,0.45232002933820087,0.44446102778116864,0.4367690285046895,0.42924302568038303,0.42187802990277606,0.4146720344821612,0.40761902928352356,0.40071503072977066,0.39395802716414136,0.3873460267980893,0.3808720310529073,0.3745340307553609,0.3683290282885234,0.3622530276576678,0.35630302627881366,0.35047802577416104,0.344774030148983,0.33918702850739163,0.3337140257159869,0.3283540258804957,0.32310202221075696,0.31795602788527805,0.31291502714157104,0.30797702570756275,0.30313702672719955,0.29839302351077396,0.2937430242697398,0.2891850272814433,0.2847160225113233,0.28033602486054104,0.27604201932748157,0.2718300273021062,0.26769902805487317,0.26364802569150925,0.2596750234564145,0.2557770237326622,0.25195202479759854,0.24819902330636978,0.24451502288381258,0.24089902266860008,0.23735002304116884,0.2338660197953383,0.23044502238432565,0.22708402077356973,0.22378402079145113,0.22054201985398927,0.2173550215860208,0.21422502025961876,0.21114902198314667,0.20812601720293364,0.2051520198583603,0.20223002011577287,0.1993550198773543,0.196527020384868,0.19374601915478706,0.19101102029283842,0.1883190174897512,0.1856690173347791,0.18306201820572218,0.18049601713816324,0.17796801775693893,0.17547901843984923,0.1730280158420404,0.1706120160718759,0.16823201502362886,0.1658870168030262,0.16357701644301414,0.16130001718799272,0.15905301521221796,0.15684001644452414,0.15465601409475008,0.15250001475214958,0.150375014791886,0.14828001707792282,0.1462110144396623,0.14416801432768503,0.14215301225582758,0.1401630106071631,0.13819601510961851,0.1362550122042497,0.1343390109638373,0.13244501128792763,0.1305730106929938,0.12872501338521639,0.1268980155388514,0.1250920140494903,0.12330601178109646,0.12154001121719678,0.11979401111602783,0.11806501137713592,0.11635701109965642,0.11466801042358081,0.11299601135154565,0.11134001053869724,0.10970301118989785,0.10808100985984008,0.10647500927249591,0.10488600966831048,0.10331400918463866,0.10175600958367188,0.10021300924321015,0.09868490944306056,0.09717040881514549,0.09566900817056496,0.09418250682453315,0.09271060799558957,0.09125090762972832,0.08980300836265087,0.08836890694995721,0.08694810730715592,0.08553850650787354,0.08413960660497348,0.08275340559581916,0.0813776074598233,0.08001180551946163,0.07865800646444161,0.07731580485900243,0.07598300588627656,0.07465940527617931,0.07334690416852634,0.07204300599793594,0.0707478045175473,0.06946290408571561,0.06818830346067746,0.06692160417636235,0.06566270378728707,0.06441350343326728,0.06317160402735074,0.06193700339645147,0.06071160268038511,0.05949510292460521,0.05828540244450172,0.05708220197508732,0.05588750199725231,0.05470120161771774,0.05352100140104691,0.05234670080244541,0.05118030061324438,0.05001960135996342,0.048864501218001045,0.047716900085409485,0.04657670048375925,0.045441699835161366,0.0443116994574666,0.04319899994879961,0.042113700260718666,0.04105510003864765,0.04002269978324572,0.03901570041974386,0.03803369992723068,0.037076100086172424,0.03614219961067041,0.03523150024314722,0.03434359965225061,0.03347770031541586,0.032633500484128795,0.031810300114254154,0.03100780009602507,0.03022530007486542,0.029462400047729414,0.028718700011571247,0.027993600349873304,0.02728669981782635,0.02659759996458888,0.02592580004905661,0.02527090006818374,0.024632399901747704,0.024010100091497105,0.023403399779150885,0.022812000010162592,0.022235399888207514,0.021673500072211027,0.02112570001433293,0.020591699983924627,0.020071200095117092,0.019563800034423668,0.019069300188372534,0.018587199815859396,0.018117299769073725,0.01765920004496972,0.017212800060709316,0.016777599851290386,0.016353399958461523,0.01593999983742833,0.015536899911239743,0.015144099947065115,0.014761200019468864,0.014388000049317876,0.014024199917912483,0.01366959985656043,0.013324000096569458,0.012987099898358187,0.0126587999984622,0.012338700083394846,0.012026800075545907,0.011722700049479803,0.011426299965629974,0.011137399977693955,0.010855899890884757,0.010581400012597442,0.010313900032391151,0.0100532000263532,0.00979901997682949,0.00955130998045206,0.009309850012262663,0.009074509997541705,0.008845119892309109,0.008621529831240574,0.008403589949011803,0.008191170015682777,0.007984129789595803,0.007782319909892976,0.007585610069024066,0.007393880009961625,0.007206999968426923,0.007024849959028264,0.006847300023461382,0.0066742399940267205,0.006505560052270691,0.006341149991688629,0.006180900032632053,0.006024700007401407,0.005872449992845456,0.005724039976485074,0.0055793999539067345,0.005438409939718743,0.005300979983682434,0.005167040042579174,0.005036470014601946,0.004909209945860009,0.004785169924919804,0.004664270013260345,0.004546419950202107,0.004431550002967318,0.004319579961399238,0.004210450065632661,0.004104080027900636,0.004000389987292389,0.003899330001634856,0.0038008200159917274,0.003704799998862048,0.003611209957549969,0.003519990035177519,0.0034310699945005276,0.0033443999903587005,0.0032599200300561884,0.0031775799967969456,0.0030973199948978922,0.0030190800122606256,0.0029428300137321153,0.0028684999560937285,0.002796049986500293,0.002725429968753209,0.0026566000500073037,0.002589499985333532,0.002524100011214614,0.002460360003169626,0.0023982199685027203,0.0023376599807913103,0.002278620027936995,0.0022210799894916513,0.0021650000126101077,0.002110320026986301,0.002057039993815124,0.00200509000569582,0.0019544599927030504,0.0019051099952775985,0.0018570100073702633,0.0018101199918116133,0.0017644199930752318,0.0017198700127967943,0.0016764499887358397,0.0016341200001382579,0.0015928599847635876,0.0015526499967866887,0.00151344999903813,0.0014752399971863877,0.0014379999871986608,0.001401700001830856,0.0013663099962286651,0.0013318199974795182,0.0012982000189367682,0.0012654299886586766,0.0012334900093264878,0.0012023499972807865,0.0011719999893102795,0.00114242000078472,0.0011135799965510766,0.0010854699939955026,0.0010580800008028746,0.0010313699992063146,0.0010053399989070992,0.0009799659940957401,0.0009552330060008293,0.000931125003262423,0.0009076249989448115,0.0008847200030383343,0.0008623920002719387,0.0008406280054866025,0.0008194140003373226,0.0007987360004335642,0.000778579997131601,0.00075893200119026,0.000739781001660352,0.0007211139988309393,0.0007029169937595725,0.0006851809885120019,0.0006678919841457779,0.0006510390036661798,0.0006346120014010618,0.0006186000052063415,0.0006029919944315528,0.0005877779913134873,0.00057294800838766,0.0005584930040640756,0.0005444030005795261,0.0005306679959176108,0.0005172799913755929,0.0005042299987204993,0.0004915089957648888,0.0004791100000147708,0.00046702299975246814,0.00045524199958890676,0.0004437580015898372,0.0004325629973512453,0.0004216520004168463,0.0004110160007257946,0.00040064799880686525,0.0003905420016963035,0.0003806909977962884,0.0003710889965683843,0.00036172900096668553,0.0003526049986248836,0.00034371100142986205,0.00033504200109746307,0.0003265919998132934,0.0003183549997629598,0.000310325999938262,0.00030249999933099997,0.00029487099770146113,0.00028743399889208376,0.00028018499627554166,0.00027311899611959234,0.00026623199907286715,0.0002595180000450152,0.00025297299968466785,0.0002465940027226073,0.0002403760008746758,0.00023431400162129043,0.00022840600043612844,0.00022264700116162808,0.0002170329995957824,0.0002115600000252016,0.00020622600034888214,0.00020102599955862388,0.000195957002385209,0.00019101699945167638,0.0001862009994511027,0.00018150600105097206,0.00017692999972496182,0.00017246899975968213,0.00016812100026678914,0.00016388199946959503,0.00015975100177456625,0.00015572299889754504,0.00015179799811448902,0.00014797100084251724,0.00014424100057415976,0.0001406050008275391,0.00013706000027013943,0.000133605000883108,0.00013023700012126938,0.00012695400073425844,0.0001237539994084121,0.00012063500010602486,0.00011759400028192128,0.00011462999888559959,0.0001117409992730245,0.00010892400071800996,0.00010617900018890698,0.00010350299938484871,0.00010089400044914025,9.835129943288241e-05,9.587249951437116e-05,9.345619946543593e-05,9.110090104513802e-05,8.880499929849368e-05,8.656699962254304e-05,8.438540013836852e-05,8.225880022412942e-05,8.018580047064461e-05,7.816510030049055e-05,7.716759985972506e-05};
        HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.94642210006714,28.906192461649578,29.83809487024943,30.606096267700195,31.154297828674316,31.483599026997883,31.5951992670695,31.591698964436848,31.57539939880371,31.546199639638264,31.504099527994793,31.449099858601887,31.381199836730957,31.300499598185223,31.206899801890057,31.100499947865803,30.981200218200684,30.855699857076008,30.730399926503498,30.605299949645996,30.48050006230672,30.355900128682453,30.231499989827473,30.107499917348225,29.983700116475422,29.86019976933797,29.736899852752686,29.614199956258137,29.492200056711834,29.37089999516805,29.250399748484295,29.130499839782715,29.01130024592082,28.892799854278564,28.775000254313152,28.657900015513103,28.54139995574951,28.425599892934162,28.310499986012776,28.196099917093914,28.08240032196045,27.969300111134846,27.856799920399983,27.745099862416584,27.63390016555786,27.52340014775594,27.413599967956543,27.3042999903361,27.19569985071818,27.08769941329956,26.980300108591717,26.873600006103516,26.76740010579427,26.661799907684326,26.55679988861084,26.45240004857381,26.348600069681805,26.24530013402303,26.142599900563557,26.040300051371258,25.938599904378254,25.83740011850993,25.7367000579834,25.636499722798664,25.53670008977254,25.437500317891438,25.338799794514973,25.24050013224284,25.142500082651775,25.044999917348225,24.947800318400066,24.851000150044758,24.754599889119465,24.658599853515625,24.562899907430012,24.467499891916912,24.37250010172526,24.277900060017902,24.18369992574056,24.089800039927166,23.99619992574056,23.90310001373291,23.81030019124349,23.71779998143514,23.625699996948242,23.534000078837078,23.44260009129842,23.351600170135498,23.26100031534831,23.170600096384685,23.080699761708576,22.991000175476074,22.901699701944988,22.81280008951823,22.724199930826824,22.635900020599365,22.54800017674764,22.460500081380207,22.373299916585285,22.286400000254314,22.199899832407635,22.113699913024902,22.027799606323242,21.942300001780193,21.857199827829998,21.772300084431965,21.687900225321453,21.603700160980225,21.51989984512329,21.436400095621746,21.353299776713055,21.270500024159748,21.187999884287517,21.105899969736736,21.024100303649902,20.942599773406982,20.861499945322674,20.780699888865154,20.700200080871582,20.619999885559082,20.540200074513752,20.460699717203777,20.381500244140625,20.302599906921387,20.224000136057537,20.145799954732258,20.06790018081665,19.990299860636394,19.912999788920086,19.835999806722004,19.759400208791096,19.683000246683758,19.60699987411499,19.53130006790161,19.455799738566082,19.38070011138916,19.30590009689331,19.231300195058186,19.157100041707356,19.083100001017254,19.009499708811443,18.936100165049236,18.86300007502238,18.790200074513752,18.717700004577637,18.64549970626831,18.57349983851115,18.501799901326496,18.430399894714355,18.359299818674724,18.288400332132976,18.21780014038086,18.14740006128947,18.077399730682373,18.007500012715656,17.937999884287517,17.86870002746582,17.79959996541341,17.73080015182495,17.66230010986328,17.59400002161662,17.526000022888184,17.458099842071533,17.390600045522053,17.323299725850422,17.256199677785236,17.18940003712972,17.12280003229777,17.056399822235107,16.990299542744953,16.924400011698406,16.858699957529705,16.79330015182495,16.728000005086262,16.663000106811523,16.598299980163574,16.53370014826457,16.46940024693807,16.4052996635437,16.341400146484375,16.2777001063029,16.21430015563965,16.150999863942463,16.088000138600666,16.025200446446735,15.962599992752075,15.900199890136719,15.837999979654947,15.776099920272827,15.71429999669393,15.65280000368754,15.591399828592936,15.530300060907999,15.46940016746521,15.408699989318848,15.348099946975708,15.287799914677938,15.227800051371256,15.167900005976358,15.108199993769327,15.048700014750162,14.989399909973145,14.93030015627543,14.871499935785929,14.81279993057251,14.754299958546957,14.69599994023641,14.638000090916952,14.580100059509277,14.522400061289469,14.464900016784668,14.407700061798096,14.350600004196167,14.293699979782104,14.236999909083048,14.180500030517578,14.124199946721395,14.068100055058798,14.012199958165487,13.956400076548258,13.900899966557821,13.84559996922811,13.7903999487559,13.735499858856201,13.680699904759726,13.626099983851114,13.57170001665751,13.517500003178915,13.463499863942465,13.40969999631246,13.35599978764852,13.302599986394247,13.249300003051758,13.196199893951416,13.14329997698466,13.09060001373291,13.038100083669027,12.985700050989786,12.933600028355917,12.881600062052408,12.829799969991049,12.778199990590414,12.726699908574423,12.67550015449524,12.624399979909262,12.573599974314371,12.522900104522705,12.472399950027466,12.422099987665812,12.371999979019165,12.322100003560385,12.272400061289469,12.22290007273356,12.173499981562296,12.12440005938212,12.075400114059448,12.026700019836426,11.978100061416626,11.929700056711832,11.881500164667765,11.833499987920126,11.785699923833212,11.738099972407023,11.690700054168701,11.643399874369303,11.596400022506714,11.549499988555908,11.502800067265829,11.456299861272177,11.410000006357828,11.363900105158487,11.317999998728434,11.272199948628744,11.226600170135498,11.18119994799296,11.135999917984009,11.090999921162924,11.046199957529703,11.001499970753988,10.957099994023642,10.912799994150797,10.868599891662598,10.824700117111206,10.780900001525879,10.73739997545878,10.694000005722046,10.650700012842814,10.607700109481812,10.564799944559732,10.52209997177124,10.47950005531311,10.43720006942749,10.394999980926514,10.352999925613403,10.311100006103516,10.269400119781494,10.227899869283041,10.186599969863892,10.145400126775106,10.104399919509888,10.063599904378256,10.022899866104126,9.982379833857218,9.942039966583252,9.901859998703003,9.861840009689331,9.821979999542236,9.782289981842041,9.742759784062704,9.70337994893392,9.664169867833456,9.625120004018148,9.586219787597656,9.547489960988363,9.508909940719604,9.4704798857371,9.432219982147217,9.394110043843588,9.356149991353353,9.318350156148275,9.280700047810873,9.243200063705444,9.205859978993734,9.168660004933676,9.131619930267334,9.094730059305826,9.057989994684855,9.021400054295858,8.984949986139933,8.948659896850586,8.91250983874003,8.87650998433431,8.840650002161661,8.804940064748129,8.769369920094809,8.733950138092041,8.69867992401123,8.66353996594747,8.628549973169962,8.593700170516968,8.558989842732748,8.524420022964478,8.489999930063883,8.45570993423462,8.421559890111288,8.387550036112467,8.35368005434672,8.319940090179443,8.286350011825562,8.252880096435547,8.219559987386068,8.186369975407919,8.153309981028238,8.120390017827352,8.087599992752075,8.05495015780131,8.022420088450113,7.99003001054128,7.957769989967346,7.925640106201172,7.893640001614888,7.861779967943828,7.830040017763774,7.798420071601868,7.766940037409465,7.735589941342671,7.704360008239746,7.6732600927352905,7.6422799825668335,7.611430009206136,7.580710053443909,7.550110061963399,7.519629995028178,7.489280064900716,7.4590500593185425,7.4289400180180865,7.398960034052531,7.369089961051941,7.339350024859111,7.309729973475139,7.2802300453186035,7.250840067863464,7.221579949061076,7.192430019378662,7.163410027821858,7.1344999472300215,7.105710029602051,7.077030022939046,7.048469980557759,7.020029942194621,6.991700053215027,6.963489969571431,6.935390114784241,6.907399972279866,6.87952999273936,6.851770003636678,6.824130018552144,6.796590010325114,6.769170045852661,6.741859992345174,6.714659969011943,6.6875700155893965,6.660580039024353,6.633710026741028,6.606949965159099,6.580289959907532,6.553750038146973,6.527309974034627,6.500979979832967,6.47475000222524,6.448630015055339,6.422620058059692,6.39670991897583,6.370909929275513,6.345209956169128,6.319609999656677,6.294120033582051,6.268730004628499,6.243449966112773,6.218269944190979,6.193179965019226,6.168209989865621,6.143330057462056,6.118550062179565,6.0938700040181475,6.069299976030986,6.044819990793864,6.020440022150676,5.99615999062856,5.971980055173238,5.947890003522237,5.923909982045491,5.900020003318787,5.876230001449585,5.852530042330424,5.828929940859477,5.805429975191752,5.7820199728012085,5.758699973424275,5.735480070114136,5.7123600244522095,5.689319928487142,5.666380047798157,5.643539985020955,5.620779951413472,5.5981199741363525,5.575549999872844,5.553070028622945,5.530680100123088,5.508379975954692,5.486180027325948,5.464059988657634,5.442030032475789,5.420089960098267,5.398240049680074,5.376480023066203,5.354809999465942,5.3332200050354,5.311720013618469,5.2903099457422895,5.2689900398254395,5.247750004132588,5.226590037345886,5.205530047416687,5.184550007184346,5.163649956385295,5.142839948336284,5.12210996945699,5.101459980010986,5.080899993578593,5.060420036315918,5.040030042330424,5.019719998041789,4.999490062395732,4.979339996973674,4.959269920984904,4.939280033111572,4.919379909833272,4.899549961090088,4.879810015360515,4.8601500193278,4.840559959411621,4.821049968401591,4.801630020141602,4.782279968261719,4.772619962692261};
        //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.1404715788861116,0.14906380822261175,0.1587368572751681,0.168672863394022,0.1789028582473596,0.18942385539412498,0.2002358635266622,0.21079787239432335,0.22056687995791435,0.22954988976319632,0.23774989818533263,0.245167908569177,0.25180791566769284,0.2576749299963315,0.26277193427085876,0.2671009401480357,0.270664947728316,0.27374494820833206,0.27661795417467755,0.2792869533101718,0.2817509522040685,0.28401296337445575,0.28606995691855747,0.28792496273914975,0.28957997014125186,0.2910359675685565,0.2922939732670784,0.2933799723784129,0.2943239783247312,0.29512397944927216,0.2957799807190895,0.29629498223463696,0.29666898896296817,0.29690198600292206,0.29699598252773285,0.29694799333810806,0.296761987109979,0.2965109869837761,0.2962679862976074,0.29603198170661926,0.2958029930790265,0.29558098812898,0.29536598175764084,0.2951579838991165,0.2949569871028264,0.2947629888852437,0.2945759842793147,0.29439398646354675,0.2942139854033788,0.29403898616631824,0.293868991235892,0.2937009905775388,0.2935369908809662,0.29337598631779355,0.293219988544782,0.29306699335575104,0.29291799167792004,0.29277198761701584,0.29262498517831165,0.29247798522313434,0.2923319886128108,0.2921849886576335,0.2920369853576024,0.2918919896086057,0.29174698640902835,0.2916009873151779,0.2914549857378006,0.291309987505277,0.29116998612880707,0.2910339857141177,0.2909029846390088,0.2907759870092074,0.2906539862354596,0.29053598642349243,0.2904219850897789,0.2903119872013728,0.2902069886525472,0.2901039868593216,0.2900029892722766,0.28990598767995834,0.2898139903942744,0.2897239848971367,0.2896369844675064,0.28955398748318356,0.2894749889771144,0.28939899057149887,0.2893249839544296,0.2892489830652873,0.2891659860809644,0.28907498717308044,0.2889779880642891,0.2888759846488635,0.2887669901053111,0.288649986187617,0.2885259861747424,0.2883949925502141,0.2882569879293442,0.28811098635196686,0.287959985435009,0.2878039851784706,0.2876409888267517,0.2874709864457448,0.28729398796955746,0.28710998843113583,0.2869189878304799,0.28672098368406296,0.28651899099349976,0.28631099065144855,0.28609599173069,0.28587499012549716,0.2856469874580701,0.2854129920403163,0.2851709897319476,0.2849229872226715,0.28467098623514175,0.28441299001375836,0.2841489886244138,0.28387898455063504,0.28360198934872943,0.28331898897886276,0.283028985063235,0.2827319900194804,0.2824319874246915,0.282125989596049,0.2818149949113528,0.28149698426326114,0.2811729932824771,0.2808419888218244,0.2805059899886449,0.2801629876097043,0.2798159917195638,0.2794639940063159,0.2791069919864337,0.2787429913878441,0.27837299307187396,0.2779969945549965,0.27761398752530414,0.27722599109013873,0.27683299283186596,0.2764369919896126,0.2760339876015981,0.27562399208545685,0.2752089972297351,0.27478798975547153,0.2743609920144081,0.2739269956946373,0.27348998934030533,0.2730479910969734,0.2725999876856804,0.27214599400758743,0.27168599267800647,0.27121999363104504,0.2707489902774493,0.2702699974179268,0.2697879920403163,0.26930199066797894,0.2688099890947342,0.2683119922876358,0.2678079878290494,0.26729799310366315,0.266780989865462,0.2662609914938609,0.26573699216047925,0.2652069901426633,0.2646709953745206,0.26412899295488995,0.2635809928178787,0.26302698999643326,0.26246699194113415,0.26190299540758133,0.26133599629004794,0.2607619936267535,0.2601819932460785,0.2595969984928767,0.25900599360466003,0.2584089959661166,0.25780599812666577,0.2571989968419075,0.25658798962831497,0.2559709921479225,0.25534899284442264,0.2547209958235423,0.2540869936347008,0.2534469962120056,0.25280199696620304,0.25215299675861996,0.2514999931057294,0.25084099918603897,0.2501769947508971,0.2495079959432284,0.24883199607332548,0.24815199648340544,0.24746499583125114,0.2467749963204066,0.24608199670910835,0.2453829968969027,0.24467899650335312,0.243968998392423,0.2432539959748586,0.2425329958399137,0.2418069951236248,0.2410779967904091,0.24034499625364938,0.23960699637730917,0.23886399591962496,0.23811599612236023,0.2373619961241881,0.2366029992699623,0.2358389968673388,0.23507199684778848,0.2343019979695479,0.23352599889039993,0.23274499798814455,0.2319599986076355,0.23116899902621904,0.2303729976216952,0.2295729989806811,0.22876899813612303,0.22796199967463812,0.22715000063180923,0.22633399814367294,0.22551200042168298,0.22468599925438562,0.22385499874750772,0.22301799928148588,0.2221800001959006,0.22133799890677133,0.22049099827806154,0.21963999792933464,0.21878400072455406,0.21792300045490265,0.21705800046523413,0.2161879986524582,0.21531500046451887,0.2144390009343624,0.2135590004424254,0.21267399936914444,0.2117889995376269,0.21090699980656305,0.2100280001759529,0.20915299902359644,0.20827999959389368,0.20741100112597147,0.20654599741101265,0.20568300286928812,0.20482500021656355,0.20396900177001953,0.20311699931820235,0.2022679994503657,0.2014220009247462,0.20057999839385351,0.19974099968870482,0.19890599946180978,0.19807399933536848,0.19724500055114427,0.1964200014869372,0.19559799879789352,0.19477899993459383,0.19396399954954782,0.19315199926495552,0.19234399870038033,0.19153799985845885,0.19073599949479103,0.18993799885114035,0.18914199993014336,0.1883500007291635,0.18756100038687387,0.18677600100636482,0.18599400048454603,0.18521499757965407,0.18443900098403296,0.18366600076357523,0.18289699902137121,0.18213100110491118,0.18136800080537796,0.180607999364535,0.17985200136899948,0.1790979988873005,0.17834800109267235,0.17760100215673447,0.1768570008377234,0.17611599961916605,0.17537900060415268,0.1746439995865027,0.17391199991106987,0.173184002439181,0.17245799799760184,0.17173599948485693,0.1710169998308023,0.17029999941587448,0.16958699996272722,0.16887700061003366,0.16816900049646696,0.16746500010291734,0.16676400105158487,0.16606500123937926,0.1653699999054273,0.16467700277765593,0.16398700202504793,0.16330100099245706,0.16261699795722961,0.16193600123127302,0.16125799963871637,0.16058200225234032,0.15990999961892763,0.1592399999499321,0.15857299913962683,0.15790899967153868,0.15724800154566765,0.15659000103672346,0.15593399852514267,0.15528099983930588,0.1546310012539228,0.15398299942413965,0.15333899979790053,0.1526970018943151,0.15205700074632963,0.15142100056012472,0.15078699961304665,0.1501560000081857,0.14952700212597847,0.14890100061893463,0.14827799797058105,0.1476570007701715,0.1470389999449253,0.1464229996005694,0.14581000059843063,0.14520000045498213,0.14459199955066046,0.1439869962632656,0.14338399966557822,0.14278400068481764,0.14218700056274733,0.14159100006024042,0.14099900051951408,0.14040899773438772,0.13982100039720535,0.13923599943518639,0.13865300143758455,0.13807299981514612,0.1374949999153614,0.13692000011603037,0.13634700079758963,0.13577599947651228,0.13520799949765205,0.13464200124144554,0.13407900060216585,0.13351800044377646,0.1329590007662773,0.13240299994746843,0.13184900085131326,0.13129699851075807,0.13074799999594688,0.13020099947849909,0.12965600192546844,0.12911399950583777,0.1285730004310608,0.12803600231806436,0.1275000013411045,0.12696600084503493,0.12643500044941902,0.1259060005346934,0.12537999947865805,0.1248549980421861,0.12433300043145816,0.12381299957633018,0.12329499920209248,0.1227790005505085,0.12226599951585133,0.12175399934252103,0.12124499926964442,0.12073799967765808,0.1202329999456803,0.11973000007371108,0.11922899944086869,0.11873099952936172,0.11823399861653645,0.11773900004724662,0.1172469990948836,0.11675700048605601,0.11626800149679184,0.11578199950357278,0.11529799985388915,0.11481599944333236,0.11433599889278412,0.11385799944400787,0.11338199923435847,0.11290699988603592,0.11243500063816707,0.11196499938766162,0.11149699923892815,0.1110310001919667,0.11056700100501378,0.11010399957497914,0.10964399886627992,0.10918499963978927,0.10872899927198887,0.10827399976551533,0.10782200035949548,0.10737099995215733,0.10692200002570947,0.10647500058015187,0.1060299991319577,0.1055869994064172,0.10514500054220359,0.1047059999157985,0.10426800015072028,0.1038320002456506,0.10339799957970779,0.10296600063641866,0.10253599969049294,0.10210700084765752,0.10168000000218551,0.10125499963760376,0.100832000374794,0.10041000135242939,0.09999080126484235,0.0995728000998497,0.09915669945379098,0.09874230002363522,0.09832959932585557,0.09791859860221545,0.09750940029819806,0.09710189948479335,0.09669609926640987,0.09629199964304765,0.09588959937294324,0.09548889907697837,0.0950897994140784,0.09469239910443623,0.09429679997265339,0.09390270027021567,0.09351029930015405,0.0931196001668771,0.09273049980401993,0.09234300069510937,0.09195719907681148,0.091572900613149,0.09119030088186264,0.09080929992099603,0.09042990145583947,0.09005210051933925,0.08967579963306586,0.08930120058357716,0.08892809910078843,0.08855660011370976,0.08818659993509452,0.08781820038954417,0.08745130027333896,0.08708600016931693,0.08672219949464004,0.0863598994910717,0.08599910015861194,0.08563989959657192,0.08528210036456585,0.08492590114474297,0.08457109952966373,0.08421790041029453,0.0838660995165507,0.08351579991479714,0.08316699974238873,0.08281960090001424,0.0824737014869849,0.08212919905781746,0.08178620040416718,0.08144460059702396,0.08110439963638783,0.08076569934686025,0.08042840038736661,0.08009249965349834,0.079758000249664,0.07942490031321843,0.07909319984416167,0.07876290008425713,0.07843400041262309,0.0781064002464215,0.07778030075132847,0.07745549951990445,0.07713199903567632,0.07680989988148212,0.076489199573795,0.07616979939242204,0.07585169995824496,0.0755350012332201,0.07521960015098254,0.07506230100989342};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2241610487302146,2.4407403071721396,2.6055001815160117,2.797560195128123,2.9832401871681213,3.163590212663015,3.339480181535085,3.485910177230835,3.580720146497091,3.630070149898529,3.639260152975718,3.61296010017395,3.5552401145299277,3.4696501096089682,3.359350085258484,3.2270800868670144,3.075290103753408,2.919510066509247,2.7735100984573364,2.6360900600751243,2.506200095017751,2.3829000989596048,2.2653600573539734,2.152850031852722,2.0447300374507904,1.940420041481654,1.839430034160614,1.7425600290298462,1.6505400240421295,1.5627400477727253,1.478620042403539,1.3976800441741943,1.3195000092188518,1.2437000373999278,1.1699700057506561,1.0980000098546345,1.0275500118732452,0.9618890186150869,0.9039210180441538,0.8527660171190897,0.8076460162798563,0.76787302394708,0.7328380147616068,0.702003022034963,0.6748920232057571,0.6510860224564871,0.6302110155423483,0.6118660221497217,0.5956940253575643,0.5814510136842728,0.5689200162887573,0.5579100201527277,0.5482520163059235,0.5397950261831284,0.5324060171842575,0.5259670168161392,0.5203730165958405,0.5154510090748469,0.5110470155874888,0.5071030209461848,0.5035670250654221,0.5003940165042877,0.49754202117522556,0.49497701972723007,0.49266501764456433,0.4905810207128525,0.48869702219963074,0.4870930189887683,0.48583701997995377,0.4848890155553818,0.48421502113342285,0.4837840224305789,0.48356902102629346,0.483545017739137,0.4836920176943143,0.4839890201886495,0.4844210197528203,0.4849620188275973,0.48559101670980453,0.4862970213095347,0.4870740200082461,0.48791301995515823,0.4888090218106906,0.489756020406882,0.4907490188876788,0.4917840212583542,0.49285801748434704,0.49371302376190823,0.49411402146021527,0.4941120172540347,0.49375302096207935,0.49307502061128616,0.49211202065149945,0.4908950130144755,0.4894530177116394,0.48781101405620575,0.4859890167911847,0.48400601496299106,0.4818830192089081,0.47963402171929675,0.47727101296186447,0.4748060156901677,0.47225401798884076,0.469621017575264,0.4669160147507985,0.46415001650651294,0.46132901559273404,0.45845601459344226,0.45553801705439884,0.45258201907078427,0.44959201912085217,0.4465700164437294,0.4435180127620697,0.4404430165886879,0.43734701971213025,0.4342300146818161,0.43109401563803357,0.42794401198625565,0.4247790103157361,0.4216010148326556,0.41841301570336026,0.41521601130565006,0.4120090107123057,0.40879301478465396,0.405571016172568,0.4023440132538478,0.399110014239947,0.39587001502513885,0.39262601484855014,0.38937901457150775,0.38612601161003113,0.3828670134147008,0.3796050151189168,0.3763370141386986,0.3730630154410998,0.36978501081466675,0.3665040135383606,0.3632170135776202,0.35992301255464554,0.3566260089476903,0.3533250118295352,0.3500170061985652,0.34670300781726837,0.3433850134412448,0.34006301065286,0.3367350126306216,0.3334000160296758,0.33006101349989575,0.32671601325273514,0.3233650078376134,0.3200110122561455,0.3166520098845164,0.31328800817330676,0.3099170078833898,0.306543009976546,0.3031660094857216,0.29978301127751666,0.29639500627915066,0.2930040086309115,0.2896090125044187,0.28621000548203784,0.2828060140212377,0.2793990100423495,0.27598700920740765,0.27257100741068524,0.26915401220321655,0.2657340044776599,0.2623100106914838,0.2588820109764735,0.2554520045717557,0.25202200561761856,0.2485870085656643,0.24515000730752945,0.24171100681026778,0.2382710079352061,0.2348290098210176,0.23138400663932165,0.22793800756335258,0.22449000800649324,0.2210400067269802,0.21759100879232088,0.2141420083741347,0.2106930067141851,0.20724300667643547,0.20379500711957613,0.20034900680184364,0.19690400486191115,0.19345800330241522,0.19001600642999014,0.18657700469096503,0.18313800419370332,0.17970100417733192,0.1762670042614142,0.1728350023428599,0.16940400625268617,0.16597800453503928,0.1625550054013729,0.15913400426506996,0.15571600571274757,0.152301004777352,0.14889100442330042,0.1454820049305757,0.14207600305477777,0.13867500548561415,0.13527800142765045,0.13188200443983078,0.1284900059302648,0.12510200341542563,0.12171600386500359,0.11833200417459011,0.11495400406420231,0.11158000181118648,0.10820800438523293,0.10483900209267934,0.1014750028649966,0.09811530262231827,0.09475800395011902,0.09140320246418317,0.08805330221851666,0.08470810080567996,0.0813652016222477,0.0780248021086057,0.07468920076886813,0.07135610158244769,0.06802560140689214,0.0647000012298425,0.061379301672180496,0.05806090123951435,0.05474510074903568,0.05143430083990097,0.04812820069491863,0.04482450056821108,0.04152330011129379,0.03822699996332327,0.03493549985190233,0.03164640022441745,0.02835980011150241,0.025254599905262392,0.022487900064637262,0.020023200040062267,0.01782749981308977,0.015871800094222028,0.014129899985467395,0.012578699893007675,0.01119719996737937,0.00996713999969264,0.008871849936743578,0.007896660012193024,0.007028439974722763,0.006255499979791542,0.005567419963578383,0.004954899932878713,0.004409670014865696,0.003924349982601901,0.003492380007325361,0.003107910005686184,0.0027657099805461862,0.0024611600286637745,0.002190110021426032,0.0019488899949161957,0.0017342200056494523,0.0015431799984071404,0.0013731699824954073,0.001221879996592179,0.0010872499939675133,0.0009674530010670424,0.000860846004798077,0.000765981991814139,0.0006815690042761465,0.000606456000241451,0.0005396190002405395,0.0004801459969409431,0.00042722699921190116,0.00038013899999593076,0.0003382400027476251,0.0003009590024400192,0.0002677870021822552,0.0002382709972152952,0.0002120080013507201,0.00018863999866880476,0.00016784699982963502,0.0001493460003985092,0.00013288500122143887,0.00011823800074732087,0.00010520499987857572,9.360939960364097e-05,8.329159936693031e-05,7.411119986500125e-05,6.594270053028595e-05,5.8674600647160936e-05,5.2207599461932354e-05,4.645350024172027e-05,4.1333699603759065e-05,3.6778200107316174e-05,3.272479989391286e-05,2.9118200018274365e-05,2.5909100107431488e-05,2.3053799850458745e-05,2.051310017729217e-05,1.8252500012749806e-05,1.6241100032251172e-05,1.4451300027455241e-05,1.2858799967337594e-05,1.1441800097600208e-05,1.018100003117676e-05,9.059129903713862e-06,8.060909825265602e-06,7.172690023556545e-06,6.3823600081983995e-06,5.679130026692292e-06,5.053389979063165e-06,4.49661001766799e-06,4.001180040328715e-06,3.560349966846843e-06,3.1680900178798765e-06,2.819059962651712e-06,2.5084799896527934e-06,2.2321299676756703e-06,1.9862299893702584e-06,1.7674200023520825e-06,1.572719990387365e-06,1.3994699846383203e-06,1.2453099884623953e-06,1.1081299836253795e-06,9.860649896609175e-07,8.774490064903754e-07,7.807990082634811e-07,6.947960002889886e-07,6.182680039046318e-07,5.501699954872189e-07,4.895739967499443e-07,4.356530046341807e-07,3.8767200057539714e-07,3.4497599917434246e-07,3.0698200248480134e-07,2.7317400016121e-07,2.43090000869491e-07,2.1631899945380914e-07,1.9249699908148918e-07,1.7129900105790816e-07,1.5243500091817927e-07,1.356490007727492e-07,1.2071200098754767e-07,1.074200005983054e-07,8.398765534896787e-09,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.83471910158793,12.709800799687704,13.146400451660156,13.803100188573202,13.641600131988525,12.805300076802572,11.41130018234253,9.889789978663126,8.595030069351196,7.484940052032471,6.525549968083699,5.689320087432861,4.9538900057474775,4.301040053367615,3.715940018494924,3.186450024445852,2.7026399970054626,2.2777299880981445,1.9228399991989136,1.6260000069936116,1.3772600293159485,1.168410023053487,0.9926339983940125,0.844277004400889,0.718670000632604,0.6119399865468343,0.5208759978413582,0.4435740013917287,0.37845700482527417,0.32346299787362415,0.27689000219106674,0.23732900122801462,0.20360099772612253,0.17473100001613298,0.14991599942247072,0.12847499921917915,0.10984999996920426,0.09386240070064862,0.0803624006609122,0.06894260148207347,0.059272799330453076,0.05107160067806641,0.04409770015627146,0.03815990034490824,0.03309220060085257,0.028750500020881493,0.02502429997548461,0.02183120030288895,0.01910229989637931,0.016763900096217792,0.01475439996769031,0.013021800123775998,0.011522499999652306,0.010219700013597807,0.009082520147785544,0.008084949959690372,0.007205070035221676,0.006434700063740213,0.005761780038786431,0.005171170070146521,0.004655420042884846,0.0042029300626988215,0.003798660026707997,0.0034351300176543496,0.003106050018686801,0.0028060800201880434,0.0025307300578181944,0.0022865900148948035,0.002074009991095712,0.0018882100121118128,0.0017251400277018547,0.0015813599942096819,0.0014539599942509085,0.0013404600225233783,0.0012387700068453948,0.0011471000034362078,0.0010639500008740772,0.000982750013160209,0.0009032280164926002,0.0008304160098001981,0.000763302004391638,0.0006957389996387064,0.0006277950014919043,0.0005595280090346932,0.0004962740034291832,0.0004372789990156889,0.00037661099728817743,0.0003198039945952284,0.0002715600033601125,0.00023059100082415776,0.0001957989964769998,0.0001662559989199508,0.00014116999955149367,0.00011986899941499966,0.00010178099910262972,8.642370024366149e-05,7.33837005100213e-05,6.231160053478864e-05,5.2910600061295554e-05,4.4928300364214614e-05,3.815080041628486e-05,3.2396100020074904e-05,2.7509800171780323e-05,2.3360999724294135e-05,1.9838200235729648e-05,1.6846900052769342e-05,1.430689993261088e-05,1.2150199988051705e-05,1.0318799922970356e-05,8.763630072886977e-06,7.443029934014096e-06,6.321589997545137e-06,5.369250023553225e-06,4.560499974104459e-06,3.87367005790414e-06,3.290359984475799e-06,2.7949800103973152e-06,2.3742399927565807e-06,2.0168999981251545e-06,1.7133900106121776e-06,1.4555999901707157e-06,1.2366299889284467e-06,1.0506300232767292e-06,8.926409928259696e-07,7.584320040147455e-07,6.444220067199543e-07,5.475680069366717e-07,4.652869970792987e-07,3.953830021904044e-07,3.3599199866785057e-07,2.855309991408224e-07,2.4265600255072667e-07,2.0622400024687218e-07,1.7526699972828888e-07,1.4896099879517047e-07,1.266049996691739e-07,9.92927340348615e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8709112852811813,0.9575190643469492,1.0230700771013896,1.0758000512917836,1.1172100603580475,1.1486300627390544,1.1712300578753154,1.183350036541621,1.1834700306256611,1.1728500227133434,1.1526000301043193,1.123710036277771,1.0870500306288402,1.0434300204118092,0.9935210247834524,0.9379680156707764,0.8773260166247686,0.8167810142040253,0.7609730164210001,0.709373007218043,0.6615100055932999,0.6169660141070684,0.5753630052010218,0.5363680024941763,0.49968500683705014,0.4650480051835378,0.4322200044989586,0.40151100357373554,0.3731980050603549,0.3470110048850377,0.32270800322294235,0.30007799963156384,0.27893200268348056,0.259101003408432,0.24043800433476767,0.2228080021838347,0.20609500259160995,0.1906480019291242,0.17678100367387137,0.16432599971691766,0.15313700089852014,0.1430790014564991,0.13403700043757757,0.12590500277777514,0.11858600067595641,0.11199500163396199,0.1060570018986861,0.10070700198411942,0.09588740207254887,0.09154210115472476,0.08762460139890511,0.08408890167872111,0.08089600255091985,0.0780106025437514,0.07540140238900979,0.07304220149914424,0.07090550226469834,0.06897090251247089,0.06722210099299748,0.06563840247690678,0.06420290097594261,0.06290280011792977,0.06172240152955055,0.060649702015022434,0.05967580216626326,0.05879100194821755,0.05798430213083824,0.057263302306334175,0.05663480175038179,0.05608960178991159,0.05561940185725689,0.05521470153083404,0.05487090162932873,0.05458220156530539,0.0543428019930919,0.05414820152024428,0.05399370131393274,0.05387590235720078,0.05378960197170576,0.053733802400529385,0.0537054023394982,0.05370190180838108,0.05372090203066667,0.05376030163218578,0.05381810199469328,0.053890702004233994,0.05397860147058964,0.05405190152426561,0.05408150174965461,0.05407170175264279,0.05402650156368812,0.05395150215675434,0.05384970176964998,0.05372170234719912,0.05357020224134127,0.053397501508394875,0.05320580179492632,0.05299690179526806,0.052772601755956806,0.05253450137873491,0.052285801619291306,0.05202780136217674,0.051759202033281326,0.05148130189627409,0.051194801616171993,0.050900801395376526,0.05059990162650744,0.05029280173281828,0.04998010117560625,0.04966450141121944,0.04934610209117333,0.04902340192347765,0.048696701104442276,0.04836630138258139,0.04803280159831047,0.0476964016755422,0.047357301227748394,0.047017901514967285,0.04667820160587629,0.04633620164046685,0.04599210216353337,0.04564610216766596,0.045298501228292785,0.044949400859574475,0.0445988013719519,0.04424710168192784,0.04389620137711366,0.043546101388831936,0.043194701274236046,0.042842001343766846,0.04248830148329338,0.04213340114802122,0.04177750057230393,0.041420601618786655,0.04106280083457629,0.04070610087364912,0.0403502012292544,0.03999320138245821,0.03963500137130419,0.03927570146818956,0.03891530136267344,0.03855390070627133,0.038191501051187515,0.03782820080717405,0.03746600076556206,0.0371048009643952,0.03674230072647333,0.03637870090703169,0.03601400088518858,0.035648301554222904,0.03528160136193037,0.034914001201589905,0.0345455010732015,0.0341782004882892,0.033811901385585465,0.03344440087676048,0.03307590074837208,0.03270640131086111,0.032336000353097916,0.031964700358609356,0.03159260035802921,0.031221801104644935,0.030852001005162794,0.03048120082045595,0.030109400860965252,0.02973670093342662,0.02936320099979639,0.028988900904854138,0.028613900610556204,0.028238301165401936,0.027864000915239256,0.027491000791390736,0.02711710085471471,0.02674230079477032,0.02636690080786745,0.02599070081487298,0.025613900739699602,0.025236600854744513,0.024858700732390087,0.024482500584175188,0.024107600872715313,0.02373210045819481,0.023356000892817974,0.02297940058633685,0.02260250101486842,0.02222510054707527,0.02184760058298707,0.021469800888250273,0.02109380081916849,0.02071960037574172,0.02034490027775367,0.019969900604337454,0.019594700696567696,0.019219200282047193,0.01884350071971615,0.018467800691723824,0.018092000701775152,0.01771820041661461,0.01734620053321123,0.016973900298277538,0.016601400449872017,0.016228700522333384,0.015855800205220778,0.01548290035376946,0.015110000502318144,0.014737000378469626,0.014366100309416652,0.013997100216026107,0.013627800314376751,0.013258400450771054,0.01288870039085547,0.012519000330939889,0.01214920023145775,0.011779500249152383,0.011411700320119659,0.011045900328705708,0.01067970033424596,0.010313400144999227,0.009946890020122131,0.009580290177837014,0.009213630187635621,0.008846970275044441,0.008480340164775649,0.008115770140041908,0.007753100052165489,0.007390170164095859,0.007027050131000578,0.006663810112513602,0.0063004700156549616,0.005937110011776288,0.005573750124312937,0.005210430050889651,0.004849190047631661,0.004489850058841209,0.004130280110985041,0.0037705200375057757,0.0034106300057222447,0.0030686500249430537,0.0027608100014428296,0.0024837099869425097,0.00223430998933812,0.0020098600070923567,0.0018078899981143575,0.0016261399917614956,0.0014626099922073383,0.0013154800108168274,0.0011831200002537419,0.0010640399996191263,0.0009569190006004646,0.0008605609958370527,0.000773888998082839,0.0006959300032273555,0.0006258130063846087,0.0005627489978602777,0.0005060330028451668,0.00045502499900370214,0.00040915300147995975,0.0003679009969346225,0.0003308039958938025,0.0002974439994432032,0.00026744600230207044,0.00024047199864677774,0.0002162160017178394,0.0001944049993956772,0.00017479300004197285,0.00015715899765685512,0.00014130300041870214,0.00012704699899283392,0.00011422800101475634,0.00010270199951870988,9.233879973180592e-05,8.302109987804822e-05,7.46434998291079e-05,6.711110048248277e-05,6.033869976818096e-05,5.4249700042419136e-05,4.877510006432809e-05,4.385290018641778e-05,3.9427399921502605e-05,3.544850005710032e-05,3.1871100418356946e-05,2.8654800189542584e-05,2.5763000242780738e-05,2.316309989206881e-05,2.0825600131502142e-05,1.872389975687838e-05,1.6834400109170627e-05,1.5135600051507936e-05,1.360820010631869e-05,1.2234999834011736e-05,1.1000299991792417e-05,9.890290054196763e-06,8.892279993233387e-06,7.994980023795506e-06,7.18823999553327e-06,6.462920017232439e-06,5.810789995545444e-06,5.224469987297198e-06,4.69732996558984e-06,4.223369993875774e-06,3.7972500119091515e-06,3.4141299920520396e-06,3.0696600106239202e-06,2.7599599926967735e-06,2.4815099853488696e-06,2.23114998713451e-06,2.0060600149918173e-06,1.8036800023916537e-06,1.6217200027313083e-06,1.458120029459072e-06,1.311029999821282e-06,1.1787700202603446e-06,1.0598699968037788e-06,9.529530065795674e-07,8.568270004616352e-07,7.703990026660298e-07,6.926910032234446e-07,6.228220049327623e-07,5.600010031988253e-07,5.035180000353042e-07,4.52732997757721e-07,4.0707099913106504e-07,3.660149966814667e-07,3.2910100126552305e-07,2.959099963580532e-07,2.6606700013568724e-07,2.392349974419024e-07,2.1510799896873323e-07,1.9341599847659077e-07,1.7391099878712643e-07,1.563730016584941e-07,1.406049996433012e-07,1.26426002111657e-07,1.1367800093845896e-07,6.934310015083156e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.2528686498602231,0.26552995791037876,0.2743329852819443,0.2813509851694107,0.2864999820788701,0.2898989866177241,0.2916639844576518,0.29187098642190296,0.2905839880307515,0.28788499037424725,0.2838519910971324,0.27855699012676877,0.2720699931184451,0.26445399473110837,0.255771999557813,0.24608199670910835,0.23543799916903177,0.22457099705934525,0.21416999772191048,0.20420599728822708,0.19465099647641182,0.18547899648547173,0.17666599775354067,0.16818799823522568,0.16002400095264116,0.1521519993742307,0.1445540003478527,0.13727799927194914,0.13036999851465225,0.1238060003767411,0.1175639983266592,0.11162299911181132,0.10596299916505814,0.10056599974632263,0.0954155009239912,0.09049479911724727,0.08578929988046487,0.08131980026761691,0.07710609957575798,0.07313260063529015,0.06938500019411246,0.06584969970087211,0.06251399995138247,0.05936589961250623,0.05639429918179909,0.053588700480759144,0.05093929978708426,0.04843729982773463,0.046074300073087215,0.04384229922046264,0.04173350054770708,0.03974069965382417,0.03785699916382631,0.036076199263334274,0.034392199789484344,0.0327994991093874,0.03129259978110591,0.029866999791314203,0.02851819961021344,0.027241899942358334,0.026033799940099318,0.02489019992450873,0.023807399906218052,0.022781799857815106,0.02181029987211029,0.020889900003870327,0.020017599842200678,0.019191199603180092,0.01840879985441764,0.01766789983958006,0.016966199812789757,0.01630159995208184,0.015671999504168827,0.015075600007548928,0.014510499701524774,0.013975000008940697,0.013467499675850073,0.01298679985726873,0.012531499766434232,0.012100199780737361,0.011691799852997065,0.01130489989494284,0.010938399859393636,0.010591199699168405,0.010262199755137166,0.00995051977224648,0.009655159820492068,0.0093740897718817,0.009106769924983382,0.008852459800740084,0.0086104697547853,0.00838015996851027,0.00816088984720409,0.007952079875394702,0.0077517598401755095,0.007560869834075372,0.007378929799112181,0.007205439847894013,0.007039949763566256,0.0068820298959811526,0.006731269803519051,0.006585879911047717,0.006446979862327377,0.006314219829315941,0.006187259801663458,0.006065799815890689,0.00594952985799561,0.0058381798056264715,0.005730079836212099,0.005626439854192237,0.0055270498075212044,0.005431649857200682,0.005340039885292451,0.0052520198514685035,0.005167389831816156,0.005084549814152221,0.005004819870615999,0.004928029840812087,0.00485401984769851,0.004782639793120325,0.0047137398505583405,0.004647199879400432,0.004581479821354151,0.00451792993893226,0.004456449882127345,0.004396919859573245,0.0043392298587908345,0.004281879829553266,0.004226249875500798,0.004172249891174336,0.004119789887530108,0.004068779875524342,0.004019149928353727,0.003970809862948954,0.003922279827141513,0.003874979893832157,0.0038288398645818233,0.0037837898901974163,0.0037397799120905497,0.0036967398482374847,0.003654619892283032,0.003611949873932948,0.003570169870120784,0.003529239872780939,0.003489099869815012,0.0034497099307676158,0.0034110199000375965,0.0033729999170949063,0.0033341898621680834,0.003296049874431143,0.003258529856490592,0.0032216098625212908,0.0031852499038601914,0.003149409875428925,0.0031140598972948887,0.003077769884839654,0.003041999957834681,0.003006709875383725,0.002971879885687182,0.0029374899071020386,0.002903499931562692,0.0028698898774261274,0.0028352399240247905,0.002800999927179267,0.0027671598751718798,0.0027336799345600107,0.0027005599113181233,0.0026677699061110616,0.002635279903188348,0.002601679899574568,0.0025684399297460914,0.00253551994683221,0.0025029198926252625,0.0024706199183128774,0.0024385999616545937,0.0024068399410073957,0.0023739199386909604,0.00234131992328912,0.002308999925541381,0.0022769699377628663,0.002245209936518222,0.0022136999565797546,0.0021824299668272338,0.002149969902044783,0.0021178199482771256,0.002085939961640785,0.002054329942135761,0.002022969943936914,0.001991849955326567,0.001960969918097059,0.0019288899396390964,0.001897099942046528,0.0018655799503903836,0.0018343099606378626,0.0018032999651040882,0.0017725099654247363,0.0017419499442136537,0.0017101999352841328,0.0016787199419923127,0.001647499962321793,0.0016165499497825901,0.0015858299448154867,0.0015539299638476223,0.0015223199540438752,0.0014909999736119062,0.0014599499603112538,0.0014291499683167785,0.0013985899665082495,0.0013682599625705432,0.0013367399709143986,0.0013055099504223715,0.0012745499746718754,0.0012438499640362959,0.0012133899726904929,0.001183169981231913,0.001153179977942879,0.0011219899752177298,0.0010910699881302814,0.0010604299992943804,0.0010300299812418718,0.000999881992659842,0.0009699599856200317,0.0009402559808222577,0.0009093509725062177,0.0008787219946195061,0.000848354985161374,0.0008182389962409312,0.0007883589860284701,0.0007587059953948483,0.0007292679899061719,0.0006986249888238186,0.0006682549962230647,0.0006381460019232085,0.000608282988347734,0.0005786560068372637,0.0005492520043238377,0.0005200610030442476,0.0004910719968999425,0.0004636860006333639,0.0004378139977537406,0.00041337600123370066,0.00039029199979268014,0.0003684900002554059,0.00034789799732000876,0.0003284499980509281,0.00031008400158801425,0.0002927409999150162,0.00027636299637379125,0.00026089799697122845,0.00024629499966977164,0.00023250600012640157,0.00021948699941276573,0.00020719500025734305,0.0001955899982325112,0.0001846330002687561,0.0001742880000771644,0.0001645219987646366,0.00015530199986339235,0.00014659799974954998,0.00013838100373201692,0.00013062399981815057,0.00012330100192533186,0.00011638799999976375,0.00010986200019639607,0.00010370199925091583,9.788699996230814e-05,9.239779986576953e-05,8.721609932157055e-05,8.232500052448206e-05,7.77079009518881e-05,7.334970056642003e-05,6.923580015912496e-05,6.535259975256243e-05,6.168709963579506e-05,5.82270998468933e-05,5.49612001729353e-05,5.187840027550313e-05,4.89685001715164e-05,4.622179979681581e-05,4.362920026323991e-05,4.118199952548215e-05,3.887210065537753e-05,3.6691699885219954e-05,3.463370073101638e-05,3.2691100083563164e-05,3.0857400361128384e-05,2.912659980817504e-05,2.7492999834066723e-05,2.595090002917762e-05,2.4495400187637035e-05,2.3121500059157068e-05,2.1824700070283143e-05,2.060069982690038e-05,1.9445299888805796e-05,1.835469993238803e-05,1.7325299874452565e-05,1.635370017538662e-05,1.543650008291782e-05,1.4570799976354465e-05,1.3753699856048721e-05,1.2982399994143634e-05,1.2254399962330353e-05,1.1567200090212282e-05,1.091849988673251e-05,1.0306299903580415e-05,9.728370059747249e-06,9.182869992703976e-06,8.667960022042584e-06,8.181939923209333e-06,7.723180071176708e-06,7.290149975839692e-06,6.881400016330493e-06,6.495580009868718e-06,6.131399989802351e-06,5.787639982675803e-06,5.463170017113346e-06,5.156890059273185e-06,4.8677799592648325e-06,4.594890015141573e-06,4.337299969847663e-06,4.094160014271135e-06,3.864650087355888e-06,3.648010003113692e-06,3.443520010174931e-06,3.250489991539022e-06,3.0682899894903435e-06,2.8963099983532934e-06,2.7339600402835154e-06,2.58072001694624e-06,2.4360799860308666e-06,2.2995400286163203e-06,2.170649944825224e-06,2.049000026242235e-06,1.9341599776604803e-06,1.825760004218561e-06,1.7234399933840905e-06,1.6268499981227553e-06,1.535680003901992e-06,1.4496199677675274e-06,1.3683899927248906e-06,1.2917100017754517e-06,1.2193199836474378e-06,1.1509999922054703e-06,1.0865000111455931e-06,1.0256200084768352e-06,9.681490003761912e-07,9.139019994108821e-07,8.626939992003221e-07,8.14356999020068e-07,7.687289951263665e-07,7.256589971878687e-07,6.850019976430607e-07,6.466240023428327e-07,6.103960004111286e-07,5.761989996244665e-07,5.439179915356362e-07,5.134459968303418e-07,4.846820000163158e-07,4.575299972960541e-07,4.31898998935291e-07,4.0770499983485326e-07,3.8486599862608273e-07,3.6330700462864723e-07,3.429560019678017e-07,3.23745001177637e-07,3.0561100080224907e-07,2.884919965140398e-07,2.723329994106886e-07,2.570799964018988e-07,2.4267999639467536e-07,2.2908799953332468e-07,2.162569986789246e-07,2.0414500075579176e-07,1.927109991584075e-07,1.819179994792345e-07,1.7173000088632762e-07,1.6211199849180957e-07,1.5303399910256607e-07,1.444630003769968e-07,1.3637300118792459e-07,1.2873600023037093e-07,1.2152700001877292e-07,1.1472200019587338e-07,1.0829799990119682e-07,9.393681447515216e-08,4.2064848789398944e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3642334739367168,1.4753399888674419,1.5921800037225087,1.702720006306966,1.8128400146961212,1.9225600063800812,2.031859964132309,2.1395400365193686,2.244389990965525,2.346430003643036,2.445650041103363,2.5420700112978616,2.6356800198554993,2.7264899810155234,2.8145099878311157,2.899739980697632,2.982189953327179,3.0634700655937195,3.145210007826487,3.227399984995524,3.3100499709447226,3.39314999183019,3.476710021495819,3.5607100129127502,3.6451599995295205,3.7300600012143454,3.815409998099009,3.901319960753123,3.987899978955587,4.075139999389648,4.163049936294556,4.251619935035706,4.34086008866628,4.4307600657145185,4.521320064862569,4.612540006637573,4.704409996668498,4.79678996404012,4.8895299434661865,4.9826399485270185,5.076110005378723,5.169930060704549,5.2641100486119585,5.35863999525706,5.453530033429463,5.548780004183452,5.6443800528844195,5.740369915962219,5.836789965629578,5.933650056521098,6.030949989954631,6.1286700169245405,6.226829965909322,6.325419982274373,6.424429972966512,6.523879965146382,6.623759984970093,6.724059979120891,6.82480001449585,6.925960024197896,7.027559995651245,7.129580020904541,7.232040007909139,7.334919969240825,7.438230037689209,7.541960000991821,7.646130045255025,7.750669916470845,7.855520049730937,7.960709969202678,8.06620995203654,8.172030051549276,8.278180042902628,8.384649991989136,8.491429964701334,8.59854006767273,8.705960035324097,8.813760121663412,8.92200001080831,9.030659993489584,9.139750003814697,9.249269962310791,9.359220027923584,9.469600041707357,9.58041008313497,9.691640059153238,9.803300062815348,9.914650042851767,10.024899959564209,10.134100039800009,10.242300033569336,10.349399964014689,10.455399910608927,10.560399850209555,10.664299964904785,10.767100016276041,10.868899981180826,10.96970001856486,11.06939991315206,11.168099959691366,11.265700022379557,11.362300078074137,11.457800149917603,11.552300055821737,11.645800034205118,11.738200028737387,11.829599857330322,11.919999996821085,12.009399970372518,12.097699960072836,12.185000022252401,12.271299997965494,12.356599966684977,12.440800031026205,12.52399984995524,12.606299956639608,12.6875,12.76769987742106,12.846799929936727,12.924999952316284,13.00219996770223,13.078400055567423,13.153600056966146,13.227799971898397,13.300900141398111,13.37309996287028,13.444299936294556,13.51450022061666,13.583700180053711,13.651999950408936,13.719200054804483,13.785499970118204,13.850799957911173,13.915099859237671,13.978399991989136,14.040800015131632,14.102099974950155,14.162499984105429,14.221999963124594,14.280400037765503,14.337900082270304,14.394400040308634,14.450000047683716,14.504599968592325,14.558200041453043,14.610900084177652,14.66259996096293,14.7134002049764,14.763200044631958,14.812099933624268,14.860000133514404,14.906900008519491,14.95300006866455,14.997999986012777,15.042099952697754,15.085300127665201,15.127499977747599,15.168799956639608,15.209200064341227,15.248600006103516,15.287099917729696,15.324600060780844,15.361199935277304,15.396900018056234,15.431699991226196,15.465499957402548,15.49840005238851,15.530400196711222,15.561500072479248,15.591599941253662,15.620799938837687,15.649099985758463,15.676499843597412,15.70300006866455,15.728500048319498,15.753100077311197,15.776899814605713,15.799699942270914,15.821600039800009,15.842600027720133,15.86270006497701,15.881899992624918,15.900200049082438,15.91759991645813,15.934099992116293,15.949700037638346,15.964399973551432,15.978300094604492,15.991200049718222,16.00319989522298,16.01439968744914,16.0246000289917,16.033999919891357,16.042500178019207,16.050100167592365,16.056900183359783,16.06279993057251,16.067699909210205,16.071799914042156,16.07509994506836,16.07740004857381,16.07889986038208,16.079599539438885,16.079299926757812,16.078199704488117,16.07629982630412,16.073399861653645,16.06969992319743,16.065200010935467,16.059799671173096,16.053499698638916,16.04639991124471,16.03839985529582,16.029599984486897,16.020000139872234,16.009400208791096,15.99810004234314,15.985900084177652,15.972799936930338,15.958899974822998,15.944200038909912,15.928600072860718,15.912200053532919,15.895000060399374,15.87689995765686,15.858000040054321,15.838300148646036,15.817700147628784,15.796300013860067,15.774099985758463,15.751000165939331,15.727199951807657,15.702499945958456,15.676999966303507,15.650600035985311,15.623500188191732,15.595500071843466,15.567200104395548,15.538899898529053,15.510600010553995,15.482400099436441,15.454300006230673,15.426199913024902,15.398199955622355,15.370199998219809,15.342300097147623,15.31439995765686,15.286600033442179,15.258800029754639,15.2311000029246,15.203399976094564,15.175800085067749,15.148200114568075,15.120699961980185,15.093200047810873,15.065799872080484,15.038400014241537,15.011100053787231,14.983800013860067,14.956599950790405,14.929500023523966,14.902299960454306,14.87529993057251,14.848300059636435,14.821299950281778,14.794399976730347,14.767499923706055,14.740700006484985,14.713899850845337,14.68719998995463,14.660499890645346,14.633900006612143,14.60730012257894,14.58080005645752,14.554299910863241,14.527900060017904,14.501500050226847,14.475200017293295,14.448899984359741,14.422600110371908,14.39650003115336,14.370299895604452,14.344200054804483,14.3182000319163,14.292200088500977,14.266199827194214,14.240300099054972,14.214500029881796,14.188700040181478,14.162900050481161,14.137200037638346,14.111499945322672,14.085900147755941,14.06030003229777,14.034800052642822,14.009299914042154,13.98389991124471,13.958499908447266,13.933199882507324,13.907899856567383,13.88259998957316,13.857400099436441,13.832300027211508,13.807100057601929,13.782100121180216,13.757100025812784,13.732100009918213,13.707200050354004,13.682300090789795,13.657399972279867,13.632700125376383,13.607900063196817,13.583199977874756,13.558599948883057,13.533899863560995,13.509399970372518,13.4849001566569,13.460399945576986,13.436000029246012,13.411600033442179,13.387200037638346,13.362900098164877,13.33870005607605,13.314499934514364,13.290299971898397,13.266199906667074,13.24209992090861,13.21810007095337,13.194100062052408,13.170099973678589,13.14620010058085,13.122399806976318,13.098600069681803,13.07479993502299,13.05109985669454,13.027400016784668,13.003700017929077,12.98009999593099,12.956600030263266,12.93309998512268,12.909600098927816,12.886199871699015,12.862799962361654,12.839400053024292,12.816099961598715,12.7928999265035,12.769700050354004,12.746499935785929,12.723399877548218,12.700299978256226,12.677199999491373,12.654199997584024,12.63129997253418,12.608400026957193,12.585500001907349,12.562599897384644,12.539899905522665,12.517100016276041,12.494399865468344,12.471699873606363,12.449100097020468,12.426499923070272,12.403999964396158,12.381500005722046,12.359000047047934,12.336599985758463,12.314200083414713,12.291800101598104,12.269500096638998,12.247300068537394,12.225099881490072,12.202900012334188,12.180700063705444,12.158600171407064,12.136600017547607,12.11459994316101,12.092600027720133,12.070700089136759,12.048799991607666,12.026899894078573,12.005099932352701,11.983299970626831,11.961600065231323,11.939900080362955,11.918199936548868,11.896599928538004,11.875,11.85349996884664,11.831999937693277,11.810500065485636,11.78910001118978,11.767700036366781,11.746299902598063,11.724999904632568,11.703799883524576,11.682500123977661,11.661400000254313,11.640199979146322,11.619100014368692,11.597999890645346,11.57699998219808,11.556000073750814,11.535000006357828,11.514100074768066,11.493199904759726,11.472400108973185,11.451600074768066,11.430799961090088,11.410099903742472,11.389399925867716,11.36870010693868,11.348100026448568,11.327500104904175,11.307000001271566,11.286500136057535,11.266000111897787,11.24559998512268,11.225199937820435,11.204799969991049,11.184499979019165,11.164199988047281,11.143999973932901,11.12369998296102,11.103600025177002,11.083400011062622,11.063299894332886,11.043299992879232,11.023199955622355,11.003299951553345,10.983299970626831,10.96340004603068,10.94349996248881,10.923699935277304,10.903900067011515,10.884099960327148,10.86429993311564,10.844600121180216,10.825000047683716,10.80530015627543,10.785799900690714,10.766199986139933,10.746700048446655,10.727199872334799,10.70769993464152,10.688299973805746,10.66890001296997,10.64960010846456,10.630300045013428,10.611000061035156,10.591799974441528,10.57260004679362,10.553399960199991,10.534299850463867,10.515199899673462,10.496099948883057,10.477099974950155,10.458100001017252,10.43909994761149,10.420200030008951,10.401299953460693,10.382399956385294,10.363600095113119,10.344799757003784,10.32610003153483,10.307399988174438,10.288699944814047,10.269999980926514,10.251399914423624,10.232800086339315,10.21429999669393,10.1957000096639,10.177299976348877,10.15880004564921,10.140399932861328,10.121999979019165,10.103700002034506,10.085299968719482,10.067099968592325,10.048799912134806,10.03060007095337,10.012400150299072,9.994269927342733,9.976150035858154,9.958070039749146,9.940010070800781,9.931000073750814};
        C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480124394098918,4.563908735911052,4.604879220326741,4.670729319254558,4.735669294993083,4.799679358800252,4.862759351730347,4.924999356269836,4.986469268798828,5.047179341316223,5.107129295667012,5.166309356689453,5.224719405174255,5.282369335492452,5.339259425799052,5.395379424095154,5.45073934396108,5.505649407704671,5.56045933564504,5.61514941851298,5.669719378153483,5.72417938709259,5.778529365857442,5.832759380340576,5.886879404385884,5.940889398256938,5.994779348373413,6.048529386520386,6.102119406064351,6.155539433161418,6.208809455235799,6.261909405390422,6.314839482307434,6.36760938167572,6.420219381650289,6.472669402758281,6.524959405263265,6.577009439468384,6.628759463628133,6.680219451586406,6.731379469235738,6.7822394371032715,6.832799394925435,6.88305942217509,6.9330293734868365,6.982689380645752,7.03205935160319,7.081159432729085,7.130009412765503,7.178609490394592,7.226969480514526,7.2750794887542725,7.322949449221293,7.370569467544556,7.417939464251201,7.465059399604797,7.511939366658528,7.558589537938436,7.604999423027039,7.651189525922139,7.697139541308085,7.74286949634552,7.788369536399841,7.83363954226176,7.878679553667705,7.923489491144816,7.968069513638814,8.01254959901174,8.05704951286316,8.101569414138794,8.14609956741333,8.190659602483114,8.235239505767822,8.279829422632853,8.324439446131388,8.36907951037089,8.413729508717855,8.458469470342001,8.503379503885904,8.548449516296387,8.593679507573446,8.639079491297403,8.684639612833658,8.730359554290771,8.776249329249064,8.82228946685791,8.868509531021118,8.914639552434286,8.960459391276041,9.005949338277182,9.051129579544067,9.095979452133179,9.140519539515177,9.184739351272583,9.228639523188273,9.27221941947937,9.315479675928751,9.358429431915283,9.401049455006918,9.443359533945719,9.485349575678507,9.527019580205282,9.568369468053183,9.609399716059366,9.650119622548422,9.690509557723999,9.730589628219604,9.770349502563477,9.80977956453959,9.848899602890015,9.887699683507284,9.926189502080282,9.964349667231241,10.002199490865072,10.03969963391622,10.076899687449137,10.113799571990967,10.150399684906006,10.186699628829956,10.222599585851034,10.258199691772461,10.29349970817566,10.328499635060629,10.363199710845947,10.397499481836954,10.431499560674032,10.465299526850382,10.49869974454244,10.531699657440186,10.564499696095785,10.59689966837565,10.628999710083008,10.660799741744995,10.692299604415894,10.723499695460001,10.75439969698588,10.784899711608887,10.815099716186523,10.84499971071879,10.87459953625997,10.903899590174357,10.932799736658732,10.961399793624878,10.989699602127075,11.017699797948202,11.04539966583252,11.072799603144327,11.099799712498983,11.126499652862549,11.152899742126465,11.17899982134501,11.20479973157247,11.230299711227417,11.255399703979492,11.280199527740479,11.304699818293253,11.32889986038208,11.352799733479818,11.376399834950766,11.39959979057312,11.422499736150106,11.445099751154581,11.467399915059408,11.489399751027426,11.51099967956543,11.532399733861288,11.553399880727133,11.574099779129028,11.594499826431274,11.614499727884928,11.634299675623575,11.65369979540507,11.672899881998697,11.691699743270874,11.710099617640177,11.728299856185913,11.7461998462677,11.763699690500895,11.78089968363444,11.797899723052979,11.814399719238281,11.830699920654297,11.846699794133505,11.8622997601827,11.877599557240805,11.892599821090698,11.907299836476644,11.92169984181722,11.935799916585287,11.9494997660319,11.962999820709229,11.976099888483683,11.988899866739908,12.001399914423624,12.013499895731607,12.025399923324585,12.03689980506897,12.048099915186564,12.05899985631307,12.069599787394205,12.079899867375692,12.089899937311808,12.099499861399332,12.108799854914347,12.117799997329712,12.126499891281128,12.134899854660034,12.142999728520712,12.150699774424234,12.158199946085611,12.165299812952677,12.172099908192953,12.178599993387857,12.184699932734171,12.190599918365479,12.196099996566772,12.201399803161621,12.206299861272177,12.21089998881022,12.215200026830038,12.219100077946981,12.222800016403198,12.226099809010824,12.22920004526774,12.231899897257486,12.23419992129008,12.236299991607666,12.238100051879883,12.239499886830648,12.240699847539267,12.24150005976359,12.242000023523966,12.242200056711832,12.24209992090861,12.241599957148233,12.240900039672852,12.239799976348877,12.238600095113119,12.23740005493164,12.236200094223022,12.234899838765463,12.233700195948282,12.232500076293945,12.231299956639608,12.229999939600626,12.228800137837728,12.227599859237671,12.226400136947632,12.22509996096293,12.223900000254313,12.222699960072836,12.221499999364218,12.22029995918274,12.218999942143759,12.21779990196228,12.216600100199381,12.215400060017904,12.214099963506063,12.212900082270304,12.211699962615967,12.210500001907349,12.20930012067159,12.20799994468689,12.206800063451132,12.205599943796793,12.204399983088175,12.203200022379557,12.201900084813436,12.200700044631958,12.19950000445048,12.198300043741861,12.197099924087524,12.195800065994263,12.194599946339926,12.193400224049887,12.192200104395548,12.19099990526835,12.18969996770223,12.188499927520752,12.187299966812134,12.186100006103516,12.184900124867758,12.183600107828775,12.182399908701578,12.18119994799296,12.179999987284342,12.178800026575724,12.177599986394247,12.176299969355265,12.175100008646647,12.17389996846517,12.172699928283691,12.171500047047934,12.170300086339315,12.168999910354614,12.167799949645996,12.166599909464518,12.16540010770162,12.164199988047281,12.162999947865805,12.161700010299683,12.160500049591064,12.159300009409586,12.15809996922811,12.15690008799235,12.155700047810873,12.154399951299032,12.153200070063273,12.151999950408936,12.150800069173178,12.14959987004598,12.148399829864502,12.147199948628744,12.145900090535482,12.144699970881144,12.143499930699667,12.142299890518188,12.14109985033671,12.139900048573812,12.138700008392334,12.137400150299072,12.136200189590454,12.135000149408976,12.133800029754639,12.13259998957316,12.131400108337402,12.130200147628784,12.128900130589804,12.127700010935465,12.126499970753988,12.125300089518229,12.124099969863892,12.122900009155273,12.121699968973795,12.120500087738037,12.119200070699057,12.118000030517578,12.1167999903361,12.115600029627482,12.114400068918863,12.113200108210245,12.111999909083048,12.11080002784729,12.109600067138672,12.108300050099691,12.107100009918213,12.105900049209595,12.104700009028116,12.103500048319498,12.102300008138021,12.101100047429403,12.099900086720785,12.098700046539307,12.097500085830688,12.096199989318848,12.09499994913737,12.093799908955893,12.092599948247274,12.091399908065796,12.090200106302897,12.089000225067139,12.087800105412802,12.086600065231323,12.085400025049845,12.084100087483725,12.082900126775106,12.081700086593628,12.080499966939291,12.079300006230673,12.078099966049194,12.076899925867716,12.075699965159098,12.074499686559042,12.073300043741861,12.072100083033243,12.070900122324625,12.06969984372457,12.06849996248881,12.067199945449829,12.065999984741211,12.064799944559732,12.063599983851114,12.062400023142496,12.061200062433878,12.05999986330668,12.058799982070923,12.057599941889444,12.056399822235107,12.055200099945068,12.05400013923645,12.052800019582113,12.051599899927774,12.050400098164877,12.049200057983398,12.04800009727478,12.04670000076294,12.045499960581461,12.044299999872843,12.043100039164225,12.041899919509888,12.04069995880127,12.039499998092651,12.038299957911173,12.037099917729696,12.035900036493937,12.03469999631246,12.033499956130981,12.032299995422363,12.031100034713745,12.029899994532267,12.02869995435079,12.02750007311503,12.026300032933554,12.025099992752075,12.023900032043457,12.022700071334839,12.02150003115336,12.020299990971884,12.019100109736124,12.017900069554647,12.016700029373169,12.01549998919169,12.014299949010214,12.013099908828735,12.011899948120117,12.010699987411499,12.00949994723002,12.008299907048544,12.007100025812784,12.005899985631308,12.004699945449829,12.003499984741211,12.002300024032593,12.001099983851114,11.999899943669638,11.998700062433878,11.997500022252401,11.996299982070923,11.995100021362305,11.993900060653687,11.992700020472208,11.991499980290731,11.990300099054972,11.989100058873495,11.987900018692017,11.986700057983398,11.98550009727478,11.984299977620443,11.983099937438965,11.981899976730347,11.980699936548868,11.979499896367392,11.978300015131632,11.977099974950155,11.975899934768677,11.974699974060059,11.97350001335144,11.972299973169962,11.971099932988485,11.969900051752726,11.968700011571249,11.96749997138977,11.966300010681152,11.965100049972534,11.963900009791056,11.962699969609579,11.96150008837382,11.960300048192343,11.959100008010864,11.957900047302246,11.956700086593628,11.955499966939291,11.954300085703531,11.953099966049194,11.95199998219808,11.950800021489462,11.949600060780844,11.948399941126505,11.947199900945028,11.94599994023641,11.944799979527792,11.943600018819174,11.942399978637695,11.941200017929077,11.940000057220459,11.93940003712972};
        //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174926857153574,0.6330969383319219,0.6429339597622553,0.6567259430885315,0.6703249563773473,0.6837289581696192,0.696939950188001,0.709972952802976,0.7228439499934515,0.7355559517939886,0.7481069515148798,0.7604979425668716,0.7727279563744863,0.7847959498564402,0.7967039545377096,0.8084519704182943,0.8200399627288183,0.8315349618593851,0.843003953496615,0.8544499625762304,0.8658709476391474,0.8772689600785574,0.8886419584353765,0.8999889642000198,0.9113129526376724,0.9226119567950567,0.9338879535595576,0.9451339542865753,0.9563449521859487,0.9675209522247314,0.978662962714831,0.9897689620653788,1.0008399536212285,1.011879950761795,1.022879958152771,1.0338499546051025,1.0447899599870045,1.055669943491618,1.0664899547894795,1.0772499442100525,1.087949961423874,1.0985799531141918,1.109149972597758,1.1196599503358204,1.1300999522209167,1.140489975611369,1.1507999698321025,1.1610699693361919,1.1712699631849925,1.1814299523830414,1.191529929637909,1.2015899618466694,1.2115899721781414,1.2215399543444316,1.2314399580160778,1.24127995967865,1.2510799566904705,1.260819951693217,1.2705199519793193,1.2801699539025624,1.2897599736849468,1.2993099590142567,1.3088199694951375,1.3182699580987294,1.327679951985677,1.3370299637317657,1.3463399608929951,1.35562997063001,1.3649199604988098,1.3742099702358246,1.3835099538167317,1.3928099671999614,1.4021199643611908,1.4114299714565277,1.420739968617757,1.4300499657789867,1.4393699665864308,1.4487099448839824,1.458079953988393,1.4674899478753407,1.4769199589888256,1.4863999684651692,1.4958999852339427,1.5054499606291454,1.515019953250885,1.524629960457484,1.5342699587345123,1.5438999632994335,1.5534499486287434,1.562949965397517,1.5723699629306793,1.581729958454768,1.59101997812589,1.6002399722735088,1.6093899607658386,1.618479977051417,1.6274999678134918,1.6364599466323853,1.64533997575442,1.654159963130951,1.6629199584325154,1.6715999643007915,1.680219978094101,1.6887699663639069,1.697249948978424,1.7056699494520824,1.7140199641386669,1.722299963235855,1.7305199603239696,1.7386699517567952,1.7467499673366547,1.754759947458903,1.7627099553744,1.7705899675687153,1.7783999741077423,1.7861499587694805,1.793829967578252,1.8014399806658428,1.808989942073822,1.8164699772993724,1.8238799770673115,1.8312299748261769,1.8384999732176464,1.845719963312149,1.8528599739074707,1.8599399626255035,1.8669499655564625,1.8738899727662404,1.8807699779669445,1.8875799775123596,1.894319971402486,1.9009999831517537,1.9076099594434102,1.9141599734624226,1.9206299781799316,1.9270399709542592,1.933379977941513,1.9396599928538005,1.9458699723084767,1.9520099659760792,1.9580799639225006,1.9640899797280629,1.9700399736563365,1.9759099781513214,1.981719970703125,1.9874599774678547,1.9931399822235107,1.9987499713897705,2.004289964834849,2.0097699761390686,2.0151700178782144,2.020519971847534,2.025789976119995,2.0309999585151672,2.0361400047938027,2.041219969590505,2.0462299982706704,2.05116997162501,2.0560499827067056,2.06085999806722,2.0655999978383384,2.0702799558639526,2.0748899976412454,2.0794299840927124,2.0839099685351052,2.088319977124532,2.0926599701245627,2.096939980983734,2.1011499762535095,2.105299989382426,2.109369953473409,2.113380014896393,2.117329935232798,2.121209998925527,2.1250200072924295,2.1287699540456138,2.132450004418691,2.1360599795977273,2.139609972635905,2.143089989821116,2.146499991416931,2.149849991003672,2.153129975001017,2.1563499569892883,2.1594999631245932,2.1625799934069314,2.165600001811981,2.1685500144958496,2.171430011590322,2.1742499470710754,2.1770000060399375,2.1796900033950806,2.1823099851608276,2.1848599712053933,2.1873499949773154,2.189769983291626,2.1921199957529702,2.194409966468811,2.1966300010681152,2.1987800002098083,2.2008699973424277,2.202899992465973,2.204849978288015,2.2067400018374124,2.2085699836413064,2.210330009460449,2.2120200196901956,2.2136500080426535,2.2152100006739297,2.216699957847595,2.2181300123532615,2.2194899916648865,2.2207900285720825,2.2220200101534524,2.2231799960136414,2.224279999732971,2.225320021311442,2.2262800137201944,2.227179984251658,2.228019952774048,2.228790005048116,2.2294899821281433,2.230120003223419,2.2306900024414062,2.2311999599138894,2.231640021006266,2.232010006904602,2.232320010662079,2.232550024986267,2.2327300310134888,2.2328400015830994,2.2328800161679587,2.232860048611959,2.232770005861918,2.2326200008392334,2.2323999802271524,2.23211000363032,2.2317899664243064,2.231469968954722,2.231149991353353,2.230840007464091,2.2305199901262918,2.230200012524923,2.2298799753189087,2.2295599977175393,2.2292399803797402,2.228920022646586,2.2286099990208945,2.228290021419525,2.2279699643452964,2.227649966875712,2.2273300091425576,2.227020025253296,2.226700007915497,2.226380010445913,2.2260600129763284,2.2257399757703147,2.2254199783007302,2.225110034147898,2.224790016810099,2.2244699796040854,2.224150021870931,2.2238399982452393,2.22351998090744,2.223200023174286,2.222880025704702,2.22257000207901,2.222250004609426,2.221929987271627,2.2216100096702576,2.221300025780996,2.2209799885749817,2.2206600109736123,2.2203399936358132,2.2200300097465515,2.2197100122769675,2.219390014807383,2.2190800110499063,2.2187600135803223,2.218439996242523,2.218119998772939,2.2178099751472473,2.217489997545878,2.217170019944509,2.216860055923462,2.216539998849233,2.216219981511434,2.215909997622172,2.215590000152588,2.215269982814789,2.2149600187937417,2.214639981587728,2.214330017566681,2.214010000228882,2.213690002759298,2.213379999001821,2.2130600015322366,2.2127400437990823,2.212430000305176,2.212110002835592,2.2118000189463296,2.211479961872101,2.2111600041389465,2.2108499805132547,2.2105300227801004,2.2102200190226235,2.20989998181661,2.2095899979273477,2.2092700203259787,2.2089500029881797,2.208639979362488,2.208319981892904,2.2080100178718567,2.2076900204022727,2.207380016644796,2.207059999306997,2.20674999554952,2.206429978211721,2.206120014190674,2.20580001672109,2.205489993095398,2.2051700154940286,2.2048600117365518,2.2045400142669678,2.204230010509491,2.203910013039907,2.20360000928243,2.203279991944631,2.202970008055369,2.202650010585785,2.202340006828308,2.202020009358724,2.2017099857330322,2.201390027999878,2.2010799845059714,2.2007700006167092,2.2004500031471252,2.2001399795214334,2.199820021788279,2.1995099782943726,2.1991899808247886,2.1988799969355264,2.1985700130462646,2.198249955972036,2.197940011819204,2.1976200143496194,2.1973100304603577,2.196999986966451,2.196680009365082,2.19636998573939,2.196050008138021,2.195740024248759,2.1954300006230674,2.195110003153483,2.194799999396006,2.1944899956385293,2.1941700180371604,2.1938600142796836,2.1935500105222068,2.1932299931844077,2.192919989426931,2.192609985669454,2.1922899881998696,2.191980024178823,2.1916699608167014,2.191349983215332,2.1910399993260703,2.190730035305023,2.190409998099009,2.1901000340779624,2.1897899905840554,2.1894800066947937,2.1891599694887796,2.1888499657313027,2.1885400215784707,2.1882299979527793,2.187910000483195,2.187599996725718,2.1872900128364563,2.186969975630442,2.1866600116093955,2.1863500277201333,2.186040004094442,2.185730000336965,2.1854100028673806,2.185100038846334,2.184789995352427,2.1844799717267356,2.1841700275739035,2.1838499903678894,2.1835400263468423,2.183230002721151,2.182919998963674,2.182610015074412,2.182290017604828,2.181980013847351,2.1816700299580893,2.1813600063323975,2.1810500025749207,2.180739998817444,2.1804199616114297,2.1801100174585977,2.1797999938329062,2.1794899900754294,2.1791800061861673,2.178869982560476,2.1785600185394287,2.1782400012016296,2.177929997444153,2.177619973818461,2.1773100097974143,2.1770000060399375,2.1766900022824607,2.1763800183931985,2.1760700146357217,2.175760010878245,2.175450007120768,2.1751400033632913,2.174819986025492,2.1745100021362305,2.1741999983787537,2.173889994621277,2.1735799908638,2.1732700069745383,2.1729600032170615,2.1726499994595847,2.172339995702108,2.1720300118128457,2.1717199881871543,2.171410004297892,2.1711000005404153,2.1707899967829385,2.1704799930254617,2.1701700091362,2.169860005378723,2.1695499817530313,2.1692399978637695,2.168930013974508,2.168619990348816,2.168309986591339,2.1680000027020774,2.1676899989446006,2.1673799951871238,2.167069991429647,2.166760007540385,2.1664499839146933,2.166140000025431,2.1658299962679544,2.165519972642263,2.1652099887530007,2.164900004863739,2.1645999948183694,2.1642900109291077,2.163979987303416,2.163670003414154,2.1633600195248923,2.1630499958992004,2.1627400120099387,2.162429988384247,2.16211998462677,2.161810020605723,2.1615100105603537,2.161200006802877,2.1608900030454,2.160580019156138,2.1602699955304465,2.1599600116411843,2.1596500078837075,2.159350017706553,2.1590399940808616,2.1587300101915994,2.1584200064341226,2.1581100026766458,2.1577999790509543,2.1574999888738,2.1571900248527527,2.156880001227061,2.156570037206014,2.156259993712107,2.1559500098228455,2.155650019645691,2.155340015888214,2.1550299723943076,2.1547199885050454,2.154419998327891,2.1542600194613137};
        //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18198377390702566,0.18441500018040338,0.18685400113463402,0.1892519990603129,0.19161499912540117,0.19394300132989883,0.19623700032631555,0.1985000011821588,0.20073500275611877,0.20294099921981493,0.20511900012691817,0.20726799964904785,0.20938899864753088,0.21148300046722093,0.21354899803797403,0.21558699881037077,0.2175959994395574,0.2195880003273487,0.22157699863115946,0.22356000170111656,0.22553999970356622,0.22751600046952566,0.22948599979281425,0.2314509997765223,0.2334129996597767,0.23537000020345053,0.2373229997853438,0.2392710025111834,0.2412129988272985,0.24314800277352333,0.24507700031002363,0.2470000001291434,0.2489179993669192,0.25082800288995105,0.2527329996228218,0.25463099777698517,0.2565230006972949,0.25840600083271664,0.26027699808279675,0.2621389999985695,0.26398999740680057,0.26582899938027066,0.26765599846839905,0.26947200298309326,0.2712780013680458,0.2730719993511836,0.27485500027736026,0.2766279975573222,0.2783909986416499,0.28014600028594333,0.28189100325107574,0.2836270009477933,0.2853530024488767,0.28707100202639896,0.28877900540828705,0.2904770001769066,0.2921679963668187,0.29384999722242355,0.29552200188239414,0.2971859996517499,0.2988430013259252,0.30048999935388565,0.3021270011862119,0.3037570044398308,0.3053790008028348,0.30699299772580463,0.30859699845314026,0.31019800156354904,0.31179900219043094,0.3134000028173129,0.3150019993384679,0.31660500168800354,0.3182080015540123,0.31981100390354794,0.3214160030086835,0.32302000125249225,0.32462500035762787,0.32623400042454404,0.32784899820884067,0.3294690002997716,0.33109500010808307,0.33272699763377506,0.3343640019496282,0.336007999877135,0.33765800297260284,0.33931199957927066,0.34097300469875336,0.342630997300148,0.3442770019173622,0.34591099868218106,0.347532997528712,0.34914399931828183,0.3507420023282369,0.3523290033141772,0.35390399644772214,0.3554669991135597,0.3570190022389094,0.3585589975118637,0.36008699735005695,0.3616030017534892,0.36310700078805286,0.3646000027656555,0.36608000348011654,0.36754899720350903,0.36900700132052106,0.37045200169086456,0.3718849966923396,0.37330499788125354,0.3747139995296796,0.3761110007762909,0.37749699999888736,0.37886999547481537,0.38023200382788974,0.38158200681209564,0.38292000194390613,0.38424700250228244,0.385562002658844,0.38686500241359073,0.3881560017665227,0.3894359990954399,0.39070400098959607,0.3919600024819374,0.393205001950264,0.3944370026389758,0.3956579988201459,0.39686599870522815,0.3980620006720225,0.39924700061480206,0.40042000512282055,0.4015809992949168,0.40273000051577884,0.40386799971262616,0.40499399850765866,0.40610799690087634,0.4072110007206599,0.4083020016551018,0.40938099722067517,0.41044799486796063,0.41150399794181186,0.4125479981303215,0.4135800028840701,0.41460099816322327,0.41560999552408856,0.41660699993371964,0.41759200145800907,0.41856500258048374,0.41952600330114365,0.4204750011364619,0.42141299198071164,0.4223390022913615,0.42325299481550854,0.42415600021680194,0.42504699776570004,0.4259260023633639,0.42679399996995926,0.4276499996582667,0.4284940039118131,0.42932700117429096,0.43014800051848096,0.43095699697732925,0.4317549988627434,0.43254200120766956,0.43331600228945416,0.43407800048589706,0.4348280007640521,0.4355659981568654,0.4362930009762446,0.43700800091028214,0.4377110004425049,0.4384030004342397,0.4390830025076866,0.4397520000735919,0.4404089997212092,0.4410550023118655,0.44168800115585327,0.44231100380420685,0.4429209977388382,0.44351999710003537,0.4441069960594177,0.4446830004453659,0.44524599860111874,0.4457970013221105,0.4463370045026143,0.4468649973471959,0.44738200306892395,0.44788699597120285,0.4483800008893013,0.4488619988163312,0.4493320013086001,0.4497910017768542,0.4502380018432935,0.45067399740219116,0.4510980024933815,0.4515099972486496,0.4519109974304835,0.45230000217755634,0.45267799993356067,0.45304400473833084,0.45339799920717877,0.4537399982412656,0.45406999439001083,0.4543890009323756,0.4546959971388181,0.45499200622240704,0.45527600000302,0.4555480008323987,0.45580899715423584,0.45605899890263873,0.45629700024922687,0.45652300119400024,0.45673799763123196,0.4569409986337026,0.4571330025792122,0.45731300115585327,0.4574820001920064,0.45763900379339856,0.4577849954366684,0.4579189990957578,0.4580410023530324,0.45815100024143857,0.458248995244503,0.4583359981576602,0.4584120015303294,0.4584749986728032,0.4585279996196429,0.4585690001646678,0.458597997824351,0.4586160058776538,0.4586229970057805,0.45861800014972687,0.4586009979248047,0.4585739995042483,0.45853399982055026,0.4584830005963643,0.4584209993481636,0.4583469976981481,0.45826200147469837,0.45817000170548755,0.4580790027976036,0.4579870030283928,0.457895003259182,0.45780399938424426,0.45771200209856033,0.4576210007071495,0.4575289984544118,0.45743799954652786,0.45734599481026333,0.45725500335295993,0.4571630011002223,0.4570720046758652,0.4569800024231275,0.45688900103171665,0.4567980046073596,0.4567059949040413,0.4566150059302648,0.45652399708827335,0.4564319998025894,0.4563410008947055,0.45624999950329465,0.45615900307893753,0.456066998342673,0.4559760019183159,0.45588500052690506,0.45579399913549423,0.4557030027111371,0.4556120013197263,0.4555200015505155,0.45542900264263153,0.4553380037347476,0.4552469998598099,0.45515600095192593,0.4550649995605151,0.4549740006526311,0.45488300174474716,0.45479199786980945,0.4547010014454524,0.45461000005404156,0.45451899866263074,0.4544290006160736,0.4543379967411359,0.45424700031677884,0.45415600140889484,0.4540650025010109,0.45397400110960007,0.4538839980959892,0.4537929967045784,0.4537020002802213,0.45361099640528363,0.4535209983587265,0.45342999945084256,0.45333900302648544,0.4532490049799283,0.4531580035885175,0.45306699971357983,0.4529769991834958,0.45288600275913876,0.45279599726200104,0.4527050008376439,0.45261399696270627,0.45252399891614914,0.4524329950412114,0.45234299451112747,0.45225199560324353,0.452162005007267,0.45207199702660245,0.45198100556929904,0.4518910025556882,0.45179999868075055,0.4517100031177203,0.4516199976205826,0.45152899871269864,0.4514389981826146,0.4513490026195844,0.45125899463891983,0.4511679982145627,0.45107800016800564,0.4509880021214485,0.45089800159136456,0.45080799609422684,0.4507169971863429,0.45062699913978577,0.4505369986097018,0.4504469980796178,0.45035699754953384,0.4502670019865036,0.45017699897289276,0.4500869984428088,0.44999700287977856,0.4499069998661677,0.4498169993360837,0.44972700377305347,0.4496369982759158,0.4495469977458318,0.4494569996992747,0.4493670016527176,0.44927700112263363,0.4491879989703496,0.44909800092379254,0.4490080028772354,0.44891800234715146,0.44882799685001373,0.4487389996647835,0.44864900161822635,0.4485590010881424,0.44846900304158527,0.4483800008893013,0.4482899953921636,0.4481999948620796,0.4481110026439031,0.44802099963029224,0.447932002445062,0.447842001914978,0.4477529972791672,0.44766300171613693,0.447573001186053,0.44748400151729584,0.447393998503685,0.44730499635140103,0.4472159966826439,0.44712600111961365,0.4470370014508565,0.44694700092077255,0.4468579962849617,0.44676899661620456,0.4466789960861206,0.44659000138441723,0.4465009992321332,0.44641100118557614,0.446322001516819,0.44623300184806186,0.446142998834451,0.44605399668216705,0.4459650019804637,0.44587600231170654,0.4457869976758957,0.44569799800713855,0.4456079999605815,0.44551900029182434,0.4454299981395404,0.44534099847078323,0.445252001285553,0.445162999133269,0.44507400194803876,0.44498499979575473,0.44489600509405136,0.4448070004582405,0.44471800327301025,0.4446289986371994,0.44454000145196915,0.4444509992996852,0.44436200459798175,0.4442739933729172,0.4441849961876869,0.44409600148598355,0.4440069993336995,0.44391799966494244,0.4438300008575122,0.44374100118875504,0.4436519965529442,0.4435630018512408,0.44347499559322995,0.4433859934409459,0.44329699873924255,0.4432089999318123,0.4431200052301089,0.4430310030778249,0.4429430017868678,0.44285400211811066,0.4427660008271535,0.44267699867486954,0.4425889973839124,0.44250000019868213,0.44241199890772503,0.4423229992389679,0.44223499794801074,0.4421460007627805,0.4420579969882965,0.44196899731953937,0.441881000995636,0.44179299970467883,0.4417040025194486,0.4416159987449646,0.44152799745400745,0.4414390002687772,0.44135099401076633,0.44126300017038983,0.4411749963959058,0.4410860016942024,0.44099800040324527,0.4409099966287613,0.4408220003048579,0.44073399901390076,0.4406449993451436,0.44055700053771335,0.44046899924675625,0.4403809954722722,0.44029299914836884,0.4402050053079923,0.4401170015335083,0.4400289977590243,0.43994099895159405,0.4398530001441638,0.43976500382026035,0.4396769975622495,0.4395889987548192,0.43950100243091583,0.43941299865643185,0.4393260031938553,0.4392379994193713,0.43914999564488727,0.439061996837457,0.4389740029970805,0.43888600418965024,0.43879900376001996,0.4387110024690628,0.4386229986945788,0.4385350023706754,0.4384479969739914,0.438360000650088,0.438271996875604,0.43818500141302746,0.43809699763854343,0.43800999720891315,0.4379219984014829,0.4378339995940526,0.43774699916442233,0.43765900035699207,0.43757199744383496,0.4374839961528778,0.43739700069030124,0.43730899939934414,0.43722199896971387,0.4371340001622836,0.43704699724912643,0.43696000178654987,0.4368720029791196,0.4367850000659625,0.43669699877500534,0.43660999834537506,0.4365230028827985,0.4364359999696414,0.43634800364573795,0.43626099576552707,0.43617400030295056,0.4360859990119934,0.4360429992278417};
        //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12690951178471246,0.12775300070643425,0.12864899883667627,0.12949799994627634,0.13033499817053476,0.13115999847650528,0.13197200000286102,0.13277300198872885,0.13356399784485498,0.13434399788578352,0.1351140004893144,0.1358729973435402,0.1366219980021318,0.13736100122332573,0.13809000079830488,0.13880900045235953,0.1395170030494531,0.14022000009814897,0.1409200020134449,0.14161799972256026,0.14231599743167558,0.1430119996269544,0.1437069997191429,0.14439900095264116,0.14509000008304915,0.14577900245785713,0.14646699900428453,0.1471530000368754,0.1478360009690126,0.14851699893673262,0.14919699976841608,0.14987300336360931,0.1505470002690951,0.15121899917721748,0.15188999846577644,0.15255799889564514,0.15322299798329672,0.1538850019375483,0.1545440008242925,0.1551979991296927,0.15584900105992952,0.1564949999252955,0.15713699782888094,0.15777499849597612,0.1584080010652542,0.1590379998087883,0.1596640000740687,0.16028699899713197,0.1609060031672319,0.16152099892497063,0.1621329995493094,0.16274100169539452,0.16334600125749907,0.16394799947738647,0.16454700008034706,0.1651419997215271,0.16573400050401688,0.16632299994428953,0.1669089992841085,0.16749199976523718,0.16807099928458533,0.16864700242877007,0.16921999926368395,0.16979100182652473,0.17035700008273125,0.17092099785804749,0.17148100088040033,0.1720410001774629,0.17260000109672546,0.17316000163555145,0.17371900007128716,0.1742789993683497,0.1748389999071757,0.1754000000655651,0.1759600006043911,0.17651999990145364,0.1770809975763162,0.17764399821559587,0.17820800095796585,0.17877300331989923,0.1793410008152326,0.1799120008945465,0.1804839993516604,0.18105900039275488,0.18163599943121275,0.18221399933099747,0.18279500181476274,0.18337599808971086,0.18395200123389563,0.18452400093277296,0.1850919984281063,0.185654999067386,0.186214001228412,0.18676800156633058,0.18731900056203207,0.18786499897638956,0.18840700015425682,0.18894399950901666,0.1894769991437594,0.1900059978167216,0.19052999839186668,0.19104999924699465,0.19156500324606895,0.19207700217763582,0.19258400176962218,0.1930870016415914,0.1935849984486898,0.19407899926106134,0.19456899786988893,0.19505399838089943,0.19553600127498308,0.19601300110419592,0.19648600245515505,0.19695399949947992,0.197418000549078,0.19787799815336862,0.19833300138513246,0.19878500203291574,0.1992319996158282,0.19967500244577727,0.20011299972732863,0.20054699977238974,0.2009769988556703,0.20140199859937033,0.2018239994843801,0.20224099978804588,0.20265399912993112,0.20306200037399927,0.20346600065628687,0.20386600121855736,0.20426099871595702,0.2046519989768664,0.20503900200128555,0.20542200033863386,0.2057999980946382,0.20617499947547913,0.20654399941364923,0.20690999800960222,0.2072710022330284,0.20762800052762032,0.20798100158572197,0.20833000168204308,0.2086739999552568,0.20901399850845337,0.20935000230868658,0.20968099931875864,0.2100080003341039,0.21033100162943205,0.2106500007212162,0.2109649988512198,0.2112750013669332,0.21158099919557571,0.21188199892640114,0.2121790014207363,0.21247300008932749,0.21276199941833815,0.2130470002690951,0.21332799891630808,0.21360400194923082,0.2138759990533193,0.21414300054311752,0.2144059973458449,0.21466500063737234,0.21492000048359236,0.2151709981262684,0.21541699891289076,0.21566000084082285,0.21589700256784758,0.21613099922736487,0.21636000151435533,0.21658500035603842,0.21680699909726778,0.21702400098244348,0.21723599980274835,0.21744400014479956,0.21764799828330675,0.21784799918532372,0.2180439978837967,0.21823500096797943,0.21842299898465475,0.2186060001452764,0.21878399699926376,0.2189589999616146,0.21912899985909462,0.21929500003655752,0.2194570004940033,0.2196149987479051,0.21976899976531664,0.21991800020138422,0.22006299967567125,0.22020299856861433,0.22033999984463057,0.2204729989171028,0.22060099989175797,0.22072499866286913,0.22084500143925348,0.22095999990900358,0.2210710011422634,0.22117799893021584,0.22128100072344145,0.22138000279664993,0.22147400056322417,0.2215639998515447,0.22164999941984811,0.221731998026371,0.22181000063816705,0.2218830001850923,0.2219520000120004,0.22201699887712797,0.2220780005057653,0.22213499868909517,0.22218799963593483,0.2222360000014305,0.2222789985438188,0.22232000157237053,0.22235599905252457,0.22238699967662492,0.2224150002002716,0.22243799765904745,0.2224570003648599,0.22247099876403809,0.22248100116848946,0.22248699888586998,0.2224889981249968,0.2224879985054334,0.22248099992672601,0.22247100124756494,0.22245599702000618,0.22243700052301088,0.22241399809718132,0.22238699967662492,0.222356000294288,0.22232099870840707,0.22228099778294563,0.22223700086275736,0.22218899925549826,0.22213700165351233,0.22208299984534582,0.22202800090114275,0.22197400157650313,0.22191999976833662,0.22186600044369698,0.22181199863553047,0.22175800055265427,0.22170399750272432,0.221650001903375,0.2215960013369719,0.2215419995288054,0.2214869981010755,0.2214330000181993,0.2213789994517962,0.22132500012715658,0.22127199793855348,0.22121800109744072,0.22116399804751077,0.22110999872287115,0.2210559993982315,0.2210020013153553,0.22094800074895224,0.22089400018254915,0.2208399996161461,0.22078600029150644,0.22073199848333994,0.22067900002002716,0.22062499821186066,0.22057100012898445,0.2205170008043448,0.2204629989961783,0.22041000053286552,0.22035599872469902,0.22030199940005937,0.2202480025589466,0.22019500037034354,0.22014099980394045,0.22008700047930083,0.22003400325775146,0.2199799989660581,0.21992599964141846,0.21987300117810568,0.21981900185346603,0.21976600090662637,0.21971199909845987,0.21965799729029337,0.21960500131050745,0.2195509970188141,0.2194979985555013,0.2194440004726251,0.21939099952578545,0.21933700268467268,0.21928400049606958,0.21922999992966652,0.21917699774106345,0.2191229984164238,0.21907000119487444,0.21901600062847137,0.21896299968163171,0.2189099999765555,0.21885600065191588,0.21880300094683966,0.2187490016222,0.2186959981918335,0.21864299972852072,0.21858899916211763,0.21853600069880486,0.21848300099372864,0.21843000253041586,0.21837600072224936,0.2183229997754097,0.21827000255386034,0.21821700036525726,0.2181629997988542,0.2181100013355414,0.21805699914693832,0.21800400068362555,0.2179509997367859,0.21789700289567313,0.21784400070707002,0.2177910010019938,0.21773800005515417,0.21768500035007796,0.2176319994032383,0.21757900093992552,0.2175260012348493,0.21747300028800964,0.21741999934116998,0.21736699963609377,0.21731399868925413,0.21726100022594133,0.2172080005208651,0.2171550008157889,0.21710199986894926,0.21704900016387305,0.21699600045879683,0.21694299951195717,0.21688999980688095,0.21683700010180473,0.21678400039672852,0.21673099820812544,0.21667899936437607,0.21662599965929985,0.2165730024377505,0.21651999900738397,0.2164670005440712,0.21641399959723154,0.2163620019952456,0.2163089985648791,0.21625599885980287,0.21620299791296324,0.21615100279450417,0.2160980006059011,0.21604500090082487,0.2159930020570755,0.21593999986847243,0.21588699892163277,0.21583499759435654,0.21578199913104376,0.21572899942596754,0.2156769980986913,0.21562400087714195,0.21557199954986572,0.21551899860302606,0.2154660001397133,0.21541399881243706,0.21536099910736084,0.21530899902184805,0.21525600055853525,0.21520400047302246,0.2151510032514731,0.21509900068243346,0.2150459997355938,0.214993999650081,0.21494199708104134,0.21488900110125542,0.21483700101574263,0.2147839975853761,0.2147320012251536,0.21467999865611395,0.21462700019280115,0.21457500010728836,0.21452300250530243,0.2144699990749359,0.21441800023118654,0.21436600014567375,0.2143129991988341,0.21426100035508475,0.21420900026957193,0.2141569989422957,0.21410399799545607,0.21405200039347014,0.21399999782443047,0.21394800022244453,0.21389600013693175,0.21384300167361894,0.2137910003463427,0.21373900026082993,0.21368700017531714,0.21363500133156776,0.2135829987625281,0.21353099991877875,0.21347899859150252,0.2134269985059897,0.21337500090400377,0.21332299833496413,0.21327000111341476,0.21321799730261168,0.21316600094238916,0.21311400085687637,0.213063000390927,0.21301099906365076,0.2129590002199014,0.2129070001343886,0.2128550000488758,0.21280299872159958,0.2127509998778502,0.21269899979233742,0.21264699970682463,0.21259499962131181,0.21254299953579903,0.21249200155337652,0.2124400002261003,0.21238800138235092,0.2123360000550747,0.21228400245308876,0.21223299826184908,0.2121810019016266,0.21212900057435036,0.21207699924707413,0.21202600002288818,0.21197399869561195,0.21192199861009917,0.21187100062767664,0.21181900054216385,0.21176700169841448,0.21171599874893823,0.2116639999051889,0.21161199981967607,0.21156100059549013,0.21150899802645048,0.2114579975605011,0.2114060012002786,0.21135499825080237,0.211302999407053,0.21125100056330362,0.21120000009735426,0.2111480012536049,0.21109700202941895,0.21104499946037927,0.21099400147795677,0.21094299977024397,0.2108910009264946,0.21084000170230865,0.21078800037503242,0.21073700115084648,0.21068499982357025,0.21063399935762087,0.21058300137519836,0.2105309988061587,0.21047999834020933,0.2104290003577868,0.21037700027227402,0.21032599980632463,0.2102750005821387,0.21022299925486246,0.21017200003067651,0.21012099956472716,0.21006999909877777,0.21001799777150154,0.2099669985473156,0.20991599932312965,0.20986500134070715,0.20981399714946747,0.20976199954748154,0.20971100156505904,0.2096599998573462,0.20960899939139685,0.2095580001672109,0.20950700094302496,0.20945600171883902,0.2094050000111262,0.20935400078694025,0.2093030003209909,0.20925100023547807,0.20919999852776527,0.20914900054534277,0.2090980000793934,0.20907300213972727};
        C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.2844058970610301,0.28999100128809613,0.2952450017134349,0.3011849994460742,0.30703899761041004,0.31280900289614993,0.31849299867947894,0.32409899681806564,0.3296329975128174,0.33509699751933414,0.34049099932114285,0.3458139995733897,0.3510650048653285,0.3562460020184517,0.36135600010554,0.3663950016101201,0.3713639974594116,0.37629099438587826,0.3812070017059644,0.3861110011736552,0.3910039961338043,0.39588600645462674,0.40075699736674625,0.4056159978111585,0.4104650020599365,0.41530100256204605,0.42012500017881393,0.42493599901596707,0.42973100145657855,0.4345100025335948,0.4392719989021619,0.44401900221904117,0.4487499992052714,0.45346499979496,0.4581649949153264,0.46284900108973187,0.46751699844996136,0.47216399759054184,0.47678199658791226,0.48137100289265317,0.48593199998140335,0.4904650002717972,0.49497000128030777,0.4994479989012082,0.503897006313006,0.5083180020252863,0.5127100000778834,0.5170769989490509,0.5214210003614426,0.525739997625351,0.5300369958082835,0.534310003121694,0.5385599931081136,0.5427870005369186,0.5469900021950403,0.5511689980824789,0.555326004823049,0.5594589859247208,0.5635720044374466,0.5676620006561279,0.5717310011386871,0.5757790009180704,0.5798039883375168,0.5838070064783096,0.5877890040477117,0.5917499909798304,0.5956889937321345,0.5996169944604238,0.6035459985335668,0.6074750026067098,0.6114060034354528,0.6153390059868494,0.6192720035711924,0.6232059995333353,0.6271410038073858,0.6310759981473287,0.6350120107332865,0.6389549970626831,0.6429130037625631,0.6468839993079504,0.6508699953556061,0.654869998494784,0.6588840037584305,0.6629119962453842,0.6669540007909139,0.6710100024938583,0.6750809997320175,0.679143006602923,0.6831750025351843,0.6871769974629084,0.6911499996980032,0.6950939993063608,0.6990070094664892,0.7028899937868118,0.7067429920037588,0.7105659991502762,0.7143590052922567,0.7181219955285391,0.7218550046284994,0.7255600094795227,0.7292339950799942,0.7328779995441437,0.7364930113156637,0.7400769939025243,0.7436310003201166,0.7471559941768646,0.7506520003080368,0.7541179955005646,0.7575539996226629,0.7609600027402242,0.7643359998861948,0.7676820109287897,0.770997996131579,0.7742849985758463,0.7775429983933767,0.7807720005512238,0.7839699983596802,0.7871380001306534,0.7902770141760508,0.7933850040038427,0.7964649945497513,0.7995150039593378,0.8025359958410263,0.805527001619339,0.808488001426061,0.8114189952611923,0.8143209914366404,0.8171920031309128,0.820034995675087,0.8228489955266317,0.8256330043077469,0.828386997183164,0.8311120023330053,0.8338070015112559,0.8364719996849695,0.8391080051660538,0.8417149980862936,0.8442929983139038,0.8468410074710846,0.849359005689621,0.8518480012814204,0.8543070008357366,0.8567359993855158,0.8591369936863581,0.8615090052286783,0.8638510008653005,0.8661630054314932,0.8684460073709488,0.87069899837176,0.8729230066140493,0.8751180022954941,0.8772850036621094,0.879421000679334,0.8815290033817291,0.8836059818665186,0.8856540024280548,0.8876729955275854,0.8896619975566864,0.8916219969590505,0.8935539970795313,0.8954570045073827,0.8973300009965897,0.8991730014483134,0.9009870042403539,0.9027710060278574,0.9045270085334778,0.9062550018231074,0.9079529990752538,0.909621000289917,0.9112599988778433,0.9128699998060862,0.914451003074646,0.9160010019938151,0.917524000008901,0.9190179953972498,0.920483003060023,0.9219180047512054,0.9233239988485972,0.9247010002533594,0.9260480006535848,0.9273669968048731,0.9286580036083857,0.9299189945062002,0.9311510076125463,0.9323539982239405,0.933527002731959,0.9346719980239868,0.9357869972785314,0.9368730088075002,0.9379320045312246,0.938960999250412,0.9399610012769699,0.9409320056438446,0.9418729990720749,0.9427849998076757,0.9436699996391932,0.9445260067780813,0.9453519980112711,0.946150004863739,0.9469179858764013,0.9476579974095026,0.9483679930369059,0.9490490009387335,0.9497020045916239,0.95032699406147,0.9509219924608866,0.9514889965454737,0.9520270079374313,0.952534998456637,0.9530149946610132,0.9534659882386526,0.9538890073696772,0.9542840073506037,0.9546489963928858,0.9549850076436996,0.9552920063336691,0.9555710007747015,0.9558200041453043,0.9560409933328629,0.9562349915504456,0.9563990036646525,0.9565350015958151,0.9566410034894943,0.9567190110683441,0.9567670077085495,0.9567879835764567,0.9567809949318568,0.95674500366052,0.9566800047953924,0.9565859983364741,0.9564630091190338,0.9563120057185491,0.9561310062805811,0.9559229910373688,0.9556870063145956,0.9554220040639242,0.9551280041535696,0.9548200070858002,0.9545120000839233,0.9542049964269003,0.9538969943920771,0.9535890022913615,0.9532819986343384,0.9529739965995153,0.9526669979095459,0.9523589958747228,0.9520520021518072,0.951744998494784,0.9514379898707072,0.9511310011148453,0.9508249958356222,0.9505180070797602,0.9502110083897909,0.9499050031105677,0.949599007765452,0.9492919991413752,0.9489859938621521,0.9486800034840902,0.948373998204867,0.9480680028597513,0.947762002547582,0.9474569956461588,0.9471509953339895,0.9468459983666738,0.946539988120397,0.946234996120135,0.9459299991528193,0.94562499721845,0.9453200002511343,0.9450149983167648,0.9447100013494492,0.9444049894809723,0.944101000825564,0.9437959988911947,0.943492000301679,0.9431879967451096,0.9428830047448477,0.9425789962212244,0.9422749976317087,0.9419709990421931,0.9416670004526774,0.9413640002409617,0.9410599966843923,0.9407570014397303,0.9404529929161072,0.9401500076055527,0.9398469974597295,0.9395439972480139,0.9392399986584982,0.9389379968245825,0.9386350015799204,0.9383320013682047,0.9380290061235428,0.9377270042896271,0.9374240040779114,0.9371220022439957,0.93682000041008,0.9365179985761642,0.9362159967422485,0.9359139998753866,0.9356119980414709,0.9353099962075552,0.9350079993406931,0.9347070058186849,0.9344050089518229,0.9341039955615997,0.9338030070066452,0.9335010051727295,0.9332000017166138,0.9328990032275518,0.9325990130503973,0.932297999660174,0.9319970011711121,0.9316959977149963,0.931396002570788,0.9310960024595261,0.9307949890693029,0.930495003859202,0.9301949987808863,0.9298949986696243,0.9295949985583624,0.929295003414154,0.9289950033028921,0.9286959916353226,0.9283959915240606,0.928096999724706,0.9277979930241903,0.9274979879458746,0.9271990011135737,0.9269000043471655,0.9266010075807571,0.9263019959131876,0.9260029991467794,0.9257050057252248,0.9254060039917628,0.9251080006361008,0.9248089989026388,0.9245109806458155,0.9242129971583685,0.9239150037368139,0.9236169954140981,0.923318992058436,0.9230209986368815,0.9227239986260732,0.9224260002374649,0.9221279968818029,0.9218309968709946,0.9215339869260788,0.9212360084056854,0.9209389984607697,0.9206419984499613,0.9203449934720993,0.9200489968061447,0.9197520067294439,0.9194549967845281,0.919158990184466,0.9188619951407114,0.9185659885406494,0.9182689984639486,0.9179730067650477,0.9176770001649857,0.9173810034990311,0.9170849919319153,0.9167899986108144,0.9164940069119135,0.9161980003118515,0.9159030020236969,0.9156069954236349,0.9153120070695877,0.9150169889132181,0.9147220055262247,0.9144270022710165,0.9141319990158081,0.9138370007276535,0.9135419974724451,0.9132479975620905,0.9129529992739359,0.9126590043306351,0.9123640010754267,0.9120700011650721,0.9117760012547175,0.9114820013443629,0.9111879964669546,0.9108940015236536,0.9106000065803528,0.9103060116370519,0.9100130051374435,0.9097189952929815,0.9094259937604269,0.9091329872608185,0.9088390022516251,0.9085459957520167,0.9082529991865158,0.9079599976539612,0.9076669961214066,0.9073749979337057,0.9070820162693659,0.9067890097697576,0.906497006615003,0.9062049935261408,0.9059120019276937,0.9056199987729391,0.9053280005852381,0.9050359974304835,0.9047440042098364,0.9044520010550817,0.9041609962781271,0.9038689980904261,0.9035779982805252,0.903286005059878,0.9029950002829233,0.9027029971281687,0.9024119973182678,0.9021210024754206,0.9018299927314123,0.9015390127897263,0.9012490014235178,0.9009580016136169,0.9006670018037161,0.900377000371615,0.9000869989395142,0.8997959991296133,0.8995060125986735,0.8992160012324651,0.8989259998003641,0.8986359983682632,0.8983459919691086,0.8980560004711151,0.8977669974168142,0.8974770059188207,0.8971879929304123,0.8968980063994726,0.8966090033451716,0.8963200002908707,0.8960310171047846,0.8957419991493225,0.8954529911279678,0.8951640029748281,0.8948749999205271,0.8945869902769724,0.8942980070908865,0.8940100024143854,0.8937209943930308,0.8934329996506373,0.8931450049082438,0.8928570002317429,0.8925690054893494,0.8922809958457947,0.891993006070455,0.8917060047388077,0.8914180099964142,0.8911309987306595,0.8908429990212122,0.8905560076236725,0.8902690062920252,0.8899810016155243,0.889694000283877,0.8894069989522299,0.88912100593249,0.8888339946667353,0.8885470032691956,0.8882610003153483,0.8879740039507548,0.8876880009969076,0.8874009946982065,0.8871150016784668,0.8868289987246195,0.8865429957707723,0.8862569977839788,0.885971004764239,0.885684996843338,0.8854000071684519,0.8851140042146047,0.8848289946715037,0.8845429966847101,0.8842579970757166,0.8839729974667231,0.8836879928906759,0.8834029932816824,0.8831179986397425,0.8828330039978027,0.8825479944547018,0.8822639932235082,0.8819790035486221,0.8816950072844824,0.8815520058075587};
        //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12944590176145235,0.13278100018699965,0.13609799866875014,0.13956499844789505,0.14298200234770775,0.14634900043408075,0.1496669997771581,0.15293900047739348,0.1561689985295137,0.15935800224542618,0.16250699882706007,0.16561499858895937,0.16868000105023384,0.17170500010252,0.17468800023198128,0.17763099695245424,0.18053199847539267,0.18340799833337465,0.18627899885177612,0.18914300203323364,0.19199899832407633,0.1948490006228288,0.19769300147891045,0.20052999878923097,0.2033590003848076,0.20618300264080366,0.2089999976257483,0.2118079997599125,0.2146069978674253,0.2173979990184307,0.2201789990067482,0.22295000031590462,0.2257129984597365,0.22846599916617075,0.2312089999516805,0.233944001297156,0.23666900023818016,0.23938100039958954,0.2420760008196036,0.24475500111778578,0.24741900091369948,0.250065000106891,0.2526960050066312,0.2553109998504321,0.25790799657503766,0.26048899938662845,0.2630529999732971,0.2656029984354973,0.2681380013624827,0.27065999805927277,0.27316900342702866,0.27566399921973544,0.2781449978550275,0.2806130026777585,0.2830670028924942,0.2855070009827614,0.2879349986712138,0.2903490016857783,0.2927500009536743,0.29513800392548245,0.2975150023897489,0.29987800121307373,0.30222899715105694,0.30456699430942535,0.3068920026222865,0.30920500059922534,0.3115050022800763,0.3137980004151662,0.31609299530585605,0.3183880001306534,0.32068400581677753,0.32297999660174054,0.325274998943011,0.3275719955563545,0.32986899962027866,0.3321680004398028,0.33446700125932693,0.3367689996957779,0.33907999843358994,0.3413989990949631,0.3437259991963704,0.34606100370486576,0.34840300182501477,0.3507539977629979,0.3531140014529228,0.35548200209935504,0.35785700132449466,0.36022700121005374,0.3625800038377444,0.36491500089565915,0.3672329957286517,0.3695340007543564,0.3718169977267583,0.3740830024083455,0.37633099903663,0.37856200089057285,0.38077399879693985,0.3829710011680921,0.385150005420049,0.3873110016187032,0.38945600390434265,0.3915820022424062,0.39369100083907443,0.3957820013165474,0.39785699794689816,0.3999149998029073,0.4019549985726674,0.40397800753513974,0.40598300099372864,0.40797000130017597,0.409940001865228,0.4118940010666847,0.4138299996654193,0.41574900100628537,0.4176510001222293,0.41953499615192413,0.4214009965459506,0.4232510030269623,0.4250820030768712,0.42689700424671173,0.4286950007081032,0.43047600487867993,0.43223900099595386,0.4339849998553594,0.4357130005955696,0.4374240015943845,0.43911799788475037,0.44079599529504776,0.44245600203673047,0.4440989966193835,0.445723998049895,0.447332002222538,0.4489220008254051,0.45049600303173065,0.4520530005296071,0.4535929982860883,0.45511599630117416,0.4566209986805916,0.4581089988350868,0.4595790033539136,0.4610330065091451,0.4624699999888738,0.4638900011777878,0.46529199928045273,0.4666769976417224,0.4680450012286504,0.4693959951400757,0.4707299992442131,0.47204699615637463,0.4733470007777214,0.474630003174146,0.4758960008621216,0.4771440053979556,0.4783750002582868,0.47958899786074954,0.4807869990666707,0.4819680005311966,0.4831309989094734,0.48427700499693555,0.4854059964418411,0.4865180005629857,0.4876120040814082,0.48869000126918155,0.48975200206041336,0.49079599728186923,0.4918229977289836,0.4928330034017563,0.4938260018825531,0.49480099976062775,0.4957599987586339,0.49670299887657166,0.49762799839178723,0.49853599816560745,0.49942799905935925,0.500300998489062,0.5011579940716425,0.5019990007082621,0.5028230100870132,0.5036289989948273,0.5044189840555191,0.5051920016606649,0.5059470037619272,0.5066859920819601,0.5074080129464468,0.5081129918495814,0.5088020066420237,0.5094729959964752,0.5101280013720194,0.510764996210734,0.511384998758634,0.511989007393519,0.5125769972801208,0.5131469964981079,0.513701006770134,0.5142369965712229,0.5147560139497122,0.5152590026458105,0.5157449940840403,0.5162150065104166,0.516666998465856,0.5171030014753342,0.5175220022598902,0.5179240008195242,0.5183090021212896,0.5186769962310791,0.5190290063619614,0.519365002711614,0.5196829984585444,0.5199839969476064,0.5202689965566,0.5205359905958176,0.5207870006561279,0.5210209985574087,0.5212389975786209,0.521439994374911,0.5216250022252401,0.521791989604632,0.521942009528478,0.5220759958028793,0.5221930046876272,0.5222940047581991,0.5223790059487025,0.5224459916353226,0.5224969983100891,0.5225300043821335,0.5225470016400019,0.5225480000178019,0.522531991203626,0.5224999984105428,0.5224510083595911,0.5223850011825562,0.5223020017147064,0.5222020049889883,0.5220859994490942,0.5219540049632391,0.5218059966961542,0.5216400027275085,0.521466001868248,0.5212929944197336,0.5211189985275269,0.5209449927012125,0.5207720051209132,0.5205979943275452,0.5204249918460846,0.5202510009209315,0.5200780034065247,0.5199039975802103,0.519731009999911,0.519557997584343,0.5193849951028824,0.5192120025555292,0.5190390050411224,0.5188660025596619,0.5186930000782013,0.5185199975967407,0.5183470050493876,0.518174002567927,0.5180019984642664,0.5178289959828059,0.517655998468399,0.5174840092658997,0.5173109968503317,0.5171389977137247,0.5169670035441717,0.5167939960956573,0.5166219969590505,0.5164499978224436,0.5162780036528906,0.51610599954923,0.515934000412623,0.5157620012760162,0.5155899971723557,0.5154180030028025,0.5152459988991419,0.5150749931732813,0.5149029990037283,0.5147309998671213,0.5145599941412607,0.5143880099058151,0.5142170041799545,0.5140449951092402,0.5138739943504333,0.513703003525734,0.5135320077339808,0.5133599986632665,0.5131890028715134,0.5130180070797602,0.5128470013538996,0.5126760005950928,0.5125059882799784,0.512334997455279,0.5121639966964722,0.511993000904719,0.5118230034907659,0.511652002731959,0.5114820003509521,0.5113109995921453,0.5111410021781921,0.5109700014193853,0.5107999990383784,0.510630006591479,0.5104600091775259,0.5102899968624115,0.5101190010706583,0.5099489937225977,0.5097800095876058,0.5096099972724915,0.509440004825592,0.5092699974775314,0.5091000000635783,0.5089310059944788,0.5087609936793646,0.5085909962654114,0.508422002196312,0.5082519948482513,0.5080829958120981,0.5079140116771063,0.5077439894278845,0.5075750052928925,0.5074059963226318,0.5072369972864786,0.5070680032173792,0.5068990041812261,0.5067299902439117,0.5065610011418661,0.5063920021057129,0.506223996480306,0.5060550024112066,0.505885993440946,0.5057179977496465,0.5055489987134933,0.5053809980551401,0.5052119990189871,0.5050439933935801,0.5048749993244807,0.504707008600235,0.5045389980077744,0.5043710023164749,0.5042030016581217,0.5040350009997686,0.5038670003414154,0.503699004650116,0.5035309990247091,0.5033630033334097,0.5031950076421102,0.5030280003945032,0.5028599997361501,0.5026920040448507,0.5025249918301901,0.5023570011059443,0.5021900037924448,0.5020230064789454,0.5018550058205923,0.5016879985729853,0.5015210012594858,0.5013540039459864,0.501186008254687,0.5010189960400263,0.5008520036935806,0.5006859997908274,0.5005189975102743,0.5003519902626673,0.5001850028832754,0.5000179956356684,0.499851996699969,0.49968499938646954,0.4995190004507701,0.49935200065374374,0.4991860017180443,0.49901900440454483,0.49885299801826477,0.4986870015660922,0.49852100263039273,0.4983540003498395,0.4981879989306132,0.49802200744549435,0.4978560035427411,0.49769000212351483,0.49752500156561535,0.4973589951793353,0.49719300121068954,0.49702699730793637,0.4968620042006175,0.49669599781433743,0.4965309997399648,0.4963650008042653,0.496199997762839,0.49603399882713956,0.4958690007527669,0.49570400019486743,0.49553800125916797,0.4953730031847954,0.495208000143369,0.4950429971019427,0.49487799902757007,0.4947129984696706,0.494548000395298,0.49438400318225223,0.49421899517377216,0.49405400454998016,0.4938890015085538,0.4937250042955081,0.493559996287028,0.49339599907398224,0.4932309960325559,0.493067001303037,0.4929030016064644,0.492737998565038,0.4925740013519923,0.4924099991718928,0.49224600195884705,0.49208199977874756,0.49191800008217496,0.49175399790207547,0.4915900031725566,0.4914260034759839,0.4912619988123576,0.4910990024606387,0.49093499779701233,0.49077100058396655,0.4906080017487208,0.49044399956862134,0.49028100321690243,0.49011699855327606,0.4899539997180303,0.48979099839925766,0.4896279995640119,0.4894639973839124,0.48930100351572037,0.48913799971342087,0.4889750008781751,0.48881199955940247,0.4886490007241567,0.48848599940538406,0.48832400391499203,0.48816100011269253,0.48799799879391986,0.48783599336942035,0.4876730019847552,0.4875099981824557,0.4873479977250099,0.48718499888976413,0.4870230033993721,0.4868610029419263,0.4866989975174268,0.48653600364923477,0.486374003191789,0.48621199776728946,0.48604999979337055,0.48588800181945163,0.4857260013620059,0.4855640009045601,0.48540200541416806,0.48524100085099536,0.48507899791002274,0.4849170024196307,0.484755997856458,0.48459399739901227,0.48443300276994705,0.4842709998289744,0.48410999526580173,0.4839479997754097,0.4837869976957639,0.48362600058317184,0.4834650009870529,0.4833039989074071,0.4831420034170151,0.48298099885384244,0.48281999429066974,0.48265999803940457,0.48249900341033936,0.4823379988471667,0.4821769992510478,0.482015997171402,0.48185600092013675,0.4816950013240178,0.48153500258922577,0.48137400050957996,0.4812139968077342,0.48105299721161526,0.48089299847682315,0.4807329972585042,0.48057300100723904,0.4804120014111201,0.4802519952257474,0.4801719958583514};
        //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09223855659365654,0.09351150008539359,0.0947222001850605,0.09604009923835595,0.09733929981787999,0.0986189004033804,0.09987919963896275,0.1011220005651315,0.10234900005161762,0.10356099965671699,0.10475599952042103,0.10593599950273831,0.10709900036454201,0.10824700072407722,0.10937900034089883,0.11049499859412511,0.11159600007037322,0.11268800062437852,0.11377600021660328,0.1148620005697012,0.11594600044190884,0.11702599997321765,0.11810499988496304,0.11918000007669131,0.12025399940709273,0.1213249998788039,0.12239300025006135,0.12345799927910169,0.12451900045077006,0.12557699903845787,0.12663200000921884,0.1276830012599627,0.1287300003071626,0.12977399925390878,0.1308139997224013,0.13185000171264014,0.13288399825493494,0.1339119995633761,0.1349330022931099,0.1359490007162094,0.1369590014219284,0.13796199982364973,0.1389580008884271,0.13994800051053366,0.14093200117349625,0.141910000393788,0.1428819994131724,0.14384700109561285,0.14480799933274588,0.14576399947206178,0.14671299730738005,0.14765800163149834,0.14859800040721893,0.14953199898203215,0.15046000108122826,0.15138399973511696,0.15230300153295198,0.15321599940458933,0.154124998797973,0.15502900133530298,0.1559279983242353,0.15682199969887733,0.15771099800864855,0.1585949994623661,0.15947499995430311,0.1603499986231327,0.16121900205810866,0.1620860000451406,0.16295399889349937,0.1638219989836216,0.16469000031550726,0.16555800040562949,0.1664260004957517,0.16729500020543733,0.16816399991512299,0.1690329983830452,0.1699029989540577,0.17077399790287018,0.17164799943566322,0.17252499982714653,0.17340600118041039,0.17428900053103766,0.17517599960168204,0.1760649991532167,0.17695799842476845,0.1778539977967739,0.1787529985109965,0.17964999874432883,0.1805410012602806,0.18142599860827127,0.18230300024151802,0.1831739991903305,0.18403799956043562,0.1848950001100699,0.1857459992170334,0.18659000098705292,0.18742700045307478,0.18825799971818924,0.18908200164635977,0.18989900002876917,0.19071000069379807,0.19151300067702928,0.1923109988371531,0.19310200090209642,0.19388500228524208,0.19466200098395348,0.19543299823999405,0.19619699815909067,0.19695399949947992,0.1977050006389618,0.19844899823268256,0.19918600097298622,0.1999169997870922,0.2006400004029274,0.2013579991956552,0.20206899816791216,0.2027729998032252,0.20347000161806741,0.20416100199023882,0.2048449975748857,0.20552299792567888,0.20619399969776472,0.2068580004076163,0.20751499757170677,0.20816699912150702,0.20881100123127302,0.20944900065660477,0.21007999777793884,0.21070400004585585,0.2113219996293386,0.21193400025367737,0.21253899981578192,0.21313700079917908,0.2137279969950517,0.2143129991988341,0.21489100034038225,0.21546300128102303,0.2160279986759027,0.2165870008369287,0.2171389994521936,0.21768399824698767,0.21822299932440123,0.21875500058134398,0.2192810003956159,0.21980000038941702,0.22031300142407417,0.2208179992934068,0.2213170019288858,0.22180999939640364,0.2222959982852141,0.2227760006984075,0.2232490008076032,0.2237159994741281,0.2241759995619456,0.2246289998292923,0.22507499903440475,0.22551599765817323,0.2259490005671978,0.22637700041135153,0.226797999193271,0.22721199815471968,0.2276189997792244,0.2280199999610583,0.22841400280594826,0.22880200172464052,0.2291840004424254,0.22955900058150291,0.22992699841658273,0.23028899977604547,0.2306449996928374,0.23099400103092194,0.23133599758148193,0.23167200262347856,0.23200200001398721,0.23232399920622507,0.2326409990588824,0.2329509990910689,0.23325499892234802,0.2335509993135929,0.23384100074569383,0.23412500073512396,0.23440200090408325,0.23467300087213516,0.2349380018810431,0.23519600306948027,0.2354470007121563,0.2356920006374518,0.23593000198403993,0.23616199692090353,0.23638800034920374,0.23660699898997942,0.23681999991337457,0.23702500139673552,0.23722499733169874,0.23741800213853517,0.23760400215784708,0.23778499787052473,0.2379589987297853,0.23812600101033846,0.23828599974513054,0.23844099914034209,0.2385890024403731,0.23873000343640646,0.23886500050624213,0.23899399861693382,0.23911599814891815,0.2392309991021951,0.23933999985456467,0.23944299792249998,0.2395390011370182,0.23962900042533875,0.2397129995127519,0.23979000002145767,0.23986000070969263,0.23992399871349335,0.23998199899991354,0.24003300070762634,0.2400779997309049,0.2401169997950395,0.2401490012804667,0.24017399922013283,0.24019300068418184,0.24020600070556006,0.24021200090646744,0.24021300052603087,0.24020700032512346,0.2401940015455087,0.24017400170365968,0.24014799917737642,0.24011699731151262,0.24007799848914146,0.2400329982240995,0.23998200024167696,0.23992500081658363,0.23986100032925606,0.23979000002145767,0.23971400037407875,0.23963399976491928,0.23955400039752325,0.23947399978836378,0.23939399793744087,0.2393140010535717,0.23923500006397566,0.23915500193834305,0.23907500132918358,0.2389959990978241,0.23891600221395493,0.2388359991212686,0.23875700185696283,0.2386769987642765,0.23859800149997076,0.2385180008908113,0.23843899990121523,0.23835900177558264,0.23828000078598657,0.2381999989350637,0.23812099918723106,0.23804100106159845,0.2379620000720024,0.23788300280769667,0.2378039980928103,0.23772399996717772,0.23764499897758165,0.23756599674622217,0.23748699948191643,0.2374079984923204,0.23732799912492433,0.23724900061885515,0.2371699996292591,0.23709100112318993,0.23701199889183044,0.23693300038576126,0.23685400312145552,0.23677500089009604,0.23669600238402685,0.23661799977223077,0.23653900002439818,0.2364599990348021,0.2363809992869695,0.2363019995391369,0.23622299854954085,0.2361450009047985,0.23606599991520247,0.23598700016736984,0.2359089987973372,0.23583000153303146,0.23575200140476227,0.23567299793163934,0.23559399942557016,0.23551600302259126,0.23543700203299522,0.23535899942119917,0.23527999967336655,0.23520199954509735,0.23512399941682816,0.23504499718546867,0.23496699954072633,0.23488900313774744,0.23481000090638796,0.23473200077811876,0.23465400064984956,0.23457599927981695,0.23449799915154776,0.23441900064547858,0.2343409980336825,0.23426299914717674,0.234185000260671,0.2341070001324018,0.2340290000041326,0.2339509998758634,0.2338729997475942,0.23379500086108843,0.23371699949105582,0.23363900060455003,0.23356099923451742,0.23348399996757507,0.23340600108106932,0.23332799971103668,0.23325000082453093,0.23317200069626173,0.23309499894579253,0.2330169975757599,0.232939001172781,0.23286200066407522,0.23278399805227915,0.23270700126886368,0.23262899989883104,0.23255099977056184,0.23247399926185608,0.2323969987531503,0.23231899986664453,0.2322420005997022,0.23216399922966957,0.23208699996272722,0.23200900107622147,0.23193199932575226,0.2318550000588099,0.23177800079186758,0.2317000006635984,0.23162300139665604,0.23154600088795027,0.23146899913748106,0.23139199738701186,0.23131499936183295,0.23123699923356375,0.23115999872485796,0.23108300069967905,0.23100600019097328,0.23092899968226752,0.23085200041532516,0.23077499866485596,0.2306980018814405,0.23062199975053468,0.23054499924182892,0.23046799997488657,0.2303909994661808,0.23031400019923845,0.23023799931009611,0.23016100004315376,0.2300839970509211,0.2300070027510325,0.22993099813659987,0.22985400011142096,0.2297779992222786,0.22970099871357283,0.22962400068839392,0.22954799979925156,0.2294709992905458,0.22939500088493028,0.22931800161798796,0.22924200197060904,0.22916599983970323,0.22908899933099747,0.229013000925382,0.22893700251976648,0.22886000201106071,0.22878399988015494,0.22870800271630287,0.22863199934363365,0.22855500256021818,0.22847899918754896,0.22840300078193346,0.22832699989279112,0.22825100148717561,0.2281749981145064,0.22809900095065436,0.22802300254503885,0.22794700041413307,0.22787100076675415,0.22779500111937523,0.2277190014719963,0.22764300058285394,0.22756699845194817,0.2274910012880961,0.22741499915719032,0.2273399978876114,0.22726399824023247,0.2271879973510901,0.22711199894547462,0.22703699891765913,0.22696100051204363,0.22688499838113785,0.22680999835332236,0.22673399870594343,0.22665899867812792,0.22658300027251244,0.22650800148646036,0.22643199811379114,0.22635700181126595,0.22628100092212358,0.22620599965254465,0.22613000000516573,0.22605500121911368,0.2259799987077713,0.22590400030215582,0.2258289990325769,0.22575399776299795,0.22567900146047273,0.2256030005713304,0.22552799930175146,0.2254530005156994,0.2253780004878839,0.22530299921830496,0.22522800043225288,0.2251530004044374,0.22507799913485846,0.22500300034880638,0.2249280003209909,0.22485300029317537,0.22477800026535988,0.2247030002375444,0.22462799896796545,0.22455300142367682,0.22447800015409788,0.2244029976427555,0.22432900220155716,0.22425399969021478,0.2241789996623993,0.22410400087634721,0.2240299992263317,0.22395499919851622,0.22388000041246414,0.2238060012459755,0.22373099873463312,0.22365699956814447,0.22358200078209242,0.22350800037384033,0.22343300034602484,0.2233589986960093,0.22328399990995726,0.22320999950170517,0.2231350007156531,0.22306100030740103,0.22298700114091238,0.22291199987133345,0.22283799822131792,0.22276400153835615,0.22268900026877722,0.22261500110228857,0.22254099821050963,0.22246700152754784,0.22239300111929575,0.22231899946928024,0.2222450003027916,0.22216999779144922,0.22209600110848746,0.22202199945847192,0.22194800153374672,0.22187399864196777,0.22180000071724257,0.22172699868679047,0.22165300076206526,0.2215790015955766,0.22150499870379767,0.22143099829554558,0.22135700037082037,0.22128399834036827,0.22121000165740648,0.22113600124915442,0.22106200084090233,0.22098900005221367,0.22091499964396158,0.22084100171923637,0.22076799968878427,0.22069400052229562,0.2206570009390513};
        CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.83428891499837,82.68911616007487,83.12951151529948,83.83631134033203,84.52521133422852,85.19641176859538,85.8498109181722,86.48521105448405,87.10231018066406,87.701109568278,88.28161112467448,88.84380849202473,89.38770993550618,89.9132080078125,90.42050870259602,90.90950838724773,91.38020833333333,91.84090677897136,92.30010795593262,92.75770696004231,93.21360842386882,93.6680081685384,94.12080764770508,94.57200813293457,95.02160771687825,95.46960703531902,95.91600672403972,96.3609078725179,96.80410703023274,97.24580764770508,97.68580691019694,98.12430763244629,98.56120681762695,98.99640782674153,99.43010838826497,99.86220741271973,100.2930081685384,100.72100766499837,101.1480058034261,101.57200813293457,101.99400774637859,102.41300710042317,102.8310063680013,103.2460085550944,103.6590067545573,104.06900787353516,104.47800763448079,104.88400650024414,105.28900655110677,105.69300651550293,106.09500503540039,106.49500719706218,106.89400672912598,107.29200744628906,107.68800608317058,108.08300654093425,108.47600682576497,108.86800638834636,109.25900650024414,109.6500072479248,110.04000663757324,110.43000729878743,110.8190066019694,111.20700772603352,111.59500630696614,111.98300679524739,112.37000528971355,112.75600687662761,113.14300600687663,113.52900632222493,113.91600735982259,114.30300712585449,114.6900068918864,115.07600657145183,115.46300633748372,115.85000673929851,116.2370065053304,116.6240062713623,117.01200739542644,117.40100733439128,117.79000790913899,118.18000729878743,118.57100741068523,118.9630069732666,119.35500653584798,119.74800682067871,120.14200592041016,120.53500747680664,120.9250062306722,121.3120059967041,121.69700558980306,122.07900746663411,122.45900535583496,122.83600680033366,123.21000544230144,123.5810063680013,123.95000584920247,124.31700579325359,124.68000666300456,125.04100608825684,125.39900652567546,125.7550048828125,126.10800615946452,126.45800526936848,126.80600547790527,127.15100542704265,127.49400520324707,127.83300526936848,128.1710065205892,128.50500615437826,128.83700561523438,129.16600290934244,129.49200312296549,129.81600697835287,130.13800430297852,130.45600763956705,130.7720044453939,131.08500544230142,131.3960049947103,131.70400746663412,132.00900395711264,132.3120028177897,132.61200714111328,132.90900548299155,133.20400365193686,133.49600728352866,133.78500493367514,134.07200495402017,134.35600662231445,134.63800430297852,134.91700490315756,135.1930046081543,135.46600468953451,135.73700332641602,136.0050048828125,136.2710049947103,136.53400548299155,136.79400507609049,137.0520044962565,137.307004292806,137.55900446573892,137.8090031941732,138.05600611368814,138.3000030517578,138.54200490315756,138.7810033162435,139.01800409952799,139.25100326538086,139.48200225830078,139.71100616455078,139.93700536092123,140.16000366210938,140.3810043334961,140.59900410970053,140.81400426228842,141.026003519694,141.23600133260092,141.44400278727213,141.64800516764322,141.85000356038412,142.05000432332358,142.2460034688314,142.4410031636556,142.63200505574545,142.82100423177084,143.0070037841797,143.19000371297201,143.3710034688314,143.54900232950845,143.72500228881836,143.89800516764322,144.0680046081543,144.23600387573242,144.40100479125977,144.56300354003906,144.72300338745117,144.8800048828125,145.03400293986002,145.18600209554037,145.33500289916992,145.48100153605142,145.6250025431315,145.7660026550293,145.90500259399414,146.0410016377767,146.17400232950845,146.30500284830728,146.43200174967447,146.55800247192383,146.68000030517578,146.80000178019205,146.9180005391439,147.0320027669271,147.14400227864584,147.2540028889974,147.36100387573242,147.46500142415366,147.56600189208984,147.66499964396158,147.76100158691406,147.8550008138021,147.94600041707358,148.03400166829428,148.1190045674642,148.20199839274088,148.2830022176107,148.36000315348306,148.43500137329102,148.50800196329752,148.57699966430664,148.64400100708008,148.70900217692056,148.77100118001303,148.8300018310547,148.8860003153483,148.93999862670898,148.9910011291504,149.04000091552734,149.08600234985352,149.12900161743164,149.1700007120768,149.2079989115397,149.24300257364908,149.27600224812826,149.30600102742514,149.3329989115397,149.3580004374186,149.38000106811523,149.3999989827474,149.41599909464517,149.43099975585938,149.44200007120767,149.45100021362305,149.4569994608561,149.46100107828775,149.46200052897134,149.45999908447266,149.4569994608561,149.45400110880533,149.45100021362305,149.44799931844076,149.44499969482422,149.44200007120767,149.4389991760254,149.4360008239746,149.43299992879233,149.43000030517578,149.42700068155924,149.42399978637695,149.4210001627604,149.41799926757812,149.41499964396158,149.4119987487793,149.40899912516275,149.40599950154623,149.40399932861328,149.400998433431,149.39799880981445,149.39500045776367,149.39199701944986,149.38900248209634,149.3860003153483,149.38299942016602,149.38000106811523,149.3769989013672,149.3740005493164,149.37099965413412,149.36800003051758,149.36500040690103,149.36199951171875,149.3589998881022,149.3560002644857,149.35299936930338,149.34999974568686,149.3470001220703,149.34399922688803,149.34100087483725,149.33799997965494,149.33500035603842,149.33200073242188,149.3289998372396,149.32600021362305,149.32299931844076,149.31999969482422,149.31700007120767,149.3139991760254,149.3110008239746,149.30799992879233,149.30500030517578,149.30200068155924,149.29899978637695,149.2960001627604,149.29299926757812,149.28999964396158,149.28700002034506,149.28399912516275,149.28100077311197,149.2779998779297,149.27500025431314,149.27200063069662,149.2689997355143,149.2660001118978,149.26300048828125,149.25999959309897,149.25699996948242,149.25399907430014,149.2509994506836,149.2480010986328,149.24500020345053,149.24200057983398,149.2389996846517,149.23600006103516,149.2330004374186,149.22999954223633,149.22699991861978,149.2239990234375,149.22100067138672,149.21799977620444,149.21499888102213,149.21200052897134,149.20899963378906,149.20600001017252,149.20299911499023,149.20000076293945,149.1969985961914,149.19499715169272,149.19199879964194,149.18900044759116,149.18599955240884,149.18299992879233,149.17999903361002,149.17700068155924,149.17399978637695,149.1710001627604,149.16799926757812,149.16499964396158,149.16200002034506,149.15899912516275,149.15600077311197,149.1529998779297,149.15000025431314,149.14700063069662,149.1439997355143,149.1410001118978,149.13800048828125,149.13499959309897,149.13199996948242,149.12899907430014,149.1259994506836,149.1230010986328,149.12000020345053,149.11700057983398,149.1139996846517,149.11100006103516,149.1080004374186,149.10499954223633,149.10199991861978,149.0989990234375,149.09599939982095,149.09300104777017,149.0900001525879,149.08700052897134,149.08399963378906,149.08100001017252,149.078000386556,149.0749994913737,149.07199986775717,149.06900024414062,149.06599934895834,149.0629997253418,149.06000010172525,149.05700047810873,149.0540008544922,149.0509999593099,149.04800033569336,149.04499944051108,149.04199981689453,149.03900019327799,149.03600056966147,149.03299967447916,149.03000132242838,149.02700169881186,149.0250015258789,149.02200063069662,149.0189997355143,149.0160001118978,149.01300048828125,149.00999959309897,149.00699996948242,149.00399907430014,149.0009994506836,148.9980010986328,148.99500020345053,148.99200057983398,148.9889996846517,148.98600006103516,148.9830004374186,148.97999954223633,148.97699991861978,148.9739990234375,148.97099939982095,148.96800104777017,148.9650001525879,148.96200052897134,148.95899963378906,148.95600001017252,148.953000386556,148.9499994913737,148.94699986775717,148.94400024414062,148.94099934895834,148.9379997253418,148.93500010172525,148.93200047810873,148.9290008544922,148.9259999593099,148.92300033569336,148.91999944051108,148.91699981689453,148.91400019327799,148.9109992980957,148.90799967447916,148.90500005086264,148.9020004272461,148.89900080362955,148.89599990844727,148.89300028483072,148.88999938964844,148.8869997660319,148.8840014139811,148.8820012410482,148.87899780273438,148.87599817911783,148.87299982706705,148.87000020345053,148.86700057983398,148.8639996846517,148.86100006103516,148.8580004374186,148.85499954223633,148.85199991861978,148.8489990234375,148.84599939982095,148.84300104777017,148.8400001525879,148.83700052897134,148.83399963378906,148.83100001017252,148.828000386556,148.8249994913737,148.82199986775717,148.81900024414062,148.81599934895834,148.8129997253418,148.81000010172525,148.80700047810873,148.8040008544922,148.8009999593099,148.79800033569336,148.79499944051108,148.79199981689453,148.78900019327799,148.7859992980957,148.78299967447916,148.78000005086264,148.7770004272461,148.77400080362955,148.77099990844727,148.76799901326498,148.76499938964844,148.76199849446616,148.75900268554688,148.75699996948242,148.75399907430014,148.7509994506836,148.7480010986328,148.74500020345053,148.74199676513672,148.73900095621744,148.73600006103516,148.7329978942871,148.7300008138021,148.72699864705405,148.724001566569,148.72100067138672,148.71900049845377};
        //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3766834537188213,1.413340002298355,1.4500099817911785,1.4858900010585785,1.5208399891853333,1.5548800031344097,1.5879899958769481,1.6201700170834858,1.6514000197251637,1.6816899975140889,1.7110299964745839,1.7394199868043263,1.7668599983056386,1.7933600147565205,1.8189000189304352,1.843510001897812,1.867160012324651,1.8902999957402546,1.9133500059445698,1.9363100032011669,1.9591899911562602,1.9819799959659576,2.004670004049937,2.0272799928983054,2.0498000184694924,2.0722399751345315,2.0945799946784973,2.1168400247891745,2.139020005861918,2.1610999703407288,2.1830899715423584,2.2050000031789145,2.2268099983533225,2.248540004094442,2.2701800068219504,2.2917300264040628,2.313199977080027,2.3345600366592407,2.355799992879232,2.3769100308418274,2.3979100386301675,2.4187899629275003,2.4395399689674377,2.460170030593872,2.4806900024414062,2.5010799964269004,2.521350006262461,2.5415199995040894,2.561610003312429,2.5816100041071572,2.601520001888275,2.6213599840799966,2.6411100228627524,2.6607800126075745,2.6803699731826782,2.699880003929138,2.7192999720573425,2.7386699517567954,2.7579999764760337,2.777300000190735,2.796559989452362,2.815779983997345,2.834970017274221,2.8541300296783447,2.8732500076293945,2.8923400044441223,2.911390026410421,2.93042000134786,2.9494499961535134,2.9684699972470603,2.9874899983406067,3.006499985853831,3.0255199869473777,3.0445200403531394,3.0635300079981485,3.0825300017992654,3.101520001888275,3.1205400029818215,3.139579991499583,3.158650000890096,3.177749991416931,3.1968899766604104,3.216059982776642,3.23526002963384,3.25449001789093,3.2737499674161277,3.2930400371551514,3.312279979387919,3.3313699762026467,3.3503200014432273,3.369129995505015,3.3877999782562256,3.4063299695650735,3.424720029036204,3.442970037460327,3.4610699812571206,3.479040006796519,3.4968600273132324,3.5145500103632608,3.5320899883906045,3.5494900147120156,3.5667500098546348,3.5838700334231057,3.600839992364248,3.617670019467672,3.6343599756558738,3.6509100000063577,3.6673200130462646,3.683589975039164,3.699720005194346,3.7157000501950583,3.7315500179926553,3.747260014216105,3.7628300189971924,3.778249979019165,3.793540040651957,3.8086900313695273,3.823700030644735,3.8385600248972573,3.853290021419525,3.8678799668947854,3.8823300202687583,3.8966399828592935,3.9108000000317893,3.9248299996058145,3.9387200077374778,3.9524700045585632,3.9660800298055015,3.979550004005432,3.99288002649943,4.006070057551066,4.01911997795105,4.032029946645101,4.044789950052897,4.057420015335083,4.069899996121724,4.082249919573466,4.094460050264995,4.106530070304871,4.118459939956665,4.1302500168482466,4.141899983088176,4.153409997622172,4.164789994557698,4.1760200659434,4.187120000521342,4.198080102602641,4.2089000542958575,4.219580014546712,4.230119983355205,4.2405299345652265,4.250790119171143,4.26092000802358,4.270910024642944,4.280760010083516,4.290469964345296,4.300040046374003,4.309470057487488,4.318769931793213,4.327930013338725,4.336950023969014,4.345830043156941,4.354570031166077,4.363170027732849,4.371630032857259,4.3799500068028765,4.388140002886455,4.3961799542109175,4.404090007146199,4.41185994942983,4.41950003306071,4.426989992459615,4.43435005346934,4.441569964090983,4.448650002479553,4.455599983533223,4.462409973144531,4.469080011049907,4.475609978040059,4.482010006904602,4.488270044326782,4.49439005057017,4.500369946161906,4.506219983100891,4.511929988861084,4.517499923706055,4.522940079371135,4.528240005175273,4.5333999792734785,4.538420041402181,4.543310085932414,4.548059980074565,4.552680055300395,4.557140032450358,4.561480005582173,4.565670013427734,4.569730043411255,4.5736600160598755,4.577439983685811,4.581099987030029,4.584609945615132,4.587990045547485,4.591229955355327,4.594329992930095,4.597300012906392,4.60014005502065,4.602830012639363,4.6053900718688965,4.6078199942906695,4.610100030899048,4.6122599840164185,4.614269971847534,4.61615006128947,4.617900013923645,4.6195099751154585,4.6209800243377686,4.622320016225179,4.623519976933797,4.6245899597803755,4.6255199909210205,4.626309951146443,4.626969973246257,4.627479990323384,4.627860029538472,4.62811001141866,4.628220001856486,4.6281899611155195,4.628030021985372,4.627729972203572,4.627300024032593,4.626739978790283,4.626030007998149,4.625199913978577,4.624229987462361,4.623119950294495,4.621880054473877,4.620500008265178,4.619060039520264,4.617610017458598,4.616169969240825,4.614730000495911,4.613289952278137,4.611850023269653,4.610399961471558,4.608960032463074,4.60751994450887,4.606080055236816,4.604649980862935,4.603210012118022,4.6017699639002485,4.600330034891765,4.59889002641042,4.597459991772969,4.596019943555196,4.594580014546712,4.593150019645691,4.5917099714279175,4.590279936790466,4.588840007781982,4.587410012880961,4.5859800179799395,4.584540009498596,4.583109895388286,4.581679979960124,4.580250024795532,4.578819990158081,4.57738999525706,4.575960079828898,4.574529965718587,4.573100010553996,4.571669975916545,4.570240020751953,4.568809946378072,4.56738003094991,4.565959970156352,4.56453005472819,4.563100020090739,4.56167995929718,4.560249964396159,4.55883002281189,4.557399948438008,4.55598000685374,4.55456002553304,4.55312995115916,4.55171000957489,4.550289988517761,4.548869967460632,4.547449946403503,4.546020030975342,4.544600009918213,4.543180068333943,4.5417600472768145,4.540349960327148,4.53892997900645,4.53751003742218,4.536090016365051,4.5346700350443525,4.533260027567546,4.531840006510417,4.530419985453288,4.529009977976481,4.527590036392212,4.526179949442546,4.524770021438599,4.52334996064504,4.521939992904663,4.520530025164287,4.519110004107158,4.517699956893921,4.516289989153544,4.514879981676738,4.51347001393636,4.5120599667231245,4.510649998982747,4.5092399915059405,4.507830023765564,4.506419936815898,4.505010048548381,4.503600001335144,4.50220004717509,4.500790039698283,4.499379952748616,4.497979998588562,4.496569991111755,4.495169997215271,4.493759989738464,4.49236003557841,4.490960041681926,4.4895501136779785,4.488150000572205,4.48675004641215,4.485350052515666,4.483940005302429,4.482539971669515,4.4811400175094604,4.479739983876546,4.4783399899800616,4.476939996083577,4.475550015767415,4.474149982134501,4.472749948501587,4.471350034077962,4.469950000445048,4.468559900919597,4.467160026232402,4.46577000617981,4.464370052019755,4.462980031967163,4.461579958597819,4.4601900180180865,4.458789984385173,4.457400004069011,4.456010023752849,4.454620003700256,4.453220049540202,4.45183006922404,4.450440049171448,4.4490500291188555,4.447660009066264,4.446270028750102,4.44487996896108,4.443490028381348,4.442100008328755,4.440720001856486,4.439330021540324,4.437939961751302,4.436560034751892,4.43516993522644,4.4337799946467085,4.432400027910869,4.4310100475947065,4.429630080858867,4.428239981333415,4.426859974861145,4.425479968388875,4.424089988072713,4.422710061073303,4.421330014864604,4.419950048128764,4.418570001920064,4.417189836502075,4.415809988975525,4.414429982503255,4.413049976030986,4.411670009295146,4.410289963086446,4.408909916877747,4.407540003458659,4.406160076459249,4.404779990514119,4.403409997622172,4.402029991149902,4.4006500244140625,4.399280031522115,4.397900025049846,4.396529992421468,4.395159920056661,4.393779993057251,4.392409960428874,4.391040007273356,4.389670054117839,4.388289968172709,4.386920015017192,4.385550022125244,4.384179989496867,4.38281003634135,4.381440043449402,4.380070010821025,4.378709991772969,4.377340038617452,4.375970045725505,4.374600013097127,4.373239954312642,4.371870040893555,4.370499968528748,4.369139989217122,4.367769956588745,4.36641001701355,4.365039944648743,4.363680005073547,4.362320025761922,4.360950072606404,4.35958997408549,4.358230074246724,4.356870055198669,4.355510075887044,4.354140082995097,4.352779944737752,4.351420044898987,4.350059946378072,4.348710020383199,4.347350001335144,4.345989982287089,4.344630042711894,4.343269983927409,4.341920018196106,4.3405600388844805,4.339200019836426,4.337850054105123,4.336489995320638,4.335139989852905,4.33378001054128,4.332430005073547,4.331069986025493,4.32971994082133,4.328370014826457,4.327019969622294,4.325659990310669,4.324309945106506,4.322959939638774,4.321610013643901,4.320260047912598,4.318909962972005,4.3175599575042725,4.316210031509399,4.314860026041667,4.313519994417827,4.312170028686523,4.310819983482361,4.309470057487488,4.308129986127217,4.306780020395915,4.305429975191752,4.304089983304341,4.302740017573039,4.301399985949199,4.300060033798218,4.298710028330485,4.297369996706645,4.296030004819234,4.294679959615071,4.293340007464091,4.2920000950495405,4.29066002368927,4.28932003180186,4.287979920705159,4.286640048027039,4.285299976666768,4.283959984779358,4.282619992891948,4.281280040740967,4.279949982961019,4.278609991073608,4.277269919713338,4.275940020879109,4.275270024935405};
        SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568467537562052,8.884455839792887,9.180607000986734,9.503506422042847,9.825696388880411,10.147206544876099,10.46790631612142,10.784506241480509,11.09350593884786,11.394805749257406,11.68850572903951,11.974505503972372,12.252905368804932,12.523705323537191,12.786805152893066,13.042304913202921,13.290204922358194,13.535104910532633,13.781704902648926,14.029905001322428,14.279805024464926,14.531405051549276,14.78470516204834,15.039605299631754,15.296105146408081,15.554405132929483,15.814205328623453,16.076105038324993,16.34030564626058,16.606805483500164,16.875505447387695,17.146605491638184,17.41990566253662,17.695605436960857,17.973505814870197,18.25380579630534,18.536305745442707,18.820705890655518,19.106606006622314,19.393905639648438,19.68260622024536,19.972805976867676,20.264405727386475,20.557406266530354,20.851905981699627,21.14780616760254,21.44520616531372,21.74410597483317,22.044706026713055,22.346906185150146,22.650806268056233,22.956406434377033,23.26370636622111,23.572606404622395,23.883206685384113,24.195506413777668,24.509406248728435,24.82500648498535,25.142306645711262,25.46130673090617,25.781906445821125,26.10430637995402,26.42820692062378,26.75390640894572,27.08130677541097,27.410306930541992,27.74100653330485,28.073206742604572,28.406906763712566,28.741806825002033,29.07820685704549,29.416006724039715,29.755107084910076,30.095606962839764,30.437506993611652,30.78080685933431,31.125407059987385,31.471607208251953,31.819506804148357,32.16910648345947,32.520407358805336,32.87340704600016,33.22810713450114,33.58450730641683,33.94250742594401,34.30230712890625,34.663807233174644,35.02480697631836,35.38320700327555,35.739006996154785,36.09230772654215,36.44290701548258,36.79090722401937,37.13630739847819,37.479207038879395,37.81940746307373,38.15710703531901,38.492106119791664,38.8246062596639,39.15450668334961,39.48170693715414,39.806406021118164,40.128506342569985,40.44800694783529,40.76500574747721,41.07930596669515,41.391106287638344,41.7002067565918,42.00680637359619,42.31080627441406,42.61220614115397,42.9111057917277,43.207305908203125,43.50100517272949,43.79210599263509,44.08070627848307,44.36660607655843,44.65000534057617,44.93080552419027,45.2090056737264,45.48460578918457,45.75770568847656,46.02820555369059,46.29610506693522,46.56150499979655,46.82420508066813,47.08450508117676,47.3421049118042,47.59720516204834,47.84970474243164,48.09960524241129,48.347004890441895,48.59180514017741,48.83410517374674,49.07380485534668,49.31090513865153,49.545504570007324,49.77750460306803,50.00690460205078,50.23380470275879,50.4581044514974,50.679903984069824,50.89910475413004,51.11580435434977,51.329904556274414,51.54140377044678,51.750404040018715,51.95690409342448,52.160804430643715,52.362104415893555,52.560903549194336,52.75710391998291,52.95080439249674,53.14200369517008,53.33060359954834,53.51660346984863,53.700103759765625,53.88110319773356,54.05950355529785,54.23540369669596,54.40870316823324,54.57950369517008,54.747703552246094,54.91350301106771,55.07660357157389,55.237304051717125,55.395402908325195,55.55090300242106,55.703902880350746,55.8544028600057,56.002403259277344,56.14780298868815,56.29070281982422,56.431002616882324,56.568902333577476,56.70410283406576,56.83690230051676,56.967102686564125,57.094902674357094,57.22000281016032,57.342702547709145,57.462801933288574,57.58040269215902,57.695501963297524,57.808101971944176,57.918101946512856,58.02560170491537,58.13060220082601,58.2331018447876,58.3330020904541,58.43040180206299,58.52540143330892,58.61780198415121,58.70760154724121,58.79500261942545,58.87990093231201,58.96220270792643,59.04200077056885,59.11930179595947,59.19410101572672,59.266401290893555,59.336201667785645,59.403501192728676,59.46820259094238,59.530500729878746,59.59020137786865,59.64750099182129,59.70220057169596,59.754501024881996,59.80420080820719,59.851401011149086,59.89610036214193,59.93840058644613,59.97810077667236,60.01530075073242,60.05000082651774,60.08230050404867,60.112000465393066,60.13920052846273,60.164000511169434,60.18620045979818,60.206000645955406,60.22319984436035,60.23799991607666,60.250200271606445,60.260000228881836,60.26729996999105,60.27209981282552,60.274399757385254,60.274200439453125,60.271599451700844,60.26640033721924,60.25879923502604,60.24869950612386,60.236099561055504,60.22099908192953,60.20339902242025,60.18459955851237,60.16580009460449,60.146999994913735,60.12819957733154,60.10939979553223,60.09059969584147,60.07179927825928,60.053099632263184,60.03430016835531,60.01559925079346,59.99679978688558,59.978099505106606,59.95929972330729,59.94059944152832,59.921799977620445,59.90310001373291,59.88439909617106,59.865699768066406,59.84700012207031,59.82830015818278,59.80959924062093,59.79089959462484,59.77219899495443,59.753600120544434,59.734899838765465,59.71619955698649,59.69760004679362,59.67889976501465,59.6602996190389,59.64159965515137,59.622999827067055,59.60439936319987,59.585699717203774,59.56709988911947,59.548499743143715,59.52989991505941,59.51129945119222,59.49269994099935,59.474099477132164,59.45549933115641,59.436999003092446,59.418399492899574,59.39979934692383,59.381299336751304,59.36269919077555,59.344200134277344,59.325599670410156,59.30709934234619,59.28859933217367,59.269999504089355,59.251499811808266,59.23300011952718,59.214499155680336,59.19599914550781,59.17749945322672,59.159000078837074,59.14050006866455,59.121999740600586,59.103599548339844,59.08509953816732,59.066599210103355,59.04819965362549,59.0296999613444,59.0113000869751,58.99279975891113,58.974400202433266,58.95599937438965,58.937599182128906,58.919199307759605,58.900699615478516,58.88230005900065,58.86389986673991,58.84559981028239,58.827199618021645,58.80880037943522,58.7903995513916,58.7719996770223,58.753699938456215,58.735300064086914,58.71699937184652,58.69859949747721,58.68029975891113,58.66189956665039,58.64359982808431,58.62530008951823,58.60699971516927,58.58869934082031,58.57039928436279,58.55209986368815,58.533799489339195,58.51549975077311,58.49719969431559,58.47889963785807,58.46059926350912,58.44239934285482,58.424099922180176,58.40589904785156,58.38759962717692,58.36939938863119,58.35109996795654,58.33289909362793,58.31469980875651,58.29649957021078,58.27819951375326,58.25999959309896,58.24179935455322,58.223599116007485,58.20539919535319,58.18719959259033,58.16909980773926,58.15089956919352,58.132699966430664,58.11459986368815,58.09639930725098,58.078200022379555,58.060099601745605,58.04199981689453,58.023799896240234,58.00570011138916,57.98759969075521,57.96949990590414,57.951300303141274,57.93319924672445,57.91510009765625,57.8969996770223,57.878899574279785,57.86089960734049,57.84279982248942,57.82469971974691,57.80659929911295,57.78859933217367,57.77049859364828,57.7524995803833,57.73439979553223,57.716399828592934,57.69839954376221,57.68029975891113,57.66229979197184,57.644299825032554,57.62629954020182,57.608299573262535,57.59029897054037,57.572299321492515,57.55429903666178,57.536299069722496,57.518299420674644,57.50040022532145,57.48239962259928,57.464399337768555,57.446499824523926,57.42849890391032,57.41059970855713,57.392599741617836,57.37469927469889,57.35679976145426,57.33889961242676,57.32099978129069,57.30299949645996,57.28509966532389,57.26719983418783,57.24930000305176,57.231499989827476,57.21359952290853,57.19569969177246,57.177799224853516,57.160000483194985,57.14210033416748,57.12429936726888,57.10639921824137,57.08859952290853,57.07069969177246,57.0528990427653,57.03509966532389,57.01719951629639,56.999399503072105,56.98159980773926,56.963799476623535,56.94599914550781,56.92819913228353,56.910399754842125,56.892699241638184,56.87490018208822,56.857099533081055,56.83929920196533,56.82159964243571,56.803799629211426,56.786099433898926,56.76830005645752,56.75059986114502,56.73289998372396,56.7150993347168,56.69739977518717,56.67969957987467,56.662000020345054,56.644299825032554,56.62659994761149,56.608899434407554,56.59120019276937,56.57349999745687,56.55589962005615,56.53819942474365,56.52049954732259,56.502899487813316,56.485198974609375,56.467599868774414,56.449899991353355,56.43229993184408,56.41459973653158,56.3969996770223,56.37939993540446,56.36179987589518,56.34419949849447,56.326599756876625,56.30900001525879,56.29139963785807,56.273799896240234,56.2562001546224,56.23859977722168,56.2209997177124,56.20349947611491,56.18589973449707,56.168399492899574,56.15080038706461,56.133299827575684,56.115699450174965,56.098199208577476,56.080699602762856,56.06309986114502,56.045599619547524,56.02809969584147,56.010600090026855,55.993099530537926,55.975600242614746,55.958099683125816,55.94059975941976,55.92319997151693,55.905699729919434,55.888199170430504,55.87079938252767,55.85329945882162,55.835899670918785,55.81839942932129,55.80099964141846,55.78349939982096,55.766099294026695,55.74870014190674,55.731300036112465,55.71380011240641,55.70510005950928};
        //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129413823286692,2.2199289798736572,2.2950963973999023,2.37214587132136,2.4435757398605347,2.509555538495382,2.570225397745768,2.625685234864553,2.676045080025991,2.7214349706967673,2.76199479897817,2.7978446086247764,2.8291044433911643,2.855914314587911,2.8783841331799827,2.8966440161069236,2.910793960094452,2.922603964805603,2.933793922265371,2.944393972555796,2.954403897126516,2.9638638893763223,2.972773869832357,2.9811538656552634,2.9890238841374717,2.996393839518229,3.003273844718933,3.0096838672955832,3.015633781750997,3.0211438139279685,3.026213745276133,3.0308637420336404,3.03511377175649,3.038953721523285,3.042403737703959,3.045483708381653,3.0481936931610107,3.0504736502965293,3.0522636771202087,3.053593655427297,3.0544536113739014,3.054863611857096,3.0548436045646667,3.054393549760183,3.0535335342089334,3.0522635181744895,3.050613502661387,3.048653483390808,3.0464635094006858,3.04406346877416,3.041433413823446,3.038603444894155,3.035573442776998,3.032333413759867,3.028913418451945,3.025303383668264,3.021513362725576,3.017633378505707,3.013753374417623,3.009873370329539,3.0060033798217773,3.002133369445801,2.998263339201609,2.99440336227417,2.9905433654785156,2.9866833090782166,2.9828133583068848,2.9790133436520896,2.9753233393033347,2.97174334526062,2.9682633678118386,2.964893360932668,2.9616132974624634,2.9584333300590515,2.955353319644928,2.952353358268738,2.9494433403015137,2.9466933210690818,2.9441633820533752,2.9418433705965676,2.939733386039734,2.9378233551979065,2.9361133774121604,2.9345834056536355,2.933253447214762,2.932103435198466,2.9311333894729614,2.9299933314323425,2.928363343079885,2.926253338654836,2.9236733317375183,2.9206532637278237,2.917183260122935,2.9132832090059915,2.908963203430176,2.904243210951487,2.8991331259409585,2.8936331470807395,2.8877631028493247,2.8815330862998962,2.8749430576960244,2.8680130441983542,2.8607529997825623,2.853163003921509,2.8452630043029785,2.837042967478434,2.8285329143206277,2.819732884565989,2.8106528520584106,2.801292876402537,2.791662812232971,2.7817728519439697,2.771632810433706,2.7612427870432534,2.7506127754847207,2.73975270986557,2.7286627491315207,2.7173527081807456,2.7058326601982117,2.694092631340027,2.682162602742513,2.6700225869814553,2.657692571481069,2.6451825499534607,2.6324825088183084,2.6196125149726868,2.6065724889437356,2.593352456887563,2.5799824396769204,2.566442390282949,2.552752415339152,2.538912375768026,2.5249223510424295,2.510792354742686,2.49652228752772,2.482112248738607,2.4675722320874534,2.452912231286367,2.4381222128868103,2.4232021967569985,2.408172150452932,2.393022139867147,2.3777620991071067,2.362392087777456,2.3469120462735495,2.331332047780355,2.31564199924469,2.2998619874318442,2.283981998761495,2.268001933892568,2.251941959063212,2.2357919017473855,2.219551920890808,2.203221837679545,2.1868218382199607,2.1703317761421204,2.1537618041038513,2.137121776739756,2.120401759942373,2.103611687819163,2.0867516795794168,2.0698216954867044,2.0528316497802734,2.035771628220876,2.0186415712038674,2.0014516015847525,1.9842115739981334,1.966901530822118,1.9495415091514587,1.9321215053399403,1.9146414697170258,1.8971214493115742,1.879541426897049,1.861911416053772,1.844231386979421,1.8265113532543182,1.8087413410345714,1.7909213105837505,1.7730612953503926,1.7551612854003906,1.737221250931422,1.7192312280337017,1.7012112140655518,1.683141181866328,1.6650511622428894,1.6469111442565918,1.6287411153316498,1.6105310916900635,1.5923010607560475,1.5740210513273876,1.5557210346062977,1.5373909870783489,1.5190309683481853,1.5006409486134846,1.4822209179401398,1.46378089984258,1.4453108708063762,1.4268108705679576,1.408290833234787,1.3897408147652943,1.3711808025836945,1.3525907794634502,1.3339807490507762,1.3153507212797801,1.2966907024383545,1.278020699818929,1.2593306700388591,1.240620642900467,1.2218906184037526,1.2031405965487163,1.18438055117925,1.1656005481878917,1.1468005180358887,1.1279905140399933,1.1091604828834534,1.0903204381465912,1.0714704195658367,1.052590399980545,1.033710390329361,1.0148203670978546,0.9959073414405187,0.9769883255163828,0.9580553025007248,0.9391112625598907,0.9201572487751642,0.9011952380339304,0.8822222004334132,0.863237182299296,0.8442451606194178,0.8252431402603785,0.8062311162551244,0.7872120887041092,0.7681830624739329,0.749146044254303,0.7301030158996582,0.7110509971777598,0.691991001367569,0.6731869975725809,0.6548929959535599,0.6370949993530909,0.6197799940903982,0.6029340028762817,0.5865459938844045,0.5706019997596741,0.5550910085439682,0.5400009999672571,0.5253210018078486,0.5110399971405665,0.49714600543181103,0.4836300015449524,0.4704810008406639,0.4576900005340576,0.4452450027068456,0.43313900132973987,0.4213619977235794,0.4099049965540568,0.39875900248686474,0.3879159986972809,0.3773679981629054,0.3671069989601771,0.3571239983042081,0.3474129984776179,0.3379660000403722,0.3287759969631831,0.31983500222365063,0.3111379990975062,0.3026770055294037,0.29444599399964017,0.2864389990766843,0.278649998207887,0.27107200026512146,0.26370100180308026,0.2565300017595291,0.24955400079488754,0.24276799956957498,0.2361659991244475,0.2297430026034514,0.22349599873026213,0.2174180013438066,0.21150600165128708,0.20575400069355965,0.20015900085369745,0.19471599782506624,0.1894209993382295,0.18426999946435293,0.17925899972518286,0.17438399915893874,0.16964200139045715,0.16502900049090385,0.160541000465552,0.15617499748865762,0.1519279989103476,0.1477969984213511,0.14377799878517786,0.1398679999013742,0.13606500004728636,0.1323650007446607,0.12876500189304352,0.1252639995266994,0.1218569998939832,0.11854400051136811,0.11532000017662843,0.11218399927020073,0.1091339997947216,0.10616600016752879,0.10327899952729543,0.10047099987665813,0.0977388999114434,0.0950811995814244,0.09249580030639966,0.08998059978087743,0.08753390051424503,0.08515370016296704,0.08283819941182931,0.08058570077021916,0.07839440119763215,0.07626280002295971,0.07418909917275111,0.07217180045942466,0.0702094001074632,0.06830029996732871,0.06644309995075066,0.06463649931053321,0.06287890020757914,0.06116919995596012,0.05950600001960993,0.05788799996177355,0.05631389996657769,0.05478270041445891,0.053293200209736824,0.051844099846978985,0.050434499979019165,0.049063099237779774,0.04772910010069609,0.04643129991988341,0.045168899931013584,0.043940700590610504,0.042745999371012054,0.041583700415988765,0.04045309964567423,0.03935319992403189,0.03828320031364759,0.03724230049798886,0.0362296998500824,0.03524460022648176,0.03428639999280373,0.033354100150366627,0.03244729960958163,0.03156509964416424,0.030706799899538357,0.029871900100260973,0.02905980000893275,0.028269699774682522,0.027501100208610296,0.02675330002481739,0.026026000268757343,0.025318299885839224,0.02462999988347292,0.02396029994512598,0.02330890002970894,0.022675199899822474,0.022058700521787006,0.021458899912734825,0.020875500204662483,0.020307999880363543,0.019755800099422533,0.019218700006604195,0.018696199947347242,0.018187899918605883,0.017693399917334318,0.017212399902443092,0.016744400064150494,0.01628920001288255,0.015846300094077986,0.015415499995773038,0.01499640002536277,0.014588700219367942,0.014192100071037808,0.013806200042987863,0.013430900095651547,0.013065699953585863,0.012710499887665113,0.012365000089630485,0.012028799935554465,0.011701800084362427,0.011383699951693416,0.01107419996211926,0.010773099958896637,0.010480199940502644,0.010195300060634812,0.009918140014633536,0.00964849985515078,0.009386199992150068,0.009131019935011864,0.008882790027807156,0.008641299946854511,0.008406380036224922,0.008177850085000197,0.00795552988226215,0.007739259861409664,0.007528860044355194,0.007324180022502939,0.007125070008138816,0.006931380019523203,0.006742949946783483,0.006559640013923247,0.006381309979284803,0.006207840051501989,0.006039079977199435,0.005874910003816088,0.005715200134242575,0.005559829995036125,0.005408690039378901,0.005261659971438348,0.005118619999848306,0.004979470046237111,0.004844109954622884,0.004712429945357144,0.004584319967155655,0.0044597000038872165,0.004338469938375056,0.004220529963883261,0.004105799947865307,0.003994190017692745,0.003885609970893711,0.0037799800047650933,0.0036772299596729376,0.0035772699823913476,0.0034800200179840126,0.0033854199767423174,0.0032934000288757184,0.003203870030120015,0.003116779999497036,0.003032050017888347,0.0029496300073030093,0.0028694500021326044,0.0027914500096812844,0.002715569998448094,0.0026417500145422914,0.0025699399799729386,0.0025000799990569553,0.002432120032608509,0.0023660099832341075,0.002301699986370901,0.0022391300299204886,0.0021782699623145163,0.002119059965480119,0.002061449980828911,0.002005420004328092,0.0019509099753728758,0.0018978799926117063,0.001846290009173875,0.0017961000072925042,0.001747280010022223,0.0016997899995961536,0.001653580004737402,0.0016086300020106137,0.0015649099853665878,0.001522370002930984,0.001480990011865894,0.00144072999440444,0.0014015699950202058,0.0013634800076639901,0.0013264100125525147,0.0012903599999845028,0.0012552900006994605,0.00122116999894691,0.0011879699886776507,0.0011556799969791125,0.0011242699983995408,0.001093709977188458,0.001063980006923278,0.001035060005960986,0.0010069300090738882,0.0009795599956608687,0.0009529350015024344,0.0009270329998495678,0.0009018359996844083,0.000877322997742643,0.0008534770022379234,0.0008302789986676847,0.0008077120000962168,0.0007857580058043823,0.0007644010086854299,0.0007436239975504577,0.0007333790029709538};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11866760253906,80.86898803710938,79.52129300435384,78.11829503377278,76.6684964497884,75.1794974009196,73.65859985351562,72.11220105489095,70.54630025227864,68.96630223592122,67.37740262349446,65.78390439351399,64.19020557403564,62.599806467692055,61.01620674133301,59.44240792592367,57.88110828399658,56.33490816752116,54.80580870310465,53.29580879211426,51.80660915374756,50.339708964029946,48.89630953470866,47.47750981648763,46.08421007792155,44.71740976969401,43.377509435017906,42.06520970662435,40.78080972035726,39.52480983734131,38.29720973968506,37.098209381103516,35.927809715270996,34.78620910644531,33.67300923665365,32.58830897013346,31.531809012095135,30.50330877304077,29.502408504486084,28.529008388519287,27.58250840504964,26.662708282470703,25.769108136494953,24.901307900746662,24.058807690938313,23.241207281748455,22.448007265726726,21.67860730489095,20.9327073097229,20.209606806437176,19.50900681813558,18.830206712086994,18.17280626296997,17.536206086476643,16.91990582148234,16.323405742645264,15.746205647786459,15.18780549367269,14.64770539601644,14.125405152638754,13.620405038197836,13.13220485051473,12.660404761632284,12.204404592514038,11.76380451520284,11.338204304377237,10.927104234695435,10.530104080835978,10.146803855895996,9.77665376663208,9.419373591740927,9.07451351483663,8.741693576176962,8.420543432235718,8.11068324247996,7.8117430210113525,7.523392995198567,7.245272954305013,6.977052768071492,6.718422691027324,6.469042619069417,6.228622515996297,5.996842384338379,5.773442347844441,5.558112263679504,5.350582242012024,5.145912210146586,4.944302320480347,4.750622232755025,4.564552108446757,4.385801990826924,4.214071949323018,4.049101809660594,3.8906017740567527,3.7383417089780173,3.5920616587003074,3.4515215357144675,3.3165115118026733,3.18679145971934,3.0621713995933533,2.942451318105062,2.827421267827352,2.7169112165768943,2.6107312043507895,2.508721133073171,2.4107110699017844,2.3165510296821594,2.2260810335477195,2.139160990715027,2.055640935897827,1.9754008849461873,1.8983008762200673,1.824230819940567,1.753060797850291,1.6846707959969838,1.6189707418282826,1.5558306972185771,1.495170682668686,1.4368906418482463,1.3808806538581848,1.3270706037680309,1.275370568037033,1.225680559873581,1.1779405375321705,1.132070501645406,1.088000496228536,1.045640488465627,1.004940465092659,0.9658354371786118,0.9282564173142115,0.8921454052130381,0.8574443906545639,0.8240993718306223,0.7920553535223007,0.761263350645701,0.7316723316907883,0.7032353182633718,0.6759082973003387,0.6496462970972061,0.6244082848230997,0.6001542707284292,0.5768452535072962,0.5544442484776179,0.5329162379105886,0.5122262289126714,0.49234222372372943,0.4732312162717183,0.4548652072747548,0.4372131998340289,0.42024819552898407,0.40394218266010284,0.3882711778084437,0.3732091685136159,0.3587331647674243,0.34481915334860486,0.331446148455143,0.3185931493838628,0.30623913804690045,0.29436412702004117,0.28295112897952396,0.2719811250766118,0.2614371180534363,0.2513031139969826,0.24156110982100168,0.23219810674587885,0.22319810216625532,0.21454709892471632,0.2062320920328299,0.19823909054199854,0.19055608784159025,0.18317108352979025,0.17607307930787405,0.16924907639622688,0.1626910741130511,0.15638607243696848,0.1503260682026545,0.144501065214475,0.13890106230974197,0.13351806129018465,0.12834405899047852,0.1233710553497076,0.11859005379180114,0.11399405201276143,0.10957604895035426,0.1053300475080808,0.10124804638326168,0.09732454394300778,0.09355294145643711,0.08992754233380158,0.08644253884752591,0.08309263673921426,0.07987253554165363,0.07677723467350006,0.07380193347732227,0.070941931878527,0.0681927315890789,0.06555012986063957,0.06300982863952716,0.06056812716027101,0.05822102694461743,0.05596482505400976,0.05379612402369579,0.051711423632999264,0.04970762226730585,0.047781421492497124,0.04592982058723768,0.04415002092719078,0.04243921892096599,0.04079471807926893,0.03921401811142763,0.037694516902168594,0.03623391594737768,0.03482991550117731,0.03348031515876452,0.0321831147496899,0.03093611417959134,0.02973741355041663,0.028585213081290323,0.027477712525675695,0.026413112102697294,0.02538971183821559,0.02440601106112202,0.023460410845776398,0.022551510172585647,0.02167780976742506,0.02083800934876005,0.020030709138760965,0.019254708817849558,0.01850870841493209,0.017791708155224722,0.01710250771914919,0.016440007214744885,0.015803107448543113,0.015190906977901856,0.014602506533265114,0.014036806377892693,0.013493106079598268,0.012970505903164545,0.012468105647712946,0.011985105384762088,0.011520905264963707,0.011074705049395561,0.010645804926753044,0.010233504620070258,0.00983715453185141,0.009456194238737226,0.0090899842325598,0.008737963857129216,0.008399593799064556,0.008074323646724224,0.007761653512716293,0.007461103416668872,0.007172193222989638,0.0068944831533978386,0.006627522991038859,0.006370912888087332,0.006124232740451892,0.00588711261904488,0.005659172544255853,0.005440072505734861,0.005229452353281279,0.005026982243483265,0.004832362290471792,0.004645282169803977,0.004465442034415901,0.004292571955981354,0.004126391878041129,0.003966651837496708,0.0038130917431165776,0.0036654816358350217,0.003523581583673755,0.003387181553989649,0.0032560714753344655,0.003130021427447597,0.0030088613469464085,0.0028923912905156612,0.0027804312218601504,0.002672811213415116,0.0025693511318725846,0.0024699010925057032,0.002374301082454622,0.002282401042369505,0.002194060963423302,0.0021091309608891606,0.0020275009252751866,0.00194903087685816,0.0018735908476325374,0.0018010808174343158,0.0017313707794528455,0.0016643607523292303,0.001599940723584344,0.0015380206847718607,0.0014785006739354383,0.0014212806515085201,0.0013662706187460572,0.0013133905789194007,0.0012625605644037325,0.0012137005299640198,0.001166730517676721,0.0011215805037257571,0.0010781804739963263,0.001036450470564887,0.0009963424430073549,0.0009577854313344384,0.0009207204226792479,0.0008850903977872804,0.0008508393802912906,0.0008179143672653785,0.0007862633598657945,0.0007558373423914114,0.0007265893315585951,0.0006984733142113934,0.0006714453047607094,0.0006454633015285557,0.0006204872818974158,0.0005964772766067957,0.0005733962607337162,0.0005512092417726914,0.0005298802425386384,0.0005093772294155011,0.0004896682197189269,0.00047072121136200923,0.0004525072023776981,0.0004349981973064132,0.00041816718779349077,0.0004019871848868206,0.0003864341730756375,0.0003714821699153011,0.0003571091607833902,0.0003432921609298016,0.0003300101476876686,0.00031724114281435806,0.0003049671358894557,0.0002931681301561184,0.0002818251256636965,0.0002709211233498839,0.0002604401185332487,0.0002503641153452918,0.00024067710789192157,0.00023136610373815833,0.00022241510062788924,0.00021381009719334543,0.00020553809372358955,0.00019758608929502466,0.00018994208464088538,0.00018259408170706593,0.00017553008001414128,0.0001687390783141988,0.0001622110733781786,0.00015593607046563798,0.00014990306832866432,0.00014410406341388202,0.0001385300614250203,0.0001331710603456789,0.0001280190578351418,0.0001230670544221842,0.00011830605399154592,0.00011372905161503392,0.0001093300500845847,0.00010510004722164012,7.613582238263916e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45183436075845,229.59260686238608,226.30971908569336,223.6417096455892,220.94771194458008,218.22970708211264,215.49370702107748,212.74170430501303,209.97670110066733,207.20170211791992,204.41970189412436,201.6337038675944,198.8467025756836,196.05970255533853,193.27670288085938,190.49970372517905,187.7297045389811,184.9687042236328,182.21871058146158,179.4827092488607,176.76071166992188,174.05471420288086,171.3647143046061,168.69471740722656,166.04372024536133,163.412722269694,160.8037223815918,158.2177276611328,155.65473047892252,153.11573282877603,150.6007334391276,148.11273574829102,145.64974085489908,143.2127431233724,140.80274709065756,138.42074712117514,136.0667495727539,133.7397549947103,131.44175974527994,129.17176055908203,126.93176396687825,124.71976661682129,122.53676986694336,120.38277371724446,118.25877634684245,116.162779490153,114.09678204854329,112.05978457132976,110.05179023742676,108.07379213968913,106.12379519144694,104.20379892985027,102.31180063883464,100.44880358378093,98.6138064066569,96.80751037597656,95.02931340535481,93.27911631266277,91.55661964416504,89.86172231038411,88.19402567545573,86.55342801411946,84.93973096211751,83.3525333404541,81.79163614908855,80.25673866271973,78.74774169921875,77.26414426167806,75.80574607849121,74.37214914957683,72.96325174967448,71.57875569661458,70.21815745035808,68.8813591003418,67.56806246439616,66.27786509195964,65.01046689351399,63.76566950480143,62.54307238260905,61.342474619547524,60.16347694396973,59.0058790842692,57.869181315104164,56.75338331858317,55.65788491566976,54.58258819580078,53.54819424947103,52.55369599660238,51.576596895853676,50.61669890085856,49.67370065053304,48.74740250905355,47.8375047047933,46.94380601247152,46.065908432006836,45.2037099202474,44.356911977132164,43.52521260579427,42.70851389567057,41.90641562143961,41.11881732940674,40.34541893005371,39.58602046966553,38.84032154083252,38.108123461405434,37.389225006103516,36.68342590332031,35.99042797088623,35.31012852986654,34.64223003387451,33.986531257629395,33.3429323832194,32.71103382110596,32.09083557128906,31.48193597793579,30.884336948394775,30.297738552093506,29.722039699554443,29.156940778096516,28.60234196980794,28.05794318517049,27.523743788401287,26.999445120493572,26.484846274058025,25.979947090148926,25.48434813817342,24.998048941294353,24.520849863688152,24.052550951639812,23.59305206934611,23.14205265045166,22.69955348968506,22.26535479227702,21.83935562769572,21.421356519063313,21.011157194773357,20.6086581548055,20.21375910441081,19.82625945409139,19.446060021718342,19.073060830434162,18.707061767578125,18.347962379455566,17.995663166046143,17.649963855743408,17.31076415379842,16.978065331776936,16.65156586964925,16.331266562143963,16.017067193984985,15.708767731984457,15.40626851717631,15.10956883430481,14.818469524383545,14.532870133717855,14.252670605977377,13.977771202723185,13.70807178815206,13.443572282791138,13.183972915013632,12.929373423258463,12.679673910140991,12.434574365615845,12.19427482287089,11.958475351333618,11.727175871531168,11.500176270802816,11.277576764424643,11.059277216593424,10.845077594121298,10.634877999623617,10.428778489430746,10.226578871409098,10.028279383977255,9.833709637324015,9.64286994934082,9.455670436223349,9.272040764490763,9.091931263605753,8.915271441141764,8.741971890131632,8.571982304255167,8.405272483825684,8.241742928822836,8.08133316040039,7.924003521601359,7.769693891207377,7.618344187736511,7.469894448916118,7.324284752209981,7.181485056877136,7.0414453347524,6.904095609982808,6.76939590771993,6.637286146481832,6.507716417312622,6.380646626154582,6.256026983261108,6.133827209472656,6.013967474301656,5.896427710851033,5.781157970428467,5.6681281725565595,5.557268381118774,5.448558608690898,5.341958840688069,5.237419048945109,5.134899258613586,5.034369468688965,4.935799678166707,4.839139938354492,4.744370102882385,4.6514302889506025,4.560310443242391,4.470950643221538,4.383320848147075,4.297401070594788,4.213141202926636,4.130521337191264,4.04949152469635,3.970041731993357,3.892141858736674,3.81577201684316,3.740882178147634,3.6674323280652366,3.59543244043986,3.524832626183828,3.455592771371206,3.387722909450531,3.3211630384127298,3.2559231519699097,3.1919433077176413,3.1292234659194946,3.067733565966288,3.0074337124824524,2.948323825995127,2.890363931655884,2.833534061908722,2.777804176012675,2.7231743137041726,2.6696044206619263,2.6171045303344727,2.5656246145566306,2.5151547392209372,2.4656648437182107,2.417134920756022,2.369565010070801,2.32292511065801,2.2771951953570047,2.232365349928538,2.18843537569046,2.145355482896169,2.103105584780375,2.061705688635508,2.0210957527160645,1.9812858402729034,1.9422559241453807,1.9040060142676036,1.86651607354482,1.8297461370627086,1.7936862309773762,1.7583463092645009,1.7237063745657604,1.689756453037262,1.6564565201600392,1.6237965822219849,1.5917866627375286,1.560416728258133,1.5296667913595836,1.4995268285274506,1.4699669082959492,1.440966973702113,1.4125470320383708,1.3846970697244008,1.3573871453603108,1.3306271930535634,1.304407258828481,1.2786773045857747,1.2534373700618744,1.2286974092324574,1.2044474482536316,1.1806775331497192,1.1573875645796459,1.1345576047897339,1.1121776700019836,1.090237706899643,1.0687477588653564,1.047647774219513,1.0269578297932942,1.0066678822040558,0.9867859234412512,0.9672979613145193,0.948197012146314,0.9294750442107519,0.9111240804195404,0.893138125538826,0.8755091627438863,0.858230193456014,0.8412942339976629,0.8246932625770569,0.8084233005841573,0.7924753328164419,0.776822363336881,0.7614593903223673,0.7464004258314768,0.7316404531399409,0.7171734919150671,0.7029935171206793,0.6890955418348312,0.6754725724458694,0.6621206104755402,0.6490326374769211,0.6362056583166122,0.6236316909392675,0.6113087187210718,0.5992297331492106,0.5873897622028986,0.5757847925027212,0.5644108206033707,0.5532618363698324,0.5423348546028137,0.5316238800684611,0.5211258977651596,0.5108359158039093,0.5007499406735102,0.49086396396160126,0.4811749880512555,0.471677007774512,0.46236802885929745,0.45324404537677765,0.4443010687828064,0.4355350856979688,0.4269431009888649,0.4185211236278216,0.4102671320239703,0.40215415010849637,0.39418216794729233,0.38636717945337296,0.37870720277229947,0.37120021879673004,0.3638412331541379,0.35662824660539627,0.3495582590500514,0.342629278699557,0.33583729217449826,0.3291793043414752,0.3226543168226878,0.3162583311398824,0.3099893430868785,0.30384436001380283,0.29782136778036755,0.2919183820486069,0.2861313944061597,0.2804604048530261,0.2749014124274254,0.26945243030786514,0.26411144187053043,0.2588764528433482,0.2537454639871915,0.2487164723376433,0.24378648524483046,0.23895449688037237,0.23421850552161536,0.22957651441295943,0.22502652431527773,0.22056653474768004,0.2161945439875126,0.211910550793012,0.20771056165297827,0.20359357073903084,0.19955857718984285,0.19560358673334122,0.19172759478290877,0.1879276024798552,0.18420361106594405,0.1805536188185215,0.17697562649846077,0.17346763362487158,0.17003064105908075,0.16666064659754434,0.1633586548268795,0.16012166067957878,0.1569486695031325,0.15383867174386978,0.15078967933853468,0.14780168856183687,0.14487269272406897,0.14200269803404808,0.13918870811661085,0.13643071179588637,0.13372771814465523,0.1310777241985003,0.12848072995742163,0.12593473556141058,0.12343973852694035,0.12099374458193779,0.1185967493802309,0.11624675368269284,0.11394375873108704,0.11168576342364152,0.1094727690021197,0.10730377336343129,0.10517777750889461,0.10309478268027306,0.10105178567270438,0.09904978983104229,0.097087395687898,0.09516399912536144,0.09327870421111584,0.091430705661575,0.0896194117764632,0.08784391482671101,0.0861037162443002,0.0843979213386774,0.08272602471212546,0.08108722853163879,0.0794809324045976,0.07790643535554409,0.07636313823362191,0.07485044188797474,0.07336774468421936,0.07191434875130653,0.07048985175788403,0.06909355459113915,0.06772485685845216,0.0663833599537611,0.06506846224268277,0.06377956581612428,0.06251626865317424,0.06127797098209461,0.060064272955060005,0.058874575421214104,0.057708377639452614,0.05656538034478823,0.05544498283416033,0.05434688491125902,0.0532704871147871,0.05221538990736008,0.05118119157850742,0.050167493832608066,0.049173896200954914,0.04819999821484089,0.04724539971599976,0.04630970240881046,0.04539250396192074,0.04449360600362221,0.04361240814129511,0.0427487101405859,0.041902111222346626,0.04107221340139707,0.0402589151635766,0.039461616426706314,0.03868011819819609,0.03791411935041348,0.03716332123925289,0.03642742273708185,0.03570602461695671,0.03499892633408308,0.034305927343666553,0.03362652907768885,0.032960730604827404,0.03230803180485964,0.03166823306431373,0.031041134614497423,0.03042653591061632,0.029824036949624617,0.029233538235227268,0.02865463960915804,0.028087240799019735,0.027531141880899668,0.026986043124149244,0.026451644022017717,0.02592794519538681,0.025414546485990286,0.024911347000549238,0.02441814836735527,0.02393474957595269,0.023460850430031616,0.022996351433296997,0.022541052506615717,0.022094753260413807,0.021657354198396206,0.02122855543469389,0.02080825452382366,0.02039626861612002,0.020192382857203484};
        CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452011108398,71.4100399017334,70.57014846801758,69.81604131062825,69.0663407643636,68.32124137878418,67.58124097188313,66.84654108683269,66.11744054158528,65.39403978983562,64.67653910319011,63.96513875325521,63.259939193725586,62.56093819936117,61.868438720703125,61.18233776092529,60.502637227376304,59.82953707377116,59.162936528523765,58.502936363220215,57.849435806274414,57.20253531138102,56.562034924825035,55.92813491821289,55.300734202067055,54.67973391215006,54.06513373057047,53.456933657328285,52.855133056640625,52.2595329284668,51.67023245493571,51.08713181813558,50.51013215382894,49.93933137257894,49.37463092803955,48.81583054860433,48.26313018798828,47.7163298924764,47.17542966206869,46.640329360961914,46.11102867126465,45.58752886454264,45.069728215535484,44.55742804209391,44.05082734425863,43.54972775777181,43.054127057393394,42.563926696777344,42.0791269938151,41.59972635904948,41.125526110331215,40.65662542978922,40.192925453186035,39.73432572682699,39.28082466125488,38.832424799601235,38.38902441660563,37.95052401224772,37.51692422231039,37.088123639424644,36.6642230351766,36.245022455851235,35.830522219340004,35.42062218983968,35.015421867370605,34.61482175191244,34.21872170766195,33.8271214167277,33.43992074330648,33.05712095896403,32.67872015635172,32.30452028910319,31.934619903564453,31.56902011235555,31.207519849141438,30.850119431813557,30.49691931406657,30.14771906534831,29.802519003550213,29.461318651835125,29.124018510182697,28.79071839650472,28.46121819814046,28.135517915089924,27.81361786524455,27.49551757176717,27.181017239888508,26.870316823323567,26.563116709391277,26.25961669286092,25.959616502126057,25.663116455078125,25.370116074879963,25.08051586151123,24.79421583811442,24.511415481567383,24.231815179189045,23.95551522572835,23.682415008544922,23.412614822387695,23.145814259847004,22.882214387257893,22.6217139561971,22.364214102427166,22.109713872273762,21.858213583628338,21.60961373647054,21.363913377126057,21.121013323465984,20.881013075510662,20.643813133239746,20.40941270192464,20.17771275838216,19.94871250788371,19.722312450408936,19.49861224492391,19.277511755625408,19.059011777242024,18.843012015024822,18.62951135635376,18.418511549631756,18.209911346435547,18.003811200459797,17.800111293792725,17.598711172739666,17.39971113204956,17.20301087697347,17.00851074854533,16.81641085942586,16.626410643259685,16.43871021270752,16.25311024983724,16.06971017519633,15.888409932454428,15.70920991897583,15.53210973739624,15.357009569803873,15.18390949567159,15.01280943552653,14.843709309895834,14.676509300867716,14.511308987935385,14.347908973693848,14.186408758163452,14.026808897654215,13.869008700052897,13.713008562723795,13.55880848566691,13.406408230463663,13.25570821762085,13.10670804977417,12.959408044815063,12.813808043797811,12.66980791091919,12.527507861455282,12.386807759602865,12.247707684834799,12.110207557678223,11.974307457605997,11.83990732828776,11.70700732866923,11.575607140858969,11.445707162221273,11.317207018534342,11.190306901931763,11.064706802368164,10.940606753031412,10.817906697591146,10.696506579717001,10.576506535212198,10.457906405131022,10.340606530507406,10.22460643450419,10.110006332397461,9.996576229731241,9.884466250737509,9.773616075515747,9.664005915323893,9.555615981419882,9.448455890019735,9.342485825220743,9.23770578702291,9.134105602900187,9.031655550003052,8.930365403493246,8.8302055199941,8.731165409088135,8.63324530919393,8.536415497461954,8.440675258636475,8.346005042394003,8.252404928207397,8.159845113754272,8.068324963251749,7.977835059165955,7.888364950815837,7.7998948097229,7.712414781252543,7.625924706459045,7.54039470354716,7.455824653307597,7.3722145557403564,7.289534489313762,7.207784493764241,7.126954396565755,7.047034382820129,6.96800430615743,6.889864285786946,6.812604188919067,6.73621420065562,6.660674134890239,6.5859940846761065,6.512144088745117,6.43912402788798,6.366923967997233,6.295533895492554,6.224943836530049,6.155153870582581,6.086143811543782,6.017903685569763,5.950443665186564,5.883733590443929,5.817763606707255,5.752543568611145,5.688063542048137,5.624293526013692,5.561253468195598,5.498913407325745,5.437273343404134,5.376333276430766,5.316063284873962,5.256483276685079,5.197573145230611,5.139313181241353,5.081713120142619,5.024763107299805,4.968453129132588,4.912773052851359,4.857723077138265,4.803292989730835,4.749473015467326,4.696252822875977,4.643642783164978,4.591612855593364,4.540172815322876,4.489312807718913,4.439022699991862,4.389302770296733,4.340132673581441,4.291522701581319,4.243452628453572,4.195922573407491,4.148932576179504,4.1024625698725385,4.056522409121196,4.01109250386556,3.96618245045344,3.9217624266942344,3.8778523802757263,3.8344323436419168,3.7914923230806985,3.7490423123041787,3.707072297732035,3.6655622919400535,3.62452224890391,3.583942234516144,3.543822169303894,3.5041521787643433,3.4649221698443093,3.4261321425437927,3.387782096862793,3.3498620986938477,3.3123620748519897,3.2752820452054343,3.238621989885966,3.2023719946543374,3.166531980037689,3.1310919721921286,3.0960418979326882,3.0613918900489807,3.0271318554878235,2.993251840273539,2.959751844406128,2.92663182814916,2.8938817977905273,2.8614917596181235,2.829471747080485,2.79781174659729,2.766501704851786,2.7355416814486184,2.704931676387787,2.674661656220754,2.644731601079305,2.6151416500409446,2.5858816107114158,2.556941588719686,2.528341551621755,2.5000515580177307,2.4720715085665383,2.4444214900334678,2.4170714815457663,2.390021502971649,2.3632914622624717,2.3368514577547708,2.3107014298439026,2.284851392110189,2.259291410446167,2.234011391798655,2.209021349747976,2.1843113700548806,2.159881313641866,2.1357113321622214,2.1118212938308716,2.0882012645403543,2.0648412704467773,2.0417412519454956,2.018901248772939,1.9963212112585704,1.9739912052949269,1.9519112209479015,1.930081178744634,1.908491164445877,1.887141187985738,1.8660411636034648,1.8451711336771648,1.8245311379432678,1.8041211267312367,1.7839411199092865,1.7639911075433095,1.7442610661188762,1.7247610688209534,1.7054710388183594,1.6863910555839539,1.667531023422877,1.6488910416762035,1.6304510136445363,1.612211008866628,1.5941809912522633,1.5763609608014424,1.5587309698263805,1.5413009524345398,1.5240609248479207,1.507020930449168,1.490170915921529,1.4735009173552196,1.4570308923721313,1.4407409032185872,1.4246308902899425,1.4087008734544118,1.3929508527119954,1.3773708442846935,1.361970841884613,1.3467408219973247,1.3316808144251506,1.3167908092339833,1.3020708064238231,1.2875108023484547,1.2731207807858784,1.2588907778263092,1.2448107699553173,1.2308907608191173,1.2171307404836018,1.2035307586193085,1.1900707483291626,1.1767707268397014,1.163610726594925,1.1506007115046184,1.1377407014369965,1.1250206927458446,1.112440675497055,1.1000106632709503,1.0877106885115306,1.0755506853262584,1.0635306537151337,1.0516406496365864,1.0398806631565094,1.0282606581846874,1.0167706211407979,1.0054006377855937,0.9941646109024683,0.983051617940267,0.9720636010169983,0.9611985931793848,0.9504545877377192,0.9398315946261088,0.9293265690406164,0.9189395705858866,0.9086695661147436,0.8985135505596796,0.8884705553452173,0.8785405407349268,0.8687225331862768,0.8590125242869059,0.8494125207265218,0.8399195124705633,0.8305325110753378,0.8212505082289377,0.8120725005865097,0.8029974897702535,0.7940234939257304,0.7851504782835642,0.7763754775126775,0.7676994800567627,0.7591204792261124,0.7506374617417654,0.7422494639952978,0.7339554578065872,0.7257534464200338,0.7176434447367986,0.7096244444449743,0.7016954272985458,0.6938544263442358,0.6861014266808828,0.6784344166517258,0.670854409535726,0.6633584151665369,0.6559464037418365,0.6486174017190933,0.6413704007863998,0.6342033892869949,0.6271173854668936,0.6201113810141882,0.613182375828425,0.6063313782215118,0.5995573749144872,0.5928593675295512,0.5862353642781576,0.5796853651603063,0.5732093552748362,0.5668053527673086,0.5604733427365621,0.554211343328158,0.5480203380187353,0.5418983350197474,0.5358443409204483,0.5298583308855692,0.5239393214384714,0.518086314201355,0.5122983157634735,0.5065753161907196,0.5009163146217664,0.4953213060895602,0.48978830377260846,0.4843173027038574,0.4789072920878728,0.47355729589859646,0.4682672893007596,0.46303728967905045,0.45786528040965396,0.4527512788772583,0.44769327094157535,0.4426932732264201,0.4377482682466507,0.43285926928122836,0.4280242621898651,0.4232442652185758,0.41851625839869183,0.41384225835402805,0.40922025094429654,0.4046492551763852,0.4001302445928256,0.39566123982270557,0.39124224086602527,0.3868732402722041,0.38255223135153454,0.37828023235003155,0.3740552266438802,0.36987822751204175,0.36574722578128177,0.36166322727998096,0.35762422780195874,0.3536302174131076,0.34968121846516925,0.3457762176791827,0.34191521257162094,0.3380972122152646,0.3343212107817332,0.3305882041652997,0.3268972064057986,0.32324620087941486,0.3196372017264366,0.3160681948065758,0.31253819664319354,0.30904918909072876,0.3055982043345769,0.30388203759988147};
        CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297698338826496,16.274217287699383,16.21771017710368,16.17810821533203,16.132907390594482,16.08290672302246,16.028705596923828,15.970905065536499,15.909804582595825,15.845904032389322,15.779603481292725,15.71120309829712,15.641002734502157,15.569302399953207,15.496202150980631,15.422101815541586,15.347001632054647,15.271101554234823,15.194501399993896,15.117501179377237,15.040001074473063,14.96220095952352,14.884200890858969,14.806000630060831,14.727700471878052,14.649300654729208,14.571000576019287,14.492700417836508,14.414600451787313,14.336500406265259,14.25860039393107,14.18090025583903,14.103400230407715,14.026200215021769,13.949100097020468,13.872400204340616,13.795900185902914,13.71970017751058,13.643800179163614,13.568300167719523,13.493000189463297,13.418100198109945,13.343500216801962,13.26930014292399,13.19539999961853,13.12180002530416,13.048600196838379,12.975800037384033,12.903300126393637,12.831200122833252,12.759399970372518,12.687999963760376,12.616999944051107,12.546300093332926,12.47599999109904,12.405999819437662,12.336399873097738,12.267199993133545,12.198400020599365,12.129899978637695,12.061700026194254,11.99399995803833,11.926600058873495,11.859600146611532,11.792900085449219,11.726600090662638,11.660600026448568,11.59499994913737,11.529799858729044,11.464999993642172,11.400400082270304,11.336299975713095,11.272500276565552,11.209099928538004,11.146000067392984,11.083199818929037,11.020900090535482,10.958799997965494,10.897200028101603,10.835899909337362,10.774899880091349,10.71429999669393,10.653999964396158,10.594000021616617,10.534499963124594,10.475200017293295,10.416299819946289,10.357800006866455,10.299599885940552,10.241700013478598,10.184199889500936,10.126999934514364,10.070199886957804,10.013699928919474,9.957469940185547,9.901620070139566,9.846100012461344,9.790899912516275,9.73602000872294,9.681469996770224,9.62723994255066,9.573320070902506,9.51973001162211,9.466439962387085,9.413469950358072,9.360809961954752,9.308459917704264,9.256420135498047,9.2046799659729,9.153249979019165,9.102109988530477,9.05128026008606,9.000740051269531,8.950499931971232,8.900559981664022,8.850909948348999,8.80154005686442,8.752469857533773,8.70368997255961,8.655189832051596,8.606969992319742,8.559039990107218,8.511380036671957,8.464010000228882,8.41691001256307,8.370090087254843,8.32355006535848,8.277270078659058,8.23127007484436,8.185530026753744,8.14006002744039,8.094860076904297,8.049920082092285,8.005239963531494,7.960819999376933,7.916660030682881,7.872749964396159,7.829100012779236,7.785699923833211,7.742550094922383,7.699649969736735,7.656999985376994,7.614590009053548,7.572429935137431,7.530509988466899,7.48881995677948,7.447379986445109,7.406170010566711,7.365200002988179,7.324459989865621,7.283960024515788,7.243679960568746,7.2036300500233965,7.163809935251872,7.124219973882039,7.084850072860718,7.045700033505757,7.006770014762878,6.96805997689565,6.929569999376933,6.891300002733867,6.853240052858989,6.815389951070149,6.777760028839111,6.740339994430542,6.703130046526591,6.666119972864787,6.629319985707601,6.592730005582173,6.556340018908183,6.520150025685628,6.4841599861780805,6.448370059331258,6.4127800067265825,6.377390027046204,6.342200001080831,6.30718998114268,6.272379954655965,6.237770040829976,6.20333993434906,6.1690999666849775,6.135059952735901,6.101200024286906,6.0675199429194135,6.034030079841614,6.000729997952779,5.967609961827596,5.9346699714660645,5.9019200801849365,5.869350035985311,5.836949984232585,5.804740071296692,5.772700031598409,5.740839958190918,5.709149996439616,5.677639961242676,5.646310011545817,5.615140000979106,5.584150075912476,5.553329984347026,5.522689978281657,5.492209951082866,5.461899995803833,5.4317500193913775,5.401779969533284,5.371969978014628,5.342320005098979,5.312839984893799,5.283520023028056,5.254370013872783,5.225370009740193,5.1965400377909345,5.16786003112793,5.139349977175395,5.110989967981975,5.082789977391561,5.054740031560262,5.02685006459554,4.999120036760966,4.971530040105184,4.944100022315979,4.916830023129781,4.889699935913086,4.862730026245117,4.835899988810222,4.80922003587087,4.782690008481343,4.756309946378072,4.7300699551900225,4.703979969024658,4.6780299345652265,4.652229984601338,4.626569946606954,4.601050019264221,4.575670043627421,4.5504400332768755,4.5253400405248,4.500379999478658,4.47557000319163,4.45087997118632,4.4263399839401245,4.401930014292399,4.377660036087036,4.353530049324036,4.329519947369893,4.305649995803833,4.2819199959437055,4.258310039838155,4.2348399957021075,4.211489915847778,4.188280026117961,4.165189981460571,4.142229994138082,4.119400064150493,4.0966999133427935,4.0741199652353925,4.051669994990031,4.029340028762817,4.007130066553752,3.9850500226020813,3.9630899826685586,3.9412500262260437,3.919539988040924,3.8979400197664895,3.876460015773773,3.8550999959309897,3.833859999974569,3.8127400080362954,3.791730006535848,3.7708400090535483,3.7500699957211814,3.7294099728266397,3.708859999974569,3.6884300311406455,3.6681100130081177,3.647899945576986,3.6278100411097207,3.607829988002777,3.5879500110944114,3.568190018335978,3.548530022303263,3.528990010420481,3.5095499753952026,3.4902199705441794,3.471000015735626,3.4518799980481467,3.432870010534922,3.413960019747416,3.3951599995295205,3.376460015773773,3.357859989007314,3.3393699725468955,3.3209799925486245,3.3026899894078574,3.284500002861023,3.266420006752014,3.248429993788401,3.2305399576822915,3.212749977906545,3.1950599948565164,3.1774699886639914,3.159969985485077,3.1425700187683105,3.125269969304403,3.1080600221951804,3.090939998626709,3.073930025100708,3.057000001271566,3.040169974168142,3.0234299898147583,3.006779988606771,2.9902299841245017,2.973770002524058,2.957389990488688,2.9411099751790366,2.9249199827512107,2.9088199933369956,2.8928000132242837,2.8768800099690757,2.861040016015371,2.8452899853388467,2.8296299974123635,2.8140499790509543,2.7985599835713706,2.783150017261505,2.7678299943606057,2.752590000629425,2.737440009911855,2.7223700086275735,2.707389990488688,2.6924900015195212,2.6776600082715354,2.6629300117492676,2.648269991079966,2.6336900194485984,2.619199971357981,2.6047800183296204,2.590440014998118,2.576180020968119,2.5620099902153015,2.5478999614715576,2.5338799953460693,2.51993997891744,2.5060700178146362,2.492269972960154,2.478559990723928,2.4649199644724527,2.4513500332832336,2.4378599921862283,2.4244399865468345,2.411099990208944,2.397830009460449,2.3846399784088135,2.3715099891026816,2.358459989229838,2.3454899986584983,2.3325799902280173,2.3197399973869324,2.306979993979136,2.294279992580414,2.281660000483195,2.26910001039505,2.2566200296084085,2.244199971357981,2.231849988301595,2.2195700804392495,2.207360009352366,2.1952099800109863,2.1831299861272178,2.17112002770106,2.159179985523224,2.1472999850908914,2.135479986667633,2.1237300435702005,2.1120499769846597,2.100429972012838,2.088870048522949,2.0773800015449524,2.0659499963124595,2.054580012957255,2.043280045191447,2.032039999961853,2.020860016345978,2.0097400148709617,1.9986799955368042,1.9876900017261505,1.9767499963442485,1.965879996617635,1.955070008834203,1.9443099995454152,1.9336099823315938,1.9229800005753834,1.9123999973138173,1.9018800059954326,1.8914199968179066,1.8810099959373474,1.8706700106461842,1.8603799839814503,1.8501399954160054,1.8399699926376343,1.8298500180244446,1.8197800020376842,1.8097699880599976,1.7998199959595997,1.7899199922879536,1.7800699869791667,1.770279993613561,1.7605500022570293,1.7508599956830342,1.7412299911181133,1.731660008430481,1.722130000591278,1.7126600046952565,1.7032400071620941,1.6938699980576832,1.6845599909623463,1.6752900183200836,1.6660799980163574,1.6569199959437053,1.6477999885876973,1.6387400130430858,1.6297300060590107,1.6207700073719025,1.6118599971135457,1.6029900014400482,1.594180017709732,1.5854099889596303,1.5766899983088176,1.5680200258890789,1.5594000021616619,1.550819993019104,1.5422999858856201,1.5338099896907806,1.5253800054391224,1.5169900059700012,1.5086499949296315,1.5003600021203358,1.492110013961792,1.48389999071757,1.4757399956385295,1.467629998922348,1.4595599869887035,1.451530009508133,1.4435500105222066,1.4356199999650319,1.4277200102806091,1.4198700090249379,1.4120700061321259,1.4042999943097432,1.3965800007184346,1.388899991909663,1.3812699913978577,1.3736699918905895,1.3661200106143951,1.3586099942525227,1.3511400123437245,1.3437100052833557,1.336329996585846,1.328979988892873,1.321679989496867,1.3144099911053975,1.3071800072987874,1.299999992052714,1.2928500076134999,1.2857399880886078,1.2786799867947896,1.2716499765714009,1.2646600008010864,1.2577100098133087,1.2507900098959606,1.2439200083414714,1.2370799978574116,1.2302799920241039,1.223520000775655,1.2167899906635284,1.2100999852021534,1.2034499943256378,1.1968400080998738,1.1902599930763245,1.1837200125058491,1.177210013071696,1.1707399984200795,1.164309988419215,1.1579099893569946,1.1515399813652039,1.1483699977397919};
        CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.46001680692037,8.488823413848877,8.531164328257242,8.575854063034058,8.61820419629415,8.658293883005777,8.696213801701864,8.73206361134847,8.765883525212606,8.797773281733194,8.827803293863932,8.856033325195312,8.882543166478476,8.907392899195353,8.930632829666138,8.952332814534506,8.97255253791809,8.991352637608847,9.008782545725504,9.024882316589355,9.03971234957377,9.053312063217163,9.065742015838623,9.07704210281372,9.08726191520691,9.096421798070272,9.104581753412882,9.111761649449667,9.118011713027954,9.123361587524414,9.127851565678915,9.13150151570638,9.134361664454142,9.136451482772827,9.137791474660238,9.138431390126547,9.138381322224935,9.137681325276693,9.136351188023886,9.134411017100016,9.131881157557169,9.128801107406616,9.125170946121216,9.121031125386557,9.11638100941976,9.111260890960693,9.105690797170004,9.099670807520548,9.093220869700113,9.086370706558228,9.07913080851237,9.071510712305704,9.06354053815206,9.055230617523193,9.04658063252767,9.037610610326132,9.028340498606363,9.01878046989441,9.008940617243448,8.998830556869507,8.988460381825766,8.977850437164307,8.967000563939413,8.955910444259644,8.944610436757406,8.933110475540161,8.921410401662191,8.909520308176676,8.89745044708252,8.885200182596842,8.872790495554606,8.860220432281494,8.847500324249268,8.834630250930786,8.821620305379232,8.80849027633667,8.795230388641357,8.781850258509317,8.768370230992636,8.754780133565268,8.741080204645792,8.727280298868815,8.713390191396078,8.69942021369934,8.685370206832886,8.67123007774353,8.655700127283732,8.638830025990805,8.621990044911703,8.60518995920817,8.588429848353067,8.571699937184652,8.555010080337524,8.538349946339926,8.521730105082193,8.505150000254313,8.488599936167398,8.472089926401773,8.455609957377115,8.439169963200888,8.422769943873087,8.406400044759115,8.390070041020712,8.373770078023275,8.357510169347128,8.341279904047648,8.325090090433756,8.308929999669393,8.292809963226318,8.27671996752421,8.260669946670532,8.24465004603068,8.228669961293539,8.212719917297363,8.196810086568197,8.180929978688559,8.165079911549887,8.149270057678223,8.133500019709269,8.117760022481283,8.102050145467123,8.086380084355673,8.07074006398519,8.055130004882812,8.039559920628866,8.024019956588745,8.008520046869913,7.99305001894633,7.977609952290853,7.962209979693095,7.946840008099874,7.9315100113550825,7.916200002034505,7.900930047035217,7.885689973831177,7.870489994684855,7.85532009601593,7.840179999669393,7.825069944063823,7.809989968935649,7.794950008392334,7.7799400091171265,7.764959971110026,7.750010013580322,7.735089977582295,7.720200061798096,7.705339948336284,7.690520008405049,7.675720016161601,7.660959959030151,7.6462299426396685,7.631519913673401,7.616849978764852,7.602199951807658,7.587590018908183,7.573010007540385,7.558450023333232,7.543930013974507,7.529429992039998,7.514960010846456,7.500530004501343,7.486119985580444,7.471740047136943,7.457389950752258,7.443060040473938,7.428769946098328,7.4145000378290815,7.400259931882222,7.38604998588562,7.3718700011571245,7.357709964116414,7.343590100606282,7.329490025838216,7.315410017967224,7.301369984944661,7.287350058555603,7.273360013961792,7.259390076001485,7.245459953943889,7.2315400044123335,7.217659989992778,7.203800042470296,7.189970016479492,7.176170110702515,7.1623899936676025,7.148639996846517,7.134910027186076,7.121209979057312,7.107539971669515,7.093889951705933,7.080270012219747,7.0666699806849165,7.053110043207805,7.039560039838155,7.026049971580505,7.01256004969279,6.9990899960199995,6.985650022824605,6.972239971160889,6.958859999974568,6.945499936739604,6.932160019874573,6.9188499848047895,6.905569990475972,6.8923100233078,6.8790799379348755,6.865870038668315,6.852689941724141,6.8395300308863325,6.82640000184377,6.813299973805745,6.800220012664795,6.787159999211629,6.77412994702657,6.761130054791768,6.748149871826172,6.7351999680201216,6.722270051638286,6.709369977315267,6.6964900096257525,6.683630029360454,6.6708000500996905,6.6579999923706055,6.645220041275024,6.632470051447551,6.619739969571431,6.607029994328816,6.594350020090739,6.581699967384338,6.569060047467549,6.556460022926331,6.543869972229004,6.5313200155893965,6.518779993057251,6.506269931793213,6.493789951006572,6.481330037117004,6.468889991442363,6.456480026245117,6.444090008735657,6.431729992230733,6.419389963150024,6.40707000096639,6.394779960314433,6.38250998655955,6.370270053545634,6.358050028483073,6.345850030581157,6.333679993947347,6.321529984474182,6.309410015741984,6.297310034434001,6.2852299610773725,6.27318000793457,6.261149962743123,6.249140063921611,6.237149953842163,6.225190083185832,6.213250041007996,6.201339999834697,6.1894499858220415,6.177579959233602,6.165740092595418,6.153909921646118,6.142109910647075,6.130340019861857,6.118580102920532,6.1068499485651655,6.095139980316162,6.083459973335266,6.071789979934692,6.060149987538655,6.048539956410726,6.036940058072408,6.025369962056478,6.013820052146912,6.0022900104522705,5.990779956181844,5.979300022125244,5.967840035756429,5.956400076548259,5.944980065027873,5.933579961458842,5.9222099383672075,5.910860021909078,5.899530092875163,5.888219912846883,5.87693993250529,5.865670045216878,5.854430039723714,5.843209942181905,5.83201003074646,5.82083002726237,5.809679985046387,5.798540075620015,5.7874300082524615,5.776339968045552,5.765269994735718,5.754220008850098,5.743190010388692,5.732190012931824,5.721200068791707,5.710240006446838,5.699289957682292,5.688369989395142,5.677469968795776,5.666590015093486,5.65573004881541,5.644900004069011,5.634079972902934,5.623280008633931,5.6125099658966064,5.601760029792786,5.591019988059998,5.580309987068176,5.569619973500569,5.558940013249715,5.548290014266968,5.537660042444865,5.527050058046977,5.516459941864014,5.5058900117874146,5.49533998966217,5.484820008277893,5.474310000737508,5.463820020357768,5.453350027402242,5.442899982134501,5.432479977607727,5.422069946924846,5.411679943402608,5.401310046513875,5.39097003142039,5.380640029907227,5.3703300555547075,5.360039989153544,5.349769989649455,5.339529991149902,5.329299966494243,5.319090008735657,5.308899998664856,5.29872989654541,5.288579940795898,5.278450012207031,5.2683400710423784,5.258249958356221,5.248170057932536,5.238119959831238,5.228089968363444,5.218069990475972,5.208080013593038,5.198100050290425,5.18815000851949,5.178210020065308,5.168290019035339,5.1583900054295855,5.148509979248047,5.138649980227153,5.128810008366902,5.118980010350545,5.109180013338725,5.099390029907227,5.089629968007405,5.079879999160767,5.070149978001912,5.060439984003703,5.050750017166138,5.041079878807068,5.031419992446899,5.021789948145549,5.01216995716095,5.002569993336995,4.992990016937256,4.983430027961731,4.973880052566528,4.964359958966573,4.954850037892659,4.945359985033671,4.935889959335327,4.926440040270488,4.917009989420573,4.90759003162384,4.898190061251323,4.88880995909373,4.879450003306071,4.870109915733337,4.860779960950215,4.851480007171631,4.842190066973369,4.832909981409709,4.823659976323445,4.814420064290364,4.805209994316101,4.795999964078267,4.78682001431783,4.777660051981608,4.768510063489278,4.759380062421163,4.750270048777263,4.741169969240825,4.73209007581075,4.723030010859172,4.7139900128046675,4.704959988594055,4.69596004486084,4.686969995498657,4.677989999453227,4.669039924939473,4.660099943478902,4.651180068651835,4.642269968986511,4.633380055427551,4.624510010083516,4.615660031636556,4.606820027033488,4.5980000495910645,4.589199980099996,4.5804199775060015,4.57165006796519,4.562899986902873,4.554159959157308,4.545439998308818,4.5367400248845415,4.5280600388844805,4.5193900267283125,4.510739962259929,4.502100070317586,4.493480046590169,4.484879970550537,4.476300001144409,4.4677300453186035,4.459179997444153,4.450640042622884,4.442119995752971,4.433619976043701,4.425129930178325,4.416659990946452,4.408209999402364,4.3997699817021685,4.3913499514261884,4.3829500277837115,4.374559958775838,4.366179982821147,4.357830007870992,4.3494900067647295,4.34116005897522,4.332850019137065,4.324560006459554,4.316280047098796,4.308019955952962,4.299780011177063,4.291549960772197,4.283330003420512,4.275140007336934,4.266950011253357,4.258790016174316,4.250639915466309,4.242500027020772,4.234380046526591,4.226279973983765,4.218189994494121,4.210120002428691,4.202059984207153,4.19401999314626,4.186000029246013,4.177989959716797,4.169990062713623,4.162009954452515,4.1540500322977705,4.146100004514058,4.138159990310669,4.130239963531494,4.122340003649394,4.114449938138326,4.106579979260762,4.098720033963521,4.090879996617635,4.083050012588501,4.075240095456441,4.067439993222554,4.059659997622172,4.051890015602112,4.044140060742696,4.036399920781453,4.028669993082683,4.02481997013092};
        CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192413330078,514.5848337809244,508.8199412027995,504.2629089355469,499.6559143066406,495.013910929362,490.35090891520184,485.67591094970703,480.99790954589844,476.32391357421875,471.6609115600586,467.01491292317706,462.3879114786784,457.7859115600586,453.2089157104492,448.6629155476888,444.14691162109375,439.6639175415039,435.2149175008138,430.80191802978516,426.42391713460285,422.08391825358075,417.77991739908856,413.51392364501953,409.2859242757161,405.0959192911784,400.9439214070638,396.8299280802409,392.75392659505206,388.7169189453125,384.7169240315755,380.7549285888672,376.8299280802409,372.9429244995117,369.09393310546875,365.2809244791667,361.5049311319987,357.7659327189128,354.0639343261719,350.39692942301434,346.76693471272785,343.1729329427083,339.6129379272461,336.0889383951823,332.59993743896484,329.1459376017253,325.72593688964844,322.33993275960285,318.9879328409831,315.66894276936847,312.3839365641276,309.1319402058919,305.9119415283203,302.7249399820964,299.5699412027995,296.44793701171875,293.35694122314453,290.2969436645508,287.2679392496745,284.2699483235677,281.3029479980469,278.3659439086914,275.45995076497394,272.5829442342122,269.7349497477214,266.91695404052734,264.1279525756836,261.36795298258465,258.63595326741535,255.93295033772787,253.2569465637207,250.60894902547201,247.98895136515299,245.39595158894858,242.82995223999023,240.29095458984375,237.77895228068033,235.29195276896158,232.83295567830405,230.3979517618815,227.98995463053384,225.60695521036783,223.24995803833008,220.9169553120931,218.60895665486655,216.32595698038736,214.06695683797201,211.8329594930013,209.62196095784506,207.43496068318686,205.27196248372397,203.1309611002604,201.01396052042642,198.91896184285483,196.8469607035319,194.79596074422201,192.76796086629233,190.7609634399414,188.77596155802408,186.81196467081705,184.86896514892578,182.94696553548178,181.0449651082357,179.16296768188477,177.3019650777181,175.45996602376303,173.63796361287436,171.83596674601236,170.05296579996744,168.28896967569986,166.54297002156576,164.81596883138022,163.10796991984049,161.41796747843424,159.74596786499023,158.09096908569336,156.45496877034506,154.8349698384603,153.23296991984049,151.64797083536783,150.07997131347656,148.52897008260092,146.99397150675455,145.4749755859375,143.97297032674155,142.48597208658853,141.01597340901694,139.5599733988444,138.12097295125326,136.69697443644205,135.2869758605957,133.89297358194986,132.51397196451822,131.1489741007487,129.79797490437826,128.46197636922201,127.13997459411621,125.83197593688965,124.53797658284505,123.25697580973308,121.98997624715169,120.73597653706868,119.49497604370117,118.26697667439778,117.05197715759277,115.84997812906902,114.66097768147786,113.48397763570149,112.31897926330566,111.1659787495931,110.02597745259602,108.89697901407878,107.77997970581055,106.67498016357422,105.58097902933757,104.49798075358073,103.4269790649414,102.36697959899902,101.31798108418782,100.2799809773763,99.25228055318196,98.23548189798991,97.2290808359782,96.23318099975586,95.2474816640218,94.27198092142741,93.30658276875813,92.35108184814453,91.40538279215495,90.46948305765788,89.54318173726399,88.62638282775879,87.7189826965332,86.82088279724121,85.93208440144856,85.05228360493977,84.1815840403239,83.31978352864583,82.46678479512532,81.6224848429362,80.7867857615153,79.95968437194824,79.14108467102051,78.33078511555989,77.5288855234782,76.73508580525716,75.94948450724284,75.17188707987468,74.40228525797527,73.6404857635498,72.88648732503255,72.14028549194336,71.40168571472168,70.67068672180176,69.9471861521403,69.23098627726237,68.52218691507976,67.82068761189778,67.12638727823894,66.43908818562825,65.75898742675781,65.08568827311198,64.41938654581706,63.75998751322428,63.10718790690104,62.46118768056234,61.82178815205892,61.18888759613037,60.562588691711426,59.942588806152344,59.32898871103922,58.72168890635172,58.12068843841553,57.52578926086426,56.93698914845785,56.35418891906738,55.77738952636719,55.206488927205406,54.64148966471354,54.08229001363119,53.52878952026367,52.98099009195963,52.43879000345866,51.90209039052328,51.37099011739095,50.845290184020996,50.32499027252197,49.81009070078532,49.30039087931315,48.79599062601725,48.29669062296549,47.80249055226644,47.313490867614746,46.82939084370931,46.35029125213623,45.87609100341797,45.40679136912028,44.9422918955485,44.48259162902832,44.02759106953939,43.57719135284424,43.1314910252889,42.69039217631022,42.25379180908203,41.821691830952965,41.393991788228355,40.970691998799644,40.55179214477539,40.13709259033203,39.726792335510254,39.32059224446615,38.91859277089437,38.52069250742594,38.12689208984375,37.73709265391032,37.35129356384277,36.96949291229248,36.591593424479164,36.2175931930542,35.84739303588867,35.48099327087402,35.118393898010254,34.759393056233726,34.40419356028239,34.05259354909261,33.70459397633871,33.36009375254313,33.01919364929199,32.681793530782066,32.34779357910156,32.01729393005371,31.690094153086346,31.366294225056965,31.045794010162354,30.728594144185383,30.41469446818034,30.103894233703613,29.79629421234131,29.491893927256267,29.19059403737386,28.89239438374837,28.59719451268514,28.305094401041668,28.015894730885822,27.7296945254008,27.446494579315186,27.166094938913982,26.88859494527181,26.613894780476887,26.342095216115315,26.072994867960613,25.806695143381756,25.54309542973836,25.28219525019328,25.023895263671875,24.768395105997723,24.515395164489746,24.26499541600545,24.017195224761963,23.771895090738933,23.529095490773518,23.288795630137127,23.050995508829754,22.815595626831055,22.582595825195312,22.351895650227863,22.123695850372314,21.897795995076496,21.674095789591473,21.45279582341512,21.233695824940998,21.01689624786377,20.80229600270589,20.58989604314168,20.379696210225422,20.17159620920817,19.965596199035645,19.761696497599285,19.559996287027996,19.360196272532146,19.162596543629963,18.966896216074627,18.773296515146892,18.58159637451172,18.39189640680949,18.20409631729126,18.018296718597412,17.834296703338623,17.652196407318115,17.471996625264484,17.29369656244914,17.117096583048504,16.942396481831867,16.769396781921387,16.598196983337402,16.428797086079914,16.261096636454266,16.095096747080486,15.93079694112142,15.768196900685629,15.607196966807047,15.44789711634318,15.290197054545084,15.13409717877706,14.979697227478027,14.826797167460123,14.675397078196207,14.52559725443522,14.377397219340006,14.230597257614136,14.085397481918335,13.941597143809,13.799297332763672,13.658497412999472,13.519097407658895,13.381097316741943,13.244597514470419,13.109397490819296,12.975597620010376,12.843197584152222,12.712097565333048,12.582397619883219,12.453997611999512,12.326897621154785,12.20109756787618,12.076597690582275,11.95329769452413,11.831397692362467,11.71059775352478,11.591097831726074,11.47289768854777,11.355797926584879,11.239897807439169,11.125197966893515,11.011697928110758,10.899298032124838,10.788097858428955,10.67809796333313,10.569098075230917,10.46129822731018,10.354497989018759,10.248897790908813,10.144298235575357,10.040798107782999,9.938368082046509,9.836968183517456,9.736608266830444,9.63726806640625,9.538948138554892,9.441628138224283,9.345308224360148,9.24996829032898,9.155598402023315,9.062198321024576,8.969748338063559,8.87824813524882,8.787678241729736,8.698028405507406,8.609298388163248,8.521478414535522,8.434548377990723,8.34850843747457,8.26334834098816,8.179058392842611,8.095628420511881,8.01304841041565,7.9313085079193115,7.850408474604289,7.7703384558359785,7.691078503926595,7.612628539403279,7.53497854868571,7.458128611246745,7.382058580716451,7.306768576304118,7.23223861058553,7.158478577931722,7.085468610127767,7.0131986538569135,6.941668669382731,6.87087865670522,6.800798734029134,6.731438795725505,6.66278874874115,6.594838738441467,6.527588725090027,6.461018800735474,6.395128806432088,6.329908847808838,6.265358765920003,6.201458732287089,6.138218839963277,6.075628956158956,6.013668855031331,5.952348828315735,5.891648928324382,5.8315688371658325,5.772108872731526,5.7132488489151,5.654988964398702,5.5973289012908936,5.540258963902791,5.483758966128032,5.427848895390828,5.3724989493687945,5.3177289962768555,5.263499021530151,5.2098389863967896,5.156718969345093,5.104139010111491,5.052099068959554,5.000589052836101,4.949609041213989,4.8991390864054365,4.849199096361796,4.799759030342102,4.750819126764934,4.702389081319173,4.654449105262756,4.606999198595683,4.560029149055481,4.51353907585144,4.4675291776657104,4.4219891627629595,4.376909216245015,4.332289179166158,4.2881191571553545,4.244409203529358,4.201139211654663,4.158319274584453,4.1159292459487915,4.07396924495697,4.032449205716451,3.991339306036631,3.9506592750549316,3.910389264424642,3.8705292542775473,3.8310793042182922,3.7920292615890503,3.753379245599111,3.7151193022727966,3.677249312400818,3.6397693157196045,3.6026692589124045,3.5659497380256653,3.54768959681193};
        //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.80513699849447,40.027069091796875,40.50437513987223,34.26265366872152,33.29267183939616,32.36515585581461,31.432478586832683,30.0959374109904,28.30821943283081,26.481454849243164,24.651962280273438,22.82218074798584,20.992127577463787,19.16272719701131,17.33194096883138,15.50402045249939,13.670034408569336,12.518940528233847,12.124982833862305,11.797574281692505,11.474451462427774,11.152015209197998,10.829583644866943,10.507123311360678,10.184640963872274,9.862331708272299,9.539416869481405,9.29267962773641,9.130319913228353,8.97546645005544,8.821026682853699,8.666691700617472,8.512340545654297,8.35801076889038,8.203619639078775,8.049408157666525,7.894687175750732,7.807871540387471,7.796269814173381,7.791425506273906,7.786903500556946,7.7825034856796265,7.778075337409973,7.773658712704976,7.769237319628398,7.76481846968333,7.7603960037231445,7.756408015886943,7.75288466612498,7.7493956089019775,7.745914936065674,7.742435336112976,7.7389551003774,7.735475222269694,7.731995066006978,7.728515704472859,7.725042859713237,7.722171306610107,7.7199861605962115,7.717857678731282,7.715736707051595,7.713617205619812,7.711496909459432,7.7093772093455,7.70725663503011,7.705138882001241,7.703008770942688,7.7034183740615845,7.706657965977986,7.710145115852356,7.713640411694844,7.717143336931865,7.720651308695476,7.724152684211731,7.7276517152786255,7.7311623096466064,7.734662055969238,7.7381623188654585,7.741642475128174,7.7451322476069135,7.748612562815349,7.752092321713765,7.755582372347514,7.75906240940094,7.762542486190796,7.766026735305786,7.769523620605469,7.769469658533732,7.765427589416504,7.761057337125142,7.756657520929973,7.752257625261943,7.747847596804301,7.743447502454122,7.739047527313232,7.734637538592021,7.7302374839782715,7.725837349891663,7.721437692642212,7.717027584711711,7.712627371152242,7.708227634429932,7.7038174867630005,7.699417432149251,7.695017536481221,7.690617561340332,7.686207572619121,7.681807438532512,7.677407582600911,7.67299763361613,7.66859753926595,7.664197564125061,7.659797350565593,7.655397693316142,7.6509876648585005,7.646587332089742,7.642187595367432,7.63777756690979,7.633377512296041,7.628977457682292,7.624577681223552,7.62016749382019,7.615767439206441,7.6113676230112715,7.606957674026489,7.602557420730591,7.598157485326131,7.593757510185242,7.58934760093689,7.584947466850281,7.580547610918681,7.576137542724609,7.57173752784729,7.567337473233541,7.562937617301941,7.55852750937144,7.55412745475769,7.549727598826091,7.5453176101048784,7.54091747601827,7.5365175406138105,7.532117605209351,7.527707656224568,7.5233074426651,7.5189075867335005,7.514507571856181,7.510097702344258,7.50569752852122,7.50129755338033,7.496887644131978,7.49248743057251,7.488087455431621,7.483687559763591,7.479277610778809,7.4748774766922,7.47047773996989,7.466067632039388,7.46166745821635,7.45726756254832,7.4528675476710005,7.448457717895508,7.444057544072469,7.439657529195149,7.43525763352712,7.430847644805908,7.426447470982869,7.4220476150512695,7.41764760017395,7.4132377703984575,7.40883747736613,7.404437621434529,7.400027712186177,7.39562741915385,7.391227602958679,7.38682754834493,7.382417798042297,7.378017505009969,7.373617808024089,7.369207660357158,7.3648074467976885,7.360407590866089,7.356007536252339,7.351597785949707,7.347197373708089,7.342797636985779,7.338387568791707,7.3339875141779585,7.329587539037068,7.325187603632609,7.3207777341206866,7.316377401351929,7.311977744102478,7.307567596435547,7.303167502085368,7.298767447471619,7.294367710749309,7.289957761764526,7.285557468732198,7.281157732009888,7.276747624079387,7.272347609202067,7.267947554588318,7.263547698656718,7.259137709935506,7.2547374566396075,7.250337719917297,7.245927611986796,7.241527557373047,7.237127582232158,7.232727726300557,7.228317618370056,7.223917643229167,7.2195175886154175,7.2151176532109575,7.210707585016887,7.206307609875997,7.201907555262248,7.197507659594218,7.193097750345866,7.188697497049968,7.184297601381938,7.179887612660726,7.175487637519836,7.171087543169658,7.166687687238057,7.162277658780416,7.157877643903096,7.153477589289348,7.149077574412028,7.144667665163676,7.140267531077067,7.135867675145467,7.131457527478536,7.127057949701945,7.122656385103862,7.118260622024536,7.113839427630107,7.111421902974446,7.111206650733948,7.111199975013733,7.111198504765828,7.111199061075847,7.111198862393697,7.111198902130127,7.111198941866557,7.111198941866557,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
        CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.6675059000651045,6.884205182393392,6.581218163172404,6.571951707204183,6.562196334203084,6.552963574727376,6.54433027903239,6.5389485359191895,6.53671932220459,6.534229516983032,6.530659635861714,6.525879939397176,6.5199499527613325,6.51300032933553,6.505109906196594,6.49639093875885,6.486928264300029,6.482374350229899,6.4847447872161865,6.489404479662578,6.49498434861501,6.50106422106425,6.507504105567932,6.514244000116984,6.521243890126546,6.528473734855652,6.535923798878987,6.543163975079854,6.54996399084727,6.556613922119141,6.5631738503774,6.569693843523662,6.576173822085063,6.582623680432637,6.5890538692474365,6.595463395118713,6.601864616076152,6.605916062990825,6.60688583056132,6.60688579082489,6.606555779774983,6.606075684229533,6.605515638987224,6.604885578155518,6.604215502738953,6.603495438893636,6.602765242258708,6.602304935455322,6.602184891700745,6.6021348635355634,6.602064808209737,6.601974805196126,6.601834694544475,6.601674675941467,6.601484576861064,6.601274490356445,6.6010446945826216,6.60039484500885,6.599174737930298,6.597714742024739,6.596124728520711,6.594444712003072,6.592694640159607,6.59089457988739,6.589054505030314,6.587184508641561,6.5852740208307905,6.58431347211202,6.584573586781819,6.585113684336345,6.58565366268158,6.586113731066386,6.586493690808614,6.5868037939071655,6.587043801943461,6.587233901023865,6.5873933633168535,6.588802615801494,6.59185266494751,6.595422665278117,6.599152723948161,6.6029428243637085,6.606782793998718,6.610642949740092,6.614542841911316,6.618472615877788,6.6224541664123535,6.622497161229451,6.617376685142517,6.610726634661357,6.603656490643819,6.596506436665853,6.58936619758606,6.582266092300415,6.575216015179952,6.568195899327596,6.5612157980601,6.55426565806071,6.547355651855469,6.540465474128723,6.533615469932556,6.526775320370992,6.519975185394287,6.513185103734334,6.5064250230789185,6.499684890111287,6.492954810460408,6.4862446784973145,6.479554573694865,6.472874482472737,6.466204404830933,6.459554354349772,6.452914198239644,6.446284135182698,6.439674139022827,6.433063983917236,6.426463882128398,6.419873833656311,6.413293679555257,6.406723578770955,6.400163610776265,6.393603404362996,6.387063304583232,6.380523204803467,6.373983184496562,6.36745301882426,6.360932985941569,6.354412794113159,6.347892721494039,6.341362635294597,6.334812521934509,6.328242460886638,6.321642438570659,6.3150023221969604,6.308342297871907,6.301642139752706,6.294912099838257,6.288142005602519,6.281341989835103,6.2745018402735395,6.267621874809265,6.260701696077983,6.2537415822347,6.246751507123311,6.239711403846741,6.2326314051946,6.225511391957601,6.21834123134613,6.211141188939412,6.203901092211406,6.1966110070546465,6.1892809470494585,6.181920846303304,6.174510836601257,6.167060732841492,6.159570654233296,6.152040521303813,6.1444705327351885,6.1368604103724165,6.129220366477966,6.121530254681905,6.113810102144877,6.10605001449585,6.098250031471252,6.090409954388936,6.082529902458191,6.074609796206157,6.066649675369263,6.058659593264262,6.050629576047261,6.042559464772542,6.034449418385823,6.026309331258138,6.018119255701701,6.009899179140727,6.001639048258464,5.993349075317383,5.985008875528972,5.976648807525635,5.968258738517761,5.959858655929565,5.95145857334137,5.943048437436421,5.9346383810043335,5.926218350728353,5.917798201243083,5.909388105074565,5.900967995325725,5.892547965049744,5.884137868881226,5.875727732976277,5.8673176765441895,5.858907580375671,5.850497444470723,5.842097361882527,5.833687265714009,5.825287143389384,5.816887140274048,5.808497031529744,5.800096909205119,5.791706879933675,5.783316691716512,5.7749366362889605,5.766556580861409,5.758166511853536,5.749796350797017,5.741416255633037,5.733046134312947,5.724676092465718,5.716306090354919,5.707935810089111,5.699575821558635,5.691215634346008,5.682855645815532,5.674505511919658,5.666155457496643,5.657805363337199,5.649455308914185,5.6411051750183105,5.632765054702759,5.624425013860066,5.616084853808085,5.607754786809285,5.599414785703023,5.591084559758504,5.582754492759705,5.5744344393412275,5.566104332605998,5.557784199714661,5.549464066823323,5.541144092877706,5.532823920249939,5.524513840675354,5.516203800837199,5.5078935623168945,5.499583880106608,5.49128258228302,5.485401034355164,5.482681155204773,5.48098103205363,5.479661027590434,5.478501081466675,5.477450966835022,5.476480960845947,5.475590904553731,5.474760890007019,5.4739909172058105,5.473270813624064,5.472610870997111,5.47200075785319,5.471430778503418,5.470910747845967,5.4704307317733765,5.4699907302856445,5.469580769538879,5.469200770060222,5.468860745429993,5.4685507615407305,5.468260685602824,5.468000650405884,5.467760642369588,5.467540701230367,5.467340707778931,5.467160662015279,5.467000643412272,5.4668506781260175,5.4667205810546875,5.4666106303532915,5.4665006796518965,5.4664106369018555,5.466330607732137,5.466260671615601,5.466200590133667,5.466140627861023,5.466100613276164,5.466060598691304,5.466030677159627,5.466010610262553,5.465990503629048,5.465980569521586,5.465980648994446,5.465970595677693,5.465980569521586,5.465980569521586,5.4659905433654785,5.466010570526123,5.466030597686768,5.466050585110982,5.466070652008057,5.466090599695842,5.466120560963948,5.466150601704915,5.466180602709453,5.466220657030742,5.466250658035278,5.466290593147278,5.466330647468567,5.466360608736674,5.466400583585103,5.466450572013855,5.466490586598714,5.4665305614471436,5.466570655504863,5.466620643933614,5.466660658518474,5.466710646947225,5.466750542322795,5.466800610224406,5.466850558916728,5.4668904940287275,5.466940561930339,5.466990669568379,5.467040618260701,5.467080553372701,5.467130581537883,5.467180609703064,5.467230637868245,5.467280586560567,5.467320521672566,5.467370629310608,5.46742061773936,5.467470606168111,5.467520594596863,5.467570622762044,5.4676105578740435,5.467660586039226,5.467710574467977,5.467760602633159,5.46781059106191,5.4678506056467695,5.4679005940755205,5.4679505825042725,5.468000650405884,5.468040585517883,5.468090573946635,5.4681406418482466,5.468180576960246,5.468230605125427,5.468280593554179,5.468320647875468,5.46837055683136,5.468420664469401,5.468460559844971,5.468510588010152,5.468560616175334,5.468600591023763,5.4686505397160845,5.468690514564514,5.4687405824661255,5.4687806367874146,5.4688306252161665,5.468870480855306,5.468920628229777,5.468960563341777,5.469010591506958,5.469050645828247,5.469100594520569,5.469140688578288,5.469180623690288,5.469230572382609,5.469270586967468,5.46932065486908,5.469360629717509,5.469400564829509,5.46945063273112,5.46949056784312,5.469530542691548,5.46958057085673,5.469620585441589,5.469660600026448,5.469700614611308,5.469750603040059,5.469790577888489,5.469830632209778,5.4698706070582075,5.4699205954869585,5.469960570335388,5.470000545183818,5.470040599505107,5.470080614089966,5.470130602518718,5.4701705773671465,5.470210631688436,5.470250606536865,5.470290541648865,5.470330595970154,5.470370650291443,5.470420638720195,5.470460613568624,5.470500628153483,5.470540603001912,5.470580617586772,5.470620592435201,5.4706605275472,5.470700581868489,5.470740596453349,5.470780650774638,5.470820585886638,5.470860600471497,5.4709006150563555,5.470940510431926,5.470980604489644,5.471020619074504,5.471060554186503,5.471100568771362,5.471140583356221,5.471180558204651,5.47122057278951,5.471260627110799,5.471300641695659,5.471340576807658,5.471380631128947,5.471420645713806,5.471460580825806,5.471500595410665,5.471540609995524,5.471580584843953,5.471620599428813,5.4716605345408125,5.471700549125671,5.47174056371053,5.471770644187927,5.471810579299927,5.471850514411926,5.4718906084696455,5.471930623054504,5.471970597902934,5.472010652224223,5.4720505475997925,5.472080588340759,5.472120563189189,5.472160577774048,5.4722005526224775,5.472240527470906,5.4722806215286255,5.472320596377055,5.472350517908732,5.472390532493591,5.47243058681488,5.472470601399739,5.472510536511739,5.472540616989136,5.472580512364705,5.472620606422424,5.472660621007283,5.472700675328572,5.47273067633311,5.472770690917969,5.472810626029968,5.472850561141968,5.472880562146504,5.4729206164677935,5.472960591316223,5.473000566164653,5.4730305671691895,5.473070581754048,5.473110556602478,5.473140557607015,5.473180651664734,5.473220666249593,5.473260601361592,5.47329052289327,5.473330616950989,5.473370631535848,5.473400592803955,5.473440607388814,5.473480621973674,5.473510543505351,5.473550637563069,5.473590652147929,5.473620533943176,5.473660667737325,5.473700602849324,5.473730564117432,5.473770658175151,5.473800579706828,5.473840634028117,5.473880569140117,5.4739106098810835,5.473950505256653,5.473980665206909,5.4740205605824785,5.474060575167338,5.474090615908305,5.474130590756734,5.474140644073486};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219187219937644,2.603925089041392,2.036609172821045,1.6560320556163788,1.3475098113218944,1.0969156275192897,0.8935603648424149,0.7283865114053091,0.5942771732807159,0.4852093706528346,0.3964308351278305,0.3240884393453598,0.26509066050251323,0.21693705394864082,0.17755509416262308,0.14532499263683954,0.11898915593822797,0.09745924361050129,0.07986157387495041,0.06546470212439696,0.05369516275823116,0.04405311526109775,0.03617150460680326,0.029702893768747646,0.024415936321020126,0.02006961281100909,0.016515289433300495,0.013590684160590172,0.01119531411677599,0.00922370965903004,0.00760556369399031,0.006273514552352329,0.005178143658364813,0.004276039234052102,0.0035330897856814167,0.002920737761693696,0.0024158104012409845,0.001999045955017209,0.0016547235815475385,0.0013701420781823497,0.0011348753081013758,0.0009402778911559532,0.0007793282663139204,0.000646074942778796,0.0005358455382520333,0.0004444624646566808,0.0003688881818864805,0.0003061337362548026,0.0002542485187101799,0.0002111066205543466,0.00017542726103177605,0.00014574651504517533,0.00012117223135040452,5.346995203581173e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8628336588541,563.0202382405599,557.0959116617838,556.9292805989584,555.6558278401693,554.0758005777994,552.4436899820963,550.9550832112631,549.5851287841797,548.1325124104818,546.5458984375,544.8193359375,542.9626261393229,540.9891001383463,538.9081013997396,536.7339528401693,534.4728698730469,533.1106313069662,533.0212758382162,533.3826700846354,533.9193115234375,534.5381469726562,535.2060292561849,535.9099426269531,536.6438598632812,537.4037933349609,538.1877288818359,538.9906870524088,539.7996826171875,540.6096852620443,541.4166920979818,542.220703125,543.0227101643881,543.8217112223307,544.6197408040365,545.4156646728516,546.2128702799479,546.8436177571615,547.247080485026,547.5661773681641,547.853261311849,548.1232757568359,548.3852945963541,548.6413116455078,548.8923288981119,549.1383412679037,549.38330078125,549.6571858723959,549.9691111246744,550.2901153564453,550.6121114095052,550.9321339925131,551.2491251627604,551.5631256103516,551.8741404215494,552.1841430664062,552.4921569824219,552.7971649169922,553.0931955973307,553.3812154134115,553.6592559814453,553.9292653401693,554.1932830810547,554.4522959391276,554.7073109944662,554.9583129882812,555.2063852945963,555.3876800537109,555.4768778483073,555.52294921875,555.5450185139974,555.550059000651,555.5440826416016,555.5281016031901,555.5051320393881,555.4751586914062,555.4411163330078,555.4588623046875,555.5477142333984,555.6627095540365,555.7876739501953,555.9176686604818,556.0516560872396,556.1886444091797,556.3286336263021,556.4725494384766,556.6217702229818,556.5627950032552,556.2202606201172,555.7803904215494,555.3124287923177,554.8384297688802,554.3664347330729,553.8974202473959,553.4343973795573,552.9753875732422,552.5203704833984,552.0693664550781,551.6213582356771,551.1773427327474,550.7363332112631,550.298329671224,549.8623199462891,549.4293060302734,548.9982961018881,548.5702972412109,548.144287109375,547.7192891438802,547.2962799072266,546.8752797444662,546.4552866617838,546.0372670491537,545.6202697753906,545.2052612304688,544.7912546793619,544.3782501220703,543.9662526448568,543.5552469889323,543.146250406901,542.7372436523438,542.3292490641276,541.9222361246744,541.5162353515625,541.1102396647135,540.7052256266276,540.3022308349609,539.8982238769531,539.4962259928385,539.0932210286459,538.6892293294271,538.2842305501302,537.8752492268881,537.4642537434896,537.0492706298828,536.6312713623047,536.2092895507812,535.7843068440756,535.3543090820312,534.9213205973307,534.4833374023438,534.0423431396484,533.5963541666666,533.1453704833984,532.6903788248698,532.2313995361328,531.7674153645834,531.2994181315104,530.8264465332031,530.3484547932943,529.8664499918619,529.3794708251953,528.8884938557943,528.3925120035807,527.8915201822916,527.3865305582682,526.8765462239584,526.3625539143881,525.8445688883463,525.3215840657552,524.7945988972982,524.2636082967123,523.7276153564453,523.1876373291016,522.6436462402344,522.0946578979492,521.5416768391927,520.9836883544922,520.4216868082682,519.855712890625,519.2847290039062,518.7097345987955,518.1307500203451,517.5477574666342,516.9597803751627,516.3677851359049,515.7718022664388,515.1708119710287,514.5658264160156,513.9578297932943,513.3478317260742,512.7348454793295,512.1218414306641,511.5078430175781,510.89284261067706,510.27784729003906,509.662846883138,509.047846476237,508.43284861246747,507.8178405761719,507.20284779866535,506.5878372192383,505.97284444173175,505.35784912109375,504.7428436279297,504.12884012858075,503.5148417154948,502.90084584554035,502.2868398030599,501.67284393310547,501.0598424275716,500.4458414713542,499.8328348795573,499.2208429972331,498.6078364054362,497.99583435058594,497.3828379313151,496.7708282470703,496.1598358154297,495.54783121744794,494.93683369954425,494.3258336385091,493.71483357747394,493.1038335164388,492.4938329060872,491.8838297526042,491.2738291422526,490.66383361816406,490.05383046468097,489.44482167561847,488.83582814534503,488.22682189941406,487.6178283691406,487.0088297526042,486.40081787109375,485.7928237915039,485.18482208251953,484.57682545979816,483.9688262939453,483.36082458496094,482.75381724039715,482.1468149820964,481.5398203531901,480.93281809488934,480.32582092285156,479.7198028564453,479.1128616333008,478.50767771402997,478.0470377604167,477.78562418619794,477.6015218098958,477.45044962565106,477.3174133300781,477.19637807210285,477.0853551228841,476.9823303222656,476.8873112996419,476.7982915242513,476.7162780761719,476.64026133219403,476.5702387491862,476.50522867838544,476.4452133178711,476.38920338948566,476.3381856282552,476.29117584228516,476.24816131591797,476.2091573079427,476.1731440226237,476.1391372680664,476.10913340250653,476.0811233520508,476.0561116536458,476.03311411539715,476.0131022135417,475.9940948486328,475.97708892822266,475.9620895385742,475.94808197021484,475.9360758463542,475.9250742594401,475.9160690307617,475.90806833902997,475.9010645548503,475.8940658569336,475.88905080159503,475.88505299886066,475.8810526529948,475.8780568440755,475.87604268391925,475.8750483194987,475.8740488688151,475.8740412394206,475.8740463256836,475.8750406901042,475.87604268391925,475.87703704833984,475.87904103597003,475.88103739420575,475.88404083251953,475.8860397338867,475.8890329996745,475.8930358886719,475.89602915445965,475.90003458658856,475.9040349324544,475.9080301920573,475.9120381673177,475.91603088378906,475.92102813720703,475.92502848307294,475.9300282796224,475.9350331624349,475.9400278727214,475.9450276692708,475.95003000895184,475.9550272623698,475.9600296020508,475.9650293986003,475.97003173828125,475.9750239054362,475.9810333251953,475.9860331217448,475.9910252888997,475.99703216552734,476.0020268758138,476.0080286661784,476.0130310058594,476.0180257161458,476.0240249633789,476.0290298461914,476.0350290934245,476.04002888997394,476.04502868652344,476.05102793375653,476.05602773030597,476.06202697753906,476.06703186035156,476.072026570638,476.0780283610026,476.0830256144206,476.08902740478516,476.09402720133465,476.0990295410156,476.10502370198566,476.1100311279297,476.1150309244792,476.12002817789715,476.1260248819987,476.1310323079427,476.1360270182292,476.14102935791016,476.14702860514325,476.1520284016927,476.1570281982422,476.16203053792316,476.1670277913411,476.1720250447591,476.1780293782552,476.1830317179362,476.18802642822266,476.1930287679036,476.19803110758465,476.2030283610026,476.2080307006836,476.21302795410156,476.21803283691406,476.2230275472005,476.22802480061847,476.2330271402995,476.23802947998047,476.24302927652997,476.2480290730794,476.2530288696289,476.2570317586263,476.2620264689128,476.2670313517253,476.27202860514325,476.27703348795575,476.2820281982422,476.28603108723956,476.29102834065753,476.29603322347003,476.301025390625,476.30603281656903,476.3100280761719,476.3150278727214,476.32002512613934,476.3250249226888,476.3290303548177,476.3340250651042,476.3390299479167,476.34303029378253,476.34803009033203,476.353032430013,476.3570276896159,476.3620249430339,476.3670349121094,476.37102762858075,476.3760274251302,476.3800303141276,476.3850275675456,476.39003499348956,476.39402262369794,476.39902750651044,476.4030303955078,476.4080276489258,476.4130325317383,476.4170277913411,476.4220377604167,476.426030476888,476.4310353597005,476.43502553304035,476.4400329589844,476.44403076171875,476.44903564453125,476.4530283610026,476.4580332438151,476.46202850341797,476.467035929362,476.4710286458333,476.47603607177734,476.48003641764325,476.48402913411456,476.4890314737956,476.49302927652997,476.49803161621094,476.50203196207684,476.5060348510742,476.5110321044922,476.5150324503581,476.52002716064453,476.5240300496419,476.5280303955078,476.5330276489258,476.5370279947917,476.5420277913411,476.54603322347003,476.5500259399414,476.5550282796224,476.5590337117513,476.5630289713542,476.5680287679036,476.57203165690106,476.57602945963544,476.5810292561849,476.5850372314453,476.58903249104816,476.59303029378253,476.5980275472005,476.6020329793294,476.6060333251953,476.6110305786133,476.6150360107422,476.61903381347656,476.62303161621094,476.62803141276044,476.6320292154948,476.6360346476237,476.64003499348956,476.64402770996094,476.6490300496419,476.6530303955078,476.6570307413737,476.66103108723956,476.6660334269206,476.67003377278644,476.6740315755208,476.6780319213867,476.6820322672526,476.686030069987,476.69102478027344,476.6950327555339,476.69903055826825,476.7030309041341,476.70703125,476.7110315958659,476.71503194173175,476.7200291951497,476.7240269978841,476.72802988688153,476.7320302327474,476.7360331217448,476.74003346761066,476.74402872721356,476.74803161621094,476.7520345052083,476.7560323079427,476.76003011067706,476.76402791341144,476.7680308024089,476.77203369140625,476.77603403727215,476.780034383138,476.7840321858724,476.7880325317383,476.7900390625};
        //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.43590792020162,9.763129870096842,10.082971413930258,9.098507642745972,9.042675256729126,8.992238839467367,8.941489537556967,8.894886016845703,8.852614323298136,8.81070613861084,8.768835385640463,8.726956049601236,8.68508505821228,8.643216689427694,8.601333141326904,8.559470176696777,8.517588376998901,8.49211843808492,8.484498580296835,8.47838274637858,8.472371419270834,8.466371774673462,8.460381587346395,8.454381465911865,8.448391675949097,8.442391236623129,8.436402002970377,8.429166634877523,8.420578797658285,8.41187850634257,8.403168598810831,8.394468466440836,8.385758797327677,8.37704849243164,8.368338743845621,8.35963805516561,8.350929816563925,8.338802218437195,8.322959184646606,8.30680763721466,8.290638248125711,8.274458010991415,8.258278171221415,8.242098093032837,8.22591801484426,8.209748188654581,8.193567554155985,8.178692777951559,8.165239969889322,8.15191082159678,8.138580401738485,8.125260591506958,8.11193041006724,8.098610440889994,8.085290511449179,8.071960608164469,8.058640281359354,8.045748631159464,8.033337791760763,8.020967960357666,8.008587876955668,7.996218005816142,7.983847975730896,7.9714780648549395,7.959107796351115,7.946738243103027,7.934356490770976,7.928242325782776,7.928929924964905,7.930193781852722,7.931501070658366,7.93280287583669,7.934111674626668,7.935422301292419,7.936731855074565,7.938042362531026,7.939351439476013,7.944287021954854,7.953180193901062,7.962412317593892,7.971660733222961,7.980921824773152,7.990170915921529,7.999431649843852,8.008681297302246,8.017938057581583,8.02719509601593,8.02428380648295,8.008131305376688,7.990870753924052,7.973520914713542,7.956170956293742,7.93881090482076,7.921460906664531,7.904100775718689,7.886750896771749,7.869390964508057,7.852040847142537,7.8346807559331255,7.817330956459045,7.799970825513204,7.782620867093404,7.765260775883992,7.747910817464192,7.73055084546407,7.713200767834981,7.6958407163619995,7.67849063873291,7.6611307462056475,7.643780787785848,7.626420656840007,7.609070738156636,7.591710766156514,7.574360609054565,7.557000756263733,7.539640585581462,7.5222907066345215,7.50493057568868,7.48758061726888,7.470220565795898,7.452870527903239,7.435510555903117,7.418160637219747,7.400800585746765,7.383450587590535,7.366090496381124,7.348740537961324,7.331380526224772,7.3140305280685425,7.29667051633199,7.279320398966472,7.261960546175639,7.24461046854655,7.227250456809998,7.209900418917338,7.192540407180786,7.175190409024556,7.157830437024434,7.140480359395345,7.123120387395223,7.105760415395101,7.088410377502441,7.07105032602946,7.05370032787323,7.036340316136678,7.0189902782440186,7.0016303062438965,6.984280268351237,6.966920216878255,6.949570218722026,6.932210246721904,6.914860208829244,6.897500236829122,6.880150198936462,6.86279018719991,6.845440149307251,6.828080256779988,6.810730179150899,6.793370167414348,6.776009996732076,6.758660078048706,6.741300106048584,6.7239499886830645,6.706600109736125,6.689240097999573,6.671880046526591,6.654530048370361,6.637170036633809,6.61981999874115,6.602459987004598,6.585109988848369,6.567750056584676,6.5503999789555865,6.533040006955464,6.515689929326375,6.498330036799113,6.480979879697164,6.463619947433472,6.446269830067952,6.42890993754069,6.411559859911601,6.394199967384338,6.37684981028239,6.359489917755127,6.342129786809285,6.324779907862346,6.307419776916504,6.290069778760274,6.272709767023723,6.255359808603923,6.237999677658081,6.220649719238281,6.203289747238159,6.185939788818359,6.168579697608948,6.151229699452718,6.1338696877161665,6.1165196895599365,6.099159638086955,6.081809600194295,6.064449588457744,6.047099630037944,6.029739618301392,6.012389620145162,5.99502952893575,5.97767957051595,5.9603196779886884,5.9429694811503095,5.925609548886617,5.908249497413635,5.890899578730266,5.873539487520854,5.856189449628194,5.838829477628072,5.821479479471843,5.804119388262431,5.786769469579061,5.769409418106079,5.752059419949849,5.734699368476868,5.717349370320638,5.699989438056946,5.682639400164287,5.665279348691304,5.647929310798645,5.630569299062093,5.613219380378723,5.595859249432881,5.578509291013082,5.5611493190129595,5.5437992811203,5.526439309120178,5.509089112281799,5.491729458173116,5.474368691444397,5.457020560900371,5.439656098683675,5.430237412452698,5.429451425870259,5.429394880930583,5.429393410682678,5.429383913675944,5.4293837149937945,5.429383794466655,5.429383754730225,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225375016530354,24.52680730819702,24.887107213338215,25.253907044728596,25.64010747273763,26.04190731048584,26.455807209014893,26.84650754928589,27.183507283528645,27.47270743052165,27.719307104746502,27.928006807963055,28.06740665435791,28.111006418863933,28.0727063814799,27.964606444040935,27.7974058787028,27.547805468241375,27.19670534133911,26.761704921722412,26.258004665374756,25.699004650115967,25.09620412190755,24.459603945414226,23.797904014587402,23.118403752644856,22.42750358581543,21.72800334294637,21.02190287907918,20.31390317281087,19.60790268580119,18.90720256169637,18.21460262934367,17.532502333323162,16.862802346547443,16.20700216293335,15.566401958465576,14.94120192527771,14.331601858139038,13.738301515579224,13.161901712417603,12.602901458740234,12.061501423517862,11.538001298904419,11.032401323318481,10.544601202011108,10.074401140213013,9.621791044871012,9.18631100654602,8.767680883407593,8.365570942560831,7.979610761006673,7.609390775362651,7.25450074672699,6.9144907395044966,6.588930646578471,6.277360717455546,5.979190627733867,5.693840543429057,5.420900543530782,5.15993054707845,4.910520434379578,4.672260483105977,4.444730440775554,4.227540413538615,4.020280381043752,3.822580357392629,3.6339003642400107,3.453760345776876,3.281820317109426,3.1177902817726135,2.9613502621650696,2.8122002681096396,2.6700602372487388,2.5346402525901794,2.4056702057520547,2.282880187034607,2.1660202145576477,2.054850220680237,1.9491301874319713,1.8486001789569855,1.7530501584211986,1.6622401475906372,1.5759701530138652,1.494020124276479,1.4162001311779022,1.3445101181666057,1.2798201441764832,1.2206401228904724,1.1664801438649495,1.1168701549371083,1.071400135755539,1.0296901265780132,0.991407131155332,0.9562341322501501,0.9238881270090739,0.8941131432851156,0.8666741251945496,0.8413581202427546,0.8179721236228943,0.7963401228189468,0.7763001173734665,0.7577091157436371,0.7404351284106573,0.7243571182092031,0.709366112947464,0.6953641126553217,0.6822601109743118,0.6699701150258383,0.6584211190541586,0.647547110915184,0.637285108367602,0.6275811195373535,0.6183821161588033,0.6096431016921997,0.6013191143671671,0.5933751165866852,0.5857771088679632,0.5784921099742254,0.5714921106894811,0.5647501051425934,0.5582451075315475,0.5519501020510992,0.5458501031001409,0.5399271051088969,0.5341640909512838,0.5285471081733704,0.5230610917011896,0.5176941007375717,0.5124370902776718,0.507278099656105,0.5022071003913879,0.49721809724966687,0.4923000931739807,0.4874450961748759,0.4826490953564644,0.4779060905178388,0.47321109225352603,0.46855709205071133,0.4639420881867409,0.45936008791128796,0.454807090262572,0.4502800901730855,0.44577808678150177,0.4412960857152939,0.43683307866255444,0.4323870862523715,0.42795507858196896,0.4235330770413081,0.41912208249171573,0.41472108165423077,0.41032807528972626,0.40594207495450974,0.40156207730372745,0.3971860781311989,0.3928120732307434,0.3884420692920685,0.38407406707604724,0.37970906992753345,0.37534507115681964,0.370983066658179,0.366621067126592,0.3622570683558782,0.35789306710163754,0.35353006422519684,0.34916606545448303,0.3448010633389155,0.34043606370687485,0.3360700656970342,0.33170006175835925,0.3273300627867381,0.3229590604702632,0.3185870597759883,0.3142140557368596,0.30984005828698474,0.3054650550087293,0.30108705163002014,0.29670805235703784,0.2923280547062556,0.2879480520884196,0.2835680494705836,0.27918804933627445,0.2748090500632922,0.27042805403470993,0.26604804893334705,0.2616700480381648,0.25729304552078247,0.2529190431038539,0.24854604030648866,0.24417604257663092,0.2398060423632463,0.23543904100855192,0.23107404013474783,0.22671303898096085,0.222355039169391,0.21800003697474798,0.21364803363879523,0.20929803450902304,0.20495103299617767,0.2006070353090763,0.19626803199450174,0.19193203002214432,0.18759802977244058,0.18326803048451742,0.17894202967484793,0.1746200273434321,0.17030202597379684,0.16598802556594214,0.16167802487810454,0.15737002342939377,0.15306602170070013,0.1487670230368773,0.1444710207482179,0.14018002152442932,0.13589402164022127,0.13161101564764977,0.12733101720611253,0.12305501662194729,0.11878301637868087,0.11451601485411327,0.11025301367044449,0.10599401282767455,0.10173901170492172,0.09748711188634236,0.09323920930425326,0.08899580873548985,0.08475680835545063,0.0805222075432539,0.07629200629889965,0.07206610403954983,0.06784220474461715,0.06362290401011705,0.05940810280541579,0.055197701789438725,0.050991700651745,0.04679010032365719,0.04259289956341187,0.038592799877127014,0.03496660012751818,0.031679599856336914,0.02870039998864134,0.026000399918605883,0.023553500107179087,0.021336100064218044,0.019326899976780016,0.017506299850841362,0.015856800057614844,0.014362400009607276,0.013008500061308345,0.011781999996552864,0.010670900034407774,0.009664400092636546,0.008752690007289251,0.00792687013745308,0.007178859979224701,0.006501350008572142,0.005887710023671389,0.005331939978835483,0.0048285699837530656,0.004372689950590332,0.003959810012020171,0.0035858899742985764,0.0032472600190279386,0.002940589969512075,0.002662869985215366,0.00241135999870797,0.0021836000184218087,0.0019773399884191654,0.0017905599961522967,0.0016214199907456834,0.0014682499944077183,0.001329550005417938,0.001203949999762699,0.0010902099990441154,0.0009872129933986191,0.000893948003067635,0.0008094930041503782,0.0007330169998264561,0.0006637649979287138,0.000601055997928294,0.0005442710050071279,0.0004928510049163984,0.000446289004078911,0.0004041260011338939,0.0003659469972869071,0.0003313750009207676,0.0003000690000286947,0.00027172100332487997,0.0002460510016438396,0.0002228070006822236,0.00020175899771857075,0.00018269900222852206,0.00016544000027352013,0.000149812000017846,0.00013566000052378513,0.00012284499886542713,0.00011124099971008643,5.997194724235063e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050127506256104,22.259799321492512,22.13089927037557,22.1349991162618,22.1134991645813,22.071499506632488,22.013498942057293,21.926599343617756,21.80009921391805,21.64129940668742,21.456799666086834,21.251999219258625,21.010799566904705,20.720099449157715,20.389899730682373,20.02899996439616,19.644800027211506,19.22399965922038,18.75599988301595,18.251999696095783,17.721499919891357,17.172499815622967,16.611799875895183,16.044999837875366,15.476999759674072,14.911700010299683,14.3522998491923,13.799999872843424,13.255400021870932,12.720799843470255,12.19789981842041,11.687999804814657,11.192300001780191,10.711400032043457,10.246000051498413,9.796299854914347,9.362610022226969,8.944680054982504,8.542189995447794,8.155050039291382,7.783100008964539,7.426090041796367,7.083740035692851,6.755710005760193,6.441629926363627,6.141109983126323,5.853729963302612,5.579049984614055,5.316629966100057,5.066029946009318,4.826810002326965,4.598530054092407,4.380770007769267,4.173089981079102,3.975089967250824,3.7863600055376687,3.6064900159835815,3.435069998105367,3.2716899712880454,3.1159799893697104,2.9676100413004556,2.8262400031089783,2.691569983959198,2.5633000135421753,2.441119968891144,2.3247599999109902,2.213949998219808,2.1083799799283347,2.00776998202006,1.9118800063927968,1.8205099900563557,1.7334499955177307,1.6504800021648407,1.5714399913946788,1.4961300094922383,1.42439000805219,1.3560499946276348,1.2909499804178874,1.228959987560908,1.169919987519582,1.113699992497762,1.0601599911848705,1.0091900030771892,0.9606499920288721,0.9144410043954849,0.8704500049352646,0.829123005270958,0.7903299927711487,0.7533979962269465,0.7182369927565256,0.6847619861364365,0.6528909901777903,0.6225509941577911,0.5936679939428965,0.5661689986785253,0.5399920096000036,0.5150709996620814,0.4913440023859342,0.4687570035457611,0.4472539921601613,0.42678099622329074,0.40728699912627536,0.3887290010849635,0.37106100221474964,0.35423700014750165,0.33821899940570194,0.3229690020283063,0.3084460000197093,0.294615996380647,0.2814469983180364,0.26890799899895984,0.2569650014241536,0.2455929989616076,0.23476299891869226,0.2244469995299975,0.21462199836969376,0.20526500170429549,0.19635099917650223,0.1878580003976822,0.17976799855629602,0.17206200088063875,0.1647179995973905,0.1577219987908999,0.1510569987197717,0.14470499753952026,0.13864900171756744,0.1328789989153544,0.1273800004273653,0.12213699954251449,0.11714000068604946,0.11237699848910172,0.1078339982777834,0.1034999992698431,0.09936799978216489,0.09542799989382426,0.0916681991269191,0.08808219991624355,0.08466149866580963,0.08139579991499583,0.07827999939521153,0.07530679926276207,0.07246679874757926,0.06975369962553184,0.06716370023787022,0.06469080038368702,0.062326998760302864,0.0600693995753924,0.05791279921929041,0.05585009977221489,0.05387659960736831,0.05199049940953652,0.050187499883274235,0.04846119942764441,0.04681039943049351,0.04523139943679174,0.04371829982846975,0.04227039994051059,0.040884499438107014,0.03955529940625032,0.038279999047517776,0.03705849995215734,0.03588819938401381,0.03476410017659267,0.03368659938375155,0.0326532997811834,0.03165969951078296,0.03070399972299735,0.029786699606726568,0.028905999691536028,0.02805769971261422,0.02724259967605273,0.026459299648801487,0.025703699483225744,0.02497689953694741,0.024277599683652323,0.02360199981679519,0.022949099851151306,0.022320099951078493,0.0217137997969985,0.021126899868249893,0.02056079947700103,0.02001449962457021,0.019484699703752995,0.018970600018898647,0.01847389992326498,0.017993699448804062,0.017526899774869282,0.017075299906233948,0.016637999874850113,0.016212199659397204,0.015799499737719696,0.015399399834374586,0.015008999810864529,0.014627699817841252,0.014257599599659443,0.01389799996589621,0.013546199925864736,0.013204099843278527,0.012871299870312214,0.012544899868468443,0.012224699836224318,0.011912799905985594,0.01160879984187583,0.011309899855405092,0.011018199923758706,0.010733499890193343,0.010452999888608852,0.010176499839872122,0.009906229718277851,0.009641899882505337,0.009380859943727652,0.00912531977519393,0.008875019925956925,0.008627359755337238,0.008384570013731718,0.008146439989407858,0.007910379907116294,0.007676299894228578,0.007446479983627796,0.0072207199021553,0.006996479894345005,0.0067760398766646785,0.006559229999159773,0.00634351985839506,0.0061288800012941165,0.005917609902098775,0.005709559967120488,0.00550222994449238,0.0052979399139682455,0.005096559956048925,0.004895600024610758,0.004697399990012248,0.004501829971559346,0.004306420062979062,0.00411116995383054,0.00391843996476382,0.0037281199862870076,0.003542450004412482,0.00336593003400291,0.0031981299980543554,0.003038619994185865,0.002887000019351641,0.0027428899969284735,0.002605919997828702,0.002475749992299825,0.002352050020514677,0.0022344900256333253,0.0021227799588814378,0.002016620012000203,0.001915749996745338,0.0018199099965083103,0.0017288399879665424,0.0016423099829504888,0.001560109987622127,0.0014820000117955108,0.0014077899977564812,0.001337299996521324,0.0012703200045507401,0.0012066900089848787,0.0011462399949474882,0.001088819990400225,0.0010342599901681144,0.0009824410032403346,0.0009332120049900065,0.0008864459960022941,0.0008420219916539887,0.0007998220098670572,0.0007597350049763918,0.0007216560043161735,0.0006854839981921638,0.0006511250054851795,0.0006184860055024425,0.0005874829997386163,0.0005580339978526657,0.0005300600023474544,0.0005034889982198365,0.0004782490019958156,0.00045427399648663897,0.0004315009985778791,0.0004098699985964534,0.0003893229998842192,0.00036980599543312564,0.00035126700095133856,0.00033365799754392356,0.00031693199950192746,0.0003010439977515489,0.00028595299954758957,0.0002716180048688936,0.0002580019984937583,0.00024506899959912215,0.0002327839999149243,0.00022111600022374964,0.00021003200163249858,0.00019950400140563337,0.000189504000445595,0.0001800050013116561,0.000170983001832307,0.00016241299939186624,0.00015427200075161332,0.00014653999945342852,0.0001391949990647845,0.00013221899886654379,0.00012559200088920383,0.00011929799863234318,0.00011331900047177139,0.0001076399991385794,9.39248511713231e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.69500478108725,237.72884623209634,240.99987157185873,243.5529022216797,245.43892288208008,246.82693099975586,247.8499870300293,247.88906224568686,246.51109059651694,244.13911946614584,241.09712727864584,237.62818145751953,233.21624883015951,227.50027211507162,220.94129435221353,213.88629277547201,206.59233601888022,198.59939575195312,189.5874048868815,179.99441274007162,170.14741007486978,160.2864023844401,150.5863889058431,141.16837056477866,132.11635398864746,123.48533503214519,115.30531883239746,107.53830337524414,100.14628601074219,93.15207036336263,86.56255276997884,80.37673695882161,74.58692169189453,69.1805051167806,64.14209175109863,59.45387840270996,55.097365061442055,51.05095386505127,47.2935422261556,43.807332038879395,40.5746218363444,37.57861296335856,34.80300490061442,32.23239707946777,29.852389653523762,27.649283091227215,25.610076904296875,23.722771326700848,21.976165771484375,20.359760761260986,18.863756497701008,17.479352474212646,16.198148250579834,15.01234475771586,13.914741357167562,12.89883828163147,11.95843537648519,11.087632894515991,10.281030495961508,9.533838113149008,8.841586192448935,8.200204253196716,7.605912486712138,7.055210789044698,6.544869303703308,6.071897904078166,5.633516589800517,5.227005362510681,4.849844336509705,4.499903241793315,4.175202290217082,3.8739213744799295,3.594350596268972,3.3349398374557495,3.094219128290812,2.870838443438212,2.6635678807894387,2.4712473154067993,2.2928067445755005,2.1272462606430054,1.9736558397610982,1.8311553994814556,1.6989350219567616,1.5762746433417003,1.4624643127123516,1.3568839728832245,1.2592336932818096,1.1689034303029378,1.0850031872590382,1.0070729553699493,0.9347127427657446,0.867545540134112,0.8051993697881699,0.7473011960585912,0.6935580422480901,0.6436688899993896,0.5973567515611649,0.5543626298507055,0.5144485086202621,0.4774194036920865,0.44306430717309314,0.4111662084857623,0.381545123954614,0.35406503826379776,0.32857096443573636,0.30491789678732556,0.28297583013772964,0.2626177668571472,0.24373171602686247,0.22618166853984198,0.2098736179371675,0.19474257280429205,0.18070553118983904,0.16768149410684904,0.15559745828310648,0.14438742523392042,0.1339853915075461,0.12433536412815253,0.11538133832315604,0.10707331386705239,0.09936559262375037,0.0922136710335811,0.08557765123744805,0.07942033434907596,0.07370711552600066,0.06840580080946286,0.06348678718010585,0.05892237306882938,0.0546868604918321,0.05075664880375067,0.047109438106417656,0.04372492774079243,0.04058411903679371,0.037669310656686626,0.03496430224428574,0.03245379480843743,0.030123788087318342,0.0279613818662862,0.025954275857657194,0.02409147083138426,0.022362465659777325,0.020757660424957674,0.019268056377768517,0.01788545244683822,0.016601948533207178,0.015410645244022211,0.014304741829012832,0.013278238863373796,0.012325336147720614,0.011440733525281152,0.01061963119233648,0.009857358876615763,0.009149726790686449,0.008492824776719013,0.007883003175569078,0.007316881480316321,0.006791339915556212,0.006303468563904365,0.005850557199058433,0.005430095984290044,0.005039784824475646,0.004677433675775926,0.004341062740422785,0.004028801806271076,0.0037389209804435572,0.0034698201925493777,0.003220019474004706,0.0029881287870618203,0.0027728681452572346,0.0025730375782586634,0.0023875570429178574,0.002215376511837045,0.002055546035990119,0.0019071956436770658,0.001769495216043045,0.0016416848423735548,0.001523054486218219,0.0014129441794163238,0.0013107438668763887,0.001215893590900426,0.0011278633319307119,0.0010461731095953535,0.0009703588730189949,0.0009000066638691351,0.0008347224647877738,0.0007741452912644794,0.000717936132180815,0.0006657839743032431,0.0006173958342211942,0.0005725026906778415,0.0005308535813431566,0.0004922154621453956,0.00045637235840937745,0.00042312325482877594,0.00039228116899418336,0.00036367308590949204,0.00033713800318461534,0.0003125269310354876,0.00028970186637404066,0.0002685328048149434,0.0002489017436649495,0.00023069568851497024,0.00021381363815938434,0.00019815959240077063,0.00018364454930027327,0.0001701855107967276,0.00015770647223689593,0.00014613743769587018,0.00013541140530530052,0.00012546837691237064,0.00011625034979563982,0.00010770532329236933,5.0820006435969844e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.652732769648234,3.5471805334091187,3.4357604583104453,3.327050526936849,3.2169004678726196,3.1060304641723633,2.9950804313023887,2.884580433368683,2.775020440419515,2.666780412197113,2.5602304339408875,2.455640355745951,2.353260358174642,2.2532903949419656,2.1558903654416404,2.061180373032888,1.9692703386147816,1.8802103499571483,1.7940603097279866,1.7108403245608013,1.6305602888266246,1.5532202621301014,1.4787902534008026,1.407240241765976,1.3385202487309773,1.2726002434889476,1.209400236606598,1.1488802134990692,1.0909502009550731,1.0355602006117504,0.9826311816771826,0.9320831795533498,0.8838401635487875,0.8378281543652216,0.7939691593249639,0.752184142669042,0.712395136555036,0.674526130159696,0.6385021259387335,0.604247123003006,0.571691115697225,0.5407611032327017,0.5113870973388354,0.4835020949443181,0.45703908801078796,0.43193408101797104,0.4081270818909009,0.3855590770641963,0.36417107035716373,0.3439060648282369,0.3247120628754298,0.30653706441322964,0.2893330579002698,0.27305105328559875,0.2576460540294647,0.24307304869095483,0.2292920450369517,0.21626104538639387,0.203943041463693,0.1923020395139853,0.18130203584829965,0.17091003308693567,0.16109303509195647,0.151822030544281,0.14306902885437012,0.13480502739548683,0.12700602660576502,0.11964502433935802,0.11270002275705338,0.10614702229698499,0.09996512035528819,0.09413401906689008,0.08863551976780097,0.08345071723063786,0.07856211625039577,0.07395461512108643,0.06961251422762871,0.06551951356232166,0.06166191337009271,0.05802841205149889,0.05460511179020008,0.05137911066412926,0.04834150988608599,0.045480609561006226,0.04278550886859497,0.04024760890752077,0.037944307550787926,0.03584870727111896,0.03386610591163238,0.03198950660104553,0.030212105717509985,0.028527905698865652,0.026931005530059338,0.025433405147244532,0.024011604953557253,0.0226607044848303,0.021393804345279932,0.020188303974767525,0.019040203808496397,0.017963503797849018,0.016953803443660338,0.016006803062434,0.015101203229278326,0.014234402837852636,0.01342150274043282,0.012659102600688735,0.011944002471864223,0.011273402099808058,0.010644402044514814,0.01003700215369463,0.009449912002310157,0.008899251775195202,0.008382781641557813,0.007898361616147062,0.007444001540231208,0.007017841407408317,0.00661812136725833,0.006243201321922243,0.005891531123779714,0.005561681037458281,0.00525229109916836,0.004962090984918177,0.004689880918400983,0.004434550879523158,0.004177620944877465,0.003919170839556803,0.0036767507748057446,0.003449340738976995,0.0032360306746947267,0.0030359206333135567,0.00284822063986212,0.002672140544746071,0.0025069605326279998,0.0023520104975129166,0.002206650465571632,0.0020702804322354496,0.001942360414735352,0.0018223603838123381,0.0017097703724478681,0.0016041603618456672,0.0015050703174589823,0.0014121202887812008,0.0013249102824678023,0.0012430902764511604,0.001166340245011573,0.0010943202457080285,0.0010267602240977187,0.000963378207719264,0.0009039101957265908,0.0008481161882324765,0.000795770164889594,0.0007466571599555513,0.00070057814688577,0.0006573461384202043,0.000616783140382419,0.000578726117964834,0.000543018114209796,0.0005095151136629283,0.0004780811019979107,0.0004485870958887972,0.0004209140897728503,0.0003949480887968093,0.0003705860775274535,0.0003477270753743748,0.0003262790705775842,0.0003061540677056958,0.00028727106594791013,0.00026955305656883866,0.0002529280536691658,0.00023732905174256302,0.0002226920466152175,0.00020895804482279345,0.00019607104089421531,0.0001839790384110529,0.00017263303501143432,0.00016198603528512953,0.00015199703314768462,0.00014262303132757856,0.00013382702794236442,0.00012557402806123719,0.00011782902523312562,0.0001105630235542776,0.00010374402336310595,8.343504305230454e-06,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844180266062417,3.2989591161410012,3.3043991724650064,3.3077791929244995,3.3091992338498435,3.3087492187817893,3.3065293033917746,3.302629311879476,3.2971293528874717,3.2901093562444053,3.2816593845685325,3.271849433581034,3.2607494393984475,3.2484394709269204,3.2349894841512046,3.220459500948588,3.20490954319636,3.1884095072746277,3.170999546845754,3.152759552001953,3.133719563484192,3.1139396031697593,3.093469580014547,3.0723596612612405,3.050649642944336,3.0283696254094443,3.005579670270284,2.9823096990585327,2.9585896929105124,2.934469699859619,2.909969707330068,2.885129690170288,2.859979728857676,2.8345497449239097,2.808869779109955,2.782959759235382,2.756849765777588,2.7305598060290017,2.7041297952334085,2.677559792995453,2.650889794031779,2.624129831790924,2.597299794356028,2.5704198082288108,2.5434998075167337,2.5165698329607644,2.4896398385365806,2.4627198378245034,2.4358298579851785,2.408979833126068,2.3821898897488913,2.355469842751821,2.3288198908170066,2.302259862422943,2.275799890359243,2.249449888865153,2.2232098976771035,2.1970999042193093,2.171129882335663,2.145289897918701,2.1196099321047464,2.094079911708832,2.068709909915924,2.043509920438131,2.0184799234072366,1.993629922469457,1.9689599176247914,1.9444899260997772,1.9201999406019847,1.8960999250411987,1.8722099363803864,1.8485199411710103,1.8250299592812855,1.8017499446868896,1.7786799371242523,1.755819946527481,1.7331699430942535,1.7107499539852142,1.6885399520397186,1.6665499607721965,1.6447799603144329,1.6232299506664276,1.6019099553426106,1.5808099607626598,1.5599299569924672,1.5392699937025707,1.518069972594579,1.496369997660319,1.4749599893887837,1.4538599848747253,1.4330299993356068,1.4124899804592133,1.3922399878501892,1.37226997812589,1.3525800009568532,1.3331500093142192,1.3139799932638805,1.2950999935468037,1.2764799892902374,1.2581200003623962,1.240009993314743,1.2221499979496002,1.20456001162529,1.1872100035349529,1.1700999935468037,1.1532399952411652,1.1366199950377147,1.12021999557813,1.1040599942207336,1.0881499946117401,1.0724499921003978,1.0569700002670288,1.0417100091775258,1.0266900062561035,1.0118800004323323,0.9972789982954661,0.9828719943761826,0.9686790059010187,0.9546960045893987,0.9409200002749761,0.9273490111033121,0.9139599998792013,0.9007489929596583,0.8877339959144592,0.8749109953641891,0.8622790028651556,0.8498340000708898,0.8375730067491531,0.8254940013090769,0.8135930001735687,0.8018680115540823,0.7902970016002655,0.7788769950469335,0.7676249941190084,0.7565399954716364,0.7456180055936178,0.7348559945821762,0.7242529988288879,0.713807001709938,0.7035130063692728,0.6933709929386774,0.683378001054128,0.6735319991906484,0.6638300021489462,0.6542699982722601,0.6448509991168976,0.6355690012375513,0.6264230012893677,0.6174110074838003,0.6085299998521805,0.599779004851977,0.5911560008923212,0.582658996184667,0.5742660065491995,0.5659750004609426,0.557805006702741,0.549754003683726,0.5418199946482977,0.5340010027090708,0.526296004652977,0.5187030037244161,0.5112210065126419,0.5038460046052933,0.49657899886369705,0.48941700408856076,0.48235899955034256,0.47540299842755,0.4685479998588562,0.4617920021216075,0.45513400187095004,0.4485719973842303,0.4421039968729019,0.4357310011982918,0.42944899946451187,0.4232580016056697,0.4171560009320577,0.411141999065876,0.4052150025963783,0.39937300235033035,0.3936159983277321,0.38794099539518356,0.38234799603621167,0.37683599690596264,0.3714029962817828,0.36604899913072586,0.3607710028688113,0.3555700009067853,0.350443996489048,0.34539199620485306,0.3404119983315468,0.3355040003856023,0.33066699902216595,0.32589999834696454,0.32120200246572495,0.31657099972168606,0.31200699508190155,0.30750899761915207,0.30307599902153015,0.2987060025334358,0.29439999908208847,0.2901559993624687,0.28597300002972287,0.281850000222524,0.2777870024243991,0.27378299832344055,0.269836001098156,0.265945998330911,0.2621129999558131,0.2583340009053548,0.254611000418663,0.2509410021205743,0.24732299894094467,0.2437590000530084,0.24024500201145807,0.2367819994688034,0.23336999863386154,0.23000600064794222,0.2266909976800283,0.22342399880290031,0.22020399942994118,0.21702999994158745,0.21390299871563911,0.2108200006186962,0.20778200030326843,0.2047879993915558,0.20183699702223143,0.1989280010263125,0.1960619998474916,0.1932359995941321,0.19045199950536093,0.18770800034205118,0.18500300124287605,0.1823380005856355,0.17971100037296614,0.1771219993631045,0.17457000042001405,0.17205500106016794,0.16957600166400275,0.1671340006093184,0.1647260015209516,0.16235300029317537,0.16001500189304352,0.15771000335613886,0.1554389993349711,0.15320000052452087,0.15099400157729784,0.1488189995288849,0.14667600020766258,0.14456399778525034,0.14248299847046533,0.140430998057127,0.13840899740656218,0.13641600062449774,0.13445200150211653,0.13251599917809168,0.13060900072256723,0.12872799982627234,0.1268749994536241,0.12504899936417738,0.12324899931748708,0.12147500055531661,0.11972600035369396,0.118002999573946,0.1163039995978276,0.11463000004490216,0.11298000005384286,0.11135400086641312,0.10975200061996777,0.10817200007538001,0.10661500133574009,0.10508100067575772,0.10356900095939636,0.10207800008356571,0.10060900015135606,0.09916149949034055,0.09773460030555725,0.09632819953064124,0.09494209910432498,0.09357599914073944,0.09222950041294098,0.09090249985456467,0.08959449951847394,0.08830539944271247,0.08703490036229293,0.08578270114958286,0.08454850005606811,0.08333210088312626,0.08213319939871629,0.08095150006314118,0.07978689981003602,0.07863909999529521,0.07750779887040456,0.07639279899497826,0.07529380048314731,0.07421070026854674,0.07314310036599636,0.07209100015461445,0.07105390044550101,0.07003180061777432,0.06902450012664,0.06803159974515438,0.06705300013224284,0.06608860070506732,0.06513800037403901,0.06420109917720158,0.06327759971221288,0.06236749949554602,0.06147050019353628,0.06058640001962582,0.05971499998122454,0.05885609984397888,0.05800959995637337,0.05717529977361361,0.05635309964418411,0.05554260003070036,0.054743800312280655,0.05395649994413058,0.05318060020605723,0.05241579997042815,0.05166199989616871,0.050919100331763424,0.050186799839138985,0.04946509997049967,0.0487538001810511,0.048052699925998844,0.04736170017470916,0.04668070003390312,0.04600950020054976,0.045347899508972965,0.04469579985986153,0.0440531000494957,0.04341970011591911,0.04279539982477824,0.04218000049392382,0.0415735999122262,0.04097580040494601,0.04038669945051273,0.03980599995702505,0.03923370006183783,0.03866959953059753,0.03811359995355209,0.037565600437422596,0.03702559943000475,0.03649320018788179,0.03596859953055779,0.03545149943480889,0.0349418002491196,0.03443950042128563,0.03394439940651258,0.03345640034725269,0.03297540017714103,0.03250140075882276,0.03203410003334284,0.03157359982530276,0.03111980001752575,0.030672399792820215,0.030231500044465065,0.029796899762004614,0.029368600031981867,0.028946399843941133,0.028530299973984558,0.02812019983927409,0.027716000098735094,0.02731760001430909,0.02692499989643693,0.026537999976426363,0.026156499826659758,0.025780600029975176,0.0254100002348423,0.025044800092776615,0.02468479983508587,0.024329999927431345,0.023980399904151756,0.02363570003459851,0.023295999970287085,0.022961200059701998,0.022631200185666483,0.02230590023100376,0.02198540015767018,0.021669400079796713,0.021357999959339697,0.021051000182827313,0.020748500091334183,0.020450300071388483,0.02015640027821064,0.01986679993569851,0.01958130020648241,0.01929989969357848,0.01902249998723467,0.018749200118084747,0.018479700200259686,0.01821419984723131,0.01795239994923274,0.01769449996451537,0.017440199851989746,0.01718959988405307,0.016942600098749,0.016699100223680336,0.01645919991036256,0.016222699855764706,0.015989600059886772,0.015759799784670275,0.01553339984578391,0.015310199931263924,0.015090200118720531,0.014873399942492446,0.014659699983894825,0.014449100087707242,0.014241499981532494,0.014036899898201227,0.013835200030977527,0.013636399991810322,0.013440499858309826,0.013247400056570768,0.013057099965711435,0.01286950008943677,0.012684599962085485,0.01250240004931887,0.012322800001129508,0.0121457000883917,0.011971300079797706,0.011799300011868278,0.011629800001780191,0.011462700087577105,0.011297999881207943,0.011135700081164638,0.010975799911345044,0.01081809999110798,0.010662699971968928,0.010509500047191978,0.010358599945902824,0.010209800054629644,0.010063100062931577,0.009918560041114688,0.00977609003894031,0.009635670110583305,0.009497260053952536,0.009360840000833074,0.009226389927789569,0.00909386994317174,0.008963250011826554,0.008834509877488017,0.008707620048274597,0.008582550023371974,0.008459279856955012,0.008337780057142178,0.008218029979616404,0.00809999997727573,0.0079836700266848,0.00786900008097291,0.0077559899461145205,0.007644600002095103,0.007534809953843554,0.007426600010755162,0.00731994006006668,0.007214820051255326,0.007111200092670818,0.007009080106702943,0.006908420007675886,0.006809209977897505,0.0067114299939324456,0.006615049904212356,0.006520049956937631,0.006426420023975273,0.00633414004308482,0.006243180017918348,0.006153529975563288,0.006065170008999606,0.005978069927853842,0.005892229926151534,0.005807620007544756,0.005724229966290295,0.005642039934173226,0.00556101999245584,0.0054811700247228146,0.005402469968733688,0.005324899956273536,0.005248440002712111,0.005173079979916413,0.00509880999258409,0.005025600044367214,0.0049534399683276815,0.0048823200243835645,0.004812219956268867,0.004743130023901661,0.004708840007272859};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261275604367256,0.4188620348771413,0.4108480264743169,0.4034980237483978,0.3960840255022049,0.3886190156141917,0.38112201790014905,0.37360502282778424,0.36608202507098514,0.3585640216867129,0.3510630155603091,0.34359001864989597,0.3361540138721466,0.32876401394605637,0.3214290166894595,0.31415501485268277,0.30695001035928726,0.299820010860761,0.29277001072963077,0.28580601265033084,0.27893101175626117,0.27215001235405606,0.26546601206064224,0.2588820084929466,0.2523990087211132,0.24602300922075906,0.23975300788879395,0.23359200979272524,0.22754100834329924,0.22160100688536963,0.21577301000555357,0.2100560056666533,0.2044520042836666,0.19896100709835687,0.19358200579881668,0.1883150041103363,0.1831610066195329,0.17811900501449904,0.17318800588448843,0.16836600502332053,0.16365500539541245,0.15905100479722023,0.15455400322874388,0.15016300479571024,0.1458770049115022,0.14169400309522948,0.13761300469438234,0.1336320030192534,0.12975100303689638,0.12596600378553072,0.1222780030220747,0.11868300288915634,0.11518100276589394,0.11177000279227893,0.1084470022469759,0.10521300323307514,0.10206400230526924,0.09900040179491043,0.09601870241264503,0.09311760154863198,0.09029530175030231,0.08755000246067841,0.08488140193124612,0.08228760212659836,0.0797661015142997,0.07731540190676849,0.07493400014936924,0.07261940153936546,0.07037040156622727,0.06818560076256593,0.06606400075058143,0.06400430016219616,0.06200430107613405,0.060061801224946976,0.058176000602543354,0.05634580117960771,0.054569300885001816,0.05284560068200032,0.05117400145779053,0.04955250055839618,0.04797940142452717,0.0464528010537227,0.044972301150361695,0.04353720135986805,0.04214590104917685,0.04079689954717954,0.03939740018298229,0.03795389955242475,0.036563500141104065,0.035224199605484806,0.03393430014451345,0.03269180003553629,0.03149499992529551,0.030342199839651585,0.029231900194038946,0.028162299655377865,0.02713210027044018,0.02613979981591304,0.025183900104214747,0.024263099922488134,0.02337620019291838,0.02252189985786875,0.021698900188008945,0.020906200011571247,0.020142499978343647,0.01940689980983734,0.018698299614091713,0.018015699926763773,0.017358200003703434,0.01672470010817051,0.016114500040809315,0.015526700066402555,0.014960400061681867,0.014414899904901782,0.013889400055631995,0.013383100042119622,0.01289540009262661,0.012425500123451153,0.01197290001437068,0.011536799914514026,0.011116700091709694,0.010711999920507273,0.01032200005526344,0.009946389977509776,0.009584479965269566,0.00923581002280116,0.008899899975707134,0.008576260103533665,0.008264450045923391,0.007964039997508129,0.00767460997061183,0.007395749950471024,0.007127070023367803,0.006868199910968542,0.00661878000634412,0.006378460015791158,0.0061469000453750295,0.005923790042288601,0.005708810019617279,0.005501660013881822,0.005302070019145806,0.005109740033124884,0.0049244100227952,0.004745840094983578,0.004573759972117841,0.004407940005573134,0.004248159937560558,0.004094189964234829,0.003945810002430032,0.003802830004133284,0.0036650500066267946,0.0035322699889851115,0.0034043200042409203,0.0032810100043813386,0.0031621799959490695,0.003047659993171692,0.002937300014309585,0.002830950000012914,0.0027284499956294894,0.0026296799769625068,0.002534479989359776,0.0024427400009396174,0.002354319983472427,0.002269109982686738,0.002186989993788302,0.0021078400313854218,0.002031560017106434,0.001958049979293719,0.0018871899810619652,0.0018189099985950936,0.0017530899979950239,0.001689660013653338,0.0016285299983186026,0.001569599990034476,0.0015128100058063865,0.0014580800003993015,0.0014053199944707255,0.0013544799973412107,0.0013054699811618775,0.001258240023162216,0.0012127099810944249,0.0011688400021133323,0.0011265499827762444,0.0010857899906113744,0.0010464999941177666,0.0010086400046323736,0.0009721410024212673,0.0009369669908968111,0.0009030650010875737,0.0008703899948159233,0.0008388980058953166,0.0008085450002302726,0.0007792899996275082,0.000751094000103573,0.0007239179976750165,0.0006977249965226898,0.0006724799944398304,0.0006481489981524646,0.0006246980046853423,0.0006020960039071118,0.0005803120099396134,0.0005593159973310927,0.000539079987599204,0.0005195760022616014,0.0005007779933900262,0.000482660000367711,0.00046519799798261374,0.0004483679998277997,0.00043214600009378046,0.00041651199959839386,0.00040144399827113375,0.0003869210001236449,0.0003729229986978074,0.00035943200297576067,0.0003464300001117711,0.0003338970006249535,0.00032181899587158114,0.00031017700045291957,0.0002989570057252422,0.0002881419980743279,0.0002777190044677506,0.0002676739968592301,0.0002579909972458457,0.0002486589995290463,0.00023966499914725622,0.00023099600002751686,0.000222640999709256,0.0002145890005825398,0.0002068270005111117,0.0001993469995795749,0.00019213700094648326,0.0001851880018269488,0.0001784900002045712,0.00017203499858927293,0.000165814000259464,0.00015981700319874412,0.00015403700065993084,0.00014846700044775693,0.00014309800220265365,0.00013792399840895087,0.0001329360020463355,0.00012813000163684288,0.00012349700106521291,0.00011903200053590506,0.00011472799997136462,0.0001105800001823809,0.00010658199971658178,0.0001027289993847565,2.5096619841254626e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1795959472656,329.0759735107422,329.781977335612,330.5289713541667,331.2759704589844,332.0209732055664,332.7659734090169,333.50897216796875,334.2469762166341,334.9809748331706,335.70997365315753,336.43497467041016,337.1559753417969,337.8729731241862,338.58497111002606,339.2939758300781,339.9979731241862,340.7019729614258,341.40797932942706,342.1189727783203,342.8319727579753,343.54797108968097,344.26697794596356,344.98997497558594,345.71597544352215,346.4439748128255,347.1759745279948,347.90997314453125,348.64697265625,349.38697560628253,350.1289774576823,350.8729756673177,351.61997985839844,352.36897532145184,353.12097422281903,353.8749720255534,354.63197835286456,355.3909734090169,356.15397389729816,356.9189758300781,357.68797810872394,358.45997365315753,359.23497517903644,360.01297251383465,360.792973836263,361.57697041829425,362.3639780680339,363.15396881103516,363.9479726155599,364.7449773152669,365.5449752807617,366.3489735921224,367.1559778849284,367.96697998046875,368.78097279866535,369.5979741414388,370.4189758300781,371.2429733276367,372.0699717203776,372.8989715576172,373.73197174072266,374.56797281901044,375.40697479248047,376.2479756673177,377.09297434488934,377.93997446695965,378.78997802734375,379.64197540283203,380.49297587076825,381.3439712524414,382.1939748128255,383.042973836263,383.8929697672526,384.74097696940106,385.58997599283856,386.43797556559247,387.2859751383464,388.1299743652344,388.96897379557294,389.8009719848633,390.62797292073566,391.448974609375,392.26397196451825,393.07397715250653,393.8779754638672,394.6759745279948,395.4689763387044,396.25497182210285,397.03197479248047,397.8009745279948,398.5619761149089,399.3149719238281,400.05897521972656,400.7959747314453,401.5239715576172,402.2449722290039,402.9569803873698,403.6619822184245,404.35897572835285,405.04797617594403,405.729975382487,406.40397389729816,407.0709762573242,407.729975382487,408.38097890218097,409.0259780883789,409.66297658284503,410.292973836263,410.9149754842122,411.5309778849284,412.1389745076497,412.74097696940106,413.3349787394206,413.9229736328125,414.5039749145508,415.0779749552409,415.6449788411458,416.20597585042316,416.7589797973633,417.3069839477539,417.8469772338867,418.3819758097331,418.90997823079425,419.4309717814128,419.94597880045575,420.4549814860026,420.9579798380534,421.4539794921875,421.94397989908856,422.4289779663086,422.906977335612,423.37897237141925,423.84498087565106,424.3049799601237,424.75997670491535,425.2079772949219,425.6509730021159,426.0879770914714,426.5199737548828,426.9449818929036,427.36497497558594,427.7799809773763,428.18898010253906,428.59197998046875,428.98997751871747,429.38297780354816,429.76997629801434,430.15198008219403,430.5279795328776,430.8999786376953,431.26597849527997,431.6269785563151,431.98197682698566,432.3329772949219,432.67798105875653,433.01898193359375,433.3539784749349,433.68497975667316,434.0099792480469,434.3309809366862,434.64698028564453,434.95797475179035,435.2639795939128,435.56497955322266,435.8619791666667,436.1539815266927,436.4409815470378,436.72397867838544,437.0019810994466,437.27598063151044,437.54497782389325,437.8089828491211,438.06898244222003,438.32498423258465,438.5759785970052,438.82298278808594,439.0649820963542,439.30397542317706,439.53698476155597,439.76697794596356,439.9929784138997,440.21398162841797,440.4309768676758,440.64398193359375,440.8529815673828,441.05798085530597,441.2589797973633,441.4559809366862,441.64898173014325,441.8379821777344,442.0229771931966,442.20398203531903,442.38197835286456,442.5549825032552,442.72498321533203,442.89097849527997,443.0539830525716,443.2119827270508,443.36697642008465,443.5189793904622,443.66697947184247,443.81097920735675,443.9519805908203,444.08898162841797,444.22197977701825,444.3529815673828,444.47998301188153,444.6029764811198,444.7229766845703,444.83997853597003,444.9529800415039,445.062983194987,445.16998291015625,445.27298227945965,445.3739827473958,445.4709828694661,445.5649770100911,445.6549835205078,445.7429835001628,445.8279774983724,445.9089813232422,445.9879837036133,446.06297810872394,446.1349817911784,446.2049814860026,446.27098083496094,446.33498128255206,446.3949839274089,446.45298258463544,446.5079828898112,446.55997975667316,446.6089808146159,446.6549809773763,446.69898223876953,446.73998260498047,446.77798716227215,446.812983194987,446.8469772338867,446.8809814453125,446.91398366292316,446.9469858805339,446.97998046875,447.0129852294922,447.04497782389325,447.0769856770833,447.1089833577474,447.14098103841144,447.17298380533856,447.20398712158203,447.23497772216797,447.26598103841144,447.29598236083984,447.3269780476888,447.3569844563802,447.3869806925456,447.416987101237,447.4459762573242,447.47598520914715,447.5049819946289,447.5329818725586,447.5619761149089,447.5909779866536,447.6189829508464,447.64698028564453,447.67498270670575,447.7019856770833,447.72998046875,447.7569834391276,447.7839838663737,447.8109842936198,447.83698018391925,447.86398061116535,447.8899841308594,447.91598256429035,447.9419860839844,447.96798451741535,447.99298604329425,448.0179850260417,448.0439860026042,448.06798044840497,448.09297943115234,448.11798095703125,448.14197540283203,448.16598256429035,448.18997955322266,448.2139841715495,448.2379786173503,448.260986328125,448.2849833170573,448.3079833984375,448.3309809366862,448.35298411051434,448.37598673502606,448.3979848225911,448.4209798177083,448.44298553466797,448.46498616536456,448.4869842529297,448.5079828898112,448.5299784342448,448.5509796142578,448.5719807942708,448.59297943115234,448.6139831542969,448.6349817911784,448.6549835205078,448.6759796142578,448.69598388671875,448.71598052978516,448.7359797159831,448.75598398844403,448.77498626708984,448.79497782389325,448.81398010253906,448.8329823811849,448.8519821166992,448.87097930908203,448.8899841308594,448.9089813232422,448.92698160807294,448.94498443603516,448.96398162841797,448.9819819132487,448.99997965494794,449.01698303222656,449.0349833170573,449.052983601888,449.06998443603516,449.0869852701823,449.104985555013,449.12198130289715,449.1379801432292,449.1549784342448,449.17198435465497,449.187983194987,449.2049840291341,449.2209828694661,449.23698170979816,449.2529830932617,449.2689844767253,449.2849807739258,449.30098215738934,449.31597900390625,449.3319829305013,449.34697977701825,449.36198170979816,449.3779805501302,449.3929850260417,449.40697987874347,449.42198435465497,449.4369812011719,449.4509862263997,449.46598561604816,449.47998301188153,449.49498240152997,449.5089823404948,449.52298736572266,449.53697967529297,449.5509796142578,449.5639826456706,449.5779800415039,449.59098561604816,449.60497792561847,449.61798095703125,449.6309814453125,449.64498138427734,449.65797932942706,449.67098236083984,449.68298085530597,449.6959813435872,449.708984375,449.72098032633465,449.7339833577474,449.74598693847656,449.7579803466797,449.77098083496094,449.7829818725586,449.7949803670247,449.8069814046224,449.81897989908856,449.8299814860026,449.84197998046875,449.8539810180664,449.86498006184894,449.8769785563151,449.88798268636066,449.89898173014325,449.9099807739258,449.92097727457684,449.9319788614909,449.94298044840497,449.95398203531903,449.96497853597003,449.9759826660156,449.98598225911456,449.9969787597656,450.0069808959961,450.01798248291016,450.0279820760091,450.0379816691081,450.04798380533856,450.0579833984375,450.06798553466797,450.07798258463544,450.0879847208659,450.0979817708333,450.10797627766925,450.11698150634766,450.1269836425781,450.13597615559894,450.14598592122394,450.1549809773763,450.1639811197917,450.17398325602215,450.18298085530597,450.1919809977214,450.2009785970052,450.20998128255206,450.21898651123047,450.2279815673828,450.23698170979816,450.2449773152669,450.2539825439453,450.26198323567706,450.27098337809247,450.27898661295575,450.2879816691081,450.2959798177083,450.3039830525716,450.31298065185547,450.32097880045575,450.3289845784505,450.3369827270508,450.34498341878253,450.3529790242513,450.3609848022461,450.36898549397785,450.375981648763,450.3839874267578,450.39198048909503,450.39898173014325,450.40698496500653,450.41398366292316,450.42198181152344,450.4289805094401,450.4369837443034,450.44398244222003,450.4509862263997,450.4579798380534,450.46498107910156,450.47198486328125,450.47898356119794,450.4859873453776,450.49298095703125,450.49998474121094,450.5069808959961,450.5139846801758,450.52098337809247,450.52698771158856,450.5339864095052,450.5399805704753,450.54698181152344,450.55298105875653,450.5599822998047,450.56597900390625,450.57298533121747,450.5789794921875,450.5849787394206,450.5919825236003,450.59797922770184,450.6039784749349,450.60998789469403,450.61597951253253,450.62198130289715,450.6279805501302,450.6339848836263,450.6399841308594,450.64598083496094,450.65098063151044,450.656977335612,450.6629816691081,450.6689860026042,450.6739857991536,450.6799850463867,450.68497975667316,450.68797810872394};
}

void set_concs_ssp460() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.78215876,9.836893944,9.891629127,9.946364311,10.00109949,10.01641191,10.03172433,10.04703675,10.06234917,10.07766159,10.09297401,10.10828643,10.12359885,10.13891127,10.15422369,10.13313466,10.11204563,10.0909566,10.06986757,10.04877854,10.02768952,10.00660049,9.98551146,9.964422431,9.943333403,9.877855816,9.812378228,9.746900641,9.681423054,9.615945467,9.550467879,9.484990292,9.419512705,9.354035118,9.28855753,9.182172485,9.075787439,8.969402394,8.863017348,8.756632302,8.650247257,8.543862211,8.437477166,8.33109212,8.224707075,8.121358176,8.018009277,7.914660379,7.81131148,7.707962582,7.604613683,7.501264785,7.397915886,7.294566987,7.191218089,7.079205681,6.967193273,6.855180865,6.743168457,6.63115605,6.519143642,6.407131234,6.295118826,6.183106418,6.07109401,5.971136562,5.871179114,5.771221666,5.671264218,5.57130677,5.471349322,5.371391874,5.271434426,5.171476978,5.07151953,4.997381593,4.923243656,4.849105719,4.774967782,4.700829844,4.626691907,4.55255397,4.478416033,4.404278096,4.330140159,4.310782881,4.291425603,4.272068326,4.252711048,4.23335377,4.213996492,4.194639214,4.175281937,4.155924659,4.136567381,4.117210103,4.097852825,4.078495547,4.05913827,4.039780992,4.020423714,4.001066436,3.981709158,3.962351881,3.942994603,3.923637325,3.904280047,3.884922769,3.865565491,3.846208214,3.826850936,3.807493658,3.78813638,3.768779102,3.749421825,3.730064547,3.710707269,3.691349991,3.671992713,3.652635436,3.633278158,3.61392088,3.594563602,3.575206324,3.555849046,3.536491769,3.517134491,3.497777213,3.478419935,3.459062657,3.43970538,3.420348102,3.400990824,3.381633546,3.362276268,3.34291899,3.323561713,3.304204435,3.284847157,3.265489879,3.246132601,3.226775324,3.207418046,3.188060768,3.16870349,3.149346212,3.129988934,3.110631657,3.091274379,3.071917101,3.052559823,3.033202545,3.013845268,2.99448799,2.975130712,2.955773434,2.936416156,2.917058879,2.897701601,2.878344323,2.858987045,2.839629767,2.820272489,2.800915212,2.781557934,2.762200656,2.742843378,2.7234861,2.704128823,2.684771545,2.665414267,2.646056989,2.626699711,2.607342433,2.587985156,2.568627878,2.5492706,2.529913322,2.510556044,2.491198767,2.471841489,2.452484211,2.433126933,2.413769655,2.394412377,2.3750551,2.355697822,2.336340544,2.316983266,2.297625988,2.278268711,2.258911433,2.239554155,2.220196877,2.200839599,2.181482322,2.162125044,2.142767766,2.123410488,2.10405321,2.084695932,2.065338655,2.045981377,2.026624099,2.007266821,1.987909543,1.968552266,1.949194988,1.92983771,1.910480432,1.891123154,1.871765876,1.852408599,1.833051321,1.813694043,1.794336765,1.774979487,1.75562221,1.736264932,1.716907654,1.697550376,1.678193098,1.65883582,1.639478543,1.620121265,1.600763987,1.581406709,1.562049431,1.542692154,1.523334876,1.503977598,1.48462032,1.465263042,1.445905765,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487,1.426548487};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,35.02706045,35.30809667,35.58913289,35.87016911,36.15120534,36.04762683,35.94404832,35.84046981,35.7368913,35.63331279,35.52973428,35.42615577,35.32257726,35.21899875,35.11542024,35.09335077,35.0712813,35.04921183,35.02714236,35.00507289,34.98300342,34.96093395,34.93886448,34.91679501,34.89472554,34.7855949,34.67646427,34.56733364,34.458203,34.34907237,34.23994173,34.1308111,34.02168047,33.91254983,33.8034192,33.52032304,33.23722689,32.95413073,32.67103457,32.38793841,32.10484226,31.8217461,31.53864994,31.25555378,30.97245763,30.72162418,30.47079074,30.2199573,29.96912386,29.71829042,29.46745697,29.21662353,28.96579009,28.71495665,28.46412321,28.16965928,27.87519535,27.58073143,27.2862675,26.99180358,26.69733965,26.40287572,26.1084118,25.81394787,25.51948395,25.27246185,25.02543975,24.77841766,24.53139556,24.28437346,24.03735136,23.79032927,23.54330717,23.29628507,23.04926298,22.94125203,22.83324109,22.72523015,22.61721921,22.50920827,22.40119733,22.29318639,22.18517545,22.07716451,21.96915356,21.91432618,21.8594988,21.80467142,21.74984404,21.69501666,21.64018928,21.5853619,21.53053452,21.47570714,21.42087976,21.36605238,21.311225,21.25639762,21.20157024,21.14674286,21.09191548,21.0370881,20.98226072,20.92743334,20.87260596,20.81777858,20.7629512,20.70812382,20.65329644,20.59846906,20.54364168,20.4888143,20.43398692,20.37915954,20.32433216,20.26950478,20.2146774,20.15985002,20.10502264,20.05019526,19.99536788,19.9405405,19.88571312,19.83088574,19.77605836,19.72123098,19.6664036,19.61157622,19.55674884,19.50192146,19.44709408,19.3922667,19.33743932,19.28261194,19.22778456,19.17295718,19.1181298,19.06330242,19.00847504,18.95364766,18.89882028,18.8439929,18.78916552,18.73433814,18.67951076,18.62468337,18.56985599,18.51502861,18.46020123,18.40537385,18.35054647,18.29571909,18.24089171,18.18606433,18.13123695,18.07640957,18.02158219,17.96675481,17.91192743,17.85710005,17.80227267,17.74744529,17.69261791,17.63779053,17.58296315,17.52813577,17.47330839,17.41848101,17.36365363,17.30882625,17.25399887,17.19917149,17.14434411,17.08951673,17.03468935,16.97986197,16.92503459,16.87020721,16.81537983,16.76055245,16.70572507,16.65089769,16.59607031,16.54124293,16.48641555,16.43158817,16.37676079,16.32193341,16.26710603,16.21227865,16.15745127,16.10262389,16.04779651,15.99296913,15.93814175,15.88331437,15.82848699,15.77365961,15.71883223,15.66400485,15.60917747,15.55435009,15.49952271,15.44469533,15.38986795,15.33504057,15.28021319,15.22538581,15.17055843,15.11573105,15.06090367,15.00607629,14.9512489,14.89642152,14.84159414,14.78676676,14.73193938,14.677112,14.62228462,14.56745724,14.51262986,14.45780248,14.4029751,14.34814772,14.29332034,14.23849296,14.18366558,14.1288382,14.07401082,14.01918344,13.96435606,13.90952868,13.8547013,13.79987392,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654,13.74504654};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,98.25516759,95.73916821,93.22316882,90.70716943,88.19117004,88.34162459,88.49207914,88.64253369,88.79298824,88.94344279,89.09389735,89.2443519,89.39480645,89.545261,89.69571555,89.31029074,88.92486594,88.53944113,88.15401633,87.76859152,87.38316672,86.99774191,86.61231711,86.2268923,85.8414675,85.09612483,84.35078217,83.6054395,82.86009683,82.11475417,81.3694115,80.62406884,79.87872617,79.13338351,78.38804084,77.63430137,76.88056189,76.12682242,75.37308295,74.61934347,73.865604,73.11186453,72.35812505,71.60438558,70.85064611,69.93231394,69.01398177,68.0956496,67.17731743,66.25898526,65.34065309,64.42232092,63.50398875,62.58565658,61.66732441,60.35735819,59.04739198,57.73742576,56.42745955,55.11749333,53.80752711,52.4975609,51.18759468,49.87762847,48.56766225,47.58667073,46.60567921,45.62468769,44.64369617,43.66270465,42.68171313,41.7007216,40.71973008,39.73873856,38.75774704,38.0273445,37.29694195,36.5665394,35.83613686,35.10573431,34.37533176,33.64492922,32.91452667,32.18412413,31.45372158,31.25557513,31.05742869,30.85928224,30.66113579,30.46298935,30.2648429,30.06669646,29.86855001,29.67040356,29.47225712,29.27411067,29.07596422,28.87781778,28.67967133,28.48152489,28.28337844,28.08523199,27.88708555,27.6889391,27.49079265,27.29264621,27.09449976,26.89635332,26.69820687,26.50006042,26.30191398,26.10376753,25.90562108,25.70747464,25.50932819,25.31118175,25.1130353,24.91488885,24.71674241,24.51859596,24.32044951,24.12230307,23.92415662,23.72601018,23.52786373,23.32971728,23.13157084,22.93342439,22.73527794,22.5371315,22.33898505,22.14083861,21.94269216,21.74454571,21.54639927,21.34825282,21.15010637,20.95195993,20.75381348,20.55566704,20.35752059,20.15937414,19.9612277,19.76308125,19.5649348,19.36678836,19.16864191,18.97049547,18.77234902,18.57420257,18.37605613,18.17790968,17.97976323,17.78161679,17.58347034,17.38532389,17.18717745,16.989031,16.79088456,16.59273811,16.39459166,16.19644522,15.99829877,15.80015232,15.60200588,15.40385943,15.20571299,15.00756654,14.80942009,14.61127365,14.4131272,14.21498075,14.01683431,13.81868786,13.62054142,13.42239497,13.22424852,13.02610208,12.82795563,12.62980918,12.43166274,12.23351629,12.03536985,11.8372234,11.63907695,11.44093051,11.24278406,11.04463761,10.84649117,10.64834472,10.45019828,10.25205183,10.05390538,9.855758937,9.657612491,9.459466045,9.261319598,9.063173152,8.865026706,8.66688026,8.468733813,8.270587367,8.072440921,7.874294475,7.676148028,7.478001582,7.279855136,7.08170869,6.883562243,6.685415797,6.487269351,6.289122905,6.090976458,5.892830012,5.694683566,5.49653712,5.298390673,5.100244227,4.902097781,4.703951334,4.505804888,4.307658442,4.109511996,3.911365549,3.713219103,3.515072657,3.316926211,3.118779764,2.920633318,2.722486872,2.524340426,2.326193979,2.128047533,1.929901087,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641,1.731754641};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,154.986724,154.4529979,153.9192719,153.3855458,152.8518198,152.6868265,152.5218332,152.3568399,152.1918466,152.0268532,151.8618599,151.6968666,151.5318733,151.36688,151.2018867,150.5540613,149.9062359,149.2584105,148.6105851,147.9627597,147.3149343,146.6671088,146.0192834,145.371458,144.7236326,143.6128349,142.5020371,141.3912393,140.2804416,139.1696438,138.058846,136.9480483,135.8372505,134.7264528,133.615655,132.5500092,131.4843634,130.4187177,129.3530719,128.2874261,127.2217803,126.1561345,125.0904887,124.0248429,122.9591972,121.8833821,120.807567,119.7317519,118.6559368,117.5801217,116.5043066,115.4284915,114.3526764,113.2768613,112.2010462,110.671539,109.1420318,107.6125245,106.0830173,104.5535101,103.0240029,101.4944956,99.96498839,98.43548116,96.90597392,95.71827413,94.53057435,93.34287456,92.15517477,90.96747498,89.77977519,88.5920754,87.40437561,86.21667582,85.02897603,83.99101232,82.9530486,81.91508489,80.87712118,79.83915746,78.80119375,77.76323003,76.72526632,75.6873026,74.64933889,74.28309805,73.91685721,73.55061637,73.18437552,72.81813468,72.45189384,72.085653,71.71941216,71.35317132,70.98693047,70.62068963,70.25444879,69.88820795,69.52196711,69.15572627,68.78948542,68.42324458,68.05700374,67.6907629,67.32452206,66.95828122,66.59204038,66.22579953,65.85955869,65.49331785,65.12707701,64.76083617,64.39459533,64.02835448,63.66211364,63.2958728,62.92963196,62.56339112,62.19715028,61.83090943,61.46466859,61.09842775,60.73218691,60.36594607,59.99970523,59.63346438,59.26722354,58.9009827,58.53474186,58.16850102,57.80226018,57.43601934,57.06977849,56.70353765,56.33729681,55.97105597,55.60481513,55.23857429,54.87233344,54.5060926,54.13985176,53.77361092,53.40737008,53.04112924,52.67488839,52.30864755,51.94240671,51.57616587,51.20992503,50.84368419,50.47744334,50.1112025,49.74496166,49.37872082,49.01247998,48.64623914,48.2799983,47.91375745,47.54751661,47.18127577,46.81503493,46.44879409,46.08255325,45.7163124,45.35007156,44.98383072,44.61758988,44.25134904,43.8851082,43.51886735,43.15262651,42.78638567,42.42014483,42.05390399,41.68766315,41.32142231,40.95518146,40.58894062,40.22269978,39.85645894,39.4902181,39.12397726,38.75773641,38.39149557,38.02525473,37.65901389,37.29277305,36.92653221,36.56029136,36.19405052,35.82780968,35.46156884,35.095328,34.72908716,34.36284631,33.99660547,33.63036463,33.26412379,32.89788295,32.53164211,32.16540127,31.79916042,31.43291958,31.06667874,30.7004379,30.33419706,29.96795622,29.60171537,29.23547453,28.86923369,28.50299285,28.13675201,27.77051117,27.40427032,27.03802948,26.67178864,26.3055478,25.93930696,25.57306612,25.20682527,24.84058443,24.47434359,24.10810275,23.74186191,23.37562107,23.00938023,22.64313938,22.27689854,21.9106577,21.54441686,21.17817602,20.81193518,20.44569433,20.07945349,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265,19.71321265};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,66.0504185,66.82113386,67.59184922,68.36256459,69.13327995,69.84087376,70.54846758,71.25606139,71.9636552,72.67124902,73.37884283,74.08643665,74.79403046,75.50162427,76.20921809,76.88211628,77.55501446,78.22791265,78.90081084,79.57370903,80.24660722,80.91950541,81.5924036,82.26530179,82.93819998,83.5568034,84.17540683,84.79401026,85.41261368,86.03121711,86.64982054,87.26842397,87.88702739,88.50563082,89.12423425,89.57917466,90.03411508,90.48905549,90.94399591,91.39893632,91.85387674,92.30881716,92.76375757,93.21869799,93.6736384,94.16175227,94.64986613,95.13798,95.62609386,96.11420773,96.60232159,97.09043546,97.57854932,98.06666319,98.55477705,99.01013804,99.46549902,99.92086001,100.376221,100.831582,101.286943,101.742304,102.1976649,102.6530259,103.1083869,103.3303782,103.5523695,103.7743608,103.9963521,104.2183434,104.4403347,104.662326,104.8843173,105.1063086,105.3282999,105.5092538,105.6902077,105.8711616,106.0521155,106.2330694,106.4140233,106.5949772,106.7759311,106.956885,107.1378389,107.0440254,106.9502119,106.8563985,106.762585,106.6687715,106.574958,106.4811445,106.3873311,106.2935176,106.1997041,106.1058906,106.0120771,105.9182637,105.8244502,105.7306367,105.6368232,105.5430097,105.4491963,105.3553828,105.2615693,105.1677558,105.0739423,104.9801289,104.8863154,104.7925019,104.6986884,104.6048749,104.5110615,104.417248,104.3234345,104.229621,104.1358075,104.0419941,103.9481806,103.8543671,103.7605536,103.6667401,103.5729267,103.4791132,103.3852997,103.2914862,103.1976727,103.1038593,103.0100458,102.9162323,102.8224188,102.7286053,102.6347919,102.5409784,102.4471649,102.3533514,102.2595379,102.1657245,102.071911,101.9780975,101.884284,101.7904705,101.6966571,101.6028436,101.5090301,101.4152166,101.3214031,101.2275897,101.1337762,101.0399627,100.9461492,100.8523357,100.7585223,100.6647088,100.5708953,100.4770818,100.3832683,100.2894549,100.1956414,100.1018279,100.0080144,99.91420093,99.82038745,99.72657397,99.63276049,99.53894701,99.44513353,99.35132005,99.25750657,99.16369309,99.06987961,98.97606613,98.88225265,98.78843917,98.69462569,98.60081221,98.50699873,98.41318525,98.31937177,98.22555829,98.13174481,98.03793133,97.94411785,97.85030437,97.75649089,97.66267741,97.56886392,97.47505044,97.38123696,97.28742348,97.19361,97.09979652,97.00598304,96.91216956,96.81835608,96.7245426,96.63072912,96.53691564,96.44310216,96.34928868,96.2554752,96.16166172,96.06784824,95.97403476,95.88022128,95.7864078,95.69259432,95.59878084,95.50496736,95.41115388,95.3173404,95.22352692,95.12971344,95.03589996,94.94208648,94.848273,94.75445952,94.66064604,94.56683256,94.47301908,94.3792056,94.28539212,94.19157864,94.09776516,94.00395168,93.9101382,93.81632472,93.72251124,93.62869776,93.53488428,93.4410708,93.34725732,93.25344384,93.15963036,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688,93.06581688};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,227.8836549,228.5224904,229.161326,229.8001615,230.4389971,230.2554061,230.0718152,229.8882242,229.7046332,229.5210423,229.3374513,229.1538603,228.9702694,228.7866784,228.6030874,228.8602611,229.1174348,229.3746085,229.6317822,229.8889559,230.1461296,230.4033033,230.660477,230.9176507,231.1748244,230.6156446,230.0564648,229.497285,228.9381051,228.3789253,227.8197455,227.2605657,226.7013859,226.1422061,225.5830262,224.7914688,223.9999113,223.2083538,222.4167963,221.6252388,220.8336813,220.0421238,219.2505664,218.4590089,217.6674514,216.6787,215.6899486,214.7011972,213.7124459,212.7236945,211.7349431,210.7461917,209.7574403,208.7686889,207.7799375,206.6269899,205.4740423,204.3210946,203.168147,202.0151993,200.8622517,199.709304,198.5563564,197.4034087,196.2504611,195.3852363,194.5200115,193.6547867,192.7895618,191.924337,191.0591122,190.1938874,189.3286626,188.4634378,187.598213,186.2735938,184.9489746,183.6243555,182.2997363,180.9751171,179.6504979,178.3258787,177.0012596,175.6766404,174.3520212,173.4409779,172.5299346,171.6188913,170.707848,169.7968046,168.8857613,167.974718,167.0636747,166.1526314,165.2415881,164.3305448,163.4195014,162.5084581,161.5974148,160.6863715,159.7753282,158.8642849,157.9532416,157.0421982,156.1311549,155.2201116,154.3090683,153.398025,152.4869817,151.5759384,150.664895,149.7538517,148.8428084,147.9317651,147.0207218,146.1096785,145.1986352,144.2875918,143.3765485,142.4655052,141.5544619,140.6434186,139.7323753,138.821332,137.9102886,136.9992453,136.088202,135.1771587,134.2661154,133.3550721,132.4440288,131.5329854,130.6219421,129.7108988,128.7998555,127.8888122,126.9777689,126.0667256,125.1556822,124.2446389,123.3335956,122.4225523,121.511509,120.6004657,119.6894224,118.778379,117.8673357,116.9562924,116.0452491,115.1342058,114.2231625,113.3121192,112.4010758,111.4900325,110.5789892,109.6679459,108.7569026,107.8458593,106.934816,106.0237726,105.1127293,104.201686,103.2906427,102.3795994,101.4685561,100.5575128,99.64646944,98.73542613,97.82438281,96.9133395,96.00229618,95.09125287,94.18020955,93.26916624,92.35812293,91.44707961,90.5360363,89.62499298,88.71394967,87.80290635,86.89186304,85.98081973,85.06977641,84.1587331,83.24768978,82.33664647,81.42560315,80.51455984,79.60351653,78.69247321,77.7814299,76.87038658,75.95934327,75.04829995,74.13725664,73.22621333,72.31517001,71.4041267,70.49308338,69.58204007,68.67099675,67.75995344,66.84891013,65.93786681,65.0268235,64.11578018,63.20473687,62.29369355,61.38265024,60.47160693,59.56056361,58.6495203,57.73847698,56.82743367,55.91639035,55.00534704,54.09430373,53.18326041,52.2722171,51.36117378,50.45013047,49.53908715,48.62804384,47.71700053,46.80595721,45.8949139,44.98387058,44.07282727,43.16178395,42.25074064,41.33969733,40.42865401,39.5176107,38.60656738,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407,37.69552407};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9224141438801,1851.5942281087239,1875.3197021484375,1893.0016276041667,1912.5613403320312,1933.8615214029949,1956.7714945475261,1980.3113708496094,2003.5213826497395,2026.4313456217449,2049.061319986979,2071.411336263021,2093.5112915039062,2115.361328125,2136.9813232421875,2158.3812866210938,2179.5612996419272,2200.4012247721353,2220.76123046875,2240.6712036132812,2260.1712036132812,2279.2911783854165,2298.0611368815103,2316.4910888671875,2334.6010945638022,2352.441121419271,2370.0010579427085,2387.0809936523438,2403.5209757486978,2419.3409016927085,2434.5909423828125,2449.3208618164062,2463.5508829752603,2477.330810546875,2490.6907958984375,2503.6608072916665,2516.2608032226562,2528.4107462565103,2540.020711263021,2551.150675455729,2561.8106689453125,2572.0506591796875,2581.8906046549478,2591.3606160481772,2600.5006306966147,2609.3205769856772,2617.850545247396,2625.9405110677085,2633.4404907226562,2640.400431315104,2646.8604532877603,2652.8504231770835,2658.4104207356772,2663.5703938802085,2668.3603312174478,2672.8103637695312,2676.9403076171875,2680.6302490234375,2683.750244140625,2686.3501993815103,2688.470174153646,2690.1301472981772,2691.3901570638022,2692.2601318359375,2692.7901000976562,2692.9900919596353,2692.8900756835938,2692.4500528971353,2691.6400146484375,2690.480021158854,2688.9899698893228,2687.219970703125,2685.169921875,2682.8699544270835,2680.3499145507812,2677.6198933919272,2674.699910481771,2671.659912109375,2668.5499471028647,2665.3798828125,2662.159912109375,2658.8999226888022,2655.5999348958335,2652.2599283854165,2648.9099324544272,2645.5298868815103,2642.1299031575522,2638.6298828125,2634.929890950521,2631.0498860677085,2626.9998168945312,2622.799845377604,2618.4598795572915,2613.9798177083335,2609.379842122396,2604.6698404947915,2599.8598022460938,2594.9597778320312,2589.9598185221353,2584.8898111979165,2579.749755859375,2574.5397745768228,2569.2597859700522,2563.9397989908853,2558.5597534179688,2553.1297403971353,2547.6697794596353,2542.1697794596353,2536.6298014322915,2531.0597941080728,2525.4597981770835,2519.8397623697915,2514.1997680664062,2508.539754231771,2502.8597615559897,2497.1697387695312,2491.459757486979,2485.7497762044272,2480.029744466146,2474.2997436523438,2468.5597330729165,2462.8197428385415,2457.0797526041665,2451.3397216796875,2445.5997517903647,2439.8497721354165,2434.1097615559897,2428.3697509765625,2422.6397094726562,2416.9097290039062,2411.1797688802085,2405.4597371419272,2399.73974609375,2394.0297648111978,2388.3297526041665,2382.6397094726562,2376.949747721354,2371.269775390625,2365.5997314453125,2359.9397583007812,2354.2897745768228,2348.6497395833335,2343.019734700521,2337.3997395833335,2331.789754231771,2326.1897786458335,2320.5997517903647,2315.0197143554688,2309.4497884114585,2303.8997599283853,2298.3497314453125,2292.8197631835938,2287.2897338867188,2281.779744466146,2276.2797648111978,2270.789794921875,2265.309773763021,2259.8397216796875,2254.3797403971353,2248.9397989908853,2243.509765625,2238.0897623697915,2232.6797078450522,2227.279744466146,2221.8997395833335,2216.5297648111978,2211.1597696940103,2205.8097534179688,2200.479736328125,2195.1497802734375,2189.8297729492188,2184.52978515625,2179.2298177083335,2173.9497680664062,2168.6797485351562,2163.4097493489585,2158.1597696940103,2152.9197387695312,2147.6897583007812,2142.469767252604,2137.2597859700522,2132.059773763021,2126.8697509765625,2121.6897786458335,2116.519775390625,2111.3597819010415,2106.1997680664062,2101.0597534179688,2095.9297892252603,2090.809773763021,2085.699747721354,2080.5997721354165,2075.4997762044272,2070.4197794596353,2065.3497721354165,2060.2797648111978,2055.229746500651,2050.1797383626304,2045.1497701009114,2040.1197509765625,2035.0997517903645,2030.0897623697917,2025.0897521972656,2020.0997721354167,2015.1197713216145,2010.1397705078125,2005.1797281901042,2000.2197672526042,1995.269755045573,1990.3297627766926,1985.3997599283855,1980.479756673177,1975.5597432454426,1970.6497599283855,1965.749755859375,1960.8597615559895,1955.979736328125,1951.0997619628906,1946.229756673177,1941.3697611490886,1936.5197347005208,1931.6697591145833,1926.8297322591145,1921.999776204427,1917.1697692871094,1912.3597615559895,1907.5397644042969,1902.73974609375,1897.9397481282551,1893.1497599283855,1888.3697611490886,1883.5897623697917,1878.8197428385417,1874.0597534179688,1869.3097432454426,1864.5597432454426,1859.8097737630208,1855.2498270670574,1851.039815266927,1847.1498514811199,1843.5498453776042,1840.2198893229167,1837.1498718261719,1834.2998962402344,1831.6798909505208,1829.2498982747395,1826.9999084472656,1824.919942220052,1822.9999287923176,1821.2299499511719,1819.5799560546875,1818.0599466959636,1816.6499430338542,1815.3399759928386,1814.1299743652344,1813.0099792480469,1811.9699808756511,1810.9999898274739,1810.1099955240886,1809.2799886067708,1808.4999898274739,1807.7799886067708,1807.1199849446614,1806.489990234375,1805.9099934895833,1805.3699951171875,1804.8699951171875,1804.4000040690105,1803.9500122070312,1803.5400085449219,1803.1599934895833,1802.7899881998699,1802.4500325520833,1802.1299947102864,1801.8300170898438,1801.5500183105469,1801.280008951823,1801.0300191243489,1800.790018717448,1800.5599873860676,1800.3400166829426,1800.1400044759114,1799.9400227864583,1799.7600199381511,1799.5800170898438,1799.4100138346355,1799.2400207519531,1799.0900166829426,1798.9400024414062,1798.7899881998699,1798.6500040690105,1798.510009765625,1798.3800252278645,1798.2600199381511,1798.1300150553386,1798.010030110677,1797.9000040690105,1797.780029296875,1797.6700134277344,1797.5600280761719,1797.4599914550781,1797.3500264485676,1797.2500305175781,1797.1500142415364,1797.050028483073,1796.9500223795574,1796.8600158691406,1796.760030110677,1796.6700236002605,1796.5800170898438,1796.4900207519531,1796.4000142415364,1796.3100179036458,1796.2200113932292,1796.1399943033855,1796.0500183105469,1795.9700012207031,1795.8799947102864,1795.800028483073,1795.7200113932292,1795.6300557454426,1795.5500386555989,1795.4700215657551,1795.3900146484375,1795.3100179036458,1795.2300109863281,1795.1500345865886,1795.0700073242188,1794.9900004069011,1794.9100240071614,1794.8400065104167,1794.7600199381511,1794.6800231933594,1794.6100260416667,1794.5300191243489,1794.4500223795574,1794.3800048828125,1794.3000386555989,1794.2300109863281,1794.1500244140625,1794.0800170898438,1794.0100199381511,1793.9300028483074,1793.8600056966145,1793.790018717448,1793.7100321451824,1793.6400146484375,1793.5700276692708,1793.500020345052,1793.4200236002605,1793.3500162760417,1793.2800191243489,1793.2100016276042,1793.1400146484375,1793.0700073242188,1793.0,1792.9300231933594,1792.8600056966145,1792.7900390625,1792.7200215657551,1792.6500244140625,1792.5800170898438,1792.5200297037761,1792.4500325520833,1792.3799947102864,1792.3100280761719,1792.2500305175781,1792.1800130208333,1792.1100260416667,1792.0400288899739,1791.9800313313801,1791.9100240071614,1791.8500162760417,1791.7800191243489,1791.7100219726562,1791.6500244140625,1791.5800374348958,1791.52001953125,1791.4500122070312,1791.3900044759114,1791.3300069173176,1791.260030110677,1791.2000223795574,1791.1400146484375,1791.0700378417969,1791.0100199381511,1790.9500325520833,1790.8800150553386,1790.8200378417969,1790.760009765625,1790.7000020345051,1790.6400146484375,1790.5800272623699,1790.510030110677,1790.4500325520833,1790.3900349934895,1790.3300272623699,1790.2700297037761,1790.2100016276042,1790.1500142415364,1790.0900166829426,1790.030008951823,1789.9700113932292,1789.9100240071614,1789.8600260416667,1789.8000183105469,1789.7400207519531,1789.6800130208333,1789.6200256347656,1789.5700276692708,1789.5100199381511,1789.4500020345051,1789.3900248209636,1789.3400370279949,1789.280029296875,1789.2200317382812,1789.1700337727864,1789.1100158691406,1789.050028483073,1789.000020345052,1788.9400329589844,1788.8900044759114,1788.8300374348958,1788.7800191243489,1788.7200419108074,1788.6700236002605,1788.6100158691406,1788.5600077311199,1788.500020345052,1788.4500325520833,1788.4000142415364,1788.3400166829426,1788.2900085449219,1788.2300313313801,1788.1800435384114,1788.1300252278645,1788.0800170898438,1788.0200297037761,1787.9700113932292,1787.9200236002605,1787.8700256347656,1787.8100179036458,1787.7600199381511,1787.7100219726562,1787.6600138346355,1787.6100158691406,1787.5500183105469,1787.500020345052,1787.4500020345051,1787.4000040690105,1787.3500162760417,1787.300028483073,1787.2500305175781,1787.2000122070312,1787.1500244140625,1787.1000162760417,1787.0500183105469,1787.000020345052,1786.9400024414062,1786.8900146484375,1786.8400268554688,1786.8000081380208,1786.7500305175781,1786.7000020345051,1786.6500244140625,1786.6000264485676,1786.550028483073,1786.500020345052,1786.4500122070312,1786.4000142415364,1786.3500162760417,1786.300028483073,1786.2500101725261,1786.2000223795574,1786.1500244140625,1786.1000162760417,1786.0600077311199,1786.0100199381511,1785.9600118001301,1785.9099934895833,1785.8600158691406,1785.8100077311199,1785.760030110677,1785.7100219726562,1785.6700134277344,1785.6400248209636};
        CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9493891398112,403.1169611612956,405.74296315511066,408.5569585164388,411.3399607340495,414.10096486409503,416.8429590861003,419.61095937093097,422.4419581095378,425.334955851237,428.28996022542316,431.3079605102539,434.386957804362,437.52795664469403,440.73095448811847,443.9969533284505,447.324951171875,450.6959533691406,454.09295145670575,457.51795450846356,460.9729512532552,464.4569549560547,467.9729537963867,471.52095286051434,475.1019465128581,478.71695200602215,482.3659489949544,486.03294881184894,489.7029520670573,493.3779525756836,497.05895233154297,500.7469533284505,504.44395446777344,508.1499506632487,511.86695607503253,515.5939483642578,519.3319396972656,523.0739593505859,526.8129526774088,530.5479583740234,534.2809549967448,538.012949625651,541.7439473470052,545.4749552408854,549.2059478759766,552.9369557698568,556.667958577474,560.3909556070963,564.0969543457031,567.7869517008463,571.4619445800781,575.1209513346354,578.7649586995443,582.3939514160156,586.0089518229166,589.6099599202474,593.1969553629557,596.7399597167969,600.210947672526,603.6139577229818,606.9489542643229,610.2169596354166,613.4199625651041,616.5579579671224,619.6309611002604,622.6399637858073,625.5849609375,628.4629618326823,631.271962483724,634.011962890625,636.6819610595703,639.2829640706381,641.81396484375,644.2759653727213,646.6689758300781,648.9919738769531,651.2449645996094,653.4289703369141,655.5449778238932,657.5909729003906,659.5679677327474,661.4749755859375,663.3119761149088,665.0789693196615,666.7769673665365,668.4039764404297,669.9599660237631,671.4879709879557,673.0239766438802,674.5669809977213,676.1159820556641,677.66796875,679.2229766845703,680.7789662679037,682.3359883626302,683.8919728597006,685.4459838867188,686.9989725748698,688.5489756266276,690.094970703125,691.6379699707031,693.1769816080729,694.709971110026,696.2389780680338,697.7619832356771,699.2789815266927,700.7889862060547,702.2929840087891,703.7909698486328,705.2809804280599,706.7629750569662,708.2379811604818,709.7059783935547,711.1649729410807,712.6159871419271,714.0589752197266,715.4929860432943,716.9179840087891,718.3349761962891,719.7429809570312,721.1419728597006,722.531982421875,723.9119873046875,725.2829793294271,726.6439768473307,727.9959869384766,729.3379872639974,730.6699879964193,731.9919891357422,733.3039805094401,734.6059722900391,735.8979797363281,737.1799875895182,738.4509887695312,739.7119852701823,740.9619750976562,742.2019805908203,743.4289855957031,744.6409810384115,745.8369852701823,747.0179799397787,748.1829732259115,749.3329823811849,750.4669748942057,751.5859832763672,752.6899871826172,753.7779795328776,754.8499908447266,755.906992594401,756.948984781901,757.9739837646484,758.9839833577474,759.9789835611979,760.9569854736328,761.9199930826823,762.8669789632162,763.7989756266276,764.7149810791016,765.6139933268229,766.4989929199219,767.3669738769531,768.218983968099,769.0559895833334,769.875986735026,770.6809844970703,771.4699910481771,772.2429860432943,772.9989776611328,773.739990234375,774.4649709065756,775.1729838053385,775.8659922281901,776.5419871012369,777.2019856770834,777.8459981282552,778.4739939371744,779.0859934488932,779.6809895833334,780.260996500651,780.822987874349,781.3699951171875,781.8999888102213,782.4139963785807,782.9119923909506,783.3929901123047,783.8579864501953,784.3059895833334,784.7379913330078,785.1539866129557,785.5530039469401,785.9359893798828,786.3029988606771,786.6529947916666,786.9870045979818,787.3039906819662,787.604990641276,787.8889973958334,788.1569875081381,788.4090016682943,788.6439921061198,788.8619842529297,789.0649871826172,789.249989827474,789.4199829101562,789.5719960530599,789.708994547526,789.8289947509766,789.9319915771484,790.0189921061198,790.0889841715494,790.1429951985677,790.1809997558594,790.2019907633463,790.2060038248698,790.1949920654297,790.1659952799479,790.1219991048177,790.0599975585938,789.9829966227213,789.8889973958334,789.7780100504557,789.6510009765625,789.5079956054688,789.3479970296224,789.1719970703125,788.9789988199869,788.7700042724609,788.5449981689453,788.3029988606771,788.0449930826823,787.7709910074869,787.4799957275391,787.1729990641276,786.8490041097006,786.509999593099,786.1540018717448,785.7820027669271,785.4030049641927,785.0280049641927,784.6560007731119,784.2859954833984,783.9180043538412,783.5509999593099,783.1860046386719,782.8220011393229,782.4589996337891,782.0970001220703,781.7359975179037,781.3769989013672,781.0180002848307,780.6600036621094,780.3029988606771,779.9470011393229,779.5919952392578,779.2369893391927,778.8839975992838,778.5319976806641,778.1809946695963,777.8310038248698,777.4809977213541,777.1329956054688,776.7849985758463,776.4390055338541,776.0940093994141,775.7489980061849,775.405995686849,775.062998453776,774.7219950358073,774.3810017903646,774.0410003662109,773.7020060221354,773.365000406901,773.0280049641927,772.6920064290365,772.3569997151693,772.0229899088541,771.6890004475912,771.3569895426432,771.0249938964844,770.6940002441406,770.365000406901,770.0359903971354,769.7069956461588,769.3800048828125,769.0529937744141,768.7280069986979,768.4030100504557,768.0779978434244,767.7550048828125,767.4319966634115,767.1100056966146,766.7889912923177,766.4679972330729,766.1489969889323,765.8300018310547,765.5110015869141,765.1939900716146,764.8769989013672,764.5599975585938,764.2450002034506,763.9300028483073,763.615000406901,763.3019968668619,762.9889984130859,762.6759999593099,762.364003499349,762.0529988606771,761.7429962158203,761.4329986572266,761.1239980061849,760.8149922688802,760.5069936116537,760.1990102132162,759.8919932047526,759.5860036214193,759.2799987792969,758.9750010172526,758.6700083414713,758.3660024007162,758.0629933675131,757.759999593099,757.4569905598959,757.1559906005859,756.85400390625,756.5529937744141,756.2530059814453,755.9529978434244,755.6539967854818,755.3559977213541,755.0570017496744,754.7599945068359,754.4629974365234,754.1659901936849,753.8700002034506,753.5740051269531,753.2790018717448,752.9849955240885,752.6899922688802,752.3970031738281,752.1040089925131,751.8109944661459,751.5190073649088,751.2269999186198,750.9359995524088,750.64599609375,750.3550059000651,750.0659942626953,749.7759958902994,749.4879964192709,749.1990000406901,748.9109954833984,748.6239980061849,748.3370056152344,748.0509999593099,747.7649943033854,747.4789988199869,747.1939951578776,746.9099934895834,746.6259969075521,746.3420054117838,746.0589955647787,745.7759958902994,745.4939982096354,745.2120005289713,744.9300028483073,744.6490071614584,744.3689982096354,744.0890045166016,743.8090006510416,743.5299987792969,743.2509918212891,742.9729970296224,742.6950022379557,742.4170074462891,742.1400044759115,741.8639984130859,741.5880025227865,741.3120066324869,741.0370025634766,740.7619934082031,740.4870096842448,740.2129923502604,739.9399922688802,739.6670074462891,739.3939921061198,739.1219940185547,738.8499959309896,738.5779927571615,738.3070017496744,738.0370076497396,737.7659912109375,737.4969991048177,737.2269999186198,736.9580027262369,736.6900024414062,736.4219970703125,736.1539916992188,735.8870035807291,735.6200002034506,735.3529968261719,735.0870005289713,734.8209991455078,734.5559997558594,734.291005452474,734.0270029703776,733.7630004882812,733.4989929199219,733.2359975179037,732.9730021158854,732.7109934488932,732.4490000406901,732.187001546224,731.9260101318359,731.6649983723959,731.4049936930338,731.1449940999349,730.8850046793619,730.6260019938151,730.3669993082682,730.1080017089844,729.8500010172526,729.5929972330729,729.3350067138672,729.0790049235026,728.8219909667969,728.5660044352213,728.3100077311198,728.0549977620443,727.7999979654948,727.5449981689453,727.2910003662109,727.0369974772135,726.7840016682943,726.5310007731119,726.2779947916666,726.0259958902994,725.7740020751953,725.5219980875651,725.2710011800131,725.0199940999349,724.7699940999349,724.5200042724609,724.2699940999349,724.02099609375,723.7720031738281,723.5240020751953,723.2749989827474,723.0280049641927,722.7800038655599,722.5330047607422,722.2859954833984,722.0399932861328,721.7940012613932,721.5479939778646,721.3029988606771,721.0580088297526,720.8140004475912,720.5690002441406,720.3259938557943,720.0820058186849,719.8389994303385,719.5959981282552,719.3539988199869,719.1120096842448,718.8699951171875,718.6289978027344,718.3880004882812,718.1469980875651,717.9070027669271,717.667002360026,717.427001953125,717.1880086263021,716.9490051269531,716.7100016276041,716.4720001220703,716.2340037027994,715.9969940185547,715.7590077718099,715.5220082600912,715.2859954833984,715.0500030517578,714.8139902750651,714.5780029296875,714.3429972330729,714.1079966227213,713.9910024007162};
        HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.758116245269775,21.18809429804484,23.277893861134846,26.83599392573039,30.601293404897053,34.56809266408285,38.73089122772217,43.459290186564125,49.1103884379069,55.655086835225426,63.064785957336426,71.31208419799805,80.3707841237386,90.21518135070801,100.82098007202148,112.16297912597656,124.21997896830241,136.50497817993164,148.54997634887695,160.36297861735025,171.9519780476888,183.32497787475586,194.4909756978353,205.4549763997396,216.22597630818686,226.80997721354166,237.2129758199056,247.29497655232748,256.91897837320965,266.1009750366211,274.8529790242513,283.18897755940753,291.1229782104492,298.6669743855794,305.8329798380534,312.6329803466797,319.0789794921875,325.06197865804035,330.47998301188153,335.3489812215169,339.6859817504883,343.5079803466797,346.82898712158203,349.6649856567383,352.02998606363934,353.93898518880206,355.4049886067708,356.4159851074219,356.9599863688151,357.0499903361003,356.69998423258465,355.92198181152344,354.729985555013,353.1349817911784,351.14998626708984,348.7859853108724,346.0549901326497,342.99899037679035,339.65699005126953,336.0389938354492,332.15299224853516,328.00499216715497,323.60399627685547,318.95599365234375,314.0699946085612,308.95198822021484,303.60899353027344,298.12599182128906,292.58399709065753,286.98499806722003,281.3309961954753,275.6229934692383,269.86299896240234,264.0530014038086,258.19299697875977,252.28599802652994,246.33299763997397,240.40500005086264,234.56999842325845,228.82600021362305,223.16899998982748,217.5979995727539,212.11100006103516,206.70400110880533,201.37499872843424,196.1229985555013,190.94399897257486,185.8759994506836,180.95199966430664,176.16899871826172,171.52300008138022,167.00899759928384,162.62399927775064,158.3639996846517,154.2249984741211,150.20400110880533,146.296999613444,142.5009994506836,138.8139991760254,135.2310002644857,131.74899927775064,128.36600049336752,125.07999801635742,121.88599840799968,118.7819995880127,115.76699892679851,112.83599917093913,109.98799959818523,107.21999994913737,104.53099950154622,101.91699918111165,99.37629954020183,96.90719922383626,94.50729942321777,92.17459869384766,89.90719985961914,87.7031987508138,85.56069882710774,83.4778995513916,81.45309956868489,79.48449834187825,77.57059987386067,75.70959981282552,73.90009943644206,72.14050038655598,70.42939885457356,68.76540056864421,67.14699935913086,65.57279841105144,64.04169845581055,62.55229981740316,61.10339895884196,59.693699518839516,58.32219886779785,56.98769950866699,55.68909899393717,54.42519919077555,53.19519933064779,51.997898737589516,50.83249855041504,49.69789950052897,48.593199729919434,47.5175994237264,46.470099449157715,45.44989935557047,44.456299463907875,43.488399505615234,42.54539934794108,41.62659899393717,40.73119926452637,39.85859934488932,39.0080992380778,38.178998947143555,37.37069924672445,36.582499186197914,35.81379985809326,35.06399949391683,34.33259932200114,33.61899979909261,32.92269992828369,32.24309968948364,31.57979917526245,30.932199478149414,30.299899419148762,29.6822992960612,29.07919963200887,28.489899794260662,27.914099375406902,27.351399580637615,26.80139954884847,26.263699531555176,25.737899780273438,25.223599751790363,24.72059949239095,24.22839943567912,23.746699651082356,23.275299390157063,22.8136994043986,22.36169958114624,21.919099648793537,21.485399564107258,21.06049982706706,20.643999735514324,20.23579978942871,19.83549960454305,19.44289954503377,19.05779965718587,18.679999669392902,18.309099674224854,17.945099353790283,17.58769941329956,17.236599763234455,16.891799767812092,16.5529998143514,16.21999963124593,15.89259966214498,15.57069985071818,15.254199822743734,14.942699750264486,14.636299769083658,14.334699789683023,14.037699778874716,13.745299895604452,13.457299709320068,13.173599799474081,12.893999814987183,12.618399779001871,12.346599896748861,12.078699747721354,11.814399798711142,11.553599913914999,11.296299854914347,11.042299826939901,10.791499853134155,10.543799797693888,10.29919981956482,10.057499806086222,9.818589925765991,9.582499821980795,9.349069992701212,9.118250052134195,8.88992977142334,8.664060036341349,8.440539757410685,8.219320058822632,8.000319917996725,7.783479968706767,7.568719903628032,7.355989853541057,7.145220001538594,6.936359961827596,6.729349970817566,6.524130026499431,6.3206400871276855,6.1188398996988935,5.91867995262146,5.720099965731303,5.525599956512451,5.337599953015645,5.1558899482091265,4.980270028114319,4.810550053914388,4.646539926528931,4.488050063451131,4.334920008977254,4.186950047810872,4.043990035851796,3.9058799942334494,3.7724399964014688,3.643530031045278,3.5190000335375466,3.398699998855591,3.2824900150299072,3.170229971408844,3.061799963315328,2.957059999306997,2.8558899760246277,2.7581699887911477,2.6637800137201944,2.5726199944814048,2.4845599929491677,2.3995200395584106,2.3173799912134805,2.238040010134379,2.161419987678528,2.0874200065930686,2.0159399807453156,1.9469100038210552,1.8802499969800313,1.8158599932988484,1.7536699970563252,1.6936199963092804,1.635619988044103,1.5796000162760417,1.5254999995231628,1.4732600152492523,1.4227999945481618,1.374070018529892,1.3270100057125092,1.2815600037574768,1.2376699944337208,1.1952799956003826,1.1543499926726024,1.1148099998633068,1.0766299863656361,1.0397600134213765,1.0041499882936478,0.9697559972604116,0.9365440011024475,0.9044699966907501,0.87349400917689,0.8435799976189932,0.8146899988253912,0.7867909918228785,0.7598470002412796,0.7338260064522425,0.7086960027615229,0.6844279964764913,0.6609909931818644,0.6383569985628128,0.6164980034033457,0.5953879853089651,0.575001006325086,0.555312991142273,0.5362989902496338,0.5179369946320852,0.5002039968967438,0.4830779979626338,0.466538002093633,0.45056600123643875,0.4351399963100751,0.42024299999078113,0.40585600088040036,0.39196200172106427,0.37854399780432385,0.36558600266774494,0.3530709967017174,0.3409860009948413,0.3293139959375064,0.31804100175698596,0.3071549981832504,0.2966419979929924,0.28648900240659714,0.2766839986046155,0.26721400022506714,0.2580689986546834,0.24923699970046678,0.24070699885487556,0.23246900116403899,0.22451400011777878,0.2168309986591339,0.2094110002120336,0.20224499826629957,0.19532499959071478,0.1886410005390644,0.18218700091044107,0.17595299954215685,0.1699329987168312,0.16411900023619333,0.15850399931271872,0.15308099860946336,0.1478440004090468,0.14278599868218103,0.13790100067853928,0.13318400084972382,0.12862799813350043,0.12422799939910571,0.11997900033990543,0.11587499951322873,0.11191099944214027,0.10808400064706802,0.10438700020313263,0.10081699925164382,0.09736880039175351,0.09403879940509796,0.09082279913127422,0.0877168004711469,0.08471719982723395,0.08182019926607609,0.07902229949831963,0.07632019991676013,0.07371059929331143,0.0711902988453706,0.06875620037317276,0.06640540063381195,0.06413499948879083,0.06194240010033051,0.05982469984640678,0.057779499950508274,0.055804299811522164,0.05389659944921732,0.05205429966251055,0.0502749007816116,0.04855640046298504,0.04689680008838574,0.04529380022237698,0.04374580023189386,0.04225060064345598,0.04080660020311674,0.039412000216543674,0.03806520036111275,0.036764299497008324,0.035507999981443085,0.034294599977632366,0.033122800290584564,0.031991000597675644,0.030897899996489286,0.02984219991291563,0.028822600065420072,0.027837800172468025,0.026886799838393927,0.02596820006147027,0.025081099942326546,0.02422429978226622,0.02339679980650544,0.022597600240260363,0.0218257000669837,0.021080199784288805,0.020360200200229883,0.019664800104995567,0.01899309999619921,0.018344499946882326,0.01771800002704064,0.0171129001925389,0.016528500088800985,0.015964099982132513,0.0154188999440521,0.01489240008716782,0.014383900134513775,0.013892800081521273,0.013418400194495916,0.012960300004730621,0.012517800088971853,0.012090499823292097,0.011677700017268458,0.011279099931319555,0.010894000064581633,0.010522199949870506,0.010163000086322427,0.009816090033079186,0.009481049918880066,0.00915745017118752,0.008844899944961071,0.008543030126020312,0.008251479982088009,0.007969880088542899,0.007697909992809097,0.007435220022064944,0.007181500007087986,0.006936449984398981,0.006699769990518689,0.006471179930182795,0.006250390084460378,0.006037139993471404,0.0058311700510482,0.005632240014771621,0.0054400999409457045,0.005254520025725166,0.005075279972516,0.0049021500162780285,0.0047349400507907076,0.004573440024008353,0.004417449973213176,0.004266789959122737,0.004121269991931816,0.00398071005474776,0.003844960010610521,0.0037138400172504285,0.0035872000153176486,0.00346487001903976,0.0033467299848174057,0.0032326100044883788,0.0031223900344533226,0.0030159400193952024,0.0029131099969769516,0.0028138000052422285,0.002717869996558875,0.002625219989567995,0.0025357199871602156,0.0024492900314119956,0.0023658000282011926,0.002285159988484035,0.0022072700085118413,0.0021320400410331786,0.0020593699882738292,0.001989190020443251,0.0019214000009621184,0.0018559199913094442,0.0017926700044578563,0.0017315899895038456,0.001672579994192347,0.0016155900084413588,0.0015605399870158483,0.0015073700051289052,0.0014560200118770201,0.0014064099911289911,0.0013585000027281542,0.0013122200034558773,0.0012675199832301587,0.001224340017264088,0.0011826300178654492,0.0011423499866699178,0.0011034399988905836,0.0010658599979554613,0.001029559993185103,0.0010117199951006721};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.7739855448405,90.27671686808269,95.80340194702148,99.75603866577148,103.07932345072429,105.82043011983235,108.02481269836426,110.31132634480794,113.2552884419759,116.80707740783691,120.92583338419597,125.57053438822429,130.7041778564453,136.294802347819,142.3073298136393,148.71592076619467,155.49032592773438,162.11280314127603,168.10086313883463,173.49910736083984,178.3503735860189,182.68969345092773,186.5550626118978,189.97647094726562,192.98592249552408,195.61041386922201,197.87593587239584,199.79546610514322,201.3810183207194,202.65460968017578,203.63621520996094,204.34385299682617,204.79551060994467,205.00819142659506,204.99588775634766,204.77261352539062,204.3533452351888,203.67796071370444,202.69353103637695,201.41814931233725,199.87078475952148,198.0694491068522,196.0301310221354,193.76783498128256,191.2965545654297,188.6292953491211,185.77804946899414,182.76283518473306,179.59863917032877,176.2954559326172,172.8602778116862,169.30311584472656,165.6299565633138,161.84781392415366,157.96367899576822,153.98455174763998,149.91543197631836,145.79839070638022,141.66938400268555,137.53036626180014,133.37935384114584,129.21733792622885,125.04432169596355,120.86130777994792,116.66829617818196,112.46427981058757,108.25026766459148,104.08537356058757,100.022523244222,96.05614344278972,92.17886670430501,88.38497479756673,84.66898091634114,81.02547645568848,77.44986788431804,73.93765068054199,70.48453013102214,67.13850847880046,63.94422403971354,60.89170455932617,57.971887270609535,55.175947507222496,52.49580510457357,49.9240468343099,47.45348358154297,45.07740561167399,42.789826075236,40.61580181121826,38.57888698577881,36.67005729675293,34.88111718495687,33.20436668395996,31.632405916849773,30.158536593119305,28.776458899180096,27.480172793070476,26.26397959391276,25.122979482014973,24.051972548166912,23.046660264333088,22.102641741434734,21.216018358866375,20.383089701334637,19.60015646616618,18.864218552907307,18.171977043151855,17.52083158493042,16.90788221359253,16.330830017725628,15.787174701690674,15.274816274642944,14.79165514310201,14.335791428883871,13.90552568435669,13.499157349268595,13.114986975987753,12.751714706420898,12.407940785090128,12.082364797592163,11.773687362670898,11.481008609135946,11.203128178914389,10.939146677652994,10.688064018885294,10.449180126190186,10.221494992574057,10.004509449005127,9.797312498092651,9.599364757537842,9.41002623240153,9.228756984074911,9.055006980895996,8.888286272684732,8.728134950002035,8.574113130569458,8.425840854644775,8.282928148905436,8.145014683405558,8.011790792147318,7.882946689923604,7.7581920226414995,7.637257178624471,7.5198919375737505,7.405876437822978,7.294990579287211,7.187024434407552,7.081788142522176,6.979121486345927,6.878844698270162,6.780807733535767,6.684860348701477,6.590893069903056,6.498755574226379,6.408337831497192,6.319539984067281,6.23225200176239,6.1463838418324785,6.061845739682515,5.978557348251343,5.896438876787822,5.815410296122233,5.735421697298686,5.656403024991353,5.578294237454732,5.501045346260071,5.424596428871155,5.348917484283447,5.273938337961833,5.199639320373535,5.125970085461934,5.052910923957825,4.980401714642842,4.908432443936666,4.8369730313618975,4.7659837404886884,4.695454398790996,4.625344912211101,4.555635452270508,4.486315925916036,4.4173663854599,4.348756909370422,4.280477325121562,4.212517698605855,4.144848187764485,4.077468593915303,4.01035890976588,3.9435092012087503,3.8769095738728843,3.8105498552322388,3.744410216808319,3.6784904996554055,3.6127807895342507,3.54728102684021,3.4819612900416055,3.4168315529823303,3.3518817822138467,3.2871020237604776,3.222492237885793,3.1580424507459006,3.093752682209015,3.029602825641632,2.9656030535697937,2.90175324678421,2.8380334178606668,2.7744436264038086,2.7109838128089905,2.647653957207998,2.5844441453615823,2.521354297796885,2.4583744208017984,2.3955145875612893,2.332764744758606,2.270124892393748,2.207585016886393,2.145145138104757,2.0828153093655906,2.0205754041671753,1.958435555299123,1.8963856895764668,1.8344358106454213,1.7725659211476643,1.7107960681120555,1.6491061449050903,1.5875062843163807,1.5259863932927449,1.4645465016365051,1.4031966030597687,1.3419167200724285,1.280726820230484,1.2196069260438283,1.158567061026891,1.0975971122582753,1.0366972386837006,0.9758733212947845,0.9151224692662557,0.8544404158989588,0.7938267737627029,0.7354611059029897,0.6813533355792364,0.6311973631381989,0.584707314769427,0.5416207959254583,0.5016910036404928,0.46468989302714664,0.4304044892390569,0.3986368378003438,0.36920494089523953,0.3419378101825714,0.3166774759689967,0.29327794909477234,0.27160223325093585,0.25152435650428134,0.23292631904284158,0.21570114294687906,0.19974782566229501,0.18497139091293016,0.17128684123357138,0.15861318136254945,0.1468754236896833,0.1360055779417356,0.12593863780299822,0.11661662968496482,0.10798454657196999,0.09998938937981923,0.09258707923193772,0.08573190184930961,0.07938407796124618,0.07350589893758297,0.06806287728250027,0.06302261135230462,0.058355607402821384,0.05403396487236023,0.05003239028155804,0.04632698278874159,0.04289604723453522,0.03971908458818992,0.03677739668637514,0.03405358580251535,0.031531453443070255,0.029196101240813732,0.027033730565259855,0.025031543026367824,0.02317753992974758,0.021460922279705603,0.019871490852286417,0.01839974693333109,0.01703699181477229,0.015775225590914488,0.014606849756091833,0.013525064413746199,0.012523370950172344,0.011595969321206212,0.01073716045357287,0.009941994988669952,0.009205723103756705,0.008523985355471572,0.007892752376695475,0.007308264418194692,0.006767071899957955,0.006265954968209068,0.00580196431837976,0.005372339898409943,0.0049745321739465,0.0046061812511955695,0.0042651173037787276,0.003949310960403333,0.0036569020012393594,0.003386140703999748,0.0031354273087345064,0.002903291974992802,0.0026883347503220043,0.0024893059162423015,0.002305015475333979,0.0021343735667566457,0.0019763603437847146,0.0018300558634412785,0.001694580219918862,0.0015691335526450227,0.0014529758676265676,0.0013454272702801973,0.0012458378332667053,0.0011536176413452874,0.0010682267214482029,0.0009891640996405233,0.0009159508384376144,0.0008481590484734625,0.000785384705523029,0.0007272588651782522,0.0006734355702064931,0.000623596875811927,0.0005774477661664908,0.0005347153006975228,0.0004951454902766272,0.00045850538056887064,0.00042457697903349373,0.00039315931401991594,0.00036406839596262824,0.0003371292574835631,0.00031218490039464086,0.00028908735112054273,0.0002676986162744773,0.00024789271750099334,0.00022955266467761248,0.00021256946517193379,0.00019684413321859515,0.00018228167634030493,0.0001687971077141507,0.00015631043061148375,0.00014474865747615695,0.00013404078830111152,0.00012412584389191275,0.00011494481683863948,0.00010644271787896287,9.857035305079383e-05,9.12800248139926e-05,8.452904148725793e-05,7.827760479509986e-05,7.248851761687547e-05,6.71277866786113e-05,6.216361271071946e-05,5.756670028252605e-05,5.330985125813944e-05,4.936776834559472e-05,4.571735583643507e-05,4.233701444415298e-05,3.920664585166378e-05,3.63078531033049e-05,3.3623437957430724e-05,3.113750093082975e-05,2.8835545587450422e-05,2.6703771103105584e-05,2.4729580369845888e-05,2.2901474342991907e-05,2.1208553486455155e-05,1.9640819724979035e-05,1.818897362682037e-05,1.6844515963991096e-05,1.5599447730589116e-05,1.4446470080050252e-05,1.3378783099445476e-05,1.2389987887218012e-05,1.1474285050402008e-05,1.062627469157936e-05,9.840967929145942e-06,9.113724900089437e-06,8.440246347163338e-06,7.816552397343912e-06,7.238963500337074e-06,6.704070187879552e-06,6.208712648003711e-06,5.749981293471744e-06,5.325146238040664e-06,4.931707849209488e-06,4.567356503078675e-06,4.229932301313966e-06,3.917445288455686e-06,3.6280459880799754e-06,3.36004435060507e-06,3.111840612746164e-06,2.881984964157406e-06,2.6691074973920572e-06,2.4719584151474314e-06,2.2893777327226417e-06,2.120295638026922e-06,1.9637022224590814e-06,1.8186775416021799e-06,1.6843617534808193e-06,1.5599749474404234e-06,1.4447771263803588e-06,1.3380884145893408e-06,1.2392788922473603e-06,1.1477785809195968e-06,1.0630275160868525e-06,9.845378438437062e-07,9.11847540881657e-07,8.445256630314665e-07,7.821762532482049e-07,7.244313688185381e-07,6.70952028751041e-07,6.214212694051943e-07,5.755491135535825e-07,5.330646217771573e-07,4.937167759067052e-07,4.5727464244767663e-07,4.235242130334882e-07,3.922645201252332e-07,3.6331358188590457e-07,3.3650041804852055e-07,3.116670418042607e-07,2.8866647738823303e-07,2.6736473775675523e-07,2.476348169485239e-07,2.2936175033313097e-07,2.124375401516924e-07,1.967631995114516e-07,1.8224573613186598e-07,1.6879915539410226e-07,1.5634547523291076e-07,1.448106926223621e-07,1.3412782469875614e-07,1.2423286873305037e-07,1.1506883860571786e-07,1.065807347562971e-07,3.335419288911604e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.744826078414917,19.401511192321777,20.6254137357076,22.65611473719279,24.764015356699627,26.947916348775227,29.206718762715656,31.75482193628947,34.80192502339681,38.33832836151123,42.35453097025553,46.8413340250651,51.78943729400635,57.19003995259603,63.03434371948242,69.31384595235188,76.0201473236084,82.92524719238281,89.80544853210449,96.66184870402019,103.4950491587321,110.30604934692383,117.0950501759847,123.86305173238118,130.61005210876465,137.33805465698242,144.04604975382486,150.6500498453776,157.06605275472006,163.2980499267578,169.34904988606772,175.22204971313477,180.9230524698893,186.45205052693686,191.81505076090494,197.0140495300293,202.0520451863607,206.86204401652017,211.3740463256836,215.59604517618814,219.5330441792806,223.19004185994467,226.57103856404623,229.68303934733072,232.5300381978353,235.11803690592447,237.45003382364908,239.5190340677897,241.31603240966797,242.84503046671549,244.11302947998047,245.12302907307944,245.88102849324545,246.3900260925293,246.6560262044271,246.68302536010742,246.4750239054362,246.04902267456055,245.4220199584961,244.5970204671224,243.57702000935873,242.36601765950522,240.968017578125,239.38501485188803,237.62201436360678,235.68201319376627,233.56701151529947,231.3230120340983,228.99300893147787,226.58001200358072,224.08500798543295,221.50900522867838,218.85400772094727,216.1210060119629,213.31200536092123,210.42800521850586,207.4700050354004,204.47900517781576,201.4960060119629,198.51900482177734,195.54800415039062,192.58500162760416,189.62800470987955,186.677001953125,183.73300170898438,180.79500198364258,177.86400349934897,174.96100107828775,172.10600407918295,169.30000178019205,166.54100290934244,163.8280029296875,161.16100056966147,158.53900273640951,155.96000035603842,153.42500178019205,150.93300120035806,148.48200352986655,146.07200241088867,143.7020034790039,141.37200419108072,139.08100382486978,136.828000386556,134.6130027770996,132.43500010172525,130.29300181070963,128.1870034535726,126.11600176493327,124.0800011952718,122.07700157165527,120.10800234476726,118.17100143432617,116.26700210571289,114.39400227864583,112.55300203959148,110.74200248718262,108.9610029856364,107.21000226338704,105.48800086975098,103.7940018971761,102.12800280253093,100.4900016784668,98.87890179951985,97.29450225830078,95.73630142211914,94.2038008371989,92.69660250345866,91.21420224507649,89.75629997253418,88.32230186462402,86.91190083821614,85.52470143636067,84.1603012084961,82.81830151875813,81.49820200602214,80.19980239868164,78.92250188191731,77.66620063781738,76.43030166625977,75.21460088094075,74.01870155334473,72.8422025044759,71.68480237325032,70.54620107014973,69.42600123087566,68.32400194803874,67.23970158894856,66.17300160725911,65.12340227762859,64.09060128529866,63.0745013554891,62.07460085550944,61.09080123901367,60.12260150909424,59.169901847839355,58.23230139414469,57.30970128377279,56.401601791381836,55.50790055592855,54.628401120503746,53.76270135243734,52.91060129801432,52.07180150349935,51.24620087941488,50.43350092569987,49.633401234944664,48.84580103556315,48.07040055592855,47.3070011138916,46.55530071258545,45.81520080566406,45.086501121520996,44.36890125274658,43.6623010635376,42.96640110015869,42.28100077311198,41.606001218159996,40.94120089213053,40.28640111287435,39.64130083719889,39.005900382995605,38.38000075022379,37.76330025990804,37.15570068359375,36.55710093180338,35.967300732930504,35.386000633239746,34.813300450642906,34.2488005956014,33.692501068115234,33.14420064290365,32.60370031992594,32.07100089391073,31.545800526936848,31.028000831604004,30.517500559488933,30.01420036951701,29.517900307973225,29.02850087483724,28.54590082168579,28.069900671641033,27.600400765736897,27.13740078608195,26.6806001663208,26.229900360107422,25.785300413767498,25.34660053253174,24.91380023956299,24.486700534820557,24.06510003407796,23.649100462595623,23.238500277201336,22.833200295766193,22.433000087738037,22.03800042470296,21.64800039927165,21.262900352478027,20.88260014851888,20.507100741068523,20.13610013326009,19.769800662994385,19.40790017445882,19.050400257110596,18.697200139363606,18.34820048014323,18.003300348917644,17.662500222524006,17.325700124104817,16.992899894714355,16.66380023956299,16.33850034077962,16.016900221506756,15.698999961217245,15.38450002670288,15.073600053787231,14.76610000928243,14.462000131607056,14.162499984105429,13.869100014368692,13.581600109736124,13.29990005493164,13.02400000890096,12.753600041071573,12.488799969355265,12.229400078455607,11.975199858347574,11.726299921671549,11.482500076293945,11.243699868520102,11.009800036748251,10.780699968338013,10.556399901707968,10.336700042088827,10.121499935785929,9.910759925842285,9.704390048980713,9.50228993097941,9.30438001950582,9.110570033391317,8.920780181884766,8.734930117925009,8.552929957707724,8.374719937642416,8.200209935506185,8.029329895973206,7.862000028292338,7.698139985402425,7.537700017293294,7.380599935849507,7.226760069529216,7.076130032539368,6.928640007972717,6.784209966659546,6.642800052960713,6.504319985707601,6.36873992284139,6.235979994138082,6.105989972750346,5.978700041770935,5.8540700276692705,5.732030034065247,5.612549980481465,5.495550036430359,5.380990068117778,5.26882004737854,5.158980051676433,5.0514399607976275,4.9461400508880615,4.843040029207866,4.742090026537578,4.643240014712016,4.546449939409892,4.451680064201355,4.358889937400818,4.268030047416687,4.179069995880127,4.091970006624858,4.006680011749268,3.923170030117035,3.8413999875386557,3.761340022087097,3.6829499999682107,3.6061899860699973,3.531029999256134,3.45743997891744,3.385390023390452,3.3148399790128074,3.2457600434621177,3.1781199971834817,3.1118899981180825,3.0470400055249534,2.983549972375234,2.9213799834251404,2.8605100313822427,2.8009000221888223,2.7425400018692017,2.6853999892870584,2.629450003306071,2.574659983317057,2.521019995212555,2.4684999783833823,2.417069991429647,2.3667100270589194,2.3174099922180176,2.269129971663157,2.2218599915504456,2.175569991270701,2.1302499969800315,2.0858800212542215,2.0424299836158752,1.9998899896939595,1.9582299987475078,1.9174399971961975,1.8775099913279216,1.8383999864260356,1.800109992424647,1.7626200119654338,1.7259099980195363,1.6899700164794922,1.6547700067361195,1.6203099985917409,1.5865700046221416,1.5535299976666768,1.521179993947347,1.4895099997520447,1.458489994208018,1.4281200071175892,1.398389995098114,1.3692700068155925,1.3407600025335948,1.312850018342336,1.2855199972788494,1.2587500115235646,1.2325499951839447,1.2068900068600972,1.1817599932352703,1.1571599940458934,1.1330799758434296,1.1094900071620941,1.0864000022411346,1.0637799898783367,1.0416399935881298,1.0199600060780842,0.998732994000117,0.9779470066229502,0.9575940072536469,0.9376650005578995,0.918151006102562,0.8990439971288046,0.8803360064824423,0.8620169907808304,0.8440789928038915,0.8265149941047033,0.8093179861704508,0.7924779951572418,0.7759900043408076,0.7598449935515722,0.744036003947258,0.7285559972127279,0.7133989979823431,0.6985580027103424,0.6840259929498037,0.6697969983021418,0.6558639903863271,0.6422210137049357,0.6288620034853617,0.6157819976409277,0.602973997592926,0.5904329965511957,0.578153004248937,0.5661289989948273,0.5543550004561743,0.5428259968757629,0.5315379997094473,0.5204840004444122,0.5096609989802042,0.49906300008296967,0.4886849969625473,0.4785240019361178,0.46857499827941257,0.4588320006926854,0.44929200162490207,0.43995100011428195,0.4308050001660983,0.42184900244077045,0.41307900100946426,0.40449200570583344,0.3960840031504631,0.38785000145435333,0.37978799889485043,0.3718939969937007,0.36416399975617725,0.3565950021147728,0.34918399651845294,0.3419269993901253,0.3348210006952286,0.3278619994719823,0.3210489973425865,0.31437699993451435,0.3078449989358584,0.301447997490565,0.295184001326561,0.28905099878708523,0.2830449988444646,0.2771640047430992,0.27140600234270096,0.2657669981320699,0.26024600118398666,0.2548389981190364,0.24954500049352646,0.24436199789245924,0.23928600052992502,0.23431499923268953,0.22944800183176994,0.22468299915393194,0.22001600017150244,0.2154460002978643,0.2109720011552175,0.20659000054001808,0.20229999845226607,0.19809899851679802,0.1939850002527237,0.18995699907342592,0.1860130007068316,0.1821499988436699,0.17836800093452135,0.17466500028967857,0.17103799929221472,0.1674869991838932,0.16401000196735063,0.16060500095287958,0.15727100148797035,0.15400700271129608,0.1508100007971128,0.14767899985114732,0.14461400111516318,0.14161199952165285,0.13867300003767014,0.13579499845703444,0.13297699764370918,0.13021700084209442,0.12751500060160956,0.12486799992620945,0.12227700029810269,0.11973999937375386,0.11725499977668126,0.11482200026512146,0.1124399999777476,0.11010700029631455,0.10782199849685033,0.10558499892552693,0.10339500072101752,0.10125000029802322,0.09914960091312726,0.09709280046323936,0.09507869929075241,0.09310650018354256,0.09117529975871246,0.0892841996004184,0.08743239939212799,0.08561900009711583,0.08384330073992412,0.08210450038313866,0.08040179871022701,0.07873449847102165,0.07790959998965263};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.475468754768372,7.644590258598328,7.5821510553359985,7.351803541183472,7.034174958864848,6.670892596244812,6.283040404319763,6.031920234362285,6.003215670585632,6.09158472220103,6.241515437761943,6.423887809117635,6.623361508051555,6.8318190574646,7.045004407564799,7.260554194450378,7.47737733523051,7.599294344584147,7.574405590693156,7.470492521921794,7.323771397272746,7.153462529182434,6.969846526781718,6.7784413894017534,6.582248727480571,6.382908463478088,6.181307355562846,5.994727412859599,5.832496285438538,5.6828276713689165,5.53938623269399,5.398821949958801,5.259380300839742,5.1201203266779585,4.980591257413228,4.8405522108078,4.69991405804952,4.556950807571411,4.410707910855611,4.262391448020935,4.112694164117177,3.962006072203318,3.810567557811737,3.6585387786229453,3.5059996445973716,3.3530311981836953,3.1996904412905374,3.0528792341550193,2.9164067109425864,2.785459021727244,2.6573831836382547,2.5307810505231223,2.404869715372721,2.2792693177858987,2.1537490685780845,2.0282096366087594,1.9025885462760925,1.785470853249232,1.6815720001856487,1.5848521788914998,1.491973986228307,1.4011311928431194,1.3113389412562053,1.2220683296521504,1.1330078442891438,1.0440280040105183,0.9550462663173676,0.8753304928541183,0.8100561102231344,0.7527533024549484,0.6998274972041448,0.6493095010519028,0.6001143306493759,0.5516485522190729,0.5035775005817413,0.45572537432114285,0.4079948589205742,0.3670269747575124,0.3365226561824481,0.31180677314599353,0.29028238852818805,0.2705234959721565,0.2517368483046691,0.23349455371499062,0.21555449441075325,0.19778001805146536,0.18009700005253157,0.16614008446534476,0.15793399512767792,0.15290448690454164,0.1496263469258944,0.14731364324688911,0.14553169285257658,0.14404417450229326,0.14271489282449087,0.14147573336958885,0.1402876377105713,0.13912858565648398,0.13798456018169722,0.13685053711136183,0.13572253411014876,0.13459552451968193,0.13347351551055908,0.13235350946585336,0.13123750189940134,0.13012349916001162,0.1290114919344584,0.12790149201949438,0.12679148837924004,0.12568448359767595,0.12458047457039356,0.12347946688532829,0.12238046464820702,0.12128445444007714,0.120190454646945,0.11909545461336772,0.11800444188217322,0.11691743570069472,0.1158324306209882,0.11475042502085368,0.11367141641676426,0.1125944157441457,0.11151641545196374,0.110442403703928,0.1093723972638448,0.1083043913046519,0.10723938730855782,0.1061733899017175,0.10511137607196967,0.10405336941281955,0.1029973638554414,0.10194435839851697,0.10089335218071938,0.09984534854690234,0.0987963496396939,0.09775113749007384,0.09670903285344441,0.09566962532699108,0.09463281991581123,0.09359831425050895,0.09256621077656746,0.091533113270998,0.09050380066037178,0.08947749497989814,0.08845388951400916,0.08743278495967388,0.08641387894749641,0.08539727392295997,0.0843795786301295,0.08336556392411391,0.08235445991158485,0.08134585494796436,0.08033954973022144,0.07933544429639976,0.07833354050914447,0.07733034466703732,0.07633073193331559,0.0753339280684789,0.07433942146599293,0.0733471183727185,0.07235691323876381,0.07136860738197963,0.07037911315759023,0.06939289967219035,0.06840939757724603,0.06742819150288899,0.0664489883929491,0.06547168176621199,0.06449617973218362,0.06351938440153997,0.06254577077925205,0.06157466924438874,0.06060576190551122,0.05963865978022417,0.05867345413813988,0.05770985161264738,0.05674485738078753,0.055782842449843884,0.054823342710733414,0.053865834760169186,0.052910033613443375,0.05195602805664142,0.051003526585797467,0.05004933259139458,0.04909821723898252,0.04814941746493181,0.047202409555514656,0.04625721058497826,0.04531340176860491,0.04437120507160822,0.043427205023666225,0.0424860967323184,0.04154729284346104,0.04061018799742063,0.03967458661645651,0.038740478766461216,0.03780778218060732,0.03687318290273348,0.0359413738672932,0.03501177206635475,0.03408376437922319,0.03315716733535131,0.03222876771663626,0.03130326000973582,0.030379656702280045,0.029457751971979935,0.02853715093806386,0.027617944094041984,0.02669994750370582,0.02577984845265746,0.024862440768629313,0.023946937173604965,0.02303303328032295,0.02212033172448476,0.021208826452493668,0.020298528329779703,0.0193860304231445,0.01847622248654564,0.017568119646360476,0.016661515925079584,0.015756113920360804,0.014851809479296207,0.013948510711391767,0.013043113440896073,0.012140205828472972,0.011239003157243133,0.010339099758615097,0.009440407622605562,0.008542703775068125,0.007645964544887344,0.006746978188554446,0.005850420566275716,0.004955526480140786,0.004061898003177096,0.0031693231818887093,0.0022777342334544906,0.001386931398883462,0.0007111838640412316,0.00036428624055891606,0.00018659332393629788,9.550885564143148e-05,4.8880555368668865e-05,2.5003689188451972e-05,1.2788030668768139e-05,6.537771393292739e-06,3.3418279864842284e-06,1.7076653004248026e-06,8.72478755316782e-07,4.4565260282070085e-07,2.2760338088308649e-07,8.59133493236186e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0912393530209858,1.2003816366195679,1.2754012842973073,1.3648312191168468,1.4513312379519145,1.5350212156772614,1.6160013576348622,1.7020615140597026,1.8007916510105133,1.911831796169281,2.0348519384860992,2.169512073198954,2.3154922326405845,2.4724923769632974,2.6402125159899392,2.8183526595433555,3.0066426595052085,3.1962526440620422,3.3786125977834067,3.553942561149597,3.722432573636373,3.8842925230662027,4.0397025148073835,4.188842495282491,4.331892490386963,4.469012459119161,4.600382447242737,4.725252389907837,4.842932383219401,4.953602313995361,5.057452201843262,5.154662211736043,5.245412190755208,5.329862117767334,5.408182104428609,5.480532089869182,5.547072013219197,5.606401999791463,5.657151858011882,5.699541727701823,5.733791788419087,5.7601116100947065,5.778711557388306,5.789771477381389,5.793511430422465,5.790101369222005,5.779731273651123,5.763111273447673,5.740941206614177,5.7133510907491045,5.680471062660217,5.642451008160909,5.599401036898295,5.551450808842977,5.498740792274475,5.441370765368144,5.379470705986023,5.314090649286906,5.246280670166016,5.176090598106384,5.1035705010096235,5.0287706057230634,4.9517505168914795,4.8725703954696655,4.79127037525177,4.707900404930115,4.6225303411483765,4.536200324694316,4.4499402443567915,4.363760272661845,4.2776503165562945,4.191600203514099,4.105610251426697,4.019690116246541,3.9338201681772866,3.8480101227760315,3.76226011912028,3.677260140577952,3.593690117200216,3.511510133743286,3.4307000637054443,3.351210097471873,3.273020108540853,3.19609006245931,3.1203900973002114,3.0458900729815164,2.972560087839762,2.900710086027781,2.8306500713030496,2.762320081392924,2.695690075556437,2.6307100454966226,2.567340056101481,2.5055400729179382,2.445270081361135,2.386490066846212,2.329180041948954,2.273280064264933,2.218760053316752,2.165600081284841,2.113750080267588,2.0631900429725647,2.0138900578022003,1.9658000469207764,1.918900042772293,1.8731700579325359,1.828570048014323,1.78507004181544,1.7426600456237793,1.701290061076482,1.6609500547250111,1.621600051720937,1.583230048418045,1.5458100537459056,1.5093200504779816,1.4737400511900585,1.4390300512313843,1.4051800568898518,1.3721700410048168,1.3399800459543865,1.3085800409317017,1.2779600322246552,1.2481000522772472,1.2189700603485107,1.1905700266361237,1.1628600458304088,1.1358400483926137,1.1094900568326314,1.08378005027771,1.0587100386619568,1.0342600345611572,1.0104100207487743,0.9871460398038229,0.9644520481427511,0.9423160453637441,0.9207240442434946,0.8996610393126806,0.8791150401035944,0.8590710262457529,0.8395140419403712,0.8204360405604044,0.8018240382273992,0.7836650361617407,0.7659490406513214,0.7486610412597656,0.7317920327186584,0.7153320411841074,0.6992710332075754,0.6835980316003164,0.668303037683169,0.6533780346314112,0.6388090352217356,0.6245880325635275,0.610709031422933,0.5971610347429911,0.5839370389779409,0.5710290322701136,0.5584270258744558,0.5461220393578211,0.534107024470965,0.5223750323057175,0.5109190295139948,0.4997330332795779,0.4888090292612712,0.47814002881447476,0.46771803001562756,0.4575350309411685,0.4475890249013901,0.4378720273574193,0.4283790240685145,0.41910402476787567,0.4100400259097417,0.40118102729320526,0.3925210287173589,0.38405702263116837,0.3757840270797412,0.36769602447748184,0.3597880279024442,0.35205702235301334,0.34449502825737,0.33709702144066495,0.3298620233933131,0.3227860207358996,0.3158620198567708,0.3090890198945999,0.30246001730362576,0.29597002019484836,0.2896190236012141,0.2834020232160886,0.27731601893901825,0.2713580181201299,0.2655240148305893,0.25980901966492337,0.2542090242107709,0.24872301643093428,0.24334901571273804,0.2380840132633845,0.23292401432991028,0.22786701346437135,0.22290701419115067,0.21804301192363104,0.21327401449282965,0.20859701558947563,0.2040100134909153,0.1995100130637487,0.19509501258532205,0.19076001023252806,0.18650401135285696,0.18232700849572817,0.17822601025303206,0.17419900993506113,0.1702440120279789,0.16636000821987787,0.16254200786352158,0.15878800799449286,0.15509900947411856,0.15147400895754495,0.1479090079665184,0.14440500736236572,0.14095600694417953,0.13756200795372328,0.13422400504350662,0.13093800470232964,0.12770500406622887,0.12452300513784091,0.1213900043318669,0.11830300465226173,0.11526100275417168,0.11226500322421391,0.10931300185620785,0.10640400151411693,0.10353600171705087,0.1007100014636914,0.09792170052727063,0.09516979940235615,0.09245560007790725,0.08977809982995193,0.08715660062928994,0.08461009959379832,0.08213659996787707,0.07973410002887249,0.07740069863696893,0.07513460020224254,0.07293390048046906,0.070796899497509,0.06872180042167504,0.06670680083334446,0.06475040130317211,0.06285079910109441,0.06100649945437908,0.05921589955687523,0.057477499358356,0.055789800360798836,0.05415140030284723,0.052560899717112385,0.05101680041601261,0.04951790006210407,0.048062900081276894,0.04665050065765778,0.04527950038512548,0.04394859975824753,0.0426566998163859,0.04140270004669825,0.040185500557223953,0.03900409986575445,0.03785729998101791,0.03674410004168749,0.03566359976927439,0.03461490012705326,0.03359700025369724,0.032609000181158386,0.03164999978616834,0.030719199993958075,0.02981570006037752,0.02893890005846818,0.02808769994104902,0.027261600053558748,0.026459799924244482,0.025681600129852693,0.024926300160586834,0.024193200127532084,0.023481599676112335,0.022790999927868445,0.02212059994538625,0.02147000003606081,0.020838599962492783,0.020225700301428635,0.019630800001323223,0.019053499680012465,0.018493099759022396,0.01794919976964593,0.017421299902101357,0.016908999998122454,0.016411699975530308,0.01592909994845589,0.015460600067550937,0.015005899981285134,0.014564700036620101,0.014136300034200152,0.013720600012068948,0.013317200044790903,0.012925599934533238,0.01254550002825757,0.012176600052043796,0.011818599964802464,0.011471000034362078,0.011133799950281778,0.010806400096043944,0.01048869996642073,0.010180300024027625,0.009880969999358058,0.009590469999238849,0.009308509916688005,0.009034850168973207,0.008769240075101456,0.008511439974730214,0.008261229998121658,0.008018370174492398,0.007782660036658247,0.007553889959429701,0.0073318399566536145,0.007116329972632229,0.006907150032930076,0.006704130054761966,0.00650708000951757,0.006315830008437236,0.00613019991821299,0.005950030017023285,0.005775160000969966,0.005605429993011057,0.005440699984319508,0.005280809942632914,0.005125620014344652,0.004975000008319815,0.004828810032146673,0.004686909921777745,0.004549189975174765,0.004415520040007929,0.004285779936860005,0.00415984991316994,0.004037629929371178,0.003919000019474576,0.003803859988693148,0.0036921100108884275,0.003583639995971074,0.0034783599937024214,0.003376179995636145,0.003276999981608242,0.0031807300013800464,0.0030872999923303723,0.002996620023623109,0.002908589958678931,0.0028231600493503115,0.0027402399961526194,0.0026597599886978665,0.00258164001085485,0.0025058200117200613,0.0024322300062825284,0.0023608000095312795,0.002291469970562806,0.0022241700207814574,0.0021588599969012043,0.002095469991521289,0.0020339300002281866,0.001974209997570142,0.0019162400082374613,0.001859980004761989,0.0018053700041491538,0.0017523599963169545,0.0017009200140212972,0.0016509800140435498,0.0016025100000357877,0.001555470012438794,0.0015097999906477828,0.0014654799888376147,0.0014224699795401345,0.0013807100088646014,0.0013401799854667236,0.0013008500100113451,0.0012626699851049732,0.001225609992009898,0.0011896399955730885,0.0011547199974302202,0.0011208299935484927,0.001087940016683812,0.0010560100005629163,0.0010250299916757892,0.0009949469822458923,0.0009657519937415296,0.0009374140014794344,0.0009099089996501183,0.0008832109936823448,0.0008572980053334808,0.0008321459996902073,0.0008077320089796558,0.0007840350105349595,0.0007610350003233179,0.0007387090008705854,0.0007170389969057093,0.0006960059981793165,0.0006755899909573296,0.0006557739980053157,0.0006365390048207095,0.0006178690042967597,0.0005997469997964799,0.0005821579979965463,0.0005650849974093338,0.0005485119957787296,0.0005324269974759469,0.0005168140002448732,0.0005016590051430588,0.0004869479938255002,0.00047267000142407295,0.000458811002317816,0.00044535799922111136,0.0004323010046694738,0.0004196259978925809,0.00040732399793341756,0.00039538199780508876,0.0003837910044239834,0.00037254100607242435,0.00036161999984566745,0.00035102000159289065,0.00034073099959641695,0.00033074400077263516,0.00032104900310514495,0.0003116399990782763,0.00030250600199603167,0.0002936400002605903,0.00028503499682604644,0.0002766819986087891,0.0002685740012869549,0.00026070299888184917,0.00025306400008654845,0.00024564899770969834,0.0002384509995560317,0.0002314649985540503,0.00022468299842633618,0.00021809999816468917,0.00021170999995471598,0.0002055080003628973,0.00019948800036218017,0.00019364400092551173,0.00018797099861937264,0.0001824650001556923,0.00017712100088829175,0.0001719329993647989,0.00016689699987182394,0.00016200899942001948,0.0001572639994265046,0.00015265800053991066,0.00014818799778974304,0.00014384800063756606,0.000139634998049587,0.00013554700005139844,0.00013157800033998987,0.0001277250012208242,0.0001239849989360664,0.00012035499882282845,0.00011683099971075232,0.00011341099949883453,0.00011009099944203626,0.0001068680000268311,0.00010373900052703296,0.00010070200005429797,9.775470001234983e-05,9.489330113865435e-05,9.211579951321862e-05,8.941959943816376e-05,8.68024999363115e-05,8.426199929090217e-05,8.179599899449386e-05,7.94021986318209e-05,7.707860034618837e-05,7.48229995224392e-05,7.263350137994469e-05,7.050819961780992e-05,6.844509941098902e-05,6.644240117263205e-05,6.449839929700829e-05,6.261140030498306e-05,6.077960066856273e-05,5.9001500024654284e-05,5.7275399437154796e-05,5.559990010321295e-05,5.477460005446725e-05};
        HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.94642512003581,28.906192779541016,29.83809518814087,30.606096585591633,31.15429751078288,31.483598709106445,31.595199426015217,31.594598929087322,31.586798985799152,31.571899096171062,31.54979928334554,31.520599524180096,31.48419936498006,31.440799554189045,31.390299638112385,31.332799593607586,31.26819944381714,31.19879961013794,31.12689971923828,31.05239947636922,30.975499788920086,30.895999272664387,30.81399981180827,30.72939968109131,30.642300128936768,30.55269972483317,30.460500081380207,30.366199652353924,30.270299752553303,30.172799746195476,30.073599815368652,29.97279977798462,29.870299816131592,29.766199906667072,29.66039975484212,29.552899837493896,29.443699836730957,29.33360004425049,29.222999890645344,29.11200014750163,29.000499725341797,28.888699849446613,28.77639977137248,28.663699944814045,28.550600210825603,28.437000115712483,28.322999795277912,28.208799839019775,28.09469985961914,27.98079999287923,27.867000102996826,27.75340000788371,27.63980007171631,27.526299794514973,27.412999947865803,27.299699942270916,27.18660004933675,27.073699951171875,26.96120007832845,26.84909995396932,26.73740005493164,26.626100063323975,26.515199820200603,26.404600143432617,26.29450003306071,26.18470001220703,26.075299898783367,25.96619987487793,25.857699712117512,25.749500115712483,25.641800085703533,25.53439998626709,25.4275000890096,25.32099978129069,25.21499999364217,25.10929997762044,25.004000186920166,24.899199803670246,24.79479996363322,24.690799713134766,24.5872000058492,24.484000205993652,24.38129981358846,24.278899828592937,24.176999886830647,24.075500011444092,23.97439988454183,23.87370014190674,23.773399988810223,23.67329978942871,23.573700428009033,23.474300066630047,23.37530008951823,23.276600042978924,23.178200085957844,23.08020003636678,22.982500076293945,22.8850998878479,22.788100083669026,22.69130007425944,22.594899654388428,22.498900095621746,22.40309985478719,22.307600021362305,22.21250009536743,22.11770009994507,22.023200194040935,21.929100036621094,21.835200150807697,21.74169985453288,21.648499647776287,21.555599848429363,21.46299982070923,21.370700041453045,21.27869971593221,21.187100092569988,21.09570010503133,21.00470034281413,20.913999875386555,20.823599815368652,20.733500162760418,20.643699804941814,20.554200172424316,20.465099811553955,20.37619988123576,20.287699858347576,20.199399948120117,20.111499945322674,20.023900190989178,19.93660036722819,19.849499861399334,19.762800057729084,19.676400025685627,19.590399901072185,19.504600048065186,19.41909996668498,19.333899974822998,19.249000390370686,19.164499759674072,19.08020003636678,18.99620008468628,18.91260019938151,18.82919994990031,18.746100107828777,18.663400014241535,18.580899874369305,18.498799959818523,18.416899998982746,18.335400263468426,18.254100163777668,18.173100153605144,18.09250005086263,18.012100219726562,17.931999683380127,17.852299849192303,17.772799809773762,17.693599700927734,17.614700158437092,17.536100069681805,17.457799911499023,17.379799842834473,17.30210002263387,17.224700291951496,17.147599856058758,17.070799986521404,16.994199911753338,16.917999903361004,16.842000007629395,16.7664000193278,16.69099998474121,16.61590003967285,16.54110034306844,16.466600100199383,16.39240010579427,16.318400065104168,16.244800090789795,16.17139991124471,16.098300298055012,16.025500218073528,15.95299998919169,15.880800008773804,15.808899958928427,15.737200021743774,15.665800015131632,15.594699939092001,15.523899952570597,15.45329999923706,15.383100112279257,15.313100020090738,15.243399937947592,15.174000104268393,15.10480006535848,15.035899957021078,14.967300017674765,14.89900008837382,14.830900033315023,14.763200044631958,14.6957000096639,14.628400007883707,14.561499993006388,14.494799852371216,14.428299903869629,14.362200021743774,14.296300013860067,14.230700016021729,14.165300051371256,14.100299994150797,14.035399834314982,13.970899820327759,13.90659991900126,13.842599948247274,13.778800010681152,13.715299924214682,13.65209992726644,13.589099963506063,13.526400089263916,13.463900089263916,13.401699860890707,13.339800039927164,13.27810001373291,13.216700077056885,13.155500014623007,13.094600041707357,13.033900101979574,12.9735000928243,12.913399934768677,12.853500127792358,12.793799956639608,12.734399954477945,12.675300041834513,12.616399923960367,12.557699998219809,12.499300082524618,12.441200176874796,12.383299986521402,12.325600067774454,12.268200079600016,12.210999965667725,12.154099941253662,12.097400108973185,12.040899912516275,11.984600146611532,11.928599913914999,11.872900009155273,11.817299922307333,11.762099822362265,11.706999937693277,11.652199983596802,11.597599983215332,11.543299913406372,11.489200035730997,11.435400009155273,11.381800015767416,11.328500032424927,11.275400002797445,11.222500006357828,11.169899940490723,11.117499907811483,11.065299987792969,11.013399918874105,10.96180001894633,10.910300016403198,10.859100023905436,10.808200041453043,10.757499933242798,10.706999937693277,10.656700054804483,10.6067001024882,10.556899865468344,10.507399956385294,10.458100001017252,10.408999919891357,10.360099951426188,10.311500072479248,10.263099908828735,10.214899937311808,10.166899998982748,10.119200070699057,10.07170001665751,10.024399995803833,9.97737987836202,9.930539925893148,9.883920272191366,9.837520202000936,9.791339953740438,9.74538000424703,9.69962994257609,9.654099941253662,9.608779986699423,9.563680013020834,9.518780072530111,9.47409987449646,9.429630120595297,9.385370095570883,9.341310103734335,9.297470013300577,9.253820101420084,9.210390090942383,9.167159875233969,9.124130010604858,9.081309874852499,9.038690010706583,8.996260007222494,8.954039891560873,8.912019968032837,8.870190064112345,8.828569968541464,8.787130117416382,8.74589991569519,8.704859972000122,8.664010047912598,8.623350063959757,8.582880020141602,8.542610009511312,8.502530018488565,8.462629874547323,8.422920068105062,8.383399963378906,8.344069878260294,8.304920037587484,8.265949964523315,8.22716999053955,8.188579877217611,8.150160074234009,8.11191995938619,8.073869943618774,8.035989999771118,7.9982999960581465,7.960780024528503,7.923439979553223,7.886270006497701,7.849280118942261,7.81246002515157,7.775819977124532,7.739350040753682,7.703050017356873,7.666919986406962,7.630959987640381,7.595179994901021,7.5595600207646685,7.524109999338786,7.48881999651591,7.453710039456685,7.418749968210856,7.383969982465108,7.349340081214905,7.314879973729451,7.280580043792725,7.246449987093608,7.212469975153605,7.178659955660502,7.144999980926514,7.111499985059102,7.078169941902161,7.044980009396871,7.011959950129191,6.979089975357056,6.946369965871175,6.913810094197591,6.881410002708435,6.849149982134501,6.817050019900004,6.785099943478902,6.753299991289775,6.721650004386902,6.690140008926392,6.6587899923324585,6.62759002049764,6.596529960632324,6.565619985262553,6.534850001335144,6.50423006216685,6.473749995231628,6.443419933319092,6.4132299820582075,6.3831801017125445,6.353269974390666,6.323509971300761,6.293880025545756,6.264400005340576,6.235050002733867,6.205840031305949,6.176770011583964,6.147839983304341,6.119040052096049,6.090380032857259,6.06184999148051,6.033460021018982,6.0051999886830645,5.97708002726237,5.949090043703715,5.92123007774353,5.893500049908956,5.865900039672852,5.838430007298787,5.8110900322596235,5.7838800350824995,5.756800055503845,5.729840000470479,5.703020056088765,5.67631995677948,5.649739980697632,5.623289982477824,5.596970001856486,5.570760011672974,5.544690012931824,5.518730004628499,5.492900053660075,5.467189987500508,5.44160000483195,5.416130026181539,5.390780011812846,5.3655500411987305,5.340439955393474,5.3154399792353315,5.290570060412089,5.265809973080953,5.241169969240825,5.216639995574951,5.192230025927226,5.167939980824788,5.143760045369466,5.11968998114268,5.095740000406901,5.071899970372518,5.048169891039531,5.02455997467041,5.001050074895223,4.977660059928894,4.954369942347209,4.93119998772939,4.908129970232646,4.8851799964904785,4.862329999605815,4.8395899931589765,4.816950003306071,4.794419964154561,4.771999955177307,4.749690016110738,4.727479934692383,4.7053699890772505,4.683370033899943,4.661470015843709,4.6396699746449785,4.617979923884074,4.596390048662822,4.574899991353353,4.553510030110677,4.532230059305827,4.511040012041728,4.489949981371562,4.468960086504619,4.4480700095494585,4.427279988924663,4.406589984893799,4.385999997456868,4.365500013033549,4.34508999188741,4.324789961179097,4.304580012957255,4.284459988276164,4.264440019925435,4.244510014851888,4.224680066108704,4.204939961433411,4.18529995282491,4.165739893913269,4.146279970804851,4.126910010973613,4.107629934946696,4.08843994140625,4.069340030352275,4.05033000310262,4.031410018603007,4.012579957644145,3.993839999039968,3.975189983844757,3.9566200176874795,3.9381399552027383,3.919749995072683,3.901449998219808,3.8832300305366516,3.865090012550354,3.84704997142156,3.8290799856185913,3.8201200366020203};
        //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.14047295475999513,0.14906380822261175,0.15873685479164124,0.16867286091049513,0.1789028582473596,0.18942385042707124,0.20023582627375922,0.21228579804301262,0.22651477033893266,0.2429127444823583,0.2614727144440015,0.28218068679173786,0.30502766370773315,0.3300066317121188,0.3571066011985143,0.38631758093833923,0.41762956976890564,0.45015956461429596,0.48302655667066574,0.5162285516659418,0.5497655520836512,0.5836355437835058,0.6178375432888666,0.6523705323537191,0.6872325291236242,0.7224225203196207,0.7579425126314163,0.7934675266345342,0.8286765267451605,0.8635705163081487,0.8981505235036215,0.9324185252189636,0.9663775265216827,1.0000295390685399,1.0333695511023204,1.0664095481236775,1.0991395513216655,1.1312595705191295,1.162449558575948,1.1927195688088734,1.2220795849959056,1.250519593556722,1.278049608071645,1.3046696086724598,1.330389638741811,1.3552196323871613,1.3791496555010478,1.4020796716213226,1.4239096641540527,1.4446496764818828,1.4642996887365978,1.4828597108523052,1.5003397166728973,1.5167497396469116,1.5320797363917034,1.5463497539361317,1.5595497786998749,1.5717297891775768,1.5829197863737743,1.5931297938028972,1.6023698250452678,1.6106298367182414,1.6179198324680328,1.624239852031072,1.6296098629633586,1.6340198715527852,1.6374798715114594,1.6401598751544952,1.6422698895136516,1.6437898874282837,1.6447299023469288,1.6450899243354797,1.6448799173037212,1.6440999209880829,1.6427399317423503,1.6408199469248455,1.6383399367332458,1.635459949572881,1.6323699454466503,1.6290699640909831,1.6255499521891277,1.6218199531237285,1.6178799668947856,1.6137299835681915,1.6093799769878387,1.60480996966362,1.600029985109965,1.595149964094162,1.590269962946574,1.5853899816672008,1.5805199543635051,1.5756499767303467,1.5707799692948659,1.5659099717934926,1.561039964358012,1.5561699867248535,1.5512999892234802,1.5464399755001068,1.5415799816449482,1.536709984143575,1.5318499902884166,1.5270000000794728,1.522139996290207,1.517279992500941,1.5124299625555675,1.5075799922148387,1.5027299920717876,1.4978799720605214,1.4930299818515778,1.488179971774419,1.4833399653434753,1.478499988714854,1.4736499786376953,1.468809982140859,1.46397997935613,1.4591399828592937,1.4543099800745647,1.449479987223943,1.4446499745051067,1.439819981654485,1.4349999924500783,1.4301699896653493,1.4253499805927277,1.420529971520106,1.4157199660936992,1.4108999768892925,1.406089961528778,1.4012799859046936,1.3964699804782867,1.3916699786980946,1.3868699669837952,1.382069985071818,1.3772699932257335,1.3724799752235413,1.3676899870236714,1.3628999988238018,1.3581100006898243,1.3533299664656322,1.3485499918460846,1.3437699774901073,1.338999976714452,1.334229975938797,1.3294599950313568,1.324699987967809,1.319929987192154,1.315179963906606,1.310419996579488,1.3056699931621552,1.3009199897448223,1.296179989973704,1.291429986556371,1.286700000365575,1.2819599906603496,1.2772299945354462,1.2724999884764354,1.2677799860636394,1.2630599836508434,1.2583399713039398,1.253629982471466,1.2489199837048848,1.244219978650411,1.2395199835300446,1.2348199983437855,1.2301199932893117,1.2254299918810527,1.220749984184901,1.2160699665546417,1.2113899886608124,1.2067199846108754,1.2020499805609386,1.1973799864451091,1.192720005909602,1.188069999217987,1.1834099888801575,1.1787599722544353,1.1741199791431427,1.1694800059000652,1.164849986632665,1.1602199872334797,1.155589997768402,1.1509699920813243,1.1463499863942463,1.1417399843533833,1.1371299922466278,1.1325200001398723,1.127920001745224,1.1233299771944683,1.1187399923801422,1.1141499876976013,1.1095699866612752,1.1049999793370564,1.10043000181516,1.095859984556834,1.0913000007470448,1.086739977200826,1.0821900069713593,1.077639987071355,1.0731000006198883,1.0685599843660991,1.0640199780464172,1.05949999888738,1.054969996213913,1.0504499971866608,1.045939991871516,1.041430006424586,1.0369300146897633,1.032430003086726,1.027930001417796,1.023440013329188,1.0189599891503651,1.0144799848397572,1.010010004043579,1.0055399934450786,1.001069997747739,0.9966150025526682,0.9921610057353973,0.9877129991849264,0.9832689960797628,0.9788299997647604,0.9743959953387579,0.9699680010477701,0.9655459970235825,0.9611269980669022,0.9567139943440756,0.9523059874773026,0.9479040006796519,0.9435069958368937,0.939113994439443,0.9347270081440607,0.9303449988365173,0.9259680012861887,0.9215979973475138,0.9172309984763464,0.9128690014282862,0.9085129996140798,0.9041629980007807,0.899817998210589,0.895485003789266,0.8911690016587576,0.8868729968865713,0.8825939993063608,0.8783350040515264,0.8740949978431066,0.8698729972044627,0.8656699955463409,0.861485997835795,0.8573209991057714,0.8531760027011236,0.8490490068991979,0.8449410001436869,0.8408530006806055,0.8367830018202463,0.8327320019404093,0.8287009944518408,0.8246879975001017,0.8206939945618311,0.8167190055052439,0.8127630054950714,0.8088259945313135,0.8049069990714391,0.8010069926579794,0.7971260050932566,0.7932630032300949,0.7894190003474554,0.7855930030345917,0.7817850063244501,0.7779959986607233,0.7742250114679337,0.7704720000425974,0.7667369991540909,0.7630209972461065,0.759322002530098,0.7556410133838654,0.7519779950380325,0.7483319938182831,0.7447050015131632,0.7410939931869507,0.7375010003646215,0.7339260031779608,0.7303679982821146,0.7268269956111908,0.7233040034770966,0.7197969953219095,0.716308002670606,0.7128350039323171,0.7093789974848429,0.705939993262291,0.7025180061658224,0.699112003048261,0.6957229971885681,0.6923510034879049,0.6889940003554026,0.6856540044148763,0.6823310007651647,0.6790229976177216,0.6757320016622543,0.6724560012420019,0.6691970030466715,0.6659529954195023,0.6627249966065089,0.6595130066076914,0.6563160022099813,0.6531350066264471,0.6499699999888738,0.6468190054098765,0.6436849981546402,0.6405649880568186,0.6374609967072805,0.6343710025151571,0.6312970022360483,0.6282380024592081,0.6251929998397827,0.6221640010674795,0.6191489994525909,0.616147999962171,0.6131629993518194,0.6101919958988825,0.6072350094715754,0.6042929987112681,0.6013650000095367,0.5984510034322739,0.595551997423172,0.5926660001277924,0.5897949983676275,0.5869380036989847,0.5840940028429031,0.58126500248909,0.5784490058819453,0.5756469964981079,0.5728580007950465,0.5700829972823461,0.5673220008611679,0.5645740032196045,0.5618389944235483,0.5591180076201757,0.5564099997282028,0.5537150104840597,0.5510330001513163,0.5483639985322952,0.5457089940706888,0.5430660098791122,0.5404360095659891,0.5378189980983734,0.5352140019337336,0.5326230029265085,0.5300429960091909,0.5274769961833954,0.5249230017264684,0.5223810027043024,0.5198520024617513,0.5173350075880686,0.514830008149147,0.512337992588679,0.5098569939533869,0.5073890040318171,0.5049330095450083,0.5024880071481069,0.5000560010472933,0.49763499697049457,0.4952260032296181,0.49282899995644885,0.49044399956862134,0.4880699987212817,0.4857080007592837,0.4833569998542468,0.48101799686749774,0.4786900008718173,0.47637300193309784,0.4740680033961932,0.4717740019162496,0.46949100246032077,0.4672189950942993,0.4649579996864001,0.4627079938848813,0.46046899755795795,0.4582410007715225,0.45602400104204815,0.4538179983695348,0.45162199934323627,0.4494370023409526,0.447262999912103,0.44509899864594143,0.44294600188732147,0.44080399970213574,0.43867100526889163,0.43654900044202805,0.4344380001227061,0.4323359976212184,0.43024500211079914,0.42816400279601413,0.4260940005381902,0.4240329985817273,0.4219820002714793,0.4199419990181923,0.41791100054979324,0.4158899982770284,0.41387899965047836,0.4118779997030894,0.4098859950900078,0.4079039990901947,0.405931996802489,0.4039689972996712,0.4020159939924876,0.4000730017820994,0.39813899497191113,0.39621400088071823,0.3942990054686864,0.39239300042390823,0.390495998164018,0.38860799620548886,0.38672999540964764,0.38486099739869434,0.3830009996891022,0.3811500047643979,0.37930700182914734,0.37747399757305783,0.37564999610185623,0.3738349998990695,0.37202799568573636,0.3702310025691986,0.36844200144211453,0.36666099975506466,0.36489000419775647,0.36312700311342877,0.3613719989856084,0.35962600260972977,0.35788900156815845,0.3561599974830945,0.35443900028864544,0.3527269984285037,0.35102300345897675,0.3493280013402303,0.3476400052507718,0.34596100201209384,0.34429000069697696,0.34262799968322116,0.34097299724817276,0.33932600418726605,0.33768700063228607,0.3360570048292478,0.33443400263786316,0.33281899988651276,0.33121200402577716,0.32961199929316837,0.3280209998289744,0.3264369989434878,0.3248609999815623,0.3232930029431979,0.32173199703296024,0.32017899801333743,0.3186330000559489,0.31709500402212143,0.31556400159994763,0.31404100110133487,0.3125249942143758,0.3110170016686122,0.3095159977674484,0.30802199989557266,0.3065350006024043,0.30505599826574326,0.3035839994748433,0.30211899677912396,0.30066100011269253,0.29920999705791473,0.2977660000324249,0.29632899910211563,0.29490000009536743,0.29347699632247287,0.2920609960953395,0.290652001897494,0.2892500013113022,0.2878539984424909,0.28646599998076755,0.2850840042034785,0.2837089995543162,0.2823400025566419,0.2809779991706212,0.27962300429741543,0.2782740021745364,0.2769320011138916,0.2755970035990079,0.274267998834451,0.27294500172138214,0.2716290031870206,0.27031900237003964,0.26966599623362225};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2243289152781167,2.4407403071721396,2.6055002411206565,2.797560175259908,2.9832401871681213,3.1635901927948,3.33948024113973,3.556940277417501,3.856290320555369,4.227680404980977,4.662480354309082,5.1531403462092085,5.693050543467204,6.27638057867686,6.898030519485474,7.5535106261571245,8.2388707002004,8.909100691477457,9.52462069193522,10.09220059712728,10.617600758870443,11.10610063870748,11.562100807825724,11.989500681559244,12.391900777816772,12.772100687026978,13.132800817489624,13.461400588353476,13.746400753657023,13.993000745773315,14.20560065905253,14.388100624084473,14.544000705083212,14.676300684611002,14.78760059674581,14.880400657653809,14.956600666046143,15.003100713094076,15.007700681686401,14.975400606791178,14.910200675328573,14.815900405248007,14.695800622304281,14.552600622177124,14.389100472132364,14.20740040143331,14.009700616200766,13.79240051905314,13.552900552749634,13.29330046971639,13.016100486119589,12.723000367482504,12.415900389353434,12.096200307210287,11.765400489171347,11.424700419108072,11.075100342432657,10.719500223795572,10.360500256220499,9.998200257619223,9.633010307947794,9.265140136082968,8.89481027921041,8.522250175476074,8.147640268007914,7.771150231361389,7.39296019077301,7.021830121676127,6.665520151456197,6.322330156962077,5.990730166435242,5.669410149256389,5.357170184453328,5.052970131238301,4.755900104840596,4.465130090713501,4.179940025011699,3.9080300529797873,3.656190037727356,3.4221500158309937,3.203890045483907,2.9996100664138794,2.807730038960775,2.6268300215403237,2.4556700587272644,2.2931400338808694,2.1382600466410318,1.9951800405979156,1.867610017458598,1.753790020942688,1.65215003490448,1.5613300402959187,1.4801000356674194,1.4073700507481892,1.342190037171046,1.2836800316969554,1.231100042661031,1.183780054251353,1.1411000390847523,1.102560043334961,1.0676800310611725,1.0360400279362996,1.0072700430949528,0.9810430357853571,0.957075039545695,0.9351070324579874,0.9149140367905298,0.8962900241216024,0.8790570249160131,0.8630580306053162,0.8481510331233343,0.834215040008227,0.8211380342642466,0.808821032444636,0.7971800317366918,0.7861360261837641,0.7756240318218867,0.7655820349852244,0.7559610307216644,0.7467110256354014,0.7377910315990448,0.7291630258162817,0.7207960337400436,0.7126610229412714,0.7047330290079117,0.6969900379578272,0.6894120226303736,0.6819800287485123,0.6746790260076523,0.6674950222174326,0.6604180236657461,0.653435026605924,0.6465370307366053,0.6397150258223215,0.6329620232184728,0.626272032658259,0.6196380207935969,0.6130570322275162,0.6065230220556259,0.6000320166349411,0.5935800274213155,0.5871640145778656,0.5807810227076212,0.5744290252526602,0.568108027180036,0.5618130216995875,0.5555440237124761,0.5492970297733942,0.5430730283260345,0.5368720293045044,0.5306900242964426,0.5245270182689031,0.5183820227781931,0.512254019578298,0.5061420202255249,0.5000460172692934,0.4939680223663648,0.48790401717027027,0.48185402154922485,0.4758180156350136,0.46979501843452454,0.4637880176305771,0.4577940156062444,0.4518110180894534,0.4458410143852234,0.4398830160498619,0.43393702308336896,0.4280020197232564,0.42208001514275867,0.41617001841465634,0.41027001788218814,0.4043810193737348,0.39850301792224246,0.3926350151499112,0.38677701602379483,0.3809320131937663,0.3750960131486257,0.3692710151274999,0.36345501492420834,0.35764801253875095,0.35185401638348895,0.34606801221768063,0.3402920141816139,0.3345240131020546,0.3287660131851832,0.32301601270834607,0.3172760133941968,0.3115460127592087,0.30582501490910846,0.3001120140155156,0.2944070075949033,0.2887110114097595,0.28302300969759625,0.277343009908994,0.2716730112830798,0.266011007130146,0.26035701235135394,0.25471100956201553,0.2490720103184382,0.24344300851225853,0.23782200862963995,0.23220701018969217,0.22660000870625177,0.22100000704328218,0.2154070076843103,0.20982100814580917,0.20424500604470572,0.19867500911156336,0.19311200579007468,0.18755600725611052,0.182006003956,0.17646300544341406,0.17092600713173547,0.16539900625745454,0.15987700472275415,0.15436200549205145,0.14885200435916582,0.14334900428851446,0.13785400365789732,0.13236500322818756,0.1268820029993852,0.12140400397280852,0.11593200328449409,0.11046600217620532,0.10500600126882394,0.09955290332436562,0.0941056019316117,0.08866350228587787,0.08322680182754993,0.07779530063271523,0.0723713015516599,0.0669523011893034,0.061538200825452805,0.05612900108098984,0.05072470040371021,0.04532539968689283,0.03993090024838845,0.034879500356813274,0.03046440053731203,0.026606099990506966,0.023234700007985037,0.020289100085695583,0.0177158002431194,0.015468099930634102,0.013504800076285997,0.011790100019425154,0.01029270002618432,0.00898505987909933,0.007843290028783182,0.006846370020260413,0.005975969989473621,0.005216080035703878,0.004552699974738061,0.003973590035457164,0.0034680700046010315,0.0030267999973148108,0.0026416199980303645,0.002305429991489897,0.002011990000028163,0.0017558700249840815,0.0015323400148190558,0.0013372499961405993,0.0011669900074290733,0.0010183900061141078,0.0008887130000706142,0.0007755390009454762,0.000676773003457735,0.0005905820047094797,0.000515364986010051,0.0004497249998773138,0.00039244400250026956,0.0003424579990678467,0.00029883699608035386,0.00026077199921322364,0.00022755500079559474,0.00019856900083444393,0.00017327500002769133,0.00015120299940463156,0.00013194200194751224,0.00011513499945673782,0.00010046799980045762,8.767010028047177e-05,7.650230024106956e-05,6.67570996787011e-05,5.8253300267097075e-05,5.083279999477478e-05,4.435760032113952e-05,3.870719956466928e-05,3.3776699638110586e-05,2.9474200346157886e-05,2.5719799850776326e-05,2.2443699890573043e-05,1.9584899897987878e-05,1.7090299934352515e-05,1.4913500005301708e-05,1.3013900039974638e-05,1.1356400060928232e-05,9.909920057301255e-06,8.647729904017373e-06,7.546319996739233e-06,6.585209992711801e-06,5.746520059801696e-06,5.014649976449921e-06,4.375999954694028e-06,3.8187000086509215e-06,3.3323900083814806e-06,2.908010003466188e-06,2.5376799991742396e-06,2.2145199901994297e-06,1.9325199976568306e-06,1.6864299918021668e-06,1.4716799986066083e-06,1.284290002937875e-06,1.1207499994725367e-06,9.780469933199736e-07,8.535139954801707e-07,7.448400036006811e-07,6.500050015271578e-07,5.672460048344874e-07,4.950250035070288e-07,4.320009997134851e-07,3.770010010839542e-07,3.290049998364945e-07,2.871199953347059e-07,2.5056899962313156e-07,2.1867100130634753e-07,1.908340010459142e-07,1.6654100084186516e-07,1.453420021372646e-07,1.2684100051766714e-07,1.1069599932985359e-07,2.5398126268783017e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834727128346762,12.709800879160563,13.146400451660156,13.803100347518921,13.641600211461386,12.805299997329712,11.41130002339681,9.897239923477173,8.624449968338013,7.550049980481465,6.638850092887878,5.862000068028768,5.195780038833618,4.620710055033366,4.120770037174225,3.6827800472577414,3.295870025952657,2.958570043245951,2.669610063234965,2.420480032761892,2.204200049241384,2.015020022789637,1.8481699923674266,1.6997600098450978,1.5665800174077351,1.4459500312805176,1.3356900016466777,1.2354300022125244,1.1448500355084736,1.062250018119812,0.9862370093663534,0.9156430115302404,0.8495230078697205,0.7870810031890869,0.7276670038700104,0.670743003487587,0.6158640036980311,0.5647850086291631,0.51896699766318,0.47752300649881363,0.4397130037347476,0.4049250011642774,0.3726480056842168,0.3424530004461606,0.31398800760507584,0.28696700433890027,0.2611460064848264,0.2372770036260287,0.21599200243751207,0.19686700279513994,0.17954100171724954,0.16371100271741548,0.14912900080283484,0.13558700059851012,0.1229130004843076,0.110962999984622,0.09961760106186072,0.08922610059380531,0.08008100030322869,0.07197590172290802,0.06473340032001336,0.05821110028773546,0.052295200526714325,0.046885500041147075,0.04189850048472484,0.037259199966986976,0.03291010049482187,0.02898110030218959,0.025576000257084768,0.022609300445765257,0.020004399896909792,0.017702400063474972,0.015659199949974816,0.013832800167923173,0.01218770002014935,0.01068940005886058,0.009313919969523946,0.008088430001710853,0.0070305199672778445,0.006118260091170669,0.005328009991596143,0.004634710028767586,0.004022629970374207,0.00347855999522532,0.002991470003811022,0.0025520900186772146,0.002152679953724146,0.0018023599889905502,0.001508819996767367,0.001262879988644272,0.0010568699944997206,0.0008843190007610247,0.0007398209951740379,0.0006188319918389121,0.0005175429929901535,0.0004327610004111193,0.00036180699680699036,0.0003024339991194817,0.00025276200055183534,0.0002112119982484728,0.00017646099998576878,0.00014740300078604682,0.00012310800047998782,0.00010280000060447492,8.582700017238191e-05,7.164380076574162e-05,5.979400005647525e-05,4.989539957023226e-05,4.162819944516135e-05,3.472479966148967e-05,2.8961099966788122e-05,2.4149899824503034e-05,2.0134400074311998e-05,1.6783700023855392e-05,1.3988099908601725e-05,1.1656200058496324e-05,9.711329994388507e-06,8.089580092018878e-06,6.737489987547936e-06,5.610420013605714e-06,4.671089944470926e-06,3.888359951057889e-06,3.2362400096038377e-06,2.6930299933762094e-06,2.2406200059776893e-06,1.863900015071825e-06,1.5502499858636536e-06,1.2891700009731721e-06,1.071879988027528e-06,8.910609968400726e-07,7.406240030150002e-07,6.154840074638438e-07,5.11403998852226e-07,4.2485499799719645e-07,3.528950003328646e-07,2.9307600139342565e-07,2.433579974573756e-07,2.020409984500778e-07,1.6771200250786933e-07,1.3919400151015301e-07,1.1550699537584326e-07,2.566201769601169e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8709225406249365,0.9575190742810568,1.023070052266121,1.0758000612258911,1.1172100603580475,1.1486300627390544,1.1712300380071003,1.1950100859006245,1.2288500567277272,1.2716300785541534,1.3223500748475392,1.3801300823688507,1.4442100822925568,1.5138900876045227,1.5885600944360097,1.667670100927353,1.750740110874176,1.8296901086966197,1.8973200917243958,1.9548701047897339,2.003460079431534,2.0440500775973,2.0775100787480674,2.1046000719070435,2.1260001063346863,2.1423200964927673,2.1541001001993814,2.1616501013437905,2.165230095386505,2.165260076522827,2.162090082963308,2.1560500661532083,2.1474100748697915,2.13644007841746,2.1233600775400796,2.1083900928497314,2.0917000571886697,2.0723700523376465,2.0495600501696267,2.023620088895162,1.9948700765768688,1.963580052057902,1.9300200442473094,1.8944000601768494,1.8569400608539581,1.8178200523058574,1.7772000432014465,1.735330065091451,1.692430039246877,1.648590048154195,1.6039100388685863,1.5584500432014465,1.5123000244299571,1.4655100305875142,1.418140043814977,1.3702500363190968,1.3218900461991627,1.2736400266488392,1.2260100146134694,1.178950031598409,1.1323700149854024,1.086210012435913,1.0404300491015117,0.9949670334657034,0.9497930159171423,0.904868021607399,0.8601600180069605,0.8165470163027445,0.7748160163561503,0.734769011537234,0.6962250073750814,0.6590280135472616,0.6230380088090897,0.5881250152985255,0.55417700111866,0.5210960060358047,0.48879000544548035,0.45798300206661224,0.42932600528001785,0.4025950034459432,0.3775920048356056,0.35413600504398346,0.33206600447495777,0.31123700241247815,0.29152100284894306,0.27280400693416595,0.2549780048429966,0.2384410041073958,0.2235490046441555,0.21013100569446883,0.1980350042382876,0.1871240052084128,0.1772750032444795,0.16837700456380844,0.16033000374833742,0.1530480037132899,0.14645300433039665,0.14047200481096903,0.1350420042872429,0.13010600209236145,0.12561200310786566,0.12151400248209636,0.1177710040162007,0.11434600315988064,0.11120600253343582,0.10832100361585617,0.105665002639095,0.10321200328568618,0.10094000274936359,0.09883340386052926,0.09687410357097785,0.09504710262020429,0.09333860253294309,0.09173610371847947,0.09022870287299156,0.08880650376280148,0.08746070228517056,0.08618320276339848,0.08496720281740029,0.08380610371629398,0.08269430262347062,0.08162480282286803,0.0805933028459549,0.07959780345360438,0.07863460356990497,0.07770050254960854,0.07679260211686294,0.07590820267796516,0.0750449039041996,0.07420070221026738,0.07337360208233197,0.07256200350821018,0.07176430337131023,0.07097930150727431,0.07020380285878976,0.06943680283923943,0.06867960157493751,0.06793130189180374,0.06719110285242398,0.06645820227762063,0.06573210222025712,0.06501210108399391,0.06429770216345787,0.063588401923577,0.06288400292396545,0.06218390197803577,0.06148780199388663,0.06079550211628278,0.06010470228890578,0.05941540220131477,0.05872950175156196,0.05804680163661639,0.05736710224300623,0.05669030205657085,0.05601600216080745,0.05534430220723152,0.054674901689092316,0.054007701886196934,0.05334260190526644,0.052679602056741714,0.052018401833872,0.05135910212993622,0.05069950160880884,0.050039902329444885,0.04938230166832606,0.04872660152614117,0.048072802213331066,0.04742080128441254,0.046770401298999786,0.04612170159816742,0.045474501637121044,0.04482880110541979,0.04418460155526797,0.04354180178294579,0.04290030182649692,0.04225820178786913,0.041615601629018784,0.0409746008614699,0.040335301930705704,0.03969750149796406,0.03906110115349293,0.03842610182861487,0.03779250135024389,0.037160200998187065,0.03652910081048807,0.035899301059544086,0.035270601200560726,0.03464310150593519,0.034016700461506844,0.033389401311675705,0.0327614014968276,0.03213490049044291,0.031509700852135815,0.030885901457319658,0.030263401102274656,0.029642100756367046,0.029021900923301775,0.02840290063371261,0.02778500101218621,0.02716810101022323,0.026552201093484957,0.02593740060304602,0.025321500841528177,0.02470480076347788,0.024089400966962177,0.023475400482614834,0.02286250066633026,0.022250801014403503,0.02164010051637888,0.021030600493152935,0.02042200059319536,0.01981440077846249,0.01920780058329304,0.01860210035617153,0.01799720075602333,0.01739320034782092,0.016788000396142404,0.01618190063163638,0.015577100372562805,0.014973300431544581,0.014370600382486979,0.013769000303000212,0.013168400386348367,0.012568600320567688,0.011969800184791287,0.011371900249893466,0.010774700126300255,0.010178400203585625,0.009582790158068141,0.008987950161099434,0.008391850084687272,0.007794690201990306,0.007198640067751209,0.006603640038520098,0.006009610020555556,0.005416509966986875,0.004824289974446098,0.00426653993781656,0.003772979990268747,0.003336279963453611,0.0029499400213050344,0.002608170014961312,0.0023058800337215266,0.002038520013835902,0.0018020699984238793,0.0015929900012755145,0.0014080999923559527,0.0012446300049001973,0.0011001000045022618,0.0009723299881443381,0.0008593719927982116,0.0007595170027343556,0.000671249998655791,0.0005932279988580073,0.0005242650076979771,0.00046331000097173575,0.0004094359998513634,0.00036182100060007844,0.00031973999527205404,0.00028254899856013555,0.00024968099751276895,0.0002206350000051316,0.00019496499832409123,0.00017228099992886806,0.0001522349994047545,0.000134521000290988,0.0001188670006134392,0.00010503399971639737,9.28109996796896e-05,8.200970053925023e-05,7.246519999171142e-05,6.403140135565384e-05,5.657890020908477e-05,4.999370018291908e-05,4.4174900115952674e-05,3.9033299799484666e-05,3.4490000264971364e-05,3.047560009387477e-05,2.6928399771956418e-05,2.379399999578406e-05,2.1024500104734518e-05,1.8577299973306555e-05,1.6414999966703665e-05,1.4504400041914778e-05,1.2816100024792831e-05,1.1324399944593702e-05,1.0006300044551608e-05,8.841660170825586e-06,7.812559942976804e-06,6.903240015769067e-06,6.099779966461938e-06,5.389829955978105e-06,4.762519968911268e-06,4.208230014531485e-06,3.718460012199406e-06,3.2856899565558706e-06,2.903299976727188e-06,2.565409999988333e-06,2.266850003707077e-06,2.003039999938968e-06,1.769940003744826e-06,1.5639700166047987e-06,1.3819699897036723e-06,1.2211499912003394e-06,1.0790500084567611e-06,9.534820009093892e-07,8.425310037788828e-07,7.444930029502453e-07,6.578650015853782e-07,5.81317001054534e-07,5.136779985074705e-07,4.539099999571287e-07,4.010969997618001e-07,3.5443000238425765e-07,3.1319399814340915e-07,2.7675500291479693e-07,2.4455699805988235e-07,2.1610599887367243e-07,1.9096399957637308e-07,1.6874900055086073e-07,1.4911799913382615e-07,1.317709994452798e-07,1.1644200033818682e-07,7.835310474509545e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.2528697003920873,0.26552995791037876,0.27433298031489056,0.281350980202357,0.2864999820788701,0.28989898413419724,0.2916639869411786,0.29297198355197906,0.29492198179165524,0.2974749803543091,0.3005899836619695,0.30423198143641156,0.308366984128952,0.31296397745609283,0.3179929777979851,0.3234259784221649,0.3292379826307297,0.33472397923469543,0.3392239858706792,0.3427949796120326,0.3454919829964638,0.3473679820696513,0.34846998502810794,0.3488429859280586,0.348528986175855,0.34756798793872196,0.34599698583285016,0.3439689849813779,0.34162598848342896,0.338983990252018,0.3360589842001597,0.33286498735348385,0.3294169877966245,0.3257259825865428,0.32180699209372204,0.3176699901620547,0.31332699209451675,0.30877699206272763,0.3040179858605067,0.29905999203523,0.2939149911204974,0.28859199086825055,0.2830989857514699,0.2774469902118047,0.2716439937551816,0.2656969924767812,0.2596139907836914,0.2534499913454056,0.24725899597009024,0.2410389930009842,0.23479199409484863,0.22851899514595667,0.22221999367078146,0.21589699387550354,0.20954899365703264,0.20317899684111276,0.19678699597716331,0.19043399641911188,0.1841799976925055,0.1780179999768734,0.17193999762336412,0.16594299798210463,0.16002099712689719,0.15416799982388815,0.14837999766071638,0.14265299836794534,0.13698299725850424,0.1314309984445572,0.1260549978663524,0.12084199922780196,0.11578499898314476,0.11087400031586488,0.10609899771710236,0.10145499867697556,0.09693189958731334,0.09252389955023925,0.08822389940420787,0.08407219871878624,0.08010669983923435,0.07631689868867397,0.0726923979818821,0.06922390001515548,0.0659023995200793,0.06271939941992362,0.05966689934333166,0.05673739997049173,0.05392379965633154,0.05124419958641132,0.04871569946408272,0.04632969883581003,0.0440780995413661,0.041951799454788365,0.039943599763015904,0.038048299960792065,0.036259399726986885,0.03457089948157469,0.03297689991692702,0.03147209947928786,0.030051399643222492,0.02870999959607919,0.027443299535661936,0.026245699884990852,0.025113199837505817,0.024043499647329252,0.023032899480313063,0.02207819962253173,0.02117599981526534,0.020323399764796097,0.019517499798287947,0.018755699507892132,0.01803389952207605,0.017349899746477604,0.01670289970934391,0.016090700092415016,0.015511399833485484,0.014963099732995033,0.014443999854847789,0.013952299719676375,0.013486599627261361,0.013043799748023352,0.01262259972281754,0.012223299747953812,0.011844499735161662,0.011485099714870254,0.011143899677942196,0.010819799732416868,0.01051199979459246,0.010219299777721366,0.009940989781171083,0.00967475981451571,0.009419939713552594,0.00917723976696531,0.008945979721223315,0.00872547971084714,0.008515119707832733,0.008314289851114154,0.008122439729049802,0.007939059830581149,0.007762229690949122,0.0075915797691171365,0.007428149770324429,0.007271519862115383,0.0071212998203312354,0.0069770998088642955,0.00683857985616972,0.0067053997578720255,0.006577259783322613,0.006452439779726167,0.0063307598466053605,0.006213449717809756,0.006100249748366575,0.005990919812271993,0.005885229834044973,0.005782969800444941,0.005683929853451748,0.0055879398714751005,0.0054948198376223445,0.005402979790233076,0.00531236978713423,0.005224309784049789,0.005138669783870379,0.0050552898707489176,0.004974049787657957,0.004894829859646658,0.004817499779164791,0.004741959894696872,0.004666699833857517,0.0045917098565648,0.004518379767735799,0.004446619811157386,0.004376339842565358,0.004307449872915943,0.004239869847272833,0.0041735298388327164,0.004108359920792282,0.004044279805384576,0.003979839811411996,0.003915049834176898,0.0038513598847202957,0.0037886998422133424,0.003727009849778066,0.0036662398682286343,0.003606329846661538,0.003547229901111374,0.0034889098800097904,0.0034298998846982918,0.003370269880785296,0.003311449875279019,0.0032534098718315363,0.0031960899165521064,0.0031394698889926076,0.0030834898740674057,0.0030281198560260236,0.0029733298967281976,0.002917689911555499,0.0028612399085735283,0.0028054598757686713,0.002750299929175526,0.0026957199055080614,0.0026416999171487987,0.002588209909542153,0.0025352098940250776,0.0024826799247724316,0.0024305799161083996,0.0023775099543854594,0.00232350993125389,0.002270059931712846,0.0022171199476967254,0.0021646799480852983,0.0021126899519003928,0.0020611299163041017,0.0020099899653966227,0.0019592299261906496,0.0019074299489147961,0.0018546699332849432,0.0018024099505661677,0.0017506199559041609,0.0016992799646686763,0.0016483499590928357,0.0015978299585791926,0.0015476799647634227,0.0014978799736127257,0.0014470099607327331,0.001395149971358478,0.0013437599894435455,0.0012928199721500278,0.0012422899696199845,0.0011921699818534155,0.0011424099696644892,0.001093009962157036,0.0010439499649995316,0.000995194025260086,0.0009453349969893073,0.0008944440002475554,0.000843993000065287,0.0007939569962521394,0.0007443110031696657,0.0006964309965648378,0.0006516050052596256,0.0006096420111134648,0.0005703619972337037,0.0005335970005641381,0.0004991870058195976,0.0004669839981943369,0.0004368489996219675,0.0004086479966645129,0.0003822610039302769,0.00035757099734231207,0.0003344699992643048,0.00031285599834518507,0.0002926360005706859,0.000273718001456776,0.00025602000338646275,0.00023946399839284518,0.00022397700134509554,0.00020948900297905007,0.0001959369971397488,0.00018326000038844845,0.00017140199997811578,0.00016031000025880834,0.00014993499886865416,0.00014023100084159523,0.00013115500041749328,0.00012266499834368005,0.00011472500045783818,0.00010729800123954192,0.00010035199920821469,9.385479946407334e-05,8.777829983349268e-05,8.209509966642751e-05,7.677960032500171e-05,7.180829985979169e-05,6.715869979719476e-05,6.28100997346337e-05,5.874309984695477e-05,5.493930014684641e-05,5.138180010059538e-05,4.805469992182528e-05,4.494299961758467e-05,4.203270024542386e-05,3.9311000364250503e-05,3.6765400182048324e-05,3.4384699877894796e-05,3.2158200156118255e-05,3.0075800016978366e-05,2.8128299921566697e-05,2.6306999946730986e-05,2.460350015098811e-05,2.3010399975949742e-05,2.152050016472155e-05,2.012699981908857e-05,1.882379986758072e-05,1.7605000114902698e-05,1.6465099937098177e-05,1.5398999721583095e-05,1.4402000033442164e-05,1.346950011793524e-05,1.2597499941572702e-05,1.1781900032777534e-05,1.101909992939909e-05,1.030570016761582e-05,9.638479999315072e-06,9.014490084761443e-06,8.430909929302288e-06,7.885120112405275e-06,7.374670000596477e-06,6.897269903068566e-06,6.450779968266336e-06,6.033209956513019e-06,5.642670013609556e-06,5.277419973026554e-06,4.935819977921104e-06,4.6163399929355364e-06,4.317539984792044e-06,4.038079964630015e-06,3.776720025901644e-06,3.5322800044923497e-06,3.3036700036367015e-06,3.089860039532747e-06,2.8898900268359284e-06,2.702859963695422e-06,2.5279400119870843e-06,2.3643499578914393e-06,2.2113399988180995e-06,2.0682400077021157e-06,1.9344100034383396e-06,1.80923000433116e-06,1.6921600073753023e-06,1.5826699855855015e-06,1.4802600105667807e-06,1.3844900195181253e-06,1.2949100020402209e-06,1.2111299933318758e-06,1.1327699761901993e-06,1.0594799846330716e-06,9.9093698698501e-07,9.26828998141597e-07,8.668700009669313e-07,8.107909981921088e-07,7.583409977011494e-07,7.092850040635312e-07,6.634040090602866e-07,6.204920026675609e-07,5.803560014783216e-07,5.428170008296244e-07,5.077070047339779e-07,4.7486899982610947e-07,4.4415600086722407e-07,4.15429999141755e-07,3.885619979845008e-07,3.634329956980764e-07,3.39928997542908e-07,3.179459990102866e-07,2.973850001808387e-07,2.7815499947791977e-07,2.601680032891333e-07,2.4334500399921427e-07,2.276099995886701e-07,2.1289199973277087e-07,1.9912699874187942e-07,1.862519987128053e-07,1.7421000109152374e-07,1.629469987089275e-07,1.5241200064982271e-07,1.4255899927206883e-07,1.3334300182539968e-07,1.2472300052005872e-07,1.1666000136282643e-07,1.0911899946582555e-07,8.552429697772368e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3642349143822987,1.4753400087356567,1.5921800136566162,1.702720006306966,1.8128400047620137,1.9225600063800812,2.0318600138028464,2.1411499977111816,2.2508400082588196,2.3609299858411155,2.4714199900627136,2.5822999676068625,2.6935800115267434,2.8052499890327454,2.917319973309835,3.0297800501187644,3.1426199873288474,3.2556100289026895,3.368490000565847,3.4812600215276084,3.5939300457636514,3.7064799865086875,3.81892999013265,3.9312700033187866,4.043489992618561,4.155609965324402,4.267619967460632,4.379129966100057,4.489759922027588,4.599500060081482,4.708359956741333,4.81634000937144,4.9234399398167925,5.029660026232402,5.134999990463257,5.2394700050354,5.34305997689565,5.446270028750102,5.549579977989197,5.652999957402547,5.756519953409831,5.8601300319035845,5.9638599554697675,6.06768000125885,6.1716099580128985,6.275639931360881,6.379770000775655,6.4839299122492475,6.588080008824666,6.692210038503011,6.796309987703959,6.9004000425338745,7.004459977149963,7.10851005713145,7.212529977162679,7.316539963086446,7.420520027478536,7.524380048116048,7.628039995829265,7.731499989827474,7.8347500165303545,7.937789996465047,8.040630062421164,8.143270095189413,8.245699961980185,8.347940047581991,8.449959993362427,8.55148990948995,8.652220090230307,8.752140045166016,8.851280053456625,8.949610074361166,9.047159989674887,9.143909931182861,9.239870071411133,9.335050106048584,9.42943000793457,9.523139953613281,9.61627999941508,9.708849986394247,9.800840059916178,9.892269929250082,9.983119885126749,10.073399941126505,10.163100004196167,10.252300103505453,10.340900103251139,10.428799947102865,10.515700022379557,10.601800044377645,10.687000115712484,10.771300077438354,10.854700009028116,10.937300046284994,11.018899917602539,11.099699894587198,11.17959992090861,11.258600155512491,11.336700042088827,11.413899898529053,11.490300019582113,11.565799951553345,11.640400012334188,11.714200019836426,11.787099917729696,11.859099944432577,11.930299997329712,12.000600099563599,12.07009998957316,12.13860011100769,12.206399917602539,12.273200035095215,12.33929991722107,12.404399951299032,12.468700011571249,12.53220009803772,12.594800074895224,12.656599998474121,12.71750005086263,12.777599891026815,12.83680009841919,12.89520001411438,12.952800035476685,13.00950002670288,13.065400123596191,13.120500008265177,13.174700021743774,13.228099902470907,13.280699968338013,13.332399924596151,13.383299986521402,13.43339991569519,13.482700109481812,13.531099955240885,13.578800121943155,13.62559994061788,13.671600023905436,13.716800133387247,13.761100053787231,13.804699977238974,13.847399950027466,13.889400005340576,13.930499792098999,13.970899979273478,14.010399977366129,14.049100001653036,14.087099949518839,14.124199867248535,14.160499890645346,14.196099917093912,14.23080007235209,14.264799992243448,14.297899881998697,14.330300013224283,14.361899932225546,14.392700036366781,14.422700007756552,14.452000061670939,14.480400005976358,14.508100112279257,14.535000085830688,14.561099847157797,14.58649984995524,14.61109987894694,14.634899775187174,14.657900015513102,14.680200020472208,14.70169997215271,14.722400029500326,14.74240001042684,14.761600017547607,14.77999997138977,14.79770008722941,14.814700047175089,14.83080013593038,14.84630004564921,14.860900004704794,14.874899943669638,14.888000011444092,14.900399923324585,14.912099997202555,14.92300001780192,14.933200041453043,14.942699988683065,14.95139996210734,14.95929996172587,14.966499964396158,14.972999970118204,14.978800137837728,14.983800093332926,14.988099892934164,14.991599957148233,14.994499921798706,14.996599992116293,14.997900009155273,14.998600085576376,14.998499949773153,14.997699975967407,14.996200005213419,14.993899981180826,14.991000016530355,14.987299919128418,14.982899904251099,14.977799892425537,14.972000042597452,14.965499957402548,14.958300034205118,14.95039995511373,14.941699902216593,14.932400067647299,14.922300020853678,14.911600112915039,14.900099913279215,14.888000011444092,14.875099897384644,14.861600001653036,14.847400029500326,14.832399924596151,14.816799958546957,14.800500075022379,14.783499876658121,14.76579999923706,14.747499942779541,14.728399912516275,14.708700021107992,14.688299894332886,14.667200009028116,14.645400047302246,14.622900009155273,14.599799871444702,14.576000134150187,14.551500002543131,14.526400009791056,14.50059994061788,14.474100033442179,14.446899970372518,14.419099966684977,14.390999952952066,14.362900018692017,14.33489998181661,14.306899944941202,14.279000123341879,14.251199960708618,14.223399957021078,14.195600032806396,14.167900005976358,14.140300114949545,14.11269998550415,14.085199991861979,14.057700077692667,14.03029990196228,14.003000020980835,13.975600004196167,13.948399941126505,13.921200037002563,13.894100109736124,13.866999864578247,13.839899937311808,13.812899986902872,13.785999854405722,13.759099880854288,13.732300043106079,13.705499966939291,13.678799947102865,13.65209992726644,13.625499884287516,13.598999977111816,13.572499990463257,13.546000003814697,13.519599914550781,13.493199984232584,13.466900189717611,13.440700054168701,13.414499998092651,13.388300021489462,13.362200021743774,13.33619999885559,13.310199975967407,13.284300088882446,13.258399963378906,13.232500076293945,13.206700166066488,13.181000153223673,13.15529990196228,13.12970002492269,13.10409982999166,13.078500111897787,13.053099950154623,13.027599970499674,13.00219996770223,12.976899941762289,12.951599915822348,12.926400025685629,12.90120013554891,12.876000006993612,12.85100015004476,12.825899918874105,12.800899982452393,12.776000022888184,12.751100063323975,12.726199865341187,12.7014000415802,12.676700194676718,12.652000109354654,12.627400159835815,12.602800051371256,12.578199942906698,12.553700049718222,12.529199997584024,12.504800001780191,12.480500062306723,12.456199963887533,12.431899944941202,12.407700061798096,12.38349994023641,12.359399875005087,12.335299968719482,12.311299959818522,12.287299791971842,12.263400077819824,12.239500045776367,12.21560009320577,12.19190009435018,12.168100039164225,12.144400040308634,12.120800097783407,12.097100019454956,12.073599974314371,12.050099929173788,12.026600042978922,12.003200054168701,11.97980006535848,11.956500053405762,11.933200041453043,11.910000006357828,11.886799812316895,11.863599936167398,11.840500036875406,11.8174999554952,11.79449995358785,11.77150003115336,11.748600085576376,11.72569990158081,11.702900012334188,11.680100123087565,11.657299915949503,11.634699980417887,11.611999909083048,11.589399894078573,11.566799879074097,11.544300079345703,11.52180004119873,11.499399979909262,11.477000077565512,11.454700072606405,11.432399908701578,11.410099983215332,11.38789987564087,11.365799824396769,11.343600034713745,11.321599960327148,11.299499988555908,11.277499993642172,11.255600055058798,11.233699957529703,11.21180001894633,11.190000057220459,11.168199936548868,11.14650011062622,11.124799966812134,11.103099902470907,11.081499894460043,11.060000022252401,11.038399855295816,11.017000118891398,10.995500008265177,10.97409995396932,10.952799956003824,10.93149995803833,10.910199960072836,10.888999859491983,10.867799997329712,10.84660005569458,10.825500011444092,10.804500023523966,10.7835001150767,10.762499968210856,10.74150013923645,10.720700025558472,10.69979993502299,10.67900005976359,10.658199946085611,10.637499968210856,10.616799910863241,10.596100091934204,10.575500011444092,10.555000066757202,10.53440006573995,10.5139000415802,10.493499914805094,10.473100026448568,10.452699979146322,10.432399908701578,10.412100076675415,10.391799926757812,10.371599833170572,10.351499954859415,10.331300020217896,10.311200062433878,10.291200002034506,10.271200021107992,10.251199881235758,10.231300036112467,10.211399873097738,10.191500027974447,10.17170000076294,10.151900053024292,10.132200002670288,10.112500031789144,10.092800060907999,10.07320006688436,10.053600072860718,10.03410005569458,10.014599959055582,9.995109955469767,9.975680112838745,9.956290006637573,9.936930100123087,9.917620023091635,9.898339907328287,9.87909992535909,9.859899997711182,9.84073003133138,9.82160997390747,9.802520036697388,9.783460060755411,9.764449834823608,9.74547004699707,9.726530075073242,9.707629919052124,9.688759962717691,9.669939994812012,9.651139895121256,9.632389942804972,9.613669951756796,9.594989935557047,9.57635005315145,9.557739973068237,9.539170026779175,9.520630121231079,9.502129952112833,9.483669996261597,9.465239922205607,9.446850061416626,9.428500096003214,9.41018001238505,9.391900142033895,9.373650074005127,9.355440060297648,9.337270100911459,9.319130023320517,9.301030000050863,9.282960176467896,9.26493008931478,9.246930122375488,9.228969891866049,9.211049954096476,9.193149964014689,9.175300041834513,9.157480160395304,9.139690001805624,9.12194005648295,9.104219913482666,9.086540142695108,9.068900108337402,9.051279862721762,9.033710161844889,9.016159931818644,8.99866008758545,8.9811798731486,8.963740030924479,8.946340004603067,8.928959925969442,8.911629915237427,8.894319852193197,8.885680039723715};
        C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480125069618225,4.563908616701762,4.604879180590312,4.670729319254558,4.735669255256653,4.799679239590962,4.8627593119939165,4.92574926217397,4.989479303359985,5.05393918355306,5.119149287541707,5.185089190800984,5.251769304275513,5.31917929649353,5.38732926050822,5.45621923605601,5.525849183400472,5.5959592660268145,5.666309197743733,5.736899137496948,5.80773921807607,5.878809134165446,5.9501092831293745,6.021659175554912,6.093449195226033,6.1654791831970215,6.237739205360413,6.310139179229736,6.382569273312886,6.455019235610962,6.527499159177144,6.599999189376831,6.672529220581055,6.745089213053386,6.817679206530253,6.8902891874313354,6.962929209073384,7.035459200541179,7.107749183972676,7.179789225260417,7.2515891790390015,7.3231492439905805,7.394469261169434,7.465539216995239,7.536359270413716,7.606949170430501,7.677289207776387,7.747289180755615,7.816849231719971,7.885989268620809,7.954679171244304,8.02294925848643,8.090769290924072,8.158169269561768,8.22512928644816,8.291649341583252,8.357739289601644,8.423279285430908,8.488159338633219,8.552369276682535,8.615929206212362,8.67880916595459,8.741039196650187,8.80259919166565,8.863489309946695,8.923729260762533,8.983299255371094,9.04232923189799,9.100929419199625,9.159109274546305,9.216869195302328,9.274209340413412,9.331119298934937,9.387619336446127,9.443679332733154,9.499329408009848,9.55454953511556,9.609369357426962,9.663809458414713,9.717849334081015,9.771509329477945,9.824769417444864,9.877659241358439,9.93014931678772,9.982259273529053,10.0339994430542,10.085299253463745,10.13629945119222,10.186899503072103,10.237099329630533,10.286999464035034,10.336599508921305,10.385799407958984,10.43459963798523,10.483099301656088,10.531299511591593,10.579099496205648,10.62649941444397,10.673599402109781,10.72029940287272,10.766699314117432,10.812699476877848,10.858399629592896,10.903699477513632,10.948699474334717,10.99329940478007,11.037599484125773,11.081499417622885,11.125099420547485,11.168299516042074,11.21109946568807,11.253599643707275,11.295799414316813,11.337599515914917,11.378999551137289,11.42009941736857,11.460899432500204,11.501299460728964,11.54129958152771,11.580999612808228,11.620399395624796,11.659399588902792,11.697999477386475,11.736299673716227,11.774199644724527,11.811799685160318,11.848999659220377,11.885899623235067,11.922399679819742,11.95859956741333,11.994499603907267,12.029899597167969,12.065099557240805,12.099799553553263,12.134299675623575,12.168299674987793,12.20199982325236,12.23539956410726,12.268399635950724,12.3010995388031,12.333399693171183,12.365399599075317,12.396999597549438,12.42829966545105,12.459199746449789,12.489699602127075,12.519999742507935,12.5497997601827,12.579299608866373,12.608499765396118,12.63729969660441,12.665799856185913,12.693899710973104,12.721599658330282,12.748999754587809,12.776099761327108,12.802799701690674,12.829099655151367,12.855199654897055,12.880799690882364,12.906099637349447,12.931099732716879,12.955699602762857,12.979899644851685,13.003799676895142,13.027399698893229,13.050599654515585,13.07349967956543,13.095999797185263,13.118099689483643,13.139899730682373,13.161399761835733,13.182499726613363,13.203199704488119,13.223599751790365,13.243699868520102,13.263399680455526,13.28279972076416,13.301799774169922,13.32039968172709,13.33869973818461,13.35669986406962,13.374299764633179,13.391599814097086,13.408499797185263,13.425099690755209,13.441299756368002,13.457099914550781,13.472599824269613,13.487799962361654,13.502599875132242,13.517099698384603,13.531199932098389,13.544999917348227,13.558399756749472,13.571499903996786,13.584199825922648,13.596599896748861,13.60859990119934,13.620300054550171,13.63159982363383,13.642599821090698,13.653199831644693,13.66349983215332,13.673399845759073,13.683000008265177,13.692199945449829,13.701099952061972,13.709699869155884,13.71779990196228,13.72569982210795,13.733199755350748,13.740300019582113,13.747099955876669,13.753599961598715,13.759699980417887,13.765399932861328,13.7707998752594,13.775899887084961,13.780599991480509,13.784900029500326,13.788899898529053,13.79259999593099,13.795900026957193,13.79889988899231,13.801500002543131,13.803799867630005,13.805699904759726,13.807300011316935,13.808499972025553,13.809400002161661,13.809899886449179,13.810100158055624,13.809899806976318,13.809400002161661,13.808599869410196,13.807400067647299,13.805999994277954,13.80460000038147,13.803200006484985,13.801800092061361,13.800400018692017,13.799100081125895,13.79770008722941,13.796299934387207,13.794900099436441,13.793600082397461,13.792200009028116,13.790799935658773,13.789400180180868,13.788000106811523,13.786699930826822,13.78529985745748,13.783900022506714,13.78249994913737,13.781099955240885,13.779799938201904,13.77839994430542,13.776999950408936,13.775600035985311,13.77429993947347,13.772900025049845,13.77150003115336,13.770099878311157,13.768700043360392,13.767400026321411,13.766000032424927,13.764600038528442,13.763199965159098,13.761899948120117,13.760500033696493,13.759099960327148,13.757699966430664,13.756400028864542,13.754999876022339,13.753600041071573,13.752200047175089,13.750899950663248,13.749500036239624,13.74809988339742,13.746700127919516,13.745399951934814,13.74400003751119,13.742600043614706,13.741200049718222,13.73990019162496,13.738500038782755,13.73710012435913,13.735700050989786,13.734400033950806,13.733000040054321,13.731600046157837,13.730199972788492,13.728899955749512,13.727499961853027,13.726099888483683,13.724799871444702,13.723400036493937,13.721999963124594,13.720600048700968,13.719299952189127,13.717899878819784,13.716499964396158,13.715199947357178,13.713800112406412,13.712399959564209,13.711000124613443,13.709700028101603,13.708300034205118,13.706899960835775,13.705600102742514,13.704200029373169,13.702800035476685,13.70139996210734,13.700099865595499,13.698699871699015,13.69729995727539,13.696000019709269,13.694599946339926,13.693199952443441,13.69190001487732,13.690500020980835,13.689099868138632,13.687699953715006,13.686400095621744,13.685000022252401,13.683599948883057,13.682300011316935,13.68090001742045,13.679500023523966,13.678200006484985,13.676800012588501,13.675400018692017,13.674100001653036,13.672700007756552,13.671300093332926,13.669999996821085,13.668600082397461,13.667199929555258,13.665899912516275,13.664499998092651,13.663100083669027,13.661799987157186,13.660399913787842,13.658999919891357,13.657700141270956,13.656299988428751,13.654900074005127,13.653599977493286,13.652199904123941,13.650800069173178,13.649499972661337,13.648099978764852,13.646699984868368,13.645400047302246,13.644000053405762,13.642700036366781,13.641299962997437,13.639900048573812,13.63860003153483,13.637200117111206,13.635800123214722,13.6345001856486,13.633099873860678,13.631700038909912,13.630400021870932,13.628999948501587,13.627699931462606,13.62630001703898,13.624900023142496,13.623599926630655,13.622200091679892,13.620799859364828,13.619500001271566,13.618099927902222,13.616799910863241,13.615399996439615,13.613999923070272,13.61269990603129,13.611299912134806,13.609999895095825,13.608599980672201,13.607199986775717,13.605900049209595,13.60450005531311,13.603099822998047,13.601799964904785,13.600400050481161,13.59909995396932,13.597700039545694,13.59630004564921,13.59499994913737,13.593600034713745,13.592300017674765,13.59090002377828,13.589500109354654,13.588200012842814,13.58680009841919,13.585500160853067,13.584099849065145,13.582799911499023,13.5813999970754,13.579999923706055,13.578700065612793,13.57729991277059,13.575999975204468,13.574599981307983,13.573299884796143,13.571900049845377,13.570499976476034,13.569200118382772,13.567799965540567,13.566500027974447,13.565100113550821,13.56380001703898,13.562400102615356,13.561000029246012,13.559700012207031,13.558300018310547,13.557000080744425,13.55560008684794,13.5542999903361,13.552899916966757,13.551599979400635,13.55019990603129,13.548799991607666,13.547500054041544,13.546099980672201,13.544800202051798,13.543400049209595,13.542100032170614,13.54070003827413,13.539400100708008,13.538000106811523,13.536700010299683,13.535299936930338,13.533899943033854,13.532599925994873,13.531200011571249,13.529899994532267,13.528500000635782,13.527199983596802,13.525799989700317,13.524500052134195,13.523100137710571,13.52179996172587,13.520399967829386,13.519100030263266,13.517700036366781,13.516400019327799,13.514999945958456,13.513700008392334,13.51229993502299,13.510999917984009,13.509600003560385,13.508300065994263,13.506900072097778,13.505600055058798,13.504199822743734,13.502899964650473,13.501499891281128,13.500200112660727,13.498799959818522,13.497500022252401,13.496100107828775,13.494800090789795,13.49340001742045,13.49210007985433,13.490699927012125,13.489400068918863,13.48799999554952,13.48669981956482,13.485300143559774,13.483999967575073,13.482599894205729,13.481300036112467,13.479899883270264,13.478600025177002,13.477199951807657,13.475900014241537,13.474500020345053,13.47320000330607,13.471799929936727,13.470499992370605,13.469099998474121,13.468500057856241};
        //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174928297599157,0.6330969482660294,0.6429339448610941,0.6567259579896927,0.6703249464432398,0.6837289482355118,0.6969399551550547,0.710130954782168,0.7234759479761124,0.7369729479153951,0.75062395632267,0.764429951707522,0.7783899406592051,0.7925029546022415,0.806768943866094,0.8211889415979385,0.8357629428307215,0.8504389375448227,0.8651639421780905,0.8799369434515635,0.8947609464327494,0.9096349477767944,0.9245569457610449,0.9395289421081543,0.9545509467522303,0.9696219265460968,0.9847409476836523,0.9998889565467834,1.0150399506092072,1.030199944972992,1.0453599492708843,1.0605299373467763,1.075699935356776,1.0908799469470978,1.1060599486033122,1.1212399403254192,1.1364399294058483,1.1516099274158478,1.1667199432849884,1.1817899545033772,1.1967999339103699,1.2117599447568257,1.2266699473063152,1.2415299514929454,1.256339927514394,1.2710999548435211,1.2857999503612518,1.300429920355479,1.3149699370066326,1.3294199407100677,1.3437799314657848,1.3580499490102131,1.3722199499607086,1.3862999478975933,1.4002999365329742,1.414199948310852,1.4279999434947968,1.4416999518871307,1.4552499453226726,1.4686599572499592,1.4819399515787761,1.495069960753123,1.5080699622631073,1.520919958750407,1.533639947573344,1.5462199449539185,1.5586499571800232,1.5709799726804097,1.5832099517186482,1.5953599512577057,1.6074099441369374,1.6193799475828807,1.6312599579493205,1.643049955368042,1.6547499497731526,1.66635995109876,1.6778799494107564,1.6893199582894642,1.7006799578666687,1.7119499345620472,1.7231399615605671,1.7342499593893688,1.7452799777189891,1.7562299569447835,1.7670999666055043,1.777879963318507,1.788579950730006,1.7992099622885387,1.8097599546114604,1.820229947566986,1.830629954735438,1.8409599661827087,1.851209968328476,1.8613899648189545,1.8714899619420369,1.8815199732780457,1.8914799590905507,1.9013599654038746,1.91116996606191,1.9208999574184418,1.9305599729220073,1.9401399592558544,1.9496499598026276,1.9590899646282196,1.9684499502182007,1.9777399599552155,1.9869499703248341,1.9960899551709492,2.0051599542299905,2.0141499837239585,2.023069977760315,2.031909942626953,2.040679931640625,2.049369970957438,2.0579899748166404,2.066539943218231,2.0750099420547485,2.0834099849065146,2.091739992300669,2.0999899903933206,2.108169992764791,2.1162699858347573,2.124299963315328,2.13224995136261,2.140139957269033,2.1479399601618447,2.155679980913798,2.1633399724960327,2.170919954776764,2.1784300009409585,2.1858699917793274,2.1932399670283,2.200529952843984,2.207740008831024,2.2148799697558084,2.2219499746958413,2.228949944178263,2.2358699639638266,2.2427199681599936,2.2494900027910867,2.256190001964569,2.262819985548655,2.269369979699453,2.275849978129069,2.2822499871253967,2.288580000400543,2.2948399980862937,2.3010299801826477,2.307139972845713,2.3131699562072754,2.3191399772961936,2.325019915898641,2.330839971701304,2.336579978466034,2.3422499696413674,2.34784996509552,2.353369951248169,2.358809987703959,2.3641899625460305,2.3694899876912436,2.3747199972470603,2.3798699577649436,2.3849499821662903,2.389960010846456,2.3948999842007956,2.3997599879900613,2.4045499563217163,2.4092599749565125,2.4139099717140198,2.4184699654579163,2.4229699770609536,2.427389979362488,2.4317399660746255,2.436009963353475,2.440219978491465,2.4443399707476297,2.4483999808629355,2.4523799618085227,2.456289986769358,2.460119982560476,2.4638799826304116,2.467569967110952,2.4711899757385254,2.4747299551963806,2.4781999985376992,2.48158997297287,2.484909971555074,2.488159974416097,2.491340001424154,2.494439979394277,2.497469981511434,2.5004199941953025,2.5032999912897744,2.5061100125312805,2.5088499784469604,2.511509974797567,2.514099975426992,2.5166200002034507,2.5190599958101907,2.5214299956957498,2.523729979991913,2.525949994723002,2.5280999739964805,2.530179977416992,2.5321799914042153,2.534109969933828,2.5359700322151184,2.5377599596977234,2.5394700169563293,2.5411099791526794,2.5426699916521707,2.5441699822743735,2.5455899834632874,2.546929975350698,2.548210024833679,2.5494100054105124,2.5505399902661643,2.551590005556742,2.5525700052579245,2.5534799695014954,2.55431999762853,2.555079996585846,2.555769960085551,2.5563899874687195,2.5569300055503845,2.5574100017547607,2.5578099886576333,2.5581300059954324,2.5583800077438354,2.5585700074831643,2.558670004208883,2.5587100187937417,2.558670004208883,2.558559993902842,2.5583800077438354,2.558120012283325,2.557790001233419,2.557419995466868,2.5570599834124246,2.556689997514089,2.5563299854596457,2.55595995982488,2.555600027243296,2.5552300016085305,2.5548699696858725,2.5545000036557517,2.5541399916013083,2.5537700057029724,2.553409993648529,2.553040007750193,2.552679975827535,2.5523200035095215,2.551949997742971,2.551590005556742,2.5512200196584067,2.5508600076039634,2.5504899621009827,2.550129989782969,2.5497600038846335,2.54939999183019,2.5490400195121765,2.548670013745626,2.5483100215593972,2.547939976056417,2.5475799838701882,2.54721999168396,2.546850005785624,2.5464900135993958,2.54611998796463,2.5457599759101868,2.545400023460388,2.545029958089193,2.5446700056393943,2.544309993584951,2.5439399679501853,2.5435799956321716,2.543220023314158,2.5428499976793923,2.542489985624949,2.5421299934387207,2.541760007540385,2.5414000352223716,2.541039983431498,2.5406699776649475,2.540310005346934,2.5399500131607056,2.539590001106262,2.5392199953397117,2.5388599832852683,2.5384999910990396,2.538130005200704,2.5377699931462607,2.537410000960032,2.5370500087738037,2.536680042743683,2.5363200505574546,2.535960058371226,2.535599966843923,2.5352399945259094,2.5348700086275735,2.5345099568367004,2.534150004386902,2.5337899923324585,2.53343000014623,2.5330599745114646,2.532700002193451,2.5323400298754373,2.531980017820994,2.531619966030121,2.53125,2.5308900276819863,2.530530035495758,2.5301700234413147,2.5298100113868713,2.529449979464213,2.5290900071461997,2.5287200013796487,2.5283600091934204,2.527999997138977,2.5276400049527488,2.5272799928983054,2.5269200205802917,2.5265600085258484,2.526199996471405,2.5258400241533914,2.525480031967163,2.52511998017629,2.524750014146169,2.524390002091726,2.524030009905497,2.5236699978510537,2.5233100056648254,2.522949993610382,2.522590001424154,2.5222299893697104,2.5218699971834817,2.5215100049972534,2.52114999294281,2.5207900007565818,2.520430008570353,2.5200699965159097,2.5197100043296814,2.519350012143453,2.5189900000890098,2.5186299880345664,2.5182700157165527,2.5179100036621094,2.517549991607666,2.5171899994214377,2.516830007235209,2.5164699951807656,2.5161100029945374,2.515749990940094,2.5153899788856506,2.515030006567637,2.5146799882253013,2.5143200159072876,2.5139600038528442,2.513600011666616,2.5132399996121726,2.5128799875577292,2.5125199953715005,2.512159983317057,2.511800010999044,2.5114399989446006,2.5110900004704795,2.510729988416036,2.5103700160980225,2.510010004043579,2.509650011857351,2.5092899799346924,2.508929987748464,2.508579989274343,2.5082200169563293,2.507860004901886,2.5074999729792276,2.507140020529429,2.5067800084749856,2.5064300100008645,2.5060700178146362,2.505710025628408,2.5053500135739646,2.504989981651306,2.50463996330897,2.5042799711227417,2.5039199590682983,2.503560026486715,2.5032100081443787,2.5028500159581504,2.5024900237719216,2.5021300117174783,2.5017799735069275,2.501420001188914,2.5010599891344705,2.500699996948242,2.500349978605906,2.4999899864196777,2.499630014101664,2.4992799957593284,2.498919983704885,2.4985600113868713,2.498199999332428,2.497850000858307,2.4974899888038635,2.49712997674942,2.4967800180117288,2.496419986089071,2.496060013771057,2.495710015296936,2.4953500231107077,2.4949899911880493,2.494639972845713,2.4942800005277,2.493930002053579,2.49357000986735,2.493210017681122,2.4928600192070007,2.4924999674161277,2.492139975229899,2.491790016492208,2.4914300243059793,2.4910799860954285,2.4907199939092,2.490369975566864,2.4900099833806357,2.489649991194407,2.489300012588501,2.4889400005340576,2.4885900020599365,2.488229990005493,2.487880011399587,2.4875199794769287,2.4871699611345925,2.486810028553009,2.486449976762136,2.486099978288015,2.485740005970001,2.485389987627665,2.485030015309652,2.4846799969673157,2.484320024649302,2.483970026175181,2.483609994252523,2.483259995778402,2.4829099774360657,2.4825499852498374,2.4821999867757163,2.4818399945894876,2.481489976247152,2.481130003929138,2.4807799657185874,2.4804199735323587,2.4800699949264526,2.4797200163205466,2.4793600042661033,2.479009985923767,2.478649993737539,2.4782999753952026,2.477940003077189,2.477589964866638,2.477240006128947,2.476879974206289,2.4765299956003823,2.4761799971262612,2.475820004940033,2.475469966729482,2.475110034147898,2.4747600158055625,2.474410037199656,2.474050005276998,2.4737000266710916,2.473350008328756,2.4729899962743125,2.4726399978001914,2.4722899993260703,2.4719300071398416,2.4715800086657205,2.4712300101915994,2.4708699584007263,2.4705199797948203,2.470170001188914,2.469819962978363,2.4694599906603494,2.4691099921862283,2.468759993712107,2.4685799876848855};
        //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18198380743463835,0.18441500018040338,0.18685399989287058,0.18925200154383978,0.1916150003671646,0.19394300132989883,0.19623700032631555,0.19852900008360544,0.2008459990223249,0.20318999886512756,0.20556200047334036,0.20795999839901924,0.21038400009274483,0.21283499896526337,0.2153150017062823,0.21781999990344048,0.22035200148820877,0.22290299956997237,0.22546199957529703,0.22802899777889252,0.23060499876737595,0.23318900043765703,0.23578199992577234,0.23838300009568533,0.24099200094739595,0.24360999961694083,0.24623600021004677,0.24886700014273325,0.2514989996949832,0.2541310017307599,0.256763997177283,0.2593979984521866,0.26203300058841705,0.26466800024112064,0.267304003238678,0.26994099964698154,0.272577998538812,0.27521199484666187,0.27783700078725815,0.2804519981145859,0.2830579976240794,0.2856550042827924,0.28824199984471005,0.29082099845012027,0.29339099675416946,0.2959510038296382,0.29850199570258457,0.3010390003522237,0.3035610020160675,0.3060669998327891,0.3085570012529691,0.3110310013095538,0.31348800162474316,0.31592799723148346,0.31835199644168216,0.3207609976331393,0.3231540024280548,0.32552500317494076,0.3278719981511434,0.33019499977429706,0.33249299973249435,0.33476700137058896,0.3370159988602002,0.3392410029967626,0.34144100298484165,0.3436169996857643,0.3457679996887843,0.3478979965051015,0.3500120018919309,0.35211100180943805,0.3541930019855499,0.3562610000371933,0.3583119983474414,0.36034799615542096,0.36236799508333206,0.36437199761470157,0.36635999629894894,0.3683339978257815,0.3702939972281456,0.37223900109529495,0.3741700028379758,0.3760869974891345,0.3779889990886052,0.3798759977022807,0.3817490041255951,0.38360800097386044,0.3854519998033841,0.38728199402491253,0.38909899940093357,0.3909029960632324,0.39269400139649707,0.39447099963823956,0.39623499910036725,0.3979869981606801,0.3997250000635783,0.4014500007033348,0.40316199759642285,0.4048610006769498,0.40654699752728146,0.40821899970372516,0.40987899899482727,0.4115250036120415,0.41315900286038715,0.41477900246779126,0.41638599584499997,0.41798000037670135,0.41956199953953427,0.4211299965778987,0.42268400142590207,0.4242260009050369,0.42575500160455704,0.4272709960738818,0.42877400169769925,0.4302630027135213,0.43174000084400177,0.43320300181706745,0.43465399990479153,0.43609099835157394,0.4375159988800685,0.4389270022511482,0.44032499690850574,0.441711001098156,0.4430830031633377,0.4444420014818509,0.4457880010207494,0.4471209992965062,0.4484419996539752,0.44974900037050247,0.4510429998238881,0.45232400049765903,0.4535919974247615,0.4548470030228297,0.4560889999071757,0.4573180004954338,0.45853399982055026,0.45973699788252514,0.46092699964841205,0.4621039976676305,0.4632679993907611,0.46441999822854996,0.465558002392451,0.4666830003261566,0.4677950069308281,0.46889400482177734,0.46997999648253125,0.47105300426483154,0.4721140041947365,0.4731609995166461,0.4741950035095215,0.4752170021335284,0.47622499614953995,0.47721999635299045,0.4782029961546262,0.4791719987988472,0.4801290010412534,0.481072003642718,0.48200300087531406,0.4829209993282954,0.4838260014851888,0.4847169990340869,0.485595998664697,0.4864619970321655,0.487315001587073,0.48815599580605823,0.48898300031820935,0.48979700605074566,0.49059800058603287,0.491386999686559,0.4921620041131973,0.4929250031709671,0.49367500344912213,0.49441100160280865,0.49513499935468036,0.4958460008104642,0.4965440010031064,0.49722999582688016,0.4979020009438197,0.49856099983056384,0.4992080007990201,0.49984200050433475,0.500461995601654,0.5010700027147929,0.501665011048317,0.5022470007340113,0.5028169999519984,0.5033729920784632,0.5039169987042745,0.5044470032056173,0.5049649973710378,0.505470002690951,0.5059620042641958,0.5064409971237183,0.5069079995155334,0.5073609898487726,0.5078019996484121,0.5082299957672755,0.5086449980735779,0.5090470065673193,0.5094360013802847,0.509813000758489,0.5101759980122248,0.5105270047982534,0.5108650028705597,0.5111900021632513,0.511503001054128,0.5118019978205363,0.5120889941851298,0.5123629967371622,0.5126240104436874,0.5128719955682755,0.5131079951922098,0.5133299976587296,0.5135399997234344,0.5137370079755783,0.5139209926128387,0.5140929967164993,0.5142519921064377,0.5143970002730688,0.5145309915145239,0.5146510004997253,0.5147580107053121,0.5148529956738154,0.5149349917968115,0.5150050024191538,0.5150610059499741,0.5151050090789795,0.5151360034942627,0.5151539941628774,0.515158991018931,0.5151520073413849,0.5151320000489553,0.5150990039110184,0.5150530089934667,0.5149949987729391,0.5149239997069041,0.5148399968942007,0.5147429953018824,0.514640008409818,0.5145380000273386,0.5144350032011668,0.5143320063749949,0.514229009548823,0.5141260077555975,0.5140230009953181,0.5139200041691462,0.5138180106878281,0.513714998960495,0.5136119971672694,0.5135090003410975,0.5134069969256719,0.5133039951324463,0.5132009983062744,0.5130990048249563,0.5129960079987844,0.512893999616305,0.5127909978230795,0.5126890043417612,0.5125859876473745,0.5124829957882563,0.5123809973398844,0.5122790038585663,0.5121760020653406,0.5120739986499151,0.5119710117578506,0.5118689984083176,0.5117670049269994,0.5116639931996664,0.5115620046854019,0.51146000623703,0.5113569994767507,0.5112549960613251,0.5111529976129532,0.5110510041316351,0.5109479973713557,0.5108459939559301,0.5107440004746119,0.5106419920921326,0.5105399936437607,0.5104380051294962,0.5103359967470169,0.5102340032656988,0.5101309965054194,0.5100290030241013,0.5099270045757294,0.5098250011603037,0.5097240010897318,0.5096219976743063,0.5095200091600418,0.5094180007775625,0.5093159973621368,0.5092139939467112,0.5091119954983393,0.5090099970499674,0.5089089870452881,0.5088069885969162,0.5087050000826517,0.5086030066013336,0.508502001563708,0.5083999981482824,0.5082980046669642,0.5081969896952311,0.5080950011809667,0.5079929977655411,0.5078919927279154,0.5077899992465973,0.5076890041430792,0.5075869957605997,0.5074860006570816,0.507383997241656,0.5072829922040304,0.5071810036897659,0.507080003619194,0.5069779952367147,0.5068770001331965,0.5067760050296783,0.5066740016142527,0.5065730065107346,0.5064719915390015,0.5063699980576833,0.5062689979871114,0.5061679979165395,0.5060669978459676,0.505964994430542,0.5058639993270239,0.505762999256452,0.5056619991858801,0.5055609991153082,0.5054599990447363,0.5053589989741644,0.5052579989035925,0.5051569988330206,0.5050559987624487,0.5049550036589304,0.5048539986213049,0.5047530035177866,0.5046519984801611,0.5045510033766428,0.5044499983390173,0.5043489982684454,0.5042480081319809,0.5041469981273016,0.5040460030237833,0.5039459963639578,0.5038450012604395,0.503743996222814,0.5036429961522421,0.5035429994265238,0.5034419993559519,0.5033410042524338,0.5032409926255544,0.5031399975220362,0.5030390024185181,0.5029389907916387,0.5028379857540131,0.5027379939953486,0.5026370038588842,0.5025370021661123,0.5024360020955404,0.5023360004027685,0.5022350003321966,0.5021350036064783,0.5020339985688528,0.5019339968760809,0.5018340051174164,0.5017329951127371,0.5016330033540726,0.5015330016613007,0.5014320015907288,0.5013320048650106,0.5012319982051849,0.5011309931675593,0.5010309964418411,0.5009310096502304,0.5008310029904047,0.5007310012976328,0.5006310045719147,0.5005299896001816,0.5004299928744634,0.500330001115799,0.500229999423027,0.5001300026973089,0.5000300059715906,0.4999299968282382,0.49983000010252,0.49973000089327496,0.49962999920050305,0.49952999750773114,0.4994309991598129,0.4993309999505679,0.4992310007413228,0.4991309965650241,0.49903100232283276,0.49893100063006085,0.4988319973150889,0.4987320005893707,0.49863199641307193,0.4985320021708806,0.4984330013394356,0.49833299964666367,0.49823299795389175,0.4981340045730273,0.4980339954296748,0.4979339987039566,0.4978350003560384,0.49773500363032025,0.49763599783182144,0.49753600110610324,0.4974370002746582,0.4973369985818863,0.49723800271749496,0.49713800102472305,0.49703899770975113,0.4969400018453598,0.4968400026361148,0.49674099683761597,0.49664200097322464,0.49654199928045273,0.4964430009325345,0.4963439976175626,0.49624399840831757,0.49614499260981876,0.49604599674542743,0.4959469983975093,0.49584800253311795,0.49574800084034604,0.49564900000890094,0.4955499991774559,0.4954510008295377,0.49535199999809265,0.49525300165017444,0.4951540008187294,0.49505499998728436,0.49495600163936615,0.4948570008079211,0.494757999976476,0.494658999145031,0.49456000328063965,0.4944609999656677,0.4943620016177495,0.4942630007863045,0.49416500329971313,0.4940659999847412,0.493967001636823,0.49386800080537796,0.4937689999739329,0.4936709975202878,0.4935720016558965,0.49347300082445145,0.4933739999930064,0.4932760000228882,0.49317700167497,0.49307900418837863,0.4929800008734067,0.49288100004196167,0.49278300007184345,0.4926839992403984,0.49258600175380707,0.49248699595530826,0.4923890009522438,0.4922899976372719,0.49219200015068054,0.49209300180276233,0.49199499438206357,0.49189700186252594,0.491797998547554,0.4916999985774358,0.49160199612379074,0.49150299777587253,0.4914050002892812,0.49130699535210925,0.4912080044547717,0.49110999951759976,0.49101199954748154,0.4909139995773633,0.49081599960724515,0.49071700125932693,0.4906190012892087,0.49052100131909054,0.4904230013489723,0.4903250013788541,0.49022700140873593,0.4901290014386177,0.49003099898497265,0.48993299901485443,0.4898349990447362,0.48978600402673084};
        //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12690952544411024,0.1277529994646708,0.12864899759491286,0.12949799870451292,0.1303349994122982,0.13116000096003214,0.13197200124462447,0.13278299942612648,0.13360299915075302,0.1344330000380675,0.13527300084630647,0.13612199947237968,0.13698099926114082,0.1378490005930265,0.13872799898187319,0.13961599891384444,0.14051300038894018,0.14141699920097986,0.14232399935523668,0.14323500047127405,0.14414799958467484,0.14506499841809273,0.14598399897416434,0.14690500125288963,0.14782999952634177,0.14875800162553787,0.14968900009989738,0.15062200153867403,0.1515550004939238,0.15248899906873703,0.15342199802398682,0.15435600156585375,0.1552900013824304,0.1562239999572436,0.15715899815162024,0.15809299796819687,0.15902799988786379,0.15996200094620386,0.16089199980099997,0.1618180014193058,0.16274099921186766,0.16366100187102953,0.16457799822092056,0.16549100105961165,0.1664010025560856,0.16730699936548868,0.16821000104149184,0.16910800089438757,0.17000100140770277,0.170888002961874,0.17176900058984756,0.17264400174220404,0.17351300021012625,0.17437600096066794,0.17523299902677536,0.17608500147859255,0.17693000162641206,0.17776799947023392,0.17859600111842155,0.17941600208481154,0.18022700026631355,0.18102999900778136,0.18182299907008806,0.18260799845059714,0.18338400001327196,0.18415100003282228,0.18490900099277496,0.18566000213225684,0.18640399848421416,0.18714300294717154,0.1878760022421678,0.18860399971405664,0.189325001090765,0.19004099940260252,0.1907509999970595,0.19145699962973595,0.19215600192546844,0.19284799819191298,0.19353599846363068,0.19421900063753128,0.19489799812436104,0.195571002860864,0.19623899832367897,0.1969009985526403,0.19755900154511133,0.19821099936962128,0.19885699823498726,0.19949900110562643,0.20013599966963133,0.2007679988940557,0.20139500002066293,0.2020180026690165,0.2026359997689724,0.2032490000128746,0.2038580005367597,0.20446199923753738,0.20506099859873453,0.20565400024255118,0.2062429984410604,0.20682800188660622,0.20740700016419092,0.2079820012052854,0.20855199918150902,0.20911799867947897,0.20967799921830496,0.2102350021402041,0.21078599989414215,0.21133200079202652,0.21187400072813034,0.21241099884112677,0.21294300133983293,0.21347100039323172,0.2139939988652865,0.21451099961996078,0.21502399817109108,0.21553300072749457,0.2160359981159369,0.21653500075141588,0.217029998699824,0.21751900017261505,0.21800400192538896,0.21848400061329207,0.21895899747808775,0.2194300020734469,0.21989599987864494,0.2203570008277893,0.22081299995382628,0.22126599897940954,0.2217130002876123,0.22215400139490762,0.22259100154042244,0.2230240007241567,0.22345200181007385,0.22387499983112016,0.22429400061567625,0.22470700119932493,0.22511599957942963,0.22552100072304407,0.22592100004355112,0.22631599878271422,0.22670599818229675,0.22709200034538904,0.22747300068537393,0.22785000006357828,0.22822099924087524,0.22858699907859167,0.22894899919629097,0.22930600121617317,0.22965900103251138,0.23000600064794222,0.23034999892115593,0.23068799947698912,0.23102199782927832,0.23135099932551384,0.23167499899864197,0.231994998951753,0.23230999956528345,0.23262100045879683,0.23292599990963936,0.23322800050179163,0.23352400089303652,0.23381600032250086,0.23410300041238466,0.2343860020240148,0.2346629984676838,0.23493499805529913,0.23520400002598763,0.23546700179576874,0.235725998878479,0.2359799991051356,0.23622899999221167,0.23647399991750717,0.23671399926145872,0.23695000012715658,0.23717999955018362,0.23740700135628381,0.2376280017197132,0.23784500112136206,0.23805799956123033,0.23826499904195467,0.23846800128618875,0.2386650008459886,0.23885899658004442,0.23904699956377348,0.23923099661866823,0.2394109976788362,0.2395850010216236,0.23975499843557677,0.23992100109656653,0.240081999450922,0.2402379997074604,0.2403900014857451,0.240537000199159,0.24067900205651918,0.240817000468572,0.24094999954104424,0.24107699965437254,0.24120100090901056,0.24132000158230463,0.2414340004324913,0.24154299994309744,0.241647998491923,0.24174800142645836,0.24184400091568628,0.2419349985818068,0.2420219990114371,0.24210299799839655,0.24218100061019263,0.24225300177931786,0.2423219991226991,0.24238499999046326,0.24244399989644685,0.24249699960152307,0.24254599710305533,0.2425910010933876,0.24263099829355875,0.2426660011212031,0.24269700050354004,0.24272300178805986,0.24274500086903572,0.2427619993686676,0.2427740010122458,0.2427820016940435,0.2427849993109703,0.24278400217493376,0.24277799824873605,0.242767001191775,0.24275200193126997,0.2427319996058941,0.24270700042446455,0.24267800028125444,0.2426430011789004,0.24260500197609267,0.24256200219194093,0.2425140030682087,0.24246200049916902,0.24240499983231226,0.24234599992632866,0.24228699877858162,0.24222800135612488,0.24216900020837784,0.2421099990606308,0.24205100163817406,0.24199199676513672,0.24193300306797028,0.24187399819493294,0.2418150007724762,0.2417560008664926,0.24169699847698212,0.24163800229628882,0.24157899618148804,0.2415200024843216,0.24146099636952081,0.24140199894706407,0.24134300276637077,0.24128400161862373,0.24122600133220354,0.2411670001844565,0.2411080002784729,0.2410490003724893,0.24099000170826912,0.2409320001800855,0.24087299779057503,0.24081400160988173,0.2407550004621347,0.2406970001757145,0.2406380002697309,0.24057899912198386,0.2405210000773271,0.24046199768781662,0.24040299778183302,0.24034500122070312,0.24028599883119264,0.2402270001669725,0.2401689998805523,0.2401099999745687,0.24005199844638506,0.2399929997821649,0.23993500073750815,0.23987599834799767,0.23981800178686777,0.23975900063912073,0.23970100035270056,0.23964200168848038,0.23958400388558707,0.23952500025431314,0.23946699872612953,0.23940899843970934,0.23934999977548918,0.23929200197259584,0.2392329995830854,0.23917500053842863,0.23911700025200844,0.23905800158778825,0.23900000005960464,0.23894199977318445,0.2388840007285277,0.2388250008225441,0.2387670005361239,0.23870900024970373,0.2386509987215201,0.23859200005729994,0.2385339985291163,0.23847599948445955,0.2384180004398028,0.23836000139514604,0.23830200110872587,0.23824400082230568,0.23818500091632208,0.23812700187166533,0.2380690003434817,0.23801100005706152,0.23795300101240477,0.23789499948422113,0.23783699919780096,0.2377790001531442,0.23772099986672401,0.23766299958030382,0.23760499929388365,0.2375470002492269,0.2374889999628067,0.2374309996763865,0.23737299938996634,0.237315999964873,0.23725800092021623,0.23720000063379607,0.23714200034737587,0.23708400130271912,0.23702599853277206,0.23696900034944215,0.236911000063022,0.2368529997766018,0.2367949994901816,0.23673700044552484,0.23668000102043152,0.23662200073401132,0.236564002931118,0.2365069997807344,0.2364489994943142,0.23639099796613058,0.23633400350809097,0.23627600073814392,0.23621800045172373,0.23616099978486696,0.2361029994984468,0.23604600007335344,0.23598799978693327,0.23593000322580338,0.2358729988336563,0.23581499978899956,0.23575800036390623,0.2357000025610129,0.23564300189415613,0.23558499912420908,0.2355280009408792,0.23547100275754929,0.23541300122936568,0.2353560005625089,0.23529800027608871,0.23524099960923195,0.23518400142590204,0.23512600113948187,0.2350690004726251,0.23501199980576834,0.234954002002875,0.23489699761072794,0.23483999942739806,0.2347820003827413,0.2347249984741211,0.23466800029079118,0.234610998382171,0.23455299933751425,0.23449599742889404,0.23443899800380072,0.23438199857870737,0.2343249979118506,0.23426800097028413,0.23420999944210052,0.2341530000170072,0.23409600059191385,0.23403899868329367,0.23398199925820032,0.23392500107487044,0.23386800040801367,0.23381100222468376,0.23375400031606355,0.2336970033744971,0.23363999898235002,0.2335829995572567,0.23352599889039993,0.23346900070707002,0.23341199879844984,0.23335499813159308,0.23329799870649973,0.23324099803964296,0.23318399861454964,0.2331279975672563,0.23307100062568983,0.23301400244235992,0.2329569992919763,0.23289999862511954,0.23284299920002619,0.2327869993944963,0.23273000245292982,0.23267300054430962,0.2326159986356894,0.23256000131368637,0.23250300188859305,0.2324459987382094,0.23239000017444292,0.23233299950758615,0.2322759988407294,0.2322200002769629,0.23216299961010614,0.23210599894324938,0.2320500003794829,0.23199299971262613,0.2319370023906231,0.23188000048200288,0.23182299981514612,0.23176700125137964,0.23171000058452287,0.23165400077899298,0.23159700011213621,0.2315410003066063,0.23148399963974953,0.23142800107598305,0.23137199878692627,0.23131499936183295,0.23125899955630302,0.2312020001312097,0.23114600032567978,0.231089998036623,0.2310329998532931,0.2309770000477632,0.23092100148399672,0.2308639995753765,0.2308079997698466,0.2307520012060801,0.23069499929745993,0.23063900073369345,0.23058300092816353,0.23052699863910675,0.23047000169754028,0.23041400065024695,0.23035799836119017,0.2303020010391871,0.23024599875013033,0.23019000266989073,0.23013299951950708,0.2300769972304503,0.23002099990844727,0.2299650013446808,0.229908999055624,0.22985299676656723,0.2297969994445642,0.22974099963903427,0.22968499983350435,0.22962900002797446,0.22957300022244453,0.2295170004169146,0.22946100061138472,0.22940499956409136,0.22934899975856146,0.22929299995303154,0.22923700014750162,0.22918100158373514,0.22912500177820525,0.22906899824738503,0.2290140005449454,0.2289580007394155,0.22890199845035872,0.22884600112835565,0.22878999883929887,0.2287340002755324,0.2286790000895659,0.228623000284036,0.2285670004785061,0.22851100067297617,0.22845600048700967,0.22839999943971634,0.228343998392423,0.22828900068998337,0.22823299964269003,0.2281769998371601,0.22814899931351343};
        C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.2844059616327286,0.28999100377162296,0.2952450017134349,0.3011850044131279,0.3070389951268832,0.31280900289614993,0.31849299867947894,0.3241669957836469,0.329905999203523,0.3357119982441266,0.3415839994947116,0.3475220004717509,0.35352499783039093,0.3595939998825391,0.3657280032833417,0.37192899982134503,0.37819600105285645,0.3845049987236659,0.3908339962363243,0.3971850002805392,0.4035549983382225,0.4099459970990817,0.41635599732398987,0.42278700073560077,0.429238997399807,0.4357109988729159,0.44220299770434696,0.4487059985597928,0.45520999282598495,0.4617149978876114,0.46822000046571094,0.47472700228293735,0.4812349999944369,0.4877439985672633,0.4942539980014165,0.5007650032639503,0.5072780003150305,0.5137779911359152,0.5202560027440389,0.5267099986473719,0.5331389904022217,0.539544994632403,0.5459269980589548,0.5522860139608383,0.5586219926675161,0.5649349987506866,0.5712230056524277,0.5774790098269781,0.5836939911047617,0.5898690025011698,0.5960030009349188,0.6020950029293696,0.6081460068623225,0.6141570011774699,0.6201269924640656,0.6260570039351782,0.6319450040658315,0.637782002488772,0.643556997179985,0.6492700030406316,0.6549219985802969,0.6605120003223419,0.6660410016775131,0.6715080042680105,0.6769140015045801,0.6822580049435297,0.6875410030285517,0.6927730043729147,0.697964996099472,0.7031170129776001,0.7082309971253077,0.7133040030797323,0.7183380027612051,0.723332996169726,0.7282879948616028,0.7332030038038889,0.7380779981613159,0.7429169913132986,0.747718999783198,0.7524849971135458,0.7572140147288641,0.7619079947471619,0.7665639966726303,0.7711830039819082,0.7757660001516342,0.7803130000829697,0.7848239988088608,0.7893009980519613,0.7937440077463785,0.7981540014346441,0.8025309989849726,0.806875005364418,0.8111860156059265,0.815462996562322,0.819708009560903,0.8239209949970245,0.8281000057856241,0.8322449972232183,0.836358000834783,0.8404380033413569,0.8444840063651403,0.848499005039533,0.8524799942970276,0.8564279973506927,0.8603439927101135,0.8642260034879049,0.8680749932924906,0.871890996893247,0.8756750027338663,0.8794270058472952,0.8831449995438257,0.8868299971024195,0.8904820084571838,0.8941010038057963,0.8976879964272181,0.9012420028448105,0.9047629982233047,0.9082520057757696,0.9117079973220825,0.915130004286766,0.9185200035572052,0.9218770066897074,0.9252020021279653,0.92849400639534,0.9317539980014166,0.9349799950917562,0.9381739944219589,0.9413359959920248,0.9444650014241537,0.9475620041290919,0.9506250023841858,0.9536560028791428,0.9566540022691091,0.9596190055211385,0.9625530044237772,0.9654540022214254,0.9683220038811365,0.9711569994688034,0.9739600022633871,0.9767300138870875,0.9794669995705286,0.9821730057398478,0.9848460008700689,0.987485999862353,0.9900940010945002,0.9926690061887106,0.995211993654569,0.997720996538798,1.0001999934514363,1.0026499927043915,1.0050599972407024,1.0074400107065837,1.0097900032997131,1.0121000011761982,1.0143900016943614,1.0166399876276653,1.018859992424647,1.021039992570877,1.0232000052928925,1.0253200034300487,1.0274099906285603,1.0294600129127502,1.0314900080362956,1.0334800084431965,1.0354399979114532,1.0373700261116028,1.039270003636678,1.0411299963792164,1.042959988117218,1.0447599987188976,1.0465299983819325,1.0482600033283234,1.0499600072701771,1.0516300002733867,1.0532700022061665,1.0548799932003021,1.0564499994119008,1.05799001455307,1.0594999889532726,1.060980002085368,1.062420000632604,1.063839981953303,1.0652199983596802,1.0665699938933055,1.067879984776179,1.0691699981689453,1.0704199969768524,1.0716399947802226,1.0728299915790558,1.0739800135294597,1.0751100083192189,1.0761999885241191,1.077260007460912,1.0782899955908458,1.0792900025844574,1.0802500148614247,1.0811799863974254,1.0820899804433186,1.0829500059286754,1.083790014187495,1.0846000015735626,1.0853699843088787,1.08610999584198,1.0868200063705444,1.087500015894572,1.0881400008996327,1.088759998480479,1.0893399914105732,1.0898900032043457,1.090410013993581,1.0908999939759572,1.091349999109904,1.0917700032393138,1.092170000076294,1.0925200084845226,1.0928499897321065,1.093150019645691,1.0934099952379863,1.0936499933401744,1.0938500066598256,1.0940199891726177,1.0941500067710876,1.0942600071430206,1.0943300227324169,1.094380001227061,1.0943899949391682,1.094369997580846,1.0943099955717723,1.0942299862702687,1.0941100021203358,1.093970000743866,1.0937899947166443,1.0935800075531006,1.0933399895826976,1.0930600066979725,1.0927599867184956,1.0924199918905895,1.0920700132846832,1.0917199850082397,1.0913599928220112,1.0910099943478901,1.0906600058078766,1.090309997399648,1.0899599889914195,1.0895999769369762,1.0892500082651775,1.0889000097910564,1.0885500013828278,1.0881999929745991,1.087849994500478,1.087499996026357,1.0871500074863434,1.0868000090122223,1.0864500006039937,1.0860999822616577,1.0857500036557515,1.0853900015354156,1.0850400030612946,1.0846899847189586,1.0843399961789448,1.0840000013510387,1.0836499830087025,1.0833000044027965,1.0829499860604603,1.082599977652232,1.0822499990463257,1.0819000005722046,1.0815500020980835,1.08120001355807,1.0808500051498413,1.0804999967416127,1.0801600019137065,1.0798100034395854,1.0794600049654643,1.0791099965572357,1.0787600179513295,1.0784100194772084,1.0780699948469799,1.0777199864387512,1.0773699780305226,1.077019989490509,1.0766800045967102,1.0763300061225891,1.0759799877802532,1.0756400028864543,1.0752899944782257,1.0749399960041046,1.0746000011761982,1.0742499927679698,1.0738999942938487,1.0735599994659424,1.0732099910577138,1.0728600124518077,1.072519987821579,1.0721700092156727,1.071830004453659,1.0714800159136455,1.071129987637202,1.0707900027434032,1.070440004269282,1.0700999895731609,1.0697500109672546,1.0694099863370259,1.0690599977970123,1.0687200129032135,1.0683699945608776,1.0680299798647563,1.0676799913247426,1.0673399865627289,1.06700000166893,1.0666500131289165,1.0663099984327953,1.0659600098927815,1.0656199951966603,1.0652800103028615,1.064930001894633,1.0645900170008342,1.0642500122388203,1.0638999938964844,1.0635600090026855,1.0632199943065643,1.0628699759642284,1.0625300109386444,1.062190016110738,1.0618499914805095,1.0615000128746033,1.0611599882443745,1.0608200132846832,1.060479998588562,1.0601300199826558,1.0597899953524272,1.0594500104586284,1.0591100056966145,1.0587700108687084,1.0584299961725872,1.0580800076325734,1.0577400128046672,1.057399998108546,1.0570600032806396,1.056719998518626,1.0563800036907196,1.056039998928706,1.0557000041007996,1.0553599993387859,1.055019994576772,1.0546800096829732,1.054339994986852,1.0540000001589458,1.0536600053310394,1.0533199906349182,1.0529800057411194,1.0526400009791057,1.0522999962170918,1.051960011323293,1.0516199966271718,1.0512800017992656,1.0509399970372517,1.050599992275238,1.0502599974473317,1.0499200026194255,1.0495900015036266,1.0492499868075054,1.0489100019137065,1.0485700070858002,1.048229992389679,1.0478899876276653,1.0475600063800812,1.0472200016180675,1.0468799869219463,1.0465400020281475,1.0462099810441334,1.0458699961503346,1.0455299814542134,1.0451899965604146,1.0448599954446156,1.044519990682602,1.044180025657018,1.0438500146071117,1.0435099800427754,1.0431699852148693,1.0428400039672852,1.0425000091393788,1.0421600043773651,1.0418300032615662,1.0414900183677673,1.0411599973837535,1.0408199926217396,1.0404800077279408,1.0401499966780345,1.0398099819819133,1.0394799808661144,1.0391400059064229,1.038809984922409,1.0384700000286102,1.0381399989128113,1.037800004084905,1.0374700129032135,1.0371300081411998,1.0368000070254009,1.0364600121974945,1.036130001147588,1.0358000199000041,1.0354599754015605,1.0351300140221913,1.0347900092601776,1.0344600081443787,1.0341300070285797,1.0337900122006733,1.033460001150767,1.0331300000349681,1.0327900052070618,1.0324600040912628,1.0321300029754639,1.0317899982134502,1.0314600070317586,1.0311299959818523,1.0307999948660533,1.0304600099722545,1.030129998922348,1.0297999878724415,1.0294699966907501,1.0291299919287364,1.0288000007470448,1.0284699996312459,1.028139998515447,1.0278099874655406,1.027479996283849,1.0271399815877278,1.0268099904060364,1.026479999224345,1.0261500080426533,1.0258200069268544,1.0254900058110554,1.0251600046952565,1.0248299936453502,1.0245000024636586,1.0241700013478596,1.0238400002320607,1.0235099991162617,1.0231800079345703,1.0228499968846638,1.0225199957688649,1.022189994653066,1.0218600034713745,1.0215300023555756,1.0212000012397766,1.0208700001239777,1.0205399990081787,1.0202099978923798,1.0198799967765808,1.0195500055948894,1.0192200044790904,1.0188900033632915,1.0185700058937073,1.0182400147120159,1.0179099837938945,1.0175799926122029,1.0172500212987263,1.0169200003147125,1.0166000028451283,1.0162700017293294,1.015940010547638,1.0156099994977315,1.0152900020281475,1.0149600009123485,1.0146300097306569,1.0143000185489655,1.0139799813429515,1.0136500199635823,1.013319989045461,1.0130000213781993,1.012669990460078,1.0123400191466014,1.0120200018088024,1.0116900006930034,1.0113599995772045,1.0110399921735127,1.0107100009918213,1.0103800098101299,1.0100600024064381,1.0097299913565319,1.00941002368927,1.0090800027052562,1.0087599953015645,1.008430004119873,1.0082699954509735};
        //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12944593777259192,0.13278100018699965,0.136098001152277,0.13956499844789505,0.14298199862241745,0.14634899919231734,0.1496669997771581,0.15297900140285492,0.15632900098959604,0.1597169997791449,0.16314400111635527,0.1666090004146099,0.17011200139919916,0.17365300034483275,0.17723200097680092,0.18084999918937683,0.1845060003300508,0.18818699941039085,0.1918790005147457,0.19558299953738847,0.19929900020360947,0.20302699878811836,0.20676699901620546,0.21051800126830736,0.2142809989551703,0.21805600076913834,0.22184300050139427,0.2256359967092673,0.22942999874552092,0.2332249991595745,0.2370189999540647,0.2408140003681183,0.24460999915997186,0.24840799843271574,0.2522049993276596,0.25600199898084003,0.2597999970118205,0.26359199980894726,0.26736899713675183,0.2711330031355222,0.27488400290409726,0.27861999720335007,0.28234199931224185,0.28605100015799206,0.2897459988792737,0.29342799882094067,0.29709599663813907,0.3007450004418691,0.3043700009584427,0.307970995704333,0.31154799709717435,0.3151020010312398,0.31863199919462204,0.3221370056271553,0.32561899969975155,0.3290770004192988,0.3325120011965434,0.33591599265734357,0.3392849986751874,0.342618003487587,0.34591400374968845,0.34917499870061874,0.35240000238021213,0.35558900733788806,0.35874199618895847,0.3618590012192726,0.36494099845488864,0.3679929996530215,0.3710220033923785,0.3740279972553253,0.37701099862655,0.3799700041611989,0.38290699819723767,0.38582099974155426,0.38871100296576816,0.3915790021419525,0.3944230005145073,0.39724599570035934,0.40004699925581616,0.40282700459162396,0.40558600177367526,0.4083230048418045,0.411040003101031,0.4137359981735547,0.4164100040992101,0.4190630043546359,0.42169400056203205,0.424306000272433,0.4268990034858386,0.4294719969232877,0.4320259988307953,0.43456099430720013,0.4370759998758634,0.4395730048418045,0.442050002515316,0.44450700283050537,0.4469460000594457,0.4493649999300639,0.4517659991979599,0.45414700110753375,0.45650800317525864,0.45885099470615387,0.46117400129636127,0.46347899983326596,0.46576400101184845,0.46802999824285507,0.47027600308259326,0.47250399738550186,0.4747120017806689,0.47690200060606003,0.4790719971060753,0.4812229995926221,0.4833549956480662,0.48546800514062244,0.4875609998901685,0.48963600397109985,0.4916919991374016,0.49372799694538116,0.4957460016012192,0.49774400393168133,0.4997230072816213,0.5016830017169317,0.5036239971717199,0.5055469969908396,0.5074499994516373,0.509333997964859,0.5111990024646124,0.513044998049736,0.5148719996213913,0.5166789988676707,0.5184680024782816,0.520237997174263,0.5219890028238297,0.523720994591713,0.5254340022802353,0.5271280060211817,0.5288030058145523,0.5304589966932932,0.5320969919363657,0.5337149997552236,0.5353139986594518,0.5368940035502116,0.5384560078382492,0.5399979998668035,0.5415220061937968,0.5430260052283605,0.5445119986931483,0.5459789931774139,0.5474270035823187,0.5488560001055399,0.5502659926811854,0.5516580094893774,0.553029994169871,0.5543840030829111,0.5557190030813217,0.5570350040992101,0.5583319962024689,0.5596100042263666,0.5608690033356348,0.5621100018421809,0.5633320063352585,0.5645350019137064,0.5657180001338323,0.566881999373436,0.5680269996325175,0.5691529909769694,0.5702609966198603,0.5713500082492828,0.5724200010299683,0.573471004764239,0.5745030095179876,0.5755170037349066,0.576512003938357,0.5774880051612854,0.5784459859132767,0.5793849974870682,0.5803050051132838,0.5812060038248698,0.5820889969666799,0.5829529960950216,0.5837980012098948,0.5846250057220459,0.5854330013195673,0.5862220029036204,0.5869930038849512,0.5877450009187063,0.5884780039389929,0.5891930013895035,0.5898890048265457,0.5905659943819046,0.5912249982357025,0.5918649981419245,0.5924870024124781,0.5930899977684021,0.5936740040779114,0.5942399998505911,0.5947870016098022,0.5953150043884913,0.5958250015974045,0.5963170031706492,0.596790000796318,0.597243994474411,0.5976799974838892,0.5980970015128454,0.5984959999720255,0.5988759944836298,0.5992369949817657,0.5995799948771795,0.5999050041039785,0.6002109944820404,0.6004990041255951,0.6007679949204127,0.6010179917017618,0.60125000278155,0.6014640033245087,0.6016589999198914,0.6018360058466593,0.601993997891744,0.6021339943011602,0.6022550016641617,0.6023579885562261,0.6024419963359833,0.6025080035130183,0.6025560001532236,0.6025849978129069,0.6025959948698679,0.6025880028804144,0.6025619953870773,0.6025180071592331,0.6024549951155981,0.6023740023374557,0.6022739956776301,0.6021560033162435,0.6020199954509735,0.6018659919500351,0.601692999402682,0.6015010078748068,0.6013009995222092,0.6011000027259191,0.6008999943733215,0.6007000009218851,0.6005000074704488,0.600299005707105,0.6000989874204,0.5998989939689636,0.5996990005175272,0.5994999955097834,0.5993000020583471,0.5990999937057495,0.5989000002543131,0.5987009952465693,0.5985010067621866,0.5983019967873892,0.598101998368899,0.5979029983282089,0.5977040032545725,0.5975050081809362,0.5973049948612849,0.5971059997876486,0.5969069997469584,0.5967079947392145,0.5965099980433782,0.5963109930356344,0.5961119929949442,0.5959130078554153,0.5957150012254715,0.5955160011847814,0.595318004488945,0.5951190044482549,0.5949210077524185,0.5947230011224747,0.5945239961147308,0.5943259944518408,0.5941280076901118,0.5939299960931143,0.5937320043643316,0.5935340027014414,0.5933370043834051,0.5931390027205149,0.592940996090571,0.5927440027395884,0.5925459911425909,0.5923490077257156,0.5921510010957718,0.5919540027777354,0.5917560011148453,0.5915589978297552,0.5913619995117188,0.5911649962266287,0.5909679929415385,0.5907709995905558,0.5905740161736807,0.590377002954483,0.5901810079813004,0.5899839997291565,0.5897870014111201,0.5895910064379374,0.5893939932187399,0.5891980081796646,0.5890009999275208,0.5888050049543381,0.5886089901129404,0.5884130001068115,0.58821702003479,0.5880210051933924,0.5878250151872635,0.5876290053129196,0.5874330103397369,0.5872369905312856,0.5870410054922104,0.5868459939956665,0.5866499990224838,0.5864550073941549,0.5862590074539185,0.5860639959573746,0.5858680059512457,0.5856730043888092,0.5854779978593191,0.5852830012639364,0.5850879947344462,0.5848929981390635,0.5846979965766271,0.5845029950141907,0.5843080083529154,0.5841129968563715,0.5839190036058426,0.5837240070104599,0.583529993891716,0.5833349972963333,0.5831409990787506,0.5829459975163142,0.5827519992987314,0.5825580010811487,0.5823639978965124,0.5821699947118759,0.581976001461347,0.5817820032437643,0.581587995092074,0.5813940018415451,0.5812000036239624,0.5810059954722723,0.5808129956324896,0.5806190023819605,0.5804260075092316,0.5802320043245951,0.580038994550705,0.5798459947109222,0.5796520014603933,0.5794590016206106,0.5792660117149353,0.5790730019410452,0.5788799971342087,0.5786870022614797,0.5784939974546432,0.5783010025819143,0.5781089961528778,0.5779159963130951,0.5777230064074198,0.5775309999783834,0.5773380051056544,0.5771460086107254,0.5769540071487427,0.5767609973748525,0.5765689959128698,0.5763769994179407,0.576184997955958,0.575993001461029,0.5758009999990463,0.5756090035041174,0.5754169970750809,0.5752250005801519,0.5750340024630228,0.5748420010010401,0.5746499995390574,0.5744590063889822,0.5742670049269994,0.5740760117769241,0.573884998758634,0.5736929972966512,0.5735019991795222,0.5733109960953394,0.5731200029452642,0.5729289998610815,0.5727379967768987,0.5725469986597697,0.5723560005426407,0.5721660008033117,0.5719750076532364,0.5717839946349462,0.5715939998626709,0.5714029918114344,0.5712130020062128,0.5710219939549764,0.5708320041497549,0.5706419944763184,0.5704520046710968,0.5702620049317678,0.5700720002253851,0.5698820054531097,0.569692000746727,0.569502001007398,0.5693119963010153,0.5691219965616862,0.5689330101013184,0.5687430004278818,0.5685530006885529,0.5683640042940775,0.568174014488856,0.5679849882920583,0.5677960018316904,0.5676070054372152,0.5674170106649399,0.5672279894351959,0.5670390029748281,0.566850001613299,0.56666100025177,0.5664730022350947,0.5662839959065119,0.5660949895779291,0.5659060031175613,0.5657180001338323,0.565529003739357,0.565341000755628,0.5651520093282064,0.5649640013774236,0.5647759983936945,0.5645870019992193,0.5643989990154902,0.5642109960317612,0.5640230029821396,0.5638349999984106,0.5636470019817352,0.5634590039650599,0.5632720043261846,0.5630840013424555,0.5628959983587265,0.5627090086539587,0.5625209907690684,0.5623340010643005,0.5621460030476252,0.5619589984416962,0.5617720037698746,0.5615840007861456,0.561397006114324,0.5612100015083948,0.561022991935412,0.5608359922965368,0.5606490025917689,0.5604620029528936,0.5602750033140182,0.5600890020529429,0.5599019974470139,0.5597150027751923,0.5595290015141169,0.5593420018752416,0.5591560006141663,0.5589700043201447,0.5587829947471619,0.5585969984531403,0.5584109922250112,0.5582250008980433,0.5580389946699142,0.5578529834747314,0.5576669971148173,0.5574809908866882,0.5572949995597204,0.5571099917093912,0.5569239954153696,0.556737999121348,0.5565530012051264,0.5563670049111048,0.5561819970607758,0.5559960057338079,0.5558110028505325,0.5556259999672571,0.5554410020510355,0.5552559942007065,0.5550709962844849,0.5548859934012095,0.5547009954849879,0.5545159975687662,0.554330994685491,0.5541460116704305,0.553961992263794,0.5537770042816798,0.5536850045124689};
        //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09223856652776401,0.0935115007062753,0.0947222001850605,0.09604009861747424,0.09733929981787999,0.09861889916161697,0.09987919901808102,0.1011370016882817,0.10241000043849151,0.10369799969096978,0.10500100006659825,0.10631800070405006,0.10764999936024348,0.10899599952002366,0.11035700018207233,0.11173199924329917,0.11312300028900306,0.11452300039430459,0.11592799983918667,0.11733699962496758,0.11875099937121074,0.12016900070011616,0.12159099988639355,0.12301900113622348,0.12445099962254365,0.1258879986902078,0.12732900058229765,0.12877199922998747,0.130216001222531,0.13165999948978424,0.13310400024056435,0.1345490018526713,0.1359929988781611,0.13743800049026808,0.1388830008606116,0.14032799998919168,0.14177299663424492,0.14321599900722504,0.14465399955709776,0.14608600114782652,0.14751300091544786,0.1489350013434887,0.1503510003288587,0.1517620012164116,0.15316700066129366,0.15456699952483177,0.15596300115187964,0.15734999751051268,0.15872900063792864,0.16009800136089325,0.16145899891853333,0.16281000028053919,0.16415200009942055,0.16548500085870424,0.1668080004553,0.16812299812833467,0.169429000467062,0.17072299992044768,0.17200300097465515,0.17326999952395758,0.17452300215760866,0.175761998941501,0.17698700229326883,0.17819799979527792,0.17939500013987222,0.18057900170485178,0.18174900114536285,0.18290900066494942,0.18405899902184805,0.18519900118311247,0.1863310014208158,0.18745499973495802,0.18857000271479288,0.1896749995648861,0.19077199697494507,0.19186000153422356,0.1929389995833238,0.1940100019176801,0.19507200146714845,0.1961269974708557,0.1971719997624556,0.19820999850829443,0.19924000153938928,0.20026200140515962,0.20127600183089575,0.20228200033307076,0.20327899853388467,0.2042690006395181,0.20525100082159042,0.2062259999414285,0.20719299962123236,0.2081530007223288,0.20910600076119104,0.21005100011825562,0.2109890008966128,0.2119189997514089,0.21284200126926103,0.21375799924135208,0.21466699987649918,0.21556799858808517,0.21646100158492723,0.2173470010360082,0.2182259994248549,0.21909800171852112,0.21996099626024565,0.22081800053517023,0.22166699916124344,0.2225090004503727,0.2233440006772677,0.22417099649707475,0.22498999908566475,0.22580300023158392,0.22660900031526884,0.22740599885582924,0.22819699719548225,0.2289799985786279,0.22975600014130274,0.23052499939997992,0.23128599921862283,0.23203899711370468,0.23278600225845972,0.2335249992708365,0.2342579998075962,0.23498199880123138,0.23569899797439575,0.23640899981061617,0.23711199934283891,0.2378080002963543,0.23849599932630858,0.23917699853579202,0.2398499995470047,0.24051700035730997,0.24117500086625418,0.24182599782943726,0.24246999993920326,0.2431079981227716,0.24373799934983253,0.24435999741156897,0.24497499937812486,0.2455819994211197,0.2461829992632071,0.24677700052658716,0.247363002349933,0.24794099728266397,0.2485129994650682,0.24907700096567473,0.24963400016228357,0.25018400326371193,0.25072599699099857,0.25126100331544876,0.25178999702135724,0.2523110012213389,0.25282400101423264,0.253330002228419,0.2538289974133174,0.2543209989865621,0.2548059970140457,0.2552840014298757,0.25575300057729083,0.25621599952379864,0.25667199740807217,0.2571209991971652,0.2575620040297508,0.25799599786599475,0.25842300057411194,0.25884300221999484,0.2592549994587898,0.2596599981188774,0.2600569998224576,0.26044799387454987,0.2608319992820422,0.2612080027659734,0.26157700022061664,0.2619390015800794,0.2622929960489273,0.2626409977674484,0.26298200090726215,0.26331400126218796,0.26364000141620636,0.26395900050799054,0.26427099853754044,0.264575997988383,0.26487300048271817,0.26516299694776535,0.2654460022846858,0.26572200159231824,0.2659909973541896,0.26625199615955353,0.26650599886973697,0.2667530005176862,0.26699399948120117,0.2672269990046819,0.2674519990881284,0.26767100145419437,0.26788199692964554,0.2680860012769699,0.2682829995950063,0.2684729993343353,0.2686559930443764,0.2688320005933444,0.26899999876817066,0.26916100333134335,0.26931499938170117,0.2694620018204053,0.26960300157467526,0.2697360043724378,0.26986100027958554,0.2699800009528796,0.2700909972190857,0.27019599825143814,0.27029399822155636,0.2703839987516403,0.27046700318654376,0.27054300159215927,0.27061200390259427,0.2706739977002144,0.2707289978861809,0.27077599863211316,0.2708170066277186,0.2708509986599286,0.2708779995640119,0.27089699854453403,0.2709090014298757,0.2709149991472562,0.2709129999081294,0.27090300371249515,0.27088699986537296,0.2708639974395434,0.2708339989185333,0.270796999335289,0.27075200031201047,0.27070000519355136,0.2706420024236043,0.2705770010749499,0.27050499866406125,0.2704249968131383,0.2703379988670349,0.2702480008204778,0.27015800029039383,0.2700680022438367,0.26997799923022586,0.2698879987001419,0.2697980006535848,0.2697080026070277,0.26961799710989,0.26952799906333286,0.2694380010167758,0.26934799800316495,0.2692590008179347,0.2691690002878507,0.2690789997577667,0.2689900000890096,0.26889999955892563,0.2688099965453148,0.26872099687655765,0.2686309988300006,0.26854199916124344,0.2684519986311595,0.26836300144592923,0.2682729984323184,0.26818400124708813,0.2680939982334773,0.26800499856472015,0.267915998895963,0.26782599836587906,0.2677369962135951,0.26764799902836484,0.2675589993596077,0.26746999720732373,0.2673799966772397,0.26729099700848263,0.2672020047903061,0.26711299767096836,0.2670240004857381,0.266935000816981,0.2668460011482239,0.26675700147946674,0.26666800181070965,0.2665800005197525,0.26649100085099536,0.2664020036657651,0.26631300151348114,0.266224001844724,0.26613599558671314,0.2660469984014829,0.2659579987327258,0.26587000240882236,0.2657810052235921,0.265692005554835,0.26560399929682416,0.2655150021115939,0.26542700330416363,0.2653380011518796,0.2652499998609225,0.26516200105349225,0.265073003868262,0.26498500009377796,0.26489600042502087,0.2648080016175906,0.26472000032663345,0.2646319940686226,0.26454400022824603,0.26445499807596207,0.2643669992685318,0.26427899797757465,0.26419100165367126,0.264103002846241,0.2640149916211764,0.26392700026432675,0.2638389964898427,0.2637510026494662,0.2636629988749822,0.2635749975840251,0.2634869987765948,0.26339999834696454,0.2633119970560074,0.263224000732104,0.26313599695761997,0.26304900149504346,0.26296100517114,0.26287299891312915,0.26278599351644516,0.2626979996760686,0.2626109992464383,0.26252299795548123,0.26243600249290466,0.2623480061690013,0.26226100077231723,0.26217299948136014,0.26208599905172986,0.2619990011056264,0.2619109998146693,0.26182399938503903,0.26173699895540875,0.2616490026315053,0.2615619997183482,0.26147500177224475,0.26138799885908764,0.2613010033965111,0.2612140004833539,0.26112700005372363,0.26103999962409336,0.26095300167798996,0.2608659987648328,0.2607790008187294,0.2606920003890991,0.26060499995946884,0.26051799952983856,0.2604309991002083,0.2603449995319049,0.2602580015858014,0.26017100115617114,0.26008400072654086,0.25999799619118374,0.2599109982450803,0.2598240052660306,0.2597379982471466,0.25965100278457004,0.2595649982492129,0.25947800527016324,0.25939200073480606,0.2593050003051758,0.2592190032203992,0.2591320027907689,0.25904600073893863,0.2589600036541621,0.25887300322453183,0.25878699620564777,0.25870100408792496,0.2586149995525678,0.2585280016064644,0.2584420045216878,0.2583559999863307,0.2582699979345004,0.2581840033332507,0.2580979987978935,0.25801200171311695,0.2579259971777598,0.25784000009298325,0.25775400052467984,0.25766800343990326,0.25758200138807297,0.2574959968527158,0.2574110006292661,0.2573250010609627,0.25723900149265927,0.257152999440829,0.25706800321737927,0.2569819986820221,0.2568960015972455,0.2568109979232152,0.2567250008384387,0.2566399996479352,0.2565540000796318,0.2564680005113284,0.2563829993208249,0.2562980006138484,0.2562120010455449,0.2561269998550415,0.2560410002867381,0.2559559966127078,0.2558709954222043,0.2557850008209546,0.2556999946633975,0.2556150009234746,0.2555299972494443,0.2554450010259946,0.2553599998354912,0.2552740027507146,0.2551889990766843,0.2551039978861809,0.25501899669567746,0.25493400543928146,0.25484899431467056,0.25476400554180145,0.25467899938424426,0.25459500153859455,0.25451000531514484,0.2544249991575877,0.25433999796708423,0.2542550017436345,0.2541709939638774,0.2540860002239545,0.2540009965499242,0.25391699622074765,0.25383200744787854,0.25374699880679447,0.25366300344467163,0.2535779997706413,0.2534939969579379,0.2534089982509613,0.25332500288883847,0.2532399967312813,0.25315599888563156,0.25307199855645496,0.25298699736595154,0.2529029995203018,0.2528189991911252,0.2527340004841487,0.2526500001549721,0.25256600230932236,0.2524819994966189,0.2523979991674423,0.2523139963547389,0.2522289976477623,0.25214500228563946,0.252060999472936,0.25197700162728626,0.25189300378163654,0.2518089960018794,0.2517249981562297,0.25164199620485306,0.25155799587567645,0.25147400548060733,0.251390000184377,0.25130599985520047,0.25122300038735074,0.251139002541701,0.2510550022125244,0.250970999399821,0.25088799993197125,0.25080400208632153,0.2507209951678912,0.2506370047728221,0.2505540003379186,0.25046999752521515,0.25038699557383853,0.2503029977281888,0.2502199982603391,0.25013600289821625,0.25005300094683963,0.24996999775369963,0.2498859999080499,0.2498030016819636,0.24972000097235045,0.249635998159647,0.24955299869179726,0.24946999798218408,0.24938700223962465,0.24930399904648462,0.24922100206216177,0.24913799886902174,0.24905500188469887,0.24897199869155884,0.2488889992237091,0.2488469990591208};
        CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.8342997233073,82.68911743164062,83.12951215108235,83.83631134033203,84.52521133422852,85.19641049702962,85.84981155395508,86.49631055196126,87.14681180318196,87.80121103922527,88.45961125691731,89.1219113667806,89.78821182250977,90.45841217041016,91.1326109568278,91.8107115427653,92.49281120300293,93.17881202697754,93.86891237894694,94.56301244099934,95.26111221313477,95.96331214904785,96.66941324869792,97.37961069742839,98.093812306722,98.81201171875,99.53421211242676,100.25901285807292,100.9860127766927,101.71501223246257,102.44501304626465,103.17701148986816,103.91001256306966,104.64601262410481,105.38301213582356,106.12201245625813,106.8620122273763,107.60101318359375,108.33701197306316,109.06801160176595,109.79501152038574,110.51801300048828,111.23701095581055,111.95201174418132,112.66301155090332,113.37101236979167,114.0740114847819,114.77101135253906,115.46201070149739,116.14601135253906,116.82401084899902,117.49401092529297,118.15801048278809,118.81501070658366,119.4650109608968,120.10801060994466,120.74500974019368,121.37401008605957,121.99401028951009,122.60500907897949,123.20700963338216,123.80001068115234,124.38500912984212,124.96100934346516,125.52700996398926,126.0850092569987,126.63400840759277,127.17601013183594,127.71300824483235,128.24400838216147,128.77000681559244,129.2900072733561,129.80600611368814,130.31500752766928,130.82000732421875,131.31900787353516,131.8130086263021,132.3020108540853,132.78600692749023,133.2650057474772,133.73900604248047,134.2080078125,134.67200724283853,135.1320063273112,135.58700688680014,136.03600692749023,136.48100789388022,136.9220059712728,137.36000951131186,137.7950096130371,138.22800827026367,138.65700658162436,139.0830052693685,139.50600560506186,139.92600758870444,140.3430061340332,140.75700759887695,141.16900507609049,141.57700729370117,141.98200607299805,142.3850072224935,142.78400802612305,143.1800053914388,143.57400767008463,143.96400705973306,144.35100682576498,144.7360076904297,145.11700566609701,145.49600474039713,145.8710060119629,146.2440071105957,146.61400604248047,146.9800059000651,147.34400685628256,147.70400873819986,148.06200536092123,148.41700490315756,148.76800664265951,149.11700566609701,149.46300506591797,149.8060048421224,150.1460049947103,150.48200480143228,150.8160031636556,151.1470044453939,151.47500610351562,151.8000055948893,152.12200673421225,152.44100443522134,152.7570063273112,153.07000478108725,153.38000615437826,153.68700408935547,153.99100240071616,154.2930030822754,154.59100468953451,154.88600540161133,155.17800267537436,155.46700286865234,155.75400416056314,156.03700510660806,156.31700388590494,156.5950024922689,156.86900583902994,157.14100646972656,157.40900548299155,157.67400487263998,157.93700536092123,158.19600423177084,158.4530029296875,158.7070058186849,158.95700454711914,159.20500310262045,159.44900512695312,159.6910031636556,159.93000411987305,160.1660041809082,160.39800389607748,160.6280059814453,160.85500462849936,161.07900365193686,161.3000030517578,161.51800282796225,161.73300170898438,161.9440015157064,162.15300623575845,162.35900497436523,162.56300354003906,162.76300430297852,162.9600041707357,163.15400187174478,163.3450024922689,163.53300348917642,163.71800231933594,163.901003519694,164.08000310262045,164.25600306193033,164.4290033976237,164.6000010172526,164.76700083414713,164.93200302124023,165.09300104777017,165.2510019938151,165.40700403849283,165.55900192260742,165.70900090535483,165.8560028076172,165.99900182088217,166.1400032043457,166.27700169881186,166.4120012919108,166.54400507609049,166.67300160725912,166.79800033569336,166.92100270589194,167.0410016377767,167.15800348917642,167.27200190226236,167.38300069173178,167.49099985758463,167.59600194295248,167.6980005900065,167.79700215657553,167.89300282796225,167.98600260416666,168.07600021362305,168.16300201416016,168.24700164794922,168.3290023803711,168.40700149536133,168.48200225830078,168.55500030517578,168.6240005493164,168.69000244140625,168.75399907430014,168.81400044759116,168.87200037638345,168.9259999593099,168.9780019124349,169.02599970499674,169.0720011393229,169.11399841308594,169.15400060017905,169.19100189208984,169.22400283813477,169.25499852498373,169.28300094604492,169.30799992879233,169.3299992879232,169.34900029500326,169.3639996846517,169.37700017293295,169.38700103759766,169.39400100708008,169.3979975382487,169.3990020751953,169.39799880981445,169.3939997355143,169.3910001118978,169.38700103759766,169.38400014241537,169.3810017903646,169.3770014444987,169.3739980061849,169.37000020345053,169.36700185139975,169.36400095621744,169.36000188191733,169.35699971516928,169.35300064086914,169.34999974568686,169.3470001220703,169.34299977620444,169.3400001525879,169.3370018005371,169.33300018310547,169.3300018310547,169.32599894205728,169.32300186157227,169.31999969482422,169.31599934895834,169.31300099690756,169.30899937947592,169.30599975585938,169.30300013224283,169.2989985148112,169.2960001627604,169.2930005391439,169.28899892171225,169.2859992980957,169.28199895222983,169.27900187174478,169.27600224812826,169.2719980875651,169.26900100708008,169.26500193277994,169.2619997660319,169.2590014139811,169.25499852498373,169.25200017293295,169.24899927775064,169.24500020345053,169.24200185139975,169.23800150553384,169.23500061035156,169.23199844360352,169.22799936930338,169.22500228881836,169.22099939982095,169.21799977620444,169.2150001525879,169.21099980672201,169.20800145467123,169.2049992879232,169.20099894205728,169.19799931844076,169.19400024414062,169.19099934895834,169.18799845377603,169.18400065104166,169.18099975585938,169.17700068155924,169.1739985148112,169.17100143432617,169.16699854532877,169.16399892171225,169.1609992980957,169.15699895222983,169.15400060017905,169.15000025431314,169.1469980875651,169.14400227864584,169.14000193277994,169.13700103759766,169.13299942016602,169.12999852498373,169.1270014444987,169.12299982706705,169.11999893188477,169.11700057983398,169.1130002339681,169.11000188191733,169.10599899291992,169.10299936930338,169.09999974568686,169.09599939982095,169.09300104777017,169.0890007019043,169.08599853515625,169.08300018310547,169.07900110880533,169.07599894205728,169.07299931844076,169.06900024414062,169.06599934895834,169.06199900309244,169.05899937947592,169.05599975585938,169.052001953125,169.0489985148112,169.0460001627604,169.04199727376303,169.03900019327799,169.03500111897787,169.03199768066406,169.02900060017905,169.0249989827474,169.02199935913086,169.01800155639648,169.01500193277994,169.0119997660319,169.00800069173178,169.00499979654947,169.0019989013672,168.9980010986328,168.99500147501627,168.99099985758463,168.98800150553384,168.98500061035156,168.98099772135416,168.9780019124349,168.97499974568686,168.97099939982095,168.96800231933594,168.9639981587728,168.96099980672201,168.95800018310547,168.9540023803711,168.95099894205728,168.94799931844076,168.94400024414062,168.94100189208984,168.9370002746582,168.93400065104166,168.93099975585938,168.92700068155924,168.92400105794272,168.9200007120768,168.91699854532877,168.91399765014648,168.9099998474121,168.90699895222983,168.90400060017905,168.89999771118164,168.89699935913086,168.89300155639648,168.8900006612142,168.8869972229004,168.88300069173178,168.87999852498373,168.8770014444987,168.87299982706705,168.87000147501627,168.86599985758463,168.8630002339681,168.85999806722006,168.85599899291992,168.85299682617188,168.8500010172526,168.84600067138672,168.84300104777017,168.8390007019043,168.83599853515625,168.8329989115397,168.82900110880533,168.82599894205728,168.8230005900065,168.8190015157064,168.81600062052408,168.8119977315267,168.80899937947592,168.80600102742514,168.80200068155924,168.79900105794272,168.7960001627604,168.79200236002603,168.78900019327799,168.78499857584634,168.78200022379556,168.77899932861328,168.7750015258789,168.77200063069662,168.7689997355143,168.76499938964844,168.76200230916342,168.75799942016602,168.75500106811523,168.7519989013672,168.74799982706705,168.74500147501627,168.74200057983398,168.73799896240234,168.73500061035156,168.7310002644857,168.7280019124349,168.72499974568686,168.72099939982095,168.71800104777017,168.71499888102213,168.71100107828775,168.70800145467123,168.7039998372396,168.70099894205728,168.69800186157227,168.69399897257486,168.69099807739258,168.68800099690756,168.6839968363444,168.68099975585938,168.677001953125,168.67399978637695,168.67100143432617,168.6670010884603,168.66399892171225,168.6609992980957,168.65700022379556,168.65400060017905,168.6500015258789,168.64700063069662,168.64399846394858,168.63999938964844,168.63699849446616,168.63400014241537,168.62999979654947,168.6269989013672,168.62299982706705,168.62000020345053,168.61699930826822,168.6130002339681,168.6099993387858,168.60700098673502,168.60300064086914,168.6000010172526,168.59600194295248,168.59300104777017,168.5900001525879,168.58599980672201,168.58300272623697,168.5799992879232,168.57599894205728,168.5730005900065,168.57000223795572,168.56600062052408,168.56299845377603,168.55899937947592,168.55799992879233};
        //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3766839106877644,1.4133399923642476,1.4500100016593933,1.4858900010585785,1.5208399991194408,1.5548800031344097,1.5879899859428406,1.6207400063673656,1.6536899904410045,1.6868199904759724,1.7201500137646992,1.7536800106366475,1.7873899936676025,1.8212999999523163,1.8553999960422516,1.889689991871516,1.9241799811522167,1.9588599999745686,1.9937299887339275,2.0288000106811523,2.0640700260798135,2.099529961744944,2.135190010070801,2.1710400382677713,2.2070900003115335,2.2433299819628396,2.279769996802012,2.316350003083547,2.353000024954478,2.38974001010259,2.426549971103668,2.4634300072987876,2.500390032927195,2.537429988384247,2.5745400389035544,2.6117300192515054,2.6490000089009604,2.6862000226974487,2.723180035750071,2.759939968585968,2.7964800000190735,2.8328100045522056,2.868920008341471,2.9048099915186563,2.940489967664083,2.975950002670288,3.0111900170644126,3.046149988969167,3.080749988555908,3.114989956219991,3.1488799850145974,3.1824100414911904,3.2155800263086953,3.248389979203542,3.28083997964859,3.3129300077756247,3.344669977823893,3.3759899934132895,3.4068599740664163,3.437260011831919,3.467200001080831,3.4966699878374734,3.5256800055503845,3.554229974746704,3.5823099613189697,3.6099299788475037,3.637090007464091,3.6638799905776978,3.6903799970944724,3.716600020726522,3.7425399820009866,3.7681999802589417,3.7935799757639566,3.8186699946721396,3.84348996480306,3.868019978205363,3.8922800024350486,3.916260004043579,3.9399900237719216,3.9634599685668945,3.986669977506002,4.009630044301351,4.03233003616333,4.054780006408691,4.07695996761322,4.098900039990743,4.120570023854573,4.142039974530538,4.163349986076355,4.184499939282735,4.20550004641215,4.226330002148946,4.2470100323359175,4.267530043919881,4.287890036900838,4.308089971542358,4.328129927317302,4.348010023434957,4.3677399555842085,4.38730001449585,4.406710068384807,4.425960024197896,4.445049961407979,4.463989973068237,4.482760032018025,4.50137992699941,4.519840041796367,4.538139979044597,4.556290030479431,4.574270049730937,4.592100063959758,4.609770019849141,4.62728997071584,4.6446400086085005,4.661840001742045,4.678880016009013,4.6957599719365435,4.712490042050679,4.729060053825378,4.74547000726064,4.761720061302185,4.777819991111755,4.793750007947286,4.809539993604024,4.825160026550293,4.8406299750010175,4.855940024058024,4.871090054512024,4.886090000470479,4.900930007298787,4.915610035260518,4.930140018463135,4.944509943326314,4.9587200085322065,4.972780028978984,4.986679991086324,5.0004200140635175,5.014010032018025,5.0274399518966675,5.040709972381592,5.053829987843831,5.066790024439494,5.07959000269572,5.09224001566569,5.104740023612976,5.117069959640503,5.1292500495910645,5.1412800550460815,5.153150041898091,5.164860049883525,5.176420013109843,5.187819997469584,5.1990700562795,5.21015989780426,5.221089998881022,5.23186997572581,5.2424899737040205,5.252959966659546,5.263270020484924,5.273429989814758,5.283429900805156,5.293280005455017,5.30296003818512,5.312489946683248,5.321860035260518,5.331079959869385,5.3401399453481035,5.349050005276998,5.357799967130025,5.3664000034332275,5.374839981396993,5.383129994074504,5.391260027885437,5.399239977200826,5.407059987386067,5.414729992548625,5.422249992688497,5.429609894752502,5.43680997689565,5.443859974543254,5.450759967168172,5.4574999411900835,5.464090029398601,5.47052001953125,5.476800044377645,5.482929984728496,5.488900065422058,5.494719982147217,5.500379999478658,5.505889972050984,5.511240005493164,5.516449928283691,5.521489977836609,5.526389996210734,5.531129956245422,5.5357100168863935,5.540150086085002,5.544429977734883,5.548549930254619,5.552529970804851,5.556350032488505,5.560010035832723,5.563519994417827,5.566879987716675,5.570090015729268,5.573139945665996,5.576039989789327,5.578790028889974,5.581380009651184,5.5838199853897095,5.58611003557841,5.588250041007996,5.5902299880981445,5.592060009638469,5.593730052312215,5.59526006380717,5.596630056699117,5.597850044568379,5.598910013834636,5.5998300313949585,5.600590070088704,5.601199984550476,5.6016499598821,5.601960023244222,5.602109988530477,5.602110028266907,5.601959943771362,5.60165003935496,5.601190010706584,5.600589950879415,5.599820017814636,5.598910013834636,5.59785008430481,5.5966300169626875,5.59525998433431,5.593740026156108,5.592070023218791,5.590320070584615,5.588580012321472,5.586830019950867,5.585089961687724,5.5833399295806885,5.581600030263265,5.57984999815623,5.5781099398930865,5.5763700405756635,5.574619968732198,5.572879989941915,5.571139971415202,5.569399873415629,5.567660013834636,5.565919995307922,5.56417993704478,5.5624399582544966,5.560700058937073,5.558969974517822,5.557230035463969,5.555489977200826,5.553760011990865,5.552020033200582,5.550289988517761,5.548550009727478,5.546819965044658,5.545089999834697,5.5433500210444135,5.5416200160980225,5.539890011151631,5.53816004594167,5.53643000125885,5.534700036048889,5.532969991366069,5.531240026156108,5.529509981473287,5.5277799765268965,5.526060024897258,5.5243299802144366,5.522599975268046,5.520880063374837,5.5191499789555865,5.5174299875895185,5.51570995648702,5.513980031013489,5.512259999910991,5.510540008544922,5.508820017178853,5.507089932759603,5.505369981129964,5.503650069236755,5.501930038134257,5.5002100467681885,5.4984999895095825,5.496779958407084,5.495060046513875,5.493340015411377,5.491629958152771,5.4899100462595625,5.4881999890009565,5.4864799578984575,5.484769980112712,5.483049949010213,5.481340050697327,5.479629993438721,5.477919975916545,5.476199984550476,5.4744899670283,5.472780028978984,5.471069971720378,5.4693600336710615,5.467650055885315,5.465950012207031,5.464239994684855,5.462530056635539,5.460819959640503,5.459119995435079,5.457409977912903,5.455709934234619,5.454000075658162,5.452299992243449,5.4505899747212725,5.448889970779419,5.447190006573995,5.445489962895711,5.443789998690288,5.442080020904541,5.4403800169626875,5.438679973284404,5.4369800090789795,5.435290018717448,5.433590014775594,5.43189005057017,5.430190006891887,5.428499976793925,5.426800052324931,5.425100008646647,5.423410058021545,5.421710014343262,5.4200199842453,5.418329993883769,5.416630029678345,5.414939959843953,5.413250009218852,5.41156001885732,5.409870028495789,5.408180038134257,5.406490008036296,5.404800017674764,5.403109987576802,5.401419997215271,5.39972996711731,5.398049990336101,5.396359960238139,5.394669969876607,5.392989953358968,5.391300002733867,5.3896199862162275,5.3879300355911255,5.386250019073486,5.384570002555847,5.382890025774638,5.381200035413106,5.379520018895467,5.377839962641398,5.376160025596619,5.374479969342549,5.37279995282491,5.371119976043701,5.369450012842814,5.367769996325175,5.366089979807536,5.364410042762756,5.362740000089009,5.36106006304423,5.3593900601069135,5.357710043589274,5.356039961179097,5.35437007745107,5.352690021197001,5.351019978523254,5.349350015322368,5.34768005212148,5.346009969711304,5.344340006510417,5.34266996383667,5.341000000635783,5.339329997698466,5.337659955024719,5.335989952087402,5.334320028622945,5.33266003926595,5.330989996592204,5.329330007235209,5.3276600042978925,5.325999975204468,5.32433009147644,5.322669982910156,5.320999940236409,5.319340030352275,5.31768000125885,5.3160200119018555,5.314360062281291,5.312699993451436,5.311039924621582,5.3093799750010175,5.307720065116882,5.306059877077739,5.304400086402893,5.302749991416931,5.301089922587077,5.299430052439372,5.2977800369262695,5.296120007832845,5.294469952583313,5.2928100029627485,5.291159987449646,5.289499998092651,5.287849982579549,5.286199967066447,5.284549951553345,5.282899975776672,5.28125,5.279600024223328,5.277950048446655,5.276300032933553,5.274649937947591,5.273000001907349,5.271349986394246,5.269709944725037,5.268060008684794,5.266409993171692,5.264770030975342,5.263120015462239,5.26147997379303,5.259829998016357,5.2581900755564375,5.256549994150798,5.254909952481587,5.253260056177775,5.251620014508565,5.249980012575786,5.248340010643005,5.246699968973796,5.245060006777446,5.243420044581096,5.241789937019348,5.240150014559428,5.238510012626648,5.2368699709574384,5.23523994286855,5.2335999806722,5.231970032056172,5.230330030123393,5.228700041770935,5.227059960365295,5.225430011749268,5.22379998366038,5.222170074780782,5.220529953638713,5.218900044759114,5.217269976933797,5.21563998858134,5.214010000228882,5.212380011876424,5.210749983787537,5.209130009015401,5.207500020662944,5.205869992574056,5.204249978065491,5.202620069185893,5.2009899616241455,5.19936998685201,5.197739998499553,5.196119983990987,5.194500009218852,5.192869981129964,5.191250006357829,5.189629991849263,5.188009937604268,5.186389962832133,5.184769988059998,5.183149973551433,5.181529998779297,5.179909984270732,5.178289969762166,5.176670074462891,5.1750500202178955,5.174239993095398};
        SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568472703297934,8.884455839792887,9.180607080459595,9.503506342569986,9.825696388880411,10.147206465403238,10.46790631612142,10.789206504821777,11.112006664276123,11.436506589253744,11.762606779734293,12.090306599934896,12.419606685638428,12.750606536865234,13.083106756210327,13.417306582132975,13.753206729888916,14.089906692504883,14.426806767781576,14.763906717300415,15.10120677947998,15.43860681851705,15.776306788126627,16.114106734593708,16.45220677057902,16.790406862894695,17.128806908925373,17.466306527455647,17.801806608835857,18.13520685831706,18.466606458028156,18.795906225840252,19.12320629755656,19.448506673177082,19.771806557973225,20.09300661087036,20.41210635503133,20.730706532796223,21.05000638961792,21.3701065381368,21.690906683603924,22.01250648498535,22.334906419118244,22.658106962839764,22.98210636774699,23.306806564331055,23.632306734720867,23.958306630452473,24.284906546274822,24.611806392669678,24.93920660018921,25.266906420389812,25.595106601715088,25.92380666732788,26.252806822458904,26.58230670293172,26.912206649780273,27.24230670928955,27.572306791941326,27.902206897735596,28.23190673192342,28.561606566111248,28.891106764475506,29.220606486002605,29.549906730651855,29.879106521606445,30.208306630452473,30.536406358083088,30.86280616124471,31.18730640411377,31.51000674565633,31.8309063911438,32.15000661214193,32.46720600128174,32.78270626068115,33.09630616505941,33.40810585021973,33.71840604146322,34.02750587463379,34.33540598551432,34.64210573832194,34.947505950927734,35.2518056233724,35.554905573527016,35.85670566558838,36.157406171162926,36.45680650075277,36.75460561116537,37.050205866495766,37.34360567728678,37.63490549723307,37.92400582631429,38.21100584665934,38.495805740356445,38.778405825297035,39.058905601501465,39.337205251057945,39.61340490976969,39.887405713399254,40.15930589040121,40.42900530497233,40.69660504659017,40.96200466156006,41.225305239359535,41.48640441894531,41.745405197143555,42.00220521291097,42.25690523783366,42.50940545399984,42.759805043538414,43.008005142211914,43.25410525004069,43.49800523122152,43.73980522155762,43.97940476735433,44.21700509389242,44.45230484008789,44.68550491333008,44.9166046778361,45.1456044514974,45.37240473429362,45.59700393676758,45.819604555765785,46.040004094441734,46.25820446014404,46.47430388132731,46.68830426534017,46.90020434061686,47.10990365346273,47.31750361124674,47.522903760274254,47.726203282674156,47.92740345001221,48.126404444376625,48.32340431213379,48.518204053243004,48.71080334981283,48.901403745015465,49.08980401357015,49.2761033376058,49.46020380655924,49.64220364888509,49.82210350036621,49.9999033610026,50.17560386657715,50.34910329182943,50.52050336201986,50.68980312347412,50.85700352986654,51.022002855936684,51.18500264485677,51.3458038965861,51.50450293223063,51.66110324859619,51.815503438313804,51.96790313720703,52.11810302734375,52.26620356241862,52.41220251719157,52.556102434794106,52.69790236155192,52.837502797444664,52.97510210673014,53.11050319671631,53.24380238850912,53.3751023610433,53.50420252482096,53.63120206197103,53.756102879842125,53.878902435302734,53.99950249989828,54.11810270945231,54.23460261027018,54.34890206654867,54.46120230356852,54.57140223185221,54.67940171559652,54.78540293375651,54.88920211791992,54.99100144704183,55.09060255686442,55.188201586405434,55.283702532450356,55.37700176239014,55.46830177307129,55.55740197499593,55.64450200398763,55.729502042134605,55.812401135762535,55.89310201009115,55.9718017578125,56.048401832580566,56.12300173441569,56.19540214538574,56.26570097605387,56.33390204111735,56.40010039011637,56.46410242716471,56.52610047658285,56.586000760396324,56.64380137125651,56.6995013554891,56.75310103098551,56.80470053354899,56.8541005452474,56.90150101979574,56.94680150349935,56.99000040690104,57.0311009089152,57.07020060221354,57.107200622558594,57.1420005162557,57.17490037282308,57.20560042063395,57.2342004776001,57.2608003616333,57.28530089060465,57.30770047505697,57.32809988657633,57.34639994303385,57.362600008646645,57.37670008341471,57.38879998524984,57.39870007832845,57.406700452168785,57.41249974568685,57.416300455729164,57.417999585469566,57.41759967803955,57.415200551350914,57.410699208577476,57.40410010019938,57.39549986521403,57.38479963938395,57.37200005849203,57.35719998677572,57.3402992884318,57.32239945729574,57.30449962615967,57.28660011291504,57.268699645996094,57.250800132751465,57.23289934794108,57.214999516805015,57.19719982147217,57.17929935455322,57.161399841308594,57.14359919230143,57.12569936116537,57.10789934794108,57.089999516805015,57.07219982147217,57.0542999903361,57.036499659220375,57.01869932810465,57.00089899698893,56.98309930165609,56.96529960632324,56.947499910990395,56.92969957987467,56.91189956665039,56.89409955342611,56.8763001759847,56.85859966278076,56.84079933166504,56.82299963633219,56.80529944101969,56.78749974568685,56.769799868265785,56.751999855041504,56.73429934183756,56.716599464416504,56.698899586995445,56.68109957377116,56.66340001424154,56.64569981892904,56.6279993057251,56.6102991104126,56.59259955088297,56.57499980926514,56.55729961395264,56.53960005442301,56.5219996770223,56.5042994817098,56.4865992863973,56.46899954477946,56.4512996673584,56.43369960784912,56.416099548339844,56.398399670918785,56.38079961140951,56.36319955190023,56.34560012817383,56.32800006866455,56.31039969126383,56.292799949645996,56.27519989013672,56.257599194844566,56.239999771118164,56.22249952952067,56.20489978790283,56.187299728393555,56.16979948679606,56.15219942728678,56.13469950358073,56.11719926198324,56.099599838256836,56.082098960876465,56.06459903717041,56.0470994313558,56.02949937184652,56.011999448140465,55.99449952443441,55.976999282836914,55.95959981282552,55.94209988911947,55.924599965413414,55.90709972381592,55.88959916432699,55.872199376424156,55.8546994527181,55.8372999827067,55.81980005900065,55.80239963531494,55.78499984741211,55.76749960581461,55.75009981791178,55.73269907633463,55.71529960632324,55.69789950052897,55.68049971262614,55.66309960683187,55.64569918314616,55.628299395243324,55.61089897155762,55.593499501546226,55.57610003153483,55.5587994257609,55.54140027364095,55.524099349975586,55.506699879964195,55.4893995920817,55.471999168395996,55.45470015207926,55.43739986419678,55.42010021209717,55.40269978841146,55.38540013631185,55.368099212646484,55.350799878438316,55.333499590555824,55.31619962056478,55.299000104268394,55.28169949849447,55.26439984639486,55.24709924062093,55.22990004221598,55.21260007222494,55.19539928436279,55.178099632263184,55.16089916229248,55.14369932810465,55.12639967600504,55.10919984181722,55.09199968973795,55.07479953765869,55.05759970347086,55.0403995513916,55.023200035095215,55.00599988301595,54.98879909515381,54.97159989674886,54.954400062561035,54.93719959259033,54.92009989420573,54.90289910634359,54.885799407958984,54.86859957377116,54.851499239603676,54.83429972330729,54.81720002492269,54.80009969075521,54.78300031026205,54.7657995223999,54.7486998240153,54.73159980773926,54.71449947357178,54.697400410970054,54.68029975891113,54.66319974263509,54.646199544270836,54.62909984588623,54.61199951171875,54.59499931335449,54.57789929707845,54.56089941660563,54.54379971822103,54.52679983774821,54.50969918568929,54.49269994099935,54.47570006052653,54.45859972635905,54.44160016377767,54.42459964752197,54.407599767049156,54.3905995686849,54.373599688212074,54.35659948984782,54.339600245157875,54.322699228922524,54.30569998423258,54.28869946797689,54.27180004119873,54.2547992070516,54.237899462381996,54.220898946126304,54.2039992014567,54.18699963887533,54.17010021209717,54.15319983164469,54.13629976908366,54.11930020650228,54.102400143941246,54.08549944559733,54.06859938303629,54.05169995625814,54.034799575805664,54.01799964904785,54.00109990437826,53.98419952392578,53.967299461364746,53.950499852498375,53.93359978993734,53.91679890950521,53.899900118509926,53.88309955596924,53.8661994934082,53.849400202433266,53.83259932200114,53.815799395243324,53.79899946848551,53.78209940592448,53.765299797058105,53.748500188191734,53.73179944356283,53.71500015258789,53.6981995900472,53.681399981180824,53.66460005442301,53.64789994557699,53.631099700927734,53.61429977416992,53.59759966532389,53.58079973856608,53.56409931182861,53.547399838765465,53.53059959411621,53.51389948527018,53.497199058532715,53.480499585469566,53.46380011240641,53.44710000356039,53.430399894714355,53.413699785868324,53.3969996770223,53.38029956817627,53.36359945933024,53.346899350484215,53.33029969533285,53.31359990437826,53.296999295552574,53.28029918670654,53.263599713643394,53.24700005849203,53.23039976755778,53.21369902292887,53.197099685668945,53.18049971262614,53.163899421691895,53.147299448649086,53.130699475606285,53.11409950256348,53.09749984741211,53.080899238586426,53.064300219217934,53.055999755859375};
        //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.1294158895810447,2.219929019610087,2.2950964172681174,2.372145891189575,2.4435757398605347,2.5095555981000266,2.5702256162961326,2.6278756260871887,2.684745669364929,2.7408556938171387,2.7962157328923545,2.850855747858683,2.9047858119010925,2.9580358068148294,3.0106058915456138,3.0625359217325845,3.1138159036636353,3.1644959648450217,3.2146060466766357,3.2641560633977256,3.3131560484568277,3.361626128355662,3.409576157728831,3.4570361773173013,3.5039862195650735,3.5504762729008994,3.596496284008026,3.6418262918790183,3.686286290486654,3.7298763394355774,3.7726263205210366,3.8145563205083213,3.855696380138397,3.896056373914083,3.9356663823127747,3.97453639904658,4.012696286042531,4.049586335817973,4.084686279296875,4.118026256561279,4.149666269620259,4.179646174112956,4.2080161571502686,4.234816153844197,4.260086139043172,4.283875981966655,4.30621596177419,4.326875925064087,4.345635890960693,4.362545808156331,4.37764569123586,4.390995621681213,4.402645627657573,4.412625551223755,4.420995593070984,4.427785515785217,4.433055400848389,4.436635295550029,4.438355207443237,4.438285152117412,4.4364651044209795,4.432955026626587,4.427774985631307,4.420994877815247,4.412644783655803,4.402764678001404,4.391414602597554,4.3789546092351275,4.365784605344136,4.351914485295613,4.337354461352031,4.322144468625386,4.306284427642822,4.2898043394088745,4.272724310557048,4.255044341087341,4.2367942333221436,4.218024174372355,4.198804060618083,4.179144064585368,4.159054001172383,4.138553977012634,4.11764399210612,4.096343914667766,4.074663917223613,4.052603840827942,4.030183792114258,4.007603804270427,3.9850337306658425,3.962483743826548,3.939943710962931,3.917423685391744,3.894923667112986,3.872433602809906,3.8499636054039,3.827513555685679,3.80507355928421,3.7826435367266336,3.760233521461487,3.737833480040232,3.715443432331085,3.6930633982022605,3.670703371365865,3.648353377978007,3.6260233322779336,3.6036933064460754,3.581383307774862,3.559093256791433,3.5368032654126487,3.514523208141327,3.492263158162435,3.470013161500295,3.4477731585502625,3.4255430897076926,3.4033230741818747,3.3811230659484863,3.358923017978668,3.336733023325602,3.314562996228536,3.292402962843577,3.2702429493268332,3.248102923234304,3.225972910722097,3.203852872053782,3.1817328135172525,3.1596327821413674,3.137542804082235,3.1154627799987793,3.093382716178894,3.0713226795196533,3.0492726961771646,3.0272326469421387,3.0051926374435425,2.983172615369161,2.961162527402242,2.9391525785128274,2.9171624978383384,2.8951724966367087,2.8731924891471863,2.851232409477234,2.829272429148356,2.807322402795156,2.785382390022278,2.763442357381185,2.7415223121643066,2.7196123003959656,2.6977022687594094,2.675812284151713,2.653922200202942,2.63205224275589,2.6101721922556558,2.5883121291796365,2.5664621194203696,2.5446121096611023,2.522782027721405,2.5009520053863525,2.4791319767634072,2.4573219815889993,2.4355119665463767,2.4137219389279685,2.391931931177775,2.370151917139689,2.3483818968137107,2.3266218105951944,2.304861823717753,2.2831117709477744,2.2613717516263327,2.239641765753428,2.2179216941197715,2.1962016820907593,2.1744916836420694,2.1527916193008423,2.131091594696045,2.1094115575154624,2.0877315402030945,2.0660515427589417,2.0443915128707886,2.0227315028508506,2.0010814666748047,1.979431430498759,1.957791397968928,1.9361613889535267,1.9145413637161255,1.892931302388509,1.871321310599645,1.849721262852351,1.8281212449073792,1.8065312206745148,1.7849512000878651,1.7633711795012157,1.7418011526266735,1.7202311356862385,1.6986810962359111,1.677131066719691,1.6555810471375783,1.6340510149796803,1.6125109990437825,1.5909909705320995,1.5694709320863087,1.5479609072208405,1.5264508823553722,1.504950871070226,1.48345085978508,1.4619608024756114,1.4404807885487874,1.419000764687856,1.3975307444731395,1.3760607143243153,1.3546006778875987,1.333150674899419,1.3117006421089172,1.2902506192525227,1.2688105901082356,1.247380554676056,1.225950539112091,1.2045205136140187,1.1831004917621613,1.161690463622411,1.1402804255485535,1.118880420923233,1.0974803864955902,1.0760903557141621,1.0547103186448414,1.033320317665736,1.0119502743085225,0.9905712554852167,0.9692022303740183,0.9478372037410736,0.9264781773090363,0.9051241527001063,0.8837741216023763,0.8624291022618612,0.841089074810346,0.8197540491819382,0.7984230220317841,0.7770959983269373,0.7557750095923742,0.7347490042448044,0.7143070052067438,0.694432000319163,0.6751089990139008,0.6563229958216349,0.6380580067634583,0.6202999949455261,0.6030360013246536,0.5862520088752111,0.5699339956045151,0.554068997502327,0.5386460075775782,0.5236519972483317,0.509074995915095,0.4949030006925265,0.48112499962250393,0.46773000061511993,0.4547090033690135,0.4420489991704623,0.4297420009970665,0.41777700185775757,0.40614499896764755,0.39483699947595596,0.38384400059779483,0.37315700203180313,0.36276700099309284,0.3526660005251567,0.34284700204928714,0.33330100029706955,0.32401999831199646,0.31499800086021423,0.3062270035346349,0.2977009986837705,0.2894109959403674,0.28135300427675247,0.27351900190114975,0.2659029985467593,0.25849899649620056,0.25130099927385646,0.24430400133132935,0.2375009978810946,0.2308880016207695,0.22445899744828543,0.21820899844169617,0.21213400115569434,0.2062270020445188,0.20048500100771585,0.1949019990861416,0.18947499990463257,0.18420000250140825,0.1790710004667441,0.174085001150767,0.16923699900507927,0.1645250009993712,0.1599439966181914,0.15549100066224733,0.15116100137432417,0.14695199951529503,0.14286099995175996,0.1388830008606116,0.13501600051919618,0.1312569963435332,0.1276019997894764,0.12404899920026462,0.12059500068426132,0.11723800065616767,0.11397299915552139,0.11080000052849452,0.1077150000880162,0.10471600045760472,0.10180100053548813,0.09896619928379853,0.09621080073217551,0.09353209969898064,0.09092800008753936,0.08839630025128524,0.08593520025412242,0.08354270023604234,0.08121670037508011,0.07895549945533276,0.07675730002423127,0.07462029966215293,0.07254269967476527,0.07052309935291608,0.06855970124403636,0.06665090098977089,0.06479530160625775,0.06299140087018411,0.061237600011130176,0.059532800068457924,0.05787540009866158,0.05626410059630871,0.05469770015527805,0.05317489989101887,0.05169459960112969,0.050255400128662586,0.04885629999140898,0.04749619991828998,0.04617390005538861,0.04488849981377522,0.043638799960414566,0.042423999247451626,0.04124300026645263,0.04009480029344559,0.038978599632779755,0.03789350048949321,0.03683859979112943,0.03581309970468283,0.034816100262105465,0.0338468998670578,0.03290470037609339,0.03198870023091634,0.031098200008273125,0.030232499819248915,0.029391000047326088,0.02857280025879542,0.027777399867773056,0.027004199878623087,0.026252500091989834,0.0255216999600331,0.024811300293852884,0.02412059996277094,0.023449200205504894,0.022796399736156065,0.022161899755398434,0.021544999908655882,0.02094529972722133,0.02036230017741521,0.019795500052471954,0.01924450012544791,0.018708799965679646,0.018188000035782654,0.017681799829006195,0.01718959988405307,0.01671110015983383,0.016245999994377296,0.01579379988834262,0.01535419987825056,0.014926800038665533,0.014511299940447012,0.0141073998529464,0.013714799967904886,0.013332999932269255,0.01296190001691381,0.012601200180749098,0.012250400070721904,0.011909500074883303,0.011577999917790294,0.011255799947927395,0.010942499929418167,0.010637899938349923,0.01034190016798675,0.01005399995483458,0.009774199997385343,0.009502169986565908,0.009237709998463592,0.008980610019837817,0.008730670049165687,0.008487679995596409,0.008251459881042441,0.008021820103749633,0.007798560118923585,0.007581529983629783,0.007370530045591295,0.007165410051432748,0.006965989984261493,0.006772130029276013,0.006583660026080906,0.006400440043459336,0.006222320022061467,0.006049160030670464,0.005880810009936492,0.0057171599473804235,0.005558050082375606,0.005403379987304409,0.0052530099637806416,0.005106830076935391,0.00496470994160821,0.004826559995611508,0.004692239997287591,0.00456167000811547,0.00443473004270345,0.004311319983874758,0.004191349959000945,0.0040747100332130986,0.003961329969267051,0.003851100026319424,0.003743930001898358,0.003639750008005649,0.0035384699585847557,0.0034400099927249053,0.0033442799855644503,0.0032512300143328807,0.003160760000658532,0.0030728100100532174,0.002987310018700858,0.002904180029872805,0.0028233699849806726,0.002744809976623704,0.0026684399733009436,0.002594190009403974,0.002522009987539301,0.002451839992621293,0.0023836199931489923,0.0023172899770239988,0.002252819986703495,0.0021901399983714023,0.002129200011646996,0.0020699600184646747,0.00201236002612859,0.0019563699897844344,0.001901940015765528,0.0018490199969771008,0.00179757999527889,0.001747569990887617,0.001698940012526388,0.0016516799999711413,0.0016057199876134594,0.001561050002540772,0.0015176199958659708,0.0014754000003449619,0.0014343499982108672,0.0013944400028170396,0.001355649981026848,0.0013179300100697826,0.0012812700006179512,0.0012456200007970135,0.001210970008590569,0.0011772800062317401,0.0011445299993890028,0.0011126900111169864,0.0010817299868601065,0.0010516400119134535,0.0010223800200037658,0.0009939390001818538,0.0009662889982185637,0.0009394080019167935,0.0009132750031615918,0.0008878690035392841,0.0008631689900842806,0.0008391580001140634,0.0008158140068796153,0.0007931190048111603,0.000771056996503224,0.0007496080021761978,0.0007287550057905415,0.0007084829994710162,0.000688774996281912,0.0006790599970069403};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11866823832194,80.86898803710938,79.52129300435384,78.11829439798991,76.66849581400554,75.17949803670247,73.65859858194987,72.11220041910808,70.54630343119304,68.96640268961589,67.3774045308431,65.78370475769043,64.18950494130452,62.598405838012695,61.013906478881836,59.43880716959635,57.87600803375244,56.32780774434408,54.796409606933594,53.283708572387695,51.79150899251302,50.321309407552086,48.87420908610026,47.45160992940267,46.05430920918783,44.68311023712158,43.338809967041016,42.02181021372477,40.732710202534996,39.471710205078125,38.23910999298096,37.03501001993815,35.859509785970054,34.71270910898844,33.59440930684408,32.504509607950844,31.442808945973713,30.40920893351237,29.403308550516766,28.424808502197266,27.473408222198486,26.548808256785076,25.650508244832356,24.778107802073162,23.93110768000285,23.10920763015747,22.31180731455485,21.53840732574463,20.788607279459637,20.061906814575195,19.357706864674885,18.675506591796875,18.014906406402588,17.375306447347004,16.75610589981079,16.157005945841473,15.577305634816488,15.016605377197266,14.474405447642008,13.95010526974996,13.443405151367188,12.953604857126871,12.480304797490438,12.023004531860352,11.58140460650126,11.154804388682047,10.743004163106283,10.345404068628946,9.96160395940145,9.591203769048056,9.233783721923828,8.888933579126993,8.556283473968506,8.235413471857706,7.925973256429036,7.627593119939168,7.339893023173015,7.06255288918813,6.795222798983256,6.537572622299194,6.2892725467681885,6.050022482872009,5.819512486457825,5.597442348798116,5.383532365163167,5.177492141723633,4.974382241566976,4.774402340253194,4.5824021100997925,4.398082097371419,4.221142013867696,4.051271915435791,3.888191819190979,3.731651763121287,3.5813716650009155,3.4371116161346436,3.2986215353012085,3.1656914750734964,3.0380914211273193,2.9156014124552407,2.7980212966601052,2.685161272684733,2.5768312414487204,2.4728511373202005,2.373041093349457,2.277241071065267,2.185291031996409,2.097030997276306,2.012320955594381,1.9310209254423778,1.85298087199529,1.7780808409055073,1.7062008082866669,1.637210766474406,1.5709907511870067,1.507440725962321,1.4464506804943085,1.3879206677277882,1.3317506313323975,1.277830610672633,1.2261005739370983,1.1764405369758606,1.1287905474503834,1.083060512940089,1.0391804973284404,0.997066468000412,0.9566524475812912,0.9178704420725504,0.8806544144948324,0.8449404040972391,0.8106703807910284,0.7777833739916483,0.7462263604005178,0.7159443447987238,0.6868873288234075,0.6590043157339096,0.6322493056456248,0.6065772871176401,0.5819422751665115,0.5583052684863409,0.5356252491474152,0.5138622373342514,0.49298123518625897,0.4729462265968323,0.45372121532758075,0.43527621030807495,0.41757820049921673,0.4005981907248497,0.3843051840861638,0.3686731730898221,0.35367616762717563,0.33928616096576053,0.3254801581303279,0.31223414838314056,0.29952513923247653,0.28733313580354053,0.27563513070344925,0.26441212743520737,0.25364511956771213,0.24331511681278548,0.23340411360065141,0.22389610732595125,0.21477510159214339,0.20602409914135933,0.1976290966073672,0.18957509100437164,0.18184809014201164,0.17443508406480154,0.16732408106327057,0.16050307576855025,0.15395807723204294,0.14768007025122643,0.14165706684192023,0.13588006421923637,0.1303370619813601,0.12502105782429376,0.11992005755503972,0.11502705514431,0.11033405301471551,0.10583105062445004,0.10151204839348793,0.09736934676766396,0.0933950450271368,0.08958264191945393,0.08592564115921657,0.08241764083504677,0.07905263702074687,0.0758247369279464,0.07272843519846599,0.06975843322773774,0.06690953175226848,0.06417673081159592,0.06155542843043804,0.059041028221448265,0.056629227163890995,0.054315826234718166,0.05209672482063373,0.04996822432925304,0.04792662306378285,0.0459682218109568,0.04408982147773107,0.0422881202151378,0.040559918930133186,0.038902318415542446,0.03731231763958931,0.035787317591408886,0.03432451654225588,0.03292151540517807,0.03157581528648734,0.030285014460484188,0.029047013881305855,0.02785951333741347,0.02672061293075482,0.02562821206326286,0.024580411923428375,0.023575411333392065,0.022611510939896107,0.021687010303139687,0.02080020975942413,0.01994970953091979,0.01913400925695896,0.018351609042535227,0.017601208450893562,0.016881507976601522,0.01619120795900623,0.01552910745764772,0.014894007239490747,0.0142850069484363,0.013700806691000858,0.013140606305872401,0.012603206094354391,0.012087805895134807,0.011593505507335067,0.011119405273348093,0.010664705109472076,0.010228604932005206,0.009810354793444276,0.009409194501737753,0.009024454358344277,0.00865544417562584,0.008301534069081148,0.007962103777875503,0.007636553607881069,0.007324333535507321,0.007024873319702844,0.006737663255383571,0.00646220314471672,0.006198012890915076,0.005944632886288066,0.0057016027470429735,0.005468522625354429,0.005244972455936174,0.005030562402680516,0.004824922381279369,0.004627692202727,0.004438522116591533,0.004257092058348159,0.004083081924666961,0.00391619186848402,0.0037561217905022204,0.003602591711872568,0.0034553416383763156,0.003314111556392163,0.0031786615339418254,0.0030487414139012494,0.00292414139645795,0.002804631347923229,0.002690011286176741,0.002580071256185571,0.002474631182849407,0.0023734911422555647,0.0022764911021416387,0.002183461037930101,0.002094231022056192,0.002008650995170077,0.00192656092500935,0.0018478408843899767,0.0017723308507508289,0.0016999008269825329,0.0016304407909046859,0.0015638107530927907,0.001499910712785398,0.0014386206942920883,0.001379840667747582,0.0013234606400753062,0.0012693806008125346,0.0012175205920357257,0.0011677705527593691,0.0011200605464788775,0.001074290523926417,0.0010304004924061398,0.0009883004725755502,0.0009479224487828711,0.0009091934383225938,0.000872047419155327,0.0008364204065098116,0.0008022483816603199,0.0007694733746272201,0.0007380373572232202,0.000707886332141546,0.0006789673255601277,0.0006512303128450488,0.0006246262976977354,0.0005991102855963012,0.000574636273086071,0.0005511622584890574,0.0005286472587613389,0.0005070522408156345,0.00048634023308598745,0.00046647422277601436,0.0004474202190370609,0.0004291442019166425,0.00041161519766319543,0.0003948021864440913,0.0003786761832695144,0.0003632091757026501,0.0003483741675154306,0.0003341451544353428,0.0003204981524807711,0.0003074081420587997,0.0002948531400761567,0.0002828101351042278,0.00027126013204300153,0.0002601821252028458,0.0002495561202522367,0.0002393641164720369,0.00022958910994930193,0.00022021310360287316,0.0002112201024525954,0.00020259409696639827,0.00019432109305247044,0.00018638509088001834,0.000178774083906319,0.0001714740828901995,0.0001644720796321053,0.00015775607486527102,0.00015131407417356968,0.00014513507024579061,0.00013920906712883152,0.00013352506357477978,0.00012807306363053309,0.0001228440572352459,0.00011782805753076293,0.00011301705368775099,0.00010840305124778145,0.0001039770498512856,4.206894421561932e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45183563232422,229.5926055908203,226.3097178141276,223.6417121887207,220.94771194458008,218.22970708211264,215.49370447794595,212.74170303344727,209.97670237223306,207.20170211791992,204.41970443725586,201.6337038675944,198.84470240275064,196.05670293172201,193.2707036336263,190.48970413208008,187.71570460001627,184.94970575968424,182.19370651245117,179.44970830281576,176.71871058146158,174.0017115275065,171.30171330769858,168.6197141011556,165.95471700032553,163.31071980794272,160.68572107950845,158.0837262471517,155.50372695922852,152.94572830200195,150.4127311706543,147.90373357137045,145.42073567708334,142.96274185180664,140.53174336751303,138.12674458821616,135.74875259399414,133.39875157674155,131.07575480143228,128.78175926208496,126.51576105753581,124.2777640024821,122.06876754760742,119.88877042134602,117.73777262369792,115.61577542622884,113.52277946472168,111.45778210957845,109.42278480529785,107.41678873697917,105.43979199727376,103.49179522196452,101.57279777526855,99.68240229288737,97.82050514221191,95.98710759480794,94.18201001485188,92.4049129486084,90.65591621398926,88.93451881408691,87.24072329203288,85.57432492574056,83.93492889404297,82.32253138224284,80.7367337544759,79.17723655700684,77.64403978983562,76.1367416381836,74.65504328409831,73.19874699910481,71.76755015055339,70.36115264892578,68.97935549418132,67.62175687154134,66.28816159566243,64.97826258341472,63.69166533152262,62.42816766103109,61.18736902872721,59.96907265981039,58.7729746500651,57.59877681732178,56.44607893625895,55.31468137105306,54.20418357849121,53.11428642272949,52.06599235534668,51.05789438883463,50.06769593556722,49.09509754180908,48.13989988962809,47.20180161794027,46.28060340881348,45.37600580851237,44.48780663808187,43.61560853322347,42.7593100865682,41.9186118443807,41.09331385294596,40.28321488698324,39.48791662851969,38.70731830596924,37.94111982981364,37.18912124633789,36.45112291971842,35.72682476043701,35.01602554321289,34.31852722167969,33.63402811686198,32.96243031819662,32.30353101094564,31.65703233083089,31.02273352940877,30.400434811909992,29.789936542510986,29.19103701909383,28.603538513183594,28.027339617411297,27.462140878041584,26.907742182413738,26.364043076833088,25.83074410756429,25.3077449798584,24.794746081034344,24.29174741109212,23.798548539479572,23.314849217732746,22.840550422668457,22.37545124689738,21.91945219039917,21.472253163655598,21.033854166666668,20.60405508677165,20.182755947113037,19.769656658172607,19.364657560984295,18.967658360799152,18.57845942179362,18.197060108184814,17.823060989379883,17.45656156539917,17.097262382507324,16.745062987009685,16.399963855743408,16.061664660771687,15.730165402094523,15.405266046524048,15.086766719818115,14.774767398834229,14.468968073527018,14.169268528620401,13.875569264094034,13.587869882583618,13.305870532989502,13.029571215311686,12.758771737416586,12.49357239405314,12.233672857284546,11.978973468144735,11.729473988215128,11.485074281692505,11.245574951171875,11.010975440343222,10.781075954437256,10.55587649345398,10.335277160008749,10.119177420934042,9.907517910003662,9.700148423512777,9.497008800506592,9.29802918434143,9.103119611740112,8.912210067113241,8.725220441818237,8.542050758997599,8.362651348114014,8.186941623687744,8.014851927757263,7.846312363942464,7.681252797444661,7.519583145777385,7.361253420511882,7.206203738848369,7.054354111353557,6.905624429384868,6.7599847714106245,6.6173650821050005,6.477695385615031,6.340915679931641,6.206975976626079,6.0758163134257,5.947386582692464,5.821636875470479,5.698507150014241,5.577927390734355,5.459867636362712,5.3442478974660235,5.2310582002003985,5.120238383611043,5.01171871026357,4.905468861262004,4.801439166069031,4.699589371681213,4.599859555562337,4.502219796180725,4.406639973322551,4.3130602439244585,4.2214204867680865,4.131720662117004,4.04391086101532,3.957951009273529,3.87381120522817,3.7914313673973083,3.71079158782959,3.631841758886973,3.554551919301351,3.4788921078046164,3.40482227007548,3.332312444845835,3.261322577794393,3.1918227672576904,3.123792906602224,3.0572230418523154,2.9920431772867837,2.928233325481415,2.8657735188802085,2.8046436111132302,2.7447937726974487,2.6862138509750366,2.6288839975992837,2.572774132092794,2.517844259738922,2.464094400405884,2.4114745060602822,2.3599746227264404,2.3095746835072837,2.260234812895457,2.2119449377059937,2.1646750370661416,2.1184151768684387,2.0731252431869507,2.028825362523397,1.9854654769102733,1.943015565474828,1.901465654373169,1.8607957661151886,1.820995847384135,1.7820459604263306,1.7439160346984863,1.706616113583247,1.6701162060101826,1.634386271238327,1.5994063516457875,1.5651864210764568,1.5316864947477977,1.4988865852355957,1.4667966465155284,1.435396711031596,1.404686798652013,1.3746168514092763,1.3451669216156006,1.3163569966952007,1.2881770730018616,1.260607123374939,1.2336071630318959,1.207167237997055,1.1813072860240936,1.1559973657131195,1.1312374273935955,1.1070174674193065,1.0832975109418232,1.0600675841172535,1.0373376309871674,1.0150976578394573,0.9933457225561142,0.9720617830753326,0.9512368192275366,0.930840864777565,0.9108649144570032,0.8913199603557587,0.8721980104843775,0.8534900546073914,0.8351850907007853,0.817277138431867,0.7997551709413528,0.7826132029294968,0.7658402472734451,0.7494092832008997,0.733312318722407,0.7175623575846354,0.7021533946196238,0.6870774179697037,0.6723274538914362,0.6578954855600992,0.6437765260537466,0.6299615502357483,0.6164455910523733,0.6032216300566992,0.5902836471796036,0.5776256769895554,0.5652407159407934,0.5531237373749415,0.5412467668453852,0.5296047826608022,0.5182148118813833,0.5070708394050598,0.4961668575803439,0.4854998861749967,0.47506191581487656,0.46485093732674915,0.4548589587211609,0.44508398075898487,0.43551999827226,0.426163025200367,0.41700704395771027,0.4080500652392705,0.3992860863606135,0.39071110635995865,0.38232212762037915,0.37411314497391385,0.3660821591814359,0.35822517921527225,0.3505371982852618,0.3430162121852239,0.3356562356154124,0.3284562478462855,0.32141126195589703,0.3145192836721738,0.3077752962708473,0.30117731044689816,0.2947213277220726,0.28840534140666324,0.28222635636727017,0.27617937078078586,0.2702643771966298,0.26445438961188,0.2587494030594826,0.25316742062568665,0.24770542979240417,0.24236144373814264,0.23713345328966776,0.232018464555343,0.22701347743471464,0.22211648896336555,0.2173254986604055,0.21263751139243445,0.2080515225728353,0.2035635324815909,0.19917354360222816,0.19487755248943964,0.19067456076542535,0.18656156957149506,0.1825385789076487,0.17860158905386925,0.17475059628486633,0.1709816058476766,0.16729461401700974,0.16368662317593893,0.16015663122137389,0.1567036397755146,0.1533246487379074,0.15001865476369858,0.14678366233905157,0.14361866936087608,0.1405226786931356,0.1374926840265592,0.13452869156996408,0.13162769625584284,0.12878970305124918,0.12601370799044767,0.12329671656092007,0.12063872255384922,0.1180387269705534,0.11549373529851437,0.1130037394662698,0.11056774420042832,0.1081847505023082,0.10585275727013747,0.10357176202038924,0.1013387671361367,0.09915487219889958,0.09701777560015519,0.09492678257326286,0.09288088604807854,0.09087919009228547,0.08892069570720196,0.0870044007897377,0.08512940506140391,0.08329490820566814,0.08150001242756844,0.0797438162068526,0.07802551984786987,0.07634422369301319,0.07469922800858815,0.07308973247806232,0.07151493492225806,0.06997413995365302,0.06846654290954272,0.06699144405623277,0.06554814862708251,0.06413605312506358,0.06275435568143924,0.06140245900799831,0.06007966181884209,0.058785464925070606,0.05751916797210773,0.0562801705673337,0.05506787387033304,0.05388177620867888,0.05272117846955856,0.05158568173646927,0.050474584102630615,0.04938748603065809,0.0483238889525334,0.04728309158235788,0.04626479372382164,0.045268495877583824,0.044293598582347236,0.0433398000895977,0.042406502179801464,0.04149330469469229,0.04059980654468139,0.039725608502825104,0.03887021075934172,0.03803331249703964,0.03721441545834144,0.03641311607013146,0.03562921875466903,0.034862120325366654,0.03411152151723703,0.03337722333769003,0.03265862508366505,0.03195562648276488,0.03126762822891275,0.03059462985644738,0.029936031283189852,0.02929163274044792,0.02866113418713212,0.028044235426932573,0.02744053676724434,0.026849938556551933,0.026272040015707415,0.025706640910357237,0.02515334232399861,0.024612043363352615,0.024082344646255176,0.023564145745088656,0.02305704712246855,0.022560848233600456,0.02207534946501255,0.021600350582351286,0.02113555169974764,0.020680752272407215,0.020235753773401182,0.01980035441617171,0.019374355518569548,0.018957556535800297,0.018549657426774502,0.018150558539976675,0.017760058864951134,0.01737796002998948,0.017004160831371944,0.01663836184889078,0.016280462499707937,0.015930263325572014,0.015587564247349897,0.01525226499264439,0.014924165792763233,0.014603166375309229,0.01428906728203098,0.013981768007700643,0.013681068706015745,0.013386769297843179,0.013098869938403368,0.012817170470952988,0.012541571321586767,0.012271871867900094,0.012007972380767265,0.011749773053452373,0.011497073729212085,0.01124987417521576,0.011007974777991572,0.010771275342752537,0.010539674976219734,0.010313082719221711,0.010200990674396357};
        CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452011108398,71.4100399017334,70.57014846801758,69.81604131062825,69.0663407643636,68.32124137878418,67.58124033610027,66.8465404510498,66.11744054158528,65.39404042561848,64.67653973897298,63.96503988901774,63.259538650512695,62.56033833821615,61.86723836263021,61.18043772379557,60.49993705749512,59.82563749949137,59.15773709615072,58.49603589375814,57.84073575337728,57.19163576761881,56.548835118611656,55.91233476003011,55.28203455607096,54.65793418884277,54.03993352254232,53.4281333287557,52.82243347167969,52.222732861836754,51.62903245290121,51.04133224487305,50.45953210194906,49.883731524149574,49.31363169352213,48.749430656433105,48.19102986653646,47.63832982381185,47.0913298924764,46.54992993672689,46.01422913869222,45.484029134114586,44.95932865142822,44.44002819061279,43.926328341166176,43.41782792409261,42.91482798258463,42.417027155558266,41.924526850382485,41.43722693125407,40.955126444498696,40.47802607218424,40.00612608591715,39.539225578308105,39.0774253209432,38.620424588521324,38.16842492421468,37.721324602762856,37.278924306233726,36.841423988342285,36.408623377482094,35.980523109436035,35.5571231842041,35.138322830200195,34.72402286529541,34.314422607421875,33.9092222849528,33.50852139790853,33.11222139994303,32.72032165527344,32.33282152811686,31.949621200561523,31.5707205136617,31.196120421091717,30.82562033335368,30.459320386250813,30.097119967142742,29.739019711812336,29.385018984476726,29.035019238789875,28.689018726348877,28.34691874186198,28.008718490600586,27.674418290456135,27.34401798248291,27.01731777191162,26.694317658742268,26.375117619832356,26.059617042541504,25.74771722157796,25.439417044321697,25.134716669718426,24.833516438802082,24.535816192626953,24.24151595433553,23.950716018676758,23.663215796152752,23.37901512781779,23.098215262095135,22.820715109507244,22.54631519317627,22.275214831034344,22.007214546203613,21.742314338684082,21.480614185333252,21.2219139734904,20.966213703155518,20.71351385116577,20.463813940684002,20.217013676961262,19.973013242085774,19.73201338450114,19.493812719980877,19.258312702178955,19.025712649027508,18.7957124710083,18.568512598673504,18.34391212463379,18.1220121383667,17.902712027231853,17.68601147333781,17.471911748250324,17.260311603546143,17.051111539204914,16.84451134999593,16.640311241149902,16.43851121266683,16.239110946655273,16.04201078414917,15.847310781478882,15.654910723368326,15.464810371398926,15.276910146077475,15.091310262680054,14.907910029093424,14.726610024770102,14.547509908676147,14.370609680811564,14.195709625879923,14.023009459177652,13.852209488550821,13.683609326680502,13.51690904299418,13.352209011713663,13.18950899442037,13.028808832168579,12.869908730189005,12.713008642196655,12.557908376057943,12.40470846494039,12.253308296203613,12.103808244069418,11.956008195877075,11.81000804901123,11.665807882944742,11.523307879765829,11.38250764211019,11.243407567342123,11.105907440185547,10.970107396443685,10.836007277170816,10.703507343928019,10.57250706354777,10.443207184473673,10.315406958262125,10.189106861750284,10.064406871795654,9.941136916478476,9.819396734237671,9.699116547902426,9.580296436945597,9.462916453679403,9.346956332524618,9.232386350631714,9.119216203689575,9.007416089375814,8.896956046422323,8.787845849990845,8.680055777231852,8.573575814565023,8.468385696411133,8.364475647608439,8.261815627415976,8.160415649414062,8.060235579808554,7.961275378863017,7.863525311152141,7.766955256462097,7.671565294265747,7.5773351192474365,7.484255075454712,7.392305056254069,7.301475008328755,7.21175491809845,7.123124877611796,7.035574793815613,6.949094772338867,6.863674680391948,6.7792946100234985,6.695934613545735,6.613604505856832,6.532274444897969,6.4519444306691485,6.372584342956543,6.294204314549764,6.216784278551738,6.140304287274678,6.064764102300008,5.99014409383138,5.916444023450215,5.843643983205159,5.7717439730962115,5.700713912645976,5.630553841590881,5.561263759930928,5.49281374613444,5.425213694572449,5.358433683713277,5.2924736340840655,5.227333585421245,5.162983496983846,5.09942348798116,5.036653518676758,4.974643429120381,4.913403352101644,4.85291330019633,4.79317323366801,4.734163244565328,4.6758731206258135,4.618313193321228,4.561453143755595,4.505293091138204,4.449823061625163,4.395043094952901,4.3409329652786255,4.287492950757344,4.234702865282695,4.182572801907857,4.131082852681478,4.0802327791849775,4.030012726783752,3.980402708053589,3.931412696838379,3.8830226262410483,3.8352326154708862,3.788032591342926,3.7414125402768454,3.695372521877289,3.6499024828275046,3.6049824555714927,3.5606224139531455,3.5168124039967856,3.4735423922538757,3.430802345275879,3.3885923425356546,3.346902290980021,3.305722256501516,3.265052239100138,3.224892179171244,3.185212194919586,3.146032154560089,3.1073321104049683,3.0691120823224387,3.0313620368639627,2.9940720200538635,2.9572419921557107,2.920871992905935,2.8849419554074607,2.8494619727134705,2.8144219517707825,2.779801865418752,2.745611866315206,2.7118518352508545,2.678501844406128,2.6455618341763816,2.613031804561615,2.580891728401184,2.549161712328593,2.5178116957346597,2.486851692199707,2.4562716682751975,2.4260716636975608,2.396241625150045,2.3667816321055093,2.3376815915107727,2.308941602706909,2.280551572640737,2.252521514892578,2.2248215079307556,2.1974715193112693,2.1704614758491516,2.1437814633051553,2.1174214482307434,2.091391444206238,2.065691431363424,2.0402913888295493,2.015221357345581,1.9904413521289825,1.9659813245137532,1.941821297009786,1.9179513057072957,1.8943812847137451,1.8710912764072418,1.848101258277893,1.8253912329673767,1.8029512166976929,1.7808012266953785,1.7589111824830372,1.7373011807600658,1.7159511645634968,1.694861153761546,1.6740411321322124,1.6534711321194966,1.6331511040528615,1.6130810976028442,1.5932610829671223,1.5736910700798035,1.5543510516484578,1.53526105483373,1.5163910388946533,1.4977610409259796,1.4793609877427418,1.4611909786860149,1.4432409902413685,1.4255109628041585,1.4080009460449219,1.3907009363174438,1.3736209273338318,1.3567509055137634,1.3400809069474537,1.3236209154129028,1.307370901107788,1.2913108865420024,1.2754508753617604,1.2597808639208476,1.244310845931371,1.2290308276812236,1.2139408091704051,1.1990308165550232,1.1843108038107555,1.1697607934474945,1.1554007828235626,1.1412107745806377,1.127200762430827,1.1133607625961304,1.0996907552083333,1.0861807366212208,1.0728507339954376,1.0596807201703389,1.0466707050800323,1.0338207085927327,1.0211206873257954,1.00859068830808,0.9962076892455419,0.9839776655038198,0.9718986650307974,0.9599686612685522,0.9481846491495768,0.9365466386079788,0.9250506261984507,0.9136966218551,0.9024816205104192,0.8914056122303009,0.8804645985364914,0.8696585943301519,0.8589855879545212,0.8484445810317993,0.8380315651496252,0.827747568488121,0.8175905495882034,0.807557558019956,0.7976485441128413,0.7878605276346207,0.778193528453509,0.7686445166667303,0.759213517109553,0.7498985131581625,0.7406985064347585,0.731610506772995,0.7226354827483495,0.7137694805860519,0.7050134837627411,0.6963644673426946,0.6878224660952886,0.6793844550848007,0.6710504591464996,0.662819450100263,0.6546894510587057,0.6466594388087591,0.6387274364630381,0.6308934291203817,0.6231564283370972,0.6155134191115698,0.6079644113779068,0.6005084117253622,0.5931444068749746,0.5858704050381979,0.5786853929360708,0.5715893854697546,0.5645803759495417,0.557657370964686,0.550820380449295,0.544066364566485,0.5373953729867935,0.5308063626289368,0.5242983549833298,0.5178703566392263,0.5115213493506113,0.5052503446737925,0.49905634423096973,0.4929393356045087,0.4868963286280632,0.48092732578516006,0.4750323221087456,0.46921031922101974,0.46345831205447513,0.45777831226587296,0.4521673073371251,0.44662530223528546,0.44115130106608075,0.43574529389540356,0.43040429304043454,0.4251302828391393,0.41992028554280597,0.4147742862502734,0.4096912791331609,0.404671274125576,0.3997122719883919,0.39481526613235474,0.38997726142406464,0.38519926369190216,0.38047925879557926,0.3758182500799497,0.37121324986219406,0.3666662499308586,0.36217424521843594,0.3577372431755066,0.3533542404572169,0.3490262379248937,0.3447502354780833,0.3405272339781125,0.33635622759660083,0.3322362278898557,0.3281672199567159,0.3241482228040695,0.32017721732457477,0.31625621517499286,0.31238320966561633,0.3085572123527527,0.30477820585171383,0.3010462050636609,0.29736019919315976,0.29371819645166397,0.29012219856182736,0.2865691954890887,0.2830601930618286,0.27959418793519336,0.2761711850762367,0.2727901836236318,0.2694501851995786,0.26615118235349655,0.2628931775689125,0.2596741740902265,0.2564951727787654,0.2533551752567291,0.2502541703482469,0.2471911683678627,0.24416516224543253,0.2411761631568273,0.2382241611679395,0.2353091612458229,0.23242815832297006,0.22958415374159813,0.22677415361007056,0.22399915009737015,0.2212571489314238,0.2185501493513584,0.2158751462896665,0.21323314433296522,0.21062414223949114,0.20804714038968086,0.2055011379222075,0.20298713694016138,0.20050313572088876,0.19805014381806055,0.19683102890849113};
        CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297698497772217,16.274217128753662,16.21771017710368,16.17810805638631,16.132907390594482,16.082906246185303,16.028706073760986,15.97090514500936,15.909804503122965,15.845903952916464,15.779603560765585,15.71120309829712,15.641002575556437,15.569202502568563,15.496102253595987,15.421801884969076,15.346601565678915,15.270601511001587,15.193901300430298,15.116701126098633,15.038901011149088,14.960900863011679,14.882600704828898,14.804000695546469,14.725400606791178,14.646600484848022,14.56790033976237,14.489100376764933,14.41040047009786,14.33180046081543,14.253400246302286,14.175000190734863,14.096900224685669,14.018900156021118,13.941199938456217,13.863600174585978,13.786400079727173,13.70930012067159,13.63260014851888,13.556100130081177,13.479900121688843,13.403999964396158,13.328400055567423,13.253099918365479,13.178100109100342,13.103399991989136,13.029099941253662,12.955099900563559,12.881300131479898,12.807999928792318,12.734900077184042,12.662200053532919,12.589799960454306,12.517699956893921,12.44599986076355,12.374599933624268,12.303599993387857,12.232900063196817,12.162499904632568,12.09250005086263,12.022799968719482,11.953399976094564,11.884400049845377,11.815700054168701,11.747400045394897,11.679400126139322,11.611700137456259,11.544400135676065,11.477399905522665,11.410799900690714,11.344499905904135,11.278500080108643,11.212900002797445,11.147600015004477,11.08269993464152,11.01799988746643,10.953800042470297,10.889899969100952,10.826299985249838,10.763000011444092,10.70010002454122,10.637500047683716,10.575299978256226,10.513299942016602,10.451799869537354,10.39049998919169,10.329600016276041,10.269000053405762,10.208800077438354,10.148799896240234,10.08929991722107,10.02999989191691,9.97104008992513,9.912419954935709,9.854120016098022,9.796149969100952,9.738489866256714,9.681150118509928,9.624130090077719,9.5674200852712,9.511020024617514,9.454939842224121,9.39917000134786,9.343709945678711,9.288559993108114,9.233710050582886,9.17916997273763,9.124930063883463,9.070990085601807,9.017360210418701,8.964020093282064,8.910990079243978,8.85824990272522,8.805800120035807,8.753650029500326,8.70179001490275,8.650219837824503,8.598949909210205,8.547959884007772,8.497260093688965,8.446839968363443,8.39670991897583,8.346860011418661,8.297289927800497,8.248000065485636,8.198999881744385,8.150269985198975,8.101809899012247,8.053629954655966,8.005719939867655,7.958089987436931,7.910719990730286,7.863629937171936,7.816800038019816,7.770240028699239,7.7239499886830645,7.677920023600261,7.632150014241536,7.586650013923645,7.541400035222371,7.496410051981608,7.451680024464925,7.407210032145183,7.362989942232768,7.3190300067265825,7.275319933891296,7.231859962145488,7.188639998435974,7.145680030186971,7.102969964345296,7.060499986012776,7.018280029296875,6.976300040880839,6.934559981028239,6.893060048421224,6.851810057957967,6.810789903004964,6.770009954770406,6.7294700145721436,6.6891599496205645,6.649090011914571,6.609249989191691,6.569640000661214,6.530260006586711,6.491110006968181,6.452190121014913,6.413489937782288,6.3750200271606445,6.336769978205363,6.298750042915344,6.260950009028117,6.223369995752971,6.186019976933797,6.14887003103892,6.111949960390727,6.075250029563904,6.038750052452087,6.002479990323384,5.966409961382548,5.930559992790222,5.894920110702515,5.859489997227986,5.824259996414185,5.7892500559488935,5.754439949989319,5.71983003616333,5.685429970423381,5.651229977607727,5.6172399918238325,5.583439985911052,5.549849987030029,5.516450007756551,5.483249982198079,5.450249950091044,5.417449951171875,5.384829998016357,5.352410038312276,5.320190032323201,5.288149952888489,5.256309986114502,5.224650025367737,5.193190058072408,5.161909977595012,5.130810022354126,5.099900046984355,5.069179932276408,5.038640022277832,5.008279999097188,4.978099981943767,4.948100050290425,4.918279965718587,4.88864000638326,4.859179973602295,4.829890012741089,4.800779978434245,4.771840055783589,4.7430799802144366,4.714489976565043,4.686070005098979,4.657819986343384,4.629730065663655,4.6018199523289995,4.574080069859822,4.546500007311503,4.519090016682942,4.49184004465739,4.464760025342305,4.437840024630229,4.411080042521159,4.3844800392786665,4.358050028483073,4.3317699035008745,4.305650035540263,4.2796900272369385,4.253890037536621,4.228240013122559,4.202750086784363,4.177410006523132,4.152219931284587,4.127189993858337,4.102310021718343,4.077579935391744,4.0530000527699785,4.028570095698039,4.004279990990956,3.980149984359741,3.956159989039103,3.932319978872935,3.908620019753774,3.8850599924723306,3.861649990081787,3.8383700052897134,3.8152400255203247,3.7922499974568686,3.7693999807039895,3.7466899752616882,3.7241099874178567,3.701669991016388,3.6793699860572815,3.65720001856486,3.635170022646586,3.6132700045903525,3.5915000240008035,3.5698599815368652,3.548359990119934,3.526980002721151,3.5057300130526223,3.4846099813779197,3.4636200070381165,3.4427599708239236,3.4220199982325235,3.4014099637667337,3.3809199730555215,3.3605600198109946,3.340320030848185,3.320199986298879,3.3002000053723655,3.280330022176107,3.260569989681244,3.240929981072744,3.2214199701944985,3.202020009358724,3.1827299992243447,3.1635700265566506,3.1445200045903525,3.1255800127983093,3.106760025024414,3.0880499879519143,3.0694600145022073,3.050980051358541,3.03260999917984,3.0143499771753945,2.9962000052134194,2.97816002368927,2.960230012734731,2.9424100120862327,2.924689988295237,2.9070900281270347,2.889580011367798,2.872189998626709,2.8548999627431235,2.8377100030581155,2.8206299940745034,2.80364998181661,2.786779979864756,2.7699999809265137,2.7533300121625266,2.736759980519613,2.7202800114949546,2.703909993171692,2.6876400311787925,2.671459992726644,2.6553799708684287,2.6394000252087912,2.6235199769337973,2.607729991277059,2.592040002346039,2.576439996560415,2.560929993788401,2.545520007610321,2.530209998289744,2.514979978402456,2.49985001484553,2.484809994697571,2.4698599576950073,2.4549899895985923,2.44021999835968,2.425540010134379,2.410950005054474,2.3964399695396423,2.3820300102233887,2.367700000603994,2.3534500201543174,2.339300036430359,2.325219988822937,2.311239997545878,2.2973299821217856,2.2835099697113037,2.2697799801826477,2.25613001982371,2.242560029029846,2.229070007801056,2.215659956137339,2.2023299733797708,2.1890899936358132,2.175919989744822,2.162840028603872,2.1498300035794577,2.136900007724762,2.124049961566925,2.1112799843152366,2.098580002784729,2.0859599908192954,2.073419988155365,2.060949981212616,2.0485600233078003,2.036239981651306,2.0239999890327454,2.011829952398936,1.9997399946053822,1.9877099891503651,1.9757600128650665,1.9638799925645192,1.9520800014336903,1.9403400023778279,1.928680012623469,1.917090008656184,1.9055599768956502,1.8941100041071575,1.8827200134595234,1.8714100023110707,1.8601600031057994,1.8489800095558167,1.837859998146693,1.82682000597318,1.815839986006419,1.8049299915631611,1.7940800090630848,1.7833000024159749,1.7725800077120464,1.761929988861084,1.7513400117556255,1.740820010503133,1.7303600013256073,1.7199600040912628,1.7096199989318848,1.6993499894936879,1.6891399919986725,1.6789900064468384,1.6689100066820781,1.6588799953460693,1.6489100058873494,1.639009992281596,1.6291599969069164,1.6193699936072032,1.6096500058968861,1.599980006615321,1.590369999408722,1.580810010433197,1.5713200171788533,1.5618800123532612,1.5525000095367432,1.543170024951299,1.5339099963506062,1.5246900121370952,1.5155399938424428,1.5064299901326497,1.4973899920781453,1.488400012254715,1.4794600009918213,1.470570017894109,1.461739997069041,1.452969988187154,1.4442399839560192,1.4355700016021729,1.4269499977429707,1.4183800121148427,1.4098700086275737,1.4014000197251637,1.3929900030295055,1.3846200108528137,1.376310000816981,1.3680499792099,1.3598400056362152,1.3516699969768524,1.343560000260671,1.335499991973241,1.327479988336563,1.3195099830627441,1.3115900059541066,1.3037199874718983,1.2958900133768718,1.288120021422704,1.2803900043169658,1.2727000017960866,1.2650599976380665,1.257470001777013,1.2499299943447113,1.2424299915631611,1.2349700033664703,1.227560003598531,1.220190018415451,1.2128699819246929,1.2055899997552235,1.1983599762121837,1.1911699970563252,1.1840199927488964,1.1769200066725414,1.1698599954446156,1.1628399988015492,1.155870000521342,1.1489299933115642,1.1420400043328602,1.1351900001366932,1.1283799807230632,1.1216099858283997,1.1148799856503804,1.1081999937693279,1.1015499929587047,1.0949400166670482,1.0883800188700359,1.081849992275238,1.0753599901994069,1.0689100126425426,1.0624999900658925,1.0561299721399944,1.0497999986012776,1.0434999863306682,1.0372399886449177,1.0310199956099193,1.0248399873574574,1.01870001355807,1.0125900010267894,1.006520003080368,1.0004800061384838,0.9944849958022436,0.9885230014721552,0.9825969984134039,0.9767070015271505,0.9708520025014877,0.9650319963693619,0.9592469930648804,0.9534969925880432,0.9477819949388504,0.9421009967724482,0.939269001285235};
        CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.46001680692037,8.488823413848877,8.531164328257242,8.575854063034058,8.61820419629415,8.658293883005777,8.696213881174723,8.73206353187561,8.765883445739746,8.797773361206055,8.827803055445353,8.856033166249594,8.882533073425293,8.90737279256185,8.930612643559774,8.952302614847818,8.97250247001648,8.991272528966268,9.00867247581482,9.024742364883423,9.03953218460083,9.053092082341513,9.06547212600708,9.076711893081665,9.086852073669434,9.095951795578003,9.104021708170572,9.111121733983358,9.117271820704142,9.1225217183431,9.126901547114054,9.130431413650513,9.133161544799805,9.135111411412558,9.136321465174357,9.136801401774088,9.13659119606018,9.135731140772501,9.134220997492472,9.132091124852499,9.129370927810669,9.126081069310507,9.12225111325582,9.117891073226929,9.113010803858439,9.10766077041626,9.101830959320068,9.095560868581137,9.088850816090902,9.081730763117472,9.07421064376831,9.066300710042318,9.058030684789022,9.049410661061605,9.040440638860067,9.031150658925375,9.02155057589213,9.011650482813517,9.001450538635254,8.990980466206869,8.980250597000122,8.969260533650717,8.958030382792154,8.946550448735556,8.934850454330444,8.922930399576822,8.910820404688517,8.898500363032023,8.886000394821167,8.873310327529907,8.860450347264608,8.847430308659872,8.834240277608236,8.820900281270346,8.807420492172241,8.793800195058187,8.7800501982371,8.766170263290405,8.752190351486206,8.738080342610678,8.723860184351603,8.709540287653605,8.695120096206665,8.680610259373983,8.666000127792358,8.651309967041016,8.635220050811768,8.617770036061605,8.600359996159872,8.582979838053385,8.565620104471842,8.54830010732015,8.531000057856241,8.513739983240763,8.496500015258789,8.479289929072062,8.462110042572021,8.444969971974691,8.427849849065145,8.410760005315145,8.393699963887533,8.376670042673746,8.359670003255209,8.342689911524454,8.32574995358785,8.308839956919352,8.29196015993754,8.275099913279215,8.258280038833618,8.241479953130087,8.224720001220703,8.207979996999105,8.191280126571655,8.17460004488627,8.157950083414713,8.141330083211264,8.124749978383383,8.108189980189005,8.091660102208456,8.075160026550293,8.058689991633097,8.042249997456869,8.025839964548746,8.009460051854452,7.993099927902222,7.976780017217,7.9604900280634565,7.944230039914449,7.927989919980367,7.9117900133132935,7.895609974861145,7.879469990730286,7.863349994023641,7.847259958585103,7.831200003623962,7.8151800235112505,7.799179991086324,7.783209999402364,7.767270008722941,7.7513599793116255,7.735479950904846,7.719619989395142,7.7037999629974365,7.688010056813558,7.672240058581035,7.65651003519694,7.64079995950063,7.6251300573349,7.609480023384094,7.593860030174255,7.578269998232524,7.562710007031758,7.5471800565719604,7.5316799481709795,7.5162099202473955,7.500770052274068,7.485359986623128,7.4699699481328325,7.454619963963826,7.439290006955464,7.42399001121521,7.408729990323384,7.393489956855774,7.37828000386556,7.363099972407023,7.347939968109131,7.332820018132527,7.317729989687602,7.3026600281397505,7.287630041440328,7.272619962692261,7.25763996442159,7.242690006891887,7.22777001063029,7.2128799756368,7.198019981384277,7.1831899881362915,7.16838002204895,7.153609991073608,7.1388600667317705,7.124140024185181,7.109449982643127,7.094789981842041,7.080159982045491,7.065559983253479,7.050979971885681,7.036440014839172,7.021920005480449,7.007429997126262,6.9929700295130415,6.9785399834314985,6.9641299645106,6.949759999910991,6.935409982999166,6.92110002040863,6.90680992603302,6.892550031344096,6.878310004870097,6.864110032717387,6.8499300082524615,6.835789958635966,6.821669975916545,6.80757995446523,6.793509999910991,6.77947998046875,6.765469908714294,6.751499970753987,6.737550059954326,6.723620057106018,6.70972998936971,6.69586996237437,6.682029962539673,6.668220003445943,6.65444000562032,6.640679995218913,6.626959999402364,6.61325999101003,6.599589983622233,6.585950016975403,6.57234005133311,6.558749993642171,6.5451899766922,6.531659960746765,6.5181600252787275,6.504679997762044,6.4912400643030805,6.477819999059041,6.464420000712077,6.451059977213542,6.437719980875651,6.424409985542297,6.411129991213481,6.39788003762563,6.384649952252706,6.371449987093608,6.3582799434661865,6.34512996673584,6.332020084063212,6.31893006960551,6.305869936943054,6.2928299109141035,6.279820005098979,6.266839981079102,6.253889997800191,6.240960001945496,6.228069980939229,6.215190013249715,6.2023499806722,6.18953005472819,6.1767399708429975,6.163980007171631,6.1512400309244795,6.138529936472575,6.125840028127034,6.113180001576741,6.100549976030986,6.087950070699056,6.075370033582051,6.062820076942444,6.050289988517761,6.037789980570476,6.025320013364156,6.012869993845622,6.000450094540914,5.988049944241841,5.975680073102315,5.963330030441284,5.95101002852122,5.9387199481328325,5.92645005385081,5.9142100016276045,5.902000069618225,5.889799992243449,5.8776399691899615,5.865500013033549,5.853380004564921,5.8412899573644,5.829230030377706,5.817189971605937,5.805169979731242,5.793180028597514,5.781219998995463,5.769280036290486,5.7573699951171875,5.745480060577393,5.733609954516093,5.7217700481414795,5.709949970245361,5.698160012563069,5.6863999764124555,5.6746500333150225,5.66293998559316,5.651239951451619,5.639569997787476,5.6279300053914385,5.616310040156047,5.604710022608439,5.593140006065369,5.581590016682942,5.570070028305054,5.558569987614949,5.54709005355835,5.535640001296997,5.524209976196289,5.512809952100118,5.501429955164592,5.49007002512614,5.478739937146504,5.467430114746094,5.456140041351318,5.44487996896108,5.433640003204346,5.422420024871826,5.411230047543843,5.400060057640076,5.388910015424092,5.377790013949077,5.366690039634705,5.355610013008118,5.344560027122498,5.333530028661092,5.3225200573603315,5.311539967854817,5.300579984982808,5.289639989535014,5.278720060984294,5.267830053965251,5.256960034370422,5.246109962463379,5.23527995745341,5.224480032920837,5.21369997660319,5.202939947446187,5.192199945449829,5.181490063667297,5.170799970626831,5.160129944483439,5.149480024973552,5.138859987258911,5.128260016441345,5.117680033047994,5.107119957605998,5.096579988797505,5.086069981257121,5.075570027033488,5.065100034077962,5.054660002390544,5.044230024019877,5.033819953600566,5.023439923922221,5.01307996114095,5.002740025520325,4.992419997851054,4.982119997342427,4.971839984258016,4.961590011914571,4.951359987258911,4.941139976183574,4.930950005849202,4.920779983202617,4.910629987716675,4.90050991376241,4.890399972597758,4.880319992701213,4.870249946912129,4.860209981600444,4.850190043449402,4.840180039405823,4.830199996630351,4.820240020751953,4.81029999256134,4.800390005111694,4.7904899915059405,4.780610044797261,4.770750006039937,4.76091996828715,4.7511000235875445,4.741310040156047,4.731529911359151,4.721780021985372,4.712040106455485,4.702329953511556,4.692639986673991,4.682959993680318,4.673310001691182,4.663680076599121,4.654060045878093,4.644469936688741,4.634900013605754,4.625339984893799,4.615809996922811,4.6062900225321455,4.596800049146016,4.587329983711243,4.577870051066081,4.568439960479736,4.5590200026830034,4.549630045890808,4.540250023206075,4.530890027681987,4.521560033162435,4.512240012486775,4.502940058708191,4.493659973144531,4.4843999942143755,4.475159962972005,4.465939998626709,4.456740021705627,4.44756007194519,4.438389976819356,4.429250001907349,4.4201200405756635,4.411020000775655,4.401930093765259,4.392859975496928,4.3838099638621015,4.374780019124349,4.365769982337952,4.3567800124486284,4.347799976666768,4.338850100835164,4.329910000165303,4.320989966392517,4.312090039253235,4.303209940592448,4.2943399747212725,4.285500009854634,4.276670018831889,4.2678699890772505,4.259080012639363,4.25029997030894,4.241550008455913,4.23281995455424,4.224099953969319,4.215400020281474,4.206719954808553,4.198059995969136,4.1894099315007525,4.180790026982625,4.172179937362671,4.16359003384908,4.155009945233663,4.1464600165685015,4.137919942537944,4.1294000546137495,4.12089999516805,4.112420002619426,4.103949983914693,4.0954999923706055,4.087069948514302,4.078660011291504,4.070259968439738,4.061879992485046,4.05352000395457,4.045180042584737,4.036849935849507,4.028539935747783,4.020250042279561,4.011980056762695,4.003719965616862,3.995480000972748,3.9872499903043113,3.979050040245056,3.970860024293264,3.9626899560292563,3.9545300006866455,3.9463900526364646,3.9382699926694236,3.930169999599457,3.9220800002415976,3.914010008176168,3.905959963798523,3.897919992605845,3.889899969100952,3.8818999926249185,3.8739100297292075,3.8659399350484214,3.8579800128936768,3.8500500321388245,3.8421299854914346,3.834220012029012,3.826329986254374,3.818460007508596,3.810609996318817,3.802769978841146,3.7988500197728476};
        CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192362467448,514.5848337809244,508.8199412027995,504.2629089355469,499.6559117635091,495.013910929362,490.3509114583333,485.6759084065755,480.99791208902997,476.3239110310872,471.6609115600586,467.01391347249347,462.3859176635742,457.7809143066406,453.20091756184894,448.64991505940753,444.12791697184247,439.6379165649414,435.17991892496747,430.7549184163411,426.3649164835612,422.0099131266276,417.6899185180664,413.4059193929036,409.15792592366535,404.9469223022461,400.7709248860677,396.6319274902344,392.52892303466797,388.4629211425781,384.43292744954425,380.4389241536458,376.4809290568034,372.55792744954425,368.67193094889325,364.8209279378255,361.0049311319987,357.22493235270184,353.4799321492513,349.76893107096356,346.0929361979167,342.45093027750653,338.84293365478516,335.2699330647786,331.7299346923828,328.2229359944661,324.7499313354492,321.3099365234375,317.90193430582684,314.52693939208984,311.18493906656903,307.8739420572917,304.59593709309894,301.3489405314128,298.1339365641276,294.94894154866535,291.79593658447266,288.67394256591797,285.58194224039715,282.5199457804362,279.4879455566406,276.48594156901044,273.5139465332031,270.5709482828776,267.65694427490234,264.7719446818034,261.9159469604492,259.0879491170247,256.28894933064777,253.51794942220053,250.7749481201172,248.0599505106608,245.371950785319,242.71194966634116,240.07794952392578,237.47195180257162,234.89195251464844,232.3389523824056,229.81195322672525,227.31095377604166,224.83595530192056,222.3859545389811,219.96195475260416,217.56395467122397,215.1899553934733,212.8409563700358,210.5159568786621,208.21695709228516,205.94095738728842,203.68995793660483,201.4619572957357,199.256960550944,197.07596079508463,194.9169603983561,192.7809600830078,190.66796239217123,188.57696151733398,186.50796254475912,184.46096165974936,182.43596394856772,180.43196233113608,178.4499626159668,176.48796463012695,174.5469652811686,172.62696329752603,170.7269655863444,168.84796524047852,166.98796463012695,165.14896647135416,163.3289680480957,161.52796427408853,159.74596659342447,157.98396809895834,156.23996861775717,154.5149688720703,152.8089688618978,151.12097040812174,149.45096842447916,147.79897181193033,146.16396967569986,144.5469716389974,142.94797007242838,141.36597188313803,139.79997126261392,138.25196965535483,136.71997197469076,135.20497258504233,133.70597457885742,132.2239735921224,130.75697326660156,129.30597178141275,127.87097231547038,126.45097351074219,125.04697354634602,123.65797424316406,122.28397369384766,120.92497380574544,119.57997576395671,118.25097465515137,116.9349759419759,115.63397534688313,114.34697659810384,113.07497660319011,111.81597646077473,110.56997680664062,109.33797836303711,108.11997731526692,106.91497866312663,105.72297668457031,104.54397837320964,103.37797864278157,102.22497749328613,101.0839786529541,99.95627784729004,98.84048016866048,97.73687934875488,96.6453800201416,95.56588045756023,94.49817848205566,93.44218063354492,92.39778010050456,91.36488151550293,90.34328015645345,89.33298174540202,88.33378156026204,87.34548123677571,86.36818250020345,85.40158208211263,84.44568188985188,83.50018246968587,82.56528155008952,81.64058303833008,80.72608311971028,79.8217830657959,78.92738342285156,78.04288419087727,77.16818428039551,76.30318260192871,75.44768397013347,74.6016845703125,73.76508394877116,72.93768564860027,72.1195837656657,71.31038475036621,70.51028569539388,69.71898587544759,68.93658510843913,68.16278584798177,67.39758491516113,66.64088567097981,65.89258639017741,65.15258661905925,64.4208869934082,63.697285652160645,62.98178641001383,62.274187088012695,61.57448705037435,60.88258679707845,60.198486963907875,59.52188777923584,58.85288747151693,58.19138717651367,57.53718789418539,56.89038848876953,56.25078805287679,55.618288358052574,54.99288845062256,54.37448819478353,53.76298872629801,53.158288637797035,52.560388247172035,51.96918869018555,51.38468964894613,50.806589444478355,50.23508961995443,49.6698891321818,49.11108938852946,48.55858898162842,48.012190183003746,47.47198994954427,46.93779055277506,46.40969053904215,45.887390772501625,45.371090253194176,44.86049111684164,44.35569095611572,43.85649045308431,43.36299101511637,42.87499109903971,42.39249038696289,41.915390968322754,41.44369125366211,40.97729174296061,40.51609134674072,40.0601921081543,39.60939121246338,39.163591384887695,38.72289117177328,38.28719170888265,37.85639222462972,37.43039194742838,37.00929196675619,36.59289264678955,36.18119271596273,35.774192810058594,35.37169233957926,34.973793029785156,34.58039251963297,34.19139321645101,33.80689303080241,33.4265931447347,33.05059305826823,32.678893089294434,32.31139341990153,31.94799343744914,31.588693300882976,31.233493328094482,30.882193247477215,30.534993330637615,30.191593647003174,29.85209385553996,29.516393661499023,29.184593677520752,28.856393973032635,28.531993865966797,28.211194038391113,27.893994013468426,27.580394109090168,27.270294348398846,26.963794072469074,26.66059446334839,26.360894362131756,26.064594745635986,25.771594683329266,25.481894493103027,25.19549496968587,24.91229502360026,24.632294813791912,24.35539484024048,24.081594944000244,23.81099510192871,23.543395042419434,23.27879508336385,23.017095406850178,22.758495171864826,22.502695242563885,22.24979543685913,21.99979527791341,21.7525954246521,21.508095582326252,21.266395409901936,21.027495861053467,20.791195392608643,20.5575958887736,20.326595783233643,20.098196029663086,19.872395992279053,19.64909601211548,19.42839590708415,19.21009588241577,18.994295914967854,18.780895709991455,18.56989590326945,18.3612961769104,18.154996395111084,17.951096375783283,17.749396006266277,17.550096193949383,17.352896213531494,17.15799633661906,16.965296427408855,16.774696350097656,16.586296399434406,16.399996757507324,16.215896606445312,16.0336967309316,15.853696584701538,15.675596634546915,15.49959667523702,15.325496673583984,15.153396765391031,14.983296950658163,14.81499687830607,14.648696819941202,14.48419682184855,14.321497042973837,14.160696983337402,14.001697142918905,13.844497203826904,13.689097086588541,13.535397132237753,13.383397261301676,13.233197212219238,13.084597110748291,12.937697172164917,12.792497237523397,12.648897409439087,12.50689729054769,12.36649743715922,12.227697531382242,12.090497414271036,11.954797506332397,11.820597569147745,11.687897602717081,11.556697527567545,11.426997661590576,11.298797527949015,11.171997706095377,11.046597639719645,10.922597646713257,10.800097624460856,10.678897539774576,10.558997869491577,10.440597931543985,10.323397874832153,10.207597891489664,10.092997868855795,9.979797919591268,9.867827892303467,9.757117907206217,9.647648016611734,9.53941790262858,9.432398001352945,9.32657798131307,9.22195808092753,9.118508021036783,9.016218105951944,8.915088017781576,8.815087954203287,8.716208219528198,8.618448257446289,8.521778186162313,8.426198244094849,8.331698258717855,8.238258202870687,8.14585836728414,8.054508368174234,7.964178363482158,7.874868273735046,7.7865684032440186,7.699248393376668,7.612918416659038,7.527548352877299,7.443148493766785,7.359688440958659,7.27716851234436,7.195578495661418,7.114908496538798,7.035138487815857,6.956268509229024,6.878288547197978,6.801178614298503,6.72493855158488,6.649548570315043,6.575008551279704,6.5013086795806885,6.428438703219096,6.356378634770711,6.285138726234436,6.214688738187154,6.145038723945618,6.076168696085612,6.008068760236104,5.940738717714946,5.87415874004364,5.80833884080251,5.743248860041301,5.67888879776001,5.615248799324036,5.552328864733378,5.490118900934855,5.428598841031392,5.367778897285461,5.307638923327128,5.24816890557607,5.189378937085469,5.13123885790507,5.07374890645345,5.016908963521321,4.960708936055501,4.905138969421387,4.850198984146118,4.795869032541911,4.742148995399475,4.689028978347778,4.636508981386821,4.584579030672709,4.533229033152263,4.48245910803477,4.4322590827941895,4.382629036903381,4.33354914188385,4.285019079844157,4.237029075622559,4.189589103062947,4.142669121424357,4.096289157867432,4.050419092178345,4.005069136619568,3.9602291584014893,3.9158892035484314,3.8720391988754272,3.8286991715431213,3.785829226175944,3.7434491912523904,3.7015391985575357,3.660109261671702,3.6191392739613852,3.5786192615826926,3.538569231828054,3.498959263165792,3.459799269835154,3.421069304148356,3.382779280344645,3.344919264316559,3.307489295800527,3.27046928803126,3.2338693141937256,3.197679340839386,3.1618993679682412,3.1265193621317544,3.091529369354248,3.0569393634796143,3.0227293570836387,2.988909383614858,2.9554693897565207,2.922399421532949,2.8897094130516052,2.85737939675649,2.825409412384033,2.7937994400660195,2.762549420197805,2.7316394249598184,2.7010894219080606,2.670869469642639,2.640999436378479,2.6114594539006553,2.5822494427363076,2.553369482358297,2.52480947971344,2.4965694745381675,2.468649466832479,2.441039502620697,2.413739502429962,2.386749784151713,2.3733296990394592};
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.807329177856445,40.02749729156494,40.503668467203774,34.2638373374939,33.29065704345703,32.36866935094198,31.425484498341877,31.818466027577717,33.69285806020101,35.69612979888916,37.70858097076416,39.721710840861,41.735527674357094,43.74809265136719,45.76314226786295,47.77323532104492,49.79362551371256,50.67349402109782,50.28880755106608,49.792920430501304,49.2898915608724,48.78569030761719,48.281626065572105,47.77750142415365,47.27344036102295,46.76925532023112,46.26535733540853,45.727790196736656,45.15313243865967,44.57508977254232,43.9969097773234,43.41859785715739,42.840414683024086,42.262172063191734,41.68398984273275,41.105467796325684,40.52815341949463,39.79301675160726,38.88322893778483,37.957661628723145,37.03138033548991,36.104934533437095,35.17845392227173,34.25194772084554,33.32544485727946,32.39896551767985,31.4723957379659,30.55953613917033,29.661925792694092,28.765656153361004,27.86944039662679,26.973347345987957,26.077144304911297,25.18095064163208,24.28482659657796,23.38871685663859,22.49227507909139,21.670045216878254,20.93033742904663,20.198029200236004,19.46601676940918,18.734275976816814,18.002442916234333,17.270567576090496,16.538729826609295,15.807054201761881,15.074612458546957,14.476550261179606,14.027772903442383,13.592549085617065,13.157695531845093,12.723352432250977,12.288752794265747,11.854221026102701,11.419663111368815,10.985265334447226,10.550337473551432,10.23361849784851,10.048517942428589,9.875380277633667,9.702491919199625,9.530128320058187,9.357440312703451,9.185004631678263,9.012371182441711,8.839990655581156,8.667080799738565,8.567718307177225,8.550435582796732,8.540162563323975,8.530437390009562,8.520747900009155,8.511067708333334,8.50138771533966,8.491707881291708,8.482027570406595,8.472347855567932,8.462657809257507,8.452977697054544,8.443297783533732,8.433617750803629,8.423937718073526,8.414257764816284,8.404577732086182,8.394897858301798,8.385217746098837,8.375537633895874,8.36585783958435,8.356177767117819,8.346497813860575,8.336817781130472,8.327137986818949,8.317447821299234,8.307767788569132,8.29808775583903,8.288407802581787,8.278727769851685,8.269047816594442,8.259367823600769,8.249687751134237,8.240007797876993,8.23032776514689,8.220647851626078,8.210957964261373,8.201277812321981,8.191597819328308,8.181917866071066,8.172237833340963,8.16255780061086,8.152877807617188,8.143197814623514,8.133517742156982,8.12383790810903,8.114157875378927,8.104477683703104,8.094797929128012,8.085107882817587,8.075427730878195,8.06574777762095,8.056067864100138,8.046387751897177,8.036707878112793,8.02702784538269,8.017347971598307,8.007667779922485,7.997987826665242,7.988308032353719,7.978617986043294,7.968937873840332,7.95925788084666,7.949577887852986,7.939897894859314,7.930217862129211,7.920537869135539,7.910857955614726,7.901177883148193,7.891497890154521,7.881817976633708,7.872137864430745,7.862457950909932,7.852767984072368,7.843087712923686,7.833407918612163,7.82372788588206,7.814047892888387,7.804367899894714,7.794687906901042,7.785007874170939,7.775327920913696,7.765647888183594,7.755967895189921,7.746287902196248,7.7366078694661455,7.72691810131073,7.717237909634908,7.707558035850525,7.697877883911133,7.68819797039032,7.678517858187358,7.668837904930115,7.659157951672872,7.64947787920634,7.639797925949097,7.630117932955424,7.620438019434611,7.610748012860616,7.601067900657654,7.591387907663981,7.581707994143168,7.572027842203776,7.562347928682963,7.552667856216431,7.542988061904907,7.533307949701945,7.523628036181132,7.51394780476888,7.504268089930217,7.494578123092651,7.4848978916804,7.475217898686727,7.465537985165914,7.455857912699382,7.446177879969279,7.436497926712036,7.426818013191223,7.417137900988261,7.407457947731018,7.3977779150009155,7.388098120689392,7.378407955169678,7.368727962176005,7.359047889709473,7.34936801592509,7.339687943458557,7.330007910728455,7.320327917734782,7.310648004213969,7.3009679317474365,7.2912880182266235,7.281607985496521,7.2719279527664185,7.2622478405634565,7.252568085988362,7.242877999941508,7.233197927474976,7.223518013954163,7.213837901751201,7.204157988230388,7.194477955500285,7.184798002243042,7.17511800924937,7.165438095728557,7.155757665634155,7.146078785260518,7.136395692825317,7.126714666684468,7.11700979868571,7.111697514851888,7.111233909924825,7.111201286315918,7.1111979484558105,7.1111992200215655,7.111198743184407,7.1111990213394165,7.1111988226572675,7.111198941866557,7.111198862393697,7.111198941866557,7.111198862393697,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.667515595753987,6.8842053810755415,6.581218043963115,6.571952025095622,6.562195936838786,6.552964687347412,6.544347643852234,6.5470802783966064,6.563832084337871,6.584262092908223,6.605442444483439,6.626572807629903,6.647443254788716,6.667973438898723,6.688194036483765,6.708093881607056,6.727695306142171,6.744607210159302,6.758086999257405,6.7703473170598345,6.782037456830342,6.7933376232783,6.804337819417317,6.815057913462321,6.825528224309285,6.835758248964946,6.84575875600179,6.854569514592488,6.861859480539958,6.868469715118408,6.8746598561604815,6.880529920260112,6.886130054791768,6.891470154126485,6.896580338478088,6.901479959487915,6.906201203664144,6.908452749252319,6.907572507858276,6.905622601509094,6.903222560882568,6.900572578112285,6.8977426290512085,6.894752462704976,6.891632556915283,6.888382315635681,6.8850330511728925,6.880203763643901,6.873453696568807,6.866023580233256,6.858263452847798,6.850313464800517,6.842203338940938,6.833973288536072,6.82563320795695,6.817192951838176,6.808653434117635,6.798834005991618,6.787363886833191,6.775293747584025,6.762963612874349,6.750463406244914,6.737863262494405,6.7251730759938555,6.712392886479695,6.699562907218933,6.686692078908284,6.675231059392293,6.665600935618083,6.65648086865743,6.647470672925313,6.638480703035991,6.629480441411336,6.62047032515208,6.61145023504893,6.60243018468221,6.593419988950093,6.58450984954834,6.575729648272197,6.567039608955383,6.558409372965495,6.549839337666829,6.5413291454315186,6.532879034678142,6.524488925933838,6.516148686408997,6.507858872413635,6.4989893436431885,6.48927903175354,6.479318976402283,6.46924889087677,6.45914888381958,6.449008742968242,6.438848535219829,6.428678472836812,6.4184984763463335,6.408298333485921,6.398088177045186,6.387878139813741,6.377658009529114,6.367437879244487,6.357207894325256,6.346987724304199,6.336767673492432,6.3265475034713745,6.316337426503499,6.3061273495356245,6.295917232831319,6.2857271035512285,6.275536974271138,6.265366951624553,6.255196809768677,6.245036641756694,6.234896580378215,6.224766453107198,6.214646379152934,6.204546252886455,6.194456100463867,6.184386054674785,6.1743260224660235,6.164275844891866,6.154245773951213,6.144235650698344,6.13424551486969,6.124265432357788,6.114305337270101,6.104365229606628,6.094435056050618,6.084524949391683,6.074634869893392,6.064754684766133,6.0549046993255615,6.045064489046733,6.035244504610698,6.025444388389587,6.015664180119832,6.005894144376119,5.9961540301640825,5.986423929532369,5.97671377658844,5.967023690541585,5.957343578338623,5.947693427403768,5.938063343365987,5.928443272908528,5.918853084246318,5.909273028373718,5.899712920188904,5.890182892481486,5.880662679672241,5.87116265296936,5.861682454744975,5.852222402890523,5.842782298723857,5.833352168401082,5.823952118555705,5.81456200281779,5.805201888084412,5.795851747194926,5.786521673202515,5.777211546897888,5.767921408017476,5.758641322453816,5.749391237894694,5.740151127179463,5.730931003888448,5.721720894177754,5.712540785471599,5.703370650609334,5.694220622380574,5.68509046236674,5.675970355669658,5.666880249977112,5.657800157864888,5.6487299998601275,5.639689962069194,5.630659858385722,5.621639728546143,5.61264963944753,5.60366956392924,5.594699382781982,5.585749228795369,5.576819141705831,5.567899028460185,5.558998982111613,5.550108909606934,5.541248718897502,5.53238860766093,5.523558537165324,5.514728387196858,5.505918264389038,5.497128168741862,5.48835813999176,5.479587992032369,5.4708378712336225,5.46210781733195,5.45338761806488,5.444687565167745,5.4359974066416425,5.4273273547490435,5.418667316436768,5.410017132759094,5.401387055714925,5.392766992251079,5.384166836738586,5.3755766948064165,5.366996645927429,5.358436504999797,5.349886337916057,5.341346303621928,5.332826137542725,5.324316064516704,5.315825939178467,5.307345827420552,5.298875729242961,5.29041572411855,5.281965573628743,5.273535490036011,5.26511538028717,5.256715297698975,5.248315135637919,5.239935040473938,5.231564998626709,5.223214864730835,5.214864691098531,5.206534663836162,5.198214491208394,5.189904451370239,5.181604345639546,5.173314174016316,5.165044029553731,5.156784017880757,5.148533860842387,5.1402937571207685,5.132063547770183,5.123843828837077,5.115642507870992,5.109830975532532,5.107091228167216,5.10529100894928,5.1038410266240435,5.1025610367457075,5.1014009316762285,5.100340962409973,5.099360903104146,5.0984708070755005,5.09765084584554,5.096900820732117,5.096210797627767,5.095580816268921,5.095000783602397,5.094470659891765,5.09398078918457,5.093540787696838,5.093140761057536,5.09277065594991,5.0924307107925415,5.09212068716685,5.091840744018555,5.0915907224019366,5.091360688209534,5.091150681177775,5.090960661570231,5.090790669123332,5.090630610783895,5.090500712394714,5.0903706550598145,5.090260624885559,5.090170661608378,5.0900806585947675,5.090000629425049,5.089940667152405,5.089880704879761,5.08983067671458,5.08979058265686,5.089750647544861,5.089720606803894,5.08970061937968,5.089680631955464,5.089670658111572,5.08966064453125,5.089660565058391,5.08966060479482,5.089670618375142,5.089680631955464,5.089690605799357,5.089700659116109,5.089720646540324,5.089740594228108,5.089760621388753,5.08979054292043,5.089810609817505,5.089840571085612,5.089870611826579,5.089900573094686,5.089940547943115,5.089970588684082,5.090010563532512,5.0900406042734785,5.090080499649048,5.090120593706767,5.090160568555196,5.090210517247518,5.090250571568807,5.090290546417236,5.090340614318848,5.090380628903707,5.090430537859599,5.09048060576121,5.09052054087321,5.090570608774821,5.090620597203572,5.090670625368754,5.090720574061076,5.090770602226257,5.090820550918579,5.09087061882019,5.0909305810928345,5.090980569521586,5.091030597686768,5.0910805861155195,5.091140627861023,5.091190576553345,5.091250578562419,5.09130056699117,5.091360529263814,5.091420531272888,5.09147063891093,5.0915305614471436,5.091590642929077,5.091640591621399,5.091700553894043,5.091760595639546,5.091820518175761,5.091880559921265,5.0919404824574785,5.092000603675842,5.092060565948486,5.09212052822113,5.092180649439494,5.092240571975708,5.092300534248352,5.092360655466716,5.09242061773936,5.092490593592326,5.09255051612854,5.092610597610474,5.092670599619548,5.092740575472514,5.092800577481587,5.092870593070984,5.092930555343628,5.092990517616272,5.093060572942098,5.093120535214742,5.093190550804138,5.0932605266571045,5.093320568402608,5.093390583992004,5.093450625737508,5.093520601590474,5.0935905774434405,5.093650579452515,5.093720555305481,5.093790531158447,5.093860626220703,5.093930602073669,5.093990604082744,5.094060619672139,5.0941305955251055,5.094200571378072,5.094270547231038,5.094340602556865,5.094410498936971,5.094480593999227,5.094550530115764,5.0946206251780195,5.0946905215581255,5.094760497411092,5.094830632209778,5.094900608062744,5.094980597496033,5.095050533612569,5.095120549201965,5.095190684000651,5.095260580380757,5.095340569814046,5.095410585403442,5.095480600992839,5.095560630162557,5.095630566279094,5.095700581868489,5.095780571301778,5.095850586891174,5.095930616060893,5.096000671386719,5.096080541610718,5.0961505969365435,5.096230626106262,5.096300522486369,5.096380551656087,5.0964506069819135,5.096530636151631,5.096600572268168,5.096680521965027,5.096760511398315,5.096830526987712,5.09691059589386,5.096990585327148,5.097060561180115,5.097140550613403,5.0972206592559814,5.097290515899658,5.097370584805806,5.097450574239095,5.097530563672383,5.097610632578532,5.097680568695068,5.097760558128357,5.097840587298076,5.0979206164677935,5.098000566164653,5.098080515861511,5.098160584767659,5.098230520884196,5.098310669263204,5.098390579223633,5.098470568656921,5.09855059782664,5.098630587259929,5.098710656166077,5.098790605862935,5.098870555559794,5.098950624465942,5.0990305344263716,5.0991106033325195,5.09920060634613,5.099280595779419,5.099360545476277,5.099440534909566,5.099520603815715,5.099600593249003,5.099680622418721,5.09976061185201,5.099850614865621,5.099930604298909,5.100010593732198,5.100090583165486,5.100170612335205,5.100250601768494,5.100340684254964,5.100420594215393,5.100500583648682,5.10058053334554,5.100670615832011,5.10075056552887,5.100830594698588,5.100920597712199,5.101000666618347,5.101080576578776,5.101160605748494,5.101250569025676,5.101330637931824,5.1014106671015425,5.101500590642293,5.101580619812012,5.10166056950887,5.101750572522481,5.10183056195577,5.101910630861918,5.102000594139099,5.1020805438359575,5.102170666058858,5.1022506554921465,5.102330605189006,5.1024205684661865,5.102500597635905,5.102590640385945,5.1026705503463745,5.102750579516093,5.102840582529704,5.102920611699422,5.103010535240173,5.103090524673462,5.103180607159932,5.103220621744792};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219187219937644,2.603925089041392,2.0366091827551522,1.6560320754845936,1.3475098013877869,1.0969156473875046,0.893561323483785,0.7282202343146006,0.5937187423308691,0.4842059488097827,0.3950214684009552,0.32235416521628696,0.2631244696676731,0.21482997139294943,0.1754391441742579,0.14329909905791283,0.11707025890549023,0.09566589382787545,0.07820618400971095,0.0639494772379597,0.05231574239830176,0.04280199762433767,0.03503945004194975,0.028671848122030497,0.023470758150021236,0.019207043418039877,0.015730623931934435,0.012879783210034171,0.010553861657778421,0.008647082295889655,0.007088733953423798,0.005811529234051704,0.004766169081752499,0.003909432406847675,0.00320749778378134,0.002632072486449033,0.0021603107064341507,0.0017733952457395692,0.001455975715847065,0.0011955204148155947,0.0009817705140449107,0.0008063387407067543,0.0006622910004807636,0.0005440714060872173,0.0004469311364421931,0.0003672417005873285,0.00030169112627239275,0.00024795956172359485,0.0002037144440691918,0.00016746534674894065,0.00013759803368884604,0.000113122123972668,2.578195138388158e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8638407389323,563.020273844401,557.0958353678385,556.9293924967448,555.6556142171224,554.076161702474,552.4449055989584,551.8312072753906,552.5509948730469,553.6725514729818,554.8954366048177,556.1234944661459,557.3265838623047,558.4957021077474,559.6297658284506,560.7289479573568,561.7948506673177,562.9703114827474,564.3000691731771,565.6551055908203,566.9961700439453,568.3112538655599,569.5993448893229,570.8584136962891,572.0915018717448,573.2985382080078,574.482676188151,575.5830383300781,576.572275797526,577.5014088948568,578.3885192871094,579.2416025797526,580.0647023518881,580.8597513834635,581.6308746337891,582.3797861735026,583.1082763671875,583.4818216959635,583.3817799886068,583.1069793701172,582.7601521809896,582.3762156168619,581.9682871500651,581.5423227945963,581.1003875732422,580.6443735758463,580.1765747070312,579.5552317301432,578.7286732991537,577.8177897135416,576.8668874104818,575.8919321695963,574.8989919026693,573.8910217285156,572.8710581461588,571.8390808105469,570.7981669108073,569.6874593098959,568.4876658121744,567.2447306315104,565.9787902832031,564.6968231201172,563.4018503824869,562.0968882242838,560.7838999430338,559.4629465738932,558.1378072102865,556.9631195068359,555.990712483724,555.0846913655599,554.1976267496744,553.3156534830729,552.4336242675781,551.5506388346354,550.6666361490885,549.7826385498047,548.8986256917318,548.0245869954427,547.1615651448568,546.3075408935547,545.4605204264323,544.6204986572266,543.7854817708334,542.9574584960938,542.1354471842448,541.3194274902344,540.5094045003256,539.7173258463541,538.9442952473959,538.175303141276,537.4052988688151,536.633310953776,535.8593241373698,535.0833282470703,534.3053334554037,533.5253346761068,532.7443440755209,531.9623463948568,531.1793314615885,530.3963368733724,529.6123453776041,528.8273366292318,528.0433502197266,527.2593383789062,526.475351969401,525.6913426717123,524.9073384602865,524.1253407796224,523.3433278401693,522.5613352457682,521.7813313802084,521.0023320515951,520.2243270874023,519.4473215738932,518.6713180541992,517.8973083496094,517.1243082682291,516.3523076375326,515.5822931925455,514.8143005371094,514.0462900797526,513.2812881469727,512.5172805786133,511.7552769978841,510.9952672322591,510.23626200358075,509.48026275634766,508.72525787353516,507.97124735514325,507.2202453613281,506.4702402750651,505.72222900390625,504.9762217203776,504.23222096761066,503.4902165730794,502.75021107991535,502.0111999511719,501.2751998901367,500.54019419352215,499.8071873982747,499.07618459065753,498.34718068440753,497.62017313639325,496.8951695760091,496.1721674601237,495.45115661621094,494.73214467366535,494.015141805013,493.29913838704425,492.5861307779948,491.87512461344403,491.16612243652344,490.45911661783856,489.7531102498372,489.0501022338867,488.34810129801434,487.6490885416667,486.9510904947917,486.2560755411784,485.56207784016925,484.8700714111328,484.18006896972656,483.49205525716144,482.8060531616211,482.1210479736328,481.4390385945638,480.75804138183594,480.0790252685547,479.40202077229816,478.7270202636719,478.0540135701497,477.3820114135742,476.71200307210285,476.0439987182617,475.3769938151042,474.7129872639974,474.04998779296875,473.38798268636066,472.72897084554035,472.0709762573242,471.41496022542316,470.7599639892578,470.1069564819336,469.45595296223956,468.80594635009766,468.15793863932294,467.5119323730469,466.86693064371747,466.22292073567706,465.58191680908203,464.9419199625651,464.30291239420575,463.66590627034503,463.0299021402995,462.3958994547526,461.76389567057294,461.1328887939453,460.5038833618164,459.8758824666341,459.24888102213544,458.6238708496094,458.0008595784505,457.3788604736328,456.75785573323566,456.1388575236003,455.52085367838544,454.9038492838542,454.2888412475586,453.6758397420247,453.06383514404297,452.4528299967448,451.8428268432617,451.23482513427734,450.62781524658203,450.02281697591144,449.41881052652997,448.81580861409503,448.2138036092122,447.6137975056966,447.0147933959961,446.41679128011066,445.82078552246094,445.2257843017578,444.63177998860675,444.0387700398763,443.4477717081706,442.8567708333333,442.2677637736003,441.67976633707684,441.09376017252606,440.50775655110675,439.9237518310547,439.3407516479492,438.75875091552734,438.17772420247394,437.5987854003906,437.0205993652344,436.5799967447917,436.3236338297526,436.13455454508465,435.97547149658203,435.83443959554035,435.7063980102539,435.58936818440753,435.4823455810547,435.3833185831706,435.2932993570964,435.2102737426758,435.1342519124349,435.0642395019531,435.0002161661784,434.9422098795573,434.88819376627606,434.8391749064128,434.795171101888,434.75415802001953,434.71714274088544,434.6831410725911,434.6521275838216,434.6241226196289,434.59811147054035,434.5751037597656,434.5541051228841,434.53510030110675,434.5180892944336,434.50308990478516,434.48907979329425,434.4770762125651,434.46607971191406,434.45606740315753,434.44806416829425,434.4400685628255,434.43406168619794,434.42806243896484,434.42405192057294,434.42005411783856,434.41605377197266,434.41404978434247,434.4120508829753,434.41004689534503,434.40904998779297,434.40904235839844,434.40904235839844,434.40904235839844,434.41004435221356,434.41104380289715,434.4130401611328,434.41503651936847,434.41703542073566,434.4190368652344,434.42103576660156,434.42403411865234,434.42704010009766,434.4300282796224,434.4340337117513,434.43703206380206,434.44103240966797,434.44503021240234,434.4490331013997,434.4530309041341,434.457026163737,434.46203358968097,434.46602630615234,434.47103118896484,434.4750289916992,434.4800338745117,434.4850336710612,434.49002329508465,434.49502817789715,434.5000228881836,434.5050303141276,434.51002248128253,434.5160268147786,434.52102915445965,434.5260314941406,434.53202565511066,434.5370229085286,434.54302469889325,434.54902903238934,434.5540262858073,434.56002553304035,434.56602478027344,434.572026570638,434.5780258178711,434.5840326944987,434.59002176920575,434.59602610270184,434.60203043619794,434.6080271402995,434.61402384440106,434.6200256347656,434.6260248819987,434.63302357991535,434.6390329996745,434.645024617513,434.6520309448242,434.6580225626628,434.66502634684247,434.6710255940755,434.67802174886066,434.68402608235675,434.69102732340497,434.697026570638,434.7040201822917,434.71102650960285,434.71702829996747,434.7240295410156,434.7310256958008,434.7380193074544,434.7450307210286,434.7510274251302,434.7580210367839,434.76502482096356,434.7720260620117,434.7790222167969,434.78602345784503,434.79302469889325,434.8000259399414,434.80802154541016,434.81502024332684,434.82201894124347,434.82902272542316,434.83602142333984,434.8440221150716,434.8510208129883,434.85801951090497,434.8650207519531,434.8730189005534,434.88002522786456,434.88802337646484,434.89502207438153,434.90302022298175,434.91002655029297,434.9180170694987,434.9250233968099,434.93301645914715,434.9400227864583,434.9480158487956,434.95502217610675,434.96301523844403,434.97102610270184,434.97901916503906,434.9860254923503,434.99401601155597,435.0020217895508,435.01002502441406,435.0170211791992,435.0250193277995,435.03301493326825,435.04101816813153,435.0490214029948,435.05702209472656,435.06502024332684,435.0730209350586,435.0810241699219,435.08902231852215,435.0970204671224,435.10501352945965,435.1130193074544,435.1210225423177,435.12902577718097,435.1370162963867,435.1460215250651,435.1540222167969,435.1620178222656,435.17002360026044,435.1780141194661,435.187016805013,435.1950225830078,435.20301564534503,435.2120183308919,435.2200215657552,435.22801971435547,435.2370198567708,435.2450256347656,435.2530161539714,435.26202392578125,435.27002207438153,435.2790247599284,435.28702036539715,435.29602305094403,435.3040135701497,435.3130187988281,435.3210220336914,435.3300196329753,435.3380126953125,435.3470179239909,435.35502370198566,435.364013671875,435.3730189005534,435.38101959228516,435.39001719156903,435.3980229695638,435.40702056884766,435.41601816813153,435.4240137736003,435.43301645914715,435.4420166015625,435.45101674397785,435.45902252197266,435.46801503499347,435.47701772054035,435.4860204060872,435.4940236409505,435.5030161539714,435.51201883951825,435.5210240681966,435.53001912434894,435.53901926676434,435.5470225016276,435.55601755777997,435.5650177001953,435.57401784261066,435.58301798502606,435.5920155843099,435.6010208129883,435.6100209554036,435.6190236409505,435.6280161539714,435.6370162963867,435.64501698811847,435.6540171305339,435.6630172729492,435.6720148722331,435.68101755777997,435.6900151570638,435.6990229288737,435.70801798502606,435.7170155843099,435.7260157267253,435.73501841227215,435.7450129191081,435.75401814778644,435.7630157470703,435.7720235188802,435.78101603190106,435.79001871744794,435.79901631673175,435.80802154541016,435.8170166015625,435.8260218302409,435.8350143432617,435.8440221150716,435.85301717122394,435.86301676432294,435.8670399983724};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.435959974924723,9.763131380081177,10.082969109217325,9.098511934280396,9.042668263117472,8.99225083986918,8.941473642985025,8.932788689931234,8.969672838846842,9.010390996932983,9.051398595174154,9.092438777287802,9.133479356765747,9.17451810836792,9.215560833613077,9.256595611572266,9.297644774119059,9.326130310694376,9.340963204701742,9.354640007019043,9.36824138959249,9.381820996602377,9.395411173502604,9.408990701039633,9.422581593195597,9.436159690221151,9.449753443400065,9.457982699076334,9.460392951965332,9.462311029434204,9.464201847712198,9.466071685155233,9.467951854070028,9.469831307729086,9.471712191899618,9.47359045346578,9.47547427813212,9.470539013544718,9.45817263921102,9.445189714431763,9.432151079177856,9.41912055015564,9.406080722808838,9.393040498097738,9.380000750223795,9.36696990331014,9.35393238067627,9.336059967676798,9.312939882278442,9.289377371470133,9.265778621037802,9.242178042729696,9.218578418095907,9.194968144098917,9.171368281046549,9.147767623265585,9.12416966756185,9.094781398773193,9.059093316396078,9.022879918416342,8.986631870269775,8.950370788574219,8.914111375808716,8.877850850423178,8.841590960820517,8.805341402689615,8.769079605738321,8.738876263300577,8.715274175008139,8.692217826843262,8.669205268224081,8.646196683247885,8.62319572766622,8.600186506907145,8.577175935109457,8.554176171620687,8.531165838241577,8.509042580922445,8.487870693206787,8.466791152954102,8.445710817972818,8.424631118774414,8.403550942738852,8.382471005121866,8.361390948295593,8.340311169624329,8.319230596224466,8.299017151196798,8.279745856920878,8.260555903116861,8.241376002629599,8.222195903460184,8.20301608244578,8.183835943539938,8.164645870526632,8.145465930302938,8.126285791397095,8.10710589090983,8.087915857632956,8.068735758463541,8.049555579821268,8.030375838279724,8.011185805002848,7.9920057853062945,7.972825686136882,7.953645666440328,7.934455752372742,7.915275613466899,7.896095712979634,7.876915733019511,7.857725699742635,7.838545600573222,7.819365660349528,7.800185600916545,7.780995726585388,7.761815627415975,7.742635567982991,7.723455588022868,7.704275608062744,7.685085455576579,7.665905475616455,7.646725535392761,7.627545515696208,7.608355561892192,7.5891755024592085,7.569995443026225,7.550815463066101,7.531625509262085,7.512445330619812,7.493265390396118,7.474085330963135,7.454895377159119,7.435715357462565,7.416535377502441,7.397355318069458,7.378165404001872,7.358985265096028,7.339805285135905,7.320625305175781,7.301435271898906,7.282255252202352,7.2630752722422285,7.243895252545674,7.224705219268799,7.205525159835815,7.186345219612122,7.167165199915568,7.147985180219014,7.1287951072057085,7.109615127245585,7.090435147285461,7.071255127588908,7.052065213521321,7.032885114351909,7.013705054918925,6.994525114695231,6.975335041681926,6.956155021985372,6.936975081761678,6.917794982592265,6.898605028788249,6.8794249296188354,6.860244989395142,6.841064929962158,6.821875015894572,6.802694916725159,6.783514897028605,6.764334877332051,6.745144883791606,6.725964864095052,6.7067848443984985,6.687604904174805,6.668424844741821,6.649234851201375,6.630054791768392,6.610874851544698,6.591694792111714,6.572504758834839,6.553324739138286,6.534144759178162,6.514964739481608,6.4957748254140215,6.476594646771749,6.457414746284485,6.438234647115071,6.419044613838196,6.399864713350932,6.3806846141815186,6.361504634221395,6.342324614524841,6.323134581247966,6.303954521814982,6.284774541854858,6.265584588050842,6.246404528617859,6.2272244691848755,6.2080444892247515,6.188864509264628,6.169674515724182,6.150494535764058,6.1313144365946455,6.112134496370952,6.092944502830505,6.073764403661092,6.054584344228108,6.035404364267985,6.016214370727539,5.997034351030986,5.977854371070862,5.958674311637878,5.939484357833862,5.920304298400879,5.901124318440755,5.881944338480632,5.862754384676616,5.843574245770772,5.824394265810649,5.805214246114095,5.786024252573649,5.766844113667806,5.747664173444112,5.728484153747559,5.709294239679973,5.690114140510559,5.670934120814006,5.651754061381022,5.632574081420898,5.613384087880452,5.594204107920329,5.575024048487346,5.555843949317932,5.536654154459636,5.517473936080933,5.498294234275818,5.479113419850667,5.459925532341003,5.440740505854289,5.430328845977783,5.4294612010320025,5.4293950001398725,5.4293932517369585,5.429383993148804,5.4293837149937945,5.429383754730225,5.429383794466655,5.429383834203084,5.429383754730225,5.429383794466655,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.22537136077881,24.52680730819702,24.887106895446777,25.253907362620037,25.64010715484619,26.04190715154012,26.455807367960613,26.84280761082967,27.169407685597736,27.44310728708903,27.670207341512043,27.85660696029663,27.971706867218018,27.98970635732015,27.925206343332928,27.79090627034505,27.598005771636963,27.32420555750529,26.951005458831787,26.495305061340332,25.971904754638672,25.393704573313396,24.77190415064494,24.11630407969157,23.43540382385254,22.73650376001994,22.02600320180257,21.30720313390096,20.58280324935913,19.85730282465617,19.134703000386555,18.4182022412618,17.710602442423504,17.01420243581136,16.3311022122701,15.66280198097229,15.010501861572266,14.375301996866861,13.757601896921793,13.158301750818888,12.577601432800293,12.015801588694254,11.473201354344686,10.94960125287374,10.445101340611776,9.959541161855062,9.492621024449667,9.044100999832153,8.613660971323648,8.200880924860636,7.805310845375061,7.426500876744588,7.063960870107015,6.71721072991689,6.3857507308324175,6.069080630938212,5.766690651575725,5.47821060816447,5.203230500221252,4.941190441449483,4.691570480664571,4.453840494155884,4.227500478426616,4.012070437272389,3.8070703744888306,3.6120604276657104,3.426600376764933,3.25020037094752,3.0824203491210938,2.9228802919387817,2.7712102929751077,2.6270702481269836,2.4901202917099,2.360030253728231,2.236480236053467,2.1191702286402383,2.007810195287069,1.9021101991335552,1.8017801741758983,1.7065801819165547,1.6162601709365845,1.5305801729361217,1.449340134859085,1.3723001380761464,1.2992801368236542,1.2300601502259572,1.1666501363118489,1.1098901530106862,1.0582301219304402,1.0111801226933796,0.968299130598704,0.9291741400957108,0.8934431225061417,0.8607771346966425,0.8308761318524679,0.8034741332133611,0.7783271272977194,0.755216121673584,0.7339441130558649,0.7143311301867167,0.6962161213159561,0.679451122879982,0.6639061272144318,0.6494641254345576,0.6360161254803339,0.6234671225150427,0.6117281218369802,0.6007201224565506,0.5903711219628652,0.5806181182463964,0.5714041193326315,0.5626771152019501,0.5543881158034006,0.546497106552124,0.5389631142218908,0.5317511061827341,0.5248321145772934,0.5181781103213629,0.5117631008227667,0.5055641035238901,0.4995611036817233,0.49373510479927063,0.4880671054124832,0.48254510511954624,0.47715509682893753,0.4718841016292572,0.4667221009731293,0.4616560985644658,0.4566790983080864,0.4517851024866104,0.4469641000032425,0.4422110964854558,0.437520091732343,0.4328860988219579,0.42830009510119754,0.4237620880206426,0.41926809151967365,0.4148130888740222,0.4103950932621956,0.40601108968257904,0.4016580854852994,0.3973320871591568,0.3930320863922437,0.3887580831845601,0.38450708240270615,0.380278080701828,0.3760690813263257,0.37187908589839935,0.3677040785551071,0.36354708174864453,0.3594060813387235,0.3552800764640172,0.35116807868083316,0.3470700780550639,0.34298507620890933,0.3389100730419159,0.3348480736215909,0.33079707125822705,0.3267570734024048,0.322727066775163,0.3187080721060435,0.31469907114903134,0.3106970687707265,0.3067050650715828,0.302722064157327,0.29874806106090546,0.2947820673386256,0.2908250615000725,0.2868760625521342,0.2829330563545227,0.2789980595310529,0.27507105966409046,0.27115105589230853,0.2672390565276146,0.2633340582251549,0.25943705439567566,0.255544051527977,0.251658050964276,0.24777905394633612,0.24390705302357674,0.2400420494377613,0.236183051019907,0.23233105118076006,0.22848304733633995,0.22464104741811752,0.22080604607860246,0.21697704369823137,0.21315404524405798,0.20933704326550165,0.20552604148785272,0.20171804105242094,0.19791604081789652,0.19412003830075264,0.19033004095156988,0.18654603883624077,0.1827670360604922,0.17899303510785103,0.175222035497427,0.17145703608791033,0.16769803191224733,0.16394403080145517,0.160194031894207,0.15644803022344908,0.15270703037579855,0.14897102986772856,0.1452410283188025,0.14151502400636673,0.1377940240005652,0.13407702619830766,0.13036402314901352,0.12665502230326334,0.12295102203885715,0.11925102273623149,0.11555601904789607,0.1118660190453132,0.10818001876274745,0.10449601834019025,0.10081601763765018,0.09714151546359062,0.09347071560720603,0.08980431345601876,0.08614191226661205,0.08248361200094223,0.07882711105048656,0.07517481036484241,0.07152650815745194,0.06788220877448718,0.06424180728693803,0.060605306488772236,0.056972505524754524,0.053341105269889035,0.049713703182836376,0.04608990220973889,0.04246990165362755,0.038853500969707966,0.035240600196023784,0.031631200263897576,0.028216199949383736,0.02516819986825188,0.02244800003245473,0.020020800021787483,0.017854999750852585,0.01592279993928969,0.014199100046729049,0.012661400018259883,0.011289899935945868,0.010066600050777197,0.008975570012504855,0.008002560042465726,0.007134839969997604,0.006361059960909188,0.005671080046643813,0.005055829960231979,0.004507250036112964,0.0040181300331217544,0.0035820299914727607,0.003193219987830768,0.0028465800375367203,0.0025375400437042117,0.002262029971461743,0.002016410008460904,0.0017974399961531162,0.0016022500155183177,0.0014282399982524414,0.0012731200161700447,0.0011348399954537551,0.0010115699988091365,0.0009016940020956099,0.0008037470009488364,0.0007164369890233502,0.000638608995359391,0.0005692349999056509,0.0005073959958584359,0.00045227400308552507,0.00040313900050629553,0.0003593419993800732,0.0003203029991709627,0.00028550499458409223,0.0002544880020044123,0.00022684000092946613,0.00020219499977732389,0.000180227999711254,0.0001606479988064772,0.0001431949992062679,0.0001276379995639824,0.00011377200159283045,6.0569516184235304e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050126552581787,22.259799003601074,22.13089911142985,22.13499879837036,22.1134991645813,22.071499188741047,22.01349925994873,21.924899101257324,21.79349931081136,21.627499103546143,21.4336994489034,21.218299706776936,20.965399583180744,20.662299156188965,20.319299697875977,19.94539960225423,19.54819981257121,19.11489963531494,18.635399500528973,18.120299975077312,17.579099655151367,17.01949993769328,16.448399861653645,15.871299823125204,15.2928999265035,14.717099905014038,14.147299925486246,13.58459989229838,13.02999989191691,12.48580002784729,11.95359992980957,11.434799830118815,10.93049987157186,10.441399971644083,9.968129952748617,9.510999838511148,9.070219993591309,8.64581004778544,8.237669865290323,7.845659971237183,7.46956996122996,7.109089930852254,6.763919989267985,6.433659950892131,6.117909908294678,5.8162299791971845,5.528199950853984,5.253359953562419,4.991249958674113,4.741379976272583,4.503300031026204,4.276529947916667,4.0606099764506025,3.855090002218882,3.6595199704170227,3.473479986190796,3.2965500156084695,3.128370006879171,2.9685699939727783,2.816770017147064,2.6725800236066184,2.535629987716675,2.405589997768402,2.282119949658712,2.164909998575846,2.05362997452418,1.9480199913183849,1.8477700054645538,1.7525899906953175,1.6622500121593475,1.5764999985694885,1.495119978984197,1.4178999761740367,1.3446100056171417,1.2750800053278606,1.2090999980767567,1.1465100049972534,1.0871300101280212,1.0307999849319458,0.9773529917001724,0.9266569962104162,0.8785680085420609,0.8329549978176752,0.7896959980328878,0.7486729969580969,0.7097739974657694,0.6734399944543839,0.6395259946584702,0.6073460032542547,0.5768129974603653,0.5478390008211136,0.520346999168396,0.4942619999249776,0.46951399991909665,0.44603200008471805,0.4237539991736412,0.40261999766031903,0.38256699591875076,0.3635439972082774,0.3454990014433861,0.32837799688180286,0.31213600436846417,0.2967279975612958,0.28211400161186856,0.2682490025957425,0.25509800016880035,0.24262499809265137,0.23079099878668785,0.219565998762846,0.20891900236407915,0.19882100075483322,0.18924100076158842,0.18015499785542488,0.1715380015472571,0.1633629985153675,0.15560999885201454,0.14825699850916862,0.14128099754452705,0.13466199859976768,0.12838399906953177,0.12242999921242396,0.1167809988061587,0.11142199921111266,0.10633899892369907,0.1015160009264946,0.09693819905320804,0.09259569831192493,0.08847619965672493,0.08456579906245072,0.08085570049782594,0.07733569915095966,0.0739931979527076,0.07081919970611732,0.06780699950953324,0.06494819931685925,0.06223239873846372,0.05965439944217602,0.05720699951052666,0.054880899687608085,0.05267209901163975,0.050574399841328464,0.04857960001875957,0.04668219915280739,0.044879499512414135,0.043166499895354114,0.04153599931548039,0.03998599915454785,0.038512200117111206,0.03710829932242632,0.035770599730312824,0.03449779966225227,0.0332866000632445,0.03213120003541311,0.031031099148094654,0.029983399746318657,0.028982799500226974,0.02802920000006755,0.027120099558184545,0.026250799652189016,0.025419199684013922,0.024625499732792377,0.023867699628074963,0.023141699532667797,0.022447899760057528,0.02178479948391517,0.02114829948792855,0.02053689956665039,0.019951699456820886,0.019391199729094904,0.01885189985235532,0.018334899563342333,0.01783889966706435,0.01736059971153736,0.01690130013351639,0.01645999976123373,0.01603339969490965,0.015620599733665586,0.015223399658376971,0.014840799694259962,0.014469699701294303,0.014111899693186084,0.013766599741453925,0.01343089978521069,0.013104099547490478,0.012788199664403995,0.012482599820941687,0.012184299761429429,0.011895399695883194,0.011615399892131487,0.011341299706449112,0.011075199659292897,0.010816799787183603,0.010563199796403447,0.010314199763039747,0.010071899897108475,0.0098359197533379,0.009603579839070639,0.009377049747854471,0.009156009803215662,0.008937809926768145,0.008722309721633792,0.008511719837163886,0.008305779891088605,0.008101879929502806,0.007902279884244004,0.007706739862139027,0.0075126998126506805,0.0073200798748681946,0.007131159887649119,0.0069457498999933405,0.006761299873081346,0.006580129847861826,0.006402059885052343,0.006224579915093879,0.006049999928412338,0.00587817991618067,0.005706619898167749,0.005535319913178682,0.005366609936269621,0.005200369943243762,0.005034099953869979,0.004870179962987701,0.004708470000574986,0.004546509900440772,0.00438432985295852,0.004224279973035057,0.004066269922380646,0.003907829930540174,0.0037513499652656415,0.003596719955870261,0.0034414899613087377,0.0032880599804533026,0.0031363299543348453,0.002983859992430856,0.002830699998109291,0.002679250028450042,0.002529419977994015,0.002383449987974018,0.002245829983924826,0.002116070012561977,0.0019937599912130586,0.0018784600057794403,0.0017697799970240642,0.0016673499970541645,0.0015708099914869915,0.0014798300010928263,0.0013941000021683674,0.0013133100098154198,0.0012371799869773288,0.0011654499782404553,0.0010978599990873288,0.0010341799934394658,0.0009741799876792356,0.0009176540042972192,0.0008643999996517474,0.0008142300018031771,0.0007669650027916456,0.0007224389992188662,0.0006804939960905662,0.0006409799971152097,0.0006037580072491741,0.0005686949928834414,0.0005356650023410717,0.0005045520083513111,0.00047524399269605055,0.00044763799814973027,0.00042163399727238965,0.00039713900090040016,0.00037406699993880466,0.0003523339983075857,0.00033186400348010164,0.00031258199790803093,0.00029442000231938437,0.0002773140028390723,0.0002612000025692396,0.0002460230001209614,0.00023172800016861098,0.00021826300144311972,0.0002055810000456404,0.000193635000565943,0.0001823840005575524,0.00017178600076780035,0.00016180400052689947,0.00015240300005340637,0.0001435470015470249,0.00013520600017121373,0.0001273499995780488,0.00011994999840680975,0.0001129810001051131,0.00010641600056260359,5.086644159746356e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.6949831644694,237.7288449605306,240.99987411499023,243.55290095011392,245.43892542521158,246.8269297281901,247.84998830159506,247.86106872558594,246.40309524536133,243.91412734985352,240.72613525390625,237.09118779500326,232.50226084391275,226.6042798360189,219.86330032348633,212.63030115763345,205.16734186808267,197.02039845784506,187.87340927124023,178.16141891479492,168.20841598510742,158.25240325927734,148.46439107259116,138.9673728942871,129.84235699971518,121.14333788553874,112.90132141113281,105.0793062845866,97.64328893025716,90.61287053426106,83.9956537882487,77.7898375193278,71.98722139994304,66.57480557759602,61.53649171193441,56.854376475016274,52.50926431020101,48.48115189870199,44.75034141540527,41.297430674235024,38.10402043660482,35.15221087137858,32.425102074941,29.906394640604656,27.581087430318195,25.43488057454427,23.454374313354492,21.627268314361572,19.941963354746502,18.387558142344158,16.95405387878418,15.632049719492594,14.412945826848349,13.28884220123291,12.252339045206705,11.296535809834799,10.415332953135172,9.603040297826132,8.854398171106974,8.164405981699625,7.5284238656361895,6.942221999168396,6.40185026327769,5.903728683789571,5.444537242253621,5.0212059418360395,4.630924701690674,4.271043499310811,3.9391424655914307,3.633021513621012,3.350700636704763,3.0903097788492837,2.8501489758491516,2.628648261229197,2.4243576924006143,2.235947052637736,2.0621764858563743,1.9018960197766621,1.7540555497010548,1.6176851292451222,1.491904725631078,1.3759043614069622,1.2689040104548137,1.170223702987035,1.0792034169038136,0.9952711264292399,0.9181628773609797,0.8472976634899775,0.781811460852623,0.7212952772776285,0.6653950959444046,0.6137849340836207,0.5661367873350779,0.5221196562051773,0.48148252815008163,0.44396641105413437,0.4093313018480937,0.37735719978809357,0.3478381112217903,0.3206130191683769,0.29550594339768094,0.27232687175273895,0.25092580169439316,0.23119373867909113,0.2130016821126143,0.19623162845770517,0.18077157934506735,0.1665225327014923,0.153388491521279,0.14125745619336763,0.1300514197597901,0.11972538816432159,0.11021135623256366,0.1014453290651242,0.09336940261224906,0.08593027914563815,0.07907805653909843,0.07276683673262596,0.06695441839595635,0.061601801154514156,0.05667288384089867,0.052134569734334946,0.04795625681678454,0.04410954316457113,0.040568532732625805,0.03730902230987946,0.03430901219447454,0.03154790339370569,0.029006995105495054,0.026668787313004334,0.024517380477239687,0.022537974019845326,0.020716868185748655,0.01904156260813276,0.01750055778150757,0.01608315280949076,0.014779548781613508,0.013580644968897104,0.01247814119172593,0.011464438013111552,0.01053233491256833,0.009675331957017383,0.008887479392190775,0.008163247102250656,0.007497534854337573,0.006885662907734513,0.0063233109734331565,0.0058064992384364205,0.005331587744876742,0.004895206346797447,0.0044942549817884965,0.004125883725161354,0.0037874626383806267,0.003476581633246193,0.00319102065016826,0.002928729789952437,0.0026878389762714505,0.0024666082463227212,0.0022634475802381835,0.0020768969552591443,0.0019055963784921914,0.0017483258658709626,0.0016039454009539138,0.0014713949446255963,0.0013497245284573485,0.0012380341552974035,0.0011355238287554432,0.0010414435237180442,0.000955101209304606,0.0008758679468883201,0.0008031627075979486,0.0007364504805688435,0.0006752412785620739,0.0006190860925319915,0.000567568926877963,0.0005203097680350766,0.00047696061665192246,0.00043719848326873034,0.00040073036022173863,0.00036728424796213705,0.00033661214547464624,0.000308484050037805,0.000282692963082809,0.00025904388166964054,0.00023736080523425093,0.00021748173821833916,0.00019925667705441205,0.0001825506199869172,0.0001672365700263375,0.0001531995221739635,0.0001403334790666122,0.00012854143642471172,0.00011773440140435316,0.00010783136955675825,3.3845009966171347e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527328491210938,3.547180493672689,3.43576047817866,3.327050487200419,3.2169004877408347,3.1060304641723633,2.9950804511706033,2.88459046681722,2.7750204205513,2.6667904257774353,2.5602304140726724,2.455630381902059,2.35323037703832,2.253240386644999,2.1558003624280295,2.061050375302633,1.9690803289413452,1.8799603283405304,1.7937303086121876,1.7104302942752838,1.6300602952639263,1.5526202817757924,1.478080262740453,1.4064302444458008,1.3376002510388691,1.271570235490799,1.2082702219486237,1.1476302047570546,1.0896001954873402,1.034100204706192,0.981064185500145,0.9304151684045792,0.8820751706759135,0.8359711617231369,0.7920241604248682,0.7501551459232966,0.7102881322304407,0.6723461349805196,0.6362541268269221,0.6019371201594671,0.5693241159121195,0.5383431017398834,0.5089250952005386,0.48100009312232334,0.4545030916730563,0.42937008291482925,0.4055400788784027,0.38295407593250275,0.3615530679623286,0.34128006796042126,0.32208306590716046,0.3039090658227603,0.286710058649381,0.2704380576809247,0.25504505013426143,0.2404890495042006,0.2267280456920465,0.21372104187806448,0.20142804210384688,0.18981603905558586,0.178847037255764,0.16848803435762724,0.15870603173971176,0.14947303012013435,0.14075902725259462,0.13253602758049965,0.12477802547315757,0.11746102447311084,0.1105590220540762,0.10405202147861321,0.09791612066328526,0.09213161965211232,0.08668011799454689,0.08154281601309776,0.07670171620945136,0.07214191555976868,0.06784751390417416,0.0638019135221839,0.05999151275803646,0.056404911602536835,0.053028211618463196,0.04984831064939499,0.04685620963573456,0.04404030988613764,0.0413894085213542,0.03889510873705149,0.03663450696816047,0.03458090747396151,0.03263920700798432,0.030802506487816572,0.029064105978856485,0.027417905783901613,0.02585810547073682,0.024396704975515604,0.02301010489463806,0.02169350441545248,0.02046010410413146,0.019287003980328638,0.018170603550970554,0.01712480342636506,0.016144903376698494,0.015227003023028374,0.014349603016550342,0.013510302873328328,0.01272400274562339,0.011987402491892377,0.011297302320599556,0.01065090213281413,0.010045402062435945,0.00946078208896021,0.008895711973309517,0.008366391683618227,0.007870571687817574,0.007406141570148368,0.006971101431796948,0.006563611367406945,0.006181921266640226,0.005824401237381001,0.005489531128356854,0.005175871114867429,0.004882090880225102,0.004606920954150458,0.004349180807669957,0.0041077807933713,0.003864270867779851,0.003618770802859217,0.003388840763363987,0.003173500687504808,0.0029718206302883723,0.0027829306006121137,0.0026060305923844376,0.0024403505570565662,0.0022852005204185843,0.002139890469455471,0.0020038004343708358,0.0018763603972426306,0.0017570103712690373,0.001645240360327686,0.0015405703549428533,0.001442550322584187,0.001350750292961796,0.0012647902864652376,0.0011842902652764071,0.0011089102384479095,0.001038320236451303,0.0009722162212710828,0.0009103151969611645,0.0008523501892341301,0.0007980701727016518,0.0007472431655817976,0.0006996491526175911,0.000655082151448975,0.000613351134234108,0.0005742751236539334,0.0005376851186156273,0.0005034231047223633,0.00047134310686184716,0.00044130409029700485,0.0004131770911044441,0.0003868410907064875,0.00036218108046644676,0.0003390920731665877,0.00031747307123926777,0.0002972310661183049,0.0002782780575216748,0.0002605330591904931,0.00024391805466924174,0.0002283610507826476,0.00021379604853185205,0.0002001590449557019,0.00018739004129505096,0.00017543604068729715,0.00016424303491173,0.00015376403583407713,0.0001439530290857268,0.00013476703073441362,0.00012616702709541036,0.00011811502554337494,0.0001105770249220465,0.00010351902286250454,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.284418006738027,3.2989591161410012,3.3043991923332214,3.3077791730562844,3.3091992139816284,3.308749258518219,3.3065293232599893,3.302629292011261,3.2971293131510415,3.2901093562444053,3.2816593647003174,3.2718394001324973,3.2607293923695884,3.2483994364738464,3.234919468561808,3.2203394373257956,3.204739491144816,3.1881595452626548,3.1706695556640625,3.152319550514221,3.1331695715586343,3.1132495999336243,3.0926295717557273,3.0713496009508767,3.049449622631073,3.0269696513811746,3.0039596358935037,2.9804397026697793,2.9564696550369263,2.9320796926816306,2.907289743423462,2.8821497360865274,2.8566797176996865,2.8309197227160134,2.8048797249794006,2.7786097327868142,2.752119799455007,2.725449800491333,2.6985997756322226,2.671619792779287,2.6445197661717734,2.617309828599294,2.5900198419888816,2.5626798272132874,2.5352898041407266,2.507879853248596,2.480449835459391,2.4530298113822937,2.4256298740704856,2.3982598384221396,2.3709398905436196,2.343679904937744,2.316489855448405,2.289389908313751,2.2623798847198486,2.235469877719879,2.2086799144744873,2.1819998820622764,2.1554599006970725,2.129059910774231,2.102799912293752,2.076699912548065,2.0507599115371704,2.0249799291292825,1.9993799130121868,1.97394992907842,1.9487099250157673,1.9236599306265514,1.8987999359766643,1.8741399347782135,1.8496799369653065,1.825429916381836,1.8013799488544464,1.7775399287541707,1.7539199491341908,1.730519950389862,1.7073399325211842,1.6843699514865875,1.6616299549738567,1.6391199429829915,1.6168299615383148,1.594759960969289,1.5729299585024517,1.5513199468453724,1.5299399495124817,1.5087899764378865,1.4871099889278412,1.4649199942747753,1.4430399735768635,1.421470006306966,1.4001799921194713,1.3791899879773457,1.3584900001684825,1.3380900025367737,1.3179599940776825,1.2980999847253163,1.2785199880599976,1.2592300176620483,1.2402100066343944,1.2214600046475728,1.2029699981212616,1.1847299933433533,1.1667699913183849,1.1490600109100342,1.1316000123818715,1.1143999894460042,1.0974399944146473,1.0807100037733715,1.0642399787902832,1.0480199952920277,1.0320200026035309,1.0162500143051147,1.000710015495618,0.9854059964418411,0.9703349967797598,0.9554729958375295,0.9408160050710043,0.9263809969027837,0.9121659894784292,0.8981659958759943,0.8843789994716644,0.8707809994618098,0.8573699941237768,0.8441640039285024,0.8311580121517181,0.8183500021696091,0.8057370036840439,0.7933160066604614,0.7810849994421005,0.7690399984518687,0.7571789970000585,0.745478997627894,0.7339390019575754,0.7225740005572637,0.7113829950491587,0.7003630002339681,0.6895120044549307,0.6788270076115926,0.6683050145705541,0.6579450021187464,0.6477429966131846,0.6376980046431223,0.6278069963057836,0.6180680096149445,0.6084780097007751,0.599034994840622,0.589738001426061,0.58058300614357,0.571569005648295,0.5626940031846365,0.5539549986521403,0.5453509986400604,0.5368790030479431,0.5285190045833588,0.5202670047680537,0.5121420125166575,0.5041429996490479,0.49626700580120087,0.48851200193166733,0.4808779979745547,0.4733610029021899,0.46596000095208484,0.45867400119702023,0.4515010019143422,0.44443800300359726,0.4374849970142047,0.43063899874687195,0.4239000007510185,0.41726400206486386,0.410731998582681,0.404300997654597,0.3979700009028117,0.3917360007762909,0.3855999956528346,0.3795589978496234,0.37361099819342297,0.3677559991677602,0.3619919990499814,0.35631700108448666,0.3507309953371684,0.3452320024371147,0.3398180032769839,0.33448799947897595,0.32924100011587143,0.32407600184281665,0.3189920013149579,0.3139860009153684,0.3090590015053749,0.3042080005009969,0.29943300286928815,0.2947330002983411,0.2901049976547559,0.28555000325043994,0.28106600046157837,0.2766519983609517,0.27230700105428696,0.26803000022967655,0.26382000495990116,0.259674996137619,0.25559499859809875,0.2515789990623792,0.24762600163618723,0.24373500173290572,0.2399039976298809,0.236134002606074,0.23242200165987015,0.22876899813612303,0.2251730002462864,0.22163299967845282,0.2181480017801126,0.21471899996201196,0.21134199822942415,0.20801899954676628,0.2047480009496212,0.2015290011962255,0.19835900018612543,0.19523999840021133,0.19216899946331978,0.18914700051148733,0.18617199982206026,0.18324399863680205,0.18036199981967607,0.1775250000258287,0.1747320033609867,0.17198399951060614,0.169278002033631,0.16661599899331728,0.16399500146508217,0.16141500075658163,0.15887599935134253,0.15637599925200144,0.15391699969768524,0.15149499972661337,0.14911199981967607,0.14676699911554655,0.14445800085862479,0.14218599845965704,0.13994900013009706,0.1377480005224546,0.1355810003976027,0.13344900061686835,0.13134999945759773,0.12928399940331778,0.12725099921226501,0.12524999802311262,0.12328000056246917,0.12134200024108092,0.11943399906158447,0.11755599888662498,0.11570700009663899,0.11388799982766311,0.11209699946145217,0.11033499923845132,0.10860000054041545,0.10689299988249938,0.10521299950778484,0.10355899917582671,0.1019310001283884,0.10032800026237965,0.09875130032499631,0.09719900041818619,0.09567120112478733,0.0941675001134475,0.09268739943703015,0.09123060045142968,0.08979669958353043,0.08838540005187194,0.08699629890422027,0.0856291006008784,0.08428329974412918,0.08295880009730656,0.0816550999879837,0.08037189953029156,0.07910889945924282,0.07786580050985019,0.07664219972987969,0.07543790029982726,0.0742526004711787,0.07308590039610863,0.07193750080962975,0.07080720054606597,0.06969469971954823,0.06859970030685265,0.0675219011803468,0.06646110117435455,0.06541700040300687,0.06438919963936011,0.0633777001251777,0.06238199987759193,0.06140209982792536,0.060437499545514584,0.05948809999972582,0.05855360006292661,0.057633900394042335,0.05672859990348419,0.055837499598662056,0.054960500138501324,0.05409720012297233,0.05324749990055958,0.05241120047867298,0.05158799979835749,0.050777800070742764,0.04998030016819636,0.049195400128761925,0.0484228003770113,0.04766239939878384,0.04691390010217825,0.046177100079754986,0.04545200026283661,0.044738300144672394,0.04403579980134964,0.043344300240278244,0.04266370056817929,0.04199379961937666,0.041334400263925396,0.04068540005634228,0.040046600004037224,0.039417899834613,0.038798999351759754,0.03818989948680004,0.03759030004342397,0.037000199779868126,0.03641929974158605,0.03584759992857774,0.035284800144533314,0.03473090007901192,0.03418570042898258,0.03364909999072552,0.03312090008209149,0.03260109977175792,0.03208930014322201,0.03158569987863302,0.03108990006148815,0.030601900070905685,0.030121700062106054,0.029648900032043457,0.0291836002531151,0.028725599714865286,0.028274800162762403,0.027831099927425385,0.02739430017148455,0.026964400274058182,0.026541299962749083,0.02612480040018757,0.025714900189389784,0.025311400182545185,0.024914200107256573,0.024523299963523943,0.02413849998265505,0.023759800164649885,0.02338699980949362,0.023020100003729265,0.02265890020256241,0.02230349974706769,0.021953599837919075,0.021609200319896143,0.02127019998927911,0.020936499970654648,0.02060809979836146,0.020284800014148157,0.019966600307573874,0.01965340009580056,0.019345199844489496,0.019041799940168858,0.018743100110441446,0.018449100044866402,0.018159800053884585,0.01787500036880374,0.017594600251565378,0.017318699974566698,0.017047100079556305,0.016779800100872915,0.01651659980416298,0.016257600237925846,0.016002699888000887,0.015751800189415615,0.015504800016060472,0.01526169991120696,0.015022399990508953,0.014786799903959036,0.014555000001564622,0.014326800126582384,0.01410219989096125,0.013881099876016378,0.013663500004137555,0.013449300002927581,0.013238400065650543,0.013030899999042353,0.012826600034410754,0.012625599978491664,0.01242769998498261,0.012232899898663163,0.01204110006801784,0.011852399989341697,0.011666599893942475,0.011483800054217378,0.011303799925372005,0.011126599973067641,0.010952300081650415,0.01078059997720023,0.010611700049291054,0.010445399985959133,0.010281700020035109,0.010120599996298552,0.009961979929357767,0.009805880021303892,0.009652229957282543,0.009501000090191761,0.009352130039284626,0.009205600013956428,0.009061369967336455,0.008919410097102324,0.008779669956614574,0.008642120053991675,0.00850672988841931,0.008373469968015948,0.008242290001362562,0.008113179976741472,0.00798608991317451,0.007860990047144393,0.007737860005969803,0.007616660014415781,0.007497359959719081,0.007379930039557318,0.0072643399859468145,0.00715057000828286,0.007038579943279426,0.0069283500003317995,0.006819850027871628,0.006713039979028205,0.006607920009021957,0.006504439981654286,0.006402579951100051,0.006302330022056897,0.00620363998071601,0.006106509982297818,0.006010889929408829,0.005916779977269471,0.005824139962593715,0.005732950017166634,0.0056431999352450175,0.00555485001920412,0.005467879973972837,0.005382280020664136,0.005298029980622232,0.005215090001001954,0.00513344999247541,0.005053100020935138,0.004974000000705321,0.004896139997678499,0.004819510000136991,0.004744070000015199,0.004669819958508015,0.004596729956877728,0.0045247900222117705,0.0044539700805520015,0.0043842700542882085,0.0043156599858775735,0.004248119929494957,0.004181639989838004,0.0041162100387737155,0.004051790029431383,0.003988389973528683,0.0039259899834481376,0.0038645599658290544,0.003804089986563971,0.0037445700145326555,0.0036859799874946475,0.003628309971342484,0.003571549973761042,0.0035156699984023967,0.0034606699870588877,0.0034065399668179452,0.003353239987821629,0.0033007900152976313,0.003249159975287815,0.003198330038382361,0.0031482999911531806,0.0030990600353106856,0.0030505899727965393,0.0030028699936034777,0.0029559099736313024,0.0029096799747397504,0.0028641700046136975,0.0028193800050454834,0.0027971599677888057};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261275604367256,0.4188620348771413,0.4108480264743169,0.4034980262319247,0.396084023018678,0.38861901809771854,0.38112201790014905,0.37360502034425735,0.3660820201039314,0.35856401920318604,0.3510630205273628,0.34358901530504227,0.33615001539389294,0.32875701536734897,0.321416012942791,0.31413501997788745,0.3069210151831309,0.2997790103157361,0.29271601140499115,0.28573601444562274,0.27884401629368466,0.27204301456610364,0.265338013569514,0.2587310050924619,0.25222400948405266,0.24582200745741525,0.23952500770489374,0.23333600784341493,0.22725500787297884,0.2212850091358026,0.21542500828703245,0.2096770058075587,0.20404000828663507,0.1985160062710444,0.193103006730477,0.18780300642053285,0.18261500572164854,0.1775390071173509,0.1725740060210228,0.16771900405486426,0.16297400618592897,0.15833700448274612,0.153808002670606,0.14938400561610857,0.14506600548823675,0.14085200180610022,0.13674000402291617,0.132730004688104,0.12882000456253687,0.1250070029248794,0.12129000201821327,0.1176700039456288,0.11414200253784657,0.11070500314235687,0.10735900327563286,0.10410200245678425,0.10093200206756592,0.09784680294493835,0.0948454017440478,0.09192560240626335,0.08908560127019882,0.0863237027078867,0.08363940318425496,0.08103110144535701,0.0784961028645436,0.07603290118277073,0.07364010127882163,0.07131520162026088,0.06905690208077431,0.06686400001247723,0.06473520087699096,0.06266940105706453,0.06066420115530491,0.058717601001262665,0.056828501323858895,0.05499600122372309,0.053218100840846695,0.051493800866107144,0.04982240063448747,0.04820200086881717,0.04663060077776512,0.04510660097002983,0.04362930047015349,0.042198200399676956,0.04081140086054802,0.03946749990185102,0.038073900466163955,0.036636900156736374,0.035253699868917465,0.033922399704655014,0.03264100011438131,0.031407699609796204,0.030220599845051765,0.029078100031862657,0.02797849988564849,0.02692009989793102,0.025901599787175655,0.024921300044904154,0.0239778997687002,0.023069999801615875,0.022196199900160234,0.021355300055195887,0.020545999829967816,0.01976729991535346,0.019017800067861874,0.018296600009004276,0.017602600157260895,0.01693479996174574,0.016292100151379902,0.01567369986635943,0.015078600030392408,0.014506000016505519,0.013955000089481473,0.01342480001039803,0.012914599928384026,0.012423800071701407,0.011951399889464179,0.011496999921898047,0.011059699890514215,0.010638999907920757,0.010234100045636296,0.009844649971152345,0.00946990012501677,0.00910935007656614,0.008762450035040578,0.008428690023720264,0.008107590023428202,0.007798649991552035,0.007501429916980366,0.007215479970909655,0.006940380088053644,0.006675720059623321,0.006421110049510996,0.00617615005467087,0.005940509998860459,0.005713810018884639,0.00549571996089071,0.005285919993184507,0.0050840900124361115,0.004889940028078854,0.004703169999023278,0.004523500062835713,0.00435065998074909,0.004184409976005554,0.0040244799650584655,0.00387063001592954,0.003722649998962879,0.003580299982180198,0.003443369991146028,0.0033116600049349167,0.0031849699832188585,0.0030631000408902764,0.002945879998151213,0.002833139985644569,0.0027246899941625693,0.002620370010845363,0.0025200399880607924,0.0024235400487668812,0.00233071002488335,0.0022414400009438396,0.0021555699834910533,0.002072969994818171,0.0019935400147611895,0.0019171399956879516,0.0018436500104144216,0.0017729800116891663,0.0017050000024028122,0.0016396300052292645,0.0015767499862704426,0.0015162800070053588,0.0014581200084649026,0.0014021799919040252,0.0013483899820130318,0.0012966500071343035,0.0012468999872605007,0.0011990399992403884,0.001153020003888135,0.0011087599947738151,0.0010662000083054106,0.0010252699721604586,0.0009859009975722681,0.0009480429968486229,0.0009116360063975056,0.000876622997263136,0.0008429529989371076,0.0008105730036428819,0.0007794339956793314,0.0007494890014640987,0.0007206919981399551,0.000692999999349316,0.000666369999332043,0.0006407610004922996,0.0006161339939959968,0.0005924529929567749,0.0005696800023239726,0.0005477809997197861,0.0005267219967208803,0.0005064720074490955,0.0004869989982883756,0.00046827400122613955,0.0004502679973181027,0.0004329530008059616,0.00041630300256656483,0.00040029300240955007,0.00038489699848772335,0.00037009399966336787,0.00035585800166397047,0.00034216999968824285,0.00032900799609099823,0.00031635100215983886,0.0003041809953477544,0.00029247899995728705,0.00028122600391119096,0.00027040699690890807,0.0002600030008276614,0.00024999899809093523,0.00024037900099453205,0.00023113000012623766,0.0002222360017185565,0.00021368500044142516,0.00020546200175886042,0.00019755499912813926,0.00018995300100262588,0.00018264299797010608,0.00017561399969660366,0.00016885600052773952,0.0001623580016409202,0.00015611000101974545,0.00015010200149845332,0.0001443250002921559,0.00013877099991077557,0.00013343000076323128,0.00012829500216563852,0.00012335799874563236,0.00011861099968276297,0.00011404599960466537,0.00010965700009061645,0.00010543699985040196,8.475839240418281e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1796061197917,329.0759735107422,329.78197479248047,330.52897389729816,331.2759730021159,332.0209732055664,332.76597849527997,333.52097574869794,334.2949727376302,335.08897399902344,335.90297444661456,336.73597462972003,337.5879720052083,338.45997111002606,339.3499755859375,340.2589696248372,341.18697357177734,342.1269709269206,343.0709737141927,344.0209706624349,344.9749704996745,345.93496958414715,346.89896901448566,347.86696370442706,348.8409729003906,349.81897226969403,350.8019739786784,351.78697204589844,352.77197265625,353.75697326660156,354.7419713338216,355.7269744873047,356.7109731038411,357.6959737141927,358.6809717814128,359.66497294108075,360.64996846516925,361.63296763102215,362.6139678955078,363.5929768880208,364.5699717203776,365.5439707438151,366.51697031656903,367.4869689941406,368.45496877034503,369.4209721883138,370.3849690755208,371.3459726969401,372.30297597249347,373.2549692789714,374.2029724121094,375.14697519938153,376.08697001139325,377.0229746500651,377.95497131347656,378.88297271728516,379.80696868896484,380.72597249348956,381.6389694213867,382.5469741821289,383.44897206624347,384.3459701538086,385.2379735310872,386.1239776611328,387.0039774576823,387.8799769083659,388.7499745686849,389.615971883138,390.4789784749349,391.33797454833984,392.1949691772461,393.04797108968097,393.8979721069336,394.74497477213544,395.58897654215497,396.42997487386066,397.2669728597005,398.1029739379883,398.93497467041016,399.76597595214844,400.59497324625653,401.4209747314453,402.24497477213544,403.06697845458984,403.88697306315106,404.7049738566081,405.5209732055664,406.3309733072917,407.13197326660156,407.9239730834961,408.70796966552734,409.48197682698566,410.2479731241862,411.0049769083659,411.75297292073566,412.4929784138997,413.2239761352539,413.9469731648763,414.6609700520833,415.3669789632161,416.06497446695965,416.7549743652344,417.43697865804035,418.10997517903644,418.7759730021159,419.4329783121745,420.0829798380534,420.72497812906903,421.3589782714844,421.98597717285156,422.604975382487,423.21597544352215,423.8199717203776,424.41697692871094,425.0059763590495,425.5879770914714,426.16197713216144,426.7289759318034,427.28897857666016,427.8429768880208,428.38897705078125,428.927973429362,429.45997619628906,429.9849802652995,430.5029780069987,431.0149739583333,431.51998138427734,432.01797739664715,432.5099792480469,432.9949773152669,433.47397867838544,433.9459762573242,434.41197713216144,434.87098185221356,435.323974609375,435.7709782918294,436.2119725545247,436.64698028564453,437.0749816894531,437.4979782104492,437.91397857666016,438.3249816894531,438.7289810180664,439.1279805501302,439.5209782918294,439.9079767862956,440.28998311360675,440.6649754842122,441.03497823079425,441.3999786376953,441.7589797973633,442.11298116048175,442.46097564697266,442.80298105875653,443.14097849527997,443.4729817708333,443.7989807128906,444.1209767659505,444.4369812011719,444.7479782104492,445.0539805094401,445.35498046875,445.65098063151044,445.94197845458984,446.2279764811198,446.5099817911784,446.7859827677409,447.0569763183594,447.32398478190106,447.58597564697266,447.8429768880208,448.09498087565106,448.3429768880208,448.5869776407878,448.8249791463216,449.0599772135417,449.2889811197917,449.5149790445964,449.73597717285156,449.95198313395184,450.16397857666016,450.3719838460286,450.5759862263997,450.77498118082684,450.96998087565106,451.1609827677409,451.3479766845703,451.5309778849284,451.70897674560547,451.8839797973633,452.0549825032552,452.22098032633465,452.3839823404948,452.54298146565753,452.6979802449544,452.84898376464844,452.99597930908203,453.1399790445964,453.2789789835612,453.4159800211589,453.54798380533856,453.6769790649414,453.80198160807294,453.92298126220703,454.0409851074219,454.15597279866535,454.26597849527997,454.3739776611328,454.47798411051434,454.57798258463544,454.6759796142578,454.7689844767253,454.85998280843097,454.9469858805339,455.03098551432294,455.1109797159831,455.1889826456706,455.26298268636066,455.333984375,455.40198008219403,455.4659779866536,455.5279795328776,455.5869852701823,455.64198048909503,455.6949818929036,455.7439829508464,455.7909800211589,455.833984375,455.8749771118164,455.91197713216144,455.9469807942708,455.9789810180664,456.0079803466797,456.0349833170573,456.0579833984375,456.0789845784505,456.09697977701825,456.1139831542969,456.13098398844403,456.14698537190753,456.1629867553711,456.17998758951825,456.1959813435872,456.21198018391925,456.22798411051434,456.2429835001628,456.2589797973633,456.2749786376953,456.28998311360675,456.3049825032552,456.32098388671875,456.3359832763672,456.3509801228841,456.36598714192706,456.3809814453125,456.3949839274089,456.40997823079425,456.42398325602215,456.4389826456706,456.45298258463544,456.4669825236003,456.48097737630206,456.49597930908203,456.5089823404948,456.5229848225911,456.53698476155597,456.5509847005208,456.56398010253906,456.5779800415039,456.59098561604816,456.6039784749349,456.6169789632161,456.63098398844403,456.64298248291016,456.6559829711914,456.66898345947266,456.6819763183594,456.6949818929036,456.7069803873698,456.71998087565106,456.7319819132487,456.7439829508464,456.7559814453125,456.7679850260417,456.7799809773763,456.79197947184247,456.8039830525716,456.8159815470378,456.82798258463544,456.83898162841797,456.8509801228841,456.8619791666667,456.87398529052734,456.8849843343099,456.89598083496094,456.906982421875,456.91798146565753,456.9289855957031,456.9399820963542,456.95098368326825,456.96198018391925,456.97198486328125,456.9829839070638,456.9939829508464,457.0039800008138,457.0139846801758,457.0249735514323,457.0349833170573,457.04498291015625,457.0549825032552,457.06498463948566,457.0749816894531,457.0849787394206,457.09498596191406,457.10498046875,457.11498006184894,457.1239827473958,457.1339823404948,457.14298248291016,457.1529795328776,457.1619822184245,457.1709798177083,457.1809794108073,457.18997955322266,457.19898478190106,457.2079849243164,457.2169774373372,457.2259826660156,457.2349802652995,457.2439829508464,457.2529830932617,457.26098378499347,457.2699788411458,457.2789815266927,457.28698476155597,457.29598236083984,457.3039830525716,457.312983194987,457.3209864298503,457.32898203531903,457.33698018391925,457.3459828694661,457.3539861043294,457.3619842529297,457.36997985839844,457.3779830932617,457.38598378499347,457.3939793904622,457.4009780883789,457.4089838663737,457.41698201497394,457.42498270670575,457.4319839477539,457.4399820963542,457.44698333740234,457.4549789428711,457.46198018391925,457.46998087565106,457.4769795735677,457.4839808146159,457.49097951253253,457.49898020426434,457.5059814453125,457.51297760009766,457.51998138427734,457.5269826253255,457.5339813232422,457.5409876505534,457.54798126220703,457.5549825032552,457.5619837443034,457.56798299153644,457.57498423258465,457.5819803873698,457.5879872639974,457.59498596191406,457.60198465983075,457.6079839070638,457.614990234375,457.62098439534503,457.6269810994466,457.6339823404948,457.6399866739909,457.64598337809247,457.6529795328776,457.6589838663737,457.66498311360675,457.6709849039714,457.6769790649414,457.68398030598956,457.68998463948566,457.6959813435872,457.70198313395184,457.7079823811849,457.71297963460285,457.71898142496747,457.72498321533203,457.7309850056966,457.7369842529297,457.74298095703125,457.74798075358075,457.7539825439453,457.7599792480469,457.7649866739909,457.77098592122394,457.77598063151044,457.781977335612,457.78698476155597,457.79298146565753,457.79798126220703,457.8039855957031,457.8089853922526,457.8139877319336,457.8199818929036,457.8249816894531,457.8299840291341,457.8349863688151,457.84098052978516,457.84598541259766,457.8509826660156,457.8559824625651,457.8609848022461,457.86598714192706,457.87098693847656,457.87597910563153,457.88097890218097,457.885981241862,457.89098358154297,457.89598592122394,457.90098571777344,457.9059880574544,457.9109853108724,457.9149805704753,457.9199803670247,457.92498270670575,457.9299825032552,457.93398030598956,457.9389826456706,457.94397735595703,457.94798787434894,457.95298258463544,457.9579798380534,457.9619827270508,457.9669825236003,457.97098032633465,457.9759801228841,457.97998046875,457.98498280843097,457.98898061116535,457.99298095703125,457.99798075358075,458.00198618570965,458.0069834391276,458.010981241862,458.0149866739909,458.01898193359375,458.0239791870117,458.0279769897461,458.031982421875,458.0359853108724,458.04098256429035,458.04498291015625,458.0489857991536,458.05298614501953,458.05698649088544,458.0609817504883,458.06498463948566,458.06897989908856,458.07298533121747,458.0769780476888,458.0809834798177,458.08498128255206,458.08898162841797,458.0929819742839,458.0969823201497,458.1009826660156,458.10498301188153,458.1089808146159,458.11297607421875,458.1159845987956,458.11998748779297,458.12398020426434,458.12798563639325,458.1319808959961,458.1349843343099,458.1369806925456};
}

void set_concs_ssp119() //from year 1700 to year 2500 - using emissions for aerosols and
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.346808649,8.96619372,8.585578792,8.204963864,7.824348936,7.48533686,7.146324785,6.807312709,6.468300633,6.129288558,5.790276482,5.451264407,5.112252331,4.773240256,4.43422818,4.345371325,4.25651447,4.167657615,4.07880076,3.989943905,3.90108705,3.812230195,3.72337334,3.634516485,3.54565963,3.470846458,3.396033286,3.321220114,3.246406942,3.171593769,3.096780597,3.021967425,2.947154253,2.87234108,2.797527908,2.769658553,2.741789198,2.713919842,2.686050487,2.658181132,2.630311776,2.602442421,2.574573066,2.546703711,2.518834355,2.503980586,2.489126817,2.474273047,2.459419278,2.444565509,2.42971174,2.41485797,2.400004201,2.385150432,2.370296662,2.357638554,2.344980446,2.332322338,2.31966423,2.307006121,2.294348013,2.281689905,2.269031797,2.256373688,2.24371558,2.23708432,2.230453061,2.223821801,2.217190541,2.210559282,2.203928022,2.197296762,2.190665503,2.184034243,2.177402983,2.167120797,2.15683861,2.146556424,2.136274237,2.125992051,2.115709864,2.105427678,2.095145491,2.084863305,2.074581118,2.068194087,2.061807056,2.055420025,2.049032995,2.042645964,2.036258933,2.029871902,2.023484871,2.01709784,2.010710809,2.004323778,1.997936747,1.991549717,1.985162686,1.978775655,1.972388624,1.966001593,1.959614562,1.953227531,1.9468405,1.940453469,1.934066438,1.927679408,1.921292377,1.914905346,1.908518315,1.902131284,1.895744253,1.889357222,1.882970191,1.87658316,1.87019613,1.863809099,1.857422068,1.851035037,1.844648006,1.838260975,1.831873944,1.825486913,1.819099882,1.812712851,1.806325821,1.79993879,1.793551759,1.787164728,1.780777697,1.774390666,1.768003635,1.761616604,1.755229573,1.748842543,1.742455512,1.736068481,1.72968145,1.723294419,1.716907388,1.710520357,1.704133326,1.697746295,1.691359264,1.684972234,1.678585203,1.672198172,1.665811141,1.65942411,1.653037079,1.646650048,1.640263017,1.633875986,1.627488956,1.621101925,1.614714894,1.608327863,1.601940832,1.595553801,1.58916677,1.582779739,1.576392708,1.570005677,1.563618647,1.557231616,1.550844585,1.544457554,1.538070523,1.531683492,1.525296461,1.51890943,1.512522399,1.506135368,1.499748338,1.493361307,1.486974276,1.480587245,1.474200214,1.467813183,1.461426152,1.455039121,1.44865209,1.44226506,1.435878029,1.429490998,1.423103967,1.416716936,1.410329905,1.403942874,1.397555843,1.391168812,1.384781781,1.378394751,1.37200772,1.365620689,1.359233658,1.352846627,1.346459596,1.340072565,1.333685534,1.327298503,1.320911473,1.314524442,1.308137411,1.30175038,1.295363349,1.288976318,1.282589287,1.276202256,1.269815225,1.263428194,1.257041164,1.250654133,1.244267102,1.237880071,1.23149304,1.225106009,1.218718978,1.212331947,1.205944916,1.199557886,1.193170855,1.186783824,1.180396793,1.174009762,1.167622731,1.1612357,1.154848669,1.148461638,1.142074607,1.135687577,1.129300546,1.122913515,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484,1.116526484};
   
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,65.25142025,65.22313737,65.19485449,65.1665716,65.13828872,65.11029536,65.08230199,65.05430863,65.02631527,64.99832191,64.97032854,64.94233518,64.91434182,64.88634846,64.85835509,64.89423802,64.93012094,64.96600387,65.00188679,65.03776971,65.07365264,65.10953556,65.14541848,65.18130141,65.21718433,65.16868015,65.12017597,65.07167179,65.02316761,64.97466343,64.92615925,64.87765507,64.82915089,64.78064671,64.73214252,64.6691932,64.60624388,64.54329456,64.48034524,64.41739592,64.3544466,64.29149728,64.22854796,64.16559864,64.10264931,64.07984602,64.05704273,64.03423944,64.01143615,63.98863286,63.96582957,63.94302627,63.92022298,63.89741969,63.8746164,63.84864504,63.82267367,63.79670231,63.77073094,63.74475958,63.71878821,63.69281685,63.66684548,63.64087412,63.61490275,63.6052374,63.59557205,63.5859067,63.57624135,63.56657599,63.55691064,63.54724529,63.53757994,63.52791458,63.51824923,63.4846377,63.45102617,63.41741464,63.38380311,63.35019158,63.31658005,63.28296852,63.24935699,63.21574547,63.18213394,63.08081105,62.97948816,62.87816527,62.77684239,62.6755195,62.57419661,62.47287373,62.37155084,62.27022795,62.16890506,62.06758218,61.96625929,61.8649364,61.76361352,61.66229063,61.56096774,61.45964485,61.35832197,61.25699908,61.15567619,61.05435331,60.95303042,60.85170753,60.75038464,60.64906176,60.54773887,60.44641598,60.3450931,60.24377021,60.14244732,60.04112443,59.93980155,59.83847866,59.73715577,59.63583289,59.53451,59.43318711,59.33186422,59.23054134,59.12921845,59.02789556,58.92657268,58.82524979,58.7239269,58.62260401,58.52128113,58.41995824,58.31863535,58.21731247,58.11598958,58.01466669,57.9133438,57.81202092,57.71069803,57.60937514,57.50805226,57.40672937,57.30540648,57.2040836,57.10276071,57.00143782,56.90011493,56.79879205,56.69746916,56.59614627,56.49482339,56.3935005,56.29217761,56.19085472,56.08953184,55.98820895,55.88688606,55.78556318,55.68424029,55.5829174,55.48159451,55.38027163,55.27894874,55.17762585,55.07630297,54.97498008,54.87365719,54.7723343,54.67101142,54.56968853,54.46836564,54.36704276,54.26571987,54.16439698,54.06307409,53.96175121,53.86042832,53.75910543,53.65778255,53.55645966,53.45513677,53.35381388,53.252491,53.15116811,53.04984522,52.94852234,52.84719945,52.74587656,52.64455367,52.54323079,52.4419079,52.34058501,52.23926213,52.13793924,52.03661635,51.93529346,51.83397058,51.73264769,51.6313248,51.53000192,51.42867903,51.32735614,51.22603325,51.12471037,51.02338748,50.92206459,50.82074171,50.71941882,50.61809593,50.51677304,50.41545016,50.31412727,50.21280438,50.1114815,50.01015861,49.90883572,49.80751283,49.70618995,49.60486706,49.50354417,49.40222129,49.3008984,49.19957551,49.09825262,48.99692974,48.89560685,48.79428396,48.69296108,48.59163819,48.4903153,48.38899242,48.28766953,48.18634664,48.08502375,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087,47.98370087};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,33.62606204,32.50609986,31.38613767,30.26617549,29.1462133,28.31322752,27.48024174,26.64725596,25.81427018,24.9812844,24.14829862,23.31531284,22.48232706,21.64934128,20.8163555,20.7988716,20.78138771,20.76390382,20.74641993,20.72893604,20.71145215,20.69396826,20.67648436,20.65900047,20.64151658,20.31657319,19.9916298,19.66668642,19.34174303,19.01679964,18.69185625,18.36691286,18.04196947,17.71702608,17.39208269,17.27486599,17.15764929,17.04043259,16.92321589,16.80599919,16.68878249,16.57156578,16.45434908,16.33713238,16.21991568,16.15481901,16.08972235,16.02462569,15.95952902,15.89443236,15.82933569,15.76423903,15.69914236,15.6340457,15.56894903,15.46525571,15.36156238,15.25786905,15.15417572,15.05048239,14.94678907,14.84309574,14.73940241,14.63570908,14.53201576,14.47550487,14.41899399,14.3624831,14.30597221,14.24946133,14.19295044,14.13643956,14.07992867,14.02341779,13.9669069,13.86418626,13.76146563,13.65874499,13.55602435,13.45330371,13.35058307,13.24786243,13.14514179,13.04242115,12.93970051,12.9085519,12.87740329,12.84625468,12.81510607,12.78395746,12.75280885,12.72166024,12.69051163,12.65936302,12.62821441,12.5970658,12.56591719,12.53476858,12.50361997,12.47247136,12.44132275,12.41017414,12.37902553,12.34787692,12.31672831,12.2855797,12.25443109,12.22328248,12.19213387,12.16098526,12.12983665,12.09868804,12.06753943,12.03639082,12.00524221,11.9740936,11.94294499,11.91179637,11.88064776,11.84949915,11.81835054,11.78720193,11.75605332,11.72490471,11.6937561,11.66260749,11.63145888,11.60031027,11.56916166,11.53801305,11.50686444,11.47571583,11.44456722,11.41341861,11.38227,11.35112139,11.31997278,11.28882417,11.25767556,11.22652695,11.19537834,11.16422973,11.13308112,11.10193251,11.0707839,11.03963529,11.00848668,10.97733807,10.94618946,10.91504085,10.88389224,10.85274363,10.82159502,10.79044641,10.7592978,10.72814919,10.69700058,10.66585197,10.63470336,10.60355474,10.57240613,10.54125752,10.51010891,10.4789603,10.44781169,10.41666308,10.38551447,10.35436586,10.32321725,10.29206864,10.26092003,10.22977142,10.19862281,10.1674742,10.13632559,10.10517698,10.07402837,10.04287976,10.01173115,9.98058254,9.94943393,9.91828532,9.88713671,9.855988099,9.824839489,9.793690879,9.762542269,9.731393658,9.700245048,9.669096438,9.637947828,9.606799217,9.575650607,9.544501997,9.513353387,9.482204777,9.451056166,9.419907556,9.388758946,9.357610336,9.326461725,9.295313115,9.264164505,9.233015895,9.201867284,9.170718674,9.139570064,9.108421454,9.077272844,9.046124233,9.014975623,8.983827013,8.952678403,8.921529792,8.890381182,8.859232572,8.828083962,8.796935351,8.765786741,8.734638131,8.703489521,8.67234091,8.6411923,8.61004369,8.57889508,8.54774647,8.516597859,8.485449249,8.454300639,8.423152029,8.392003418,8.360854808,8.329706198,8.298557588,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977,8.267408977};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,96.52676505,92.28236311,88.03796118,83.79355925,79.54915731,75.2398318,70.93050628,66.62118076,62.31185525,58.00252973,53.69320421,49.38387869,45.07455318,40.76522766,36.45590214,35.17257184,33.88924154,32.60591124,31.32258094,30.03925063,28.75592033,27.47259003,26.18925973,24.90592943,23.62259912,23.42317644,23.22375375,23.02433106,22.82490837,22.62548569,22.426063,22.22664031,22.02721763,21.82779494,21.62837225,21.53253014,21.43668802,21.3408459,21.24500379,21.14916167,21.05331955,20.95747744,20.86163532,20.76579321,20.66995109,20.44359354,20.217236,19.99087845,19.76452091,19.53816336,19.31180581,19.08544827,18.85909072,18.63273317,18.40637563,18.11615122,17.82592681,17.5357024,17.24547799,16.95525358,16.66502917,16.37480476,16.08458035,15.79435594,15.50413153,15.21591523,14.92769892,14.63948262,14.35126632,14.06305002,13.77483372,13.48661742,13.19840111,12.91018481,12.62196851,12.30591253,11.98985655,11.67380058,11.3577446,11.04168862,10.72563264,10.40957667,10.09352069,9.777464711,9.461408733,9.407221074,9.353033416,9.298845757,9.244658098,9.190470439,9.13628278,9.082095121,9.027907462,8.973719804,8.919532145,8.865344486,8.811156827,8.756969168,8.702781509,8.64859385,8.594406192,8.540218533,8.486030874,8.431843215,8.377655556,8.323467897,8.269280239,8.21509258,8.160904921,8.106717262,8.052529603,7.998341944,7.944154285,7.889966627,7.835778968,7.781591309,7.72740365,7.673215991,7.619028332,7.564840673,7.510653015,7.456465356,7.402277697,7.348090038,7.293902379,7.23971472,7.185527061,7.131339403,7.077151744,7.022964085,6.968776426,6.914588767,6.860401108,6.80621345,6.752025791,6.697838132,6.643650473,6.589462814,6.535275155,6.481087496,6.426899838,6.372712179,6.31852452,6.264336861,6.210149202,6.155961543,6.101773884,6.047586226,5.993398567,5.939210908,5.885023249,5.83083559,5.776647931,5.722460273,5.668272614,5.614084955,5.559897296,5.505709637,5.451521978,5.397334319,5.343146661,5.288959002,5.234771343,5.180583684,5.126396025,5.072208366,5.018020707,4.963833049,4.90964539,4.855457731,4.801270072,4.747082413,4.692894754,4.638707095,4.584519437,4.530331778,4.476144119,4.42195646,4.367768801,4.313581142,4.259393484,4.205205825,4.151018166,4.096830507,4.042642848,3.988455189,3.93426753,3.880079872,3.825892213,3.771704554,3.717516895,3.663329236,3.609141577,3.554953918,3.50076626,3.446578601,3.392390942,3.338203283,3.284015624,3.229827965,3.175640306,3.121452648,3.067264989,3.01307733,2.958889671,2.904702012,2.850514353,2.796326695,2.742139036,2.687951377,2.633763718,2.579576059,2.5253884,2.471200741,2.417013083,2.362825424,2.308637765,2.254450106,2.200262447,2.146074788,2.091887129,2.037699471,1.983511812,1.929324153,1.875136494,1.820948835,1.766761176,1.712573518,1.658385859,1.6041982,1.550010541,1.495822882,1.441635223,1.387447564,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906,1.333259906};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,153.5057366,151.4910231,149.4763097,147.4615963,145.4468828,139.5704584,133.6940339,127.8176095,121.941185,116.0647606,110.1883361,104.3119117,98.43548724,92.55906279,86.68263834,84.45724419,82.23185005,80.0064559,77.78106176,75.55566761,73.33027347,71.10487932,68.87948518,66.65409103,64.42869688,62.89112451,61.35355213,59.81597975,58.27840738,56.740835,55.20326262,53.66569025,52.12811787,50.59054549,49.05297311,48.59521507,48.13745703,47.67969898,47.22194094,46.7641829,46.30642485,45.84866681,45.39090877,44.93315072,44.47539268,44.28598193,44.09657118,43.90716044,43.71774969,43.52833894,43.33892819,43.14951745,42.9601067,42.77069595,42.5812852,42.35373923,42.12619326,41.89864729,41.67110132,41.44355535,41.21600938,40.98846341,40.76091744,40.53337147,40.3058255,40.12176139,39.93769728,39.75363317,39.56956905,39.38550494,39.20144083,39.01737672,38.83331261,38.64924849,38.46518438,38.35549025,38.24579612,38.13610199,38.02640786,37.91671373,37.8070196,37.69732547,37.58763134,37.4779372,37.36824307,37.23801038,37.1077777,36.97754501,36.84731232,36.71707963,36.58684694,36.45661425,36.32638156,36.19614887,36.06591618,35.93568349,35.8054508,35.67521812,35.54498543,35.41475274,35.28452005,35.15428736,35.02405467,34.89382198,34.76358929,34.6333566,34.50312391,34.37289122,34.24265853,34.11242585,33.98219316,33.85196047,33.72172778,33.59149509,33.4612624,33.33102971,33.20079702,33.07056433,32.94033164,32.81009895,32.67986627,32.54963358,32.41940089,32.2891682,32.15893551,32.02870282,31.89847013,31.76823744,31.63800475,31.50777206,31.37753937,31.24730668,31.117074,30.98684131,30.85660862,30.72637593,30.59614324,30.46591055,30.33567786,30.20544517,30.07521248,29.94497979,29.8147471,29.68451442,29.55428173,29.42404904,29.29381635,29.16358366,29.03335097,28.90311828,28.77288559,28.6426529,28.51242021,28.38218752,28.25195483,28.12172215,27.99148946,27.86125677,27.73102408,27.60079139,27.4705587,27.34032601,27.21009332,27.07986063,26.94962794,26.81939525,26.68916256,26.55892988,26.42869719,26.2984645,26.16823181,26.03799912,25.90776643,25.77753374,25.64730105,25.51706836,25.38683567,25.25660298,25.1263703,24.99613761,24.86590492,24.73567223,24.60543954,24.47520685,24.34497416,24.21474147,24.08450878,23.95427609,23.8240434,23.69381071,23.56357803,23.43334534,23.30311265,23.17287996,23.04264727,22.91241458,22.78218189,22.6519492,22.52171651,22.39148382,22.26125113,22.13101845,22.00078576,21.87055307,21.74032038,21.61008769,21.479855,21.34962231,21.21938962,21.08915693,20.95892424,20.82869155,20.69845886,20.56822618,20.43799349,20.3077608,20.17752811,20.04729542,19.91706273,19.78683004,19.65659735,19.52636466,19.39613197,19.26589928,19.1356666,19.00543391,18.87520122,18.74496853,18.61473584,18.48450315,18.35427046,18.22403777,18.09380508,17.96357239,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397,17.8333397};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,219.9155267,212.5862341,205.2569415,197.9276489,190.5983563,183.2158847,175.8334132,168.4509416,161.0684701,153.6859985,146.303527,138.9210555,131.5385839,124.1561124,116.7736408,116.1071637,115.4406866,114.7742095,114.1077323,113.4412552,112.7747781,112.1083009,111.4418238,110.7753467,110.1088696,108.4058469,106.7028243,104.9998017,103.2967791,101.5937564,99.89073382,98.1877112,96.48468857,94.78166595,93.07864333,92.15430194,91.22996055,90.30561915,89.38127776,88.45693637,87.53259498,86.60825359,85.6839122,84.75957081,83.83522942,82.97654152,82.11785362,81.25916572,80.40047782,79.54178992,78.68310203,77.82441413,76.96572623,76.10703833,75.24835043,74.36779354,73.48723665,72.60667976,71.72612287,70.84556598,69.9650091,69.08445221,68.20389532,67.32333843,66.44278154,66.07687072,65.7109599,65.34504908,64.97913826,64.61322744,64.24731662,63.8814058,63.51549498,63.14958416,62.78367333,62.35687968,61.93008603,61.50329237,61.07649872,60.64970507,60.22291141,59.79611776,59.36932411,58.94253045,58.5157368,58.38504312,58.25434944,58.12365577,57.99296209,57.86226841,57.73157474,57.60088106,57.47018738,57.3394937,57.20880003,57.07810635,56.94741267,56.816719,56.68602532,56.55533164,56.42463796,56.29394429,56.16325061,56.03255693,55.90186326,55.77116958,55.6404759,55.50978222,55.37908855,55.24839487,55.11770119,54.98700752,54.85631384,54.72562016,54.59492648,54.46423281,54.33353913,54.20284545,54.07215178,53.9414581,53.81076442,53.68007074,53.54937707,53.41868339,53.28798971,53.15729604,53.02660236,52.89590868,52.765215,52.63452133,52.50382765,52.37313397,52.2424403,52.11174662,51.98105294,51.85035926,51.71966559,51.58897191,51.45827823,51.32758456,51.19689088,51.0661972,50.93550352,50.80480985,50.67411617,50.54342249,50.41272882,50.28203514,50.15134146,50.02064778,49.88995411,49.75926043,49.62856675,49.49787308,49.3671794,49.23648572,49.10579204,48.97509837,48.84440469,48.71371101,48.58301734,48.45232366,48.32162998,48.1909363,48.06024263,47.92954895,47.79885527,47.6681616,47.53746792,47.40677424,47.27608056,47.14538689,47.01469321,46.88399953,46.75330586,46.62261218,46.4919185,46.36122482,46.23053115,46.09983747,45.96914379,45.83845012,45.70775644,45.57706276,45.44636908,45.31567541,45.18498173,45.05428805,44.92359438,44.7929007,44.66220702,44.53151334,44.40081967,44.27012599,44.13943231,44.00873864,43.87804496,43.74735128,43.6166576,43.48596393,43.35527025,43.22457657,43.0938829,42.96318922,42.83249554,42.70180186,42.57110819,42.44041451,42.30972083,42.17902716,42.04833348,41.9176398,41.78694612,41.65625245,41.52555877,41.39486509,41.26417142,41.13347774,41.00278406,40.87209038,40.74139671,40.61070303,40.48000935,40.34931568,40.218622,40.08792832,39.95723464,39.82654097,39.69584729,39.56515361,39.43445994,39.30376626,39.17307258,39.0423789,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523,38.91168523};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9559936523438,1851.593973795573,1872.6688435872395,1882.6005554199219,1889.6500447591145,1894.030008951823,1895.9098002115886,1895.0296020507812,1891.159444173177,1884.4993184407551,1875.2491861979167,1863.5790608723958,1849.658935546875,1833.6488342285156,1815.6787516276042,1795.8786214192708,1774.3886820475261,1752.3588358561199,1730.8687947591145,1709.8788350423176,1689.3788452148438,1669.3188883463542,1649.6788940429688,1630.428934733073,1611.5389506022136,1592.9889322916667,1574.7489827473958,1556.8990173339844,1539.4890238444011,1522.499043782552,1505.9090576171875,1489.6790771484375,1473.789082845052,1458.2091166178386,1442.9391174316406,1427.9291280110676,1413.1891581217449,1398.8992411295574,1385.2592468261719,1372.2292785644531,1359.7693277994792,1347.829325358073,1336.3793436686199,1325.3893737792969,1314.8193868001301,1304.639404296875,1294.8294270833333,1285.3694356282551,1276.2294820149739,1267.3894653320312,1258.8394978841145,1250.5494791666667,1242.4995218912761,1234.6795145670574,1227.0695292154949,1219.6595560709636,1212.4295450846355,1205.3195393880208,1198.2595316569011,1191.259541829427,1184.2995503743489,1177.3995564778645,1170.5295511881511,1163.7095540364583,1156.9195556640625,1150.1695251464844,1143.4495849609375,1136.819559733073,1130.3095804850261,1123.9295959472656,1117.6595865885417,1111.4995829264324,1105.4395955403645,1099.4696146647136,1093.5796000162761,1087.7796122233074,1082.0496012369792,1076.4196065266926,1070.9096374511719,1065.5296427408855,1060.2596638997395,1055.0896504720051,1050.0796915690105,1045.3096618652344,1040.7397054036458,1036.3696899414062,1032.1597290039062,1028.2197367350261,1024.6197509765625,1021.3297678629557,1018.3197784423828,1015.5597890218099,1013.0198109944662,1010.6898193359375,1008.5398203531901,1006.5498250325521,1004.7198435465494,1003.0098368326823,1001.4198404947916,999.9378611246744,998.5478515625,997.2418619791666,996.0098673502604,994.8438618977865,993.7378641764323,992.6848704020182,991.6778818766276,990.7118631998698,989.7838694254557,988.8888753255209,988.0218760172526,987.1808776855469,986.3618774414062,985.5628763834635,984.7818908691406,984.015879313151,983.2628784179688,982.5208892822266,981.7888844807943,981.0658823649088,980.3498789469401,979.639882405599,978.9338785807291,978.2328745524088,977.5348815917969,976.838877360026,976.1438751220703,975.4508870442709,974.7568817138672,974.0628763834635,973.3668874104818,972.6678771972656,971.9648793538412,971.2578684488932,970.5458831787109,969.8268839518229,969.1018727620443,968.369873046875,967.6298675537109,966.8868713378906,966.1448771158854,965.4038696289062,964.6638793945312,963.9228769938151,963.1818644205729,962.4398701985677,961.6948699951172,960.9478759765625,960.1988779703776,959.4458719889323,958.6898701985677,957.9298756917318,957.1648763020834,956.3968658447266,955.6228637695312,954.8448689778646,954.0628662109375,953.2748718261719,952.4818674723307,951.682871500651,950.8788757324219,950.0698750813802,949.2548675537109,948.4338684082031,947.6068725585938,946.7748616536459,945.9358622233073,945.0918629964193,944.2418619791666,943.3848571777344,942.5228525797526,941.6538492838541,940.7788645426432,939.8978576660156,939.0108591715494,938.1178588867188,937.2178700764974,936.3118642171224,935.3998565673828,934.4818522135416,933.557861328125,932.6298624674479,931.6968485514323,930.7588602701823,929.817860921224,928.8728586832682,927.9238535563151,926.9718577067057,926.0178578694662,925.0598551432291,924.0988515218099,923.1358642578125,922.1708526611328,921.2018483479818,920.2308502197266,919.2578531901041,918.2818603515625,917.3038533528646,916.3218638102213,915.338857014974,914.3548482259115,913.370849609375,912.3908487955729,911.4158528645834,910.4448547363281,909.4788513183594,908.5178476969401,907.5598551432291,906.6048533121744,905.6528574625651,904.703847249349,903.7568562825521,902.8118591308594,901.8698476155599,900.9288533528646,899.9888610839844,899.0508524576823,898.1138509114584,897.1778564453125,896.2428487141927,895.307861328125,894.3748626708984,893.4418487548828,892.5088500976562,891.5768483479818,890.6448465983073,889.7138468424479,888.7818450927734,887.8508504231771,886.9198506673177,885.9898427327474,885.0588429768881,884.1278483072916,883.1968536376953,882.266855875651,881.3358408610026,880.4048563639323,879.5208638509115,878.723876953125,878.0068715413412,877.3618825276693,876.7798817952474,876.2578837076823,875.7868906656901,875.3638865152994,874.983896891276,874.6418965657552,874.3348897298177,874.0588938395182,873.8108927408854,873.587890625,873.3878987630209,873.2088979085287,873.0478922526041,872.9028879801432,872.7739054361979,872.6578928629557,872.5539093017578,872.4608968098959,872.3769022623698,872.3029022216797,872.2359008789062,872.1769002278646,872.1228942871094,872.0758921305338,872.0328979492188,871.9948984781901,871.9609018961588,871.9309031168619,871.9039001464844,871.8798980712891,871.8579050699869,871.8389027913412,871.8219045003256,871.8059031168619,871.7918955485026,871.7799072265625,871.7689056396484,871.7588958740234,871.7489115397135,871.7409057617188,871.732899983724,871.7259063720703,871.7199045817057,871.7129058837891,871.7069040934244,871.701904296875,871.6959025065104,871.6908976236979,871.6859029134115,871.6799011230469,871.6749013264974,871.6699015299479,871.6639099121094,871.6588999430338,871.6528981526693,871.6469065348307,871.6409098307291,871.6339060465494,871.6279042561849,871.6209004720052,871.6129099527994,871.6048990885416,871.5969085693359,871.5888977050781,871.5799001057943,871.5698954264323,871.5599060058594,871.5499013264974,871.5388946533203,871.5278981526693,871.5159098307291,871.5029042561849,871.4899088541666,871.4759012858073,871.461903889974,871.4468994140625,871.430908203125,871.4148966471354,871.3979034423828,871.3798980712891,871.3609059651693,871.3419087727865,871.3218994140625,871.3009033203125,871.2789052327474,871.2559000651041,871.2319081624349,871.2069040934244,871.1809031168619,871.1549123128256,871.1269073486328,871.0979054768881,871.0678965250651,871.0369008382162,871.0049031575521,870.9729054768881,870.941904703776,870.9119008382162,870.8818969726562,870.8539072672526,870.8289031982422,870.8079071044922,870.7889099121094,870.7729085286459,870.7599029541016,870.7489064534506,870.7389017740885,870.7319030761719,870.7258961995443,870.7209014892578,870.7178955078125,870.7159016927084,870.7148996988932,870.7149047851562,870.7158966064453,870.7169087727865,870.7189025878906,870.7219034830729,870.7249094645182,870.7289072672526,870.73291015625,870.7379048665365,870.7419026692709,870.7469075520834,870.7528940836588,870.7579091389974,870.763916015625,870.7699076334635,870.7759094238281,870.7819112141927,870.7889048258463,870.7949015299479,870.8019053141276,870.8079020182291,870.8149058024088,870.8209025065104,870.8278961181641,870.8349049886068,870.8419036865234,870.8479054768881,870.8549092610677,870.8619028727213,870.8689117431641,870.8749084472656,870.8819020589193,870.888905843099,870.8958994547526,870.9019114176432,870.9089050292969,870.9159088134766,870.9219055175781,870.9289143880209,870.9359079996744,870.9419097900391,870.9489034016927,870.9549102783203,870.961903889974,870.9679107666016,870.9749043782552,870.9809010823568,870.9869028727213,870.9939117431641,870.9999135335287,871.0059051513672,871.0119120279948,871.0179036458334,871.0248972574869,871.0309041341146,871.0369059244791,871.0429026285807,871.0489095052084,871.0549011230469,871.0608978271484,871.066904703776,871.0719095865885,871.0779062906901,871.0838979085287,871.0899047851562,871.0959065755209,871.1009012858073,871.1069081624349,871.1119079589844,871.1179046630859,871.1239064534506,871.1289011637369,871.1349029541016,871.1398976643881,871.1449076334635,871.1509043375651,871.1559092203776,871.1619008382162,871.1669057210287,871.1719055175781,871.1769053141276,871.1819000244141,871.1879018147787,871.1929066975912,871.1979166666666,871.2029062906901,871.2079060872396,871.2129160563151,871.2179005940756,871.222910563151,871.2279154459635,871.2329050699869,871.2369079589844,871.2419077555338,871.2468973795573,871.2519073486328,871.2559000651041,871.2608998616537,871.2659098307291,871.2698974609375,871.2749074300131,871.2799072265625,871.2839050292969,871.2889048258463,871.2928924560547,871.2969055175781,871.3018951416016,871.3059031168619,871.3109029134115,871.3149007161459,871.3189036051432,871.3239084879557,871.3279012044271,871.3318990071615,871.3359018961588,871.3398996988932,871.3439076741537,871.3478953043619,871.3529001871744,871.3569132486979,871.3608957926432,871.3648986816406,871.367909749349,871.3719075520834,871.3758951822916,871.3799082438151,871.3838958740234,871.3878987630209,871.3908996582031,871.3949127197266,871.398915608724,871.4009145100912};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9491322835286,403.1169662475586,405.75096130371094,408.58695729573566,411.4049580891927,414.2139663696289,417.0139617919922,419.69896697998047,422.16996510823566,424.4429702758789,426.5249659220378,428.4259719848633,430.1509704589844,431.7059733072917,433.0959726969401,434.323974609375,435.39397684733075,436.3369776407878,437.1789830525716,437.91698455810547,438.55298614501953,439.08398691813153,439.5129877726237,439.83699289957684,440.0589904785156,440.1789906819661,440.1969935099284,440.1389897664388,440.02699025472003,439.85999298095703,439.63498942057294,439.35199483235675,439.01099395751953,438.61099497477215,438.1510009765625,437.63200124104816,437.0539957682292,436.4459966023763,435.83599853515625,435.2200012207031,434.5969975789388,433.96400197347003,433.3209966023763,432.66499582926434,431.9969991048177,431.31399790445965,430.6170018513997,429.90800221761066,429.19000244140625,428.46299997965497,427.7260004679362,426.97900136311847,426.2210057576497,425.4520034790039,424.67000579833984,423.8770065307617,423.0709991455078,422.2540054321289,421.42500559488934,420.5840021769206,419.7310078938802,418.86700439453125,417.9910024007161,417.1020050048828,416.2020034790039,415.28800710042316,414.3620071411133,413.42100524902344,412.4610061645508,411.4840087890625,410.4900080362956,409.4770100911458,408.44801330566406,407.40100860595703,406.3360112508138,405.2550048828125,404.1570053100586,403.04100545247394,401.9080073038737,400.7580108642578,399.59100850423175,398.4070103963216,397.2060089111328,395.98901112874347,394.75601450602215,393.5060119628906,392.24101003011066,390.9830093383789,389.75501759847003,388.55200958251953,387.37300872802734,386.2160135904948,385.0800145467122,383.9640121459961,382.8670120239258,381.7880096435547,380.72501373291016,379.6790084838867,378.64801025390625,377.6330159505208,376.63101450602215,375.6440073649089,374.66901143391925,373.708012898763,372.75901285807294,371.82201131184894,370.8970133463542,369.98301188151044,369.0800145467122,368.1880137125651,367.30600992838544,366.4350102742513,365.57301330566406,364.72100830078125,363.8790105183919,363.0450134277344,362.2210108439128,361.406010945638,360.59900919596356,359.8010075887044,359.01000722249347,358.2280095418294,357.4540100097656,356.68700917561847,355.92801157633465,355.17700958251953,354.4330088297526,353.7100118001302,353.02001190185547,352.3630142211914,351.7350082397461,351.1360092163086,350.5640106201172,350.0190073649089,349.50001271565753,349.00500742594403,348.5340092976888,348.08301035563153,347.65000915527344,347.2340087890625,346.8350118001302,346.45301055908203,346.08800252278644,345.74100494384766,345.4090092976888,345.09400685628253,344.79501088460285,344.5130106608073,344.24600474039715,343.99400838216144,343.7580032348633,343.53800710042316,343.3320032755534,343.1420084635417,342.9660059611003,342.8050003051758,342.6590092976888,342.5279998779297,342.4100036621094,342.30700429280597,342.218999226888,342.1440022786458,342.0830078125,342.03600311279297,342.0030008951823,341.98400115966797,341.9780044555664,341.9860026041667,342.00700124104816,342.04100036621094,342.08900451660156,342.1510009765625,342.2250035603841,342.31300099690753,342.4129994710286,342.5270029703776,342.6530024210612,342.7789993286133,342.88999938964844,342.98999786376953,343.0800018310547,343.16000111897785,343.23199971516925,343.2970021565755,343.3550033569336,343.40699768066406,343.45300038655597,343.49499766031903,343.5320053100586,343.56500244140625,343.593999226888,343.61899820963544,343.6409962972005,343.6599934895833,343.67699940999347,343.69000244140625,343.7020009358724,343.7099965413411,343.7170003255208,343.7219975789388,343.7239990234375,343.7250010172526,343.7250010172526,343.7229944864909,343.7199986775716,343.7160008748372,343.71099853515625,343.70499928792316,343.6989974975586,343.69100189208984,343.68299865722656,343.6739959716797,343.6639989217122,343.6539942423503,343.64300028483075,343.6309992472331,343.6190007527669,343.6070022583008,343.59400177001953,343.5800043741862,343.5659993489583,343.5510025024414,343.53600056966144,343.521001180013,343.50500233968097,343.48900349934894,343.47300211588544,343.4559961954753,343.4390004475911,343.4219970703125,343.4040044148763,343.38599904378253,343.36799875895184,343.34899648030597,343.3310012817383,343.31199900309247,343.2929967244466,343.2729949951172,343.2530008951823,343.23299407958984,343.21199798583984,343.1909993489583,343.16900126139325,343.14600372314453,343.1230010986328,343.0999984741211,343.0759989420573,343.0509948730469,343.0259958902995,343.0010019938151,342.9749984741211,342.9490000406901,342.9229965209961,342.8969955444336,342.8710021972656,342.84400177001953,342.81700134277344,342.7899983723958,342.76300048828125,342.73600006103516,342.70799255371094,342.68099721272785,342.65299733479816,342.62599690755206,342.5979970296224,342.5699996948242,342.5429992675781,342.51499938964844,342.4869969685872,342.4590021769206,342.4310022989909,342.4030024210612,342.37500254313153,342.3479970296224,342.3199971516927,342.291997273763,342.26399993896484,342.2360026041667,342.20800018310547,342.1800003051758,342.15199788411456,342.1230010986328,342.0949961344401,342.06699625651044,342.03900146484375,342.01100667317706,341.9830017089844,341.9549967447917,341.92699940999347,341.8989995320638,341.8709996541341,341.84300231933594,341.81500244140625,341.78700256347656,341.75900014241535,341.73100026448566,341.7030029296875,341.6750005086263,341.6470006306966,341.61900329589844,341.59100341796875,341.56299591064453,341.5350062052409,341.5069986979167,341.4780019124349,341.4499994913737,341.42199961344403,341.39400482177734,341.3659973144531,341.33799997965497,341.3100001017253,341.28200276692706,341.25399525960285,341.2259979248047,341.19700113932294,341.1689961751302,341.1409962972005,341.1129964192708,341.08399963378906,341.0560022989909,341.0279998779297,341.0,340.97100321451825,340.94299570719403,340.9139989217122,340.88599904378253,340.8570022583008,340.82899983723956,340.8000030517578,340.77099863688153,340.7430013020833,340.71400197347003,340.6850001017253,340.65599314371747,340.6270014444987,340.5979995727539,340.5690002441406,340.5400034586589,340.51099650065106,340.48100026448566,340.4520009358724,340.4229965209961,340.3939971923828,340.36500040690106,340.33600362141925,340.30699666341144,340.2780024210612,340.25,340.22100321451825,340.19299570719403,340.16500091552734,340.13700103759766,340.1080017089844,340.07999928792316,340.051996866862,340.0250015258789,339.9970016479492,339.96899668375653,339.94100189208984,339.9139989217122,339.88599904378253,339.8590037027995,339.83099873860675,339.8040008544922,339.7769953409831,339.74999745686847,339.7229995727539,339.6959966023763,339.66900126139325,339.64200083414715,339.61500040690106,339.58799997965497,339.5609944661458,339.53500111897785,339.50800069173175,339.4809977213542,339.45499928792316,339.4289957682292,339.4020029703776,339.3760045369466,339.3500010172526,339.322998046875,339.2969970703125,339.27100372314453,339.2450002034505,339.21899668375653,339.1929982503255,339.16699981689453,339.14100138346356,339.1160024007161,339.08999888102215,339.06400299072266,339.0389989217122,339.01300048828125,338.9879964192708,338.96200307210285,338.93699900309247,338.91099802652997,338.88599904378253,338.86100006103516,338.8350016276042,338.80999755859375,338.7849985758464,338.76000213623047,338.73500061035156,338.7100016276042,338.6850001017253,338.6599985758464,338.63599904378253,338.6109975179036,338.58600362141925,338.56099700927734,338.53700002034503,338.51200103759766,338.4880065917969,338.46300252278644,338.4389953613281,338.41399637858075,338.39000193277997,338.3660024007161,338.34099833170575,338.31700134277344,338.2930043538411,338.2690022786458,338.24500528971356,338.2210006713867,338.1969985961914,338.1730016072591,338.1489995320638,338.12500254313153,338.10099538167316,338.0769958496094,338.0529963175456,338.0299987792969,338.0059992472331,337.98199971516925,337.95899963378906,337.9349950154622,337.91200002034503,337.88800048828125,337.86500040690106,337.8420003255208,337.81800079345703,337.7949981689453,337.7720006306966,337.7489980061849,337.7249984741211,337.7019958496094,337.6789957682292,337.65599822998047,337.6329981486003,337.6100031534831,337.58699798583984,337.56399790445965,337.54199981689453,337.51899973551434,337.4960021972656,337.4729970296224,337.4509963989258,337.4280039469401,337.4049987792969,337.38299560546875,337.36000061035156,337.33799997965497,337.31499735514325,337.29300181070965,337.27100372314453,337.2480010986328,337.2259979248047,337.2040049235026,337.18099721272785,337.15899658203125,337.13700103759766,337.11500040690106,337.09300231933594,337.0710042317708,337.0489985148112,337.0270004272461,337.0049997965495,336.98299916585285,336.96099853515625,336.9399998982747,336.9179992675781,336.896001180013,336.87400309244794,336.8630015055339};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.753809293111164,21.1880939801534,23.537092844645183,27.863791306813557,32.888890425364174,38.58898957570394,44.94098981221517,51.186890602111816,56.59479204813639,61.192992528279625,65.00849374135335,68.06699434916179,70.39279619852702,72.00929578145345,72.93879699707031,73.20269775390625,72.82169850667317,72.09629694620769,71.31789779663086,70.48849805196126,69.61009915669759,68.68459828694661,67.71369806925456,66.69909858703613,65.6424986521403,64.54529889424641,63.40899848937988,62.276098569234215,61.187499046325684,60.14229838053385,59.139198303222656,58.17719872792562,57.25509866078695,56.371798515319824,55.526398340861,54.71769905090332,53.94479846954346,53.203198750813804,52.48899841308594,51.80149904886881,51.140198389689125,50.50459829966227,49.89409859975179,49.30799802144369,48.74589856465658,48.207098642985024,47.69099807739258,47.19709841410319,46.724698066711426,46.27319876352946,45.842098236083984,45.43079821268717,45.03889878590902,44.6657985051473,44.310898780822754,43.973898569742836,43.654098192850746,43.35049851735433,43.06199868520101,42.78809769948324,42.528398513793945,42.282398541768394,42.04969787597656,41.829799016316734,41.6223980585734,41.426998138427734,41.24329853057861,41.06859874725342,40.9006986618042,40.73919868469238,40.584197680155434,40.43529828389486,40.29249795277914,40.15549882253011,40.024298350016274,39.8985980351766,39.7781982421875,39.65879821777344,39.535698890686035,39.40929857889811,39.27979850769043,39.147098223368324,39.01269817352295,38.87769889831543,38.7422981262207,38.606398582458496,38.47009785970052,38.33239873250326,38.19229825337728,38.04979864756266,37.904998461405434,37.75809860229492,37.60899829864502,37.457798639933266,37.3045981725057,37.149498303731285,36.99249871571859,36.83369827270508,36.67309856414795,36.51079909006754,36.34669844309489,36.18109893798828,36.01379903157552,35.8450984954834,35.67479864756266,35.50299866994222,35.329898834228516,35.15529823303223,34.97939840952555,34.802199045817055,34.62369887034098,34.44399833679199,34.26309871673584,34.08099842071533,33.897698720296226,33.71329879760742,33.52789815266927,33.341298739115395,33.153798739115395,32.965198834737144,32.77559884389242,32.58509922027588,32.393598874409996,32.20129871368408,32.00799894332886,31.813798586527508,31.61879889170329,31.422998746236164,31.226398944854736,31.028899033864338,30.83069896697998,30.631698926289875,30.43189875284831,30.23129892349243,30.029998938242596,29.827998797098797,29.62519915898641,29.421699047088623,29.217499256134033,29.01249885559082,28.806899070739746,28.600598971048992,28.393598715464275,28.185898939768474,27.977599143981934,27.768599033355713,27.558999061584473,27.34869893391927,27.137799104054768,26.92629925409953,26.714099248250324,26.501398881276447,26.288098971048992,26.074199040730793,25.859699090321858,25.644699096679688,25.429099241892498,25.212899049123127,24.996199289957683,24.778899033864338,24.5611990292867,24.342899322509766,24.124098936716717,23.90479914347331,23.68489933013916,23.464599291483562,23.24389918645223,23.0225993792216,22.800899346669514,22.57859929402669,22.35599946975708,22.132899443308514,21.90929937362671,21.685399532318115,21.460899353027344,21.236099402109783,21.010899543762207,20.785199642181396,20.559099356333416,20.33269961675008,20.105799198150635,19.878599643707275,19.65109936396281,19.42319981257121,19.194899559020996,18.96639919281006,18.737499237060547,18.508299509684246,18.278799215952557,18.048999468485516,17.818899790445965,17.588599681854248,17.357999801635742,17.12709967295329,16.895999590555828,16.664599577585857,16.43299945195516,16.201199531555176,15.969099521636963,15.736799558003744,15.504299481709799,15.271599690119425,15.038599650065104,14.805499792098999,14.572199583053589,14.338599602381388,14.104899724324545,13.870999733606974,13.636899630228678,13.402699708938599,13.16819969813029,12.933599789937338,12.698899666468302,12.463899691899618,12.22879966100057,11.993499755859375,11.758099873860678,11.522599776585897,11.286799669265747,11.050999879837036,10.81499981880188,10.578799883524576,10.342499812444052,10.106099764506022,9.869479894638062,9.632759888966879,9.395919958750406,9.158949931462606,8.921839872996012,8.684609969456991,8.447259902954102,8.209779818852743,7.972180008888245,7.734450022379558,7.496610045433044,7.258650024731954,7.020570000012715,6.786409974098206,6.5600599845250445,6.341270009676616,6.129780054092407,5.925349990526835,5.727740049362183,5.536730051040649,5.352099974950154,5.173619985580444,5.0011099974314375,4.834349989891052,4.673150022824605,4.517339984575908,4.366729935010274,4.221140027046204,4.080409963925679,3.944379985332489,3.812879979610443,3.6857799887657166,3.5629100600878396,3.4441399772961936,3.3293399810791016,3.218370020389557,3.1110999981562295,3.0074100295702615,2.907169977823893,2.8102800051371255,2.7166300217310586,2.6260900100072226,2.538580000400543,2.453980008761088,2.3722100059191384,2.293160001436869,2.216749986012777,2.1428900162378945,2.071490009625753,2.002479980389277,1.9357599914073944,1.8712700108687084,1.8089299996693928,1.7486699918905895,1.6904099881649017,1.6341000000635784,1.579669992129008,1.527049978574117,1.4761800070603688,1.4270100096861522,1.379480004310608,1.3335399727026622,1.2891199886798859,1.2461900015672047,1.204690009355545,1.1645700136820476,1.1257799963156383,1.088290015856425,1.0520499845345814,1.0170199871063232,0.9831559956073761,0.9504189987977346,0.9187729954719543,0.8881819993257523,0.858610009153684,0.8300229956706365,0.8023889909187952,0.7756750037272772,0.7498520066340765,0.7248880018790563,0.7007570068041483,0.6774290005366007,0.6548789938290914,0.6330800006786982,0.6120070020357767,0.5916349987188975,0.5719430049260458,0.5529059916734695,0.5345040013392767,0.5167139967282613,0.4995170036951701,0.48289300004641217,0.4668219983577728,0.4512860005100568,0.43626800427834195,0.4217499991257985,0.4077159985899925,0.3941490054130554,0.38103300084670383,0.36835499852895737,0.3560979987184207,0.34425000349680585,0.33279600242773694,0.32172299921512604,0.31102000425259274,0.3006719996531804,0.2906690016388893,0.28099900235732395,0.2716509973009427,0.26261400431394577,0.25387799988190335,0.2454329989850521,0.23726900046070418,0.22937599942088127,0.2217469997704029,0.21437100196878114,0.2072409987449646,0.20034799973169962,0.1936850013832251,0.18724300215641657,0.1810160018503666,0.1749959997832775,0.16917600110173225,0.16354999939600626,0.15811099981268248,0.1528529996673266,0.14777000124255815,0.1428560030957063,0.1381060021619002,0.13351400072375932,0.12907399982213974,0.12478299997746944,0.12063399950663249,0.11662300179402034,0.11274500067035358,0.10899700038135052,0.10537300010522206,0.10186999912063281,0.09848339979847272,0.09520939985911052,0.0920442994683981,0.08898450123767059,0.08602640094856422,0.08316680043935776,0.0804021991789341,0.0777295995503664,0.07514589900771777,0.07264820051689942,0.07023349838952224,0.06789910048246384,0.06564229975144069,0.06346059994151194,0.061351499830683075,0.059312500059604645,0.05734129964063565,0.05543560069054365,0.053593299662073456,0.05181229983766874,0.05009049984316031,0.04842590012898048,0.046816700138151646,0.04526100028306246,0.043757000006735325,0.04230299964547157,0.04089739949752887,0.03953850052009026,0.03822469959656397,0.03695470001548529,0.03572690021246672,0.03453980044772228,0.03339229958752791,0.03228289975474278,0.03121030004695058,0.030173500068485737,0.02917099992434184,0.028201900112132233,0.02726510011901458,0.02635929997389515,0.025483700291564066,0.0246370998211205,0.02381869995345672,0.023027499827245872,0.022262600250542164,0.021523100168754656,0.020808199886232615,0.02011710001776616,0.019448900129646063,0.018802900177737076,0.018178399962683518,0.01757469990601142,0.016990999846408766,0.01642670001213749,0.015881100048621494,0.015353700068468848,0.014843800105154514,0.014350799843668938,0.013874299901848039,0.013413499963159362,0.012968099908903241,0.01253740000538528,0.012121099978685379,0.011718600057065487,0.011329500082259377,0.010953300089264909,0.010589599919815859,0.010238000191748142,0.009898049989715219,0.009569400067751607,0.009251679992303252,0.00894450000487268,0.008647530029217402,0.008360430132597685,0.008082859916612506,0.00781451006575177,0.007555079995654523,0.007304260041564703,0.0070617700306077795,0.006827340034457545,0.006600689996654789,0.006381570089918871,0.0061697299825027585,0.005964920002346237,0.005766920046880841,0.005575490028907855,0.005390420012796919,0.005211489973589778,0.005038509921481212,0.004871270037256181,0.004709580020668606,0.004553260010046263,0.004402139961409072,0.004256030001367132,0.004114770020047824,0.003978209996906419,0.003846169973257929,0.003718530021918317,0.0035951199824921787,0.003475800001372894,0.0033604499767534435,0.003248929996819546,0.0031411099674490592,0.0030368800119807324,0.002936100005172193,0.0028386700238722065,0.002744470005078862,0.0026533999868358174,0.0025653499954690537,0.002480229983727137,0.002397929997338603,0.002318360008454571,0.0022414399815412858,0.002167060001132389,0.002095160035726925,0.00202565003807346,0.0019584399997256696,0.0018934600326853495,0.0018306400161236525,0.0017698999824157606,0.0017111799970734864,0.0016544099877743672,0.0015995199889099847,0.0015725400007795542};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.766908009847,90.27675882975261,96.25290997823079,101.51613489786784,106.94242032368977,112.51471265157063,118.21776008605957,123.1871903737386,126.6230239868164,128.6351572672526,129.31938807169595,128.76673952738443,127.05921173095703,124.27375666300456,120.48045539855957,115.74612744649251,110.13004302978516,104.24504661560059,98.66115315755208,93.35910034179688,88.32085927327473,83.52938588460286,78.96869277954102,74.62358093261719,70.48005104064941,66.52449607849121,62.74463621775309,59.175947189331055,55.85178311665853,52.75638484954834,49.874770164489746,47.19313589731852,44.69828446706136,42.37791728973389,40.22053368886312,38.21523666381836,36.35192394256592,34.6178944905599,33.00175031026205,31.496098200480144,30.09393580754598,28.788565158843994,27.573785463968914,26.443698565165203,25.392903963724773,24.416001955668133,23.508294423421223,22.666182200113933,21.88636541366577,21.164743105570476,20.49741506576538,19.880682309468586,19.311245441436768,18.78570334116618,18.3011581103007,17.854808648427326,17.44395621617635,17.06750249862671,16.724147001902264,16.411587715148926,16.127625862757366,15.870261033376059,15.63749368985494,15.427624146143595,15.238952239354452,15.070078611373901,14.919402758280436,14.7851243019104,14.665643692016602,14.559761842091879,14.466678857803345,14.385294278462728,14.315009117126465,14.254822413126627,14.20403504371643,14.162146965662638,14.128357489903768,14.098259687423706,14.068058649698893,14.037558635075888,14.006958484649658,13.97635849316915,13.946560064951578,13.918362538019815,13.891864856084188,13.866866827011108,13.843268553415934,13.818164269129435,13.788758277893066,13.755353053410849,13.718248208363852,13.677743514378866,13.634039322535196,13.587435881296793,13.53823208808899,13.48642873764038,13.432325522104898,13.376022736231485,13.317820151646933,13.257717450459799,13.195815404256185,13.132413228352865,13.067411263783773,13.00110944112142,12.933407545089722,12.864606062571207,12.794604539871216,12.723603010177612,12.651601870854696,12.578700542449951,12.504899581273397,12.43039838473002,12.354997237523397,12.278996388117472,12.202295541763306,12.1249946753184,12.047094106674194,11.968693256378174,11.889692385991415,11.8102920850118,11.730391105016073,11.649990638097128,11.569290161132812,11.488189935684204,11.406689087549845,11.324788649876913,11.242688417434692,11.16018788019816,11.077387491861979,10.994287014007568,10.91098666191101,10.82728624343872,10.743386030197144,10.659285624821981,10.574785153071085,10.490185022354126,10.405184348424276,10.32008441289266,10.234683752059937,10.148983558019003,10.063183307647705,9.977072715759277,9.890772740046183,9.80425230662028,9.717522064844767,9.630591789881388,9.543461561203003,9.456131140391031,9.368610938390097,9.280900716781616,9.193000475565592,9.104930400848389,9.016679922739664,8.928249756495157,8.839649597803751,8.75088938077291,8.661959091822306,8.572868744532267,8.483628829320272,8.394218524297079,8.304668188095093,8.214968045552572,8.125117858250936,8.035127600034079,7.944997469584147,7.854727307955424,7.7643271287282305,7.673796931902568,7.583126783370972,7.492336591084798,7.401416341463725,7.310376246770223,7.219216068585713,7.1279358466466265,7.036545713742574,6.945045590400696,6.853435397148132,6.761705279350281,6.6698851982752485,6.5779649416605634,6.485944906870524,6.393834789594014,6.301644643147786,6.20937458674113,6.117024501164754,6.024604360262553,5.932124376296997,5.839584191640218,5.746974070866902,5.654314001401265,5.561593969662984,5.4688239097595215,5.375993808110555,5.283123811086019,5.190213720003764,5.097253680229187,5.004243532816569,4.911203543345134,4.818113446235657,4.72498341401418,4.6318133274714155,4.538613239924113,4.445363283157349,4.352083206176758,4.25877312819163,4.16541314125061,4.072033087412517,3.978602965672811,3.8851529359817505,3.791662851969401,3.6981328328450522,3.6045828064282737,3.5109827319780984,3.4173627297083535,3.323712686697642,3.230022609233856,3.136292576789856,3.042542517185211,2.948752462863922,2.854932407538096,2.761082410812378,2.667202333609263,2.573292334874471,2.47934228181839,2.385362227757772,2.2913521925608316,2.197312116622925,2.103242059548696,2.009142051140467,1.9150019884109497,1.82083194454511,1.726631909608841,1.6324018935362499,1.5381418069203694,1.4438518583774567,1.3495315710703533,1.255171924829483,1.1642285883426666,1.0798782706260681,1.001636028289795,0.9290716896454493,0.861763616402944,0.7993331104516983,0.7414271185795466,0.6877166976531347,0.6378998557726542,0.5916926513115565,0.5488330920537313,0.5090802237391472,0.47220804790655774,0.43800658732652664,0.4062838827570279,0.37685992817083996,0.3495667651295662,0.3242513835430145,0.3007708291212718,0.27899108330408734,0.2587881771226724,0.24004912128051123,0.22266792505979538,0.20654559507966042,0.1915911448498567,0.17771958063046137,0.1648529184361299,0.1529181549946467,0.14184830337762833,0.13157936558127403,0.12205435397724311,0.11321926862001419,0.10502311773598194,0.09742130835851033,0.09036983673771222,0.08382881619036198,0.07776154515643914,0.07213342748582363,0.0669128696123759,0.06207027037938436,0.05757833582659563,0.053411467311282955,0.04954636810968319,0.0459610391408205,0.04263518409182628,0.039550103868047394,0.036688401053349175,0.03403377501914898,0.03157123069589337,0.029287067086746294,0.027168086574723322,0.02520259019608299,0.023379279300570488,0.02168785423661272,0.020118916872888803,0.01866356764609615,0.017313407578816015,0.01606103723558287,0.014899257415284714,0.01382156927138567,0.012821872641022006,0.011894468683749437,0.01103415759280324,0.010236040378610292,0.009495767066255212,0.00880901818163693,0.008171944102893272,0.007580965291708708,0.007032732052418093,0.006524164734097819,0.006052383648542066,0.0056147288996726274,0.00520872095754991,0.004832089917423825,0.00448270607739687,0.004158589600895842,0.003857910807710141,0.003578979657807698,0.0033202264263915517,0.00308018127301087,0.002857494323203961,0.002650915722673138,0.002459275555641701,0.0022814939729869366,0.002116571025302013,0.001963566852888713,0.0018216315559887637,0.0016899551847018301,0.0015677977935411036,0.0014544795364296685,0.001349350408418104,0.0012518305253858368,0.0011613498500082642,0.0010774185551175226,0.00099954860828196,0.0009273120910317326,0.0008602960151620209,0.0007981254554276044,0.0007404494196331749,0.0006869419594295323,0.0006373020830020929,0.0005912508592397595,0.0005485282745212317,0.0005088933782341579,0.00047212317925489816,0.00043801070569315925,0.0004063629773251402,0.00037700401783998433,0.0003497658302270186,0.00032449644883551326,0.0003010528695691998,0.0002793031211088722,0.00025912621155536425,0.00024040614395441176,0.00022303994289056087,0.0002069276076023622,0.0001919801531281943,0.0001781125865818467,0.00016524691697365293,0.0001533111511283399,0.00014223729643466262,0.00013196335688310987,0.00012243234535465794,0.000113589257428733,0.00010538510711436781,9.777429477253463e-05,9.071292333828751e-05,8.416160077710326e-05,7.808363079675473e-05,7.244471271405928e-05,6.721305423222172e-05,6.235935597942444e-05,5.7856220337271225e-05,5.367835274228128e-05,4.9802253064020384e-05,4.620612526196055e-05,4.2869670323852915e-05,3.977429029570582e-05,3.690238706136976e-05,3.4237962912205454e-05,3.1765917507679355e-05,2.9472454722660284e-05,2.734457454304599e-05,2.537037895914788e-05,2.353876773971327e-05,2.1839343389729038e-05,2.0262706736199714e-05,1.8799957767138647e-05,1.744279794972196e-05,1.618362815255144e-05,1.5015348708402598e-05,1.3931460671301465e-05,1.2925764773778306e-05,1.19927609982066e-05,1.1127050584036624e-05,1.0323933490023288e-05,9.578750374809411e-06,8.88737175349282e-06,8.24589831912211e-06,7.650749807908142e-06,7.0985568451457466e-06,6.586229649959326e-06,6.110888875809906e-06,5.669864435731142e-06,5.26067670610549e-06,4.881015873555346e-06,4.528772289328724e-06,4.201946012472035e-06,3.898717409356323e-06,3.6173764404641893e-06,3.356343370342074e-06,3.114138432162387e-06,2.8894316225584285e-06,2.680933145408441e-06,2.487483167593988e-06,2.3080016831045214e-06,2.1414688831100648e-06,1.986954818751959e-06,1.8435896341391829e-06,1.7105733718381089e-06,1.5871561155715124e-06,1.4726479378168733e-06,1.3663989003968406e-06,1.267819101258283e-06,1.1763485285124868e-06,1.0914873295556997e-06,1.012745428852213e-06,9.396819820040037e-07,8.718939881191545e-07,8.089964940912372e-07,7.506375207337138e-07,6.964890957306125e-07,6.462472773212843e-07,5.996310884863002e-07,5.563775715700103e-07,5.162447062427115e-07,4.790075536220684e-07,4.4445711940473603e-07,4.123994325292794e-07,3.8265350118156977e-07,3.5505435628617005e-07,3.29445998185444e-07,3.056854538385778e-07,2.8363872435951026e-07,2.6318183662018174e-07,2.442007970652564e-07,2.2658961521907864e-07,2.1024830113939666e-07,1.9508586509194478e-07,1.810173178758608e-07,1.6796266658995288e-07,1.5585091854101543e-07,1.4461207342719717e-07,1.3418315466158978e-07,1.2450715303202742e-07,1.1552907904407068e-07,1.0719893950295045e-07,4.19702708143177e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.742653687795002,19.401511987050373,20.76111634572347,23.196019172668457,25.97072124481201,29.078122933705647,32.51132154464722,35.90242004394531,38.8917179107666,41.48741594950358,43.69751421610514,45.52951240539551,46.991010665893555,48.08910814921061,48.83070659637451,49.22270488739014,49.27160485585531,49.133204778035484,48.96040439605713,48.753804524739586,48.5143035252889,48.24260298411051,47.939503033955894,47.605703035990395,47.24180285135905,46.84850311279297,46.42640240987142,45.997403144836426,45.58250300089518,45.18180274963379,44.79490343729655,44.42170238494873,44.06200313568115,43.71570364634196,43.38240273793539,43.062103271484375,42.75440247853597,42.457303047180176,42.16860262552897,41.88830248514811,41.61630312601725,41.3526029586792,41.09720325469971,40.84980328877767,40.61050351460775,40.379302978515625,40.1559034983317,39.94070339202881,39.733903884887695,39.53550370534261,39.345303535461426,39.16320355733236,38.98910331726074,38.822903633117676,38.66450309753418,38.513803482055664,38.37050437927246,38.23430347442627,38.104403495788574,37.98070398966471,37.86320400238037,37.75170358022054,37.64600340525309,37.54620361328125,37.452003161112465,37.363404273986816,37.2802038192749,37.20080407460531,37.123403549194336,37.04810396830241,36.97490374247233,36.90370400746664,36.83460394541422,36.76740392049154,36.70220375061035,36.63900407155355,36.57770347595215,36.515904108683266,36.451104164123535,36.38340441385905,36.31300417582194,36.23990376790365,36.1647040049235,36.088103930155434,36.010203997294106,35.931104024251304,35.850704193115234,35.76850382486979,35.68390432993571,35.59700425465902,35.50780328114828,35.41650358835856,35.322903633117676,35.227203369140625,35.12950325012207,35.029603004455566,34.9278039932251,34.82400385538737,34.71820386250814,34.61060301462809,34.50110371907552,34.38970343271891,34.27660306294759,34.16170342763265,34.045002937316895,33.926703135172524,33.80670356750488,33.68500264485677,33.56180318196615,33.43690331776937,33.31050364176432,33.182602882385254,33.0532029469808,32.922303199768066,32.79000282287598,32.65620358784994,32.52110322316488,32.38450304667155,32.24670282999674,32.107502937316895,31.967002868652344,31.82520294189453,31.68220281600952,31.538003126780193,31.392502625783283,31.24590269724528,31.0981027285258,30.949102719624836,30.799002647399902,30.64780282974243,30.49550263086955,30.34210268656413,30.187702814737957,30.03220256169637,29.87560224533081,29.718002637227375,29.559402465820312,29.399802366892498,29.23920249938965,29.07760222752889,28.91500234603882,28.751502513885498,28.58710225423177,28.42170254389445,28.255402088165283,28.088202476501465,27.92010227839152,27.751102447509766,27.581202189127605,27.410502433776855,27.23890193303426,27.06650193532308,26.89330228169759,26.719202200571697,26.544401963551838,26.368701934814453,26.192302068074543,26.01510175069173,25.837101936340332,25.65840212504069,25.478902022043865,25.298701922098797,25.117801825205486,24.936101754506428,24.753801981608074,24.57070191701253,24.387001832326252,24.20260190963745,24.017501672108967,23.831801732381184,23.64540163675944,23.458301703135174,23.27070140838623,23.082401752471924,22.893401463826496,22.703901449839275,22.51380141576131,22.323101202646892,22.13180160522461,21.93990151087443,21.747401237487793,21.554401238759358,21.360901355743408,21.16680113474528,20.972301483154297,20.777201493581135,20.5816011428833,20.38550090789795,20.18890142440796,19.991901238759358,19.794401168823242,19.59640121459961,19.398001194000244,19.199100971221924,18.999900817871094,18.800200939178467,18.600101153055828,18.399501005808514,18.19860092798869,17.997300624847412,17.795601050059002,17.59350061416626,17.391100724538166,17.188300768534344,16.985100905100506,16.781600634257,16.57770077387492,16.37350050608317,16.16900094350179,15.96410075823466,15.75890072186788,15.55340051651001,15.34760053952535,15.14150063196818,14.935100475947062,14.72830073038737,14.521300474802652,14.314000447591146,14.106400410334269,13.898500283559164,13.69040036201477,13.482000350952148,13.273300409317017,13.06440019607544,12.855200290679932,12.645700295766195,12.436000347137451,12.226100206375122,12.015900214513143,11.805400053660074,11.594800154368082,11.383900006612143,11.172800143559774,10.961400190989176,10.749899864196777,10.538100004196167,10.32610003153483,10.116100072860718,9.910450061162313,9.708960056304932,9.51156997680664,9.318199952443441,9.12876001993815,8.943190097808838,8.761380116144815,8.583280007044474,8.408809979756674,8.237890084584555,8.07044005393982,7.906410018603007,7.745710055033366,7.588279962539673,7.434060017267863,7.28298004468282,7.13496994972229,6.989970048268636,6.847930034001668,6.70878001054128,6.572450002034505,6.438899993896484,6.308070023854573,6.1798999309539795,6.054339965184529,5.931329965591431,5.810830036799113,5.692779978116353,5.57712996006012,5.46383003393809,5.352830012639363,5.244099974632263,5.137569983800252,5.033220012982686,4.93098000685374,4.830820004145305,4.732710003852844,4.636579990386963,4.542409976323445,4.450159986813863,4.359780033429463,4.271239995956421,4.184500058492024,4.099530021349589,4.016279935836792,3.9347299933433533,3.854829986890157,3.7765600283940635,3.699880003929138,3.6247499783833823,3.551159977912903,3.4790600140889487,3.4084200064341226,3.3392299811045327,3.271429975827535,3.205019990603129,3.139959971110026,3.0762200156847634,3.0137700041135154,2.952590048313141,2.8926599621772766,2.833940029144287,2.776419977347056,2.720070024331411,2.6648599902788797,2.6107700069745383,2.557790001233419,2.505879978338877,2.455020010471344,2.4052000045776367,2.3563899993896484,2.3085699876149497,2.261719981829325,2.2158299883206687,2.17085999250412,2.126809994379679,2.0836600065231323,2.0413800279299417,1.9999599953492482,1.9593799908955891,1.919629991054535,1.8806800146897633,1.8425300021966298,1.80513999859492,1.7685200174649556,1.7326500018437703,1.6975000003973644,1.6630599995454152,1.6293300092220306,1.5962699949741364,1.5638899902502696,1.5321700076262157,1.5010900100072224,1.4706499973932903,1.4408199886480968,1.4115999937057495,1.3829699854056041,1.3549199998378754,1.3274399936199188,1.3005200227101643,1.2741400102774303,1.2483000059922535,1.2229900062084198,1.1981899936993916,1.1738899946212769,1.1500900089740753,1.1267699996630351,1.1039199829101562,1.0815400183200836,1.0596100091934204,1.0381199916203816,1.0170699854691823,0.996452992161115,0.97625000278155,0.9564580023288727,0.9370670070250829,0.9180689950784048,0.8994570026795069,0.881222998102506,0.8633590092261633,0.8458569943904877,0.828711008032163,0.8119120051463445,0.7954539954662323,0.7793299903472265,0.7635339995225271,0.748057002822558,0.7328949918349584,0.7180410077174505,0.7034869889418284,0.6892289966344833,0.675259992480278,0.6615749994913737,0.6481669992208481,0.635031004746755,0.622161994377772,0.6095529993375143,0.597200999657313,0.5850989917914072,0.5732420037190119,0.561626007159551,0.550245001912117,0.5390959978103638,0.5281720111767451,0.5174699972073237,0.5069849938154221,0.4967120016614596,0.48664800077676773,0.4767879967888196,0.4671280011534691,0.45766399800777435,0.44839200377464294,0.43930800010760623,0.43040799846251804,0.4216880053281784,0.4131449982523918,0.40477600196997326,0.39657600224018097,0.3885419989625613,0.380671001970768,0.3729600061972936,0.36540500074625015,0.35800399879614514,0.3507519985238711,0.34364700069030124,0.33668700357278186,0.32986699789762497,0.3231860001881917,0.3166399995485942,0.3102269967397054,0.3039439966281255,0.29778800159692764,0.2917570024728775,0.2858480016390483,0.28005899985631305,0.2743869995077451,0.2688309997320175,0.2633869970838229,0.2580530022581418,0.2528270011146863,0.24770699938138327,0.24269099906086922,0.23777699967225394,0.2329620011150837,0.22824499880274138,0.22362300008535385,0.219095000376304,0.21465899795293808,0.210312998543183,0.20605400080482164,0.20188199977080026,0.19779499992728233,0.19378999869028726,0.18986700102686882,0.18602300062775612,0.1822570003569126,0.17856699973344803,0.17495199789603552,0.17141000057260194,0.1679399994512399,0.1645400015016397,0.1612089996536573,0.15794600049654642,0.15474899982412657,0.15161599963903427,0.14854699994126955,0.14554000024994215,0.1425940009454886,0.1397080011665821,0.13688000043233237,0.13410899912317595,0.1313949997226397,0.12873500088850656,0.12612999975681305,0.12357700057327747,0.12107599961260955,0.11862500011920929,0.11622400147219498,0.11387199970583121,0.11156800078848998,0.10930999927222729,0.10709799950321515,0.10492999975879987,0.10280700027942657,0.10072599972287814,0.0986879002302885,0.09669080128272374,0.09473419934511185,0.09281710038582484,0.09093890028695266,0.08909879997372627,0.08729589978853862,0.08552949937681358,0.08379879966378212,0.08210319963594277,0.08044200018048286,0.07881440035998821,0.0772196998198827,0.07565730127195518,0.0741265993565321,0.0726267999658982,0.07115739956498146,0.06971780024468899,0.06830729978779952,0.06692530028522015,0.0655712994436423,0.06424479993681113,0.06358829885721207};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473263382911682,7.644602100054423,7.706103761990865,7.787271777788798,7.876663287480672,7.9680810769399,8.058653513590494,7.961100459098816,7.575745344161987,7.035233855247498,6.408799886703491,5.732762813568115,5.026493310928345,4.300602952639262,3.561016301314036,2.811342239379883,2.0536869764328003,1.456750859816869,1.112930456797282,0.9052703231573105,0.7705865104993185,0.6750715027252833,0.6005749503771464,0.5373737166325251,0.48024892807006836,0.4264105310042699,0.374350647131602,0.3342838113506635,0.3117162634929021,0.29854968935251236,0.29041025787591934,0.2849687337875366,0.28097910682360333,0.27777475615342456,0.27499500413735706,0.27245156466960907,0.27004633843898773,0.2676195129752159,0.265095720688502,0.26254771401484805,0.26000568891565007,0.25748762240012485,0.25500454753637314,0.252555472155412,0.25014038756489754,0.24776232490936914,0.24541421607136726,0.24330647786458334,0.24154971788326898,0.239986435820659,0.23853420342008272,0.23715208346645036,0.23581599071621895,0.23450793822606406,0.23322388405601183,0.23195785656571388,0.23070978869994482,0.22965418547391891,0.22887858500083288,0.22824639827013016,0.22769322246313095,0.22718017672499022,0.22668912385900816,0.2262071172396342,0.22573010375102362,0.22526008759935698,0.2247940848271052,0.22429718946417174,0.22375528141856194,0.2231962929169337,0.222628320256869,0.22206429267923036,0.22150529051820436,0.2209522674481074,0.22040625909964243,0.21986325085163116,0.2193282333513101,0.21847931916515032,0.2171533095339934,0.21559557567040125,0.21392884105443954,0.21220986793438593,0.21055763339002928,0.20903831471999487,0.20759323984384537,0.2061821644504865,0.2047921158373356,0.20345196748773256,0.2021708625058333,0.2009168155491352,0.19967679182688394,0.19844477251172066,0.1972167727847894,0.19598577916622162,0.19475378096103668,0.193521777788798,0.19228978330890337,0.19105279569824538,0.18981279681126276,0.18857279668251672,0.18733179941773415,0.18608681236704191,0.1848378156622251,0.18358881523211798,0.18233981728553772,0.18108882009983063,0.1798328347504139,0.17857283850510916,0.17731383567055067,0.17605284104744592,0.17478884880741438,0.1735208568473657,0.1722528524696827,0.17098485678434372,0.16971187045176825,0.1684348719815413,0.1671598677833875,0.16588387141625086,0.1646058770517508,0.1633238879342874,0.16203789164622626,0.16075288752714792,0.15946789334217706,0.1581779047846794,0.1568849061926206,0.15559290101130804,0.1542999061445395,0.15300191938877106,0.15170192097624144,0.15040192008018494,0.14910092080632845,0.14779792726039886,0.14648894468943277,0.14517594998081526,0.14386195068558058,0.14254695425430933,0.1412269634505113,0.13990297292669615,0.1385779728492101,0.13725297525525093,0.13592199111978212,0.13458699360489845,0.13325199484825134,0.13191699360807738,0.13057601327697435,0.1292320148398479,0.12788901229699454,0.1265440173447132,0.12519801718493304,0.12384703134497006,0.12249303609132767,0.12113803749283154,0.11978403230508168,0.1184240523725748,0.11706204898655415,0.1157000499467055,0.11433805090685685,0.11297106556594372,0.11160106708606084,0.11023206325868766,0.1088630643983682,0.10748907923698425,0.10611307869354884,0.10473708063364029,0.10336107698579629,0.10198507830500603,0.1006040945649147,0.09921969659626484,0.09783679060637951,0.09645369462668896,0.09506680505971114,0.09367720720668633,0.09228880268832047,0.09090050434072812,0.08950841364761193,0.08811391703784466,0.0867207112411658,0.0853277121980985,0.08393441326916218,0.08253742630283038,0.0811384233335654,0.07974131902058919,0.07834501812855403,0.07694592761496703,0.07554502723117669,0.07414642162621021,0.07274862006306648,0.07134812946120898,0.06994592708845933,0.06854592387874921,0.0671469196677208,0.06574812221030395,0.06434613093733788,0.0629423304150502,0.061540624437232815,0.06013972498476505,0.058735933154821396,0.057330333006878696,0.05592692643404007,0.054524327628314495,0.05311883675555388,0.05171153570214907,0.05030642884473006,0.04890203010290861,0.047494739294052124,0.046085637683669724,0.04467863372216622,0.04327243069807688,0.04186653314779202,0.040457241237163544,0.03904604259878397,0.037636835128068924,0.036228337635596596,0.0348169452821215,0.03340374554196993,0.03199253914256891,0.03058214004461964,0.02916874798635642,0.027753648192932207,0.026340541740258534,0.024928243054697912,0.02351295140882333,0.02209585128972928,0.02068074590836962,0.01926654375468691,0.017852545250207186,0.016435154636080068,0.015015855276336273,0.013598448596894741,0.01218184968456626,0.010762257811923822,0.009340809658169746,0.00792138984737297,0.006502788281068206,0.005081176602592071,0.003657840483356267,0.002236376555326084,0.0011574028030736372,0.0005986577040554645,0.00030977621039104025,0.0001602502749544025,8.29187999139928e-05,4.289843430645609e-05,2.2197072515458178e-05,1.1484537405218967e-05,5.942618675665774e-06,3.0748224920292464e-06,1.5910978750828992e-06,8.233087764134931e-07,4.260449581276286e-07,2.2046585238892172e-07,8.42447095787217e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911485850811005,1.2003816763559978,1.2812815109888713,1.388161559899648,1.5033116738001506,1.6264817516009014,1.7574216425418854,1.8826414843400319,1.9890713493029277,2.0772412021954856,2.147661050160726,2.200830856959025,2.2372007369995117,2.25724059343338,2.26138041416804,2.2500202655792236,2.2235902746518454,2.189420243104299,2.1546402176221213,2.119280219078064,2.0833701888720193,2.046930174032847,2.009980152050654,1.9725401401519775,1.9346401393413544,1.8962801297505696,1.8574901223182678,1.8190101285775502,1.7815401355425518,1.7450801332791646,1.7095901370048523,1.6750701169172924,1.6414901117483776,1.6088301241397858,1.5770601332187653,1.5461801290512085,1.516150136788686,1.4868601361910503,1.4582101205984752,1.4301801423231761,1.4027601182460785,1.3759501179059346,1.349730134010315,1.3241001268227894,1.2990401089191437,1.2745501200358074,1.2506101330121357,1.2272201279799144,1.204370121161143,1.1820401151974995,1.1602401336034138,1.138940115769704,1.118130127588908,1.0978201230367024,1.0779801110426586,1.0586001177628834,1.039680113395055,1.021210124095281,1.0032001187403996,0.9856351166963577,0.9685001075267792,0.9517851124207178,0.9354811211427053,0.9195761134227117,0.9040611088275909,0.8889251053333282,0.8741581191619238,0.8597461134195328,0.8456721057494482,0.8319291124741236,0.8185081084569296,0.8054031034310659,0.7926041086514791,0.7801061073939005,0.7678991009791692,0.7559771041075388,0.7443331082661947,0.7329281121492386,0.7217251062393188,0.7107201019922892,0.6999090959628423,0.6892860978841782,0.6788641015688578,0.6686540941397349,0.6586510886748632,0.6488490949074427,0.6392410943905512,0.6298460861047109,0.6206791053215662,0.6117340872685114,0.6030030896266302,0.5944810956716537,0.5861591001351675,0.5780321011940638,0.5700941036144892,0.5623380889495214,0.554759090145429,0.5473520855108897,0.5401100814342499,0.5330280860265096,0.5261020908753077,0.5193260908126831,0.5126960774262747,0.5062070886294047,0.49985408534606296,0.49363408237695694,0.4875410844882329,0.48157207916180295,0.4757230803370476,0.4699910804629326,0.46437007933855057,0.45885908355315524,0.45345307886600494,0.44814808170000714,0.4429430787762006,0.4378330782055855,0.43281607578198117,0.4278890788555145,0.42304807404677075,0.4182920729120572,0.41361607362826663,0.409020076195399,0.4045000746846199,0.40005407234032947,0.3956790665785472,0.3913740739226341,0.3871350735425949,0.38296207040548325,0.3788510685165723,0.374801071981589,0.370810071627299,0.3668760731816292,0.3629970649878184,0.3591700668136279,0.3553950637578964,0.3516700665156047,0.34799306094646454,0.3443620651960373,0.3407760684688886,0.3372330615917842,0.3337320610880852,0.33027106275161106,0.3268500591317813,0.32346605757872265,0.32011906057596207,0.31680705895026523,0.3135300601522128,0.3102850591142972,0.30707205832004547,0.3038910577694575,0.30073805153369904,0.29761505126953125,0.2945200552543004,0.2914510543147723,0.2884090517958005,0.28539105008045834,0.2823980500300725,0.27942804743846256,0.2764810472726822,0.27355604867140454,0.27065204580624896,0.26776805023352307,0.2649040495355924,0.2620590527852376,0.2592320442199707,0.2564240445693334,0.2536320462822914,0.25085704525311786,0.24809804310401282,0.24535404269893965,0.2426260436574618,0.23991104091207185,0.2372110423942407,0.23452403768897057,0.23185003797213236,0.2291890357931455,0.2265390381217003,0.2239020379881064,0.22127503777543703,0.21866003423929214,0.21605503434936205,0.21346003313859305,0.21087503557403883,0.2083000329633554,0.20573403437932333,0.20317703237136206,0.20062902942299843,0.19809003174304962,0.19555903101960817,0.19303503135840097,0.19052003075679144,0.1880120299756527,0.1855110265314579,0.18301802749435106,0.18053102741638818,0.1780510259171327,0.17557702461878458,0.17310902600487074,0.1706480234861374,0.16819202403227487,0.16574202477931976,0.16329702362418175,0.16085702180862427,0.15842302019397417,0.15599301954110464,0.15356901908914247,0.15114901835719743,0.1487330198287964,0.1463210185368856,0.14391401782631874,0.14151101683576903,0.13911201432347298,0.1367160143951575,0.13432401418685913,0.13193501407901445,0.1295500099658966,0.12716801092028618,0.12478901135424773,0.12241401026646297,0.12004100965956847,0.11767100977400939,0.11530300912757714,0.11293800920248032,0.11057600813607375,0.10821600692967574,0.10585900706549485,0.10350300619999568,0.10115000481406848,0.09879900390903155,0.09644990290204684,0.09410260369380315,0.09175720190008481,0.08941350070138772,0.08707150133947532,0.08473110074798267,0.0823923001686732,0.08005490029851596,0.07775189975897472,0.07551520007352035,0.07334279951949914,0.07123299998541673,0.06918399967253208,0.06719400050739448,0.06526120007038116,0.06338409893214703,0.06156099991252025,0.05979049919794003,0.05807089960823456,0.05640079981336991,0.05477880003551642,0.053203500186403595,0.05167349924643835,0.05018759953478972,0.04874440003186464,0.04734279991437992,0.04598149936646223,0.04465949938942989,0.04337539989501238,0.042128399945795536,0.04091719972590605,0.039740899888177715,0.03859840023020903,0.037488799852629505,0.03641110068807999,0.035364500557382904,0.034347900499900184,0.03336059985061487,0.032401700193683304,0.031470400436470904,0.03056590026244521,0.029687500093132257,0.028834299960484106,0.028005600286026795,0.02720080005625884,0.026419099885970354,0.025659900158643723,0.024922499898821115,0.02420639976238211,0.02351079989845554,0.022835299838334322,0.022179200158764917,0.021541900156686705,0.020923000139494736,0.02032189986978968,0.01973810000345111,0.019170999992638826,0.018620299641042948,0.018085400108247995,0.017565800187488396,0.017061200303335983,0.016571199831863243,0.016095199932654698,0.015632900098959606,0.015183799977724751,0.01474769995547831,0.014324200029174486,0.013912800000980496,0.013513199985027313,0.01312510009544591,0.012748200058316192,0.012382100103423,0.012026500034456452,0.011681200005114079,0.01134570005039374,0.011019899975508451,0.010703500049809614,0.010396199999377131,0.01009770001595219,0.009807749961813291,0.009526160079985857,0.009252660054092606,0.00898700999096036,0.008729009966676434,0.008478409921129545,0.008235010008017222,0.007998609992985925,0.007769000018015504,0.007545980081583063,0.00732937998448809,0.007118990023930867,0.006914649934818347,0.006716180049503843,0.006523409974761307,0.006336170054661731,0.006154319969937205,0.005977689948243399,0.0058061300466458006,0.005639500023486714,0.005477660025159518,0.005320459992314379,0.005167780017169814,0.0050194800132885575,0.004875450045801699,0.004735550028271973,0.00459966001411279,0.004467680002562702,0.004339489969424903,0.004214980018635591,0.004094049994212885,0.003976579988375306,0.0038624899849916496,0.0037516800415081284,0.003644050001942863,0.0035395000013522804,0.003437959977115194,0.0033393399983954928,0.003243540006224066,0.0031504999885025122,0.0030601300143947205,0.002972350009561827,0.002887090027797967,0.002804280025884509,0.0027238400264953575,0.0026457099981295564,0.002569829986896366,0.00249612998838226,0.0024245399981737137,0.002355000004172325,0.0022874600059973695,0.0022218599915504456,0.0021581400263433657,0.0020962500129826367,0.002036140028697749,0.0019777499643775323,0.001921030003965522,0.0018659499861920874,0.0018124400036564718,0.0017604699921018134,0.0017099899899524946,0.0016609599988441914,0.0016133400107113023,0.0015670799863679956,0.0015221499973752846,0.001478510006563738,0.0014361199961664777,0.0013949499989394099,0.0013549499950992565,0.0013161100020321708,0.0012783799999548744,0.0012417299828181665,0.0012061399756930768,0.0011715599976014346,0.0011379799980204552,0.0011053600076896448,0.0010736700108585258,0.0010428900034942974,0.0010130000106679897,0.0009839659857486065,0.000955763006156,0.0009283679974032566,0.0009017600095830858,0.0008759140037000179,0.0008508099999744445,0.0008264260007611787,0.000802740997945269,0.0007797350068964685,0.0007573889937096586,0.0007356839972392967,0.0007146010029828176,0.0006941219956691688,0.0006742310021460677,0.0006549110015233358,0.0006361439979324738,0.0006179150126020735,0.0006002090037024269,0.0005830109973127643,0.0005663050008782496,0.000550079004218181,0.000534318004307958,0.0005190080070557693,0.0005041379966617873,0.000489693998436754,0.0004756639997746485,0.00046203599534540746,0.00044879900087835267,0.0004359410037674631,0.00042345199957101914,0.00041132100159302354,0.00039953700130960595,0.00038809199516739074,0.00037697399966418743,0.00036617500154534355,0.0003556860053019288,0.0003454970016415852,0.0003355999991375332,0.00032598699908703566,0.0003166500003620361,0.0003075800001776467,0.0002987700014879617,0.0002902120031649247,0.00028190000011818483,0.00027382600092096254,0.00026598300125139457,0.00025836500329508755,0.00025096500273017835,0.0002437779973358071,0.00023679600053583272,0.00023001500085229054,0.00022342699836978377,0.00021702900024441382,0.00021081400094165778,0.00020477600022180317,0.00019891200160297254,0.00019321599878215542,0.00018768300166508803,0.0001823089987738058,0.00017708800078253262,0.00017201799952696698,0.00016709200159918206,0.00016230800126019554,0.00015766000312093334,0.00015314599780443436,0.00014876100006707324,0.00014450200008771694,0.0001403640017088037,0.0001363460008481828,0.0001324420009041205,0.00012864999735029414,0.00012496700098078387,0.00012138900031762508,0.00011791400053577188,0.00011453800046486624,0.00011125899982289411,0.00010807400030898862,0.00010498000059063391,0.0001019750003858159,9.905570004775655e-05,9.622019994518875e-05,9.346580130416744e-05,9.079030072219514e-05,8.819150086007237e-05,8.566699943912681e-05,8.32149004660702e-05,8.083299993207523e-05,7.8519299980447e-05,7.627179972284163e-05,7.408880022315618e-05,7.196819933596998e-05,6.99083005504993e-05,6.790750073074985e-05,6.596389963912468e-05,6.407599964101489e-05,6.224220063207515e-05,6.046079973505888e-05,5.873049970735641e-05,5.7877899962477386e-05};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.94633404413859,28.906192779541016,29.844895044962566,30.633196353912354,31.21499729156494,31.591198603312176,31.762498537699383,31.82159884770711,31.860599199930828,31.87939914067586,31.878199418385822,31.856899579366047,31.815699736277264,31.75439977645874,31.673200130462646,31.572100003560383,31.451200167338055,31.320300102233887,31.189300060272217,31.058300018310547,30.927199999491375,30.7960999806722,30.664999961853027,30.534000237782795,30.402899901072185,30.271899859110516,30.140899817148846,30.0100998878479,29.8795002301534,29.74910004933675,29.61900011698405,29.489200115203857,29.359700202941895,29.23039976755778,29.101399898529053,28.972700277964275,28.84440008799235,28.71620003382365,28.588300069173176,28.46049992243449,28.33300018310547,28.205700238545734,28.07859977086385,27.951800028483074,27.825300216674805,27.699100176493328,27.573099772135418,27.447499752044678,27.322100003560383,27.197099844614666,27.07230011622111,26.947799841562908,26.823699951171875,26.699900150299072,26.57640012105306,26.45329984029134,26.330399831136067,26.20800018310547,26.08590014775594,25.964200178782146,25.84280014038086,25.721799850463867,25.601199944814045,25.480899969736736,25.361000219980877,25.24149990081787,25.122300148010254,25.00350014368693,24.885100205739338,24.767100016276043,24.64940007527669,24.53219985961914,24.415299892425537,24.29890028635661,24.182899951934814,24.067200024922688,23.9520001411438,23.8372000058492,23.722699960072834,23.608699957529705,23.495000044504803,23.381700197855633,23.26890007654826,23.156699816385906,23.045100212097168,22.93400017420451,22.82360013326009,22.71370029449463,22.604399998982746,22.495699882507324,22.387600262959797,22.28000020980835,22.173100153605144,22.066700140635174,21.960899988810223,21.85570001602173,21.751000086466473,21.646900018056233,21.54330015182495,21.44039996465047,21.337899843851726,21.236000061035156,21.134699821472168,21.033899943033855,20.933600107828777,20.83390013376872,20.734699885050457,20.63599983851115,20.537800153096516,20.440200010935467,20.34310007095337,20.24650001525879,20.150400002797443,20.054800351460774,19.959700107574463,19.86519988377889,19.77110004425049,19.6775000890096,19.584400177001953,19.49179983139038,19.399699846903484,19.30810006459554,19.216900030771892,19.12629969914754,19.036100069681805,18.94630018870036,18.857100009918213,18.76830005645752,18.68000014623006,18.592099984486897,18.504700183868408,18.41770013173421,18.331200122833252,18.245199998219807,18.159599939982098,18.074399948120117,17.989599863688152,17.90529998143514,17.821499983469646,17.73799975713094,17.65500005086263,17.572400252024334,17.49020004272461,17.40850019454956,17.3271001180013,17.24620008468628,17.165599981943767,17.08549992243449,17.005800088246662,16.926500002543133,16.847500165303547,16.76900005340576,16.690800189971924,16.613100051879883,16.53569984436035,16.45870018005371,16.382099946339924,16.305899779001873,16.230000336964924,16.154499848683674,16.079399903615315,16.00469994544983,15.930300076802572,15.856299877166748,15.782600084940592,15.70929996172587,15.636400063832602,15.56380001703898,15.491599957148233,15.419699986775717,15.348099946975708,15.276899973551432,15.206099907557169,15.135599931081137,15.065399964650473,14.995600064595541,14.926099936167398,14.856900056203207,14.788100004196167,14.719500064849854,14.651400009791056,14.583499908447266,14.515999952952066,14.448700269063314,14.381799936294556,14.315299987792969,14.248999834060669,14.183100064595541,14.11740001042684,14.05209994316101,13.98710004488627,13.922399918238321,13.858000040054321,13.793900092442831,13.730200052261353,13.666699886322021,13.603499809900919,13.54069995880127,13.478100061416626,13.415799935658773,13.353900035222372,13.292199929555258,13.230799992879232,13.169700066248575,13.10890007019043,13.048400084177652,12.988199869791666,12.928300142288208,12.868600050608316,12.809299945831299,12.750199953715006,12.691399971644083,12.63290007909139,12.574700037638346,12.516700029373169,12.458999872207642,12.401599963506063,12.344499985376993,12.28759996096293,12.230999867121378,12.174699942270914,12.118599891662598,12.06279993057251,12.007299979527792,11.952099800109863,11.89709989229838,11.842300097147623,11.787900050481161,11.73360006014506,11.679700056711832,11.626000006993612,11.572499990463257,11.519400040308634,11.466400146484375,11.413700024286905,11.361300071080526,11.309099912643433,11.257199923197428,11.20550004641215,11.154000043869019,11.102799971898397,11.051800012588501,11.001000006993612,10.950500011444092,10.900200049082438,10.850200017293295,10.800299882888794,10.750800132751465,10.701400200525919,10.652300198872885,10.603300094604492,10.554699977238974,10.506200075149536,10.45800002415975,10.410000085830688,10.362199942270914,10.314599990844727,10.267300128936768,10.220099925994873,10.173200050989786,10.126499891281128,10.080000082651773,10.03380004564921,9.987729946772257,9.941889921824137,9.896270036697388,9.850850025812784,9.805649995803833,9.760649919509888,9.71586012840271,9.671279907226562,9.626899878184,9.582729975382486,9.53876002629598,9.494999885559082,9.451430002848307,9.408069928487143,9.364909966786703,9.32195003827413,9.279179811477661,9.23661986986796,9.194240093231201,9.152070124944052,9.110090017318726,9.068300008773804,9.026710033416748,8.985309918721518,8.944090127944946,8.903070052464804,8.862239996592203,8.821600039800009,8.781140009562174,8.740869998931885,8.700789848963419,8.660889943440756,8.621170043945312,8.581639925638834,8.542289892832438,8.503119945526123,8.464140017827352,8.42532992362976,8.386699994405111,8.348250071207682,8.309969981511435,8.27187999089559,8.23395005861918,8.196209907531738,8.158629973729452,8.121230125427246,8.084010124206543,8.046949942906698,8.01006011168162,7.973350087801616,7.936799923578898,7.900430003801982,7.86421000957489,7.82817002137502,7.792290012041728,7.7565799951553345,7.721030036608378,7.685649951299031,7.650429964065552,7.615370035171509,7.580469965934753,7.545740008354187,7.511159976323445,7.476740002632141,7.442480007807414,7.408380031585693,7.374439994494121,7.340650002161662,7.307019988695781,7.273540019989014,7.2402199904123945,7.20705000559489,7.174030025800069,7.141169985135396,7.1084500551223755,7.0758899847666425,7.043470064798991,7.011210044225057,6.979100028673808,6.947130004564921,6.915310025215149,6.88362991809845,6.852099974950154,6.820720036824544,6.789480010668437,6.758390029271443,6.727429986000061,6.696619987487793,6.66595995426178,6.635430018107097,6.605039993921916,6.57479993502299,6.544689933458964,6.5147199630737305,6.484889944394429,6.455190022786458,6.425639986991882,6.396220127741496,6.3669300476710005,6.337779998779297,6.308759967486064,6.279880007108052,6.251129945119222,6.222509980201721,6.19402003288269,6.16565998395284,6.137439926465352,6.109339992205302,6.081369956334432,6.053530017534892,6.025820016860962,5.998240033785502,5.970779935518901,5.943450013796489,5.916249990463257,5.889170010884603,5.8622099955876665,5.835379958152771,5.8086700439453125,5.782090028127034,5.755629976590474,5.7292799552281695,5.703060030937195,5.676959991455078,5.650979955991109,5.625119924545288,5.599379976590474,5.573760032653809,5.548250039418538,5.522859970728557,5.497590025266011,5.472429990768433,5.447390000025432,5.422470053037007,5.39766001701355,5.372960050900777,5.348380009333293,5.323910037676494,5.299550016721089,5.275299986203511,5.251169999440511,5.227139910062154,5.203230023384094,5.179419954617818,5.155729969342549,5.132139960924785,5.108669996261597,5.085299968719482,5.062029997507731,5.038879990577698,5.015830039978027,4.9928799867630005,4.970049937566121,4.947309931119283,4.924680074055989,4.902160008748372,4.879739960034688,4.857420047124227,4.8351999918619795,4.813090006510417,4.791069984436035,4.769160072008769,4.747350017229716,4.725640018781026,4.70402995745341,4.682509938875834,4.661099990208943,4.639779965082805,4.61856993039449,4.597439964612325,4.576420068740845,4.555489977200826,4.5346599817276,4.513929923375447,4.493290026982625,4.472740054130554,4.452289938926697,4.43192998568217,4.411669929822286,4.391499956448873,4.3714200258255005,4.35142997900645,4.331539988517761,4.311729947725932,4.292020082473755,4.27239990234375,4.252869963645935,4.233419934908549,4.214070002237956,4.194809953371684,4.17563001314799,4.156540036201477,4.137540141741435,4.118629972139995,4.099800030390422,4.08105997244517,4.062399983406067,4.043829997380574,4.025350014368693,4.006950040658315,3.988639990488688,3.9704100290934243,3.95225997765859,3.9341899752616882,3.9162099758783975,3.8983100255330405,3.880500018596649,3.862759987513224,3.845109979311625,3.8275299866994223,3.810039977232615,3.7926299770673118,3.7752999663352966,3.7580400307973227,3.7408699989318848,3.7237799962361655,3.7067600091298423,3.6898200114568076,3.6729599833488464,3.6561700304349265,3.639470020929972,3.6228399674097695,3.6145400206247964};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.1404639333486557,0.14906380325555801,0.15930283069610596,0.17092982058723769,0.1839688022931417,0.19841478889187178,0.21425979832808176,0.23006181915601095,0.24439084033171335,0.2572518487771352,0.2686518703897794,0.2785958871245384,0.2870929042498271,0.29414692521095276,0.2997649436195691,0.30395595480998355,0.3067239597439766,0.3087039639552434,0.31052496284246445,0.3121899664402008,0.31369996319214505,0.3150569647550583,0.3162589743733406,0.31730997065703076,0.3182079742352168,0.31895597527424496,0.3195529729127884,0.32009197771549225,0.32066497455040616,0.3212699716289838,0.321906973918279,0.32257797320683795,0.323279969394207,0.32401496917009354,0.32478297253449756,0.3255849704146385,0.3264189660549164,0.3272789691885312,0.32815997550884884,0.32906097173690796,0.3299839695294698,0.3309289688865344,0.33189497143030167,0.33288297057151794,0.3338929663101832,0.33492496858040494,0.3359759623805682,0.3370489651958148,0.3381449679533641,0.3392639681696892,0.34040596584479016,0.3415709634621938,0.34275896350542706,0.343969963490963,0.3452039634188016,0.346459964911143,0.34773896882931393,0.3490389635165532,0.35035796215136844,0.3516949638724327,0.3530519629518191,0.3544299602508545,0.35582596560319263,0.3572399616241455,0.35867195824782055,0.36012396216392517,0.36159596343835193,0.3630789543191592,0.3645709579189618,0.3660719593365987,0.36758196105559665,0.3690999572475751,0.37062495450178784,0.3721589545408885,0.37369995564222336,0.3752499595284462,0.37680695702632266,0.3783579617738724,0.379891961812973,0.3814079612493515,0.38290595759948093,0.38438695420821506,0.3858519643545151,0.3873029599587123,0.3887389575441678,0.39016195635000867,0.39156996210416156,0.3929569597045581,0.39431695888439816,0.39564896126588184,0.39695296188195545,0.398229959110419,0.3994809612631798,0.40070296327273053,0.40189796437819797,0.4030679613351822,0.4042089655995369,0.40532496323188144,0.4064149583379428,0.4074769616127014,0.4085109680891037,0.4095209588607152,0.4105039636294047,0.4114609584212303,0.412392961482207,0.4132999653617541,0.4141799608866374,0.4150359630584717,0.4158659627040227,0.41667096068461734,0.41745096693436307,0.41820696492989856,0.41893696784973145,0.41964396586020786,0.4203259696563085,0.4209819709261258,0.42161496728658676,0.4222249686717987,0.42280897001425427,0.42336996644735336,0.4239079679052035,0.42442096521457034,0.4249109700322151,0.4253779699405034,0.4258209715286891,0.42623896648486453,0.42663396894931793,0.4270069698492686,0.4273559773961703,0.42768297096093494,0.4279879679282506,0.4282689740260442,0.42852797110875446,0.4287649715940158,0.42897896965344745,0.42917097359895706,0.42934197435776394,0.42948897182941437,0.42961497356494266,0.4297189737359683,0.42980097234249115,0.42986097435156506,0.42990097651878995,0.42991697291533154,0.4299129794041316,0.4298879752556483,0.4298409695426623,0.42977197964986164,0.42968397587537766,0.4295729771256447,0.429439976811409,0.42928697913885117,0.42911297082901,0.42891797920068103,0.4287019769350688,0.4284669756889343,0.42820997536182404,0.4279339760541916,0.4276369785269101,0.4273199737071991,0.42698197563489276,0.42662598192691803,0.42624797920386,0.4258509799838066,0.4254339834054311,0.4249969820181529,0.4245409816503525,0.4240659798185031,0.42356997976700467,0.42305497576793033,0.42252198110024136,0.4219679832458496,0.4213949864109357,0.4208049823840459,0.420192984243234,0.4195619796713193,0.41891197860240936,0.41824498524268466,0.4175569812456767,0.4168509840965271,0.4161269838611285,0.4153839871287346,0.4146229873100917,0.4138439844051997,0.4130459825197856,0.4122299874822299,0.41139698773622513,0.4105449840426445,0.4096759880582492,0.4087889889876048,0.40788398683071136,0.40696098903814953,0.40602198988199234,0.40506398926178616,0.4040899897615115,0.4030979896585147,0.4020889898141225,0.4010619918505351,0.40001998593409854,0.3989589909712474,0.3978799879550934,0.3967849885423978,0.3956739902496338,0.3945449913541476,0.3934009869893392,0.3922399928172429,0.3910619889696439,0.38986799369255704,0.3886589929461479,0.3874319940805435,0.3861889938513438,0.3849319939812024,0.38365699350833893,0.38236699004968006,0.38106099267800647,0.37973899642626446,0.3784019947052002,0.3770499949653943,0.3756810004512469,0.37429699301719666,0.37289899339278537,0.3714839965105057,0.37005499998728436,0.3686109979947408,0.3671509971221288,0.3656740014751752,0.3641829937696457,0.36267799884080887,0.36115699758132297,0.35962199916442233,0.35807200024525326,0.35650700330734253,0.3549279992779096,0.35333599895238876,0.3517269988854726,0.35010500252246857,0.34846900155146915,0.34683000296354294,0.34519800295432407,0.3435739999016126,0.3419579987724622,0.3403489987055461,0.3387479980786641,0.33715399851401645,0.33556799838940304,0.3339890018105507,0.33241799970467883,0.33085500200589496,0.3292979970574379,0.3277499998609225,0.3262080028653145,0.32467400034268695,0.3231469988822937,0.3216269984841347,0.32011399914820987,0.31860899925231934,0.317111000418663,0.31561999519666034,0.31413500010967255,0.31265800446271896,0.3111879999438922,0.30972500145435333,0.30826899657646817,0.3068200002113978,0.305377001563708,0.3039410014947255,0.3025120024879773,0.30108999957640964,0.29967499772707623,0.2982660010457039,0.29686400045951206,0.2954689984520276,0.2940799966454506,0.2926979959011078,0.2913219978411992,0.28995299835999805,0.2885899965961774,0.28723400334517163,0.28588400036096573,0.2845400000611941,0.28320299834012985,0.2818719993034999,0.28054799636205036,0.279229998588562,0.2779179960489273,0.2766120011607806,0.27531199405590695,0.274017999569575,0.2727309962113698,0.2714500005046527,0.2701739991704623,0.2689050038655599,0.2676420013109843,0.2663839980959892,0.26513300091028214,0.2638879989584287,0.2626479963461558,0.2614140013853709,0.26018599917491275,0.2589639996488889,0.25774799784024555,0.2565370003382365,0.2553320030371348,0.25413299600283307,0.252940001587073,0.2517519990603129,0.2505689983566602,0.24939300119876862,0.2482220008969307,0.24705599869290987,0.24589600041508675,0.24474100271860758,0.24359200025598207,0.242447999616464,0.2413100004196167,0.24017700056234995,0.23904900128642717,0.23792699972788492,0.2368100012342135,0.23569800332188606,0.23459099978208542,0.23349000016848245,0.23239399989446005,0.2313030002017816,0.23021699860692024,0.2291359988351663,0.2280610017478466,0.2269899994134903,0.22592499976356825,0.22486399983366331,0.22380900010466576,0.22275800009568533,0.22171299904584885,0.2206720014413198,0.21963700031240782,0.2186060013870398,0.2175799993177255,0.216559000313282,0.21554300064841905,0.21453099946180978,0.21352400009830794,0.21252200131615004,0.2115249993900458,0.21053299928704897,0.20954499766230583,0.20856200034419695,0.20758300026257834,0.20660899952054024,0.20564000060160956,0.20467500016093254,0.20371499905983606,0.20275899892052016,0.20180800060431162,0.2008610020081202,0.19991900150974592,0.1989810032149156,0.19804699967304865,0.197118000437816,0.19619400054216385,0.19527300198872885,0.19435699904958406,0.19344599917531013,0.19253800188501677,0.19163500145077705,0.19073600073655447,0.18984200184543928,0.18895200019081435,0.18806500112016997,0.18718300014734268,0.18630499889453253,0.1854320007065932,0.18456199889381728,0.18369700014591217,0.18283500149846077,0.18197799970706305,0.18112400049964586,0.18027499814828238,0.17942999924222627,0.17858799919486046,0.17775100097060204,0.1769180012245973,0.1760880003372828,0.17526199916998544,0.17444100106755892,0.1736229993402958,0.17280899981657663,0.1719990000128746,0.1711920015513897,0.17038999870419502,0.16959099968274435,0.1687960016230742,0.1680039974550406,0.16721700256069502,0.16643299907445908,0.16565300027529398,0.16487600033481917,0.16410299887259802,0.16333400085568428,0.1625690000752608,0.161806999395291,0.16104799881577492,0.16029299919803938,0.15954199681679407,0.1587940032283465,0.15804999942580858,0.15730899944901466,0.1565720004340013,0.15583800027767816,0.15510800356666246,0.15438099950551987,0.15365699927012125,0.1529369999965032,0.15222099920113882,0.15150699888666472,0.15079699953397116,0.1500909999012947,0.14938700199127197,0.14868700007597604,0.1479909991224607,0.1472969986498356,0.14660699913899103,0.14591999972860017,0.14523599917689958,0.14455600082874298,0.14387899885574976,0.14320400108893713,0.14253400017817816,0.14186599726478258,0.14120099941889444,0.14053999880949655,0.13988099992275238,0.13922599827249846,0.13857399920622507,0.13792400310436884,0.13727800051371256,0.13663500174880028,0.13599499811728796,0.13535799955328306,0.13472399984796843,0.1340930014848709,0.1334649994969368,0.13284000009298325,0.1322169986863931,0.13159799948334694,0.13098200038075447,0.13036799803376198,0.12975799664855003,0.12914999946951866,0.1285449999074141,0.1279429979622364,0.12734400108456612,0.12674699847896895,0.12615399931867918,0.1255630006392797,0.12497500143945217,0.12438999985655148,0.12380699937542279,0.12322700023651123,0.12265000057717164,0.12207599977652232,0.12150399945676327,0.12093499923745792,0.12036899973948796,0.11980499948064487,0.11924399932225545,0.11868599988520145,0.11812999968727429,0.11757699958980083,0.11702699897189935,0.11647899945576985,0.1159329991787672,0.1153900008648634,0.1148499995470047,0.1143119999517997,0.11377700045704842,0.11324500106275082,0.11271400128801663,0.11218700061241786,0.11166100079814593,0.11113899946212769,0.11061799960831802,0.11010100009540717,0.10958499958117802,0.10907200103004773,0.10856200009584427,0.10830699962874253};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2237508495648703,2.4407402873039246,2.632450262705485,2.9018102486928306,3.2085703015327454,3.547910292943319,3.9155803124109902,4.240620255470276,4.460980216662089,4.589500228563945,4.637290120124817,4.613970160484314,4.527890165646871,4.386350115140279,4.195710102717082,3.961560090382894,3.6888000766436257,3.4114500681559243,3.159670035044352,2.9305200775464377,2.7213900486628213,2.529970029989878,2.3542000452677407,2.19225005308787,2.042520006497701,1.9035800397396088,1.7741600374380748,1.6574000418186188,1.5560700198014576,1.4683900475502014,1.3927700420220692,1.3277900318304698,1.2722200353940327,1.224940021832784,1.1849800248940785,1.1514800290266674,1.1236700316270192,1.100560039281845,1.0812900364398956,1.0654200315475464,1.0525700449943542,1.0423700511455536,1.0345400373140972,1.028780033191045,1.0248700380325317,1.022580047448476,1.0217300454775493,1.0221600532531738,1.0237500568230946,1.0263600548108418,1.0298700630664825,1.034170041481654,1.0391700367132823,1.0447800556818645,1.0509400566418965,1.0575600663820903,1.0646100342273712,1.0719500581423442,1.0795100529988606,1.0872300366560619,1.0951000551382701,1.103100061416626,1.1112100581328075,1.1194100677967072,1.1276800433794658,1.1360200643539429,1.1444100538889568,1.1526000400384266,1.1603600680828094,1.1677700579166412,1.1748600602149963,1.181670069694519,1.188250054915746,1.1946300665537517,1.200830082098643,1.2068800628185272,1.2127900818983715,1.217970073223114,1.2218700647354126,1.2246700624624889,1.2265200714270275,1.2275400658448536,1.227970043818156,1.2280300656954448,1.227770060300827,1.227250059445699,1.226490060488383,1.2251900533835094,1.2231000463167827,1.2203100621700287,1.216930051644643,1.2130100329717,1.2086500624815624,1.2038800418376923,1.1987700760364532,1.1933500568072002,1.1876700520515442,1.1817600627740223,1.175640046596527,1.1693500479062398,1.1628900369008381,1.156300038099289,1.1495900650819142,1.1427700519561768,1.1358500520388286,1.1288600663344066,1.1217800378799438,1.114640047152837,1.1074400544166565,1.1001900434494019,1.0928900440533955,1.0855400462945302,1.0781600375970204,1.0707400540510814,1.063280036052068,1.0558000306288402,1.0482900540033977,1.0407600502173107,1.0332000354925792,1.0256200432777405,1.018030047416687,1.0104100505510967,1.0027700612942378,0.9951180468002955,0.987449049949646,0.9797640442848206,0.9720650414625803,0.9643520464499792,0.9566250344117483,0.9488830467065176,0.9411280453205109,0.9333590368429819,0.9255770395199457,0.9177790433168411,0.909964049855868,0.9021350542704264,0.8942920416593552,0.8864320317904154,0.878556047876676,0.8706650386253992,0.8627610405286154,0.8548420468966166,0.846907044450442,0.8389560331900915,0.8309910446405411,0.8230140407880148,0.8150210330883662,0.8070130397876104,0.7989920328060786,0.7909590353568395,0.7829120308160782,0.7748510390520096,0.766777033607165,0.7586930344502131,0.7505970299243927,0.7424870332082113,0.7343640327453613,0.7262310286362966,0.7180870225032171,0.7099300275246302,0.7017610321442286,0.6935830265283585,0.6853940188884735,0.6771960258483887,0.668987030784289,0.6607660204172134,0.6525360296169916,0.6442970236142477,0.6360470205545425,0.6277870237827301,0.6195190300544103,0.6112430244684219,0.6029590219259262,0.5946660290161768,0.5863620191812515,0.57805202404658,0.5697340170542399,0.5614070296287537,0.5530720253785452,0.5447310308615366,0.5363840212424597,0.5280310213565826,0.5196710179249445,0.5113070160150528,0.5029400164882342,0.4945700193444888,0.48619402199983597,0.477813017865022,0.4694310153524081,0.4610460177063942,0.4526570215821266,0.444264014561971,0.4358690132697423,0.42747201522191364,0.41907401382923126,0.41067201892534894,0.4022660180926323,0.39385801553726196,0.3854500154654185,0.37703701357046765,0.36862001816431683,0.36020301282405853,0.35178401072820026,0.3433610151211421,0.3349340135852496,0.3265070120493571,0.3180770128965378,0.30964601039886475,0.30121200780073804,0.2927730083465576,0.2843330105145772,0.2758920093377431,0.26744601130485535,0.25899701317151386,0.25054700920979184,0.24209500725070635,0.2336410072942575,0.22518300637602806,0.21672100697954497,0.208258006721735,0.19979300598303476,0.191324004282554,0.1828520049651464,0.1743780051668485,0.16590200612942377,0.15742200364669165,0.1489380026857058,0.14045300334692,0.13196700314680734,0.12347800098359585,0.1149860005825758,0.10648900084197521,0.09799100086092949,0.08949119970202446,0.08098740130662918,0.0724796000868082,0.06397040095180273,0.05599109952648481,0.04900729997704426,0.04289470054209232,0.03754459942380587,0.03286200032259027,0.028763499887039263,0.025176200084388256,0.022036399847517412,0.019288300070911646,0.016882899838189285,0.014777599989126125,0.012934800082196793,0.011321900024389228,0.009910179922978083,0.008674509900932511,0.007592940082152684,0.006646249986564119,0.005817620006079475,0.005092320071222882,0.0044574600566799445,0.0039017699697675803,0.003415370030173411,0.0029896199703216553,0.0026169500003258386,0.00229073998828729,0.002005210000788793,0.001755270001012832,0.0015364899882115424,0.0013449899852275848,0.0011773599932591121,0.0010306200031967212,0.0009021789931769794,0.0007897469962093359,0.000691329007774281,0.0006051780025397117,0.0005297650010713065,0.00046375099918805063,0.0004059649969955596,0.00035537999792722985,0.0003111000017573436,0.0002723379996799243,0.00023840700062767914,0.00020870399991205582,0.0001827019987103995,0.00015994000083689267,0.00014001499827524336,0.00012257200008510458,0.00010730299921609306,9.393609919546482e-05,8.223470103985164e-05,7.199120106330763e-05,6.302390011114767e-05,5.517369936569594e-05,4.830160044851558e-05,4.228549975474986e-05,3.7018900002294686e-05,3.240829983042204e-05,2.837209967765375e-05,2.483870017992255e-05,2.1745299970158765e-05,1.903729980767821e-05,1.6666600004100474e-05,1.4591100049680486e-05,1.2774199982838278e-05,1.1183499888526663e-05,9.79093996041532e-06,8.571809985369327e-06,7.504509994760156e-06,6.57012003557611e-06,5.752090032729029e-06,5.035929992421491e-06,4.4089500003489474e-06,3.860040010295052e-06,3.3794799871126693e-06,2.9587599973031806e-06,2.5904299718604307e-06,2.267949999653259e-06,1.9856299976102796e-06,1.7384500002511534e-06,1.5220500036624192e-06,1.3325899980524507e-06,1.1667200112697174e-06,1.0214999974778038e-06,8.943560014055644e-07,7.830400079456012e-07,6.855819947304553e-07,6.002549923778133e-07,5.25548998098202e-07,4.601429992590056e-07,4.028780011822164e-07,3.5274000017201007e-07,3.0884399867166695e-07,2.704100007614822e-07,2.367609965858719e-07,2.0729899929960993e-07,1.81504000570006e-07,1.5891899825722552e-07,1.3914499893038132e-07,1.21831999895979e-07,1.0667299991477346e-07,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834414084752401,12.709800720214844,13.167500575383505,13.882500171661377,13.807700077692667,13.080600182215372,11.814500013987223,10.408999999364218,9.192109982172648,8.127560059229532,7.186380068461101,6.345160047213237,5.585010051727295,4.8906599680582685,4.249710043271382,3.6521300077438354,3.0897899866104126,2.588470002015432,2.170010060071945,1.8205500145753224,1.5285300115744274,1.284280002117157,1.0797800074021022,0.9083070059617361,0.764286994934082,0.6430799961090088,0.5408219993114471,0.4549029966195424,0.38317400217056274,0.3232659970720609,0.27320000032583874,0.2313220016658306,0.19626200323303541,0.16686799998084703,0.14217800150314966,0.12139599894483884,0.10386000076929729,0.08908829900125663,0.07668220127622287,0.06623930111527443,0.05743440023312966,0.04999070024738709,0.043672300254305206,0.03829320054501295,0.033693500173588596,0.029734700452536345,0.026312400431682665,0.02337030026440819,0.02085640048608184,0.018696899991482496,0.016830899752676487,0.015207600314170122,0.013785200115914146,0.012528800095121065,0.0114098001892368,0.010404400061815977,0.009492880043884119,0.00867989007383585,0.007963870108748475,0.007327770038197438,0.006762760070463021,0.006256320086928706,0.005792950124790271,0.005365130142308772,0.004972410077850024,0.004608630125100414,0.004262930092712243,0.003942650083142023,0.0036537500369983413,0.0033906800866437456,0.003154070038969318,0.0029340400360524654,0.00272768004409348,0.0025326100294478238,0.002346850039126972,0.0021739800189000866,0.002006530024421712,0.0018435600310719262,0.0016894800355657935,0.0015427300240844488,0.001402040021882082,0.0012663700132785987,0.0011350300046615303,0.0010022500064224005,0.000868294004855367,0.000738531996224386,0.0006121680053183809,0.0004989039977469171,0.00040664699918124825,0.0003314909990876913,0.00027025999588659033,0.00022036699859503037,0.00017970699991565198,0.00014656799855098748,0.00011955499879453176,9.753309980927345e-05,7.957729940244462e-05,6.493519958894467e-05,5.299380003028394e-05,4.325360017295073e-05,3.530800010291083e-05,2.8825499915304437e-05,2.3536000147335773e-05,1.921939989794434e-05,1.5696399941589334e-05,1.2820699945829498e-05,1.0472999974808772e-05,8.556300144846318e-06,6.991170001432086e-06,5.712989983900722e-06,4.6690399434131296e-06,3.816290037169286e-06,3.1196500079507436e-06,2.550459953454265e-06,2.0853600138555826e-06,1.705259999577417e-06,1.394609986012559e-06,1.1406700082261523e-06,9.330749956385868e-07,7.633449996546915e-07,6.245589929676498e-07,5.110620051596015e-07,4.1823600109106945e-07,3.4230699933838576e-07,2.801940013341664e-07,2.2937600145193451e-07,1.8773799936866453e-07,1.536189984108205e-07,1.257139992105749e-07,7.085481238770323e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708131710688273,0.9575200627247492,1.0300400753815968,1.102800081173579,1.1757400731245677,1.2487600843111675,1.3217700620492299,1.3815700709819794,1.4164200524489086,1.4290800491968791,1.421960045893987,1.3971900244553883,1.3566400210062664,1.3019500176111858,1.2345900038878124,1.1558600068092346,1.066930005947749,0.9774520049492518,0.8960880140463511,0.82198599477609,0.754376009106636,0.6925740192333857,0.6359610011180242,0.5839830090602239,0.5361419965823492,0.49199699858824414,0.45114900916814804,0.41399700691302616,0.3809030055999756,0.3514370049039523,0.32521700362364453,0.30189700424671173,0.28116700053215027,0.262752003967762,0.24640400086839995,0.23189900567134222,0.2190380059182644,0.2076100048919519,0.1974270020922025,0.18836000437537828,0.18029000610113144,0.17311400547623634,0.16673600301146507,0.1610700065890948,0.15604000414411226,0.15157900378108025,0.14762700349092484,0.14414800455172858,0.14110900461673737,0.1384620058039824,0.13616500670711199,0.13418100525935492,0.13247400522232056,0.1310150052110354,0.12977600346008936,0.12873400499423346,0.12786600490411124,0.12717300529281297,0.12665500616033873,0.12629000594218573,0.12606100365519524,0.12595300624767938,0.12595200538635254,0.12604500725865364,0.12622000401218733,0.12647000576059023,0.12678400427103043,0.12714600563049316,0.1275430048505465,0.12797200679779053,0.1284300039211909,0.12891200557351112,0.12941600382328033,0.12994100774327913,0.13048100719849268,0.13103500629464784,0.13160400465130806,0.1321260097126166,0.1325520078341166,0.13289200638731322,0.1331550069153309,0.1333510068555673,0.13350000604987144,0.1336240035792192,0.13372500613331795,0.13380500550071397,0.13386700550715128,0.13386800636847815,0.13377200812101364,0.13359000409642854,0.1333320066332817,0.13300800696015358,0.1326250061392784,0.13219100361069044,0.13171400626500449,0.13119600589076677,0.13064100469152132,0.13005400449037552,0.12943900500734648,0.12879900385936102,0.12813600649436316,0.1274530030786991,0.12675300364693007,0.126037006576856,0.12530700551966825,0.12456400444110234,0.12381100344161193,0.12304900462428729,0.1222800047447284,0.12150200456380844,0.12071700394153595,0.11992500474055608,0.11912700533866882,0.11832300511499245,0.11751400617261727,0.11670100378493468,0.11588300454119842,0.11506100371479988,0.1142360046505928,0.11340700462460518,0.112576004738609,0.11174300499260426,0.11091000524659951,0.11007400415837765,0.10923500421146552,0.10839400378366311,0.10755000449717045,0.10670500434935093,0.10585700534284115,0.10500700399279594,0.10415500402450562,0.10330100295444329,0.1024460041274627,0.1015880045791467,0.10073100465039413,0.09987300323943298,0.0990130038311084,0.09815080339709918,0.09728650376200676,0.096420103063186,0.09555160440504551,0.09468110278248787,0.09380870374540488,0.09293450290958087,0.09205840403834979,0.09118060395121574,0.09030100268622239,0.08941980451345444,0.08853900308410327,0.08765820413827896,0.08677550281087558,0.08589090344806512,0.08500450352827708,0.08411630305151145,0.08322640260060628,0.08233490337928136,0.08144180290400982,0.08054730296134949,0.07965120238562425,0.07875370296339194,0.07785480283200741,0.07695460381607215,0.07605510329206784,0.07515600385765235,0.07425530192752679,0.07335300308962663,0.07244920295973618,0.0715439027796189,0.07063730247318745,0.06972940141956012,0.0688202033440272,0.06790980324149132,0.0669982023537159,0.066085501263539,0.06517170245448749,0.06425890140235424,0.06334680256744225,0.062433301781614624,0.06151850211123625,0.06060250196605921,0.0596855025117596,0.05876740192373594,0.057848502260943256,0.05692870200922092,0.05600820202380419,0.055087001683811344,0.05416520250340303,0.05324280199905237,0.05231990168491999,0.051398501731455326,0.050478401593863964,0.049557402109106384,0.04863570133845011,0.04771320180346569,0.046790001913905144,0.04586630159368118,0.04494190122932196,0.044017101327578224,0.04309170165409645,0.04216580154995123,0.041239601559937,0.040312801177302994,0.03938770138969024,0.03846390079706907,0.03753930112967888,0.03661400141815344,0.03568790170053641,0.03476130093137423,0.033834001049399376,0.032906100464363895,0.03197780096282562,0.03104890075822671,0.030119501209507387,0.029189700881640118,0.028259401054431994,0.02732880087569356,0.026399700436741114,0.025472001017381746,0.02454340100909273,0.023614100491007168,0.022684200511624415,0.02175350037092964,0.02082230073089401,0.01989050054301818,0.018958200390140217,0.018025300465524197,0.017092000227421522,0.016158200334757566,0.015223900166650614,0.014289300267895063,0.013356200186535716,0.012424400231490532,0.011491899999479452,0.010558600071817636,0.00962459008830289,0.008689930041631063,0.007754669990390539,0.006872339989058673,0.0060904200266425805,0.005397470008271436,0.0047833800393467145,0.004239169997163117,0.00375689003461351,0.0033294900010029473,0.0029507199845587215,0.002615049985858301,0.0023175699946781,0.002053950011031702,0.0018203099898528308,0.0016132600236839305,0.0014297599943044286,0.0012671400133209925,0.0011230200082839776,0.0009952989979259048,0.0008821049996186048,0.0007817870064172894,0.0006928799994057044,0.0006140860011025021,0.0005442549979003767,0.0004823660007483947,0.0004275170019051681,0.00037890499758456525,0.0003358229999624503,0.0002976399991894141,0.00026379900130753714,0.00023380699955547848,0.00020722500024324594,0.00018366599882331988,0.00016278599772097854,0.0001442809977258245,0.0001278790005017072,0.00011334299961163197,0.00010045900065354847,8.90397004695842e-05,7.891890042325637e-05,6.994880034956925e-05,6.199839905699871e-05,5.495189998327987e-05,4.8706399866205174e-05,4.317090042604832e-05,3.8264600031349495e-05,3.391599966562353e-05,3.0061699969034333e-05,2.6645500080727896e-05,2.361759970881394e-05,2.0933900335270057e-05,1.855509981396608e-05,1.6446799994203804e-05,1.4577999915369825e-05,1.2921600045956438e-05,1.1453499989026264e-05,1.0152199971950418e-05,8.998729981612996e-06,7.976370056894666e-06,7.070190046457962e-06,6.266969990065263e-06,5.555030005173951e-06,4.923979986415361e-06,4.364620015924932e-06,3.868820006876679e-06,3.4293599734761906e-06,3.0398200010495202e-06,2.6945299775131084e-06,2.3884800270934647e-06,2.1171900167852678e-06,1.8767199965926313e-06,1.6635700035294576e-06,1.4746300015152276e-06,1.3071600146001099e-06,1.1587099966921717e-06,1.0271199926137342e-06,9.104730101701838e-07,8.070790045167087e-07,7.154290007823268e-07,6.341880028533827e-07,5.621739992041815e-07,4.983390103537507e-07,4.417540040435597e-07,3.915940022617785e-07,3.4713199899745934e-07,3.077180039667837e-07,2.727810013425369e-07,2.4181000076358333e-07,2.1435700029807472e-07,1.9002100041613326e-07,1.6844799806866226e-07,1.4932500036479723e-07,1.323729984884873e-07,1.1734599958401759e-07,8.754612264757118e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.252856516589721,0.26552995791037876,0.2752249762415886,0.2848559816678365,0.2942139804363251,0.3033069794376691,0.3121409813563029,0.31936198721329373,0.3236989825963974,0.32532599071661633,0.32440098375082016,0.3210729906956355,0.3154799888531367,0.30775199582179386,0.2980109974741936,0.2863679925600688,0.2729329963525136,0.25896799316008884,0.24566699812809625,0.23299400011698404,0.2209129991630713,0.20938999950885773,0.1983949989080429,0.18789699797828993,0.17786699905991554,0.16827799876530966,0.1591049979130427,0.15039400135477385,0.1421899994214376,0.13446400066216788,0.1271899975836277,0.12034200069804986,0.11389500026901563,0.1078269990781943,0.10211599866549174,0.09674129945536454,0.09168299908439319,0.08691929901639621,0.08242959901690483,0.07819909850756328,0.07421349982420604,0.07045909948647022,0.06692319922149181,0.06359329881767432,0.06045769962171713,0.05750529902676741,0.054725599475204945,0.05210969938586155,0.0496490995089213,0.04733489919453859,0.04515849954138199,0.043111899557212986,0.04118749871850014,0.039378099143505096,0.03767679942150911,0.03607719919333855,0.03457319891701142,0.033160500228405,0.031834799175461136,0.030590699209521215,0.029423299400756758,0.028327799402177334,0.027299899297455948,0.026335399287442367,0.02543039930363496,0.024581199201444786,0.02378439934303363,0.02303649935250481,0.022334199243535597,0.021674899384379387,0.021055899560451508,0.020474699325859547,0.019928799476474524,0.019416299182921648,0.01893489932020505,0.018482699369390804,0.018057899394383032,0.01765649936472376,0.017274699329088133,0.016911199316382408,0.01656499955182274,0.016234899250169594,0.015920899497965973,0.015622599516063929,0.01533909933641553,0.015069399339457354,0.014812699519097805,0.014567899517714977,0.014335499533141652,0.014114899405588707,0.013903699427222213,0.013701299438253045,0.013508599484339356,0.013324799481779337,0.013148099572087327,0.012977799400687218,0.012814999480421344,0.012659199458236495,0.012508399474124113,0.012362399604171515,0.012222199545552334,0.012087399528051416,0.011956299422308803,0.01182849945810934,0.011705399490892887,0.011586499478047093,0.011470099445432425,0.011356199470659098,0.011245899523297945,0.011138899562259516,0.011033699537316958,0.010930199564124147,0.010829499534641704,0.010731599604090055,0.01063469952593247,0.010538999612132708,0.010445599521820744,0.010354399681091309,0.010263899574056268,0.010173899587243795,0.010085999500006437,0.009999809553846717,0.009913969784975052,0.00982839947876831,0.009744479553774,0.009662099570656816,0.009579739688585201,0.009497409531225761,0.00941648978429536,0.009336879632125298,0.009257089657088121,0.009177109614635507,0.009098359616473317,0.009020739623034993,0.008942769529918829,0.008864449725175897,0.008787219567845264,0.008710979639242092,0.00863425969146192,0.008557079515109459,0.008480859609941641,0.00840553967282176,0.008329649688676,0.008253209680939714,0.008177649540205797,0.008102919673547149,0.008027549600228667,0.007951559654126564,0.007876409605766336,0.0078020096601297455,0.007726929732598364,0.007651189691387117,0.007576229710442324,0.007501999653565387,0.007427039750230809,0.0073513896980633335,0.0072764896710092826,0.007202289649285376,0.007127339718863368,0.007051659670347969,0.0069767197128385305,0.006902459659613669,0.006827419662537674,0.006753049713249008,0.006679309726071854,0.0066047397364551825,0.006529399737094839,0.006454729669106503,0.006380679745537539,0.006305809753636519,0.006230159701469044,0.006155179813504219,0.006080829810040693,0.006005659777050217,0.005929709761403501,0.005854439766456683,0.0057797997336213785,0.005704329814761877,0.0056280997426559525,0.0055525398735577864,0.005477619784263273,0.00540188979357481,0.005325399882470568,0.005249609782670935,0.005174459773115814,0.005098509796274205,0.0050218098719293875,0.00494581984821707,0.00487047981005162,0.004794349893927574,0.00471747984799246,0.004641319741494954,0.004565819865092635,0.004489539850813647,0.004412519823138912,0.004336219824229677,0.004260579822584987,0.004184159838284056,0.004107019864022732,0.004030579895091553,0.003954819869250059,0.003878279821947217,0.003801019901099304,0.0037244698614813387,0.003648589850248148,0.0035719398874789476,0.003494559903629124,0.0034178998903371394,0.003341919897745053,0.0032651598836916187,0.0031876699261677763,0.0031109099315168955,0.003034819907043129,0.0029579599116307995,0.0028803699533455074,0.00280350991912807,0.0027273198938928545,0.0026503599559267363,0.002572669938672334,0.002495709942498555,0.0024194199747095504,0.002342369950686892,0.0022645799714761474,0.002187519974540919,0.002111139959500482,0.0020339799618038037,0.0019560999353416264,0.0018789499687651794,0.0018024699723658462,0.0017252099836089958,0.001647239977804323,0.0015699899813625962,0.0014934099939030905,0.0014160599869986374,0.001337989999835069,0.0012606500046482931,0.001183979989339908,0.0011093399953097105,0.0010394099905776482,0.0009738860001865154,0.0009124970044164608,0.0008549779934886222,0.0008010860037757084,0.000750592997064814,0.0007032840027629087,0.000658958000713028,0.0006174259954908242,0.0005785139995471885,0.0005420550054016834,0.0005078949955835318,0.00047588799740575877,0.0004458989981988755,0.000417801000973365,0.0003914739960843387,0.00036680699849966913,0.00034369500402438763,0.00032203999823347357,0.00030175000089608756,0.00028273800368576,0.0002649249994040777,0.0002482349979497182,0.00023259699931562258,0.00021794400163344108,0.00020421500084921718,0.00019135099986063628,0.0001792980001482647,0.00016800400044303387,0.0001574219980587562,0.00014750600045469278,0.00013821599835258289,0.00012951099779456854,0.00012135400174884126,0.00011371099996419314,0.0001065500000549946,9.98403005117628e-05,9.355300001819462e-05,8.766179962549359e-05,8.214169914329734e-05,7.69692996982485e-05,7.212279888335615e-05,6.758160028160394e-05,6.332639956478185e-05,5.933930030247817e-05,5.560319944682609e-05,5.210249977001998e-05,4.8822300110866e-05,4.574870066183697e-05,4.286859984858893e-05,4.0169900178928707e-05,3.764119992410997e-05,3.527169944087897e-05,3.305140035081422e-05,3.097099988735863e-05,2.9021499964680213e-05,2.7194799713470275e-05,2.5483100065078663e-05,2.3879199943621643e-05,2.2376299966708757e-05,2.096800002012363e-05,1.964840021173586e-05,1.841179998033719e-05,1.725309978913477e-05,1.6167400038587704e-05,1.5149999853747431e-05,1.4196599977367441e-05,1.3303300117210407e-05,1.2466199981039002e-05,1.1681700016197283e-05,1.0946699906829357e-05,1.0257900006157191e-05,9.612510060226972e-06,9.00772003357512e-06,8.440990086455713e-06,7.909920138141993e-06,7.4122800318339914e-06,6.945959929301655e-06,6.508989978707784e-06,6.099509960222349e-06,5.715809985910407e-06,5.356249971555371e-06,5.019310037823743e-06,4.703579975284811e-06,4.407720060347249e-06,4.130469998623691e-06,3.870670013839117e-06,3.627210010866596e-06,3.3990699913980884e-06,3.185289983775874e-06,2.9849499962134964e-06,2.7972200200565567e-06,2.6212999841845885e-06,2.4564499957098937e-06,2.301970027929201e-06,2.157210000556612e-06,2.0215499982138376e-06,1.8944299995382607e-06,1.7753000160306935e-06,1.663670000577137e-06,1.559060005244343e-06,1.4610300051269103e-06,1.369159984202876e-06,1.2830700105344779e-06,1.202400000011039e-06,1.1268000055982459e-06,1.055960012763535e-06,9.895709922602691e-07,9.273579972083704e-07,8.690569994011336e-07,8.144219947325837e-07,7.632239942267915e-07,7.152440038756444e-07,6.702819964251224e-07,6.281469969356598e-07,5.886619950009239e-07,5.516589993703747e-07,5.169840070114636e-07,4.844879934277438e-07,4.5403499863520363e-07,4.2549800364592255e-07,3.9875399693301006e-07,3.7369199882656784e-07,3.502050039590661e-07,3.2819499769705846e-07,3.075689984181433e-07,2.8823900303602085e-07,2.7012499496474146e-07,2.5314900161295856e-07,2.3723999949728144e-07,2.223319993296021e-07,2.0836000184469108e-07,1.9526699901462052e-07,1.829970000718125e-07,1.714979992091988e-07,1.6072200044921678e-07,1.5062299970243961e-07,1.411589991562323e-07,1.3228899931050364e-07,1.2397800238280374e-07,1.1618799966583993e-07,1.0888799965395417e-07,8.549569822472829e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3648618757724762,1.4759199917316437,1.5902700126171112,1.6950699985027313,1.7956500053405762,1.8920099834601085,1.9841699798901875,2.071649968624115,2.154000004132589,2.231230000654856,2.303350031375885,2.370360016822815,2.4322800238927207,2.48909999926885,2.5408599972724915,2.5875499645868936,2.629170000553131,2.6679700215657554,2.7061400016148887,2.743690013885498,2.7806300123532615,2.816950003306071,2.8526600201924643,2.8877599835395813,2.9222400188446045,2.956120014190674,2.9893800218900046,3.021969974040985,3.053809960683187,3.08489998181661,3.1152600049972534,3.1448699831962585,3.1737500031789145,3.2018799980481467,3.2292700012524924,3.2559200127919516,3.2818400065104165,3.3071699937184653,3.3320499658584595,3.3564799427986145,3.3804500102996826,3.403979996840159,3.4270599683125815,3.4496899843215942,3.4718799392382302,3.493619998296102,3.5149200359980264,3.5357799927393594,3.556220014890035,3.576240042845408,3.5958300034205117,3.6150100032488504,3.633769969145457,3.6521100401878357,3.6700300375620523,3.687529981136322,3.7046300172805786,3.721300025780996,3.737530012925466,3.753339946269989,3.7687099973360696,3.7836400071779885,3.7981499830881753,3.8122299710909524,3.825879991054535,3.8390999833742776,3.851889987786611,3.864290018876394,3.8763299783070884,3.8880200187365213,3.899360020955404,3.910349984963735,3.9209800362586975,3.9312700231870017,3.9411999781926474,3.9507700204849243,3.960010011990865,3.96888001759847,3.9774000446001687,3.9855599999427795,3.9933599829673767,4.000810027122498,4.0078999598821,4.014630079269409,4.020999948183696,4.027030070622762,4.032699982325236,4.0381399393081665,4.043499946594238,4.048760016759236,4.053930004437764,4.059000015258789,4.063989996910095,4.068880041440328,4.073679963747661,4.078390081723531,4.083010037740071,4.087540030479431,4.09198002020518,4.096320033073425,4.10057004292806,4.104739944140117,4.108809947967529,4.112790067990621,4.116689999898274,4.120490034421285,4.124200065930684,4.127820014953613,4.131360014279683,4.134799957275391,4.138149976730347,4.141419927279155,4.144590139389038,4.147679964701335,4.150680025418599,4.1535898844401045,4.156410098075867,4.15913999080658,4.1617900133132935,4.164340019226074,4.166810035705566,4.169189969698588,4.171490112940471,4.173689961433411,4.175819953282674,4.177850047747294,4.179810086886088,4.181670029958089,4.183450063069661,4.185139934221904,4.186750014623006,4.188270012537639,4.1896999279658,4.191049973169963,4.192310055096944,4.193490028381348,4.194579998652141,4.195580005645752,4.1964999834696455,4.197330077489217,4.198080023129781,4.198740005493164,4.199320038159688,4.199809988339742,4.200219988822937,4.200539946556091,4.200780034065247,4.200940052668254,4.20100998878479,4.200990001360576,4.200889945030212,4.200709939002991,4.200440009435018,4.2000900109608965,4.199659983317058,4.199140032132466,4.198539932568868,4.197859923044841,4.1970899899800616,4.196239988009135,4.195309996604919,4.1942899624506635,4.193189938863118,4.192010005315145,4.1907499233881635,4.1893999973932905,4.187979976336162,4.186470031738281,4.18487008412679,4.183199961980184,4.181439995765686,4.179609974225362,4.177689989407857,4.175689975420634,4.1736100514729815,4.171439965565999,4.169199983278911,4.166870037714641,4.164469917615254,4.161979993184407,4.159420013427734,4.15676995118459,4.1540400584538775,4.151230096817017,4.14835000038147,4.145380020141602,4.142329970995585,4.139209985733032,4.136000037193298,4.1327199538548784,4.129350105921428,4.1259100039800005,4.122389992078145,4.118789990743001,4.1151100397109985,4.111350019772847,4.1075199842453,4.103600064913432,4.099609971046448,4.095549980799357,4.091409921646118,4.0871899127960205,4.082900007565816,4.078520019849141,4.074079950650533,4.069550037384033,4.064950029055278,4.060269991556804,4.055509964625041,4.050679961840312,4.045770009358724,4.04078996181488,4.035730004310608,4.030590017636617,4.02537989616394,4.0200899839401245,4.014729976654053,4.009289979934692,4.003780047098796,3.9981900254885354,3.9925299882888794,3.9867900013923645,3.980970005194346,3.975089947382609,3.969119966030121,3.9630900422732034,3.956980029741923,3.950790007909139,3.9445299903551736,3.9382000168164573,3.931790033976237,3.925320029258728,3.9187600016593933,3.9121399919191995,3.905440012613932,3.8986599842707315,3.891820013523102,3.884939988454183,3.878079970677694,3.8712299863497415,3.8643899957338967,3.8575700322786965,3.8507500092188516,3.843950013319651,3.8371599912643433,3.8303800026575723,3.8236199816068015,3.816860020160675,3.8101200262705484,3.8033899863560996,3.7966699997584024,3.789970020453135,3.783269981543223,3.7765899697939553,3.76992001136144,3.7632700006167092,3.7566199898719788,3.749990006287893,3.743360002835592,3.7367500265439353,3.7301599780718484,3.7235699892044067,3.7169899940490723,3.7104299664497375,3.70388001203537,3.6973399917284646,3.6908100048700967,3.6842899918556213,3.6777899861335754,3.6712899804115295,3.664810001850128,3.6583399971326194,3.6518800059954324,3.6454400022824607,3.6390000184377036,3.632580041885376,3.626159985860189,3.619759996732076,3.6133699814478555,3.6069899996121726,3.6006200313568115,3.5942699909210205,3.5879199703534446,3.581590016682943,3.5752699772516885,3.5689600110054016,3.562659978866577,3.5563700000445047,3.55009001493454,3.5438299973805747,3.537569999694824,3.5313300490379333,3.525089999039968,3.518870015939077,3.5126599868138633,3.5064600110054016,3.5002699891726174,3.4940900206565857,3.4879299799601235,3.4817699988683066,3.475629985332489,3.4694900512695312,3.4633699854214988,3.457259992758433,3.4511600136756897,3.4450700283050537,3.43898997704188,3.4329200188318887,3.426859974861145,3.4208100040753684,3.4147799809773765,3.408749997615814,3.4027399818102517,3.3967299660046897,3.3907400170962014,3.3847599824269614,3.378779967625936,3.37281999985377,3.3668700059254966,3.36093000570933,3.3549999992052713,3.34907998641332,3.3431699872016907,3.3372700015703836,3.3313899834950766,3.3255099852879844,3.3196400006612143,3.3137900034586587,3.3079399863878884,3.3021000027656555,3.2962799866994223,3.290459990501404,3.28466006120046,3.278860032558441,3.2730800112088523,3.2673099835713706,3.2615399956703186,3.2557900150616965,3.250040034453074,3.2443100214004517,3.2385900020599365,3.2328799764315286,3.227169990539551,3.2214799523353577,3.2157999873161316,3.210129976272583,3.204460004965464,3.1988100012143454,3.1931700309117637,3.1875399947166443,3.1819199919700623,3.1763000090916953,3.170699973901113,3.165110011895498,3.15953000386556,3.1539599696795144,3.1483900348345437,3.142840027809143,3.1373000144958496,3.1317699948946633,3.1262400150299072,3.120730002721151,3.1152299642562866,3.109729985396067,3.1042499939600625,3.098770022392273,3.093309998512268,3.0878499945004783,3.082409997781118,3.076970020929972,3.071549952030182,3.066129982471466,3.06072998046875,3.0553300182024636,3.049940009911855,3.0445599953333535,3.0391899943351746,3.03384002049764,3.0284900069236755,3.023150006930033,3.0178200006484985,3.012499988079071,3.0071799953778586,3.0018800099690757,2.996589998404185,2.9913100202878318,2.9860299825668335,2.9807699720064798,2.9755100210507712,2.970270017782847,2.965029994646708,2.9598000049591064,2.9545800487200418,2.949380020300547,2.9441800117492676,2.93898997704188,2.9338000218073526,2.92863001426061,2.9234700004259744,2.9183199803034463,2.9131699999173484,2.9080400268236795,2.902910033861796,2.89779003461202,2.892679989337921,2.8875799973805747,2.8824899991353354,2.8774099946022034,2.8723400235176086,2.8672799666722617,2.862219989299774,2.8571799993515015,2.852139949798584,2.847120006879171,2.842099984486898,2.837089995543162,2.8320900201797485,2.8270899852116904,2.8221099972724915,2.81714004278183,2.8121700088183084,2.807220002015432,2.80227001508077,2.7973300019900003,2.7924000024795532,2.7874799966812134,2.7825600107510886,2.777659992376963,2.7727699875831604,2.7678799827893577,2.763000011444092,2.7581300139427185,2.753269990285238,2.748420000076294,2.7435699899991355,2.738740026950836,2.7339099844296775,2.7290900150934854,2.7242899934450784,2.719480017820994,2.7146899700164795,2.709909995396932,2.7051300009091697,2.700369973977407,2.695609986782074,2.6908599734306335,2.686120013395945,2.681380013624827,2.676659941673279,2.671940008799235,2.6672299901644387,2.662529985109965,2.6578400135040283,2.653160035610199,2.64847997824351,2.6438200076421103,2.6391599774360657,2.6345099806785583,2.629869977633158,2.6252300143241882,2.620610018571218,2.6159900029500327,2.6113800009091697,2.6067800323168435,2.6021899779637656,2.597599983215332,2.5930200020472207,2.5884600083033242,2.583889981110891,2.5793400009473166,2.57479997475942,2.570259968439738,2.5657299757003784,2.561210016409556,2.556699971357981,2.5521999994913735,2.5477000077565513,2.5432100097338357,2.538729965686798,2.5342599948247275,2.529790004094442,2.5253400007883706,2.5208899974823,2.5164500077565513,2.5120099782943726,2.5097999771436057};
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.48009459177653,4.563908696174622,4.606989026069641,4.679159164428711,4.754629095395406,4.833389004071553,4.91542915503184,4.995899200439453,5.069929321606954,5.137519399325053,5.19866943359375,5.253379503885905,5.301649610201518,5.343489646911621,5.378889719645183,5.407859762509664,5.430389801661174,5.44931976000468,5.467479825019836,5.484869837760925,5.501489758491516,5.517339785893758,5.5324298938115435,5.54673985640208,5.560289899508159,5.57306985060374,5.585079908370972,5.596459825833638,5.607329924901326,5.617689887682597,5.627549846967061,5.636899948120117,5.645749926567078,5.65408988793691,5.661929965019226,5.669269879659017,5.676099936167399,5.6825400193532305,5.688699960708618,5.69458011786143,5.700179934501648,5.70549996693929,5.710549990336101,5.715319991111755,5.719809969266255,5.724019964536031,5.727959950764974,5.731679956118266,5.735240022341411,5.738649964332581,5.741910020510356,5.745019912719727,5.74796998500824,5.7507699728012085,5.753419876098633,5.755919933319092,5.7582599719365435,5.760479887326558,5.762609998385112,5.764649947484334,5.766599973042806,5.768459955851237,5.770229935646057,5.771909991900126,5.773500005404155,5.77498992284139,5.776400009791057,5.777730027834575,5.778970003128052,5.7801499764124555,5.781239986419678,5.782260020573934,5.7831999858220415,5.784070014953613,5.784859935442607,5.785569985707601,5.786209940910339,5.786769986152649,5.7872499624888105,5.787660042444865,5.787990013758342,5.78823999563853,5.788420001665751,5.788530031840007,5.788550059000651,5.78849995136261,5.7883700132369995,5.788209994633992,5.788040041923523,5.7878700494766235,5.787690003712972,5.78751003742218,5.7873300313949585,5.787149906158447,5.786969979604085,5.786780039469401,5.786589980125427,5.7864000002543134,5.786199967066447,5.78600001335144,5.785800019900004,5.785589933395386,5.785380005836487,5.785169959068298,5.784960031509399,5.784740050633748,5.78453000386556,5.784309983253479,5.784080068270366,5.783860007921855,5.783629973729451,5.7833999792734785,5.783159971237183,5.782920002937317,5.782679994901021,5.7824400663375854,5.7821900844573975,5.78193994363149,5.781690080960591,5.781440019607544,5.781179944674174,5.780919988950093,5.780660033226013,5.780399998029073,5.78012998898824,5.779860059420268,5.779589970906575,5.779310027758281,5.779030044873555,5.778749942779541,5.778469999631246,5.778180042902629,5.777889966964722,5.777599930763245,5.777300000190735,5.777009963989258,5.7767099142074585,5.776400009791057,5.776099960009257,5.775789936383565,5.775480031967163,5.775159994761149,5.774839997291565,5.7745299736658735,5.774199962615967,5.7738800048828125,5.773549993832906,5.77321990331014,5.772889931996663,5.772549986839294,5.772220015525818,5.771869977315267,5.771529992421468,5.771180033683777,5.770829995473226,5.770480036735535,5.770119945208232,5.76976998647054,5.769409974416097,5.769040028254191,5.768679936726888,5.768310070037842,5.767940004666646,5.767560005187988,5.7671899398167925,5.766810019810994,5.766430020332336,5.766040007273356,5.7656499942143755,5.765269994735718,5.764870047569275,5.764480034510295,5.764080047607422,5.763680060704549,5.763269980748494,5.762869914372762,5.762459993362427,5.762039979298909,5.761630058288574,5.761209964752197,5.760790069897969,5.760369976361592,5.759939988454183,5.7595200935999555,5.759079972902934,5.758650024731954,5.758209943771362,5.75777006149292,5.757330020268758,5.756890018781026,5.756440003712972,5.7559899886449175,5.755539973576863,5.755080024401347,5.754619995752971,5.754159927368164,5.753699938456218,5.753230015436809,5.7527700662612915,5.75228997071584,5.751820047696431,5.75133999188741,5.750860095024109,5.750379999478658,5.749890049298604,5.749399979909261,5.7489099105199175,5.748419960339864,5.747920036315918,5.747430046399434,5.7469199895858765,5.746420065561931,5.745910008748372,5.7453999519348145,5.744889974594116,5.744370063145955,5.743859966595967,5.743339975674947,5.742809971173604,5.742290059725444,5.741760055224101,5.741230050722758,5.740700006484985,5.74015998840332,5.739619930585225,5.73907991250356,5.7385300397872925,5.737980047861735,5.737430016199748,5.736879984537761,5.73631997903188,5.73576005299886,5.735200007756551,5.734640002250671,5.7340699434280396,5.733500003814697,5.732930024464925,5.732360005378723,5.731789906819661,5.731209913889567,5.730639974276225,5.730070034662883,5.729489962259929,5.728919943173726,5.728349963823955,5.727779944737752,5.727200031280518,5.726630012194316,5.726060072580974,5.725490013758342,5.7249101003011065,5.724340001742045,5.723770062128703,5.723199963569641,5.722619970639546,5.722049991289775,5.721479972203572,5.720909992853801,5.720329999923706,5.719760060310364,5.7191899220148725,5.7186200221379595,5.718049963315328,5.717479983965556,5.716899991035461,5.716330051422119,5.7157600323359175,5.715190013249715,5.714619994163513,5.7140499750773115,5.713469982147217,5.712900002797444,5.712330023447673,5.7117600440979,5.711189905802409,5.710620005925496,5.710049986839294,5.709479967753093,5.70890998840332,5.708330035209656,5.707759976387024,5.707190036773682,5.706620097160339,5.706050078074138,5.705480019251506,5.704910000165303,5.704339981079102,5.703770001729329,5.703199982643127,5.702630003293355,5.702059984207153,5.701490004857381,5.700920025507609,5.700350006421407,5.699779987335205,5.699210007985433,5.698639988899231,5.6980700095494585,5.697500030199687,5.696929971377055,5.696360031763713,5.69579001267751,5.695219993591309,5.694650014241536,5.6940799951553345,5.693509976069133,5.69294007619222,5.692370057106018,5.691799998283386,5.691239992777507,5.690669973691304,5.690099994341533,5.68952997525533,5.688960035641988,5.688390016555786,5.687820037206014,5.687250018119812,5.68667995929718,5.68612003326416,5.685549974441528,5.684979955355327,5.684410015741984,5.6838399569193525,5.6832700570424395,5.682699998219808,5.682139992713928,5.6815699736277265,5.681000034014384,5.680430054664612,5.679860075314839,5.679299990336101,5.678730010986328,5.678160031636556,5.677590012550354,5.677019993464152,5.676459987958272,5.67588996887207,5.675320029258728,5.674750010172526,5.674190044403076,5.673620065053304,5.673050006230672,5.6724900007247925,5.67192006111145,5.671350002288818,5.670779983202617,5.670219977696736,5.669649998346965,5.669080018997192,5.668520013491313,5.66794999440511,5.667379975318909,5.6668200095494585,5.666250069936116,5.665680011113484,5.665119965871175,5.664549986521403,5.663980007171631,5.663419961929321,5.662850022315979,5.662279963493347,5.661719997723897,5.661149978637695,5.660589973131816,5.660020033518474,5.659450093905131,5.6588899691899615,5.658320029576619,5.65775998433431,5.657189925511678,5.656620025634766,5.656059940656026,5.655490001042684,5.654929995536804,5.6543599764506025,5.653799970944722,5.6532299518585205,5.6526700258255005,5.652100006739299,5.651540040969849,5.650970021883647,5.650409936904907,5.649839997291565,5.649279952049255,5.648710012435913,5.6481499671936035,5.647580067316691,5.647020061810811,5.646450002988179,5.64589003721873,5.6453200578689575,5.644759972890218,5.644190073013306,5.643630067507426,5.643060008684794,5.642500042915344,5.641940077145894,5.641369978586833,5.640810052553813,5.64024003346761,5.639679988225301,5.6391200224558515,5.63854996363322,5.6379900376002,5.637420018513997,5.6368599732716875,5.636300007502238,5.635730028152466,5.635169982910156,5.634610017140706,5.6340400377909345,5.633479913075765,5.632920026779175,5.632350047429402,5.631790002187093,5.6312300364176435,5.630660017331441,5.630100051561992,5.629540046056111,5.62896994749705,5.62841002146403,5.627849976221721,5.6272900104522705,5.626719951629639,5.626160025596619,5.625600020090739,5.625040014584859,5.624469955762227,5.623909950256348,5.623349944750468,5.622790018717448,5.622219959894816,5.621659994125366,5.621100028355916,5.6205399831136065,5.6199800570805865,5.619409958521525,5.618850032488505,5.618289987246196,5.617730061213176,5.617170055707295,5.616599957148234,5.616040031115214,5.615480065345764,5.614919980367024,5.6143598556518555,5.613800009091695,5.613240003585815,5.612669984499614,5.612110058466594,5.611550013224284,5.610990007718404,5.610429922739665,5.609869996706645,5.609309951464335,5.608750065167745,5.608189980189006,5.6076299746831255,5.607059955596924,5.606499989827474,5.605940024058024,5.605380018552144,5.6048199733098345,5.604260007540385,5.603700081507365,5.6031399965286255,5.602579991022746,5.602020025253296,5.6014600197474165,5.600899974505107,5.600340048472087,5.599779963493347,5.599219997723897,5.598659992218018,5.598099986712138,5.597540020942688,5.596979975700378,5.596420009930928,5.595860004425049,5.595299998919169,5.594740033149719,5.5941799481709795,5.59361998240153,5.59305997689565,5.592509984970093,5.592229962348938};
    //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174864321947098,0.6330969432989756,0.6433759480714798,0.6584909309943517,0.6742939402659734,0.6907849262158076,0.7079629351695379,0.7248109430074692,0.7403099536895752,0.7544609407583872,0.7672619571288427,0.778715968132019,0.7888209720452627,0.7975769639015198,0.8049859752257665,0.8110479911168417,0.8157609899838766,0.8197209884723028,0.8235209882259369,0.8271579841772715,0.8306339830160141,0.833948994676272,0.8371039976676306,0.840096985300382,0.8429299841324488,0.8456019908189774,0.8481129904588064,0.8504899889230728,0.8527619938055674,0.8549260000387827,0.8569860011339188,0.858939990401268,0.8607879926760992,0.8625300029913584,0.8641669998566309,0.8656969964504242,0.8671229978402456,0.8684659997622172,0.8697499881188074,0.8709770043691,0.8721450020869573,0.8732549945513407,0.8743059933185577,0.875298003355662,0.8762339949607849,0.8771099994579951,0.8779279887676239,0.8787010014057159,0.8794429997603098,0.8801530003547668,0.8808310031890869,0.8814759999513626,0.8820869972308477,0.8826669951279958,0.8832149902979533,0.8837319960196813,0.8842159956693649,0.8846749862035116,0.8851149926582972,0.8855369985103607,0.8859389871358871,0.8863219966491064,0.8866860022147497,0.8870299955209097,0.8873559981584549,0.887663001815478,0.8879509965578715,0.888221005598704,0.8884759893019994,0.888714000582695,0.8889370014270147,0.8891440033912659,0.8893349965413412,0.8895100007454554,0.8896699994802475,0.8898130059242249,0.8899409969647726,0.8900530089934667,0.8901490072409312,0.8902289966742197,0.8902929971615473,0.8903420021136602,0.8903739949067434,0.8903909971316656,0.8903900037209193,0.8903720031181971,0.8903389970461527,0.890296995639801,0.8902550041675568,0.8902119994163513,0.8901670028765997,0.8901219964027405,0.8900769998629888,0.8900319983561834,0.889987995227178,0.88994100689888,0.8898930003245672,0.889844998717308,0.8897970020771027,0.8897490054368973,0.8897000054518381,0.8896480003992716,0.8895970036586126,0.8895460019508997,0.8894950052102407,0.8894439985354742,0.8893910050392151,0.8893369982639948,0.8892830014228821,0.8892290045817693,0.8891740043958029,0.8891200025876363,0.8890640040238699,0.8890069971481959,0.888949990272522,0.8888920048872629,0.8888349880774816,0.8887760092814764,0.8887149939934412,0.8886549969514211,0.8885939965645472,0.8885340044895808,0.8884739975134531,0.8884120086828867,0.8883480032285055,0.8882840077082316,0.8882210006316503,0.8881570001443228,0.8880920012791952,0.8880250006914139,0.8879589984814326,0.8878919978936514,0.8878250022729238,0.8877580016851425,0.8876900027195612,0.8876199970642725,0.8875499914089838,0.8874809990326563,0.8874109983444214,0.8873390108346939,0.8872670034567515,0.8871939977010092,0.8871210018793741,0.8870479961236318,0.8869750003019968,0.886899987856547,0.8868240068356196,0.8867480009794235,0.8866720000902811,0.8865959992011389,0.8865189999341965,0.8864390005668005,0.8863599995772043,0.8862809985876083,0.8862019926309586,0.88612300157547,0.8860419938961664,0.8859600027402242,0.8858780016501745,0.8857950071493784,0.8857129961252213,0.8856310000022253,0.8855470071236292,0.8854620009660721,0.885376994808515,0.8852910002072653,0.8852059990167618,0.8851190060377121,0.8850309898455938,0.8849420001109441,0.8848539988199869,0.8847649991512299,0.8846770028273264,0.8845869998137156,0.8844950000445048,0.8844040085872015,0.8843120038509369,0.8842210024595261,0.8841279993454615,0.8840329945087433,0.8839380045731863,0.883843998114268,0.8837490081787109,0.883654996752739,0.883557990193367,0.8834610084692637,0.8833629935979843,0.8832649886608124,0.8831679970026016,0.8830680002768835,0.8829679936170578,0.8828670034805933,0.882765993475914,0.8826650033394495,0.8825640082359314,0.8824619998534521,0.8823579996824265,0.8822539995114008,0.8821499943733215,0.8820459942022959,0.8819410055875778,0.8818340053160986,0.8817269951105118,0.8816199998060862,0.8815129995346069,0.8814059992631277,0.8812980055809021,0.8811880052089691,0.8810779998699824,0.8809679994980494,0.8808579991261164,0.8807460019985834,0.8806330015261968,0.8805200060208639,0.8804070105155309,0.8802929917971293,0.8801799913247427,0.8800659974416097,0.8799499968687693,0.879832997918129,0.8797170023123423,0.8796009918053945,0.8794849862655004,0.87936698893706,0.8792480031649271,0.8791290024916331,0.8790089935064316,0.8788899978001913,0.8787689954042435,0.8786470045646032,0.8785249988238016,0.878401999672254,0.878279983997345,0.8781580030918121,0.8780340005954107,0.8779080112775167,0.8777830004692078,0.8776579896608988,0.8775320003430048,0.8774069945017496,0.877281000216802,0.8771559993426005,0.877030998468399,0.8769059975941976,0.8767799983421961,0.8766549974679947,0.8765300015608469,0.8764049907525381,0.8762789964675903,0.8761540055274963,0.8760289947191874,0.8759039988120397,0.8757789979378382,0.8756539970636368,0.8755289961894354,0.8754039953152338,0.8752790043751398,0.8751540035009384,0.8750279943148295,0.8749029984076818,0.8747789909442266,0.8746540049711863,0.8745289991299311,0.8744039982557297,0.8742790023485819,0.8741540014743805,0.8740290006001791,0.8739039997259775,0.8737790038188299,0.8736550013224283,0.8735300004482269,0.8734050045410792,0.8732799937327703,0.8731550027926763,0.8730310002962748,0.8729059994220734,0.8727809935808182,0.8726569960514704,0.8725320001443228,0.8724069992701212,0.8722830017407736,0.8721579958995184,0.8720339934031168,0.8719089974959692,0.8717839966217676,0.87165999909242,0.8715349932511648,0.8714110006888708,0.8712859998146693,0.8711619973182678,0.8710369914770126,0.8709129989147186,0.8707890063524246,0.8706640005111694,0.8705400079488754,0.8704159955183665,0.8702909996112188,0.8701669921477636,0.8700429946184158,0.8699179987112681,0.8697939912478129,0.8696700036525726,0.8695460011561712,0.869420995314916,0.8692969977855682,0.8691730002562205,0.869048997759819,0.868925005197525,0.8688010076681772,0.8686760018269221,0.8685520042975744,0.8684280067682266,0.8683039943377177,0.8681800017754236,0.8680559992790222,0.8679320017496744,0.867807999253273,0.8676840017239252,0.8675600041945776,0.867436001698176,0.8673120041688284,0.8671889901161194,0.8670649975538254,0.8669410049915314,0.8668170024951299,0.866692990064621,0.8665690024693807,0.866446003317833,0.8663219958543777,0.86619799832503,0.8660740007956823,0.8659510016441345,0.8658270140488943,0.8657030065854391,0.8655799974997839,0.8654559850692749,0.8653320024410883,0.8652090032895406,0.8650849958260854,0.8649620066086451,0.8648379991451899,0.8647139966487885,0.864590992530187,0.8644669950008392,0.8643439958492914,0.8642199983199438,0.8640970041354498,0.8639740000168482,0.8638500024875005,0.8637269934018453,0.8636029958724976,0.8634799917538961,0.8633569975694021,0.8632330050071081,0.8631099959214529,0.8629869967699051,0.8628629992405573,0.8627399951219559,0.8626170009374619,0.8624940017859141,0.86237100760142,0.8622470051050186,0.8621240009864172,0.8620010018348694,0.8618779927492142,0.8617549985647202,0.8616319894790649,0.8615089903275172,0.8613860011100769,0.8612619986136755,0.8611389994621277,0.8610160052776337,0.8608930011590322,0.8607699970404307,0.8606480062007904,0.8605250070492426,0.8604019929965337,0.8602790037790934,0.8601559996604919,0.8600330054759979,0.8599100013573965,0.8597870022058487,0.8596640030543009,0.8595420072476069,0.8594189981619517,0.8592960039774576,0.8591729948918024,0.8590510040521622,0.8589279899994532,0.8588050057490667,0.8586830049753189,0.8585600008567175,0.8584369967381159,0.8583149959643682,0.8581920017798742,0.8580690125624338,0.8579470068216324,0.8578239927689234,0.8577019969622294,0.8575789928436279,0.8574569970369339,0.8573340078194936,0.8572120070457458,0.8570889979600906,0.8569670021533966,0.8568449964125952,0.8567219922939936,0.8566000064214071,0.8564769973357519,0.8563549965620041,0.8562330007553101,0.8561099966367086,0.8559880008300146,0.8558660000562668,0.855743999282519,0.8556209951639175,0.8554990043242773,0.8553769985834757,0.855254997809728,0.855133002003034,0.8550099929173788,0.8548879971106847,0.8547660013039907,0.8546440005302429,0.8545219997564951,0.8543999989827474,0.8542780031760534,0.8541560024023056,0.8540339966615041,0.8539120008548101,0.8537900000810623,0.8536679993073145,0.8535459985335668,0.853423997759819,0.8533019969860712,0.8531799962123235,0.853057990471522,0.8529359996318817,0.8528150071700414,0.8526930063962936,0.8525710006554922,0.8524490048487982,0.8523270040750504,0.8522059917449951,0.8520840009053549,0.8519619951645533,0.851841002702713,0.8517189919948578,0.8515969961881638,0.8514760037263235,0.8513540029525757,0.8512320121129354,0.8511110047499338,0.8509890039761862,0.8508680015802383,0.8507460057735443,0.8506240000327429,0.8505030026038488,0.850381001830101,0.8502599944670995,0.8501390069723129,0.8500169962644577,0.8498959988355637,0.8497739980618159,0.8496530055999756,0.8495309849580129,0.8494100024302801,0.849289005001386,0.8491669942935308,0.8490460067987442,0.8489249994357427,0.8488040020068487,0.8486820012331009,0.8485610087712606,0.8484400063753128,0.8483189990123113,0.8481980015834173,0.8480759908755621,0.8479550033807755,0.8478340009848276,0.8477129936218262,0.8475919961929321,0.8474710086981455,0.847350001335144,0.84722900390625,0.8471679985523224};
    //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194723625977835,0.18438400203982988,0.18693100040157637,0.18956000233689943,0.19230899835626283,0.19517900049686432,0.19816900044679642,0.2011019984881083,0.20379799976944923,0.20625700056552887,0.2084799992541472,0.21046599869926771,0.21221400052309036,0.21372700110077858,0.2150029999514421,0.21604299917817116,0.21684700002272925,0.2175190014143785,0.2181629997988542,0.21877899890144667,0.2193669999639193,0.21992599839965501,0.22045600041747093,0.22095699856678644,0.22142900029818216,0.22187399988373122,0.22229000180959702,0.2226830000678698,0.22305799896518388,0.22341499974330267,0.22375299905737242,0.22407200063268343,0.2243730016052723,0.2246559982498487,0.2249199983974298,0.22516400118668875,0.22539099926749864,0.2256040001908938,0.22580599909027418,0.2259980005522569,0.22618000085155168,0.2263519987463951,0.22651299958427748,0.22666400174299875,0.22680500025550523,0.22693599884708723,0.22705600038170815,0.22716899837056795,0.22727500026424727,0.22737500071525574,0.22747000058492026,0.2275599998732408,0.22764399896065393,0.22772299995025,0.22779399901628494,0.22786099836230278,0.22792300209403038,0.22797999903559685,0.22803400084376335,0.2280840016901493,0.22813199957211813,0.22817599773406982,0.22821499903996786,0.2282530019680659,0.22828700145085654,0.2283179983496666,0.2283449980119864,0.22837000091870627,0.22839200124144554,0.22841099898020426,0.22842799872159958,0.2284409999847412,0.22845000276962915,0.22845699886480966,0.22846100106835365,0.22846199944615364,0.2284609998265902,0.22845799972613653,0.22845199704170227,0.22844300046563148,0.22843199968338013,0.22841700042287508,0.2283980002005895,0.2283759998778502,0.22835200279951096,0.2283260002732277,0.22829700137178102,0.22826599950591722,0.22823599725961685,0.22820599873860678,0.2281749981145064,0.22814500207702318,0.2281149998307228,0.22808400044838587,0.22805399944384894,0.22802400216460228,0.22799300029873848,0.22796300053596497,0.227932999531428,0.22790099928776422,0.22786900028586388,0.22783600042263666,0.22780299807588258,0.2277699982126554,0.22773700207471848,0.22770500307281813,0.2276719994843006,0.22763900086283684,0.22760599851608276,0.227572999894619,0.22754100089271864,0.22750800102949142,0.2274749999245008,0.22744199757774672,0.22741000105937323,0.22737699995438257,0.22734399884939194,0.227312001089255,0.22727899874250093,0.2272460013628006,0.22721300025780997,0.2271810012559096,0.22714800015091896,0.22711500277121863,0.22708199669917425,0.22704600046078363,0.22701100135842958,0.22697599977254868,0.22694100067019463,0.22690599908431372,0.2268699991206328,0.22683499877651533,0.22680000215768814,0.22676500057180723,0.22673000146945319,0.22669499988357225,0.2266599995394548,0.22662400205930075,0.2265889992316564,0.2265539988875389,0.22651899978518486,0.22648399944106737,0.2264489990969499,0.22641399999459585,0.22637899965047836,0.2263440005481243,0.22630900144577026,0.22627399985988936,0.22623899951577187,0.22620200117429098,0.22616500159104666,0.22612699990471205,0.2260890007019043,0.22605199987689653,0.22601399819056192,0.2259770023326079,0.22593899816274643,0.2259019985795021,0.2258640006184578,0.2258270022769769,0.22578899934887886,0.2257519985238711,0.22571400180459023,0.22567699973781905,0.22563900177677473,0.22560200095176697,0.22556399802366892,0.22552700092395148,0.22548900047938028,0.22545199717084566,0.22541499882936478,0.22537700086832047,0.22533999755978584,0.22530199959874153,0.22526400163769722,0.22522400071223578,0.22518400102853775,0.22514399886131287,0.22510400041937828,0.22506399949391684,0.22502400105198225,0.22498399888475737,0.2249440016845862,0.2249039995173613,0.2248649982114633,0.22482499852776527,0.22478500256935754,0.2247449979186058,0.22470500071843466,0.22466499730944633,0.2246250001092752,0.224586001286904,0.22454600036144257,0.22450600067774454,0.22446599851051965,0.22442600006858507,0.2243870012462139,0.22434700032075247,0.224306999395291,0.22426599760850272,0.2242240011692047,0.2241820010046164,0.22413899997870126,0.224096999814113,0.2240549996495247,0.22401199986537298,0.22397000094254813,0.22392799829443297,0.2238859993716081,0.22384299834569296,0.2238009994228681,0.22375900050004324,0.22371700157721838,0.22367500141263008,0.22363300000627837,0.22359000022212663,0.22354800005753836,0.22350599989295006,0.22346399972836176,0.22342200204730034,0.22337999939918518,0.2233369971315066,0.22329499945044518,0.22325300176938376,0.22320999950170517,0.2231649992366632,0.22312099734942117,0.2230760008096695,0.22303099930286407,0.22298699989914894,0.22294200211763382,0.22289800023039183,0.2228529987235864,0.22280799970030785,0.2227640002965927,0.2227190025150776,0.2226750006278356,0.2226300003627936,0.22258600095907846,0.22254100069403648,0.2224969988067945,0.22245200102527937,0.22240799789627394,0.22236300135652223,0.2223190019528071,0.22227400044600168,0.22222999980052313,0.22218599915504456,0.22214099764823914,0.22209700072805086,0.22205199797948202,0.2220079998175303,0.22196300079425177,0.22191899766524634,0.2218750019868215,0.22183000296354294,0.2217860035598278,0.22174199918905893,0.2216970001657804,0.22165299952030182,0.22160900135835013,0.2215639998515447,0.22152000044782957,0.22147599856058756,0.22143100077907243,0.2213870013753573,0.2213429994881153,0.22129900132616362,0.2212540010611216,0.22120999917387962,0.22116600225369135,0.22112200036644936,0.22107699885964394,0.2210329994559288,0.22098900005221367,0.2209449994067351,0.2209010012447834,0.22085599725445113,0.2208120015760263,0.22076799596349397,0.22072400028506914,0.2206799996395906,0.22063600023587546,0.22059200083216032,0.2205469993253549,0.22050299992163977,0.22045900175968805,0.22041499863068262,0.22037099922696748,0.2203270010650158,0.22028300166130066,0.22023899853229523,0.2201949991285801,0.22015099972486496,0.22010700032114983,0.2200630009174347,0.2200189990301927,0.21997499838471413,0.21993100022276243,0.21988700330257416,0.21984299893180528,0.2197989970445633,0.21975500136613846,0.21971099823713303,0.21966700007518133,0.2196230006714662,0.21957899878422418,0.21953499938050905,0.2194909987350305,0.21944700057307878,0.21940400078892708,0.2193600026269754,0.21931599949796995,0.21927199885249138,0.21922799944877625,0.21918399880329767,0.21913999815781912,0.21909699961543083,0.2190530002117157,0.21900899956623712,0.21896499767899513,0.21892100324233374,0.2188779997328917,0.21883399908741316,0.21878999844193459,0.2187460002799829,0.21870300049583116,0.21865899985035261,0.21861500044663748,0.21857099855939546,0.21852800125877062,0.21848400185505548,0.21843999872605005,0.2183970001836618,0.21835300077994665,0.21830899889270464,0.21826600035031637,0.21822200094660124,0.2181779978175958,0.21813500051697096,0.21809099987149239,0.21804700046777725,0.21800400068362555,0.21795999755462012,0.21791700025399527,0.21787300085028014,0.217829001446565,0.21778599793712297,0.21774199977517128,0.21769899874925613,0.217654999345541,0.2176119995613893,0.21756799767414728,0.21752500037352243,0.21748099848628044,0.21743799870212874,0.21739399805665016,0.21735099951426187,0.21730700135231018,0.21726400032639503,0.21721999968091646,0.21717699989676476,0.21713400135437647,0.21709000070889792,0.2170470009247462,0.2170029990375042,0.2169600004951159,0.21691699822743735,0.21687300006548563,0.21683000028133392,0.2167860008776188,0.2167429973681768,0.21670000006755194,0.2166560006638368,0.21661299963792166,0.21656999985376993,0.21652599920829138,0.21648299942413965,0.21643999963998795,0.2163969986140728,0.2163530004521211,0.21631000066796938,0.21626699964205423,0.21622399985790253,0.2161800004541874,0.21613699942827225,0.2160939984023571,0.2160509998599688,0.21600699921449026,0.21596400191386542,0.2159209984044234,0.21587800110379854,0.21583499883611998,0.21579100067416826,0.2157479996482531,0.2157049998641014,0.21566200380524,0.21561900153756142,0.21557599926988283,0.21553300072749457,0.21548999970157942,0.2154469999174277,0.21540299927194914,0.2153599994877974,0.2153169997036457,0.215273999919494,0.2152310013771057,0.21518800035119057,0.21514499932527542,0.21510200078288713,0.21505899975697199,0.21501599997282028,0.21497300018866858,0.21493000040451685,0.21488700062036514,0.21484399959445,0.2148009998102983,0.21475800126791,0.2147150014837583,0.21467200045784315,0.214628999431928,0.21458599964777628,0.214543999483188,0.21450099969903627,0.21445799867312113,0.21441500137249628,0.21437200034658113,0.21432900056242943,0.21428600077827772,0.21424299975236258,0.21420100207130113,0.214158001045386,0.21411499877770743,0.21407200023531914,0.21402900045116743,0.21398599818348885,0.21394400050242743,0.21390099947651228,0.21385799845059714,0.21381499990820885,0.213773000985384,0.21373000120123228,0.2136869989335537,0.2136440003911654,0.21360200146834055,0.2135590004424254,0.2135160006582737,0.21347300335764885,0.2134310007095337,0.2133879984418551,0.21334500114123026,0.21330300097664198,0.21325999995072684,0.21321700140833855,0.21317500000198683,0.21313200145959854,0.21309000129501024,0.21304700151085854,0.2130039967596531,0.21296199907859167,0.21291900177796683,0.21287699912985167,0.21283399934569994,0.21279100080331168,0.21274900063872337,0.21270599961280823,0.21266400068998337,0.21262099966406822,0.21257900322477022,0.21253599971532822,0.21249400079250336,0.2124509997665882,0.21240900084376335,0.2123659998178482,0.2123240021367868,0.21228100111087164,0.21223900094628334,0.2121959999203682,0.21215399851401648,0.21211199959119162,0.21206899856527647,0.2120269996424516,0.21198400110006332,0.21194199721018472,0.21190000077088675,0.21187800417343775};
        //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.1268948403497537,0.12773999944329262,0.12867599974075952,0.12960899993777275,0.13058499619364738,0.1316039984424909,0.1326679972310861,0.13371000066399574,0.13466700042287508,0.13553799812992415,0.13632399961352348,0.13702399904529253,0.137638999770085,0.1381670000652472,0.1386100004116694,0.1389680008093516,0.13923999791344008,0.13946400210261345,0.13967799892028174,0.13988300040364265,0.1400769998629888,0.140260998159647,0.1404350015024344,0.14059799909591675,0.14075100049376488,0.14089399948716164,0.14102600142359734,0.14114999895294508,0.14126699790358543,0.14137699951728186,0.14148099968830744,0.1415779987970988,0.14166900143027306,0.14175300051768622,0.14183000226815543,0.14190100133419037,0.14196399971842766,0.14202200000484785,0.14207700019081435,0.1421280006567637,0.14217599853873253,0.14221900080641112,0.14225900049010912,0.1422940008342266,0.14232700069745383,0.1423560008406639,0.14238099878033003,0.14240400244792303,0.1424240010480086,0.1424419991672039,0.14245800053079924,0.14247199892997742,0.14248400057355562,0.14249400049448013,0.14250199993451437,0.1425069992740949,0.14251100023587546,0.1425129994750023,0.14251499995589256,0.14251500243941942,0.14251399785280228,0.14251100023587546,0.14250699679056802,0.1425020011762778,0.14249599973360697,0.14248899991313616,0.14248100171486536,0.14247100055217743,0.1424600010116895,0.14244900022943816,0.14243599896629652,0.1424230014284452,0.14240799968441328,0.14239200204610825,0.1423750010629495,0.14235800132155418,0.14233999947706857,0.14231999963521957,0.14229999979337057,0.14227799947063127,0.142255999147892,0.14223199834426245,0.14220799878239632,0.14218300208449364,0.14215600242217383,0.1421279994150003,0.14209899803002676,0.1420699991285801,0.14203999936580658,0.1420109992225965,0.1419810007015864,0.14195200180013975,0.14192199955383936,0.14189300065239271,0.14186299964785576,0.1418340007464091,0.14180499936143556,0.14177499959866205,0.14174599945545197,0.14171599969267845,0.14168699954946837,0.14165699978669485,0.14162800336877504,0.14159899950027466,0.14156899973750114,0.14153999959429106,0.14151099945108095,0.14148099968830744,0.1414520007868608,0.14142300064365068,0.14139300088087717,0.14136399949590364,0.14133400097489357,0.1413030003507932,0.14127200096845627,0.1412410003443559,0.14120999972025552,0.1411790003379186,0.14114799971381822,0.1411170003314813,0.14108600094914436,0.14105499908328056,0.14102399970094362,0.1409930003186067,0.14096199969450632,0.1409310003121694,0.14090000092983246,0.14086899906396866,0.14083799968163171,0.14080699905753136,0.1407759996751944,0.1407450015346209,0.14071400091052055,0.14068400114774704,0.14065299928188324,0.14062199865778288,0.14059100051720938,0.14056000113487244,0.14052899926900864,0.14049899826447168,0.14046800136566162,0.14043699825803438,0.14040600011746088,0.14037500321865082,0.14034400011102358,0.14031400034825006,0.1402829997241497,0.14025199910004935,0.14022099847594896,0.1401909999549389,0.1401600018143654,0.14012900243202844,0.14009800180792809,0.14006800080339113,0.14003700017929077,0.14000600079695383,0.13997500017285347,0.13994499916831651,0.139914001027743,0.13988299667835236,0.1398529993991057,0.1398210016389688,0.13978900015354156,0.13975600029031435,0.13972400004665056,0.13969199980298677,0.139659001181523,0.1396269996960958,0.139594999452432,0.13956200083096823,0.139529999345541,0.1394979991018772,0.13946500048041344,0.1394330014785131,0.13940099999308586,0.13936899974942207,0.13933599988619486,0.13930400336782137,0.13927199815710387,0.1392399991552035,0.1392069992919763,0.13917500153183937,0.13914299880464873,0.13911100228627524,0.13907799993952116,0.13904599969585738,0.139014000693957,0.13898200169205666,0.138949998964866,0.13891799996296564,0.13888500009973845,0.13885299985607466,0.1388210008541743,0.1387890006105105,0.13875700160861015,0.1387249988814195,0.13869299987951914,0.1386599987745285,0.13862799977262816,0.13859600077072778,0.13856399804353714,0.1385320027669271,0.13849999755620956,0.13846800227959952,0.138435997068882,0.13840400179227194,0.1383719965815544,0.13834000130494437,0.13830799609422684,0.13827599957585335,0.138244000573953,0.13821100071072578,0.13817699874440828,0.1381440001229445,0.13810999939839044,0.13807599991559982,0.1380420004328092,0.13800899932781854,0.13797499984502792,0.13794200122356415,0.13790800049901009,0.13787399977445602,0.13784100115299225,0.13780699918667474,0.13777300218741098,0.13774000108242035,0.13770599911610285,0.13767299925287566,0.137638999770085,0.1376050002872944,0.1375720016658306,0.1375379996995131,0.13750500107804933,0.1374710015952587,0.13743800049026808,0.13740399976571402,0.13737100114425024,0.1373369979361693,0.13730399931470552,0.1372699998319149,0.13723699872692427,0.13720299924413362,0.13716999938090643,0.13713599989811578,0.1371030000348886,0.13706999892989793,0.13703599944710732,0.13700299710035324,0.13696899885932604,0.13693599899609885,0.13690199827154478,0.136868999650081,0.1368359997868538,0.13680200030406317,0.13676900044083595,0.13673599809408188,0.13670200109481812,0.13666899874806404,0.1366359976430734,0.13660199816028276,0.13656900078058243,0.1365359996755918,0.13650199895103773,0.13646900157133737,0.13643600046634674,0.13640300060311952,0.1363690011203289,0.13633599877357483,0.1363030013938745,0.13626999904712042,0.13623599956432977,0.13620299970110258,0.13616999859611192,0.1361370012164116,0.13610300049185753,0.1360700006286303,0.13603699952363968,0.13600400214393935,0.13597100103894869,0.1359379986921946,0.13590400169293085,0.13587100058794022,0.13583799948294958,0.1358050008614858,0.13577200224002203,0.13573900113503137,0.13570599754651388,0.1356729989250501,0.1356390006840229,0.13560600082079569,0.1355729984740416,0.13553999985257784,0.13550699998935065,0.13547400012612343,0.1354410002628962,0.13540800039966902,0.1353750005364418,0.13534199943145117,0.13530899956822395,0.13527599970499674,0.1352429986000061,0.13521000122030577,0.1351770001153151,0.13514399901032448,0.1351110003888607,0.13507799928387007,0.13504499942064285,0.13501200079917908,0.13497899969418845,0.13494700069228807,0.1349140020708243,0.1348809984823068,0.13484800110260645,0.13481499999761581,0.13478200137615204,0.1347490002711614,0.13471599916617075,0.13468299806118011,0.13465100030104318,0.13461799919605255,0.13458500181635222,0.13455200071136156,0.13451900084813437,0.13448700060447058,0.13445399949947992,0.13442099963625273,0.1343879997730255,0.13435499866803488,0.1343229984243711,0.13429000104467073,0.13425699745615324,0.13422400007645288,0.13419200107455254,0.13415900245308876,0.1341260001063347,0.13409300024310747,0.13406099875768027,0.1340280001362165,0.13399500275651613,0.13396300127108893,0.13393000016609827,0.13389699906110764,0.1338650000592073,0.13383200019598007,0.1337990015745163,0.13376700008908907,0.13373400022586188,0.13370199874043465,0.13366900011897087,0.13363599901398024,0.13360400001207987,0.13357100014885268,0.13353899866342545,0.1335060012837251,0.1334730014204979,0.13344099869330725,0.1334079975883166,0.1333759973446528,0.13334300244847933,0.13331099972128868,0.13327799861629805,0.13324599961439768,0.1332130009929339,0.1331810007492701,0.13314799964427948,0.13311600064237913,0.13308300077915192,0.13305100177725157,0.13301900029182434,0.13298599794507027,0.13295400018493334,0.132921002805233,0.13288900131980577,0.13285600021481514,0.1328239987293879,0.13279199848572412,0.13275899986426035,0.13272700086236,0.13269399975736937,0.13266199951370558,0.13262999802827835,0.13259700064857802,0.13256500164667764,0.13253300016125044,0.13250000029802322,0.1324680025378863,0.1324360010524591,0.13240399956703186,0.13237100094556808,0.13233899821837744,0.13230699921647707,0.13227399935324988,0.1322420003513495,0.1322099988659223,0.13217799986402193,0.1321450024843216,0.13211299975713095,0.13208099951346716,0.13204899926980337,0.132017000267903,0.1319840004046758,0.13195200016101202,0.13191999991734824,0.1318880021572113,0.13185600191354752,0.13182399794459343,0.13179099932312965,0.1317590003212293,0.13172699883580208,0.13169500107566515,0.13166299959023794,0.13163099934657416,0.13159899910291037,0.13156700134277344,0.13153399899601936,0.13150199875235558,0.1314699985086918,0.1314380019903183,0.1314060017466545,0.13137399901946387,0.13134200125932693,0.1313099985321363,0.13127800077199936,0.13124599928657213,0.13121400028467178,0.131182000041008,0.1311499997973442,0.13111800079544386,0.13108599931001663,0.1310540003081163,0.13102199882268906,0.13098999857902527,0.13095799709359804,0.13092599933346113,0.13089400033156076,0.13086200008789697,0.13083099946379662,0.13079900046189627,0.13076700394352278,0.13073499873280525,0.13070300221443176,0.13067099824547768,0.13063900048534074,0.13060699899991354,0.1305759996175766,0.1305440030992031,0.13051200037201247,0.13047999888658524,0.130447997401158,0.1304159996410211,0.13038500025868416,0.13035300001502037,0.13032100101312002,0.13028900076945624,0.13025699804226556,0.13022599865992865,0.13019400089979172,0.13016199817260107,0.13013000165422758,0.1300990010301272,0.1300669995447,0.13003500178456306,0.1300040011604627,0.12997199967503548,0.12993999694784483,0.12990800167123476,0.12987699980537096,0.12984500204523405,0.12981300180157027,0.12978199993570647,0.12974999845027924,0.1297180006901423,0.1296870013078054,0.1296550010641416,0.12962400044004121,0.12959200019637743,0.12955999995271364,0.12952899932861328,0.12949700156847635,0.12946599846084914,0.12943399821718535,0.12940199797352156,0.12937100107471147,0.12933899958928427,0.12930799896518388,0.12929200008511543};
        C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.28434885293245316,0.2899609978000323,0.29543599983056384,0.3019520044326782,0.3087659974892934,0.3158760021130244,0.3232849985361099,0.3305490016937256,0.3372250000635783,0.34331299861272174,0.3488140006860097,0.3537279963493347,0.3580550005038579,0.3617949957648913,0.36494799455006915,0.36751500020424527,0.36949499944845837,0.3711479976773262,0.37273099770148593,0.37424300362666446,0.37568599979082745,0.3770570009946823,0.37835800647735596,0.3795899997154872,0.38075099885463715,0.381841999789079,0.38286300003528595,0.38382500658432644,0.3847409983476003,0.38561100016037625,0.38643499960501987,0.387214000026385,0.3879460021853447,0.3886310011148453,0.38927099853754044,0.3898630018035571,0.39041100194056827,0.3909229983886083,0.3914090022444725,0.3918699969847997,0.39230500161647797,0.3927139962712924,0.39309900005658466,0.39345799883206684,0.3937929968039195,0.3941019997000694,0.394385002553463,0.3946479956309001,0.394896999001503,0.39513300110896427,0.3953550060590108,0.3955620005726814,0.39575500041246414,0.39593500395615894,0.3961009954412778,0.39625199635823566,0.3963889976342519,0.39651600271463394,0.39663399507602054,0.3967449963092804,0.39684699724117917,0.39694099873304367,0.39702700326840085,0.3971040000518163,0.3971719990173976,0.3972330018877983,0.39728599538405734,0.39733100185791653,0.39736800144116086,0.39739900082349777,0.3974230041106542,0.39744000136852264,0.3974509984254837,0.39745299766461056,0.39744900663693744,0.39743899802366894,0.3974209974209468,0.3973969991008441,0.3973649988571803,0.39732599755128223,0.3972810010115306,0.3972289984424909,0.39717000474532443,0.39710400501887005,0.3970310017466545,0.3969509998957316,0.39686399946610135,0.3967749973138173,0.39668499926726025,0.39659599711497623,0.3965049982070923,0.39641399681568146,0.39632299542427063,0.3962319965163867,0.3961400017142296,0.39604899783929187,0.3959580014149348,0.395867000023524,0.39577500273784,0.3956819996237755,0.3955889989932378,0.395496000846227,0.3954029977321625,0.3953099995851517,0.39521700143814087,0.3951240008076032,0.3950289984544118,0.3949339985847473,0.39483999957640964,0.39474499970674515,0.39464999735355377,0.39455599586168927,0.3944610009590785,0.3943659986058871,0.39426999787489575,0.3941729987661044,0.39407700300216675,0.39398099730412167,0.39388399571180344,0.39378800243139267,0.3936909958720207,0.39359300086895627,0.39349499344825745,0.3933970034122467,0.3932990034421285,0.3932010034720103,0.3931029960513115,0.39300500601530075,0.3929059977332751,0.3928060010075569,0.3927070026596387,0.3926070009668668,0.3925069992740949,0.39240799595912296,0.39230800171693164,0.3922079975406329,0.39210600157578784,0.3920049990216891,0.39190300057331723,0.39180200050274533,0.39170099794864655,0.39159899950027466,0.39149800191322964,0.3913960059483846,0.3912929991881053,0.39118999739487964,0.39108700056870777,0.3909829979141553,0.3908799961209297,0.3907780001560847,0.3906739999850591,0.3905690014362335,0.3904639979203542,0.39035900433858234,0.39025499671697617,0.3901499981681506,0.390044999619325,0.3899409994482994,0.389835000038147,0.38972900062799454,0.3896219953894615,0.38951599846283597,0.38940899819135666,0.3893030012647311,0.3891970018545787,0.3890890007217725,0.38898099958896637,0.3888730009396871,0.38876499980688095,0.3886569986740748,0.38854899754126865,0.38844100137551624,0.3883330002427101,0.3882239982485771,0.388114000360171,0.38800500084956485,0.38789500296115875,0.38778499762217206,0.3876760005950928,0.3875660002231598,0.3874550039569537,0.38734400024016696,0.3872319981455803,0.3871210018793742,0.38700999816258747,0.3868979985515277,0.3867870047688484,0.38667600353558856,0.386563998957475,0.38645000010728836,0.3863369971513748,0.386223999162515,0.3861109986901283,0.3859980007012685,0.38588500022888184,0.3857710013786952,0.38565700004498166,0.38554200281699497,0.38542699813842773,0.3853130017717679,0.3851980020602544,0.38508299986521405,0.38496900101502735,0.3848529979586601,0.3847370023528735,0.38462000091870624,0.3845040003458659,0.3843880022565524,0.38427100082238513,0.38415499528249103,0.38403799881537753,0.38391999651988346,0.38380200167497,0.3836840018630028,0.3835659995675087,0.3834479997555415,0.38332999994357425,0.38321200013160706,0.383092999458313,0.3829739987850189,0.38285400221745175,0.3827339981993039,0.38261499752600986,0.3824950009584427,0.3823760002851486,0.38225499788920086,0.38213399797677994,0.3820130030314128,0.381891002257665,0.3817699998617172,0.3816489999492963,0.3815280000368754,0.3814070001244545,0.3812850018342336,0.38116200268268585,0.38103899856408435,0.3809159994125366,0.3807930002609889,0.3806700011094411,0.38054700195789337,0.38042500118414563,0.38030199706554413,0.3801790028810501,0.38005700210730237,0.37993400047222775,0.37981199969847995,0.3796890005469322,0.3795669997731845,0.3794440006216367,0.37932199984788895,0.37919899821281433,0.3790770024061203,0.3789550041158994,0.37883299589157104,0.37870999922355014,0.3785880009333293,0.37846599767605466,0.37834399938583374,0.3782220035791397,0.37809999535481137,0.37797799458106357,0.37785599877436954,0.3777339980006218,0.37761300305525464,0.3774909973144531,0.3773689990242322,0.3772469957669576,0.37712599833806354,0.3770039975643158,0.3768819992740949,0.376760999361674,0.3766389985879262,0.37651800115903217,0.37639599790175754,0.3762749955058098,0.37615400552749634,0.376031997303168,0.37591099987427395,0.375789999961853,0.3756690000494321,0.37554699927568436,0.3754260018467903,0.3753050019343694,0.37518399705489475,0.3750629971424739,0.37494199474652606,0.374820997317632,0.37470000237226486,0.3745800008376439,0.37445900092522305,0.374338003496329,0.3742169961333275,0.37409699708223343,0.37397600213686627,0.37385499725739163,0.3737349982062976,0.37361400326093036,0.3734940017263095,0.37337299933036167,0.3732529977957408,0.37313199539979297,0.3730120013157527,0.37289199978113174,0.3727709998687108,0.37265100081761676,0.3725309992829959,0.37241099774837494,0.37229100118080777,0.37217099964618683,0.3720510005950928,0.3719310015439987,0.37181100249290466,0.3716909984747569,0.37157099942366284,0.3714510003725688,0.37133100380500156,0.3712110022703807,0.37109199663003284,0.37097200006246567,0.3708520059784253,0.37073299785455066,0.3706130037705104,0.3704940006136894,0.37037400404612225,0.3702550008893013,0.37013500183820724,0.3700160011649132,0.3698969980080922,0.36977699647347134,0.3696579982837041,0.36953899761041004,0.36941999942064285,0.3692999978860219,0.36918099721272785,0.36906199902296066,0.3689429983496666,0.36882400264342624,0.3687050019701322,0.368586003780365,0.3684680014848709,0.36834899832804996,0.36823000262180966,0.3681109994649887,0.3679920012752215,0.36787399649620056,0.3677550007899602,0.36763600011666614,0.36751799533764523,0.3673989996314049,0.3672810023029645,0.36716199666261673,0.36704400678475696,0.36692599952220917,0.366807001332442,0.3666890040040016,0.3665709967414538,0.36645200351874035,0.3663339987397194,0.3662159989277522,0.36609800159931183,0.36598000427087146,0.36586199949185055,0.3657439947128296,0.3656259998679161,0.36550799012184143,0.36539000272750854,0.36527200043201447,0.3651539956529935,0.36503699918588,0.3649189944068591,0.36480100204547244,0.3646839956442515,0.36456600328286487,0.36444800595442456,0.3643309970696767,0.3642130022247632,0.3640959958235423,0.36397799849510193,0.3638609970609347,0.36374399562676746,0.36362600326538086,0.36350900183121365,0.36339200536410016,0.3632750039299329,0.363156999150912,0.3630400026837985,0.3629230037331581,0.362805999815464,0.36268900086482364,0.36257199943065643,0.36245500296354294,0.36233799904584885,0.36222099761168164,0.36210500200589496,0.36198800057172775,0.36187099913756055,0.36175400267044705,0.3616379996140798,0.3615210031469663,0.36140399674574536,0.36128799865643185,0.3611709997057915,0.36105500161647797,0.3609379976987839,0.36082200209299725,0.36070600152015686,0.36058900008598965,0.36047299951314926,0.36035700390736264,0.36024100085099536,0.36012400190035504,0.36000800132751465,0.35989199827114743,0.3597760001818339,0.35965999960899353,0.35954400151968,0.3594279984633128,0.3593120028575261,0.3591959998011589,0.3590799992283185,0.3589639961719513,0.35884900391101837,0.35873300085465115,0.35861700028181076,0.3585020030538241,0.35838599751393,0.35826999445756275,0.358154999713103,0.3580390016237895,0.3579240043958028,0.35780800382296246,0.35769300411144894,0.35757799943288165,0.35746200382709503,0.3573469991485278,0.357232004404068,0.35711699972550076,0.35700100163618725,0.35688599944114685,0.3567710022131602,0.3566560000181198,0.3565409978230794,0.3564260005950928,0.35631099840005237,0.35619600117206573,0.3560809940099716,0.3559660017490387,0.35585200041532516,0.35573699822028476,0.3556220009922981,0.3555070012807846,0.35539300243059796,0.35527800023555756,0.355163998901844,0.3550489991903305,0.354933999478817,0.35481999566157657,0.35470600177844364,0.3545909970998764,0.3544770007332166,0.35436200102170307,0.35424799968798953,0.3541340008378029,0.35401999950408936,0.3539050022761027,0.3537910009423892,0.3536770020922025,0.35356300075848895,0.3534489994247754,0.3533350005745888,0.35322100172440213,0.3531069979071617,0.3529929965734482,0.3528800035516421,0.3527659997344017,0.35265200088421506,0.35253799706697464,0.352423998216788,0.35231100271145505,0.35219699641068775,0.3520840009053548,0.35196999957164127,0.3518569966157277,0.35174300024906796,0.35162999977668125,0.3515730028351148};
        //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.1294021358092626,0.1327500008046627,0.13621000200510025,0.14001099889477095,0.1439869999885559,0.14813499773542085,0.15245500082770982,0.15669200072685877,0.160586000730594,0.16413900131980577,0.16735100001096725,0.170219998806715,0.1727480006714662,0.17493400101860365,0.17677800233165422,0.17828199888269106,0.17944500098625818,0.18041600038607916,0.1813460004826387,0.18223599965373674,0.18308399866024652,0.18389200046658516,0.18465899924437204,0.18538500120242438,0.18606900051236153,0.18671399727463722,0.1873170013229052,0.18788600216309229,0.1884280008574327,0.18894399826725325,0.1894329972565174,0.18989500030875206,0.19033100083470345,0.19073900083700815,0.19112000241875648,0.19147499899069467,0.19180300335089365,0.19210999955733618,0.19240299984812737,0.19268099715312323,0.1929429993033409,0.19319100181261697,0.19342399885257086,0.19364199911554655,0.19384599849581718,0.1940350023408731,0.19420799861351648,0.19437100117405257,0.19452599932750067,0.1946719984213511,0.19480999931693077,0.19493999953071275,0.19506099820137024,0.19517499829332033,0.19528100142876306,0.195377999295791,0.1954669989645481,0.19554999967416128,0.1956280010441939,0.19570200021068254,0.1957710012793541,0.19583500052491823,0.1958939991891384,0.19594799975554147,0.19599600012103716,0.19604100162784258,0.19608000045021376,0.1961159979303678,0.19614700227975845,0.1961739994585514,0.19619699815909067,0.19621599838137627,0.19623099888364473,0.1962419996658961,0.19625000034769377,0.19625300044814745,0.19625200082858404,0.19624700024724007,0.19623699908455214,0.1962240015467008,0.19620699932177862,0.1961849977572759,0.19616000105937323,0.19612999881307283,0.19609700019160906,0.19605999936660132,0.19601899882157645,0.1959750031431516,0.19593100001414618,0.19588700061043104,0.19584299872318903,0.19579899807771048,0.1957550011575222,0.19570999965071678,0.19566399976611137,0.19561900198459625,0.19557400047779083,0.1955289989709854,0.19548299784461656,0.19543800130486488,0.19539299979805946,0.19534799953301749,0.19530300050973892,0.19525700186689696,0.19520999739567438,0.19516299913326898,0.19511699924866358,0.19506999974449477,0.19502300148208937,0.19497699911395708,0.19493000085155168,0.19488399972518286,0.19483700022101402,0.19478999947508177,0.1947420003513495,0.19469399998585382,0.19464600210388502,0.1945980004966259,0.19455000013113022,0.19450200100739798,0.19445399940013885,0.19440600151817003,0.19435800115267435,0.1943099983036518,0.19426099956035614,0.19421200081706047,0.19416299959023794,0.1941129999856154,0.19406400000055632,0.19401400039593378,0.1939650004108747,0.19391599918405214,0.19386699919899306,0.19381700083613396,0.19376799960931143,0.1937180000046889,0.19366699953873953,0.193616001556317,0.19356600070993105,0.19351500272750854,0.1934639997780323,0.19341399893164635,0.19336300094922385,0.1933120017250379,0.1932619996368885,0.19320999955137572,0.1931579994658629,0.19310600186387697,0.19305400053660074,0.1930019979675611,0.19294999912381172,0.19289800028006235,0.19284600019454956,0.19279400010903677,0.19274199878176054,0.19269000242153803,0.1926369977494081,0.1925839992860953,0.19252999996145567,0.19247699777285257,0.19242299968997637,0.19236999998490015,0.19231700027982393,0.19226299971342087,0.1922099987665812,0.19215700154503187,0.19210300097862879,0.19204900041222572,0.19199400022625923,0.19194000090161958,0.19188499947388968,0.19182999804615974,0.1917750003437201,0.19172099977731705,0.1916660020748774,0.19161099940538406,0.19155700132250786,0.1915019986530145,0.19144700095057487,0.19138999904195467,0.19133399923642477,0.19127799943089485,0.19122200086712837,0.19116599981983504,0.19111000001430511,0.1910540002087752,0.1909980004032453,0.19094200059771538,0.1908849999308586,0.1908279980222384,0.1907700002193451,0.19071299831072488,0.19065499926606813,0.1905979998409748,0.19054100041588148,0.19048299764593443,0.19042599822084108,0.1903690000375112,0.19031099726756415,0.1902529994646708,0.19019400080045065,0.1901359980305036,0.19007700184981027,0.19001800070206323,0.18995900203784308,0.18990100175142288,0.18984200060367584,0.18978300069769224,0.1897250016530355,0.18966599802176157,0.18960700059930483,0.18954699859023094,0.18948600192864737,0.18942599991957346,0.18936600039402643,0.189305999626716,0.18924599885940552,0.1891859993338585,0.1891260010500749,0.18906600152452788,0.1890060007572174,0.18894399826725325,0.18888300036390623,0.1888210028409958,0.18875999997059503,0.18869799996415773,0.1886370008190473,0.18857599794864655,0.1885140004257361,0.18845300003886223,0.18839199965198836,0.1883300021290779,0.18826700126131377,0.1882040003935496,0.18814200162887573,0.188079002002875,0.18801600113511086,0.18795400112867355,0.18789100150267282,0.18782800187667212,0.18776599938670793,0.18770299976070723,0.18764099975426993,0.18757800261179605,0.18751600136359534,0.1874529980123043,0.18739100048939386,0.18732799962162971,0.18726600085695586,0.18720300123095512,0.18714099998275438,0.18707899749279022,0.18701599910855293,0.18695399910211563,0.1868919978539149,0.1868289994696776,0.18676700070500374,0.18670500194032988,0.1866419998308023,0.186579999824365,0.18651799857616425,0.1864560010532538,0.1863940010468165,0.18633200228214264,0.1862700010339419,0.1862080010275046,0.186144998917977,0.18608300015330315,0.1860209989051024,0.18595900014042854,0.18589700137575468,0.18583500012755394,0.18577399974068007,0.18571200097600618,0.18564999972780546,0.18558799847960472,0.18552599971493086,0.18546399970849356,0.18540199846029282,0.18534099931518236,0.1852790005505085,0.1852170005440712,0.1851550005376339,0.18509400015076002,0.18503200138608614,0.18497000013788542,0.1849089985092481,0.18484699726104736,0.1847850022216638,0.18472399935126305,0.18466199934482574,0.1846010001997153,0.18453900019327799,0.18447800104816756,0.18441599855820337,0.18435499941309294,0.18429299940665564,0.18423200026154518,0.18417000025510788,0.18410900110999742,0.18404800072312355,0.1839859982331594,0.18392499908804893,0.18386399745941162,0.18380200117826462,0.1837409995496273,0.18368000040451685,0.18361900125940642,0.1835579996307691,0.18349599838256836,0.1834349992374579,0.18337399885058403,0.18331299970547357,0.18325200056036314,0.18319100017348924,0.18312999978661537,0.1830689993997415,0.18300800025463104,0.18294699986775717,0.1828860007226467,0.18282500033577284,0.18276400119066238,0.18270299956202507,0.18264200165867805,0.18258100127180418,0.18252000088493028,0.18246000135938326,0.18239899848898253,0.1823380005856355,0.18227700144052505,0.18221599981188774,0.18215599656105042,0.18209500114123026,0.18203399951259294,0.18197399626175562,0.18191300084193548,0.18185200045506159,0.1817919984459877,0.18173099930087724,0.18167099977533022,0.1816099981466929,0.1815490002433459,0.18148899947603545,0.181428000330925,0.18136800080537796,0.18130800127983093,0.18124700089295706,0.18118700136741003,0.18112600098053613,0.1810660014549891,0.18100599944591522,0.1809450015425682,0.18088499953349432,0.18082500249147415,0.18076400086283684,0.18070400009552637,0.18064399932821593,0.1805839998026689,0.18052400276064873,0.18046299989024797,0.18040300036470094,0.18034299835562706,0.1802830013136069,0.18022300178805986,0.18016300102074942,0.1801029990116755,0.18004300072789192,0.17998299996058145,0.17992299795150757,0.1798630009094874,0.1798029989004135,0.17974299937486649,0.1796830010910829,0.17962299784024557,0.17956299955646196,0.17950399965047836,0.17944400012493134,0.1793840005993843,0.17932399983207384,0.17926400154829025,0.17920500164230665,0.17914500087499619,0.17908500010768572,0.17902600020170212,0.17896600191791853,0.1789059986670812,0.17884699876109758,0.17878699923555055,0.17872700095176697,0.17866799856225649,0.17860799903670946,0.1785490003724893,0.17848899960517883,0.17842999969919524,0.17836999893188477,0.17831100026766458,0.17825099950035414,0.17819200083613396,0.17813299844662348,0.1780730001628399,0.1780140002568563,0.17795500035087267,0.17789499958356222,0.17783600216110548,0.17777699852983156,0.17771699776252112,0.1776580015818278,0.17759899919231734,0.177540003011624,0.1774809993803501,0.17742199947436652,0.1773619974652926,0.17730299880107245,0.17724399889508882,0.17718499774734178,0.17712600405017534,0.1770669979353746,0.1770080029964447,0.1769489993651708,0.17689000070095062,0.17683099955320358,0.17677200213074684,0.17671299601594606,0.17665399983525276,0.17659499992926916,0.17653699964284897,0.17647800097862879,0.17641899858911833,0.1763599974413713,0.1763009987771511,0.1762430009742578,0.1761840023100376,0.17612499992052713,0.17606600001454353,0.17600799848635992,0.1759489985803763,0.175891000777483,0.1758320008714994,0.1757730022072792,0.1757150006790956,0.17565600077311197,0.17559799924492836,0.17553899933894476,0.17548099781076112,0.17542200038830438,0.17536399886012077,0.1753050001959006,0.17524699990948042,0.17518800124526024,0.1751299984753132,0.17507200067241988,0.17501300076643625,0.1749550017217795,0.17489700143535933,0.1748380002876123,0.17478000124295553,0.1747219997147719,0.17466400067011514,0.17460500076413155,0.1745470017194748,0.1744890014330546,0.174430999904871,0.1743729996184508,0.17431500057379404,0.17425599818428358,0.17419800038139024,0.17414000009497008,0.17408199856678644,0.17402400200565657,0.17396600171923637,0.17390800267457962,0.17384999990463257,0.17379200085997581,0.17373400057355562,0.1736770011484623,0.1736190008620421,0.1735609993338585,0.1735029990474383,0.17344500000278154,0.1733870009581248,0.17333000029126802,0.1732720024883747,0.17321399847666422,0.17315599943200746,0.1730989987651507,0.17306999986370405};
        //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09222396276891232,0.0935024010638396,0.09476499942441781,0.09621129992107551,0.09772430049876372,0.09930400053660075,0.10094999956587951,0.10256400083502133,0.10404699978729089,0.10539800052841504,0.10661699995398521,0.10770599978665511,0.10866300016641617,0.1094890000919501,0.11018299994369347,0.11074699958165486,0.11117900038758914,0.11153800040483475,0.11188100030024846,0.11220799883206685,0.11251999934514363,0.11281599973638852,0.11309599938491981,0.11336099977294604,0.11361000003914039,0.11384299956262112,0.11406099982559681,0.11426600068807602,0.11446000014742215,0.11464399906496207,0.11481799992422263,0.11498100124299526,0.11513400077819824,0.115276999771595,0.11541000070671241,0.11553300047914188,0.11564499946931998,0.1157490002612273,0.1158479992300272,0.11594100048144658,0.11602800029019515,0.11610899927715461,0.1161839993049701,0.11625400061408679,0.11631799985965093,0.11637700162827969,0.11643000071247418,0.11647799983620644,0.11652399909993012,0.11656600050628185,0.11660600018997987,0.11664199953277905,0.11667500001688798,0.11670400016009808,0.1167309998224179,0.11675400100648403,0.11677500046789646,0.11679300044973691,0.1168089999506871,0.11682399983207385,0.11683700047433376,0.11684700039525826,0.11685600069661935,0.11686299865444501,0.11686799985667069,0.1168710005780061,0.11687199895580609,0.11687199895580609,0.11686999971667926,0.11686700023710728,0.11686199965576331,0.11685500045617421,0.11684699977437656,0.11683699985345204,0.11682599907120068,0.11681400053203106,0.11680000089108944,0.11678400076925755,0.11676600016653538,0.11674699932336807,0.11672599986195564,0.11670399953921635,0.11668100021779537,0.11665600041548412,0.116629999751846,0.11660100022951762,0.11657099984586239,0.11653999860088031,0.11650999821722507,0.116479001318415,0.11644800007343292,0.11641800031065941,0.11638699968655904,0.11635599968334039,0.1163260005414486,0.11629500053822994,0.116264999533693,0.11623400015135606,0.1162029995272557,0.11617199952403705,0.11613999990125497,0.1161080002784729,0.11607600065569083,0.11604400041202705,0.1160130010296901,0.11598100016514461,0.11594899992148082,0.11591699967781703,0.11588500005503495,0.11585300043225288,0.11582100080947082,0.11579000080625217,0.11575799994170666,0.11572599969804287,0.11569399945437908,0.11566299883027871,0.11563100044926007,0.11559899958471458,0.11556699872016907,0.11553599995871384,0.11550399971505006,0.11547200133403142,0.11544000109036763,0.11540899984538555,0.11537599936127663,0.11534300011893113,0.11531000025570393,0.11527700039247672,0.1152440005292495,0.11521099942425887,0.11517799956103165,0.11514599993824959,0.11511300007502238,0.11507999959091346,0.11504699972768624,0.11501399800181389,0.11498100000123183,0.11494800013800462,0.11491500027477741,0.11488200041155021,0.11484899992744128,0.11481700092554092,0.11478399919966857,0.11475099995732307,0.11471799947321415,0.11468500023086865,0.11465299998720486,0.11461999950309594,0.11458700026075046,0.11455399915575981,0.11451899943252404,0.11448499994973342,0.11445099922517936,0.11441699974238873,0.11438299963871638,0.11434899953504403,0.11431500067313512,0.11428099994858106,0.11424700046579044,0.11421300036211808,0.11417900025844574,0.1141450001547734,0.11411100005110104,0.1140769999474287,0.11404299984375636,0.11400899974008401,0.11397499963641167,0.11394100015362103,0.11390800029039383,0.11387399894495805,0.11383999946216743,0.11380599997937679,0.11377199987570445,0.11373800039291382,0.11370399904747804,0.11366899994512399,0.1136330006023248,0.11359800087908904,0.11356299991408984,0.11352799956997235,0.1134929998467366,0.11345800012350082,0.11342299977938335,0.1133880006770293,0.11335200009246667,0.11331699974834919,0.11328200064599514,0.11324699968099594,0.11321200057864189,0.11317700023452441,0.11314199989040692,0.11310700016717117,0.1130720004439354,0.11303700009981792,0.11300200037658215,0.11296699941158295,0.1129320003092289,0.11289800144731998,0.1128630011032025,0.11282700051863988,0.11279099993407726,0.11275499997039636,0.11271800038715203,0.11268199980258942,0.11264600108067195,0.11261000049610932,0.11257399991154671,0.11253699908653896,0.11250100036462148,0.11246499978005886,0.11242900043725967,0.11239299985269706,0.11235700050989787,0.11232100054621696,0.11228500058253606,0.11224900061885516,0.11221300003429253,0.11217700007061164,0.11214000048736732,0.11210399990280469,0.11206800118088722,0.11203200121720631,0.11199599876999855,0.1119609996676445,0.11192399946351846,0.11188699988027413,0.11184899881482124,0.11181199985245864,0.11177500089009602,0.11173700106640656,0.11170000024139881,0.11166300065815449,0.11162600045402844,0.11158900024990241,0.11155100042621295,0.11151399898032348,0.1114770012597243,0.11143999981383483,0.11140299960970879,0.11136600064734618,0.11132899982233842,0.1112910012404124,0.11125399979452293,0.11121700083216031,0.11117999876538913,0.11114300104478995,0.11110600021978219,0.11106900001565616,0.11103200043241183,0.11099499960740407,0.11095800002415974,0.11092100044091542,0.11088399961590767,0.11084700065354507,0.11081000107030074,0.11077300024529298,0.11073600066204865,0.11069899859527747,0.11066300049424171,0.11062599904835224,0.1105889988442262,0.11055199926098187,0.11051500029861927,0.11047800071537495,0.11044099864860375,0.11040500054756801,0.11036800034344196,0.11033099951843421,0.11029399993518989,0.1102580005923907,0.11022100038826466,0.1101839995632569,0.11014699998001258,0.1101110006372134,0.11007400043308735,0.1100369996080796,0.11000100088616212,0.10996399944027264,0.10992699985702832,0.10989099989334743,0.10985399906833966,0.10981699948509534,0.10978099952141444,0.1097439993172884,0.10970799935360749,0.10967100039124489,0.10963499918580055,0.10959799960255623,0.10956099939843018,0.109525000055631,0.10948800047238667,0.10945199926694234,0.10941500030457973,0.10937900034089883,0.10934299975633621,0.10930599893132846,0.10927000020941098,0.10923300000528495,0.10919700004160404,0.109159999837478,0.10912399925291538,0.10908799928923447,0.10905099970599015,0.10901500036319096,0.10897899977862835,0.1089419995745023,0.10890600085258484,0.10886999902625878,0.10883299882213275,0.10879700072109699,0.1087610013782978,0.10872499955197175,0.10868799934784572,0.10865199938416481,0.10861600066224734,0.10857999945680301,0.10854399887224038,0.10850699928899606,0.10847099994619687,0.10843499936163425,0.10839900001883507,0.10836299881339073,0.10832699947059155,0.10829100074867408,0.10825499954322974,0.10821899957954884,0.10818199937542279,0.1081460000326236,0.10811000006894271,0.1080740001052618,0.10803799952069919,0.1080020001779,0.10796599959333737,0.10793000025053819,0.10789400028685729,0.10785799970229466,0.10782200035949548,0.10778600101669629,0.10775100005169709,0.10771499946713448,0.10767900074521701,0.10764300016065438,0.1076070008178552,0.10757100023329258,0.10753499902784824,0.10749899906416734,0.10746399996181329,0.10742799875636895,0.10739200003445148,0.10735599882900715,0.10732000010708968,0.10728499914209048,0.10724900104105473,0.10721300045649211,0.10717699863016605,0.107141999527812,0.1071059995641311,0.10707000084221363,0.10703500049809615,0.10699899929265182,0.10696300057073434,0.10692800022661686,0.10689200026293595,0.10685600029925506,0.10682099995513757,0.10678499937057495,0.10674999964733918,0.10671400030454,0.10667799971997738,0.10664300061762333,0.106606999412179,0.10657200030982494,0.10653600034614404,0.10650100062290828,0.10646500003834565,0.1064300003151099,0.10639400035142899,0.10635900000731151,0.10632299942274888,0.10628800094127655,0.10625300059715907,0.10621700001259644,0.10618200028936069,0.10614599970479806,0.10611100060244401,0.10607600025832653,0.10604000029464562,0.10600499995052814,0.10596999960641067,0.10593400026361148,0.10589899991949399,0.10586400081713994,0.1058279989908139,0.10579300050934155,0.1057580007861058,0.10572299920022488,0.10568700047830741,0.10565200199683507,0.10561700041095416,0.10558199944595496,0.10554699972271919,0.10551100037992,0.10547600065668424,0.10544100093344848,0.10540599934756756,0.10537099962433179,0.10533600052197774,0.10530100079874198,0.10526500083506107,0.10522999987006187,0.1051949995259444,0.1051599991818269,0.10512499945859115,0.10508999973535538,0.10505500063300133,0.10502000028888385,0.10498499870300293,0.1049500002215306,0.1049149992565314,0.10488000015417735,0.10484500043094158,0.10480999946594238,0.10477499974270661,0.10473999939858913,0.1047059999157985,0.10467100019256274,0.10463599922756354,0.1046010001252095,0.104565999781092,0.10453100067873795,0.1044960009555022,0.10446200023094813,0.10442699926594894,0.10439200016359489,0.10435700044035912,0.10432199947535992,0.10428799999256928,0.10425300089021523,0.10421799930433433,0.10418300020198028,0.10414900009830792,0.10411400099595387,0.1040790006518364,0.10404499992728233,0.10401000020404656,0.10397499923904736,0.10394099975625674,0.10390599941213925,0.1038709996889035,0.10383699958523114,0.10380199862023194,0.10376700075964133,0.10373299879332383,0.1036980003118515,0.10366399958729744,0.10362899924317996,0.10359500100215276,0.10355999879539013,0.10352600055436294,0.10349099958936374,0.10345699948569138,0.10342200038333733,0.10338799965878327,0.10335300055642922,0.10331900045275688,0.10328399948775768,0.10324999938408534,0.103215000902613,0.10318100017805894,0.10314699945350488,0.10311200035115083,0.10307800024747849,0.10304400014380614,0.10300899979968865,0.10297500093777974,0.10294099959234397,0.10290600048998992,0.10287199976543586,0.1028379996617635,0.10280299993852775,0.10276899921397369,0.10273499973118305,0.10270100024839242,0.10266599928339322,0.1026320004214843,0.10261499943832557};
        CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.8340072631836,82.68911743164062,83.1493148803711,83.91531435648601,84.7031135559082,85.51261393229167,86.34391212463379,87.15781211853027,87.91511154174805,88.6159102121989,89.26010958353679,89.84770838419597,90.37890752156575,90.85340627034505,91.27140553792317,91.63280614217122,91.9377047220866,92.21110407511394,92.47810554504395,92.7387040456136,92.9928035736084,93.24060376485188,93.48190371195476,93.71670405069987,93.94520441691081,94.16720326741536,94.38280296325684,94.59230295817058,94.79590288798015,94.99360275268555,95.18550237019856,95.37140146891277,95.55150349934895,95.72570292154948,95.8941027323405,96.05650266011556,96.21310297648112,96.36530303955078,96.51440302530925,96.66050338745117,96.80350303649902,96.94360224405925,97.08060137430827,97.21460215250652,97.34560203552246,97.47360229492188,97.59850056966145,97.72110303243001,97.84220186869304,97.96160252888997,98.07950146993001,98.19580268859863,98.31040128072102,98.42350196838379,98.53500239054362,98.64490063985188,98.7533016204834,98.8601016998291,98.96570078531902,99.07000096638997,99.1729024251302,99.27450180053711,99.37480036417644,99.47380129496257,99.57150204976399,99.66790199279785,99.76290130615234,99.85640144348145,99.9483019510905,100.03800201416016,100.12700208028157,100.21400197347005,100.29900232950847,100.38200187683105,100.46400197347005,100.54400316874187,100.62200037638347,100.69900131225586,100.77400016784668,100.84700139363606,100.91800053914388,100.98800086975098,101.05600166320801,101.1230017344157,101.18700154622395,101.25,101.31200154622395,101.37200101216634,101.43200047810872,101.49100049336751,101.5500005086263,101.60900115966797,101.66700172424316,101.72500165303548,101.78200085957845,101.83900133768718,101.89600054423015,101.95200157165527,102.00800196329753,102.06300036112468,102.11800193786621,102.17200088500977,102.22600110371907,102.28000005086263,102.33300081888835,102.38600095113118,102.43800036112468,102.4900016784668,102.54200108846028,102.59300168355306,102.64300219217937,102.69400215148926,102.74400202433269,102.79300053914388,102.84199968973796,102.89100074768066,102.9390017191569,102.9860013326009,103.03399976094563,103.0810006459554,103.12700080871582,103.17299969991048,103.21900113423665,103.2640012105306,103.30900065104167,103.35300064086914,103.39700063069661,103.4410006205241,103.48400115966797,103.5270004272461,103.56900024414062,103.61100069681804,103.65300114949544,103.69400024414062,103.73399988810222,103.77500089009602,103.81400108337402,103.85400072733562,103.89300028483073,103.93100102742513,103.96999994913737,104.00700124104817,104.04500007629395,104.08100128173828,104.11800066630046,104.15399996439616,104.19000053405762,104.22500101725261,104.26000086466472,104.2939993540446,104.32800038655598,104.3620007832845,104.39500109354655,104.42700131734212,104.46000099182129,104.49200057983398,104.52300135294597,104.55399894714355,104.58499972025554,104.61500040690105,104.64500045776367,104.6740010579427,104.70300038655598,104.73200098673503,104.76000086466472,104.78700065612793,104.81500053405762,104.84200096130371,104.86800003051758,104.89399973551433,104.92000007629395,104.94500160217285,104.97000058492024,104.99400075276692,105.01800028483073,105.04200108846028,105.06500053405762,105.08700116475423,105.10999997456868,105.1320006052653,105.15300051371257,105.1740010579427,105.19499969482422,105.21499951680501,105.23499997456868,105.25399907430013,105.27300071716309,105.29100036621094,105.30999946594238,105.32700157165527,105.34500058492024,105.36100069681804,105.3780008951823,105.39399909973145,105.40899976094563,105.4250005086263,105.43899981180827,105.45400110880534,105.46799850463867,105.48100026448567,105.49400011698405,105.50699996948242,105.51899909973145,105.5310001373291,105.54300117492676,105.5540002187093,105.56400108337402,105.57399940490723,105.58400026957194,105.59400049845378,105.60200055440266,105.61099942525227,105.61900011698405,105.62700080871582,105.63399950663249,105.64099947611491,105.64700126647949,105.6529992421468,105.65900039672852,105.66399955749512,105.6689993540446,105.67299906412761,105.67699940999348,105.68099975585938,105.68400001525879,105.68600018819173,105.68899981180827,105.69099998474121,105.69200007120769,105.69300142923991,105.69400087992351,105.69399897257487,105.69400087992351,105.69300015767415,105.69200007120769,105.68999926249187,105.6879997253418,105.68600018819173,105.68400001525879,105.68200047810872,105.67999903361003,105.67800076802571,105.67600059509277,105.6740010579427,105.67200024922688,105.66900062561035,105.66700045267741,105.6649996439616,105.66300010681152,105.66099993387859,105.65899976094563,105.65699895222981,105.65499941507976,105.65299987792969,105.64999834696452,105.64799944559734,105.64600054423015,105.6440003712972,105.64200019836426,105.64000002543132,105.6379992167155,105.63600095113118,105.6330000559489,105.6309986114502,105.62900098164876,105.62700080871582,105.62500063578288,105.62300046284993,105.62099965413411,105.61899884541829,105.61699867248535,105.61399904886882,105.61200014750163,105.60999933878581,105.60799916585286,105.60600026448567,105.60400009155273,105.60200119018555,105.59999974568684,105.5979995727539,105.59499867757161,105.59299977620442,105.59099960327148,105.58900006612141,105.5869992574056,105.5850003560384,105.58300018310547,105.58100001017253,105.57899920145671,105.57599957784016,105.57399940490723,105.57200050354004,105.56999905904134,105.56800079345703,105.56599998474121,105.56399981180827,105.56199963887532,105.55999946594238,105.55699984232585,105.55500030517578,105.55299949645996,105.55100059509277,105.54900042215984,105.54699961344402,105.54499944051106,105.54299926757812,105.54100100199382,105.53800010681152,105.53599993387859,105.5340010325114,105.5319995880127,105.53000005086263,105.52799987792969,105.52599970499675,105.52400016784668,105.52199999491374,105.51899909973145,105.51700019836426,105.51500002543132,105.51299985249837,105.51099904378255,105.50899950663249,105.50699806213379,105.50500043233235,105.50299962361653,105.5,105.49799982706706,105.49600092569987,105.49400011698405,105.49200057983398,105.48999977111816,105.4880002339681,105.48600069681804,105.48400052388509,105.48100090026855,105.47900009155273,105.4769999186198,105.47499910990398,105.4729995727539,105.47100003560384,105.46900113423665,105.46699905395508,105.46500142415364,105.46199989318848,105.45999908447266,105.45800018310547,105.45600001017253,105.45399983723958,105.45199966430664,105.45000076293945,105.44799995422363,105.4459997812907,105.44400024414062,105.44100125630696,105.43900044759114,105.43699963887532,105.43500010172527,105.4330005645752,105.43099912007649,105.4290002187093,105.42700068155925,105.4250005086263,105.42199961344402,105.42000071207683,105.41800117492676,105.41599973042806,105.414000193278,105.41200065612793,105.40999984741211,105.40799967447917,105.4060001373291,105.40300051371257,105.40099970499675,105.3989995320638,105.39699999491374,105.39499918619792,105.39299964904785,105.39100011189778,105.38899993896484,105.3869997660319,105.38400014241536,105.38199996948242,105.38000043233235,105.37799962361653,105.37600008646648,105.37399864196777,105.37200164794922,105.36999893188477,105.3679993947347,105.36599922180176,105.3630002339681,105.36100006103516,105.35900052388509,105.35700035095215,105.35499954223633,105.35300000508626,105.35099919637044,105.34899965922038,105.34700012207031,105.34400049845378,105.34200032552083,105.33999888102214,105.33799934387207,105.335999806722,105.33399963378906,105.33200073242188,105.3300011952718,105.32800038655598,105.32500012715657,105.32299931844075,105.3209997812907,105.31899833679199,105.31700007120769,105.31500053405762,105.31300036112468,105.31100018819173,105.30900065104167,105.30700047810872,105.30399958292644,105.30199940999348,105.29999923706055,105.29799969991048,105.29600079854329,105.29400062561035,105.29199981689453,105.29000091552734,105.28800010681152,105.28499984741211,105.28299967447917,105.2810001373291,105.27899996439616,105.27700106302898,105.27499961853027,105.27299880981445,105.27099863688152,105.26899973551433,105.26699956258138,105.26400057474773,105.2619997660319,105.25999959309895,105.2580000559489,105.25599988301595,105.25400034586589,105.25199953715007,105.25,105.24800046284993,105.24499956766765,105.24300003051758,105.24099985758464,105.23900032043457,105.23699951171875,105.23499933878581,105.23300107320149,105.23099899291992,105.22900072733562,105.2269999186198,105.22400029500325,105.22200012207031,105.21999931335449,105.2180004119873,105.2159989674886,105.21399943033855,105.21199989318848,105.20999908447266,105.20799954732259,105.20500055948894,105.20299975077312,105.20100084940593,105.19900067647298,105.19699986775716,105.19500096638997,105.1929988861084,105.19100125630696,105.18899981180827,105.18699900309245,105.18400001525879,105.1820011138916,105.18000030517578,105.1780014038086,105.17600059509277,105.17399978637695,105.17199961344402,105.17000007629395,105.16800053914388,105.16599909464519,105.16400082906087};
        //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761955698331196,1.4129399955272675,1.4510200122992198,1.4899399975935619,1.5299600064754486,1.5710799992084503,1.6133100092411041,1.654639999071757,1.693060000737508,1.7285599907239277,1.7611500124136608,1.7908299962679546,1.817600001891454,1.8414599895477295,1.8624099890391033,1.880450000365575,1.8955899973710377,1.9091200133164723,1.9223000009854634,1.9351600011189778,1.947689990202586,1.9598800043265026,1.9717399974664052,1.9832700093587239,1.994469980398814,2.0053300062815347,2.0158600012461343,2.0260600248972573,2.0359700123469033,2.0455700357755027,2.054869989554087,2.0638599594434104,2.0725499788920083,2.0809399485588074,2.089020033677419,2.096789995829264,2.1042700012524924,2.1115100185076394,2.118589997291565,2.1255199909210205,2.132300019264221,2.1389199693997702,2.1453700065612793,2.1516800125439963,2.157820006211599,2.1638100147247314,2.169639984766642,2.1753600041071572,2.1809800068537393,2.18652997414271,2.191989998022715,2.1973699728647866,2.2026599844296775,2.2078800201416016,2.21300999323527,2.218050022919973,2.223020017147064,2.2279000083605447,2.2327200174331665,2.2374599973360696,2.2421499689420066,2.2467599908510842,2.2513099710146585,2.2557900150616965,2.260200023651123,2.264539976914724,2.2688100139300027,2.272999962170919,2.2770999670028687,2.28111998240153,2.2850399812062583,2.2888799905776978,2.2926299969355264,2.2962900002797446,2.299870014190674,2.3033600052197776,2.3067500392595925,2.310070037841797,2.3132900396982827,2.3164199590682983,2.319469968477885,2.322429974873861,2.3252999782562256,2.3280799984931946,2.33078000942866,2.3333899974823,2.3359100023905435,2.3383699854214988,2.340810020764669,2.34322996934255,2.3456199963887534,2.3479999899864197,2.3503499825795493,2.3526800076166787,2.354989985624949,2.3572800159454346,2.3595400055249534,2.3617799878120422,2.3639999826749167,2.3661999901135764,2.3683800101280212,2.3705299894014993,2.37266997496287,2.374780019124349,2.3768699566523233,2.3789400259653726,2.3809799949328103,2.3829999566078186,2.3850000301996865,2.3869800170262656,2.388930002848307,2.390869994958242,2.3927800059318542,2.394670009613037,2.3965399861335754,2.398380001386007,2.4002100229263306,2.4020100037256875,2.4037899573644004,2.405550003051758,2.407289981842041,2.4090099930763245,2.410699963569641,2.412369986375173,2.41401998202006,2.4156499902407327,2.4172499577204385,2.4188400308291116,2.4203999837239585,2.42194002866745,2.423449993133545,2.4249500036239624,2.426419993241628,2.427869995435079,2.4293099840482077,2.4307199915250144,2.432100017865499,2.4334700107574463,2.434809982776642,2.436140020688375,2.437439978122711,2.4387200077374778,2.4399800300598145,2.4412100116411843,2.44242000579834,2.4436100125312805,2.4447799722353616,2.445929984251658,2.4470500349998474,2.44816001256307,2.449239989121755,2.4502999583880105,2.4513400197029114,2.4523600141207376,2.453349987665812,2.454330027103424,2.4552800059318542,2.456220010916392,2.457129975159963,2.4580199917157493,2.458879987398783,2.45973002910614,2.460550010204315,2.4613499840100608,2.462129990259806,2.462890009085337,2.4636200269063315,2.4643399914105735,2.465030034383138,2.4656999905904136,2.466349999109904,2.466980000336965,2.4675899942715964,2.4681700070699057,2.4687399864196777,2.4692800045013428,2.4698000152905784,2.4702999790509543,2.470779995123545,2.471239984035492,2.4716699918111167,2.4720800121625266,2.472470005353292,2.4728399912516275,2.4731900095939636,2.473520040512085,2.4738199710845947,2.4741000135739646,2.4743700424830117,2.4746100107828775,2.4748299717903137,2.475030024846395,2.4752100110054016,2.4753599762916565,2.475500007470449,2.475609997908274,2.4757000207901,2.4757800102233887,2.47582999865214,2.47585000594457,2.4758600195248923,2.475839992364248,2.4758000572522483,2.4757400155067444,2.4756600062052407,2.4755600094795227,2.4754400054613748,2.47529000043869,2.4751299818356833,2.474940001964569,2.474739988644918,2.4745099941889444,2.4742600123087564,2.473990003267924,2.473700006802877,2.473389983177185,2.4730500181516013,2.472699999809265,2.472320020198822,2.4719199935595193,2.471500019232432,2.4710500240325928,2.4705900152524314,2.470109979311625,2.4696000019709268,2.469070037206014,2.4685300389925637,2.467959980169932,2.4673699935277305,2.466759999593099,2.466129998366038,2.4654800295829773,2.464800000190735,2.464110016822815,2.463389972845713,2.462660014629364,2.4619000355402627,2.4611299633979797,2.4603599905967712,2.4595900177955627,2.458829959233602,2.4580599665641785,2.457290013631185,2.4565200010935464,2.455750028292338,2.454989969730377,2.4542200167973838,2.45345002412796,2.452690005302429,2.451919972896576,2.4511499603589377,2.450390021006266,2.449619988600413,2.448860009511312,2.4480899771054587,2.4473299980163574,2.446560025215149,2.445799986521403,2.4450300137201944,2.4442699948946633,2.4435099562009177,2.442740003267924,2.441979964574178,2.441219985485077,2.4404500126838684,2.4396899739901223,2.4389299949010215,2.438169995943705,2.437400003274282,2.436639984448751,2.4358799854914346,2.4351200064023337,2.4343599875768027,2.4336000084877014,2.4328399896621704,2.432080010573069,2.431319991747538,2.430559992790222,2.4297999938329062,2.42903999487559,2.428280015786489,2.427519996960958,2.4267600377400718,2.426010012626648,2.425249973932902,2.4244900147120156,2.4237299958864846,2.422979990641276,2.42221999168396,2.4214600324630737,2.4207000136375427,2.419950028260549,2.419189989566803,2.4184399843215942,2.417680025100708,2.4169300198554993,2.416170040766398,2.4154199957847595,2.4146599968274436,2.4139100313186646,2.4131500323613486,2.4123999873797097,2.4116399685541787,2.410889983177185,2.4101399978001914,2.40938001871109,2.4086299737294516,2.407879968484243,2.407130002975464,2.4063700238863626,2.405619978904724,2.4048699935277305,2.4041200081507363,2.4033700029055276,2.4026199777921042,2.40186999241511,2.4011200070381165,2.4003700017929077,2.399619996547699,2.3988700111707053,2.3981200059254966,2.3973700205485025,2.396620035171509,2.3958699901898703,2.3951200048128762,2.3943700194358826,2.393619974454244,2.3928799430529275,2.3921300172805786,2.39138001203537,2.390629986921946,2.3898900151252747,2.389140029748281,2.388389984766642,2.3876499931017556,2.386900027592977,2.3861600160598755,2.385409971078237,2.3846700390179953,2.3839200337727866,2.3831799825032554,2.3824299971262612,2.38168998559316,2.3809399803479514,2.38019996881485,2.379450023174286,2.3787100315093994,2.377970019976298,2.3772199749946594,2.3764800429344177,2.3757399717966714,2.374999980131785,2.3742600083351135,2.373510003089905,2.3727700312932334,2.372030019760132,2.3712900082270303,2.370549996693929,2.3698099851608276,2.3690700133641562,2.3683300018310547,2.3675900300343833,2.3668499986330667,2.36611000696818,2.365369995435079,2.3646299839019775,2.363889992237091,2.3631500204404197,2.362410028775533,2.361680010954539,2.3609399795532227,2.360199987888336,2.359460016091665,2.3587299982706704,2.3579899668693542,2.357249995072683,2.3565100034077964,2.355780005455017,2.3550400137901306,2.3543099959691367,2.353570024172465,2.352840006351471,2.3521000146865845,2.3513699571291604,2.350630005200704,2.34990002711614,2.3491599957148233,2.3484299977620444,2.3476900259653726,2.3469600081443787,2.3462300101915994,2.3454899986584983,2.344760000705719,2.3440300027529397,2.343299984931946,2.342560033003489,2.341830015182495,2.341100017229716,2.340369999408722,2.3396400014559426,2.338910003503164,2.3381800055503845,2.3374500075976052,2.3367199897766113,2.335989991823832,2.335259993871053,2.334529995918274,2.3338000178337097,2.333070000012716,2.3323399821917215,2.3316100041071572,2.3308799862861633,2.330149988333384,2.329419990380605,2.3287000258763633,2.3279699881871543,2.32723997036616,2.326510032018026,2.325789988040924,2.32506000995636,2.3243300120035806,2.323610007762909,2.322879989941915,2.322160005569458,2.321430027484894,2.320710003376007,2.319979965686798,2.3192600210507712,2.318530003229777,2.3178099989891052,2.3170799811681113,2.3163599967956543,2.3156299789746604,2.3149100144704184,2.3141900300979614,2.313460032145182,2.3127400080362954,2.312020003795624,2.311299999554952,2.310570021470388,2.309850056966146,2.3091299533843994,2.3084100087483725,2.3076900045077005,2.306970000267029,2.306249976158142,2.3055300116539,2.3048100074132285,2.304089983304342,2.3033699989318848,2.3026500145594277,2.301929990450541,2.3012099862098694,2.3004900217056274,2.2997699975967407,2.299050033092499,2.298329989115397,2.297610024611155,2.296899994214376,2.296179989973704,2.2954600056012473,2.294740001360575,2.2940299908320108,2.293310026327769,2.2925899823506675,2.2918800115585327,2.291159987449646,2.2904499769210815,2.2897300124168396,2.2890100280443826,2.2882999579111734,2.2875799934069314,2.286869982878367,2.2861499786376953,2.2854400277137756,2.2847299575805664,2.2840099732081094,2.28329998254776,2.2825899918874106,2.2818700472513833,2.281159977118174,2.28045000632604,2.2797300219535828,2.2790200114250183,2.278309981028239,2.2779499888420105};
        SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568533420562744,8.884455680847168,9.175116618474325,9.481545766194662,9.776285489400228,10.059305349985758,10.330705086390177,10.589104652404785,10.833104610443115,11.06270432472229,11.278004010518393,11.478903532028198,11.66550342241923,11.83780320485433,11.995702823003134,12.139302333196005,12.268502235412598,12.3898024559021,12.509502331415812,12.627502282460531,12.74400250116984,12.85880215962728,12.972102403640747,13.083702246348063,13.19370206197103,13.302102247873941,13.408902009328207,13.513902187347412,13.616901954015097,13.717801968256632,13.816801945368448,13.913801908493042,14.00870188077291,14.101701815923056,14.192601760228476,14.281601746877035,14.368501663208008,14.453901767730713,14.538001775741577,14.621001640955607,14.702801624933878,14.783301591873169,14.862701654434204,14.940901517868042,15.01790157953898,15.093701442082724,15.168301423390707,15.241701443990072,15.314101457595825,15.385201374689737,15.455301443735758,15.524201313654581,15.59200127919515,15.658701340357462,15.724201281865438,15.788601160049438,15.851901292800903,15.914101203282675,15.975001255671183,16.034801244735718,16.09330113728841,16.15070088704427,16.207001209259033,16.262000878651936,16.315901120503742,16.36850102742513,16.42000087102254,16.470401128133137,16.519901116689045,16.568401018778484,16.615800857543945,16.662400881449383,16.707901000976562,16.752501010894775,16.7961007754008,16.838700930277508,16.88040081659953,16.921001116434734,16.96070082982381,16.99940077463786,17.03700065612793,17.07370074590047,17.10930061340332,17.144000848134358,17.177600383758545,17.21030060450236,17.24190044403076,17.272900581359863,17.303700764973957,17.334200382232666,17.364500681559246,17.394500732421875,17.424200534820557,17.45370070139567,17.48300043741862,17.512000560760498,17.540700435638428,17.56920035680135,17.597500324249268,17.625500202178955,17.65320046742757,17.68070062001546,17.707900683085125,17.73490047454834,17.761600335439045,17.788100401560467,17.814300219217937,17.84030071894328,17.866000334421795,17.89150063196818,17.916700681050617,17.941600640614826,17.966400305430096,17.990800539652508,18.015000502268474,18.039000511169434,18.062700748443604,18.08620039621989,18.109400431315105,18.132300694783527,18.15500036875407,18.17750072479248,18.199700514475506,18.22160053253174,18.243400414784748,18.264800389607746,18.286000569661457,18.307000319163006,18.32770045598348,18.348100185394287,18.368300437927246,18.38830057779948,18.408000469207764,18.427400430043537,18.446600278218586,18.465600331624348,18.484300136566162,18.502800464630127,18.521000385284424,18.53890037536621,18.55660057067871,18.574100176493328,18.59130048751831,18.60830020904541,18.625000317891438,18.64140033721924,18.65760024388631,18.673600673675537,18.689300378163654,18.704800605773926,18.72000026702881,18.735000133514404,18.749700387318928,18.76420021057129,18.77839994430542,18.792400360107422,18.806100686391193,18.819600264231365,18.832900524139404,18.845800081888836,18.85860013961792,18.871099948883057,18.883300304412842,18.895300070444744,18.907100200653076,18.91860024134318,18.929800033569336,18.94090000788371,18.951600392659504,18.96210018793742,18.972400188446045,18.98240041732788,18.99220037460327,19.001700401306152,19.011000156402588,19.020099957784016,19.02880032857259,19.037400245666504,19.045700073242188,19.053700129191082,19.06160004933675,19.069100379943848,19.07640012105306,19.083500067392986,19.0903000831604,19.09689982732137,19.10319995880127,19.10929997762044,19.11520004272461,19.120700359344482,19.126100063323975,19.131199995676678,19.13610013326009,19.140700181325276,19.145000139872234,19.149199962615967,19.153000195821125,19.156699975331623,19.160100142161053,19.16320006052653,19.16609986623128,19.16880003611247,19.171199798583984,19.17340024312337,19.175299803415935,19.176999886830647,19.17840003967285,19.17959992090861,19.180500030517578,19.18120018641154,19.181699911753338,19.181900024414062,19.181899865468342,19.181599934895832,19.18110005060832,19.180299917856853,19.17930014928182,19.178099791208904,19.176600138346355,19.17490005493164,19.1728998819987,19.170699914296467,19.16820001602173,19.165500005086262,19.16260004043579,19.159399668375652,19.156000296274822,19.152299880981445,19.148399988810223,19.14420000712077,19.13979959487915,19.135200023651123,19.130299886067707,19.125200112660725,19.119800249735516,19.1141996383667,19.108399868011475,19.102399826049805,19.096399784088135,19.090499877929688,19.084499677022297,19.078499794006348,19.07259972890218,19.06659984588623,19.060699780782063,19.054700056711834,19.048700014750164,19.042800108591717,19.036800066630047,19.03090000152588,19.024999777475994,19.019000212351482,19.013099670410156,19.007099946339924,19.001200040181477,18.99519983927409,18.98930009206136,18.983399868011475,18.977399984995525,18.97149960199992,18.96560001373291,18.959699789683025,18.953699747721355,18.947799682617188,18.94189993540446,18.935999870300293,18.930099964141846,18.924099763234455,18.91819969813029,18.91230010986328,18.906399885813396,18.900499661763508,18.89459991455078,18.888700008392334,18.882799943288166,18.87689971923828,18.870999813079834,18.865099747975666,18.85920000076294,18.85329993565877,18.847399870554607,18.84149980545044,18.83559974034627,18.829800128936768,18.823899745941162,18.817999839782715,18.812099933624268,18.806199550628662,18.800399939219158,18.79449987411499,18.788599650065105,18.782699584960938,18.776899814605713,18.770999908447266,18.76509968439738,18.759299914042156,18.75339984893799,18.747599919637043,18.741699695587158,18.73579994837443,18.729999860127766,18.72409995396932,18.718299865722656,18.71239995956421,18.706599712371826,18.70079978307088,18.694900035858154,18.68909978866577,18.683199564615887,18.67739995320638,18.671600023905437,18.665699640909832,18.659899870554607,18.654099941253662,18.648199876149494,18.642399787902832,18.636599858601887,18.630800247192383,18.624899705251057,18.619099934895832,18.61330000559489,18.607499758402508,18.601699988047283,18.5958997408549,18.58999999364217,18.58419958750407,18.578399976094563,18.5725998878479,18.566799640655518,18.561000029246014,18.55519962310791,18.549399852752686,18.54359992345174,18.537799835205078,18.531999905904133,18.526300112406414,18.52049986521403,18.514699935913086,18.508899688720703,18.5031000773112,18.497299989064533,18.49149990081787,18.48579978942871,18.479999860127766,18.47420008977254,18.4684001604716,18.462699731190998,18.456900119781494,18.45109987258911,18.44539976119995,18.439600149790447,18.433899720509846,18.42809995015462,18.422300179799397,18.416600068410236,18.410799980163574,18.405099868774414,18.39929993947347,18.39359998703003,18.387800057729084,18.382099946339924,18.376300017038982,18.37060006459554,18.364899794260662,18.359100023905437,18.353399753570557,18.34759982426961,18.341899871826172,18.33619976043701,18.330499807993572,18.324699719746906,18.318999767303467,18.313299814860027,18.307599703470867,18.30180009206136,18.29610029856364,18.29040018717448,18.28469975789388,18.279000123341877,18.27329969406128,18.267599900563557,18.261800130208332,18.256099859873455,18.250399748484295,18.244700113932293,18.23899968465169,18.233299732208252,18.22759993871053,18.22189982732137,18.21619987487793,18.21059974034627,18.204899946848553,18.19919951756795,18.19349988301595,18.18779977162679,18.182100137074787,18.176400025685627,18.17080020904541,18.16509993871053,18.15939998626709,18.15369987487793,18.148099899291992,18.142399946848553,18.136699835459392,18.131099859873455,18.125400225321453,18.119700113932293,18.114099979400635,18.108399709065754,18.102699597676594,18.097099939982098,18.091399987538654,18.085800011952717,18.080099900563557,18.074499766031902,18.06879997253418,18.063199996948242,18.057499885559082,18.051899909973145,18.046299775441486,18.040599822998047,18.03500000635783,18.029399871826172,18.02370007832845,18.018099784851074,18.012499968210857,18.006799856821697,18.001200040181477,17.995599905649822,17.989999612172443,17.984300136566162,17.978700002034504,17.973100026448567,17.967499891916912,17.961899916330974,17.956299622853596,17.950700124104817,17.945000012715656,17.93939971923828,17.93380006154378,17.928199768066406,17.922599633534748,17.91699981689453,17.911399841308594,17.905799865722656,17.90019957224528,17.89459975560506,17.889099915822346,17.88349978129069,17.87789996465047,17.872299989064533,17.86669985453288,17.86109987894694,17.85550022125244,17.84999990463257,17.84439992904663,17.838800112406414,17.83319965998332,17.827699661254883,17.822099844614666,17.81649986902873,17.810999870300293,17.805400053660076,17.799799760182697,17.794299920399983,17.788699944814045,17.78309981028239,17.777599811553955,17.771999994913738,17.766499996185303,17.760899702707928,17.755399703979492,17.749799728393555,17.74430004755656,17.738700071970623,17.73319975535075,17.727699915568035,17.722099781036377,17.71659978230794,17.71109978357951,17.70549964904785,17.699999650319416,17.694499969482422,17.688899834950764,17.68339999516805,17.6806001663208};
        //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129453877607981,2.220379332701365,2.2989970445632935,2.387666881084442,2.4781970977783203,2.5705472032229104,2.664646784464518,2.7527363300323486,2.8272457917531333,2.8885553081830344,2.9370147983233132,2.9729843537012735,2.996803859869639,3.008803387482961,3.0092929005622864,2.9986124634742737,2.977042337258657,2.949832280476888,2.9220921794573465,2.893822193145752,2.865062137444814,2.8358020583788552,2.8060719966888428,2.775891959667206,2.7452518939971924,2.7141918937365213,2.6827017664909363,2.6508517464001975,2.618701676527659,2.5862616300582886,2.5535215536753335,2.520521561304728,2.487241486708323,2.453701436519623,2.4199013908704123,2.385861337184906,2.3515913089116416,2.317361315091451,2.2834612329800925,2.24987123409907,2.21659117937088,2.183611214160919,2.1509211460749307,2.118531088034312,2.0864110787709556,2.0545711119969687,2.0229910413424173,1.9918210407098134,1.9611810346444447,1.9310510059197743,1.901431014140447,1.8723010023434956,1.8436509867509205,1.815470963716507,1.7877409557501476,1.76045094927152,1.7335909307003021,1.7071809470653534,1.6812309126059215,1.6557208995024364,1.630660871664683,1.6060208876927693,1.5817908744017284,1.5579708516597748,1.534540832042694,1.5114908317724864,1.4888108273347218,1.466450810432434,1.4443707664807637,1.4225607613722484,1.4010107616583507,1.3797207574049632,1.3586807151635487,1.337880700826645,1.3173106908798218,1.2969806790351868,1.2768606742223103,1.2569706539313,1.237290620803833,1.2178206245104473,1.1985506216684978,1.17947060863177,1.1605805953343709,1.141880561908086,1.1233805616696675,1.105050543944041,1.0869005421797435,1.0690505305926006,1.05161052942276,1.034580518802007,1.0179405212402344,1.0016805132230122,0.9857925176620483,0.9702695111433665,0.9550965130329132,0.940263494849205,0.9257624993721644,0.9115854948759079,0.8977224926153818,0.8841624756654104,0.8708984901507696,0.8579204728205999,0.8452254782120386,0.8328024744987488,0.8206414679686228,0.8087374716997147,0.7970824589331945,0.785673459370931,0.7744984527428945,0.7635524521271387,0.7528284539779028,0.7423204431931177,0.7320254395405451,0.7219344327847163,0.7120414227247238,0.702341432372729,0.6928294350703558,0.6835014273722967,0.6743504256010056,0.6653714179992676,0.6565604209899902,0.64791040122509,0.6394224017858505,0.631087397535642,0.6229013999303182,0.6148603955904642,0.606960395971934,0.5992003977298737,0.5915733873844147,0.5840753714243571,0.5767033795515696,0.569453368584315,0.5623253683249155,0.555311361948649,0.548410361011823,0.5416183571020762,0.5349323550860087,0.528351346651713,0.5218703548113505,0.515487348039945,0.5091973394155502,0.5030003388722738,0.49689433475335437,0.4908753310640653,0.4849403252204259,0.47908632457256317,0.4733123183250427,0.46761831144491833,0.4620003129045169,0.4564543118079503,0.4509783039490382,0.44557230671246845,0.4402352993686994,0.43496429671843845,0.4297552928328514,0.4246082852284114,0.4195202862222989,0.4144932801524798,0.40952327599128086,0.40460727363824844,0.39974426478147507,0.39493326594432193,0.3901742622256279,0.3854652593533198,0.3808032547434171,0.3761872525016467,0.3716152509053548,0.36709024260441464,0.3626072406768799,0.3581652343273163,0.35376323014497757,0.34939923137426376,0.34507622321446735,0.34079022457202274,0.3365382179617882,0.3323222150405248,0.32813921322425205,0.32399120678504306,0.31987520555655163,0.31578920036554337,0.3117341970403989,0.30770719796419144,0.3037111908197403,0.2997431829571724,0.29580118258794147,0.29188618063926697,0.2879951745271683,0.28413217266400653,0.28029216825962067,0.2764751637975375,0.2726811617612839,0.26890815794467926,0.2651601533095042,0.26143215348323184,0.25772414604822796,0.2540351425607999,0.25036514177918434,0.24671613797545433,0.24308613066871962,0.23947212845087051,0.23587512597441673,0.2322941223780314,0.22873211776216826,0.22518511364857355,0.2216541108985742,0.2181361069281896,0.21463310346007347,0.21114609887202582,0.20767309640844664,0.2042120931049188,0.20076408858100572,0.1973280869424343,0.19390708083907762,0.19049707800149918,0.1870980734626452,0.18371007218956947,0.18033206835389137,0.17696806664268175,0.17361306274930635,0.17026805505156517,0.16693205386400223,0.16360504801074663,0.16028904666503271,0.1569820443789164,0.15368403991063437,0.15039303774634996,0.14711003129680952,0.14383702725172043,0.14057202264666557,0.13731302320957184,0.13406201700369516,0.1308170147240162,0.12758101026217142,0.12435200748344262,0.12112900490562122,0.11791099980473518,0.11469899987181027,0.11153599992394447,0.10845999978482723,0.10546900083621343,0.10255999987324078,0.09973129878441493,0.0969807996104161,0.09430620012183984,0.09170529867211978,0.0891761997093757,0.08671689902742703,0.08432539987067382,0.08199990044037501,0.07973849959671497,0.07753950046996276,0.07540110064049561,0.07332180067896843,0.07129970006644726,0.06933349867661794,0.06742149963974953,0.06556220042208831,0.06375419969360034,0.06199609922866026,0.06028639990836382,0.05862399966766437,0.05700730035702387,0.05543529987335205,0.05390659999102354,0.05242010019719601,0.05097460032751163,0.04956890021761259,0.04820200024793545,0.0468729001780351,0.0455802995711565,0.044323500245809555,0.04310119990259409,0.041912700360020004,0.04075700013587872,0.03963319988300403,0.038540299981832504,0.03747759976734718,0.036444199892381825,0.03543920007844766,0.03446210051576296,0.03351180007060369,0.03258779955406984,0.03168919961899519,0.03081539987275998,0.02996570011600852,0.029139500111341476,0.02833600000788768,0.027554699840644997,0.026794999993095796,0.026056199645002682,0.025337699955950182,0.024639099991569918,0.023959699862947065,0.023299100032697122,0.022656700263420742,0.022031999969234068,0.021424599923193455,0.020833799925943215,0.020259400208791096,0.01970080006867647,0.019157699774950743,0.018629500021537144,0.018115799874067307,0.01761640002951026,0.017130700095246237,0.016658299913009007,0.01619910014172395,0.015752399961153667,0.015318100107833743,0.014895800113057097,0.014485100051388144,0.014085799998914203,0.013697399913022915,0.013319799909368157,0.012952600062514344,0.01259549994332095,0.01224819989874959,0.011910500004887581,0.011582200027381381,0.011262900040795406,0.010952399965996543,0.010650399917115768,0.010356799932196736,0.010071300047760209,0.009793609923993548,0.009523609885945916,0.00926105996283392,0.009005749908586344,0.008757470098013679,0.008516039932146668,0.008281270042061806,0.008052969972292582,0.007830969872884452,0.007615089998580515,0.007405160033764939,0.007201009973262747,0.007002500002272427,0.006809459999203682,0.006621740021121998,0.006439200020395219,0.006261689976478617,0.006089069996960461,0.005921210007121165,0.005757990099179248,0.00559925998095423,0.005444899977495273,0.0052948099716256065,0.005148849993323286,0.005006910030109187,0.004868889964806537,0.0047346800565719604,0.00460416004837801,0.004477239951180915,0.004353820035854976,0.004233809964110454,0.004117099956298868,0.004003610035094122,0.003893250017426908,0.003785929991863668,0.0036815700198834143,0.0035800899883421757,0.003481400005208949,0.003385439980775118,0.003292120003607124,0.0032013700110837817,0.0031131200375966728,0.0030273099740346274,0.002943870010009656,0.002862720012975236,0.002783809982550641,0.0027070800036502383,0.0026324599942502878,0.002559900050982833,0.002489340006529043,0.0024207200234134993,0.0023540000159603855,0.0022891099797561765,0.0022260200154657164,0.002164659982857605,0.0021049900290866694,0.0020469700102694333,0.001990549984232833,0.001935679999102528,0.001882330000322933,0.0018304499778120469,0.0017800000011144828,0.0017309300116418551,0.0016832199956600864,0.0016368300033112366,0.0015917099954094738,0.0015478400067271043,0.0015051800000946969,0.0014636900159530342,0.0014233500114642084,0.0013841200076664488,0.0013459699985105544,0.0013088699876486014,0.0012728000001516193,0.0012377199988501768,0.0012035999873963494,0.0011704299928775679,0.0011381699878256768,0.0011067999973117064,0.0010762999881990254,0.0010466299815258633,0.0010177899966947734,0.000989734010848527,0.0009624559994942198,0.0009359290027835717,0.0009101339916621024,0.000885049996819968,0.000860657004523091,0.0008369369946497803,0.0008138699922710657,0.000791439005600599,0.000769626999196286,0.0007484160014428198,0.0007277889963006601,0.0007077310001477599,0.0006882260058773682,0.0006692580015320951,0.0006508129978707681,0.0006328770008015757,0.0006154349975986406,0.0005984729990207901,0.0005819789997379606,0.0005659400097404917,0.0005503430002136156,0.0005351759900804609,0.0005204269982641563,0.0005060840000320846,0.0004921359989869719,0.0004785730003883752,0.00046538400056306273,0.00045255900234527263,0.00044008699963645387,0.00042795800012148294,0.00041616400024698425,0.0004046950028471959,0.00039354199786127236,0.0003826969987130724,0.0003721500009608765,0.00036189400028282154,0.00035192100282680866,0.00034222199610667303,0.0003327910017105751,0.00032362000153322396,0.000314701998528714,0.0003060290012702656,0.0002975949998168896,0.0002893939987795117,0.000281418996261588,0.0002736639992993635,0.0002661219987203367,0.00025878799594162655,0.0002516570020816289,0.0002447219982665653,0.00023797800046547005,0.0002314200003941854,0.000225042000238318,0.00021884099745269245,0.00021281000105470108,0.00020694600122321086,0.0002012430013564881,0.00019569700089050457,0.0001903040004738917,0.00018506000075528087,0.00017996000193913156,0.0001750010002676087,0.00017017899881466292,0.00016548899899741323,0.00016092899992751578,0.0001564940005967704,0.00015218199769151397,0.0001479880023301424,0.00014390999907239652,0.00013994400069350377,0.00013608800024182224,0.00013233800079130256,0.00012869100100942887,0.00012514499879519766,0.00012169699887939107,0.00011834299887899154,0.00011508200016881649,0.0001119109989910309,0.0001103470009790423};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11867332458496,80.86898867289226,79.52129236857097,78.11839421590169,76.66869608561198,75.17999839782715,73.65949948628743,72.1135991414388,70.54840151468913,68.96930249532063,67.38140360514323,65.78930409749348,64.19710508982341,62.60860633850098,61.02720705668131,59.4559071858724,57.897507667541504,56.35440889994303,54.82900842030843,53.32310835520426,51.83840878804525,50.37620894114176,48.93800894419352,47.524709701538086,46.13720989227295,44.7764097849528,43.44280974070231,42.13691012064616,40.85921001434326,39.609910011291504,38.38910961151123,37.19710954030355,36.03370984395345,34.898908615112305,33.792609214782715,32.714708964029946,31.66490936279297,30.643008867899578,29.648608843485516,28.681408564249676,27.741108417510986,26.827208360036213,25.939308007558186,25.07700777053833,24.239707628885906,23.4271076520284,22.638607343037922,21.873706817626953,21.132006963094074,20.412906805674236,19.715806643168133,19.040406386057537,18.386006355285645,17.752106189727783,17.138405958811443,16.544106006622314,15.968905846277872,15.412205378214518,14.873505115509033,14.352305253346762,13.848205010096232,13.360704819361368,12.889304717381796,12.433504740397135,11.992904424667358,11.567104260126749,11.155604283014933,10.758003950119019,10.37390406926473,10.002803802490234,9.64435362815857,9.298213640848795,8.963953495025635,8.641223271687826,8.329643170038858,8.028873125712076,7.738553047180176,7.458362897237142,7.1879628499348955,6.927042722702026,6.675282597541809,6.432382504145305,6.198062419891357,5.972032388051351,5.7540123462677,5.543732285499573,5.336252252260844,5.13177231947581,4.935172160466512,4.746142188707988,4.56439205010732,4.389631907145183,4.221601963043213,4.060041785240173,3.904691735903422,3.755311667919159,3.6116716066996255,3.4735615650812783,3.340751508871714,3.213051418463389,3.090251366297404,2.972161293029785,2.858611245950063,2.749421219031016,2.6444112062454224,2.5434411565462747,2.4463310837745667,2.3529510299364724,2.2631510297457376,2.1768009662628174,2.0937509139378867,2.013880878686905,1.9370708465576172,1.8632108271121979,1.7921707928180695,1.7238507469495137,1.6581507523854573,1.5949607094128926,1.534190684556961,1.4757506648699443,1.419540633757909,1.3654805918534596,1.3134805858135223,1.2634805540243785,1.2153805394967396,1.1691205203533173,1.1246304909388225,1.0818404754002888,1.0406904717286427,1.0011004507541656,0.9630304276943207,0.9264104117949804,0.8911883980035782,0.8573093712329865,0.8247223645448685,0.7933783481518427,0.7632293254137039,0.7342293312152227,0.7063343127568563,0.6795023083686829,0.653691291809082,0.6288642833630244,0.6049832801024119,0.5820102542638779,0.5599122444788615,0.5386552413304647,0.5182062288125356,0.49853622168302536,0.4796142131090164,0.4614112029472987,0.4439011936386426,0.4270561908682187,0.41085217893123627,0.3952641760309537,0.3802681714296341,0.36584116518497467,0.3519631524880727,0.3386121516426404,0.3257691462834676,0.31341313819090527,0.30152613421281177,0.2900901287794113,0.2790891230106354,0.2685051163037618,0.2583231156071027,0.24852711086471876,0.23910410329699516,0.23003710185488066,0.22131509830554327,0.21292309338847795,0.2048500900467237,0.19708308825890222,0.18961108351747194,0.1824220803876718,0.17550507436196008,0.16885107631484667,0.162449070562919,0.15629006922245026,0.15036506578326225,0.14466406404972076,0.1391790620982647,0.13390205800533295,0.12882505729794502,0.12394005494813125,0.11924105261762936,0.11472005086640517,0.11037004925310612,0.10618604719638824,0.10215904501577218,0.09828594389061134,0.09455934104820092,0.09097404032945633,0.08752463882168134,0.08420603846510251,0.08101333553592364,0.07794163376092911,0.0749863317857186,0.07214323120812575,0.0694078312565883,0.06677622968951862,0.06424432868758838,0.061808526826401554,0.05946502617249886,0.05721032526344061,0.055041223764419556,0.052954322968920074,0.05094662246604761,0.0490150215725104,0.047156620770692825,0.04536872046689192,0.043648519863684974,0.04199371890475353,0.040401517413556576,0.03886971715837717,0.03739601590981086,0.035978216057022415,0.03461421436319748,0.03330191504210234,0.032039315129319824,0.030824613602211077,0.02965591320147117,0.028531612517933052,0.027449912391602993,0.026409211413313944,0.02540801124026378,0.024444810580462217,0.02351801050826907,0.022626409928003948,0.021768609372278053,0.020943309025218088,0.02014940915008386,0.019385508572061855,0.018650608292470377,0.017943507836510737,0.017263307701796293,0.016608807258307934,0.01597920727605621,0.015373406776537498,0.014790706491718689,0.01423000629680852,0.013690506108105183,0.013171605843429765,0.012672305572777987,0.012191905407235026,0.011729805187011758,0.011285204906016588,0.01085740498577555,0.01044590468518436,0.010050004348158836,0.009669044055044651,0.009302574132258693,0.008949994031960765,0.008610773831605911,0.008284423733130097,0.007970453472808003,0.007668373407796025,0.007377753189454476,0.0070981431830053525,0.006829142997351785,0.006570332955258588,0.006321342817197244,0.006081782553034524,0.005851312579276661,0.005629572474087278,0.005416242366967102,0.005210992298088968,0.00501353219927599,0.0048235420836135745,0.004640762073298295,0.004464911956650515,0.004295731894671917,0.004132951920231183,0.0039763516979292035,0.0038256816721210876,0.0036807315967356167,0.0035412615591970584,0.0034070914844051003,0.0032779914520991347,0.003153791360091418,0.003034301334992051,0.002919341301700721,0.002808731204519669,0.002702321178124597,0.002599931186220298,0.0025014311152820787,0.0024066610688654086,0.002315481018740684,0.002227760987201085,0.0021433609266144535,0.002062160890394201,0.001984040893148631,0.0019088808524732788,0.0018365608217815559,0.001766990792627136,0.0017000507505144924,0.001635650706399853,0.0015736906983268757,0.0015140706673264503,0.001456720638088882,0.0014015406195539981,0.0013484506052918732,0.0012973705791713048,0.0012482305561813216,0.0012009405181743205,0.0011554505229772378,0.0011116904885663341,0.0010695804764206211,0.0010290704376529902,0.000990087438064317,0.000952585415992265,0.000916505407076329,0.0008817913912935182,0.0008483923835835109,0.0008162593585439026,0.00078534334897995,0.0007555993312659363,0.0007269813262003785,0.0006994473078520969,0.0006729562980278084,0.0006474692781921476,0.0006229482823982835,0.0005993552622385323,0.0005766562583933895,0.0005548172436344126,0.0005338052336204177,0.0005135892182200527,0.0004941392083613513,0.00047542620935322094,0.00045742220148288953,0.00044009919171609607,0.00042343318394462887,0.00040739818359725177,0.0003919701727378803,0.0003771271658479236,0.00036284616120004404,0.00034910515387309715,0.000335886150423903,0.00032316714108067873,0.00031092913801937055,0.00029915613170790795,0.00028782812781476724,0.00027692911923319724,0.0002664431158336811,0.0002563541177854252,0.00024664710872457363,0.0002373081054732514,0.00022832310060039163,0.00021967809880152345,0.0002113600930897519,0.0002033570914742692,0.00019565808664386472,0.00018824908208140792,0.00018112207787150206,0.0001742640755158694,0.00016766607344228154,0.0001613180708469978,0.0001552110685831091,0.00014933406661536233,0.00014368106227872582,0.00013824106038858494,0.00013300706026105522,0.0001279720575742734,0.00012312705500031976,0.00011846505306796946,0.000113980048505861,0.00010966504729973774,0.00010551404557190835,9.319807092348735e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.4518674214681,229.59260686238608,226.30972035725912,223.6417096455892,220.9477106730143,218.23170852661133,215.4957071940104,212.7447077433268,209.98170471191406,207.2087033589681,204.42970275878906,201.6477025349935,198.8647028605143,196.08270390828451,193.30570220947266,190.53470738728842,187.772705078125,185.02170689900717,182.28270848592123,179.55870946248373,176.84971364339194,174.15871556599936,171.48571650187174,168.8337173461914,166.20172119140625,163.59172439575195,161.00472768147787,158.4417292277018,155.9027303059896,153.38873291015625,150.9007364908854,148.43974177042642,146.00574111938477,143.59774525960287,141.21875,138.86675135294595,136.54375584920248,134.24875768025717,131.98276138305664,129.7457644144694,127.53776868184407,125.35977045694987,123.2097733815511,121.0897757212321,118.99777857462566,116.93578211466472,114.90378697713216,112.89978790283203,110.92479197184245,108.97779401143391,107.06079864501953,105.1718012491862,103.31080436706543,101.4788080851237,99.67421023050944,97.89751307169597,96.14841715494792,94.4265193939209,92.73182233174641,91.06402524312337,89.42272885640462,87.80783081054688,86.21893310546875,84.65593592325847,83.11843935648601,81.60624249776204,80.11894353230794,78.65644645690918,77.21834882100423,75.80435117085774,74.41425514221191,73.04765637715657,71.70435778299968,70.38396135965984,69.0862642923991,67.8109671274821,66.55756759643555,65.32607078552246,64.11597379048665,62.92697525024414,61.758877754211426,60.61127948760986,59.48388195037842,58.37648359934489,57.2887856165568,56.22038904825846,55.192294438680015,54.20329666137695,53.230998039245605,52.27520020802816,51.33570130666097,50.412103017171226,49.50440470377604,48.61220645904541,47.73530832926432,46.873409271240234,46.026411056518555,45.19401327768961,44.37601407368978,43.57211526234945,42.78221734364828,42.00601863861084,41.243319829305015,40.49392127990723,39.757522900899254,39.034023920694985,38.32322565714518,37.62492656707764,36.93882751464844,36.264729499816895,35.60253111521403,34.95203177134196,34.31303278605143,33.685333887736,33.06873575846354,32.46303653717041,31.86813767751058,31.283738613128662,30.709839979807537,30.146140893300373,29.59244171778361,29.048643112182617,28.514644145965576,27.990145206451416,27.475045839945476,26.969146887461346,26.472447713216145,25.984548727671307,25.505449771881104,25.034950733184814,24.572951634724934,24.11935265858968,23.673853238423664,23.236454327901203,22.806955019632976,22.38515567779541,21.97105662027995,21.56435759862264,21.16515827178955,20.773059050242107,20.38815975189209,20.010160446166992,19.639061450958252,19.274661540985107,18.91696246465047,18.565763155619305,18.220963795979817,17.882364908854168,17.549965063730877,17.223665555318195,16.903266429901123,16.588767210642498,16.279967466990154,15.976768334706625,15.679068803787231,15.386969566345215,15.100070079167685,14.818470557530722,14.542071024576822,14.270671526590982,14.004272301991781,13.742672681808472,13.485973199208578,13.233973503112793,12.986574093500773,12.743674437204996,12.505274931589762,12.271275440851847,12.041575988133749,11.816076358159384,11.594676971435547,11.377477248509726,11.164177656173706,10.954878171284994,10.749378442764282,10.547678788503012,10.349679311116537,10.155279715855917,9.964590152104696,9.777390480041504,9.593630711237589,9.413271188735962,9.236261367797852,9.062521934509277,8.891981999079386,8.724612633387247,8.560342709223429,8.399123112360636,8.240893522898356,8.085583766301474,7.933174053827922,7.7836043039957685,7.636814713478088,7.492764949798584,7.351385156313579,7.212645530700684,7.076475739479065,6.942855954170227,6.8117363055547075,6.6830464998881025,6.556766748428345,6.432847062746684,6.31124730904897,6.191907445589702,6.074797709782918,5.959897955258687,5.847138166427612,5.736478408177693,5.627898613611857,5.521358847618103,5.4168291091918945,5.31425929069519,5.213609496752421,5.1148596207300825,5.0179498593012495,4.92287003993988,4.829570213953654,4.738020459810893,4.648180603981018,4.560020764668782,4.473520994186401,4.388651132583618,4.305391271909078,4.223691463470459,4.143511613210042,4.064851800600688,3.9876819054285684,3.9119420647621155,3.8376422127087912,3.764752368132273,3.693232516447703,3.6230626503626504,3.5542227824529014,3.486682931582133,3.420423070589701,3.355403204758962,3.291623334089915,3.229033430417379,3.167633573214213,3.107383688290914,3.048283835252126,2.990303933620453,2.9334240555763245,2.877614200115204,2.8228542606035867,2.7691244085629783,2.7164345184961953,2.6647245486577353,2.6139947175979614,2.5642347931861877,2.5154349207878113,2.467544953028361,2.4205550948778787,2.374465227127075,2.3292452692985535,2.284865359465281,2.241345445315043,2.1986555457115173,2.1567856272061667,2.1156956950823465,2.075375775496165,2.035835882027944,1.9970459342002869,1.9590060313542683,1.9216760993003845,1.8850361704826355,1.8490962485472362,1.8138563136259716,1.7792864044507344,1.7453864514827728,1.7121065258979797,1.6794465879599254,1.6474166611830394,1.616006722052892,1.585186779499054,1.5549668371677399,1.5253268877665203,1.4962369501590729,1.4676770269870758,1.4396670858065288,1.4121971329053242,1.3852471907933552,1.358817219734192,1.3328972856203716,1.307477355003357,1.2825373907883961,1.258087436358134,1.2340774933497112,1.2105075319608052,1.1873875856399536,1.1647076308727264,1.142467697461446,1.1206577221552532,1.0992677609125774,1.0782778064409893,1.057697852452596,1.0375079115231831,1.0177079339822133,0.9982929875453314,0.9792450070381165,0.960564042131106,0.9422400792439779,0.9242471208175024,0.9065771500269572,0.8892461905876795,0.8722482224305471,0.8555752535661062,0.8392222871383032,0.8231833179791769,0.8074523508548737,0.7920223871866862,0.7768884201844534,0.7620444546143214,0.747485488653183,0.7332065105438232,0.719200536608696,0.7054625650246938,0.6919885923465093,0.6787736117839813,0.6658106495936712,0.653097669283549,0.6406276971101761,0.6283967196941376,0.6164007435242335,0.6046337683995565,0.5930937975645065,0.5817738225062689,0.5706718415021896,0.5597818593184153,0.549100880821546,0.538624902566274,0.5283499161402384,0.5182719479004542,0.5083869695663452,0.49869198352098465,0.4891600012779236,0.47979102035363513,0.47060003876686096,0.4615860531727473,0.4527450775106748,0.444073090950648,0.43556811412175495,0.42722513029972714,0.4190431435902913,0.41101715713739395,0.4031451791524887,0.39542419215043384,0.38785120596488315,0.38042322794596356,0.3731372406085332,0.365991252164046,0.35898226747910184,0.3521072790026665,0.3453642924626668,0.33875131358702976,0.33226432154575986,0.3259013369679451,0.31966035068035126,0.31353935847679776,0.30753537515799206,0.3016463841001193,0.2958703935146332,0.2902054041624069,0.28464841842651367,0.27919843047857285,0.27385244021813077,0.2686084508895874,0.2634654665986697,0.25842147320508957,0.2534734805425008,0.24862049023310342,0.24386050179600716,0.23919151226679483,0.23461252202590308,0.23012052848935127,0.22571553910772005,0.22139354795217514,0.2171555571258068,0.21299856528639793,0.20892057195305824,0.20492058247327805,0.2009985906382402,0.1971505992114544,0.19337660695115724,0.18967461213469505,0.1860436201095581,0.1824826287726561,0.17898963515957197,0.1755636421342691,0.17220264673233032,0.16890665392080942,0.16567366073528925,0.16250266755620638,0.15939167514443398,0.15634067977468172,0.15334868803620338,0.15041369199752808,0.147534699489673,0.14471070592602095,0.14194071044524512,0.13922471553087234,0.1365597223242124,0.13394672547777495,0.13138273234168688,0.12886873384316763,0.1264017422993978,0.12398274553318818,0.12160975113511086,0.11928275600075722,0.11699976089100043,0.11476076518495877,0.11256476988395055,0.11041077474753062,0.10829777767260869,0.10622578424712022,0.10419278716047604,0.10219879200061162,0.10024279604355495,0.09832509917517503,0.09644360343615214,0.09459810703992844,0.09278801021476586,0.09101251512765884,0.0892710176606973,0.08756292114655177,0.08588752585152785,0.08424412831664085,0.08263223059475422,0.08105123477677505,0.07950043926636378,0.07797934177021186,0.07648734375834465,0.07502394604186217,0.07358854884902637,0.07218065361181895,0.07079965559144814,0.0694451592862606,0.06811656119922797,0.06681336400409539,0.06553516661127408,0.06428136800726254,0.06305157020688057,0.06184537367274364,0.06066227611154318,0.059501778334379196,0.05836348080386718,0.05724698305130005,0.05615188584973415,0.055077687526742615,0.05402408974866072,0.05299059208482504,0.051976993680000305,0.05098269569377104,0.050007497891783714,0.049050899843374886,0.0481126019731164,0.0471923037742575,0.04628960539897283,0.04540420727183422,0.04453570954501629,0.04368391105284294,0.04284831260641416,0.04202881424377362,0.0412249161551396,0.040436417174836,0.03966301865875721,0.03890442072103421,0.03816032192359368,0.03743042362233003,0.03671452465156714,0.03601232636719942,0.03532362822443247,0.03464802882323662,0.03398533103366693,0.03333543209979931,0.03269783376405636,0.03207253416379293,0.03145913608993093,0.03085753694176674,0.030267438385635614,0.02968853960434596,0.029120840597897768,0.028563941828906536,0.02801764104515314,0.02748185908421874,0.027216578212877113};
        CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452774047852,71.4100399017334,70.57014719645183,69.81614049275716,69.06644121805827,68.32144101460774,67.58164151509602,66.84724108378093,66.11843935648601,65.39543914794922,64.67853927612305,63.96783955891927,63.263438860575356,62.56553808848063,61.87423769632975,61.18953768412272,60.51163705190023,59.840436935424805,59.17613697052002,58.518636067708336,57.868035316467285,57.22433567047119,56.58753522237142,55.95753415425619,55.33433437347412,54.71793429056803,54.10823313395182,53.505233446756996,52.90893268585205,52.31923230489095,51.73603121439616,51.15943113962809,50.589231173197426,50.02543099721273,49.46792984008789,48.91672992706299,48.371730168660484,47.83282947540283,47.3001283009847,46.77342891693115,46.25262864430746,45.737827936808266,45.228827476501465,44.725527127583824,44.22802734375,43.7361265818278,43.249826749165855,42.76912625630697,42.29372596740723,41.8238255182902,41.359225273132324,40.899925231933594,40.44582494099935,39.99682458241781,39.55292479197184,39.11412334442139,38.68022346496582,38.25122324625651,37.8271230061849,37.407822926839195,36.9933230082194,36.58342266082764,36.178221702575684,35.77762222290039,35.38152186075846,34.9899206161499,34.602721214294434,34.219920794169106,33.84152094523112,33.46732044219971,33.09742005666097,32.73171933492025,32.37011973063151,32.012619177500405,31.65921958287557,31.309819221496582,30.964319229125977,30.62281862894694,30.28511842091878,29.95131826400757,29.62121804555257,29.294917742411297,28.972317695617676,28.653417587280273,28.338117440541584,28.02631711959839,27.718117237091064,27.413416862487793,27.112216472625732,26.814316272735596,26.51991621653239,26.22881619135539,25.941015879313152,25.656415462493896,25.375115553538006,25.09691508611043,24.822015126546223,24.55011510848999,24.281214555104572,24.015514691670734,23.752714316050213,23.492814540863037,23.235913912455242,22.981913884480793,22.73081398010254,22.48241360982259,22.236913522084553,21.994113127390545,21.75411335627238,21.51671266555786,21.282012780507404,21.04991277058919,20.820512771606445,20.593612353007,20.369212468465168,20.14731216430664,19.928012053171795,19.7110120455424,19.496511936187744,19.284411748250324,19.074711163838703,18.867311318715412,18.662211259206135,18.45941146214803,18.25891097386678,18.060611089070637,17.864510536193848,17.67051076889038,17.47881031036377,17.289210478464764,17.1016100247701,16.916210174560547,16.732810020446777,16.551509857177734,16.372109572092693,16.194709936777752,16.019309600194294,15.845909516016642,15.674309492111206,15.504709402720133,15.336909294128418,15.17090924580892,15.006808916727701,14.844509045282999,14.684008836746216,14.525208791097006,14.368208646774292,14.212908585866293,14.059208393096924,13.907308181126913,13.757108211517334,13.608408212661743,13.461408058802286,13.316107988357544,13.172307888666788,13.03000783920288,12.889307816823324,12.750207742055258,12.612507502237955,12.476407527923584,12.34180728594462,12.208607276280722,12.076807101567587,11.946507136027018,11.817607005437216,11.690107027689615,11.564007043838501,11.439206918080648,11.315806786219278,11.19370667139689,11.073006550470987,10.953506549199423,10.835406382878622,10.718506415685018,10.602906386057535,10.488506237665812,10.375406265258789,10.263506094614664,10.152806043624878,10.04330595334371,9.9349258740743,9.827755769093832,9.721745808919271,9.616875807444254,9.51313559214274,9.410515705744425,9.309005578358969,9.208585500717163,9.109245459238688,9.010985374450684,8.913785457611084,8.817625204722086,8.722505251566568,8.62841510772705,8.535335063934326,8.443265040715536,8.352185010910034,8.26208488146464,8.172964890797934,8.084794998168945,7.997584740320842,7.9113147258758545,7.825974623362224,7.741554657618205,7.65805455048879,7.575444459915161,7.493724505106608,7.412894407908122,7.332934379577637,7.253844340642293,7.1755943695704145,7.098194281260173,7.021634181340535,6.945894122123718,6.870984077453613,6.796874046325684,6.723553975423177,6.651043931643168,6.579303900400798,6.5083439747492475,6.438143849372864,6.368703842163086,6.300013780593872,6.2320637702941895,6.1648536920547485,6.098363637924194,6.032593647638957,5.967533588409424,5.903173446655273,5.839513460795085,5.776533484458923,5.71423343817393,5.6526133219401045,5.591653307278951,5.531343380610148,5.471693277359009,5.412683169047038,5.354313294092814,5.29658317565918,5.2394630908966064,5.182963053385417,5.12708306312561,5.071792999903361,5.017113089561462,4.963022947311401,4.909512917200725,4.856582880020142,4.804222782452901,4.75242280960083,4.701192816098531,4.65051273504893,4.600382725397746,4.550792694091797,4.501732707023621,4.45321261882782,4.405212680498759,4.357732613881429,4.310762604077657,4.264302571614583,4.218342463175456,4.172872543334961,4.127902428309123,4.083422462145488,4.039412419001262,3.995882431666056,3.9528223276138306,3.910222331682841,3.868082284927368,3.8264022866884866,3.785172243913015,3.744392216205597,3.7040421962738037,3.6641321778297424,3.624652167161306,3.585602104663849,3.546972115834554,3.5087521076202393,3.4709520737330117,3.433552086353302,3.3965620001157126,3.3599720199902854,3.323781987031301,3.2879719535509744,3.2525519927342734,3.2175119519233704,3.1828518907229104,3.1485718886057534,3.11465185880661,3.0811118284861245,3.047921816507975,3.0150917967160544,2.9826117753982544,2.950491746266683,2.9187117218971252,2.8872817556063333,2.8561816811561584,2.825421690940857,2.794991691907247,2.7648916443188987,2.7351215879122415,2.7056615551312766,2.676521599292755,2.6477015813191733,2.619191527366638,2.5909915566444397,2.563091536362966,2.5354915261268616,2.5081814924875894,2.481181522210439,2.454461455345154,2.4280314445495605,2.4018914302190146,2.3760314186414084,2.350451409816742,2.3251413702964783,2.3001113732655845,2.2753513852755227,2.2508513728777566,2.2266213099161782,2.202651302019755,2.178941269715627,2.155481239159902,2.132281243801117,2.1093212962150574,2.0866212248802185,2.064161241054535,2.041941245396932,2.01996119817098,1.9982111950715382,1.9767111937204997,1.955431153376897,1.9343811571598053,1.9135611255963643,1.8929711083571117,1.8725911378860474,1.8524411022663116,1.8325010935465496,1.8127810855706532,1.7932710746924083,1.7739710708459218,1.7548810541629791,1.7359910408655803,1.717311014731725,1.6988310019175212,1.680551012357076,1.6624709963798523,1.6445809801419575,1.6268809735774994,1.6093809604644775,1.5920609533786774,1.5749309460322063,1.5579809248447418,1.541220913330714,1.5246309041976929,1.5082308848698933,1.4920008877913158,1.4759508669376373,1.4600708683331807,1.4443608522415161,1.4288208583990734,1.413450837135315,1.3982408344745636,1.3832008143266041,1.3683208028475444,1.3536008199055989,1.3390408058961232,1.3246407906214397,1.310390790303548,1.296290785074234,1.2823507686456044,1.2685507535934448,1.2549107273419697,1.2414107422033946,1.2280507485071819,1.214840720097224,1.2017807066440582,1.1888507008552551,1.1760606865088146,1.1634106735388439,1.1509006818135579,1.1385206778844197,1.126280665397644,1.1141606668631236,1.1021806597709656,1.0903306504090626,1.0786006450653076,1.067000647385915,1.0555306375026703,1.0441806316375732,1.0329506198565166,1.0218406120936077,1.010850598414739,0.9999785870313644,0.9892255862553915,0.9785875777403513,0.9680645714203516,0.9576545655727386,0.947357565164566,0.937170555194219,0.9270935455958048,0.917124554514885,0.9072635471820831,0.8975075284639994,0.8878575215737025,0.8783115198214849,0.8688675165176392,0.859525516629219,0.8502845019102097,0.8411425054073334,0.8320995022853216,0.8231524974107742,0.8143024941285452,0.8055484791596731,0.796887477238973,0.7883204619089762,0.7798454612493515,0.7714624553918839,0.7631684591372808,0.7549644509951273,0.746848444143931,0.7388194352388382,0.7308774342139562,0.7230204343795776,0.7152484208345413,0.7075594266255697,0.6999534169832865,0.6924294133981069,0.6849864075581232,0.6776234010855356,0.6703404039144516,0.6631344010432562,0.6560063858826956,0.6489553848902384,0.64198037981987,0.6350803772608439,0.6282543689012527,0.6215013712644577,0.6148223678270975,0.608214353521665,0.6016773531834284,0.5952103435993195,0.5888133496046066,0.5824853430191675,0.5762253453334173,0.570032333334287,0.5639063268899918,0.557846337556839,0.5518513272205988,0.5459203273057938,0.5400533229112625,0.5342503239711126,0.5285083254178365,0.5228293140729269,0.5172113080819448,0.5116532941659292,0.506155307094256,0.5007162988185883,0.49533529331286746,0.4900122905770938,0.484747293094794,0.47953828424215317,0.4743862847487132,0.46928827961285907,0.46424627552429837,0.459258275727431,0.45432327191034955,0.44944126655658084,0.4446122646331787,0.43983525534470874,0.4351102535923322,0.43043525765339535,0.4258102501432101,0.42123524596293765,0.4167102475961049,0.41223324338595074,0.4078042457501094,0.4034222438931465,0.3990882337093353,0.39480123420556384,0.39055922875801724,0.38636423150698346,0.38221322496732074,0.3781072249015172,0.3740452205141385,0.37002723664045334,0.36802804718414944};
        CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297699610392254,16.2742174466451,16.217710494995117,16.178108374277752,16.132907549540203,16.083006540934246,16.02880557378133,15.97090514500936,15.909904559453329,15.84610398610433,15.779803355534872,15.71150310834249,15.64140272140503,15.569802522659302,15.496902147928873,15.42290178934733,15.348001639048258,15.272301435470581,15.196101268132528,15.119301080703735,15.042201042175293,14.964800914128622,14.887300650278727,14.809600671132406,14.731800556182861,14.65410049756368,14.57640035947164,14.4988001982371,14.421400388081869,14.34410031636556,14.267000357309977,14.190200249354044,14.113600254058838,14.037300268809,13.961300293604532,13.885600169499716,13.810200055440268,13.73520016670227,13.660500129063925,13.586200078328451,13.512200037638346,13.438600222269693,13.365300099054972,13.292400121688843,13.219900051752726,13.147799889246622,13.076000054677328,13.00470002492269,12.93370008468628,12.863100051879883,12.792900085449219,12.723100105921427,12.653600136439005,12.584499915440878,12.515900135040283,12.44760004679362,12.379600048065186,12.312099933624268,12.244899988174438,12.178099870681763,12.111700057983398,12.045699993769327,11.979999939600626,11.914699951807657,11.849800030390421,11.785199880599976,11.7210001150767,11.65720001856486,11.593699932098389,11.53059983253479,11.46779998143514,11.405400117238363,11.343399922053019,11.281699895858765,11.22029995918274,11.159299850463867,11.098699887593588,11.038399934768677,10.97849996884664,10.91890001296997,10.859599908192953,10.800700028737387,10.74210007985433,10.683800061543783,10.625900030136108,10.568300008773804,10.511100133260092,10.454100052515665,10.397599935531616,10.341300090154013,10.285300016403198,10.229700009028116,10.174399932225546,10.119400024414062,10.06469996770223,10.010399977366129,9.956339756647745,9.902599970499674,9.849169890085856,9.79604991277059,9.74323002497355,9.690709908803305,9.638480027516684,9.586560010910034,9.534929911295572,9.48360006014506,9.432550112406412,9.381799936294556,9.331329981486002,9.281149943669638,9.231260140736898,9.181639989217123,9.132309993108114,9.08326013882955,9.034480015436808,8.985980113347372,8.937750101089478,8.889799992243448,8.84210991859436,8.794690132141113,8.74753999710083,8.700659990310669,8.654039939244589,8.607679923375448,8.561580101648966,8.515739917755127,8.470160086949667,8.424829959869385,8.379759867986044,8.334940115610758,8.290369908014933,8.246049880981445,8.201970020929972,8.158140023549398,8.11456004778544,8.07121992111206,8.028120040893555,7.985249996185303,7.942630012830098,7.900239984194438,7.8580799500147505,7.816159963607788,7.774460077285767,7.733000079790751,7.691759983698527,7.6507500012715655,7.609969933827718,7.569409966468811,7.5290699402491255,7.48895001411438,7.4490500291188555,7.40936001141866,7.369900027910869,7.330649971961975,7.2916100025177,7.252780040105184,7.214160005251567,7.175750017166138,7.137560089429219,7.099559982617696,7.061770002047221,7.024189988772075,6.986809968948364,6.94963002204895,6.912649989128113,6.875869989395142,6.839280009269714,6.802890022595723,6.766699989636739,6.7307000160217285,6.694900035858154,6.659279942512512,6.623859882354736,6.588620026906331,6.553569992383321,6.518710017204285,6.48403000831604,6.449540019035339,6.41522999604543,6.381109992663066,6.34716002146403,6.313400030136108,6.279810031255086,6.2463999191919966,6.213170011838277,6.18011999130249,6.147239963213603,6.114540060361226,6.08200999101003,6.0496500333150225,6.017469922701518,5.985460003217061,5.953619996706645,5.921939969062805,5.890439947446187,5.8591000239054365,5.827929933865865,5.796930034955342,5.766090035438538,5.73541001478831,5.704899986584981,5.67454993724823,5.644369959831238,5.614339987436931,5.58447003364563,5.554769992828369,5.525219996770223,5.495820005734761,5.4665900866190595,5.437510013580322,5.40858006477356,5.379810055096944,5.351200024286906,5.32272998491923,5.294419924418132,5.266250014305115,5.238239963849385,5.210379958152771,5.182659943898519,5.155100067456563,5.127679944038391,5.100400010744731,5.073269963264465,5.046290040016174,5.019449949264526,4.99275004863739,4.966190059979756,4.939779996871948,4.91350011030833,4.887369990348816,4.861379981040955,4.835519949595134,4.809799989064534,4.784219940503438,4.758780002593994,4.7334699630737305,4.708290060361226,4.683250029881795,4.658340056737264,4.633570035298665,4.608930031458537,4.584419926007588,4.56004003683726,4.535790006319682,4.511680006980896,4.487689971923828,4.463819980621338,4.44009002049764,4.41648002465566,4.39299996693929,4.36964996655782,4.346420049667358,4.323309977849324,4.300329963366191,4.277460058530171,4.254730025927226,4.232110023498535,4.209609945615132,4.187229951222737,4.1649800936381025,4.142839948336284,4.120819965998332,4.098919947942098,4.07712999979655,4.055459976196289,4.033909956614177,4.012469967206319,3.9911399682362876,3.9699300130208335,3.948830008506775,3.9278500080108643,3.9069799979527793,3.886210004488627,3.865560015042623,3.8450200160344443,3.824590007464091,3.8042699893315635,3.7840500275293985,3.763950010140737,3.7439500093460083,3.724049965540568,3.70426998535792,3.684590001900991,3.6650099953015647,3.645540018876394,3.626169979572296,3.606910010178884,3.587739964326223,3.568679988384247,3.5497300028800964,3.530869980653127,3.5121099948883057,3.4934500455856323,3.474900007247925,3.456440011660258,3.4380799730618796,3.419819990793864,3.4016500115394592,3.3835800290107727,3.3656100034713745,3.347730020682017,3.3299500346183777,3.3122700254122415,3.2946799993515015,3.277180016040802,3.2597699960072837,3.242460012435913,3.2252400318781533,3.20810999472936,3.1910699804623923,3.1741299430529275,3.157269994417826,3.1405100425084433,3.123830020427704,3.1072400212287903,3.090739985307058,3.074329992135366,3.0580000082651773,3.0417700012524924,3.0256200035413108,3.0095500349998474,2.9935699701309204,2.977679967880249,2.961870014667511,2.9461399912834167,2.930500010649363,2.9149399995803833,2.8994699517885842,2.884070018927256,2.8687599897384644,2.853529969851176,2.838379999001821,2.8233099778493247,2.808330019315084,2.7934199968973794,2.7785900036493936,2.7638399998346963,2.7491700053215027,2.7345799803733826,2.7200600107510886,2.705620010693868,2.691259960333506,2.676979978879293,2.6627700130144754,2.6486299633979797,2.6345799962679544,2.6205899914105735,2.606679995854696,2.5928499897321067,2.5790900389353433,2.565400004386902,2.5517800052960715,2.5382400155067444,2.524769981702169,2.5113700230916343,2.498050014177958,2.4847899874051413,2.471600035826365,2.4584900538126626,2.4454399744669595,2.4324599703152976,2.4195599953333535,2.4067200223604837,2.39395002524058,2.3812399903933206,2.3686099648475647,2.3560399810473123,2.3435399731000266,2.3311100204785666,2.3187400102615356,2.3064299821853638,2.29419998327891,2.2820199728012085,2.26991997162501,2.2578699588775635,2.2458900014559426,2.233980039755503,2.222130000591278,2.2103400031725564,2.198609987894694,2.1869500080744424,2.175349990526835,2.1638099948565164,2.1523300210634866,2.140910009543101,2.129550019900004,2.1182600061098733,2.1070199608802795,2.0958399772644043,2.0847299893697104,2.0736700097719827,2.0626699924468994,2.05172997713089,2.0408400297164917,2.0300199786822,2.0192500154177346,2.0085399945576987,1.9978899955749512,1.9872899949550629,1.976749986410141,1.9662699898084004,1.955839991569519,1.9454699953397114,1.9351500074068706,1.9248800079027812,1.914680004119873,1.9045199851195018,1.8944199979305267,1.8843700091044109,1.874380002419154,1.8644400040308635,1.8545499940713246,1.8447199960549672,1.8349399864673615,1.8252099951108296,1.8155300219853718,1.8059000273545582,1.7963200012842815,1.7868000070254009,1.7773200074831645,1.7679000000158946,1.758519987265269,1.7492000063260396,1.7399300038814545,1.7306999961535137,1.7215200066566467,1.712399999300639,1.7033199965953827,1.6942800084749858,1.6852999925613403,1.6763700048128765,1.6674800018469493,1.6586400071779888,1.6498400171597798,1.6410999993483226,1.632400006055832,1.6237399975458782,1.6151300072669983,1.6065699855486553,1.5980500082174938,1.589579999446869,1.5811499853928883,1.5727699995040894,1.5644300083319347,1.556140015522639,1.5478899975617726,1.5396900077660878,1.5315199891726177,1.5234099924564362,1.5153299868106842,1.5072999993960063,1.4993100066979725,1.4913599987824757,1.4834500054518382,1.4755900005499523,1.4677700002988179,1.4599899848302205,1.4522499938805897,1.4445500075817108,1.4369000097115834,1.4292800029118855,1.4217000007629395,1.4141699771086376,1.4066700041294098,1.3992200096448262,1.3918000062306721,1.3844299912452698,1.3770900070667267,1.369789997736613,1.362529993057251,1.3553099830945332,1.3481299877166748,1.3409800132115681,1.3338700036207836,1.3268099923928578,1.3197699983914692,1.3127799928188324,1.3058200081189473,1.2988999883333843,1.2920199930667877,1.2851700186729431,1.2783600091934204,1.271589994430542,1.2648500104745228,1.2581500013669331,1.2548000117142994};
        CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.46001672744751,8.488823413848877,8.531164169311523,8.575854301452637,8.618204037348429,8.658293883005777,8.696223735809326,8.732073624928793,8.76590363184611,8.797803243001303,8.82783325513204,8.856083075205484,8.882613182067871,8.90747300783793,8.930742740631104,8.952472686767578,8.972732623418173,8.991562525431315,9.009042421976725,9.02520219484965,9.04009222984314,9.053772131601969,9.066282033920288,9.077671925226847,9.087981859842936,9.097251892089844,9.105531692504883,9.112841685612997,9.119221607844034,9.124721686045328,9.129371484120687,9.133191506067911,9.136221567789713,9.138501326243082,9.14004135131836,9.140881299972534,9.141061305999756,9.140591144561768,9.139491160710653,9.137801170349121,9.135530948638916,9.132710933685303,9.129361152648926,9.125500917434692,9.121150811513266,9.11634087562561,9.11107087135315,9.10537083943685,9.09925103187561,9.092740774154663,9.085840781529745,9.07857076327006,9.070950746536255,9.063000758488974,9.054720640182495,9.046130657196045,9.037240584691366,9.028070449829102,9.018610636393229,9.0089004834493,8.998940626780191,8.988730510075888,8.97830057144165,8.967630545298258,8.956750392913818,8.94567052523295,8.93440047899882,8.922950585683187,8.91131043434143,8.899510383605957,8.887540499369303,8.875420411427816,8.863150437672934,8.850730339686075,8.838180383046469,8.825510263442993,8.812710444132486,8.799800237019857,8.786780198415121,8.773660262425741,8.760430256525675,8.747100194295248,8.733680248260498,8.72018019358317,8.706590175628662,8.692929983139038,8.67786987622579,8.661460002263388,8.645099878311157,8.62876001993815,8.612469991048178,8.59621000289917,8.57998013496399,8.563790082931519,8.547640005747477,8.531519889831543,8.515430132548014,8.499380032221476,8.483369906743368,8.467390060424805,8.45143993695577,8.435529947280884,8.419649918874105,8.403800010681152,8.38799007733663,8.372210025787354,8.356470108032227,8.340760151545206,8.325080076853434,8.309439897537231,8.293829997380575,8.278249979019165,8.262699921925863,8.247189919153849,8.231710036595663,8.216259956359863,8.200849930445353,8.18546994527181,8.170119762420654,8.154799938201904,8.139509916305542,8.124260028203329,8.109040101369223,8.093850056330362,8.07869005203247,8.063560088475546,8.048470179239908,8.0334099928538,8.018369992574057,8.00336996714274,7.988400061925252,7.973460078239441,7.958559989929199,7.943679928779602,7.928830027580261,7.91402002175649,7.8992299636205034,7.884470025698344,7.869750022888184,7.8550500472386675,7.840379953384399,7.82575003306071,7.811139941215515,7.796560009320577,7.782009998957316,7.767489989598592,7.752999981244405,7.738540013631185,7.724100073178609,7.709699988365173,7.695320010185242,7.6809699932734175,7.66664997736613,7.652360041936238,7.6380899747212725,7.623850027720134,7.609650015830994,7.5954599777857466,7.581309994061788,7.567180037498474,7.553079962730408,7.5390100081761675,7.524959961573283,7.510950048764546,7.496949990590413,7.482990026473999,7.469050010045369,7.455140034357707,7.441250006357829,7.427389979362488,7.413559953371684,7.399750034014384,7.385970075925191,7.372209986050923,7.358479976654053,7.344779968261719,7.331099947293599,7.3174500068028765,7.303820013999939,7.290219942728679,7.276640017827352,7.263090014457703,7.249560038248698,7.23605998357137,7.2225799560546875,7.209129969278972,7.195700009663899,7.182300051053365,7.168920040130615,7.155569990475972,7.142240007718404,7.128940065701802,7.115659952163696,7.102409998575847,7.089179992675781,7.075980067253113,7.062800010045369,7.049639940261841,7.036509990692139,7.023409962654114,7.0103300015131635,6.997269908587138,6.984239975611369,6.971229990323384,6.958240032196045,6.945289969444275,6.9323499997456866,6.919439951578776,6.906550010045369,6.89368999004364,6.880850036938985,6.868040045102437,6.8552500406901045,6.842479983965556,6.829740007718404,6.817020018895467,6.804320057233174,6.791650017102559,6.779000083605449,6.7663800319035845,6.753779967625936,6.741199970245361,6.728640000025432,6.716109951337178,6.703610062599182,6.691119988759358,6.678660074869792,6.666229963302612,6.6538099845250445,6.641420006752014,6.629050016403198,6.616710027058919,6.604390025138855,6.592089970906575,6.579819997151692,6.5675599575042725,6.555329958597819,6.543130000432332,6.530939976374309,6.518779993057251,6.506650010744731,6.494530002276103,6.482439994812012,6.470370014508565,6.458319942156474,6.4462999900182085,6.434299945831299,6.422319968541463,6.410359938939412,6.3984300295511884,6.386519988377889,6.3746300141016645,6.362759987513225,6.350920001665751,6.339100003242493,6.3273000319798784,6.315520008405049,6.303770025571187,6.292029976844788,6.280320008595784,6.268630027770996,6.256970047950745,6.245320002237956,6.233699997266133,6.222099939982097,6.210520068804423,6.198959906895955,6.187419931093852,6.175909956296285,6.164419968922933,6.152949968973796,6.141499996185303,6.130069971084595,6.118660012880961,6.107279976209004,6.095909992853801,6.084570010503133,6.07325001557668,6.061949968338013,6.050669987996419,6.039410034815471,6.0281699895858765,6.016960024833679,6.005759994188945,5.9945900440216064,5.983440001805623,5.972300012906392,5.9611899852752686,5.9500999848047895,5.939029971758525,5.927989959716797,5.916960000991821,5.905949989954631,5.894959966341655,5.884000023206075,5.873049934705098,5.8621301253636675,5.8512199719746905,5.84034005800883,5.829480012257894,5.81862998008728,5.807809988657634,5.797010024388631,5.786230007807414,5.7754600048065186,5.764720002810161,5.753999988238017,5.743299961090088,5.732620000839233,5.721950054168701,5.711309989293416,5.700689951578776,5.69008994102478,5.679509997367859,5.6689399878184,5.6583999792734785,5.647879997889201,5.637380043665568,5.626889944076538,5.616430044174194,5.605990012486775,5.59555999437968,5.58516001701355,5.574769973754883,5.56440003712972,5.554059982299805,5.543729980786641,5.533419966697693,5.5231300592422485,5.5128599802653,5.502610047658284,5.4923800230026245,5.482170025507609,5.471980015436809,5.461810032526652,5.451649904251099,5.441510041554769,5.431399981180827,5.421300013860066,5.411219954490662,5.401159962018331,5.391120076179504,5.381099979082744,5.371089895566304,5.361110011736552,5.351139942804973,5.341199994087219,5.331269939740499,5.321359952290853,5.311469992001851,5.301590005556743,5.291739980379741,5.28190000851949,5.272079984347026,5.262279987335205,5.252499938011169,5.242740114529927,5.23298994700114,5.223270018895467,5.213559985160828,5.203869978586833,5.194199959437053,5.184539993604024,5.1749099890391035,5.165289918581645,5.155689994494121,5.146109978357951,5.136540015538533,5.127000053723653,5.117469986279805,5.107959945996602,5.098470012346904,5.088990052541097,5.0795300006866455,5.070099989573161,5.060670018196106,5.051270008087158,5.041879971822103,5.032509962717692,5.023159980773926,5.0138299862543745,5.004510005315145,4.99521001180013,4.9859299659729,4.9766600131988525,4.967420061429341,4.958190004030864,4.948969920476277,4.939779996871948,4.930600047111511,4.921439965565999,4.912289977073669,4.903170029322307,4.894059975941976,4.884959975878398,4.875890016555786,4.866829951604207,4.857789953549703,4.848760048548381,4.839750051498413,4.830760041872661,4.821790099143982,4.812829971313477,4.803890069325765,4.794960021972656,4.7860599756240845,4.777159969011943,4.768289923667908,4.759430011113484,4.750590006510417,4.741769989331563,4.732960025469462,4.724160075187683,4.715389966964722,4.706629951794942,4.697889963785808,4.689159989356995,4.680450042088826,4.671749949455261,4.663080056508382,4.654419978459676,4.645769993464152,4.6371400356292725,4.628530025482178,4.619929989178975,4.611350019772847,4.602779905001323,4.594230055809021,4.585700035095215,4.577180027961731,4.5686800082524615,4.560200015703837,4.551729957262675,4.543269991874695,4.534839987754822,4.526409983634949,4.5180100202560425,4.509620110193889,4.501239975293477,4.492880026499431,4.484539985656738,4.476209958394368,4.467890024185181,4.45959993203481,4.451319972674052,4.443049987157186,4.434799989064534,4.426559964815776,4.418340086936951,4.410139958063762,4.401950081189473,4.393769979476929,4.385610024134318,4.377469937006633,4.369339982668559,4.3612300157547,4.353130022684733,4.345039963722229,4.336980024973552,4.328919967015584,4.320890029271443,4.312859972318013,4.304849942525228,4.296860019365947,4.288880030314128,4.280919949213664,4.272969881693522,4.265040040016174,4.2571200132369995,4.249210039774577,4.24131993452708,4.233450015385945,4.225589990615845,4.217740058898926,4.209909995396932,4.20208998521169,4.1942899624506635,4.186510006586711,4.178729971249898,4.170980056126912,4.163230021794637,4.155500094095866,4.14779003461202,4.140090028444926,4.132399956385295,4.128559947013855};
        CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192159016927,514.5848337809244,508.81994374593097,504.2629089355469,499.6569137573242,495.01591237386066,490.3539098103841,485.67991129557294,481.00390879313153,476.3339131673177,471.67491912841797,467.0329055786133,462.4119110107422,457.81691487630206,453.24891408284503,448.71191660563153,444.2079162597656,439.73791758219403,435.30491892496747,430.9089177449544,426.5519205729167,422.23291778564453,417.95392354329425,413.7149200439453,409.5159225463867,405.35792032877606,401.2399190266927,397.16192118326825,393.1249287923177,389.12792714436847,385.1709264119466,381.25292714436847,377.3759282430013,373.5379282633464,369.7389322916667,365.9789326985677,362.25793202718097,358.57493082682294,354.929931640625,351.32293701171875,347.752934773763,344.21893819173175,340.72293345133465,337.262934366862,333.8389358520508,330.44993591308594,327.09593963623047,323.7779362996419,320.49293518066406,317.2429377237956,314.02593994140625,310.84293874104816,307.6929397583008,304.57593790690106,301.4909413655599,298.43694559733075,295.4159444173177,292.4259440104167,289.4669443766276,286.5379460652669,283.63994852701825,280.7719497680664,277.93294525146484,275.1239471435547,272.34395090738934,269.5929438273112,266.8709538777669,264.1759516398112,261.50995381673175,258.8709487915039,256.25895436604816,253.67495473225912,251.11795043945312,248.58695348103842,246.0819549560547,243.60295486450195,241.14995447794595,238.72295506795248,236.3209546407064,233.9429562886556,231.5909563700358,229.26195653279623,226.95795822143555,224.67795689900717,222.42195892333984,220.18895721435547,217.9789581298828,215.7929573059082,213.6299591064453,211.4879608154297,209.3699607849121,207.27295939127603,205.19796244303384,203.14396158854166,201.1119613647461,199.09996541341147,197.10996627807617,195.13996378580728,193.18996302286783,191.2609634399414,189.3509661356608,187.4609629313151,185.5909652709961,183.73896662394205,181.90696589152017,180.09396743774414,178.29896799723306,176.52296829223633,174.76496760050455,173.02496846516928,171.3029670715332,169.59897104899088,167.91196823120117,166.24196751912436,164.589968363444,162.95396931966147,161.3349698384603,159.73296737670898,158.14697265625,156.57697041829428,155.02297337849936,153.48496882120767,151.96297327677408,150.45597203572592,148.96497217814127,147.48897298177084,146.02697245279947,144.58097457885742,143.14997355143228,141.73297373453775,140.32997385660806,138.94197209676108,137.56697463989258,136.20697657267252,134.86097462972006,133.5279769897461,132.20797475179037,130.90197626749674,129.60897318522134,128.328976949056,127.06197738647461,125.8079776763916,124.56597646077473,123.33697764078777,122.11997731526692,120.91497802734375,119.72197723388672,118.54197883605957,117.37297757466634,116.21597862243652,115.06997871398926,113.93597920735677,112.81297938028972,111.70197931925456,110.60098012288411,109.51097933451335,108.43298021952312,107.36498006184895,106.30698076883952,105.25998115539551,104.22398058573405,103.19798024495442,102.18198076883952,101.17598152160645,100.17998186747234,99.19378153483073,98.21738306681316,97.25068219502766,96.29358228047688,95.34588241577148,94.40758196512859,93.47848320007324,92.55858357747395,91.64768282572429,90.74578348795573,89.85278383890788,88.96858406066895,88.09308369954427,87.22618293762207,86.36778322855632,85.517884572347,84.67628479003906,83.84298451741536,83.017884572347,82.2008851369222,81.39188575744629,80.59088452657063,79.79778671264648,79.01248550415039,78.2348861694336,77.46488571166992,76.70248603820801,75.94768651326497,75.20018513997395,74.46008682250977,73.72728665669759,73.0017859141032,72.2832857767741,71.57198715209961,70.86758804321289,70.17018572489421,69.47958691914876,68.79578653971355,68.1187858581543,67.44848759969075,66.78468831380208,66.12748845418294,65.47668902079265,64.83238665262859,64.19438807169597,63.56268850962321,62.937188466389976,62.31778812408447,61.70458857218424,61.097388903299965,60.4961887995402,59.90088939666748,59.31148910522461,58.72788906097412,58.14998912811279,57.5777899424235,57.011189460754395,56.4502903620402,55.894789377848305,55.344789822896324,54.80029010772705,54.26109027862549,53.72719033559164,53.198489824930824,52.67509015401205,52.15679041544596,51.64369042714437,51.13559087117513,50.63249111175537,50.13429069519043,49.640990575154625,49.15269088745117,48.669090270996094,48.19029108683268,47.71619065602621,47.24679183959961,46.78199100494385,46.32179101308187,45.86609141031901,45.41499169667562,44.968292554219566,44.525991439819336,44.08799171447754,43.65439097086588,43.2250919342041,42.799991607666016,42.37899239857992,41.96229203542074,41.54959265391032,41.14099248250326,40.73649247487386,40.335892041524254,39.93929227193197,39.54649225870768,39.15769259134928,38.77269268035889,38.39149284362793,38.01399294535319,37.64019266764323,37.27019341786703,36.90379333496094,36.54099305470785,36.18169339497884,35.82599353790283,35.47389348347982,35.12509314219157,34.77989355723063,34.4379940032959,34.099493980407715,33.76429398854574,33.43239402770996,33.10379441579183,32.778394063313804,32.45629437764486,32.137294133504234,31.821394284566242,31.508694330851238,31.198994318644207,30.89239438374837,30.588794231414795,30.28819449742635,29.990594387054443,29.695794423421223,29.40399471918742,29.115094502766926,28.828994750976562,28.545694669087727,28.26519505182902,27.987494945526123,27.71249516805013,27.440194765726726,27.170594851175945,26.903695106506348,26.63929494222005,26.377595106760662,26.11849530537923,25.861895243326824,25.607795238494873,25.356195608774822,25.10709555943807,24.860495408376057,24.616295337677002,24.37449566523234,24.134995460510254,23.89789565404256,23.663195768992107,23.430795669555664,23.200595378875732,22.97269566853841,22.747096061706543,22.523695786794026,22.3024959564209,22.083395957946777,21.866495609283447,21.651795864105225,21.439096132914226,21.228596210479736,21.020095984141033,20.81369638442993,20.60929600397746,20.406896432240803,20.206496238708496,20.007996400197346,19.811596552530926,19.61699644724528,19.424396355946858,19.233696301778156,19.044796625773113,18.857796669006348,18.672596613566082,18.489296595255535,18.307796319325764,18.127997080485027,17.949996948242188,17.773796876271565,17.599296887715656,17.426497141520183,17.255396842956543,17.085996786753338,16.918296972910564,16.752196947733562,16.587796847025555,16.42489719390869,16.263696829477947,16.103996912638348,15.94599707921346,15.78939708073934,15.634397188822428,15.480997006098429,15.328997294108072,15.178597132364908,15.029597282409668,14.882097403208414,14.735997279485067,14.591397285461426,14.448097387949625,14.306297461191813,14.165897448857626,14.026897271474203,13.889197587966919,13.752897421518961,13.617997407913208,13.484297593434652,13.351997534434,13.22099749247233,13.091197490692139,12.96279764175415,12.83559767405192,12.70959766705831,12.584897756576538,12.461397806803385,12.339097738265991,12.217997709910074,12.098197778066,11.979397853215536,11.861897865931192,11.745497783025106,11.630297819773356,11.51619784037272,11.403197844823202,11.291298071543375,11.180497884750366,11.07079792022705,10.962197860081991,10.854697942733765,10.74819795290629,10.642697970072428,10.53829805056254,10.434898058573404,10.332598129908243,10.23119823137919,10.130798101425171,10.031498193740845,9.933048089345297,9.83560824394226,9.739128112792969,9.643598238627115,9.549008131027222,9.45533831914266,9.362588246663412,9.270758231480917,9.17982816696167,9.089788357416788,9.000628471374512,8.912348508834839,8.824938376744589,8.738378286361694,8.652678489685059,8.567808469136557,8.483778476715088,8.400578498840332,8.318188428878784,8.236608505249023,8.155828555425009,8.075848579406738,7.9966485897699995,7.918228507041931,7.84057863553365,7.7636886437733965,7.687548557917277,7.612168590227763,7.537518620491028,7.4636086622873945,7.390418648719788,7.317948619524638,7.246188640594482,7.175138672192891,7.1047786474227905,7.035108645757039,6.966128667195638,6.897828698158264,6.830188711484273,6.763218800226848,6.696908791859944,6.631248752276103,6.566228787104289,6.501848737398784,6.438108801841736,6.374988873799642,6.312478860219319,6.250598827997844,6.1893088817596436,6.128638863563538,6.068548917770386,6.009058912595113,5.950148900349935,5.8918189605077105,5.834058920542399,5.776858925819397,5.720228910446167,5.664158980051677,5.608628869056702,5.553648988405864,5.499208927154541,5.445298989613851,5.391928990681966,5.3390690088272095,5.286738991737366,5.234909017880757,5.18359903494517,5.132789095242818,5.082479079564412,5.03265909353892,4.9833290576934814,4.934489091237386,4.8861190478007,4.838229099909465,4.790809154510498,4.743859171867371,4.697359124819438,4.651319146156311,4.605739196141561,4.560599088668823,4.515899181365967,4.471639156341553,4.427819172541301,4.384419123331706,4.3414491812388105,4.298909147580464,4.256779789924622,4.235819538434346};
        //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.90184052785238,40.0460418065389,40.47105693817139,37.45386791229248,38.77025159200033,40.11823018391927,41.47877057393392,40.82885615030924,37.94426759084066,34.865269343058266,31.77273114522298,28.67880328496297,25.58423678080241,22.490979194641113,19.395014603932697,16.304557641347248,13.202447096506754,11.390902598698935,11.010091145833334,10.755007982254028,10.50808604558309,10.262408574422201,10.016551494598389,9.770894606908163,9.52503760655721,9.279599030812582,9.033173084259033,8.903431057929993,8.902959505716959,8.913976232210794,8.925647139549255,8.937466065088907,8.949269771575928,8.96108110745748,8.97289260228475,8.984687010447184,8.996512571970621,9.00556461016337,9.011555671691895,9.017271280288696,9.022963285446167,9.028662522633871,9.034352620442709,9.040053049723307,9.04574147860209,9.051446676254272,9.057119846343994,9.066077947616577,9.078651746114096,9.091558774312338,9.104485273361206,9.117406924565634,9.130335966746012,9.143256505330404,9.156185547510782,9.169118881225586,9.182026227315268,9.19769318898519,9.216410875320435,9.235397895177206,9.254403670628866,9.27341596285502,9.29242475827535,9.311435143152872,9.330445289611816,9.349454164505005,9.368469635645548,9.386136213938395,9.402316729227701,9.418363253275553,9.43440580368042,9.450444062550863,9.466485102971395,9.482524315516153,9.498565594355265,9.51459034283956,9.530659198760986,9.53839079538981,9.536823749542236,9.534420569737753,9.53199871381124,9.5295356909434,9.52710517247518,9.524648110071817,9.522213776906332,9.519750992457071,9.51733128229777,9.50878103574117,9.493392785390219,9.477401733398438,9.461382389068604,9.44535223642985,9.429322560628256,9.41328231493632,9.397252321243286,9.381222248077393,9.365192413330078,9.349162260691324,9.333132266998291,9.317102193832397,9.301072438557943,9.28504220644633,9.269012292226156,9.252972523371378,9.236942291259766,9.22091237703959,9.204882383346558,9.188852310180664,9.17282239596049,9.156792481740316,9.140762329101562,9.124732414881388,9.108702500661215,9.092662413914999,9.076632420221964,9.06060242652893,9.044572353363037,9.028542439142862,9.012512365976969,8.996482372283936,8.98045245806376,8.964422424634298,8.948392351468405,8.93236251672109,8.916322549184164,8.90029239654541,8.884262402852377,8.868232448895773,8.852202455202738,8.836172262827555,8.820142467816671,8.804112315177917,8.788082520167032,8.77205240726471,8.756022532780966,8.73998256524404,8.723952452341715,8.707922498385111,8.691892425219217,8.675862471262613,8.65983247756958,8.643802483876547,8.627772331237793,8.611742377281189,8.595712423324585,8.579672574996948,8.563642422358194,8.547612428665161,8.531582554181417,8.515552441279093,8.49952256679535,8.483492374420166,8.467462460199991,8.451432267824808,8.435402313868204,8.41937255859375,8.403332591056824,8.38730231920878,8.371272524197897,8.355242411295572,8.339212457338968,8.323182503382364,8.307152469952902,8.291122476259867,8.275092403093973,8.25906244913737,8.243032574653625,8.226992646853128,8.210962494214376,8.194932460784912,8.178902506828308,8.162872592608133,8.14684247970581,8.130812565485636,8.114782571792603,8.09875245889028,8.082722663879395,8.066682696342468,8.050652464230856,8.034622629483541,8.018592397371927,8.002562602361044,7.986532529195149,7.970502495765686,7.954472343126933,7.938442349433899,7.922412594159444,7.906372507413228,7.890342553456624,7.874312520027161,7.8582825263341265,7.8422525723775225,7.8262226184209185,7.810192545255025,7.794162591298421,7.778132478396098,7.762102683385213,7.746062636375427,7.7300325234731035,7.7140025695164995,7.697972575823466,7.681942582130432,7.665912588437398,7.649882594744365,7.633852601051331,7.617822488149007,7.601792693138123,7.585752646128337,7.569722692171733,7.553692658742269,7.537662585576375,7.521632631619771,7.505602637926738,7.489572564760844,7.47354257106781,7.457512617111206,7.4414825439453125,7.425452709197998,7.409412701924642,7.393382628758748,7.377352674802144,7.3613226016362505,7.345292687416077,7.329262653986613,7.313232620557149,7.297202706336975,7.281172593434651,7.265142758687337,7.249102711677551,7.233072559038798,7.217042605082194,7.201012810071309,7.1849821011225385,7.168954133987427,7.152918696403503,7.136903484662374,7.1208328406016035,7.112016399701436,7.111250519752502,7.111202955245972,7.111197392145793,7.111199657122294,7.111198703447978,7.1111990213394165,7.111198862393697,7.111198981602986,7.111198941866557,7.111198941866557,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666922569274902,6.884193301200867,6.611528674761455,6.6703247626622515,6.737257560094197,6.8053542375564575,6.872624039649963,6.873660524686177,6.789880355199178,6.680801510810852,6.563159545262654,6.441808899243672,6.3182066679000854,6.192877014478047,6.0660719871521,5.93794830640157,5.8086572488149,5.718288938204448,5.678853631019592,5.65425185362498,5.6341317892074585,5.615521391232808,5.597541173299153,5.579920848210652,5.562570492426555,5.545450210571289,5.528549869855245,5.512149453163147,5.496339241663615,5.480879028638204,5.465668797492981,5.450678626696269,5.435878356297811,5.421258131663005,5.406797885894775,5.39248784383138,5.378337542215983,5.36467707157135,5.351696888605754,5.339146693547566,5.326946536699931,5.315066377321879,5.3034762144088745,5.292155981063843,5.281085809071858,5.27025572458903,5.259645303090413,5.249834815661113,5.240954717000325,5.232464710871379,5.224194566408793,5.216104507446289,5.20816433429718,5.200364311536153,5.1926941474278765,5.185144106547038,5.177713791529338,5.170873522758484,5.164743423461914,5.158803423245748,5.15294337272644,5.147103389104207,5.141273299853007,5.135463317235311,5.129653215408325,5.123863220214844,5.118073105812073,5.112503012021382,5.10722295443217,5.102082888285319,5.09703282515208,5.09207284450531,5.087182720502217,5.082362731297811,5.0776026248931885,5.0729025999705,5.068252603212993,5.063472708066304,5.05853267510732,5.053612629572551,5.048762520154317,5.043992042541504,5.0406709512074785,5.039280851682027,5.038550853729248,5.038010915120442,5.037540674209595,5.037780125935872,5.038880228996277,5.040230234464009,5.041660229365031,5.0431002378463745,5.044550180435181,5.046000202496846,5.0474501848220825,5.0488901535669966,5.05033020178477,5.051760236422221,5.05318025747935,5.054590225219727,5.056000312169393,5.057400266329448,5.0587901671727495,5.0601701736450195,5.0615501801172895,5.062920252482097,5.064280192057292,5.065640250841777,5.066980202992757,5.0683302481969195,5.0696602662404375,5.070990165074666,5.072320222854614,5.073630213737488,5.0749402443567915,5.076250235239665,5.077550292015076,5.078840295473735,5.080130219459534,5.081420222918193,5.082700252532959,5.083970268567403,5.085240324338277,5.086510221163432,5.087770183881124,5.089030186335246,5.090280254681905,5.0915303230285645,5.0927702983220415,5.093990246454875,5.095200260480245,5.096390287081401,5.0975602467854815,5.098700324694316,5.099820216496785,5.10092027982076,5.10200035572052,5.103050311406453,5.104080359141032,5.105090300242106,5.106070359547933,5.107030312220256,5.107980330785115,5.108900348345439,5.109800338745117,5.110690434773763,5.111550410588582,5.11240033308665,5.11322037378947,5.114030400911967,5.11482040087382,5.115590453147888,5.116340438524882,5.117070396741231,5.117780407269795,5.118470470110576,5.119150439898173,5.119810461997986,5.120440403620402,5.121070345242818,5.121670405069987,5.122250437736511,5.122820496559143,5.1233704884847,5.123900492986043,5.1244105497996015,5.124900499979655,5.125380516052246,5.125840465227763,5.126280506451924,5.126700520515442,5.127100547154744,5.127490480740865,5.1278605461120605,5.1282105048497515,5.12855060895284,5.128870566685994,5.1291706164677935,5.129450559616089,5.1297305425008135,5.130010565121968,5.130290548006694,5.1305705308914185,5.130850553512573,5.13114058971405,5.131430506706238,5.131720503171285,5.1320104996363325,5.132310509681702,5.132610599199931,5.132910529772441,5.1332205931345625,5.133520523707072,5.1338305075963335,5.134150544802348,5.13446048895518,5.134780565897624,5.135100523630778,5.135420560836792,5.135740518569946,5.136070569356282,5.136390566825867,5.136720577875773,5.137040575345357,5.1373705466588335,5.13770055770874,5.138020475705464,5.138350526491801,5.1386905113856,5.139020522435506,5.1393504937489825,5.139680544535319,5.140010436375936,5.140340447425842,5.1406805117925005,5.141010483105977,5.141340533892314,5.141680558522542,5.142010529836019,5.142350474993388,5.142680486043294,5.143020510673523,5.1433504819869995,5.143690466880798,5.144030491511027,5.144360383351644,5.144700487454732,5.145030419031779,5.1453704833984375,5.1457105080286665,5.146040479342143,5.146380464235942,5.1467204093933105,5.147050420443217,5.147390405337016,5.1477305094401045,5.148070494333903,5.148310542106628,5.148410518964131,5.148480614026387,5.148540536562602,5.1486005783081055,5.148670593897502,5.148740530014038,5.1488105456034345,5.148880521456401,5.148960590362549,5.149030566215515,5.149110515912374,5.149180610974629,5.149260600407918,5.149340589841207,5.149420539538066,5.149490674336751,5.14957058429718,5.149650573730469,5.149720589319865,5.149800539016724,5.149880568186442,5.149950583775838,5.150030612945557,5.150100588798523,5.1501805782318115,5.150250593821208,5.1503305832544966,5.150400559107463,5.150470574696858,5.150550564130147,5.150620539983113,5.15069059530894,5.1507606108983355,5.1508305470148725,5.1509106159210205,5.150980591773987,5.151050607363383,5.151120543479919,5.151190559069316,5.1512605746587115,5.151330550511678,5.151390512784322,5.151460528373718,5.151530663172404,5.15160055955251,5.151670535405477,5.15173065662384,5.151800632476807,5.151870648066203,5.151930570602417,5.1520005861918134,5.152060588200887,5.152130643526713,5.152190605799357,5.152260621388753,5.152320543924968,5.152390559514363,5.152450601259868,5.152510563532512,5.152580579121907,5.152640541394551,5.152700622876485,5.152770558993022,5.152830521265666,5.152890523274739,5.152950604756673,5.1530106862386065,5.1530706485112505,5.153140584627788,5.153200586636861,5.153260588645935,5.153320550918579,5.153380513191223,5.153440634409587,5.153500556945801,5.153560638427734,5.153620600700378,5.153680602709453,5.153740684191386,5.15380056699117,5.153860529263814,5.153920571009318,5.153980612754822,5.154040614763896,5.154090523719788,5.154150605201721,5.154210527737935,5.154270569483439,5.154330650965373,5.154390613238017,5.154440601666768,5.154500603675842,5.1545606056849165,5.15462064743042,5.154680569966634,5.154740611712138,5.15479052066803,5.154850602149963,5.154910604159038,5.154970606168111,5.155020594596863,5.155080596605937,5.155140558878581,5.155190587043762,5.155250549316406,5.155300577481587,5.1553605397542315,5.1554105679194135,5.155470569928487,5.155520558357239,5.15557062625885,5.155630588531494,5.155680576960246,5.155740578969319,5.155790607134501,5.1558405955632525,5.155890583992004,5.155950586001079,5.15600057442983,5.1560505628585815,5.156100630760193,5.1561505397160845,5.156210621198018,5.15626056989034,5.156310598055522,5.156360546747844,5.156410574913025,5.156460603078206,5.156510631243388,5.15656054019928,5.156610608100891,5.156660556793213,5.156710624694824,5.156760573387146,5.156800587972005,5.156850536664327,5.156900604565938,5.15695063273112,5.157000541687012,5.157040596008301,5.157090624173482,5.157140612602234,5.157190601030986,5.157230575879415,5.157280683517456,5.157330592473348,5.1573706070582075,5.157420635223389,5.157470623652141,5.157510598500569,5.157560626665751,5.157600561777751,5.157650550206502,5.1577006578445435,5.157740592956543,5.157790581385295,5.157830595970154,5.157880663871765,5.1579205592473345,5.157960573832194,5.158010681470235,5.158050537109375,5.158100605010986,5.158140619595845,5.158180594444275,5.158230582873027,5.158270557721456,5.158310612042745,5.158360560735066,5.1584006150563555,5.158440550168355,5.158490618069966,5.158530553181966,5.158570607503255,5.158610582351685,5.1586605707804365,5.158700545628865,5.158740599950154,5.158780574798584,5.158820668856303,5.158860603968303,5.158910592397054,5.1589506069819135,5.1589906215667725,5.159030596415202,5.159070650736491,5.159110585848491,5.15915064016978,5.159190575281779,5.159230589866638,5.159270644187927,5.159310658772786,5.159350633621216,5.159390568733215,5.1594306627909345,5.159470597902934,5.159510612487793,5.159550627072652,5.159590641657512,5.1596306165059405,5.1596706310908,5.1597105662028,5.159750620524089,5.159790595372518,5.159820516904195,5.159860571225484,5.159900585810344,5.1599405606587725,5.159980535507202,5.160020629564921,5.160050590833028,5.160090605417888,5.160130580266316,5.160170594851176,5.160210649172465,5.1602405707041425,5.160280625025432,5.160320560137431,5.16036061445872,5.160390615463257,5.160430550575256,5.160470565160115,5.160500685373942,5.160540580749512,5.160580674807231,5.160610636075337,5.160650610923767,5.160690546035767,5.1607206265131635,5.160760601361592,5.160800576210022,5.160830616950989,5.160870552062988,5.160900592803955,5.160940567652385,5.160970568656921,5.161010543505351,5.16105055809021,5.161080598831177,5.161120573679606,5.161150534947713,5.161190629005432,5.161220630009969,5.161260525385539,5.161290566126506,5.161330540974935,5.161360541979472,5.161380608876546};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219184835751853,2.6039250691731772,2.036418835322062,1.6552112400531769,1.3456987241903942,1.0938543031613033,0.8891441076993942,0.7229427943627039,0.5884100049734116,0.4793184772133827,0.3907711481054624,0.31880886604388553,0.2602691240608692,0.21260355412960052,0.17376064012447992,0.1420805181066195,0.11622857923309009,0.09509100019931793,0.07778699323534966,0.0636165455604593,0.05202776441971461,0.0425357228765885,0.03478304576128721,0.02842917898669839,0.023246262688189745,0.018996465175102156,0.015532127891977629,0.012690395582467318,0.010370263208945593,0.008468289044685662,0.006915118312463164,0.005644046274634699,0.004605926456861198,0.0037574710634847483,0.003064647064699481,0.002498902070025603,0.002037131072332462,0.001660113640051956,0.0013522174558602273,0.0011009341493869822,0.0008959582531436657,0.0007288290362339467,0.000592666634474881,0.0004817191099088329,0.00039145413029473275,0.0003179213769423465,0.0002581987573648803,0.00020952992538999146,0.0001700605838171517,0.00013789285427871315,0.00011183864201787704,2.5638091756263748e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8265838623047,563.0182749430338,559.0822143554688,563.4309794108073,567.2884826660156,570.8554738362631,574.2186177571615,574.0177510579427,569.1389872233073,562.6074625651041,555.4087270100912,547.8685658772787,540.1039326985677,532.1617889404297,524.0644836425781,515.8313166300455,507.473388671875,501.41376241048175,498.51202901204425,496.67967224121094,495.22399139404297,493.9157460530599,492.67660268147785,491.47848256429035,490.31343841552734,489.1732889811198,488.05841573079425,486.81602478027344,485.3943277994792,483.9333190917969,482.4752883911133,481.0352300008138,479.61417388916016,478.2121175130208,476.82906341552734,475.4640197753906,474.11495208740234,472.79385630289715,471.5097401936849,470.265630086263,469.05752817789715,467.8854217529297,466.74632517496747,465.63824462890625,464.5591583251953,463.50709025065106,462.4809748331706,461.51773325602215,460.6285680135091,459.77649943033856,458.94942982991535,458.1423797607422,457.35233306884766,456.5782877604167,455.8192418416341,455.07521057128906,454.34215037027997,453.6400400797526,452.969975789388,452.3099721272786,451.65495045979816,451.00295003255206,450.35194905598956,449.70293680826825,449.0559387207031,448.408935546875,447.76393636067706,447.10997517903644,446.4479802449544,445.78996022542316,445.1389414469401,444.4959131876628,443.8618876139323,443.234868367513,442.6158396402995,442.00282796223956,441.39681752522785,440.7778905232747,440.1419143676758,439.5068868001302,438.8798828125,438.26074473063153,437.79502360026044,437.53759511311847,437.35953013102215,437.2065022786458,437.06239064534503,437.00498962402344,437.05482228597003,437.13877360026044,437.2347590128581,437.33474985758465,437.4357452392578,437.53675333658856,437.6367467244466,437.73675537109375,437.83574930826825,437.9347635904948,438.03175862630206,438.1287612915039,438.22476450602215,438.31976318359375,438.4147771199544,438.50777435302734,438.6007715861003,438.6927795410156,438.78377532958984,438.8747838338216,438.96378326416016,439.0527852376302,439.1407877604167,439.2287902832031,439.3147964477539,439.4007873535156,439.4867909749349,439.57179768880206,439.65579477945965,439.7388000488281,439.82179768880206,439.90480550130206,439.98580169677734,440.06781005859375,440.14780680338544,440.2288182576497,440.3078079223633,440.3878122965495,440.46581776936847,440.54381561279297,440.62181854248047,440.6978251139323,440.77183024088544,440.84383900960285,440.912846883138,440.97985585530597,441.04386647542316,441.10586802164715,441.16587320963544,441.22288004557294,441.2768859863281,441.3288930257161,441.3779042561849,441.42491149902344,441.46891530354816,441.5119222005208,441.5519307454427,441.59093475341797,441.626948038737,441.66094970703125,441.6919581095378,441.72196197509766,441.74996693929035,441.7749735514323,441.7989756266276,441.8199869791667,441.8399887084961,441.85699971516925,441.8720016479492,441.885009765625,441.89701080322266,441.90602620442706,441.91302998860675,441.91803487141925,441.92103576660156,441.9220453898112,441.9220479329427,441.91905975341797,441.91405487060547,441.9070688883464,441.8990732828776,441.88807678222656,441.8750864664714,441.861089070638,441.84409586588544,441.8260955810547,441.8061014811198,441.7841059366862,441.76011912027997,441.73412322998047,441.7061284383138,441.6781285603841,441.64913177490234,441.6211242675781,441.59213002522785,441.5641225179036,441.53613026936847,441.5091298421224,441.4811248779297,441.4541193644206,441.4281260172526,441.40211995442706,441.37611897786456,441.3501230875651,441.3241195678711,441.2991180419922,441.2741165161133,441.24911244710285,441.22511037190753,441.2011133829753,441.1761220296224,441.15211232503253,441.1291097005208,441.1051203409831,441.08111572265625,441.05811564127606,441.0341161092122,441.01111094156903,440.98711649576825,440.964106241862,440.9411112467448,440.9181086222331,440.8951187133789,440.87111409505206,440.8481089274089,440.8251088460286,440.80311075846356,440.78011322021484,440.75711313883465,440.7341079711914,440.71111551920575,440.6881103515625,440.6661097208659,440.6431121826172,440.62011464436847,440.59710693359375,440.5751088460286,440.55211130777997,440.5291112263997,440.506108601888,440.4841079711914,440.4611129760742,440.43811289469403,440.4161071777344,440.39310963948566,440.37010955810547,440.3481089274089,440.3251139322917,440.30309804280597,440.29105377197266,440.29003651936847,440.29302978515625,440.2990239461263,440.30502065022785,440.3130238850911,440.32002512613934,440.32802327473956,440.3350245157878,440.343022664388,440.3520202636719,440.36002349853516,440.36802164713544,440.3760223388672,440.38502248128253,440.39302317301434,440.4010238647461,440.41002146402997,440.4180221557617,440.42601776123047,440.43502044677734,440.4430211385091,440.4510243733724,440.4590199788411,440.46801503499347,440.4760208129883,440.48401896158856,440.4920196533203,440.5000228881836,440.5080261230469,440.5160191853841,440.5240173339844,440.53102620442706,440.53901926676434,440.5470199584961,440.5550231933594,440.56202443440753,440.5700200398763,440.57802327473956,440.58502197265625,440.59302012125653,440.6000264485677,440.60801951090497,440.6150258382161,440.6220219930013,440.63002014160156,440.6370264689128,440.6440200805664,440.6520233154297,440.65902455647785,440.666020711263,440.6730244954427,440.6800231933594,440.68702443440753,440.6940205891927,440.7010192871094,440.70802307128906,440.71502685546875,440.72202555338544,440.72902425130206,440.7360254923503,440.7430191040039,440.7500254313151,440.7560221354167,440.76302337646484,440.770024617513,440.7770233154297,440.7830301920573,440.79002380371094,440.7970225016276,440.8030242919922,440.81002553304035,440.81702677408856,440.8230209350586,440.8300298055013,440.8360239664714,440.84302520751953,440.8490219116211,440.8560282389323,440.86202748616535,440.8690236409505,440.8750279744466,440.88101959228516,440.8880259195964,440.8940251668294,440.9010264078776,440.9070281982422,440.91301981608075,440.9200261433919,440.926025390625,440.9320246378581,440.9390284220378,440.94503021240234,440.9510243733724,440.95802815755206,440.9640299479167,440.9700291951497,440.9770253499349,440.98302459716797,440.98902893066406,440.9950230916341,441.0020217895508,441.0080286661784,441.01402791341144,441.02002207438153,441.0260264078776,441.03202565511066,441.03802490234375,441.0440266927083,441.0500259399414,441.05603281656903,441.061030069987,441.06702931722003,441.0730285644531,441.0790252685547,441.0850321451823,441.0900243123372,441.0960235595703,441.1020278930664,441.1070276896159,441.11302439371747,441.11903127034503,441.12402598063153,441.13002522786456,441.13503011067706,441.1410268147786,441.14602915445965,441.1520233154297,441.1570307413737,441.16302490234375,441.1680272420247,441.1740239461263,441.17903391520184,441.1840235392253,441.1900278727214,441.19503021240234,441.20003000895184,441.2050298055013,441.2110239664714,441.21603139241535,441.22102610270184,441.2260335286458,441.2310256958008,441.2360305786133,441.24202219645184,441.2470347086589,441.2520268758138,441.2570317586263,441.2620264689128,441.2670262654622,441.27202860514325,441.2770309448242,441.28202565511066,441.2870356241862,441.2920277913411,441.29703521728516,441.30103302001953,441.3060302734375,441.31102752685547,441.31603240966797,441.32102457682294,441.32602945963544,441.3300298055013,441.33502705891925,441.34002685546875,441.34503682454425,441.3490295410156,441.3540293375651,441.3590342203776,441.3640314737956,441.36803436279297,441.37302652994794,441.3780339558919,441.3820292154948,441.3870340983073,441.39103444417316,441.39603424072266,441.40003204345703,441.405029296875,441.4100290934245,441.4140268961589,441.4190317789714,441.42302958170575,441.4280293782552,441.4320348103841,441.436030069987,441.4410349527995,441.4450276692708,441.4500274658203,441.45403544108075,441.4590301513672,441.4630355834961,441.46702829996747,441.47203063964844,441.47603098551434,441.4800287882487,441.4850311279297,441.4890314737956,441.49303436279297,441.4970296223958,441.50203196207684,441.5060323079427,441.51003011067706,441.5140329996745,441.51903025309247,441.52303314208984,441.5270309448242,441.5310287475586,441.53503163655597,441.54002888997394,441.54403432210285,441.5480321248372,441.5520273844401,441.55603281656903,441.5600357055664,441.5640385945638,441.5680287679036,441.57203165690106,441.5760320027669,441.5810292561849,441.5850321451823,441.58903249104816,441.59303283691406,441.59703318277997,441.60103607177734,441.6050338745117,441.6090316772461,441.613037109375,441.6160405476888,441.6200307210286,441.62403361002606,441.62803904215497,441.6320317586263,441.63602956136066,441.64003499348956,441.64403279622394,441.6480305989583,441.6520309448242,441.655034383138,441.6590270996094,441.6630325317383,441.66703033447266,441.67103322347003,441.67503356933594,441.6780370076497,441.68202718098956,441.68603515625,441.69003041585285,441.6920445760091};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.446637233098349,9.763442834218344,10.082497755686441,9.426577965418497,9.602792421976725,9.784641901652018,9.966630220413208,9.903082927068075,9.572414636611938,9.219404379526773,8.86465589205424,8.50974694887797,8.154819130897522,7.799904624621074,7.4449533224105835,7.090094327926636,6.735060254732768,6.523089687029521,6.466619451840718,6.423185507456462,6.380762497584025,6.338426033655803,6.296104709307353,6.253775437672933,6.21144437789917,6.169126550356547,6.1267921924591064,6.091108242670695,6.06263542175293,6.034777681032817,6.006956775983174,5.9791470766067505,5.951336820920308,5.923517028490703,5.895706454912822,5.8678979476292925,5.840084632237752,5.817983984947205,5.802092393239339,5.786724964777629,5.771403789520264,5.75607426961263,5.7407539288202925,5.725434144337972,5.710113922754924,5.694794416427612,5.679472923278809,5.667301456133525,5.658564964930217,5.650116602579753,5.641695698102315,5.633276065190633,5.624855875968933,5.6164259513219195,5.608005881309509,5.599586049715678,5.591165502866109,5.584319631258647,5.579186360041301,5.574207146962483,5.569226781527202,5.564256985982259,5.559286793073018,5.554316957791646,5.549336830774943,5.544366836547852,5.5393968025843305,5.534775416056315,5.530524770418803,5.526314894358317,5.52209488550822,5.517884850502014,5.513674815495809,5.509464780489604,5.505254824956258,5.5010448296864825,5.496834834416707,5.492624839146932,5.488414804140727,5.484194835027059,5.479984839757283,5.475774884223938,5.471564809481303,5.4673547347386675,5.463144818941752,5.458935300509135,5.454724272092183,5.452366789182027,5.452034115791321,5.451864123344421,5.451714237531026,5.451554179191589,5.451404253641765,5.45125416914622,5.451104203859965,5.450944185256958,5.450794219970703,5.4506440957387285,5.450494209925334,5.450334191322327,5.450184146563212,5.450034221013387,5.4498841762542725,5.449734290440877,5.44957423210144,5.449424227078755,5.449274142583211,5.449124177296956,5.448964198430379,5.448814153671265,5.44866418838501,5.448514183362325,5.448364178339641,5.448204239209493,5.448054194450378,5.447904189427693,5.447754263877869,5.447594165802002,5.447444200515747,5.447294235229492,5.447144190470378,5.446994225184123,5.446834246317546,5.446684241294861,5.446534236272176,5.4463841915130615,5.446224212646484,5.44607412815094,5.445924202601115,5.445774157842,5.445624192555745,5.445464213689168,5.445314208666484,5.445164203643799,5.445014198621114,5.444854338963826,5.444704174995422,5.444554169972737,5.444404164950053,5.4442442655563354,5.444094220797221,5.443944176038106,5.443794171015422,5.443644245465596,5.44348418712616,5.443334221839905,5.4431841770807905,5.4430341720581055,5.4428742329279585,5.442724108695984,5.442574143409729,5.442424138387044,5.442264159520467,5.442114194234212,5.441964189211528,5.441814184188843,5.441664179166158,5.441504240036011,5.441354235013326,5.441204269727071,5.4410542249679565,5.4409042199452715,5.440744161605835,5.44059419631958,5.440444191296895,5.440294146537781,5.440134167671204,5.439984162648519,5.439834197362264,5.439684271812439,5.439524253209432,5.439374168713887,5.439224163691203,5.439074158668518,5.4389142592748,5.438764174779256,5.438614209493001,5.438464124997457,5.438314199447632,5.438154220581055,5.43800409634908,5.437854170799255,5.43770416577657,5.4375442663828535,5.437394142150879,5.437244216601054,5.437094171841939,5.436944206555684,5.436784227689107,5.436634182929993,5.436484177907308,5.436334212621053,5.436174194018046,5.436024188995361,5.435874263445537,5.435724139213562,5.435574173927307,5.43541419506073,5.4352641105651855,5.43511422475179,5.434964219729106,5.4348041613896685,5.434654156366984,5.434504230817159,5.434354186058044,5.4342042207717896,5.434044241905212,5.433894197146098,5.433744192123413,5.433594226837158,5.433434168497722,5.4332841237386065,5.433134158452352,5.432984193166097,5.43282421429952,5.432674129803975,5.43252416451772,5.432374159495036,5.432224154472351,5.432064175605774,5.431914210319519,5.431764125823975,5.43161420027415,5.431454261144002,5.431304136912028,5.431154211362203,5.431004126866658,5.430854121843974,5.430694142977397,5.430544137954712,5.430394132932027,5.430244207382202,5.430084228515625,5.429934183756511,5.429784218470256,5.429634213447571,5.429474234580994,5.429393768310547,5.429393728574117,5.429383834203084,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225393454233807,24.526807467142742,24.88560724258423,25.246907393137615,25.62180741628011,26.004807631174724,26.391207536061604,26.75210730234782,27.063706874847412,27.331507205963135,27.560407161712646,27.754806836446125,27.8827068010966,27.91750653584798,27.872706254323322,27.760005950927734,27.59000571568807,27.334205627441406,26.969004948933918,26.513304869333904,25.983304659525555,25.393404642740887,24.7562042872111,24.082404295603435,23.381604035695393,22.66180356343587,21.93000332514445,21.187803268432617,20.43630313873291,19.681502978007,18.92810297012329,18.180402755737305,17.441802342732746,16.715302149454754,16.003202120463055,15.307502031326294,14.629701932271322,13.970001856486002,13.328701893488565,12.706801573435465,12.105101744333902,11.524201472600302,10.964401404062906,10.425901333491007,9.90865127245585,9.412481228510538,8.937151114145914,8.48215103149414,8.04694096247355,7.631090958913167,7.234110871950786,6.8554909229278564,6.494670828183492,6.1510807275772095,5.824110706647237,5.513160705566406,5.217610677083333,4.936870535214742,4.670310576756795,4.4173405567804975,4.177340507507324,3.9497405091921487,3.733950436115265,3.5294504364331565,3.335680445035299,3.1521403789520264,2.9783403674761453,2.813810348510742,2.6581103006998696,2.5108103156089783,2.3714802861213684,2.2397203048070273,2.115150272846222,1.9973902304967244,1.8860802352428436,1.7809002101421356,1.6815002262592316,1.5875802040100098,1.4988201757272084,1.4149601757526398,1.3357301652431488,1.2609001696109772,1.1903201540311177,1.1238401432832081,1.0612201392650604,1.0022201240062714,0.948802133401235,0.9017751316229502,0.8596031367778778,0.8217441340287527,0.787720133860906,0.7571051369110743,0.729519118865331,0.7046261330445608,0.682125136256218,0.6617521246274313,0.6432721267143885,0.6264731287956238,0.6111691246430079,0.5971951385339102,0.5844021340211233,0.572658121585846,0.5618491272131602,0.5518701175848643,0.5426301211118698,0.5340461184581121,0.5260461121797562,0.5185661216576894,0.5115441183249155,0.5049331237872442,0.49868611494700116,0.49276411285003024,0.4871291170517604,0.48175110667943954,0.47660010556379956,0.4716481144229571,0.4668761119246483,0.46226411312818527,0.45779310911893845,0.4534471084674199,0.4492131049434344,0.44507810721794766,0.4410281057159106,0.437055100997289,0.43315110355615616,0.42930810153484344,0.4255191038052241,0.42177509764830273,0.4180730978647868,0.4144070992867152,0.4107740968465805,0.40716809779405594,0.40358609954516095,0.4000260904431343,0.3964800958832105,0.3929500902692477,0.3894330908854802,0.38592709352572757,0.3824300865332286,0.37894008805354434,0.375455083946387,0.37197408576806384,0.36849608769019443,0.36502008388439816,0.3615470826625824,0.3580750798185666,0.3546030844251315,0.3511310840646426,0.3476560761531194,0.34418008228143054,0.3407030800978343,0.337224081158638,0.3337430755297343,0.3302590747674306,0.3267730747660001,0.32328207542498905,0.3197890693942706,0.31629207481940586,0.3127930735548337,0.3092900688449542,0.3057850698630015,0.30227607240279514,0.298761064807574,0.2952430645624797,0.29172206421693164,0.2881980662544568,0.28467006236314774,0.2811390683054924,0.277605061729749,0.274065059920152,0.2705230539043744,0.26697705934445065,0.26342806220054626,0.2598760575056076,0.2563210551937421,0.2527630552649498,0.24919905389348665,0.2456330545246601,0.2420650546749433,0.2384930526216825,0.2349200521906217,0.2313440479338169,0.22776704902450243,0.22418504705031714,0.2206010470787684,0.2170170471072197,0.21343004579345384,0.20984304323792458,0.20625504354635874,0.20266504461566606,0.19907204061746597,0.1954780394832293,0.19188303872942924,0.1882870395978292,0.1846910367409388,0.18109403798977533,0.1774960346519947,0.17389503493905067,0.17029303312301636,0.16669003292918205,0.16308703273534775,0.1594830354054769,0.15587703262766203,0.1522690306107203,0.14866202945510545,0.14505302906036377,0.1414440261820952,0.13783402740955353,0.13422302529215813,0.1306100239356359,0.12699602420131365,0.12338102298478286,0.11976502028604348,0.11614901944994926,0.11253301985561848,0.10891501791775227,0.10529401774207751,0.1016730157037576,0.09805131641527016,0.09442881494760513,0.09080561498800914,0.08718161347011726,0.08355681225657463,0.07992901156346004,0.07630060985684395,0.07267150903741519,0.06904170910517375,0.06541120757659276,0.061779905731479325,0.058147806053360306,0.054512604450186096,0.05087680400659641,0.04724030258754889,0.04360310143480698,0.039965200858811535,0.03632640031476816,0.03268690034747124,0.02923790008450548,0.026152899954468012,0.02339349997540315,0.02092519976819555,0.018717500070730846,0.016742699934790533,0.014976300143947205,0.01339630006502072,0.011983099936818084,0.010718999973808726,0.009588220001508793,0.008576790026078621,0.007672079955227673,0.00686281993209074,0.006138949926632146,0.005491450002106528,0.004912259988486767,0.0043941699744512635,0.003930740000214428,0.0035161899674373367,0.0031453800038434565,0.0028136800004479787,0.0025169700190114477,0.0022515499925551317,0.0020141300143829235,0.0018017500018080075,0.0016117700045773138,0.0014418300124816597,0.0012898100054978083,0.0011538199808758993,0.0010321700052979093,0.000923355997656472,0.0008260119939222932,0.0007389319992701834,0.0006610350052748496,0.0005913520047518735,0.0005290159994425873,0.00047325199799767387,0.00042336799621504423,0.0003787430008136046,0.00033882199932122603,0.0003031110002969702,0.0002711639996656838,0.00024258499858357632,0.0002170190006533327,0.00019414699878931666,0.00017368700234025405,0.00015538299824887267,0.00013900900012231432,0.0001243600005788418,0.00011125599909670807,4.2822582448328227e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.05013370513916,22.259799321492512,22.13019911448161,22.13149929046631,22.104199409484863,22.052699247996014,21.980799357096355,21.878599325815838,21.73849932352702,21.56779940923055,21.37299919128418,21.15929937362671,20.91059970855713,20.61359961827596,20.278199831644695,19.912999471028645,19.525399684906006,19.099999745686848,18.624499797821045,18.1103998819987,17.567500114440918,17.00409968694051,16.427499930063885,15.843599875768026,15.257399797439575,14.673299789428711,14.094599882761637,13.522100130716959,12.956199884414673,12.399399757385254,11.853899876276651,11.321299950281778,10.802999893824259,10.299999952316284,9.812949895858765,9.3424600760142,8.88880999883016,8.451849778493246,8.031309962272644,7.627249995867412,7.239589969317119,6.86817999680837,6.512759963671367,6.173029939333598,5.848640004793803,5.539169987042745,5.244209965070088,4.963239947954814,4.695739944775899,4.441259940465291,4.199310024579366,3.9694299697875977,3.751129984855652,3.543940007686615,3.3473899761835733,3.16102002064387,2.984380026658376,2.8170299728711448,2.658549984296163,2.508519987265269,2.3665200074513755,2.232159992059072,2.105080008506775,1.984909991423289,1.8712999920050304,1.7639199992020924,1.662449985742569,1.5665900111198425,1.476060003042221,1.390579988559087,1.3098800083001454,1.2337200045585632,1.1618499954541524,1.0940399964650471,1.030080000559489,0.969756007194519,0.91287000477314,0.8592310051123301,0.8086550037066141,0.7609769950310389,0.7160389969746271,0.6736860026915868,0.6338039934635162,0.5962850004434586,0.5609949976205826,0.5278009871641794,0.4971279998620351,0.4688289985060692,0.44221799820661545,0.4171929980317752,0.39365600049495697,0.37151800096035004,0.35069599996010464,0.33111199736595154,0.3126870046059291,0.2953549971183141,0.27904899915059406,0.2637059986591339,0.24927000080545744,0.2356869988143444,0.22290199995040894,0.21086799974242845,0.19954299802581468,0.18888300036390623,0.17884700000286102,0.16939899946252504,0.16050399839878082,0.15212799981236458,0.14423799887299538,0.1368079992632071,0.12981100132068,0.12321799993515015,0.11700899961094062,0.1111589999248584,0.1056449996928374,0.10044900017480056,0.09555359929800034,0.09093709972997506,0.08658330018321674,0.08247909881174564,0.07860949883858363,0.07495829897622268,0.07151499887307484,0.06826709893842538,0.06520080069700877,0.0623052998756369,0.05957289971411228,0.05699389955649773,0.05455679974208275,0.052255699411034584,0.05008249978224436,0.048027198761701584,0.0460829995572567,0.044245499496658645,0.04250849969685078,0.04086369927972555,0.0393079991141955,0.03783609966437022,0.036440898974736534,0.03511999951054653,0.03386909949282805,0.03268179918328921,0.031554299561927714,0.030485499650239944,0.02947189938277006,0.02850789964819948,0.027592999394983053,0.026724199764430523,0.025896599671492975,0.02510769944638014,0.024357599206268787,0.023644099632898968,0.022962499565134447,0.022313499667992193,0.02169509930536151,0.021103199881811936,0.02053849942361315,0.019999599705139797,0.019482399492214125,0.018985899941374857,0.018510999623686075,0.018056599733730156,0.01761899966125687,0.01719969945649306,0.016797699655095737,0.016409399919211864,0.016034199701001246,0.015673599593962233,0.015326799592003226,0.014990499708801508,0.01466669972675542,0.014354399871081114,0.014050799732406935,0.013757599595313271,0.013474199610451857,0.013197799678891897,0.012927799796064695,0.012666299706324935,0.012412799677501122,0.012164499921103319,0.011923399598648151,0.011689199910809597,0.011458899670590958,0.011232599693660935,0.01101209968328476,0.010797299755116304,0.010585399887834987,0.01037869967209796,0.010176799803351363,0.009977049737547835,0.009781749763836464,0.009590619709342718,0.00940105978709956,0.009212989748145143,0.009028659823040167,0.008847859920933843,0.008668039847786227,0.00849147979170084,0.008318009786307812,0.008145079870397845,0.007972669787704945,0.007803099773203333,0.00763618981000036,0.007469449851972361,0.007305219808282952,0.007143339801890154,0.006981329837193091,0.0068191998871043324,0.006659289860787491,0.00650148990098387,0.006343319779261947,0.006187139932687084,0.006032839883118868,0.00587795985241731,0.005724889847139518,0.005573509959504008,0.005421369879816969,0.005268529833604892,0.005117349947492282,0.004967759906624754,0.004817299932862322,0.004668369928064446,0.004520889992515246,0.004372409932936232,0.004222989974853893,0.004075029864907265,0.0039284499556136625,0.0037808099295943975,0.003634529964377483,0.003489519973906378,0.0033433599940811596,0.0031984599966866276,0.003054749977309257,0.002909810010654231,0.00276369999240463,0.0026188299913580218,0.002475149987731129,0.002334909998656561,0.002202619992507001,0.0020778300046610334,0.001960109996919831,0.0018490699876565486,0.001744319995244344,0.0016454999955991905,0.0015522899921052158,0.0014643500132175784,0.0013814099947921932,0.0013031600004372497,0.0012293499894440174,0.0011597200063988566,0.001094030012609437,0.001032069994835183,0.0009736200008774176,0.0009184809944902858,0.0008664660078162948,0.0008173989917850122,0.0007711110083619133,0.0007274460076587275,0.0006862549926154315,0.0006473969988292083,0.0006107409911540648,0.0005761610033611456,0.0005435400040975461,0.000512767001055181,0.00048373700216567766,0.00045635200270529214,0.00043051700049545616,0.00040614600099312764,0.0003831550032676508,0.00036146600420276326,0.0003410050000335711,0.00032170299770465743,0.000303493997004504,0.0002863159994982804,0.0002701109988265671,0.0002548240008763969,0.0002404019990838909,0.0002267970000199663,0.00021396199978577593,0.0002018530006656268,0.00019043099988872805,0.0001796550010719026,0.00016948900156421587,0.0001598979991589052,0.0001508510007018534,0.0001423150000240033,0.00013426300089728707,0.00012666700058616698,0.00011949999983092614,0.00011273900114853556,0.00010636100038633838,5.9242965411006786e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.69507471720377,237.7288475036621,240.9888776143392,243.49690628051758,245.2909304300944,246.5279426574707,247.32899602254233,247.12806955973306,245.54410044352213,242.9991251627604,239.8141326904297,236.22918446858725,231.7252540588379,225.94027455647787,219.33229446411133,212.24329249064127,204.9323361714681,196.9043960571289,187.81541061401367,178.11242039998373,168.13141759236655,158.11940892537436,148.2563934326172,138.67138290405273,129.45236206054688,120.65734036763509,112.32132466634114,104.39931106567383,96.8518918355306,89.70567639668782,82.97255833943684,76.65424092610677,70.74532508850098,65.23460865020752,60.107394218444824,55.34657986958822,50.93346691131592,46.845754305521645,43.06184228261312,39.5636313756307,36.333221117655434,33.352911790212,30.605702877044678,28.07539447148641,25.746387163798016,23.604080041249592,21.634373982747395,19.824068069458008,18.16056203842163,16.63275686899821,15.23005223274231,13.942747990290323,12.761644045511881,11.678440570831299,10.685136953989664,9.774693886439005,8.940301020940145,8.175818483034769,7.475556095441182,6.8342238664627075,6.246971766153972,5.70933997631073,5.21720830599467,4.766806761423747,4.3546552658081055,3.977563997109731,3.6326127847035727,3.317121684551239,3.0286306937535605,2.7648797631263733,2.5237789352734885,2.303428133328756,2.102067470550537,1.9180768231550853,1.7499962250391643,1.5964656968911488,1.4562451938788097,1.328174740076065,1.2112243473529816,1.1044339537620544,1.0069536070028942,0.9179592877626419,0.8367929955323538,0.7628247241179148,0.6954214870929718,0.6339992433786392,0.5783220380544662,0.5278548697630564,0.48178670307000476,0.43972355624039966,0.4013364141186078,0.3663242906332016,0.3343861848115921,0.3052210782965024,0.27860898276170093,0.2543228988846143,0.232155820975701,0.2119187501569589,0.19344068070252737,0.17659362281362215,0.16123056784272194,0.1471945196390152,0.13436747218171755,0.12266943355401357,0.11200039337078731,0.10226835931340854,0.09339222870767117,0.08529519972701867,0.07790877483785152,0.07114325153330962,0.06494382830957572,0.05928750894963741,0.05412649052838484,0.049417173800369106,0.045119858967761196,0.04119814528773228,0.03761913254857063,0.034352721025546394,0.03137141062567631,0.028650200615326565,0.026166292062650125,0.02389888387794296,0.021828976770242054,0.019939269870519638,0.01821396391217907,0.01663875828186671,0.015200453189512094,0.013887148583307862,0.012687944419061145,0.011592740581060449,0.01059263696273168,0.009679143782705069,0.008844850895305475,0.008082798294102153,0.007386715811056395,0.006750853538202743,0.006169971544295549,0.005639289622195065,0.005154447940488656,0.00471146641454349,0.0043067050476868944,0.003936863678973168,0.0035989125608466566,0.0032900814937117198,0.0030078504544993243,0.0027499196003191173,0.002514188779362788,0.002298738011935105,0.0021018172847107053,0.0019218166708014905,0.0017572860815562308,0.0016068955786370982,0.0014694050963347156,0.0013437246476920943,0.0012288242675519239,0.0011237738945055753,0.001027733562902237,0.0009399232512805611,0.0008596369734732434,0.000786226722993888,0.0007191014883574098,0.0006577222811756656,0.0006015950687772905,0.0005502689018612728,0.0005033317429479212,0.0004604065931440952,0.00042115145091277856,0.0003852493270339134,0.00035241522224775207,0.00032238411464883637,0.00029491701813337084,0.00026979493122780696,0.0002468158563715406,0.0002257977806342145,0.00020657171383694126,0.00018898565273654336,0.00017289959820724712,0.00015818354828904072,0.00014472250040853396,0.0001324084551015403,0.00012114341977091196,0.00011083838277651618,6.862144982733298e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527328491210938,3.5471805334091187,3.4357604583104453,3.327050487200419,3.216910481452942,3.1060604651769004,2.9951204657554626,2.8846404353777566,2.7751004497210183,2.666900416215261,2.5603904128074646,2.4558504025141397,2.3535303672154746,2.2536203463872275,2.156300365924835,2.0616703232129416,1.969850331544876,1.880890319744746,1.794860303401947,1.7117603023846943,1.6316102941830952,1.5544002850850422,1.4801102777322133,1.4087002476056416,1.3401402533054352,1.274360219637553,1.211310217777888,1.1509302258491516,1.0931502083937328,1.0379001994927723,0.9851021816333135,0.9346831738948822,0.886564165353775,0.8406691551208496,0.7969191521406174,0.7552341421445211,0.7155381341775259,0.6777541289726893,0.6418061157067617,0.6076191167036692,0.5751221080621084,0.5442431072394053,0.5149121036132177,0.4870610957344373,0.4606240913271904,0.43553708493709564,0.411741075416406,0.3891760781407356,0.3677840729554494,0.34750806788603467,0.32829805960257846,0.3101000611980756,0.2928670570254326,0.276552048822244,0.26110804826021194,0.2464920493463675,0.23266404618819556,0.2195830469330152,0.2072110412021478,0.19551304106911024,0.18445403749744096,0.17400003224611282,0.1641190325220426,0.15478303159276643,0.14596303179860115,0.13763103013237318,0.1297630270322164,0.12233302493890126,0.11531802204747994,0.10869502152005832,0.10244302079081535,0.09654151958723863,0.09097331762313843,0.0857192190984885,0.08076171701153119,0.07608611509203911,0.07167671496669452,0.06751721414426963,0.06359401283164819,0.05989591218531132,0.05640921120842298,0.05312081084897121,0.05002211065342029,0.04710130952298641,0.04434760877241691,0.041752408569057785,0.03939320705831051,0.03724330756813288,0.03520790704836448,0.033279906337459884,0.03145270608365536,0.029720206124087174,0.028076505443702143,0.02653350525846084,0.02506770504017671,0.023674304441859324,0.0223664043781658,0.02112110424786806,0.019934604099641245,0.018820903884867828,0.017775303684175014,0.016793803156663973,0.01585490310875078,0.01495610293932259,0.014112302878250679,0.013320202628771463,0.012576502670223514,0.011878302320837975,0.011222802257786194,0.010590002251168093,0.009978462010622025,0.009404311887919903,0.008865261838460961,0.008359171682968736,0.00788402157680442,0.007437911427890261,0.007019071412893633,0.006625821348279715,0.006256601268736024,0.005909941159188747,0.005584461032412946,0.0052788610725353164,0.004991920936542253,0.004722510852540533,0.004452110966667533,0.0041807709106554585,0.0039260008100730675,0.003686780789090941,0.0034621507317448654,0.003251230693422258,0.003053180640563369,0.0028672105787942805,0.0026925805723294616,0.0025286105422613523,0.0023746304602051773,0.0022300404768126705,0.0020942704674477377,0.001966770398818577,0.0018470404029358178,0.001734610355924815,0.0016290303513718147,0.001529890326006959,0.0014367802941706032,0.0013493502726002287,0.001267240276016916,0.001190130259298409,0.0011177202492641907,0.0010497202165424824,0.0009858592190236475,0.0009258861876636123,0.0008695651777088642,0.000816671172894227,0.0007669981569051743,0.0007203481460843856,0.0006765371460157136,0.0006353921295764545,0.0005967511193982015,0.0005604611214948818,0.0005263791050917158,0.0004943710979811536,0.0004643100983230397,0.00043607708842804033,0.00040956308657769114,0.0003846600860318479,0.00036127307733598474,0.00033930806481900316,0.00031867806683294475,0.00029930406405280036,0.0002811070589814335,0.00026401705205595743,0.0002479660506651271,0.0002328910498666422,0.0002187330489202092,0.0002054360435674122,0.00019294703937096833,0.000181217038819644,0.00017020003603344472,0.00015985303131553033,0.00015013503192070252,0.00014100802945904434,0.0001324350268987473,0.00012438402457822426,0.00011682202481703523,0.0001097200232228109,0.00010305002191065189,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844178279240928,3.2989591161410012,3.3043991525967917,3.3077792127927146,3.3092092672983804,3.3087692062060037,3.3065592646598816,3.302669326464335,3.2971893151601157,3.290199359258016,3.2817793687184653,3.2720093925793967,3.2609694401423135,3.2487194339434304,3.235349496205648,3.220899482568105,3.2054595152537027,3.189079542954763,3.171819508075714,3.153739551703135,3.134889562924703,3.115319569905599,3.0950796008110046,3.0742196639378867,3.0527796546618142,3.030799627304077,3.008329669634501,2.985399683316549,2.9620397090911865,2.9383097092310586,2.914219697316488,2.889809707800547,2.8650997479756675,2.8401297529538474,2.8149297634760537,2.789519786834717,2.763919770717621,2.738169769446055,2.7122697830200195,2.6862598061561584,2.660149792830149,2.633969803651174,2.6077197988828025,2.5814398527145386,2.555129826068878,2.5288098454475403,2.50249981880188,2.4761998454729715,2.4499298731486,2.4237098693847656,2.3975398540496826,2.3714398543039956,2.3454198837280273,2.3194898764292398,2.2936498721440635,2.267919898033142,2.2423099080721536,2.216809888680776,2.1914499402046204,2.1662199099858603,2.1411399245262146,2.1161999106407166,2.0914199153582254,2.0667998989423118,2.0423399011294046,2.0180599292119346,1.9939499199390411,1.970019926627477,1.9462699194749196,1.9227099517981212,1.8993299504121144,1.876149942477544,1.8531599442164104,1.8303799629211426,1.807789941628774,1.7853999435901642,1.7632099489370983,1.7412299712498982,1.7194599608580272,1.6978999475638072,1.676539957523346,1.6553899546464284,1.6344499588012695,1.6137199501196544,1.5931999683380127,1.5728899836540222,1.552029977242152,1.5306499898433685,1.509550005197525,1.488739977280299,1.4681899944941204,1.4479199945926666,1.4279200037320454,1.4081900020440419,1.388729989528656,1.369509994983673,1.3505499958992004,1.3318600058555603,1.3134199976921082,1.2952199975649517,1.277269999186198,1.259559988975525,1.2420999904473622,1.2248799900213878,1.2078799903392792,1.1911199887593586,1.1745899816354115,1.1582699815432231,1.1421899994214375,1.1263399918874104,1.1106899976730347,1.09525000055631,1.0800299843152363,1.065029998620351,1.050249993801117,1.0356499950091045,1.0212499996026356,1.0070499976476033,0.9930480072895685,0.9792510022719702,0.9656510055065155,0.9522250046332678,0.9389700045188268,0.9259050041437149,0.9130260000626246,0.9003310004870096,0.8878160019715627,0.8754800061384836,0.8633189996083578,0.8513309955596924,0.8395139972368876,0.8278450071811676,0.8163209954897562,0.8049609959125519,0.7937629967927933,0.7827220012744268,0.7718390027681986,0.7611089994510015,0.750530997912089,0.740102007985115,0.7298210014899572,0.7196850031614304,0.709691991408666,0.6998399943113327,0.6901270051797231,0.6805499990781149,0.6711089958747228,0.6617999921242396,0.6526219993829727,0.643574004371961,0.6346520036458969,0.6258560021718343,0.6171829998493195,0.6086120009422302,0.6001420070727667,0.5917900105317434,0.5835549930731455,0.5754350076119105,0.5674300044775009,0.5595359951257706,0.5517529944578806,0.5440779974063238,0.5365110039710999,0.5290490041176478,0.5216920028130213,0.5144369949897131,0.5072840054829916,0.5002300043900808,0.4932740007837613,0.4864159971475601,0.479653000831604,0.4729839985569318,0.46640900274117786,0.45992400248845416,0.4535300036271413,0.4472250019510587,0.44100700318813324,0.4348760023713112,0.4288300002614657,0.4228680009643237,0.4169890011350314,0.41119199991226196,0.40547500054041546,0.3998379980524381,0.39427900065978366,0.3887970025340716,0.38339100033044815,0.37806099901596707,0.3728039984901746,0.36762100209792453,0.36251000066598255,0.3574690024058024,0.3524990032116572,0.34759800136089325,0.3427650009592374,0.33799999952316284,0.33329999695221585,0.32866600155830383,0.32409700006246567,0.319591003159682,0.31514700253804523,0.3107660040259361,0.3064450000723203,0.3021850014726321,0.2979830006758372,0.2938399985432625,0.28975500414768857,0.28572699924310047,0.2817540019750595,0.27783699830373126,0.2739749997854233,0.27016599973042804,0.2664100006222725,0.2627059991161029,0.259053997695446,0.2554530029495557,0.2519010007381439,0.24839900185664496,0.24494599923491478,0.24154099822044373,0.23818299919366837,0.23487200091282526,0.23160699879129729,0.228388000279665,0.22521300117174783,0.22208200146754584,0.2189949986835321,0.21595100065072378,0.2129490002989769,0.20998899762829146,0.2070700004696846,0.20419200137257576,0.20135299985607466,0.19855400050679842,0.19579499835769335,0.19307300075888634,0.19038900112112364,0.18774299944440523,0.18513400107622147,0.18255999808510145,0.18002299840251604,0.17752100030581155,0.17505400131146112,0.1726210005581379,0.17022200177113214,0.16785699874162674,0.16552400092283884,0.16322400172551474,0.16095600028832754,0.158719003200531,0.15651400138934454,0.15433899809916815,0.15219500040014586,0.15007999911904335,0.14799500132600465,0.14593899995088577,0.14391099909941354,0.14191199963291487,0.1399409994482994,0.1379960005482038,0.13607899968822798,0.13418900221586227,0.13232499981919923,0.13048699870705605,0.12867399801810583,0.12688700233896574,0.12512500087420145,0.1233869989713033,0.12167299911379814,0.11998300005992253,0.11831600094834964,0.116672998915116,0.11505299992859364,0.11345500064392884,0.11187899919847648,0.11032499993840854,0.10879300038019817,0.10728200090428193,0.10579300113022327,0.10432300033668677,0.10287500048677127,0.10144600023825963,0.10003799945116043,0.09864849969744682,0.0972786998997132,0.0959280002862215,0.09459600038826466,0.09328260024388631,0.09198740124702454,0.09071020036935806,0.08945079892873764,0.08820889890193939,0.08698420040309429,0.08577660036583741,0.08458579952518146,0.08341150047878425,0.08225349957744281,0.08111160124341647,0.07998559934397538,0.07887530016402404,0.0777804007132848,0.07670069982608159,0.07563600006202857,0.07458609901368618,0.07355079986155033,0.07252980023622513,0.071523101379474,0.07053040092190106,0.06955140084028244,0.06858609989285469,0.0676341000944376,0.06669540020326774,0.06576980091631413,0.06485699986418088,0.06395680084824562,0.06306920014321804,0.06219390003631512,0.06133080025513967,0.060479700254897274,0.05964040042211612,0.058812800484399,0.057996599934995174,0.05719180001566807,0.05639819987118244,0.05561559988806645,0.05484379983196656,0.05408280001332363,0.053332400508224964,0.05259240077187618,0.051862699910998344,0.051143099864323936,0.050433400087058544,0.04973370023071766,0.049043700098991394,0.04836319945752621,0.04769220047940811,0.047030599787831306,0.046378099670012794,0.045734699815511703,0.04510019967953364,0.044474500231444836,0.043857499646643795,0.04324910013626019,0.04264909991373619,0.042057499599953495,0.041474099891881146,0.040898799585799374,0.040331399999558926,0.03977199954291185,0.03922030019263426,0.03867630008608103,0.038139800230662026,0.03761080000549555,0.03708909948666891,0.03657469991594553,0.03606740043809017,0.03556720012178024,0.03507390028486649,0.034587400034070015,0.03410770030071338,0.03363470019151767,0.033168199472129345,0.03270820031563441,0.0322545999661088,0.031807299703359604,0.031366200341532625,0.03093119990080595,0.03050230008860429,0.030079300049692392,0.029662099822113912,0.029250799988706905,0.02884520000467698,0.02844519990806778,0.02805080000932018,0.027661800384521484,0.027278199947128694,0.02690000009412567,0.02652700012549758,0.026159199886023998,0.02579649956896901,0.025438799833257992,0.0250860999027888,0.024738299970825512,0.024395299920191366,0.02405710006132722,0.023723500315099955,0.02339459986736377,0.02307030015314619,0.022750400006771088,0.02243500001107653,0.022124000048885744,0.021817299847801525,0.021514799911528826,0.02121649992962678,0.020922400212536257,0.02063239986697833,0.020346300055583317,0.020064299926161766,0.019786199865241844,0.019511900066087644,0.019241399907817442,0.01897470001131296,0.01871169979373614,0.01845230022445321,0.018196499751259882,0.017944299926360447,0.017695600011696417,0.01745030004531145,0.01720839987198512,0.01696990042303999,0.016734699718654156,0.016502699814736843,0.01627399989714225,0.01604850000391404,0.015826000055919092,0.015606700209900737,0.015390400076285005,0.015177099887902537,0.014966699993237853,0.014759299966196219,0.014554800000041723,0.014353099977597594,0.01415409993690749,0.013957999957104525,0.013764600036665797,0.013573799980804324,0.01338569998430709,0.013200200085217753,0.013017299973095456,0.01283690007403493,0.012658999999985099,0.012483599906166395,0.012310599985842904,0.012139999928573767,0.011971800044799844,0.01180589998451372,0.011642299980546037,0.011481000032896796,0.011321900024389228,0.011164999955023328,0.01101029998001953,0.010857800021767616,0.010707300001134476,0.010559000152473649,0.01041270000860095,0.010268399879957238,0.010126100076983372,0.009985839948058128,0.00984749011695385,0.00971104996278882,0.009576509861896435,0.009443830077846846,0.009312999900430441,0.009183969969550768,0.00905673997476697,0.008931269946818551,0.008807539862270156,0.008685519996409615,0.00856520002707839,0.008446540062626203,0.008329529936114946,0.008214140000442663,0.008100349999343356,0.007988140064602097,0.007877479928235212,0.007768360044186314,0.00766075006686151,0.007554630011630555,0.0074499800490836305,0.007346790051087737,0.007245020009577274,0.007144660029249887,0.007045700020777683,0.00694810994900763,0.006851870062140127,0.006756959987493853,0.006663370023791988,0.006571079992378752,0.006480059935711324,0.006390310047815244,0.006301800060706834,0.0062145200014735264,0.006128439990182717,0.006043560026834409,0.005959859932772815,0.005918299973321457};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261276324590047,0.41886203239361447,0.4108480264743169,0.4034990295767784,0.3960850238800049,0.3886220206816991,0.3811270197232564,0.37361301978429157,0.3660930171608925,0.35858002056678134,0.35108601798613864,0.34362001965443295,0.3361930176615715,0.32881401230891544,0.3214910129706065,0.3142320141196251,0.30704300850629807,0.2999310145775477,0.29290301352739334,0.2859620079398155,0.2791140079498291,0.27236101031303406,0.26570801188548404,0.2591560060779254,0.2527090050280094,0.2463690067330996,0.2401370070874691,0.23401600743333498,0.22800601025422415,0.2221080077191194,0.2163220060368379,0.21064900855223337,0.2050890065729618,0.19964300468564034,0.19430800651510557,0.18908600509166718,0.18397600452105203,0.17897800480326018,0.17409100383520126,0.16931200524171194,0.16464300453662872,0.1600810041030248,0.1556240034600099,0.15127300471067429,0.147025004029274,0.14287900303800902,0.13883300373951593,0.13488700365026793,0.13103800266981125,0.12728500242034593,0.1236250028014183,0.12005900343259175,0.11658300086855888,0.11319600294033687,0.10989600171645482,0.10668300340572993,0.10355500318109989,0.10050900218387444,0.09754380211234093,0.09465750182668368,0.09184850193560123,0.08911490129927795,0.08645640127360821,0.08387130064268906,0.08135690167546272,0.07891190114120643,0.07653480271498363,0.07422330106298129,0.0719759011020263,0.06979170193274815,0.0676693016042312,0.0656076017767191,0.06360460196932156,0.061658001194397606,0.059767000998059906,0.057930600829422474,0.05614690141131481,0.05441510087500016,0.05273440107703209,0.05110300052911043,0.04951910053690275,0.0479810011262695,0.04648820124566555,0.04504000054051479,0.043635000474750996,0.04227160010486841,0.04085710023840269,0.03939790030320486,0.037991199952860676,0.0366349999482433,0.035327499732375145,0.03406700026243925,0.03285180001209179,0.03168019993851582,0.03055060002952814,0.02946159973119696,0.028411599962661665,0.0273991998595496,0.02642319972316424,0.02548210012416045,0.0245746998116374,0.02369989998017748,0.02285629976540804,0.022042999664942425,0.021258700018127758,0.020502599887549877,0.01977339976777633,0.019070299963156383,0.01839239988476038,0.017738699913024902,0.017108399731417496,0.01650050018603603,0.01591439979771773,0.015349199995398521,0.01480420003645122,0.014278600070004662,0.013771800013879934,0.013283099979162216,0.012811799999326468,0.012357300069803992,0.011918999875585238,0.01149629995537301,0.011088700033724308,0.010695600028460225,0.01031660009175539,0.009950979923208555,0.00959842000156641,0.009258409884447852,0.008930499975879988,0.00861426000483334,0.008309270022436976,0.008015120091537634,0.007731429960889121,0.0074578299730395274,0.007193949927265446,0.006939440073134999,0.006693969985159735,0.006457209975148241,0.006228859963205953,0.006008619985853632,0.005796190002001822,0.005591289993996422,0.005393660006423791,0.005203029955737293,0.00501917003809164,0.004841820026437442,0.004670750039319198,0.004505750024691224,0.004346589945877592,0.004193060061273475,0.004044969954217474,0.003902130042357991,0.0037643300214161477,0.0036314200066650906,0.003503210008299599,0.003379530021144698,0.0032602199935354292,0.0031451399942549565,0.003034129971638322,0.002927030009838442,0.002823730018765976,0.00272407002436618,0.0026279399559522667,0.0025352099910378456,0.0024457399655754366,0.0023594400069365897,0.0022761899745091796,0.002195879972229401,0.002118400007020682,0.002043660012229035,0.0019715599773917347,0.0019019999987600993,0.0018349000116965424,0.0017701600154396147,0.0017077099861732374,0.0016474600027625759,0.0015893400025864441,0.0015332699792149167,0.0014791799864421289,0.0014269900081368785,0.0013766500051133335,0.0013280800194479525,0.0012812199905359496,0.0012360199956068147,0.001192410010844469,0.0011503400067643572,0.0011097599926870316,0.0010705999933027972,0.0010328299831598997,0.0009963890091360856,0.0009612349967937917,0.000927320991953214,0.000894603993704853,0.0008630410011392087,0.0008325910069591677,0.0008032159967115149,0.0007748770003672689,0.0007475390011677518,0.0007211650081444532,0.000695720998919569,0.000671174998084704,0.0006474949962769946,0.0006246509922978779,0.0006026129995007068,0.0005813529957473899,0.0005608419984734306,0.00054105499778719,0.0005219670031995823,0.0005035519910355409,0.0004857870007981546,0.00046864799757410464,0.0004521150015837823,0.0004361640045923802,0.00042077700588076067,0.00040593200295309845,0.0003916119967470877,0.0003777960058262882,0.0003644679915547992,0.0003516100041451864,0.0003392059952602722,0.0003272400038743702,0.0003156950018213441,0.0003045579990915333,0.00029381399751097587,0.00028344899813722196,0.0002734500012593344,0.0002638039998904181,0.0002544980015954934,0.0002455200022571565,0.00023685899941483513,0.00022850299986506192,0.0002204430008229489,0.00021266699938375191,0.00020516500080702826,0.00019792699822573923,0.00019094600308259638,0.00018420999913359992,0.0001777119978214614,0.00017144399923078404,0.00016539600013250796,0.0001595620002869206,0.00015393399856596565,0.0001485050015617162,0.00014326700087015828,0.00013821399867689857,0.00013333899914869107,0.00012863599962050407,0.00012410000090312678,0.00011972299944318365,0.00011550100073994447,0.0001114269998652162,0.00010749799973079159,0.00010370699904645637,5.047395037157306e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1796468098958,329.0759811401367,329.7769775390625,330.5079701741536,331.22797139485675,331.93697357177734,332.63497161865234,333.3099772135417,333.9479751586914,334.5489756266276,335.1149724324544,335.6449737548828,336.13997650146484,336.5999755859375,337.0249786376953,337.41497802734375,337.77098083496094,338.1089782714844,338.44297790527344,338.7739766438802,339.1029790242513,339.427978515625,339.750981648763,340.0709762573242,340.3889795939128,340.7029774983724,341.01597849527997,341.3229726155599,341.62398020426434,341.91897837320965,342.2079798380534,342.4899724324544,342.76597595214844,343.0359827677409,343.2999776204427,343.5579833984375,343.8099772135417,344.0569763183594,344.2999776204427,344.53998311360675,344.77697499593097,345.00897725423175,345.23898061116535,345.46497853597003,345.6869761149089,345.9059804280599,346.1219838460286,346.33597564697266,346.54797617594403,346.7579828898112,346.9679768880208,347.1759770711263,347.3829828898112,347.5879821777344,347.79297892252606,347.9959767659505,348.19697825113934,348.39798227945965,348.5969772338867,348.7959798177083,348.9929835001628,349.1889826456706,349.38297780354816,349.5769805908203,349.76998138427734,349.96098073323566,350.1509831746419,350.34197998046875,350.53397878011066,350.7279790242513,350.9239781697591,351.1209767659505,351.3199818929036,351.51998138427734,351.72197977701825,351.9259796142578,352.13097381591797,352.3379770914714,352.54398345947266,352.750981648763,352.9579798380534,353.16598256429035,353.37398020426434,353.5819803873698,353.78998311360675,353.9989827473958,354.2079772949219,354.4159876505534,354.62097930908203,354.823974609375,355.0229848225911,355.21997833251953,355.41398366292316,355.6059799194336,355.7949803670247,355.9809824625651,356.16398366292316,356.34497833251953,356.52298227945965,356.698979695638,356.8719838460286,357.04197947184247,357.20998128255206,357.375981648763,357.5389760335286,357.698979695638,357.8569793701172,358.01298268636066,358.16598256429035,358.3169809977214,358.46497853597003,358.61098225911456,358.7549794514974,358.89598083496094,359.03497823079425,359.17198181152344,359.3059819539388,359.43797810872394,359.56797790527344,359.6959864298503,359.8209762573242,359.94397735595703,360.0649820963542,360.1839828491211,360.30098215738934,360.41497802734375,360.5279795328776,360.63798268636066,360.74597930908203,360.8519821166992,360.95697530110675,361.0589828491211,361.15897878011066,361.2569859822591,361.3519795735677,361.44598388671875,361.5379816691081,361.62798563639325,361.71598052978516,361.802983601888,361.8869806925456,361.96898651123047,362.0489807128906,362.1279780069987,362.20398203531903,362.2789789835612,362.3519821166992,362.4229787190755,362.49197642008465,362.55898030598956,362.62497965494794,362.6889826456706,362.7499821980794,362.81097920735675,362.86898040771484,362.9259796142578,362.9809799194336,363.0339838663737,363.0849787394206,363.1349817911784,363.1829833984375,363.22998809814453,363.27398681640625,363.31698354085285,363.3589833577474,363.39898173014325,363.4369837443034,363.47297922770184,363.5079803466797,363.54098256429035,363.57297770182294,363.6029815673828,363.6319808959961,363.6589813232422,363.6839828491211,363.7079798380534,363.7309824625651,363.7519810994466,363.7709782918294,363.7889811197917,363.8059844970703,363.8209762573242,363.833984375,363.84598032633465,363.8569869995117,363.86598205566406,363.8739827473958,363.8799794514974,363.8849843343099,363.8889846801758,363.89098358154297,363.89198048909503,363.89098358154297,363.8899841308594,363.8869883219401,363.8819859822591,363.875981648763,363.86898040771484,363.86098225911456,363.8509826660156,363.83998616536456,363.8279800415039,363.8149820963542,363.7999776204427,363.7839813232422,363.7669855753581,363.7489827473958,363.729985555013,363.708979288737,363.6869837443034,363.66398366292316,363.63998158772785,363.61398061116535,363.5879847208659,363.5599822998047,363.5309778849284,363.5019810994466,363.47098541259766,363.43798573811847,363.4049809773763,363.37098439534503,363.3359832763672,363.2989857991536,363.26198323567706,363.22298431396484,363.1839828491211,363.14298248291016,363.1009826660156,363.0589777628581,363.0149866739909,362.96998087565106,362.92498270670575,362.8779780069987,362.8299840291341,362.78198496500653,362.7319793701172,362.68098704020184,362.6299819946289,362.5799814860026,362.5299784342448,362.479985555013,362.4309844970703,362.3819808959961,362.33398183186847,362.2849807739258,362.23798116048175,362.1899820963542,362.1429850260417,362.09698486328125,362.0499801635742,362.0039825439453,361.95898183186847,361.91298421223956,361.8689829508464,361.82398478190106,361.7799809773763,361.7359797159831,361.69298299153644,361.6489791870117,361.6069844563802,361.5639826456706,361.52198537190753,361.47998809814453,361.4389826456706,361.3979848225911,361.3569869995117,361.3159815470378,361.2759831746419,361.2359848022461,361.1969807942708,361.15698496500653,361.11798095703125,361.0799814860026,361.04098256429035,361.0029830932617,360.96598052978516,360.92798105875653,360.89098103841144,360.8539810180664,360.8169759114583,360.78098551432294,360.74498494466144,360.708984375,360.67398325602215,360.63898213704425,360.6039861043294,360.56898498535156,360.5349807739258,360.50097910563153,360.46697998046875,360.43298085530597,360.3999837239583,360.36698659261066,360.333984375,360.3019790649414,360.26898701985675,360.2369842529297,360.2059809366862,360.1739857991536,360.1429799397786,360.11198170979816,360.0809834798177,360.04998270670575,360.0199839274089,359.98998260498047,359.95998128255206,359.9309819539388,359.90098063151044,359.8719838460286,359.84297943115234,359.8139826456706,359.7859802246094,359.7579828898112,359.72998301188153,359.70198313395184,359.67398834228516,359.64698028564453,359.61998494466144,359.5929819742839,359.56598409016925,359.5399856567383,359.5129852294922,359.48698170979816,359.4609832763672,359.4359842936198,359.4099833170573,359.3849817911784,359.3599853515625,359.3349838256836,359.30997975667316,359.2859853108724,359.26097615559894,359.23697662353516,359.2129770914714,359.1889826456706,359.1659851074219,359.14198303222656,359.1189829508464,359.09598541259766,359.0729802449544,359.0509847005208,359.0279795328776,359.00598398844403,358.9839833577474,358.9619827270508,358.93998463948566,358.91898345947266,358.89698028564453,358.875981648763,358.85498046875,358.833979288737,358.81298065185547,358.79198201497394,358.77198537190753,358.7519836425781,358.7319819132487,358.7119827270508,358.69198354085285,358.67198181152344,358.6529795328776,358.6329854329427,358.61398061116535,358.59498087565106,358.5759785970052,358.5579833984375,358.5389862060547,358.51998647054035,358.5019836425781,358.4839833577474,358.46598561604816,358.44798787434894,358.4299850463867,358.4129816691081,358.39498647054035,358.3779830932617,358.3609848022461,358.34398396809894,358.3269856770833,358.3099848429362,358.2939809163411,358.2769775390625,358.260986328125,358.2439778645833,358.22798411051434,358.2119827270508,358.1959813435872,358.18098704020184,358.1649805704753,358.14998626708984,358.1339797973633,358.11898040771484,358.10398356119794,358.0889841715495,358.07398223876953,358.0589853922526,358.04398345947266,358.0299809773763,358.0159861246745,358.000981648763,357.9869842529297,357.97298431396484,357.958984375,357.94497934977215,357.9309819539388,357.91798400878906,357.9039840698242,357.89098103841144,357.8769810994466,357.8639831542969,357.8509775797526,357.8379821777344,357.8249816894531,357.8119837443034,357.7999852498372,357.78697967529297,357.7749837239583,357.7619806925456,357.7499821980794,357.7379862467448,357.72598520914715,357.71398162841797,357.7019907633464,357.68998463948566,357.67798105875653,357.6659851074219,357.6549809773763,357.64298248291016,357.6319834391276,357.62097930908203,357.6099853515625,357.5989812215169,357.5879847208659,357.57698313395184,357.5659866333008,357.5549825032552,357.5439809163411,357.5339813232422,357.52298227945965,357.51298268636066,357.5029805501302,357.4919789632161,357.4819844563802,357.47197977701825,357.4619827270508,357.4519856770833,357.4419809977214,357.43298594156903,357.42298380533856,357.4129816691081,357.4039789835612,357.3939844767253,357.3849843343099,357.37598419189453,357.3669840494792,357.3569819132487,357.3479817708333,357.33898162841797,357.3299814860026,357.3219807942708,357.31298573811847,357.3039805094401,357.2949854532878,357.28697967529297,357.2779820760091,357.26998647054035,357.2619806925456,357.2529805501302,357.24498494466144,357.23698170979816,357.22898356119794,357.22098032633465,357.21297963460285,357.2049789428711,357.19697825113934,357.18898518880206,357.1809844970703,357.17398325602215,357.16598256429035,357.1589838663737,357.1509831746419,357.14398193359375,357.13598378499347,357.1289825439453,357.1219787597656,357.11498006184894,357.11098225911456};
}

void set_concs_ssp126() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.338206727,8.948989877,8.559773027,8.170556177,7.781339327,7.505990086,7.230640845,6.955291605,6.679942364,6.404593123,6.129243882,5.853894641,5.578545401,5.30319616,5.027846919,4.943111815,4.858376711,4.773641606,4.688906502,4.604171398,4.519436294,4.434701189,4.349966085,4.265230981,4.180495877,4.123748115,4.067000354,4.010252593,3.953504831,3.89675707,3.840009308,3.783261547,3.726513786,3.669766024,3.613018263,3.58905045,3.565082638,3.541114825,3.517147013,3.4931792,3.469211387,3.445243575,3.421275762,3.39730795,3.373340137,3.350692966,3.328045794,3.305398623,3.282751452,3.26010428,3.237457109,3.214809938,3.192162767,3.169515595,3.146868424,3.107429479,3.067990533,3.028551588,2.989112643,2.949673698,2.910234752,2.870795807,2.831356862,2.791917916,2.752478971,2.724462356,2.69644574,2.668429125,2.640412509,2.612395894,2.584379278,2.556362663,2.528346047,2.500329432,2.472312816,2.447784241,2.423255665,2.39872709,2.374198515,2.349669939,2.325141364,2.300612788,2.276084213,2.251555637,2.227027062,2.21968139,2.212335718,2.204990046,2.197644374,2.190298702,2.182953029,2.175607357,2.168261685,2.160916013,2.153570341,2.146224669,2.138878997,2.131533325,2.124187653,2.116841981,2.109496309,2.102150637,2.094804965,2.087459293,2.080113621,2.072767949,2.065422277,2.058076605,2.050730932,2.04338526,2.036039588,2.028693916,2.021348244,2.014002572,2.0066569,1.999311228,1.991965556,1.984619884,1.977274212,1.96992854,1.962582868,1.955237196,1.947891524,1.940545852,1.93320018,1.925854508,1.918508835,1.911163163,1.903817491,1.896471819,1.889126147,1.881780475,1.874434803,1.867089131,1.859743459,1.852397787,1.845052115,1.837706443,1.830360771,1.823015099,1.815669427,1.808323755,1.800978083,1.79363241,1.786286738,1.778941066,1.771595394,1.764249722,1.75690405,1.749558378,1.742212706,1.734867034,1.727521362,1.72017569,1.712830018,1.705484346,1.698138674,1.690793002,1.68344733,1.676101658,1.668755986,1.661410313,1.654064641,1.646718969,1.639373297,1.632027625,1.624681953,1.617336281,1.609990609,1.602644937,1.595299265,1.587953593,1.580607921,1.573262249,1.565916577,1.558570905,1.551225233,1.543879561,1.536533889,1.529188216,1.521842544,1.514496872,1.5071512,1.499805528,1.492459856,1.485114184,1.477768512,1.47042284,1.463077168,1.455731496,1.448385824,1.441040152,1.43369448,1.426348808,1.419003136,1.411657464,1.404311791,1.396966119,1.389620447,1.382274775,1.374929103,1.367583431,1.360237759,1.352892087,1.345546415,1.338200743,1.330855071,1.323509399,1.316163727,1.308818055,1.301472383,1.294126711,1.286781039,1.279435367,1.272089694,1.264744022,1.25739835,1.250052678,1.242707006,1.235361334,1.228015662,1.22066999,1.213324318,1.205978646,1.198632974,1.191287302,1.18394163,1.176595958,1.169250286,1.161904614,1.154558942,1.14721327,1.139867597,1.132521925,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253,1.125176253};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,33.61734354,32.48866286,31.35998218,30.23130149,29.10262081,28.34780042,27.59298003,26.83815965,26.08333926,25.32851887,24.57369849,23.8188781,23.06405771,22.30923733,21.55441694,21.37858645,21.20275595,21.02692546,20.85109497,20.67526448,20.49943399,20.3236035,20.147773,19.97194251,19.79611202,19.63937385,19.48263567,19.3258975,19.16915933,19.01242116,18.85568298,18.69894481,18.54220664,18.38546846,18.22873029,18.10318622,17.97764215,17.85209808,17.72655401,17.60100995,17.47546588,17.34992181,17.22437774,17.09883367,16.9732896,16.93371939,16.89414919,16.85457899,16.81500878,16.77543858,16.73586837,16.69629817,16.65672796,16.61715776,16.57758756,16.495993,16.41439845,16.3328039,16.25120935,16.1696148,16.08802024,16.00642569,15.92483114,15.84323659,15.76164204,15.67102281,15.58040358,15.48978435,15.39916512,15.30854589,15.21792666,15.12730743,15.03668821,14.94606898,14.85544975,14.67867089,14.50189203,14.32511317,14.14833431,13.97155545,13.79477659,13.61799773,13.44121887,13.26444001,13.08766115,13.05577703,13.02389291,12.9920088,12.96012468,12.92824057,12.89635645,12.86447234,12.83258822,12.8007041,12.76881999,12.73693587,12.70505176,12.67316764,12.64128353,12.60939941,12.57751529,12.54563118,12.51374706,12.48186295,12.44997883,12.41809471,12.3862106,12.35432648,12.32244237,12.29055825,12.25867414,12.22679002,12.1949059,12.16302179,12.13113767,12.09925356,12.06736944,12.03548533,12.00360121,11.97171709,11.93983298,11.90794886,11.87606475,11.84418063,11.81229651,11.7804124,11.74852828,11.71664417,11.68476005,11.65287594,11.62099182,11.5891077,11.55722359,11.52533947,11.49345536,11.46157124,11.42968713,11.39780301,11.36591889,11.33403478,11.30215066,11.27026655,11.23838243,11.20649831,11.1746142,11.14273008,11.11084597,11.07896185,11.04707774,11.01519362,10.9833095,10.95142539,10.91954127,10.88765716,10.85577304,10.82388893,10.79200481,10.76012069,10.72823658,10.69635246,10.66446835,10.63258423,10.60070011,10.568816,10.53693188,10.50504777,10.47316365,10.44127954,10.40939542,10.3775113,10.34562719,10.31374307,10.28185896,10.24997484,10.21809073,10.18620661,10.15432249,10.12243838,10.09055426,10.05867015,10.02678603,9.994901915,9.963017799,9.931133683,9.899249567,9.867365451,9.835481336,9.80359722,9.771713104,9.739828988,9.707944873,9.676060757,9.644176641,9.612292525,9.580408409,9.548524294,9.516640178,9.484756062,9.452871946,9.42098783,9.389103715,9.357219599,9.325335483,9.293451367,9.261567251,9.229683136,9.19779902,9.165914904,9.134030788,9.102146672,9.070262557,9.038378441,9.006494325,8.974610209,8.942726094,8.910841978,8.878957862,8.847073746,8.81518963,8.783305515,8.751421399,8.719537283,8.687653167,8.655769051,8.623884936,8.59200082,8.560116704,8.528232588,8.496348472,8.464464357,8.432580241,8.400696125,8.368812009,8.336927893,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778,8.305043778};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,96.64325364,92.5153403,88.38742696,84.25951362,80.13160028,77.29213385,74.45266742,71.61320099,68.77373456,65.93426813,63.0948017,60.25533527,57.41586883,54.5764024,51.73693597,50.07145859,48.40598121,46.74050382,45.07502644,43.40954905,41.74407167,40.07859429,38.4131169,36.74763952,35.08216214,34.24700653,33.41185093,32.57669533,31.74153973,30.90638413,30.07122853,29.23607292,28.40091732,27.56576172,26.73060612,26.26157406,25.79254201,25.32350995,24.85447789,24.38544584,23.91641378,23.44738172,22.97834967,22.50931761,22.04028555,21.61108163,21.1818777,20.75267377,20.32346985,19.89426592,19.465062,19.03585807,18.60665414,18.17745022,17.74824629,17.29951826,16.85079023,16.4020622,15.95333417,15.50460614,15.05587811,14.60715008,14.15842205,13.70969402,13.26096599,12.96517507,12.66938414,12.37359322,12.0778023,11.78201138,11.48622045,11.19042953,10.89463861,10.59884769,10.30305676,10.07978586,9.856514952,9.633244047,9.409973141,9.186702236,8.96343133,8.740160425,8.51688952,8.293618614,8.070347709,8.025499519,7.980651329,7.93580314,7.89095495,7.84610676,7.80125857,7.75641038,7.711562191,7.666714001,7.621865811,7.577017621,7.532169431,7.487321242,7.442473052,7.397624862,7.352776672,7.307928482,7.263080293,7.218232103,7.173383913,7.128535723,7.083687533,7.038839344,6.993991154,6.949142964,6.904294774,6.859446585,6.814598395,6.769750205,6.724902015,6.680053825,6.635205636,6.590357446,6.545509256,6.500661066,6.455812876,6.410964687,6.366116497,6.321268307,6.276420117,6.231571927,6.186723738,6.141875548,6.097027358,6.052179168,6.007330978,5.962482789,5.917634599,5.872786409,5.827938219,5.783090029,5.73824184,5.69339365,5.64854546,5.60369727,5.55884908,5.514000891,5.469152701,5.424304511,5.379456321,5.334608131,5.289759942,5.244911752,5.200063562,5.155215372,5.110367182,5.065518993,5.020670803,4.975822613,4.930974423,4.886126234,4.841278044,4.796429854,4.751581664,4.706733474,4.661885285,4.617037095,4.572188905,4.527340715,4.482492525,4.437644336,4.392796146,4.347947956,4.303099766,4.258251576,4.213403387,4.168555197,4.123707007,4.078858817,4.034010627,3.989162438,3.944314248,3.899466058,3.854617868,3.809769678,3.764921489,3.720073299,3.675225109,3.630376919,3.585528729,3.54068054,3.49583235,3.45098416,3.40613597,3.36128778,3.316439591,3.271591401,3.226743211,3.181895021,3.137046831,3.092198642,3.047350452,3.002502262,2.957654072,2.912805883,2.867957693,2.823109503,2.778261313,2.733413123,2.688564934,2.643716744,2.598868554,2.554020364,2.509172174,2.464323985,2.419475795,2.374627605,2.329779415,2.284931225,2.240083036,2.195234846,2.150386656,2.105538466,2.060690276,2.015842087,1.970993897,1.926145707,1.881297517,1.836449327,1.791601138,1.746752948,1.701904758,1.657056568,1.612208378,1.567360189,1.522511999,1.477663809,1.432815619,1.387967429,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924,1.34311924};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,153.3040865,151.0877229,148.8713594,146.6549959,144.4386323,140.9453103,137.4519883,133.9586663,130.4653443,126.9720223,123.4787003,119.9853783,116.4920563,112.9987343,109.5054123,107.8275733,106.1497344,104.4718955,102.7940565,101.1162176,99.43837868,97.76053975,96.08270082,94.40486189,92.72702295,90.90211626,89.07720958,87.25230289,85.4273962,83.60248951,81.77758282,79.95267614,78.12776945,76.30286276,74.47795607,73.75576614,73.03357621,72.31138628,71.58919636,70.86700643,70.1448165,69.42262657,68.70043664,67.97824671,67.25605678,66.45885097,65.66164516,64.86443934,64.06723353,63.27002772,62.47282191,61.6756161,60.87841028,60.08120447,59.28399866,58.33283404,57.38166943,56.43050481,55.47934019,54.52817558,53.57701096,52.62584634,51.67468172,50.72351711,49.77235249,49.24827449,48.72419649,48.20011849,47.67604048,47.15196248,46.62788448,46.10380648,45.57972848,45.05565048,44.53157248,44.2014119,43.87125132,43.54109074,43.21093016,42.88076958,42.55060901,42.22044843,41.89028785,41.56012727,41.22996669,41.07408394,40.91820118,40.76231843,40.60643568,40.45055292,40.29467017,40.13878741,39.98290466,39.82702191,39.67113915,39.5152564,39.35937365,39.20349089,39.04760814,38.89172539,38.73584263,38.57995988,38.42407712,38.26819437,38.11231162,37.95642886,37.80054611,37.64466336,37.4887806,37.33289785,37.17701509,37.02113234,36.86524959,36.70936683,36.55348408,36.39760133,36.24171857,36.08583582,35.92995306,35.77407031,35.61818756,35.4623048,35.30642205,35.1505393,34.99465654,34.83877379,34.68289104,34.52700828,34.37112553,34.21524277,34.05936002,33.90347727,33.74759451,33.59171176,33.43582901,33.27994625,33.1240635,32.96818074,32.81229799,32.65641524,32.50053248,32.34464973,32.18876698,32.03288422,31.87700147,31.72111872,31.56523596,31.40935321,31.25347045,31.0975877,30.94170495,30.78582219,30.62993944,30.47405669,30.31817393,30.16229118,30.00640842,29.85052567,29.69464292,29.53876016,29.38287741,29.22699466,29.0711119,28.91522915,28.75934639,28.60346364,28.44758089,28.29169813,28.13581538,27.97993263,27.82404987,27.66816712,27.51228437,27.35640161,27.20051886,27.0446361,26.88875335,26.7328706,26.57698784,26.42110509,26.26522234,26.10933958,25.95345683,25.79757407,25.64169132,25.48580857,25.32992581,25.17404306,25.01816031,24.86227755,24.7063948,24.55051204,24.39462929,24.23874654,24.08286378,23.92698103,23.77109828,23.61521552,23.45933277,23.30345002,23.14756726,22.99168451,22.83580175,22.679919,22.52403625,22.36815349,22.21227074,22.05638799,21.90050523,21.74462248,21.58873972,21.43285697,21.27697422,21.12109146,20.96520871,20.80932596,20.6534432,20.49756045,20.3416777,20.18579494,20.02991219,19.87402943,19.71814668,19.56226393,19.40638117,19.25049842,19.09461567,18.93873291,18.78285016,18.6269674,18.47108465,18.3152019,18.15931914,18.00343639,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364,17.84755364};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,65.25153841,65.22337369,65.19520897,65.16704424,65.13887952,65.10155154,65.06422356,65.02689558,64.9895676,64.95223962,64.91491164,64.87758366,64.84025568,64.8029277,64.76559972,64.72153196,64.67746419,64.63339643,64.58932867,64.54526091,64.50119314,64.45712538,64.41305762,64.36898985,64.32492209,64.31294744,64.30097279,64.28899814,64.27702349,64.26504884,64.25307419,64.24109954,64.22912489,64.21715024,64.20517559,64.13985286,64.07453013,64.0092074,63.94388467,63.87856194,63.81323922,63.74791649,63.68259376,63.61727103,63.5519483,63.5345075,63.5170667,63.4996259,63.4821851,63.4647443,63.44730351,63.42986271,63.41242191,63.39498111,63.37754031,63.39843991,63.4193395,63.4402391,63.4611387,63.4820383,63.50293789,63.52383749,63.54473709,63.56563669,63.58653628,63.61542611,63.64431593,63.67320576,63.70209558,63.73098541,63.75987523,63.78876506,63.81765488,63.84654471,63.87543453,63.77882506,63.68221558,63.5856061,63.48899663,63.39238715,63.29577767,63.19916819,63.10255872,63.00594924,62.90933976,62.80801687,62.70669399,62.6053711,62.50404821,62.40272533,62.30140244,62.20007955,62.09875667,61.99743378,61.89611089,61.794788,61.69346512,61.59214223,61.49081934,61.38949646,61.28817357,61.18685068,61.08552779,60.98420491,60.88288202,60.78155913,60.68023625,60.57891336,60.47759047,60.37626758,60.2749447,60.17362181,60.07229892,59.97097604,59.86965315,59.76833026,59.66700737,59.56568449,59.4643616,59.36303871,59.26171583,59.16039294,59.05907005,58.95774716,58.85642428,58.75510139,58.6537785,58.55245562,58.45113273,58.34980984,58.24848695,58.14716407,58.04584118,57.94451829,57.84319541,57.74187252,57.64054963,57.53922674,57.43790386,57.33658097,57.23525808,57.1339352,57.03261231,56.93128942,56.82996653,56.72864365,56.62732076,56.52599787,56.42467499,56.3233521,56.22202921,56.12070632,56.01938344,55.91806055,55.81673766,55.71541478,55.61409189,55.512769,55.41144611,55.31012323,55.20880034,55.10747745,55.00615457,54.90483168,54.80350879,54.7021859,54.60086302,54.49954013,54.39821724,54.29689436,54.19557147,54.09424858,53.99292569,53.89160281,53.79027992,53.68895703,53.58763415,53.48631126,53.38498837,53.28366548,53.1823426,53.08101971,52.97969682,52.87837394,52.77705105,52.67572816,52.57440528,52.47308239,52.3717595,52.27043661,52.16911373,52.06779084,51.96646795,51.86514507,51.76382218,51.66249929,51.5611764,51.45985352,51.35853063,51.25720774,51.15588486,51.05456197,50.95323908,50.85191619,50.75059331,50.64927042,50.54794753,50.44662465,50.34530176,50.24397887,50.14265598,50.0413331,49.94001021,49.83868732,49.73736444,49.63604155,49.53471866,49.43339577,49.33207289,49.23075,49.12942711,49.02810423,48.92678134,48.82545845,48.72413556,48.62281268,48.52148979,48.4201669,48.31884402,48.21752113,48.11619824,48.01487535,47.91355247,47.81222958,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669,47.71090669};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,219.5876666,211.9305139,204.2733612,196.6162084,188.9590557,182.8678432,176.7766307,170.6854182,164.5942057,158.5029932,152.4117807,146.3205682,140.2293557,134.1381432,128.0469307,127.045183,126.0434352,125.0416875,124.0399398,123.038192,122.0364443,121.0346965,120.0329488,119.0312011,118.0294533,117.1389414,116.2484295,115.3579176,114.4674057,113.5768938,112.686382,111.7958701,110.9053582,110.0148463,109.1243344,108.2697243,107.4151143,106.5605043,105.7058943,104.8512842,103.9966742,103.1420642,102.2874541,101.4328441,100.5782341,99.54598461,98.51373515,97.48148569,96.44923623,95.41698677,94.38473731,93.35248785,92.32023839,91.28798893,90.25573947,88.97441406,87.69308865,86.41176324,85.13043783,83.84911242,82.56778701,81.2864616,80.00513619,78.72381078,77.44248537,76.73775092,76.03301646,75.328282,74.62354755,73.91881309,73.21407864,72.50934418,71.80460972,71.09987527,70.39514081,69.58613236,68.77712391,67.96811546,67.15910701,66.35009855,65.5410901,64.73208165,63.9230732,63.11406475,62.3050563,62.15111785,61.9971794,61.84324095,61.68930251,61.53536406,61.38142561,61.22748716,61.07354871,60.91961026,60.76567182,60.61173337,60.45779492,60.30385647,60.14991802,59.99597958,59.84204113,59.68810268,59.53416423,59.38022578,59.22628734,59.07234889,58.91841044,58.76447199,58.61053354,58.4565951,58.30265665,58.1487182,57.99477975,57.8408413,57.68690285,57.53296441,57.37902596,57.22508751,57.07114906,56.91721061,56.76327217,56.60933372,56.45539527,56.30145682,56.14751837,55.99357993,55.83964148,55.68570303,55.53176458,55.37782613,55.22388769,55.06994924,54.91601079,54.76207234,54.60813389,54.45419544,54.300257,54.14631855,53.9923801,53.83844165,53.6845032,53.53056476,53.37662631,53.22268786,53.06874941,52.91481096,52.76087252,52.60693407,52.45299562,52.29905717,52.14511872,51.99118028,51.83724183,51.68330338,51.52936493,51.37542648,51.22148803,51.06754959,50.91361114,50.75967269,50.60573424,50.45179579,50.29785735,50.1439189,49.98998045,49.836042,49.68210355,49.52816511,49.37422666,49.22028821,49.06634976,48.91241131,48.75847287,48.60453442,48.45059597,48.29665752,48.14271907,47.98878062,47.83484218,47.68090373,47.52696528,47.37302683,47.21908838,47.06514994,46.91121149,46.75727304,46.60333459,46.44939614,46.2954577,46.14151925,45.9875808,45.83364235,45.6797039,45.52576546,45.37182701,45.21788856,45.06395011,44.91001166,44.75607321,44.60213477,44.44819632,44.29425787,44.14031942,43.98638097,43.83244253,43.67850408,43.52456563,43.37062718,43.21668873,43.06275029,42.90881184,42.75487339,42.60093494,42.44699649,42.29305805,42.1391196,41.98518115,41.8312427,41.67730425,41.5233658,41.36942736,41.21548891,41.06155046,40.90761201,40.75367356,40.59973512,40.44579667,40.29185822,40.13791977,39.98398132,39.83004288,39.67610443,39.52216598,39.36822753,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908,39.21428908};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9610799153645,1851.5939229329426,1872.2987263997395,1881.1304016113281,1886.4098714192708,1888.3897603352864,1887.2996724446614,1883.9396667480469,1879.0495503743489,1872.7494812011719,1865.1294453938801,1856.2993672688801,1846.3393249511719,1835.3292643229167,1823.3492228190105,1810.4691772460938,1796.7591451009114,1782.5391642252605,1768.0991617838542,1753.4791361490886,1738.6691385904949,1723.7191365559895,1708.619120279948,1693.3891092936199,1678.0491027832031,1662.6090901692708,1647.0791320800781,1631.6891581217449,1616.649169921875,1601.939188639323,1587.5291951497395,1573.3992106119792,1559.5392150878906,1545.929219563802,1532.5392456054688,1519.3592427571614,1506.3792419433594,1493.6592915852864,1481.249287923177,1469.1393229166667,1457.309326171875,1445.7293294270833,1434.3993326822917,1423.2893575032551,1412.3893737792969,1401.6893819173176,1391.1793823242188,1380.7793884277344,1370.4193623860676,1360.0993754069011,1349.829366048177,1339.589375813802,1329.389383951823,1319.2193908691406,1309.089375813802,1298.9893697102864,1288.9193725585938,1278.849365234375,1268.7293701171875,1258.5693461100261,1248.369364420573,1238.1493631998699,1227.8893432617188,1217.609354654948,1207.3093566894531,1196.9893290201824,1186.6593729654949,1176.5894266764324,1167.0394592285156,1157.9794820149739,1149.3694966634114,1141.1795145670574,1133.3795369466145,1125.9395548502605,1118.829569498698,1112.0295817057292,1105.5096028645833,1099.2596130371094,1093.2396138509114,1087.4396158854167,1081.8496398925781,1076.4396260579426,1071.2096659342449,1066.129659016927,1061.2096659342449,1056.4096577962239,1051.7896931966145,1047.4697265625,1043.5097554524739,1039.8997497558594,1036.5797729492188,1033.519795735677,1030.6997985839844,1028.089808146159,1025.6698252360027,1023.4098103841146,1021.309824625651,1019.3398284912109,1017.4898376464844,1015.7498372395834,1014.1098429361979,1012.5598449707031,1011.0798543294271,1009.6698557535807,1008.3198547363281,1007.0298512776693,1005.7798716227213,1004.5798695882162,1003.4098612467448,1002.2798716227213,1001.1798604329427,1000.0998687744141,999.0488739013672,998.0168660481771,997.0018717447916,996.0028788248698,995.0178782145182,994.0448710123698,993.0828704833984,992.1288706461588,991.1838785807291,990.2448781331381,989.3118794759115,988.3838755289713,987.4598693847656,986.5388793945312,985.6218668619791,984.7058715820312,983.7918701171875,982.879872639974,981.9678649902344,981.0548706054688,980.1428680419922,979.2288665771484,978.3138783772787,977.3978627522787,976.4788767496744,975.5578664143881,974.6338755289713,973.7078704833984,972.7788696289062,971.8458658854166,970.9108632405599,969.9718678792318,969.0298665364584,968.0838623046875,967.1348775227865,966.182861328125,965.2268625895182,964.2678629557291,963.3048655192057,962.3378601074219,961.3678690592448,960.3928731282552,959.4158630371094,958.4338633219401,957.4478607177734,956.4588673909506,955.4658559163412,954.4688669840494,953.4678599039713,952.4628499348959,951.4548594156901,950.4418640136719,949.4248606363932,948.4038594563802,947.3788604736328,946.349853515625,945.3168538411459,944.2798563639323,943.2378540039062,942.1928660074869,941.1458587646484,940.1008504231771,939.0568644205729,938.0138498942057,936.9718526204427,935.9308522542318,934.8888600667318,933.8478546142578,932.8068542480469,931.7648468017578,930.7238566080729,929.6818542480469,928.6398569742838,927.5978597005209,926.5558522542318,925.5138549804688,924.4718627929688,923.4288533528646,922.3858489990234,921.3428497314453,920.2998555501302,919.2568562825521,918.2128499348959,917.1688537597656,916.1248423258463,915.0808461507162,914.0358581542969,912.9908548990885,911.9458465576172,910.9008534749349,909.8548533121744,908.808848063151,907.7628479003906,906.7168375651041,905.6698557535807,904.6228485107422,903.5748545328776,902.5278574625651,901.4798482259115,900.4318491617838,899.3828430175781,898.3338470458984,897.2848459879557,896.2348429361979,895.1848500569662,894.1338551839193,893.0838470458984,892.0328521728516,890.9808553059896,889.9288482666016,888.8768412272135,887.8238525390625,886.7708485921224,885.7178446451823,884.6638437906901,883.6098581949869,882.5548451741537,881.5008392333984,880.4448394775391,879.3888448079427,878.3328399658203,877.276845296224,876.2188364664713,875.1618398030599,874.1038462320963,873.1008656819662,872.1988779703776,871.3888753255209,870.661865234375,870.0098724365234,869.4238789876302,868.8988850911459,868.4268951416016,868.0038909912109,867.6248931884766,867.2848866780599,866.9798940022787,866.7058868408203,866.4608968098959,866.2418975830078,866.0448913574219,865.868896484375,865.7118988037109,865.5698954264323,865.4439036051432,865.3308970133463,865.2299092610677,865.1398976643881,865.0589040120443,864.9869079589844,864.9219055175781,864.8638966878256,864.8129069010416,864.7669118245443,864.7259114583334,864.6889038085938,864.6558990478516,864.6269073486328,864.6008961995443,864.576904296875,864.555898030599,864.5379079182943,864.5209045410156,864.5059102376302,864.4919026692709,864.4798940022787,864.4689025878906,864.4589131673177,864.4499104817709,864.4409027099609,864.4338938395182,864.4269104003906,864.4199015299479,864.4138997395834,864.4079081217448,864.4019012451172,864.3969014485677,864.3919067382812,864.3869069417318,864.3819122314453,864.3769073486328,864.3719126383463,864.3669077555338,864.3619028727213,864.3568979899088,864.3519032796224,864.3459014892578,864.3409016927084,864.3349049886068,864.3289082845052,864.3229115804037,864.3168996175131,864.3109079996744,864.3038940429688,864.2968953450521,864.2898966471354,864.2819061279297,864.2739003499349,864.2659098307291,864.2579040527344,864.2489064534506,864.2399037679037,864.2298940022787,864.2199147542318,864.2099049886068,864.1998901367188,864.1889038085938,864.1769053141276,864.1649119059244,864.1529083251953,864.1409098307291,864.1279093424479,864.1139068603516,864.0998992919922,864.0859018961588,864.0709075927734,864.0549062093099,864.0389099121094,864.0229034423828,864.0059000651041,863.9879048665365,863.9698944091797,863.9509023030599,863.931894938151,863.9119059244791,863.8919016520182,863.8709004720052,863.8489023844401,863.8259023030599,863.8029022216797,863.7789052327474,863.7549031575521,863.7289021809896,863.7029113769531,863.6768951416016,863.6489054361979,863.6229044596354,863.5969034830729,863.5729115804037,863.5529073079427,863.5349070231119,863.5199025472006,863.5059000651041,863.4949035644531,863.4859110514323,863.4779001871744,863.4718933105469,863.4669036865234,863.462900797526,863.4609018961588,863.4589080810547,863.4579060872396,863.4579111735026,863.4579010009766,863.4589029947916,863.4598999023438,863.4618988037109,863.4649047851562,863.4679158528646,863.4709014892578,863.4739023844401,863.4779001871744,863.4819030761719,863.4859059651693,863.4898986816406,863.4939117431641,863.4989115397135,863.5029042561849,863.5079040527344,863.5129089355469,863.5179036458334,863.5229034423828,863.5279083251953,863.5329081217448,863.5379079182943,863.5429077148438,863.5479024251302,863.5529073079427,863.5579121907552,863.5638987223307,863.5689137776693,863.5739034016927,863.5789031982422,863.5838979085287,863.5889078776041,863.5949096679688,863.5999094645182,863.6049143473307,863.6099039713541,863.6149088541666,863.6199137369791,863.6249084472656,863.6299031575521,863.6349131266276,863.6399078369141,863.6449076334635,863.64990234375,863.6549021402994,863.6599070231119,863.6638997395834,863.6689046223959,863.6739095052084,863.6789143880209,863.6828969319662,863.6879119873047,863.6929117838541,863.6969197591146,863.7019093831381,863.7068990071615,863.7109171549479,863.7159016927084,863.7199096679688,863.7249043782552,863.7289021809896,863.7339070638021,863.7379150390625,863.7429046630859,863.7469228108724,863.7509053548177,863.7559102376302,863.7599029541016,863.7639109293619,863.7679036458334,863.7729085286459,863.7769063313802,863.7809041341146,863.7849070231119,863.7889048258463,863.7929026285807,863.7969004313151,863.8009033203125,863.805908203125,863.8099009195963,863.8129069010416,863.816904703776,863.8209025065104,863.8249104817709,863.8289031982422,863.8329111735026,863.836903889974,863.8408966064453,863.8449045817057,863.847900390625,863.8519032796224,863.8559061686198,863.8599039713541,863.8629048665365,863.8668975830078,863.8709106445312,863.8739064534506,863.8779093424479,863.8819020589193,863.8849080403646,863.888916015625,863.8919067382812,863.8959045410156,863.8989054361979,863.9029083251953,863.9059143066406,863.909901936849,863.9129079182943,863.9159088134766,863.919911702474,863.9229024251302,863.9269002278646,863.9299062093099,863.9329071044922,863.9359130859375,863.9399058024088,863.9429016113281,863.9459075927734,863.9489084879557,863.9529062906901,863.9539082845052};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9491551717122,403.1169611612956,405.75196075439453,408.5919596354167,411.4169642130534,414.2319615681966,417.0419642130534,419.80896250406903,422.4989700317383,425.1199645996094,427.67396545410156,430.16595967610675,432.5979639689128,434.9739685058594,437.29496510823566,439.56396484375,441.78096262613934,443.92896779378253,445.9899622599284,447.9689636230469,449.86596934000653,451.68496958414715,453.42596944173175,455.0919698079427,456.68396759033203,458.20097096761066,459.64697265625,461.0189743041992,462.3149693806966,463.53597259521484,464.68297322591144,465.7549794514974,466.7529780069987,467.67798105875653,468.5299809773763,469.3099772135417,470.01897684733075,470.66298421223956,471.24998474121094,471.7789840698242,472.250981648763,472.6649856567383,473.02198282877606,473.32198842366535,473.56398518880206,473.74998728434247,473.87798563639325,473.958989461263,473.9989878336589,473.9989878336589,473.95699310302734,473.87299092610675,473.74698638916016,473.57799530029297,473.364995320638,473.1099904378255,472.8109944661458,472.45799509684247,472.04099527994794,471.5609944661458,471.0179951985677,470.4139989217122,469.74900309244794,469.0219955444336,468.2360026041667,467.38999938964844,466.48399861653644,465.53599802652997,464.5610071818034,463.55800374348956,462.5270029703776,461.4660059611003,460.37500762939453,459.2550099690755,458.10400390625,456.9240036010742,455.71300506591797,454.50200907389325,453.31900787353516,452.1600112915039,451.02400461832684,449.9090092976888,448.812006632487,447.7340087890625,446.67200978597003,445.62500254313153,444.5920054117839,443.5780029296875,442.5860112508138,441.614008585612,440.66200002034503,439.72900390625,438.81300099690753,437.91400655110675,437.03100840250653,436.1630045572917,435.3110071818034,434.47300720214844,433.6500015258789,432.84000396728516,432.0440038045247,431.26100667317706,430.4910024007161,429.73400624593097,428.9880065917969,428.2540054321289,427.5320053100586,426.82100677490234,426.12000783284503,425.4310048421224,424.7510019938151,424.0820058186849,423.42300669352215,422.7740020751953,422.1340077718099,421.50400797526044,420.8820037841797,420.27000681559247,419.66700236002606,419.07200876871747,418.48500569661456,417.9070002237956,417.33700307210285,416.77500915527344,416.22100830078125,415.67500559488934,415.1360117594401,414.6120020548503,414.1080042521159,413.625,413.16100056966144,412.7150014241536,412.28800710042316,411.87800852457684,411.4850082397461,411.10900115966797,410.74900309244794,410.4020055135091,410.06300354003906,409.7340037027995,409.4130045572917,409.10200754801434,408.7990036010742,408.5060068766276,408.22100830078125,407.9449996948242,407.6790008544922,407.42000579833984,407.17100524902344,406.9310073852539,406.6990000406901,406.4750035603841,406.260004679362,406.0540008544922,405.8560028076172,405.66700490315753,405.48600514729816,405.31300354003906,405.1490020751953,404.99299875895184,404.84400177001953,404.7040023803711,404.573003133138,404.4490000406901,404.33300018310547,404.2250035603841,404.12500254313153,404.0329996744792,403.948003133138,403.8709971110026,403.802001953125,403.7410024007161,403.68700154622394,403.64200083414715,403.60400136311847,403.5750020345052,403.5529963175456,403.5320002237956,403.5049997965495,403.47399648030597,403.43800099690753,403.3989995320638,403.35599517822266,403.30999755859375,403.26199595133465,403.2109959920247,403.15800221761066,403.1030019124349,403.04600016276044,402.98800404866535,402.9280064900716,402.8659947713216,402.8039957682292,402.73999786376953,402.6759999593099,402.60999298095703,402.54400126139325,402.4769999186198,402.40900166829425,402.34100341796875,402.2720006306966,402.2020034790039,402.1319986979167,402.06199900309247,401.99099985758465,401.9199981689453,401.8479970296224,401.7759958902995,401.7039972941081,401.6320037841797,401.55899810791016,401.4860026041667,401.4129918416341,401.33999888102215,401.2669957478841,401.1929982503255,401.11999766031903,401.04600016276044,400.9719950358073,400.8979975382487,400.8250045776367,400.7509994506836,400.676996866862,400.6030044555664,400.5289993286133,400.4540023803711,400.3799997965495,400.30599721272785,400.2319971720378,400.1579996744792,400.08399963378906,400.00999704996747,399.93599700927734,399.8619969685872,399.7879994710286,399.71400197347003,399.63999938964844,399.56599680582684,399.4920018513997,399.41800181070965,399.34400177001953,399.26900482177734,399.1940002441406,399.11800384521484,399.04199981689453,398.9660008748372,398.88999938964844,398.81300099690753,398.7370020548503,398.66000111897785,398.583002726237,398.50599670410156,398.4289957682292,398.3519973754883,398.2749964396159,398.198003133138,398.12200419108075,398.04500071207684,397.9679997762044,397.8919957478841,397.81599680582684,397.73900095621747,397.66299692789715,397.5870005289714,397.51200103759766,397.4359995524089,397.3609975179036,397.2849985758464,397.2100016276042,397.13500213623047,397.0609995524089,396.9859975179036,396.91200002034503,396.83800252278644,396.7639973958333,396.6899998982747,396.61599985758465,396.54300181070965,396.46900431315106,396.39599863688153,396.32300059000653,396.2510019938151,396.17799886067706,396.1060028076172,396.0339991251628,395.96199798583984,395.88999938964844,395.8179982503255,395.7469991048177,395.6760025024414,395.603998819987,395.5329945882161,395.46299743652344,395.3919982910156,395.32200113932294,395.2510019938151,395.18099721272785,395.11100006103516,395.04200236002606,394.97200266520184,394.9020004272461,394.83299763997394,394.7639973958333,394.6949996948242,394.6260019938151,394.55699920654297,394.48900349934894,394.4199981689453,394.3519999186198,394.2839991251628,394.2160008748372,394.1480026245117,394.0800043741862,394.01300048828125,393.9449996948242,393.8780008951823,393.8099950154622,393.74299875895184,393.6759974161784,393.60999806722003,393.54300181070965,393.4760055541992,393.40999603271484,393.3429997762044,393.27699788411456,393.2110010782878,393.1449966430664,393.07899475097656,393.0130030314128,392.9469960530599,392.8809992472331,392.8159993489583,392.75,392.68499755859375,392.61999766031903,392.5540008544922,392.48899841308594,392.4240036010742,392.3590037027995,392.2939987182617,392.228998819987,392.1639989217122,392.09999593098956,392.03499603271484,391.9699986775716,391.90600331624347,391.8410008748372,391.77699788411456,391.7120005289714,391.6480026245117,391.58399709065753,391.5199940999349,391.4560012817383,391.3929951985677,391.32899983723956,391.26599884033203,391.2029978434245,391.13999938964844,391.07800038655597,391.01500193277997,390.9529978434245,390.89100138346356,390.8290023803711,390.76700083414715,390.70599873860675,390.6439971923828,390.58300018310547,390.5220031738281,390.4610010782878,390.4010009765625,390.34000396728516,390.27999623616535,390.21900177001953,390.1589991251628,390.0989939371745,390.03999582926434,389.9800033569336,389.92100016276044,389.86100006103516,389.802001953125,389.7429936726888,389.68400319417316,389.625,389.56699625651044,389.5080032348633,389.4499969482422,389.39200083414715,389.33399963378906,389.27599843343097,389.21799723307294,389.16100056966144,389.1029993693034,389.04600016276044,388.98899841308594,388.93199666341144,388.87500254313153,388.8179982503255,388.76200103759766,388.7050018310547,388.6489944458008,388.59300231933594,388.53599548339844,388.48000081380206,388.4249979654948,388.3690007527669,388.31299591064453,388.25799560546875,388.2020009358724,388.1470006306966,388.09199778238934,388.03700002034503,387.98199971516925,387.92799886067706,387.87300364176434,387.81900278727215,387.76399993896484,387.7099965413411,387.65599822998047,387.6019973754883,387.5480016072591,387.49400329589844,387.4409993489583,387.38700103759766,387.3340021769206,387.2799987792969,387.2269999186198,387.1739959716797,387.1209996541341,387.0679982503255,387.01599884033203,386.96300506591797,386.91099802652997,386.8580017089844,386.8060048421224,386.7540003458659,386.7020009358724,386.6499964396159,386.5980046590169,386.54600016276044,386.49499766031903,386.44300587972003,386.3919957478841,386.3400065104167,386.28900146484375,386.23800404866535,386.18699645996094,386.13600158691406,386.0860010782878,386.0349985758464,385.98399607340497,385.9340006510417,385.88400014241535,385.83300018310547,385.7829996744792,385.73299916585285,385.68299865722656,385.6329981486003,385.58399709065753,385.5339991251628,385.48400115966797,385.4350001017253,385.38600158691406,385.3360010782878,385.28699747721356,385.2380015055339,385.1890004475911,385.14000447591144,385.0920003255208,385.04300181070965,384.9950002034505,384.9459991455078,384.8979975382487,384.84900156656903,384.8009999593099,384.7530008951823,384.7050018310547,384.6570053100586,384.61000061035156,384.56199645996094,384.51399993896484,384.46699778238934,384.4189987182617,384.3719991048177,384.3249994913737,384.2779998779297,384.2540003458659
};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.75432316462199,21.18809429804484,23.52409283320109,27.811991850535076,32.773390452067055,38.385589599609375,44.62618923187256,51.080489794413246,57.3484894434611,63.43618965148926,69.34959030151367,75.09428850809734,80.67549006144206,86.0982894897461,91.36758995056152,96.48788897196452,101.46398989359538,105.95599174499512,109.63899167378743,112.53799184163411,114.67899386088054,116.08599535624187,116.7829958597819,116.7949956258138,116.14299710591634,114.84999783833821,112.93599764506023,110.72399711608887,108.52499898274739,106.33699798583984,104.1619987487793,101.99799919128418,99.84729894002278,97.70809745788574,95.58059946695964,93.46469942728679,91.36029815673828,89.29739952087402,87.30519930521648,85.38169924418132,83.52519798278809,81.73379834493001,80.0055980682373,78.33899943033855,76.73209889729817,75.18329811096191,73.69089825948079,72.25379880269368,70.8707987467448,69.54029846191406,68.26069831848145,67.03029886881511,65.84759839375813,64.71109835306804,63.61929893493652,62.57079823811849,61.56419849395752,60.597798347473145,59.66989835103353,58.779098192850746,57.92429828643799,57.10419845581055,56.317697842915855,55.563697814941406,54.84109878540039,54.148898442586265,53.48599783579508,52.84829807281494,52.23229853312174,51.6372979482015,51.06309827168783,50.50909837086996,49.97489802042643,49.45999813079834,48.96399815877279,48.486398696899414,48.026698430379234,47.57979869842529,47.14069811503092,46.70919863382975,46.28519852956136,45.868598302205406,45.45909849802653,45.056698163350426,44.66109848022461,44.272298177083336,43.890698750813804,43.51629765828451,43.148098627726235,42.78579870859782,42.429198265075684,42.07819811503092,41.732398668924965,41.39179833730062,41.05599816640218,40.72489802042643,40.39839839935303,40.07609844207764,39.75809860229492,39.44399833679199,39.133798917134605,38.82719866434733,38.52419884999593,38.224598248799644,37.92819849650065,37.63499895731608,37.34479840596517,37.05749924977621,36.772898038228355,36.49099890391032,36.21169853210449,35.934798876444496,35.6601988474528,35.387898445129395,35.117698669433594,34.8496987024943,34.58359877268473,34.31939888000488,34.05699857076009,33.79639879862467,33.53749815622965,33.28019905090332,33.024398485819496,32.7700990041097,32.51719856262207,32.265598932902016,32.01539866129557,31.766398906707764,31.518598874409992,31.27189874649048,31.026299158732098,30.781699180603027,30.53809881210327,30.295499006907146,30.053698539733887,29.812798659006756,29.572699069976807,29.333399136861164,29.094699064890545,28.856798966725666,28.61949888865153,28.382898966471355,28.146799246470135,27.911298910776775,27.67639907201131,27.441899299621582,27.20789909362793,26.974399089813232,26.741299152374268,26.508599122365315,26.276298840840656,26.044299125671387,25.81269915898641,25.581399122873943,25.350399335225422,25.119699478149414,24.889199256896973,24.65899912516276,24.428999265034992,24.199299176534016,23.969699223836262,23.740299065907795,23.511099815368652,23.28209940592448,23.053199291229248,22.82439931233724,22.595699469248455,22.367199420928955,22.13879919052124,21.910399119059246,21.682199160257976,21.453999201456707,21.22589906056722,20.997799237569172,20.76979939142863,20.541799545288086,20.313799381256104,20.085899511973064,19.857999324798584,19.630099137624104,19.402199268341064,19.174299399058025,18.946399370829266,18.718499183654785,18.490599473317463,18.262699604034424,18.034799257914226,17.806899706522625,17.57889970143636,17.350999355316162,17.122999668121338,16.894999504089355,16.666999499003094,16.438899358113606,16.21079953511556,15.982699553171793,15.754499594370523,15.526299635569254,15.298099756240845,15.069799661636353,14.841399669647217,14.613099495569864,14.384599606196085,14.15619969367981,13.92769972483317,13.69909954071045,13.470499674479166,13.24179975191752,13.012999773025513,12.784199794133505,12.555399815241495,12.326499780019125,12.09749968846639,11.868399699529013,11.639299790064493,11.410099744796753,11.180899937947592,10.951599677403768,10.7221999168396,10.492699782053629,10.26319988568624,10.033599774042765,9.803939819335938,9.574199994405111,9.344369967778524,9.114479939142862,8.884499788284302,8.654449939727783,8.424320062001547,8.194109996159872,7.963819940884908,7.733449935913086,7.503000020980835,7.272469997406006,7.041849931081136,6.811149954795837,6.5803699890772505,6.353519996007283,6.134510000546773,5.923050045967102,5.718889991442363,5.521780053774516,5.3314599593480425,5.147719979286194,4.970309933026631,4.79902998606364,4.633649945259094,4.473989923795064,4.319830020268758,4.170989910761516,4.02728005250295,3.8885300159454346,3.754570027192434,3.625229994455973,3.500349998474121,3.37977002064387,3.263360023498535,3.1509600083033242,3.042430023352305,2.9376500050226846,2.8364800016085305,2.7387999892234802,2.6444899837176004,2.5534300009409585,2.4655099908510842,2.380620022614797,2.298650006453196,2.219509998957316,2.1431000034014382,2.0693300366401672,1.9980900088946025,1.9293099840482075,1.8628999988238018,1.7987800041834514,1.7368700007597606,1.6770899991194408,1.6193699836730957,1.5636399984359741,1.5098299880822499,1.457880010207494,1.4077100058396657,1.3592700064182281,1.3124999801317851,1.2673499981562297,1.2237399816513062,1.1816399991512299,1.1409899989763896,1.1017399827639263,1.0638400117556255,1.0272499918937683,0.9919120023647944,0.9577940007050832,0.9248519986867905,0.8930430064598719,0.8623290012280146,0.8326729983091354,0.8040380030870438,0.776388997832934,0.749690999587377,0.7239130089680353,0.6990220000346502,0.6749870032072067,0.6517799894014994,0.6293710023164749,0.6077340046564738,0.5868410021066666,0.5666670054197311,0.5471879988908768,0.5283779998620352,0.5102159976959229,0.49267899990081787,0.47574499497811,0.45939400295416516,0.44360500077406567,0.4283600002527237,0.41363900403181714,0.3994239990909894,0.3856989989678065,0.3724449997146924,0.359646995862325,0.34728999932607013,0.33535699794689816,0.3238350028793017,0.3127090036869049,0.30196599662303925,0.2915919969479243,0.28157499929269153,0.27190200487772626,0.26256199926137924,0.2535429981847604,0.2448350004851818,0.23642500241597494,0.22830499957005182,0.22046400234103203,0.21289200087388357,0.20558099945386252,0.19852100064357123,0.19170300165812174,0.18512000143527985,0.1787640005350113,0.17262599989771843,0.16669800008336702,0.1609749992688497,0.15544799839456877,0.1501110022266706,0.14495699976881346,0.13998099913199744,0.13517600173751512,0.13053500031431517,0.12605399948855242,0.12172699843843778,0.1175490003079176,0.11351399930814902,0.10961799944440524,0.10585600013534228,0.10222299893697102,0.09871469934781392,0.09532700044413407,0.09205560013651848,0.0888966005295515,0.08584610062340896,0.08290040058394273,0.08005579995612304,0.07730890065431595,0.0746564008295536,0.07209489991267522,0.06962139966587226,0.06723289998869102,0.06492629957695802,0.06269899910936753,0.06054809999962648,0.058471099783976875,0.056465400072435536,0.05452849995344877,0.05265810061246157,0.050851999782025814,0.04910779992739359,0.047423500257233776,0.04579710060109695,0.04422639962285757,0.042709700452784695,0.04124499981602033,0.039830599601070084,0.03846479952335358,0.037145799957215786,0.03587199902782837,0.034642000372211136,0.03345419963200887,0.03230719951291879,0.031199499654273193,0.030129799929757912,0.029096899864574272,0.028099299874156713,0.027136000028500955,0.026205800008028746,0.025307499803602695,0.0244398998717467,0.02360220005114873,0.022793200022230547,0.02201190001020829,0.021257400047034025,0.02052879969899853,0.019825200084596872,0.01914580011119445,0.018489600159227848,0.017855999991297722,0.017244099794576567,0.01665310002863407,0.016082499952365954,0.015531399985775352,0.014999199969073137,0.014485200013344487,0.013988899920756618,0.013509600035225352,0.013046700041741133,0.012599699897691607,0.012167999986559153,0.011751200072467327,0.011348600033670664,0.01095979994473358,0.01058430007348458,0.01022180006839335,0.0098716098194321,0.009533469875653585,0.009206909919157624,0.008891549970333775,0.008586999960243702,0.008292889998604855,0.00800885003991425,0.007734560019647081,0.007469659981628259,0.007213850001183649,0.006966800002070765,0.006728210020810366,0.006497810012660921,0.006275299975338082,0.006060409980515639,0.005852890006887416,0.005652480021429558,0.005458930041640997,0.005272020003758371,0.005091509975803395,0.004917189983340601,0.004748839923801522,0.004586259989688794,0.004429240012541413,0.004277609948379298,0.004131170028510193,0.003989750053733587,0.0038531699877542755,0.003721269992335389,0.0035938899770068624,0.003470870006519059,0.003352070013837268,0.003237340017221868,0.003126529996128132,0.0030195199651643634,0.0029161799854288497,0.0028163700092894337,0.002719979966059327,0.0026269000178823867,0.0025369999542211494,0.002450179987742255,0.002366329989551256,0.0022853600094094872,0.0022071599572276077,0.002131629987464597,0.002058690006379038,0.0019882499861220517,0.0019202200055588037,0.001854520000051707,0.0017910700116772205,0.001729789995200311,0.001670609994713838,0.0016134599961029987,0.0015582600026391447,0.0015049500313277047,0.001453470002161339,0.0014037400057228904,0.0013557299971580505,0.001309350006825601,0.0012645599975561102,0.0012213099786701302,0.0011795299942605197,0.0011391899994729708,0.0011193699901923537};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76761627197266,90.27675183614095,96.23087374369304,101.43001619974773,106.7502810160319,112.17746416727702,117.69952138264973,122.82365481058757,127.09444363911946,130.5714079538981,133.31042098999023,135.36251322428384,136.77465947469076,137.59087117513022,137.8511225382487,137.59545262654623,136.8567911783854,135.54394658406576,133.56903966267905,130.97923024495444,127.82047462463379,124.13376998901367,119.95612080891927,115.32451248168945,110.27196820576985,104.82941563924153,99.02628898620605,93.23452186584473,87.79827245076497,82.69278780619304,77.89510536193848,73.38408215840657,69.13963826497395,65.14306767781575,61.37717469533285,57.82555739084879,54.473225911458336,51.332021395365395,48.41342544555664,45.70229848225912,43.184556325276695,40.84709548950195,38.67761961619059,36.66452725728353,34.79702091217041,33.06500085194906,31.459068457285564,29.972227732340496,28.597576936086018,27.327115217844646,26.15364424387614,25.069963455200195,24.06977415084839,23.146977106730144,22.296172936757404,21.51206111907959,20.789743264516193,20.126322428385418,19.5185964902242,18.96266523996989,18.454628944396973,17.99098777770996,17.568442503611248,17.183993021647137,16.834739685058594,16.51818307240804,16.231823126475017,15.972257932027182,15.736389001210531,15.522618611653646,15.329546133677164,15.155771732330322,14.999995628992716,14.860918045043945,14.737438599268595,14.62845778465271,14.532975832621256,14.446184476216635,14.363488912582397,14.284795125325521,14.209599097569784,14.138004620869955,14.069507916768393,14.004112799962362,13.941615978876749,13.881820122400919,13.825024286905924,13.768923282623291,13.710920413335165,13.651118040084839,13.589615821838379,13.526613791783651,13.462212085723877,13.396510283152262,13.32960875829061,13.261507193247477,13.192305644353231,13.122204542160034,13.051203091939291,12.979301850001017,12.906600952148438,12.833200057347616,12.759099006652832,12.684298435846964,12.608997265497843,12.532996654510498,12.45659605662028,12.379595120747885,12.302194595336914,12.224294106165567,12.146093527475992,12.067392985026041,11.98839251200358,11.908991893132528,11.829291661580404,11.749291261037191,11.668990850448608,11.588390429814657,11.507490078608194,11.426389694213867,11.345089515050253,11.26348908742269,11.181688865025839,11.099688450495401,11.017488320668539,10.935188213984171,10.852587779362997,10.769887606302897,10.686987241109213,10.60388700167338,10.520686944325766,10.437286694844564,10.353686332702637,10.269986232121786,10.186185995737711,10.102185805638632,10.018085718154907,9.93375539779663,9.849345286687216,9.764795144399008,9.680104811986288,9.595284700393677,9.510334571202597,9.425264279047648,9.340064207712809,9.254743973414103,9.169313907623291,9.08375358581543,8.998093446095785,8.912313540776571,8.826423168182373,8.740423123041788,8.654322862625122,8.568112850189209,8.481802701950073,8.395382563273111,8.30887246131897,8.222262144088745,8.135552167892456,8.048742095629374,7.9618518352508545,7.874861756960551,7.787781596183777,7.700611511866252,7.613351424535115,7.526001254717509,7.438571174939473,7.351061065991719,7.2634609540303545,7.175780773162842,7.088010668754578,7.000170588493347,6.912240544954936,6.824240326881409,6.736160198847453,6.648000160853068,6.559770107269287,6.47146999835968,6.383089900016785,6.294639786084493,6.206119616826375,6.117539644241333,6.028889497121175,5.9401793877283735,5.851399302482605,5.762569149335225,5.673679192860921,5.584739089012146,5.495738943417867,5.406688928604126,5.317588885625203,5.228438814481099,5.139238715171814,5.049988667170207,4.960688551266988,4.871338526407878,4.781948526700337,4.6925084590911865,4.603018323580424,4.513488332430522,4.423918167750041,4.334298173586528,4.244638125101726,4.154928008715312,4.065178016821544,3.975388010342916,3.885557850201925,3.7956777811050415,3.705757757027944,3.615797678629557,3.525797645250956,3.4357575376828513,3.345667521158854,3.2555474837621055,3.1653773387273154,3.0751673579216003,2.984927256902059,2.8946272134780884,2.8042971889177957,2.713927149772644,2.6235170364379883,2.533066987991333,2.4425669511159263,2.3520369132359824,2.261456867059072,2.1708468198776245,2.0801867246627808,1.9894966582457225,1.8987566033999126,1.8079765637715657,1.7171564996242523,1.626296450694402,1.535396416982015,1.4444663226604462,1.3534863491853077,1.262466053167979,1.171396404504776,1.0837330718835194,1.0026426762342453,0.9276123692591985,0.8582029591004053,0.7939887990554174,0.734582190712293,0.679623082280159,0.6287775486707687,0.5817375977834066,0.5382192780574163,0.49795758972565335,0.4607095917065938,0.42625028640031815,0.3943687056501706,0.36487287034591037,0.3375847985347112,0.3123385086655617,0.28898101548353833,0.26737132916847867,0.24737847596406937,0.22888145968317986,0.21176829809943834,0.19593599438667297,0.18128656720121702,0.16773402442534766,0.1551943669716517,0.1435936118165652,0.1328597590327263,0.12292882551749547,0.11374081112444401,0.10523972287774086,0.09737436597545941,0.09009704552590847,0.08336396825810273,0.07713423545161883,0.07137035330136617,0.06603732518851757,0.06110305432230234,0.05653764307498932,0.052313496048251786,0.048405115182201065,0.04478880235304435,0.04144286115964254,0.03834699311604103,0.0354824997484684,0.03283208360274633,0.030379746419688065,0.028110589366406202,0.026011114474385977,0.024068422615528107,0.022270915564149618,0.02060779354845484,0.019068858431031305,0.017644910607486963,0.016327351952592533,0.01510818263826271,0.013980103501429161,0.012936315188805262,0.011970518700157603,0.011076814339806637,0.010249802842736244,0.009484664847453436,0.00877663066300253,0.00812148085484902,0.007515255788651605,0.006954305727655689,0.006435241356181602,0.005954932848302026,0.005510490387678146,0.005099234442847471,0.004718685212234656,0.00436655276765426,0.0040406977059319615,0.003739180004534622,0.0034601698668363192,0.003201987458548198,0.0029630730471884212,0.0027419967227615416,0.002537418583718439,0.002348108838001887,0.0021729376361084483,0.0020108349757113806,0.0018608310007645439,0.0017220158382163693,0.0015935696040590603,0.0014747023039186995,0.0013647040565653394,0.0012629149617472042,0.001168725061385582,0.0010815643763635308,0.0010009029792854562,0.000926257964844505,0.0008571833556440348,0.000793262190806369,0.0007341105228988454,0.0006793703796574846,0.0006287137997181466,0.0005818358040414751,0.0005384554485014329,0.0004983097363340979,0.0004611587113079925,0.0004267783830679643,0.0003949627935071476,0.0003655199349547426,0.0003382718544647408,0.0003130565431395856,0.00028972204017918557,0.0002681263479947423,0.0002481414849171415,0.0002296474643420273,0.00021253129186031097,0.00019669198566892496,0.00018203355284640566,0.00016846800281200558,0.0001559133427993705,0.0001442945843640094,0.00013354273566316502,0.00012359179891063832,0.00011438278246108287,0.00010586069341419109,9.797303452311705e-05,9.067361618993648e-05,8.391823697214325e-05,7.766630551486742e-05,7.188032335155488e-05,6.652549685289462e-05,6.156982423514516e-05,5.6983415258097615e-05,5.273876892412469e-05,4.881038815559199e-05,4.5174776460044086e-05,4.181003532721661e-05,3.8696068562179185e-05,3.5814076606281255e-05,3.3146761173460014e-05,3.0678224599493355e-05,2.839356905800135e-05,2.627909452712629e-05,2.4322203747336364e-05,2.2510996889953578e-05,2.083477617513078e-05,1.9283441815787228e-05,1.7847595245257253e-05,1.6518737083970336e-05,1.5288868326024385e-05,1.4150589777273126e-05,1.3097002238282585e-05,1.2122006486000222e-05,1.1219502615252471e-05,1.0384291802741549e-05,9.611294368975601e-06,8.895830812131559e-06,8.233641589564892e-06,7.620766761344082e-06,7.053527421400456e-06,6.5285234237914365e-06,6.042605302051622e-06,5.592873321802472e-06,5.176617757266892e-06,4.7913587953492725e-06,4.434776845603968e-06,4.1047421746043256e-06,3.7992747555411674e-06,3.516554916889921e-06,3.2548728275590597e-06,3.0126686851872364e-06,2.7885025891312884e-06,2.5810146932296143e-06,2.3889752280107737e-06,2.2112241708782676e-06,2.0467017710264677e-06,1.894427972122988e-06,1.753492995248962e-06,1.623036913163863e-06,1.5022898101809308e-06,1.3905317454524873e-06,1.2870927624438384e-06,1.1913529836723076e-06,1.1027324262613547e-06,1.0207011390169403e-06,9.447812724753627e-07,8.745087569650423e-07,8.094636948878057e-07,7.492591199328066e-07,6.935330579456908e-07,6.419525580743842e-07,5.942106563831354e-07,5.500193651641894e-07,5.091157220249443e-07,4.712557668540285e-07,4.362115030668671e-07,4.0377396478182465e-07,3.7374915962118394e-07,3.459581279230406e-07,3.202338708282089e-07,2.9642340848567983e-07,2.7438376074921206e-07,2.539829324632592e-07,2.350999478058687e-07,2.1762080966899097e-07,2.0144153249172328e-07,1.8646613024012973e-07,1.726036060745173e-07,1.597729758865777e-07,1.478952403507113e-07,1.3690141405694098e-07,1.2672549705901778e-07,1.1730550160867399e-07,1.0858542983290438e-07,5.9415752910278265e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.742900371551514,19.401511510213215,20.754316488901775,23.168818950653076,25.909821033477783,28.970422744750977,32.3437229792277,35.839722633361816,39.27202288309733,42.64202308654785,45.950822830200195,49.1996234258016,52.38952382405599,55.521623293558754,58.596923828125,61.616323153177895,64.58072153727214,67.31981976826985,69.66631825764973,71.62801615397136,73.21251360575359,74.42741266886394,75.27990976969402,75.77740859985352,75.92700703938802,75.73570378621419,75.2104040781657,74.51120440165202,73.79490534464519,73.06200345357259,72.3130054473877,71.54830423990886,70.76840273539226,69.97360229492188,69.16440327962239,68.34110323588054,67.50410270690918,66.66990343729655,65.85480244954427,65.0584036509196,64.28060372670491,63.52110322316488,62.77960332234701,62.05590311686198,61.34970315297445,60.66070302327474,59.988802909851074,59.33430322011312,58.697503089904785,58.07820415496826,57.476003328959145,56.890703201293945,56.32180372873942,55.76910368601481,55.23230393727621,54.71110407511393,54.20510387420654,53.713903745015465,53.23660405476888,52.773003896077476,52.322903633117676,51.885903676350914,51.46190325419108,51.0504035949707,50.651403745015465,50.264503479003906,49.889403661092125,49.5239044825236,49.16580359141032,48.81510384877523,48.471704165140785,48.1357037226359,47.807003339131676,47.48560460408529,47.171403566996254,46.86440372467041,46.56460380554199,46.26910432179769,45.97560437520345,45.68380387624105,45.394003550211586,45.10600344340006,44.820003827412926,44.53590393066406,44.25370407104492,43.97340361277262,43.69550323486328,43.41990407307943,43.146203676859535,42.874403635660805,42.604403495788574,42.33620389302572,42.06970373789469,41.804903984069824,41.54180367787679,41.28020350138346,41.020203590393066,40.76170349121094,40.50470288594564,40.24910322825114,39.99490292867025,39.742003440856934,39.490502993265785,39.24030303955078,38.99130312601725,38.743502934773765,38.49690310160319,38.25140349070231,38.007003466288246,37.763803799947105,37.521602948506676,37.28040281931559,37.04020341237386,36.80100313822428,36.562703132629395,36.325402895609535,36.08890247344971,35.853302637736,35.6185032526652,35.384602864583336,35.15140279134115,34.91900221506754,34.68740304311117,34.45650291442871,34.22630214691162,33.99680233001709,33.76790301005045,33.53980255126953,33.31220277150472,33.08520253499349,32.85880343119303,32.633002281188965,32.40780226389567,32.18310356140137,31.958802382151287,31.735102653503418,31.51190249125163,31.28910239537557,31.066802660624187,30.844902515411377,30.6234024365743,30.402302424112957,30.181602478027344,29.961202144622803,29.741302490234375,29.5217022895813,29.302401860555012,29.08340247472127,28.864701906840008,28.64640204111735,28.42830228805542,28.21050198872884,27.99300193786621,27.775701840718586,27.558702150980633,27.341902097066242,27.12530215581258,26.90900166829427,26.692902088165283,26.47690200805664,26.261201699574787,26.045601844787598,25.830201466878254,25.615001837412517,25.400002002716064,25.18510166803996,24.97030194600423,24.755701541900635,24.54120175043742,24.32690159479777,24.11260159810384,23.89850155512492,23.68450180689494,23.470601399739582,23.256701628367107,23.04300133387248,22.82940133412679,22.615801334381104,22.40230131149292,22.18890158335368,21.975501537322998,21.76220115025838,21.54900137583415,21.335801283518474,21.122701327006023,20.909601370493572,20.696601072947185,20.483601252237957,20.270700931549072,20.057801246643066,19.845001220703125,19.63210105895996,19.41940100987752,19.20660098393758,18.99390109380086,18.781200885772705,18.568500836690266,18.35590108235677,18.143200874328613,17.930601119995117,17.718000888824463,17.50540081659953,17.292901039123535,17.08030064900716,16.867700894673664,16.655200640360516,16.4426007270813,16.230100631713867,16.017500797907513,15.80500070254008,15.592400550842285,15.379900693893433,15.167300462722778,14.954700390497843,14.74220069249471,14.529600540796915,14.316900491714478,14.104300498962402,13.891700347264608,13.679000536600748,13.46630048751831,13.253600279490152,13.040900389353434,12.828200340270996,12.615400155385336,12.402600208918253,12.189800341924032,11.976900259653727,11.764000097910563,11.551100174585978,11.338200012842814,11.125200112660727,10.912200212478638,10.699100097020468,10.486000140508017,10.272900104522705,10.059699853261312,9.848780075709024,9.642269929250082,9.44009002049764,9.242159922917685,9.048379818598429,8.858679930369059,8.672960042953491,8.491140127182007,8.313140074412027,8.138879934946695,7.968280037244161,7.801259954770406,7.637749989827474,7.477669994036357,7.32095996538798,7.167529980341594,7.017329970995585,6.870279947916667,6.726320068041484,6.5853800773620605,6.447400013605754,6.312310020128886,6.180059949556987,6.050589958826701,5.923840006192525,5.799739996592204,5.678249994913737,5.559309999148051,5.442869941393535,5.328869978586833,5.217260003089905,5.1079899072647095,5.001020034154256,4.896289944648743,4.793749968210856,4.6933700243632,4.595100045204163,4.498880068461101,4.404689947764079,4.312459985415141,4.2221799691518145,4.133780042330424,4.047250032424927,3.9625200033187866,3.8795699874560037,3.798359990119934,3.7188599904378257,3.6410200198491416,3.564809958140055,3.4902000029881797,3.4171600143114724,3.34564999739329,3.275630017121633,3.2070800065994263,3.1399700045585632,3.0742699901262918,3.0099400083223977,2.946969985961914,2.8853099743525186,2.824940005938212,2.76584001382192,2.707979996999105,2.65132999420166,2.5958599845568338,2.5415600339571633,2.4884000023206077,2.4363500277201333,2.3853900035222373,2.3355000217755637,2.286649982134501,2.238830049832662,2.192010005315145,2.1461700399716697,2.1012800534566245,2.0573399861653647,2.0143199960390725,1.972199986378352,1.9309700230757396,1.8905900120735168,1.851060003042221,1.812359978755315,1.7744700014591217,1.7373799979686737,1.7010599970817566,1.665499985218048,1.630680004755656,1.5965899924437206,1.5632200141747792,1.5305499931176503,1.4985599915186565,1.467230002085368,1.436570018529892,1.406550019979477,1.3771500090758007,1.3483699957529705,1.320190002520879,1.2926100293795268,1.2655999958515167,1.2391500075658162,1.2132599751154582,1.18791002035141,1.1630900005499523,1.1387900014718373,1.1149999996026356,1.0916999975840251,1.0688999891281128,1.0465700129667919,1.0247000058492024,1.0032999863227208,0.982343003153801,0.9618240048487982,0.9417339960734049,0.9220650096734365,0.9028069972991943,0.883951003352801,0.865489994486173,0.8474150002002716,0.8297190020481745,0.8123920013507208,0.7954270044962565,0.7788180063168207,0.7625549932320913,0.7466329981883367,0.7310430059830347,0.7157799949248632,0.7008349994818369,0.6862040062745413,0.6718770017226537,0.6578510105609894,0.6441180060307184,0.6306709895531336,0.6175060023864111,0.6046160062154134,0.5919949958721796,0.5796390076478323,0.5675399998823801,0.5556939939657847,0.544095998009046,0.5327400068442026,0.5216219971577326,0.5107359985510508,0.5000769992669424,0.4896409983436267,0.47942399481932324,0.4694190000494321,0.4596239998936653,0.45003299911816913,0.4406430001060168,0.431448998550574,0.42244700094064075,0.413632998863856,0.40500300129254657,0.39655299733082455,0.3882799992958705,0.3801800012588501,0.372248999774456,0.3644840021928151,0.3568800017237663,0.3494359999895096,0.34214700013399124,0.3350100020567576,0.3280229965845744,0.3211810017625491,0.3144819959998131,0.3079229990641276,0.3015010009209315,0.2952130014697711,0.28905700147151947,0.2830279966195424,0.277126004298528,0.2713470011949539,0.2656890004873276,0.2601489971081416,0.25472400337457657,0.24941299855709076,0.24421199783682823,0.23912099997202554,0.23413500065604845,0.2292530002693335,0.22447399919231734,0.21979399770498276,0.21521200115482012,0.21072500199079514,0.2063320018351078,0.2020310014486313,0.1978200003504753,0.19369600092371306,0.1896589994430542,0.18570500115553537,0.1818350007136663,0.17804500088095665,0.17433400079607964,0.17069999997814497,0.16714299966891608,0.16365900014837584,0.16024800017476082,0.15690900012850761,0.15363899866739908,0.1504369986553987,0.14730200171470642,0.14423299953341484,0.1412270007034143,0.138284998635451,0.13540299981832504,0.13258200014630953,0.1298189995189508,0.12711499879757562,0.12446600012481213,0.12187300063669682,0.11933399985233943,0.11684799939393997,0.11441399902105331,0.11202999949455261,0.10969600019355615,0.10741099901497364,0.10517399944365025,0.10298299913605054,0.10083799995481968,0.09873730068405469,0.09668069953719775,0.09466699945429961,0.09269519957403342,0.09076459954182307,0.08887420035898685,0.08702330042918523,0.0852109007537365,0.08343630035718282,0.0816987007856369,0.07999739982187748,0.07833149967094262,0.07670029997825623,0.07510310038924217,0.07353929926951726,0.07200800130764644,0.07050859866042931,0.06904050086935361,0.06760299888749917,0.0661954004317522,0.06481720010439555,0.06346769941349824,0.062146399480601154,0.06085260026156902,0.05958570043245951,0.05834520018349091,0.05713059970488151,0.055941300156215824,0.054776799865067005,0.05363649999101957,0.05307239977022012};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473431666692098,7.644614855448405,7.7002211809158325,7.7662161986033125,7.8350830078125,7.902770320574443,7.9675196806589765,7.917144219080607,7.693189899126689,7.377170999844869,7.011869788169861,6.6196971734364825,6.212543368339539,5.796750545501709,5.375816980997722,4.951698740323384,4.525534590085347,4.119388202826182,3.7451924482981362,3.3881550232569375,3.0404673417409263,2.6980785131454468,2.358861049016317,2.021730045477549,1.6860899031162262,1.3516832788785298,1.0182859351237614,0.7593918194373449,0.6132976611455282,0.526004875699679,0.4692358374595642,0.4283478111028671,0.39572297285000485,0.36740679293870926,0.3413445105155309,0.31647225220998126,0.29222967475652695,0.27342790613571805,0.2625720724463463,0.25585708767175674,0.25129590183496475,0.24786212791999182,0.2450180302063624,0.242490503937006,0.24013517796993256,0.23787803078691164,0.23567786564429602,0.2337819424768289,0.23231303319334984,0.23106672366460165,0.22993648797273636,0.22886739547053972,0.22783133139212927,0.22681130965550741,0.22580527265866598,0.22480727111299834,0.22381523127357164,0.22299368927876154,0.22242015600204468,0.22197100023428598,0.2215838668247064,0.22122683251897493,0.2208847999572754,0.2205477977792422,0.22021378576755524,0.2198797936240832,0.21954579651355743,0.21911711121598879,0.21855737393101057,0.2179494065543016,0.21733142932256064,0.21672537674506506,0.21613933891057968,0.2155772770444552,0.2150382325053215,0.21451918532450995,0.2140241377055645,0.21321523562073708,0.21192124113440514,0.2103994886080424,0.20877374957005182,0.2071017548441887,0.20541382456819215,0.20372677346070608,0.20204678426186243,0.2003727617363135,0.19876254225770632,0.19729817286133766,0.19596493865052858,0.19469284266233444,0.19344879190127054,0.19222175826629004,0.1910027489066124,0.18978275607029596,0.18856075530250868,0.1873417484263579,0.18612275272607803,0.18489876886208853,0.1836717650294304,0.18244676540295282,0.18121977150440216,0.17998877788583437,0.17875577881932259,0.17752278099457422,0.176288782308499,0.17505378648638725,0.17381479466954866,0.1725727990269661,0.17133079345027605,0.17008879780769348,0.16884280865391096,0.167593814432621,0.16634480903546014,0.1650968131919702,0.16384382421771684,0.1625888260702292,0.16133382419745126,0.16007882356643677,0.15882382666071257,0.15756383910775185,0.15630084027846655,0.15503883610169092,0.1537768393754959,0.1525108516216278,0.1512418525914351,0.14997384697198868,0.14870585004488626,0.14743386084834734,0.14615986247857413,0.14488686000307402,0.14361286287506422,0.14233786364396414,0.14105887711048126,0.13977588340640068,0.13849387566248575,0.13721188406149545,0.13592489436268806,0.13463489835460982,0.13334589079022408,0.13205689440170923,0.13076390388111273,0.1294679076721271,0.12817190897961458,0.12687690493961176,0.12557791670163473,0.12427591967085998,0.12297491480906804,0.12167491391301155,0.12037291936576366,0.11906693130731583,0.11775893221298854,0.11645192777117093,0.11514393364389737,0.11383294003705184,0.11251994222402573,0.11120694068570931,0.10989493814607461,0.1085789514084657,0.10725995401541392,0.10594294592738152,0.10462595025698344,0.10330595696965854,0.10198296296099822,0.100660956154267,0.09933935850858688,0.09801745849351089,0.0966915711760521,0.09536327235400677,0.09403636554876964,0.09270956926047802,0.0913793786118428,0.09004678018391132,0.08871577307581902,0.08738497582574685,0.08605068549513817,0.08471418855090936,0.08337928106387456,0.08204468339681625,0.08070978273948033,0.07937139458954334,0.0780307948589325,0.07669198699295521,0.07535369011263053,0.0740123987197876,0.07266910063723724,0.07132769251863162,0.0699870940297842,0.06864330545067787,0.06729770017166932,0.065953999136885,0.06461089507987101,0.06326799839735031,0.061921506809691586,0.060573107873400055,0.05922650173306465,0.05788060370832682,0.056531512178480625,0.05518051236867905,0.05383140593767166,0.052483007622261844,0.05113151607414087,0.049778116246064506,0.04842651014526685,0.04707571119070053,0.04572172028323015,0.04436591950555643,0.04301191587001085,0.041658613830804825,0.040305315516889095,0.03894862439483404,0.03758982537935177,0.03623291912178198,0.03487652167677879,0.03351703006774187,0.03215563048919042,0.030796123978992302,0.02943722562243541,0.028075234188387792,0.026711334784825642,0.025349328604837258,0.023987929957608383,0.022623438543329637,0.021257038538654644,0.019892533775418997,0.01852863219877084,0.017164734192192554,0.015797443067034084,0.014428144165625175,0.013060538253436485,0.011693539718786875,0.010323447796205679,0.008951419886822501,0.007581250548052291,0.00621172944859912,0.0048390581117322045,0.0034645518753677607,0.002091768760389338,0.0010578173484342794,0.000534614026643491,0.0002703162111477771,0.00013663756180903874,6.908654965324483e-05,3.4925423430346804e-05,1.7659245258982992e-05,8.928125680540688e-06,4.514485453910311e-06,2.2826063646637826e-06,1.1542452540425074e-06,5.836516005312357e-07,2.951523316122954e-07,1.492553411234591e-07,8.7298020664169e-09,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911573469638824,1.2003816664218903,1.2809914747873943,1.3869915505250294,1.5006916522979736,1.6218617459138234,1.750241716702779,1.878231664498647,1.9984616140524547,2.111141622066498,2.216471552848816,2.31466152270635,2.405901471773783,2.490381439526876,2.5682813922564187,2.639771342277527,2.7050312558809915,2.7605111598968506,2.802801012992859,2.8322509129842124,2.8492207725842795,2.8540806770324707,2.847160538037618,2.8288004795710244,2.7993303338686624,2.7590602238972983,2.7083102265993753,2.6526801784833274,2.5976401766141257,2.543170173962911,2.4892701705296836,2.435930152734121,2.3831401467323303,2.3308801651000977,2.279160181681315,2.227950155735016,2.177250107129415,2.1274201075236,2.0788201292355857,2.031420131524404,1.985210120677948,1.9401501317818959,1.8962201277414958,1.8534001211325328,1.8116501073042552,1.7709601124127705,1.7312901218732197,1.6926501095294952,1.655020107825597,1.618370105822881,1.5826901296774547,1.547930121421814,1.5140901108582814,1.4811401168505351,1.4490401148796082,1.4177901248137157,1.3873601059118907,1.357730120420456,1.328910122315089,1.3008601268132527,1.2735701004664104,1.2470201253890991,1.2211801211039226,1.196040113766988,1.1715701222419739,1.1477600832780201,1.1245901187260945,1.102020114660263,1.080020119746526,1.0585801204045613,1.0376801093419392,1.0173201064268749,0.997484102845192,0.9781611065069834,0.9593421071767807,0.9410131027301153,0.9231641044219335,0.9057481090227762,0.8887181083361307,0.8720661054054896,0.8557831148306528,0.8398591031630834,0.82428710659345,0.8090560932954153,0.7941600978374481,0.7795881032943726,0.7653440982103348,0.7514600902795792,0.7379510899384817,0.7248070935408274,0.7120151023070017,0.6995640893777212,0.6874440958102545,0.6756430914004644,0.6641510923703512,0.6529590884844462,0.6420560926198959,0.6314330895741781,0.6210820923248926,0.6109930922587713,0.6011580924193064,0.5915700842936834,0.5822190841039022,0.5730980833371481,0.5642000834147135,0.5555180907249451,0.5470450768868128,0.5387740830580393,0.5306990842024485,0.5228130916754404,0.5151100854078928,0.5075840801000595,0.5002300764123598,0.4930420791109403,0.4860160748163859,0.4791440765062968,0.47242407500743866,0.465849074224631,0.45941607654094696,0.45311907182137173,0.4469550773501396,0.44091907391945523,0.43500606964031857,0.4292140727241834,0.42353807638088864,0.4179740672310193,0.41251906752586365,0.40717006971438724,0.4019230703512828,0.3967740659912427,0.39172106484572095,0.3867600659529368,0.38188906262318295,0.3771040638287862,0.3724030653635661,0.367783064643542,0.36324206242958706,0.35877606521050137,0.35438406467437744,0.3500630632042885,0.34581106156110764,0.34162506461143494,0.3375040590763092,0.33344505975643796,0.32944606244564056,0.3255060588320096,0.32162205626567203,0.31779205550750095,0.31401605904102325,0.3102910593152046,0.3066150521238645,0.3029880498846372,0.29940605411926907,0.2958700507879257,0.2923770571748416,0.28892605006694794,0.28551605095465976,0.28214505314826965,0.27881204585234326,0.2755160505572955,0.2722560490171115,0.2690300519267718,0.2658380443851153,0.26267704119284946,0.25954904158910114,0.2564500446120898,0.2533800428112348,0.25033904363711673,0.24732504412531853,0.24433804427584013,0.24137604236602783,0.2384390408794085,0.23552604019641876,0.23263604069749513,0.22976904238263765,0.226923036078612,0.22409803792834282,0.22129303589463234,0.21850803742806116,0.21574203670024872,0.21299503495295843,0.2102650341888269,0.20755203564961752,0.20485603561004004,0.20217603320876756,0.19951203341285387,0.19686303287744522,0.19422803074121475,0.1916080303490162,0.18900102749466896,0.18640702962875366,0.18382702643672624,0.18125802899400392,0.17870202660560608,0.17615702748298645,0.1736240287621816,0.1711010249952475,0.16858902449409166,0.16608702267209688,0.16359502325455347,0.16111302251617113,0.15863902121782303,0.15617502108216286,0.15371901914477348,0.15127102037270865,0.14883101855715117,0.14639902114868164,0.1439750182131926,0.14155701672037443,0.13914701466759047,0.13674401367704073,0.13434701412916183,0.13195601354042688,0.1295710156361262,0.12719201296567917,0.1248190136005481,0.12245101171235244,0.12008901250859101,0.11773101178308328,0.11537901125848293,0.1130310104538997,0.11068800898889701,0.10834900848567486,0.10601400770246983,0.10368400750060876,0.1013570073992014,0.09903390457232793,0.09671450530489285,0.09439870404700439,0.09208620215455691,0.0897769033908844,0.08747070282697678,0.08516740115980308,0.0828671008348465,0.08056940138339996,0.07827439966301124,0.07598190009593964,0.07372479823728402,0.07153470069169998,0.06940980007251103,0.06734810024499893,0.06534770006934802,0.06340680023034413,0.0615236001710097,0.059696500189602375,0.05792359976718823,0.05620350005726019,0.05453459980587164,0.052915300242602825,0.0513440997650226,0.04981959983706474,0.04834049971153339,0.046905300269524254,0.04551289975643158,0.04416180060555538,0.04285089951008558,0.041578899758557476,0.040344800179203354,0.039147300024827324,0.03798539967586597,0.036858100133637585,0.03576419968158007,0.0347028998658061,0.0336730998630325,0.03267390032609304,0.03170439973473549,0.030763699983557064,0.02985099997992317,0.028965300259490807,0.028105999963978927,0.027272199901441734,0.026463200182964403,0.0256782000263532,0.024916500163575012,0.024177499891569216,0.02346030001839002,0.02276449992010991,0.022089400018254917,0.021434300113469362,0.02079859996835391,0.02018190020074447,0.01958339987322688,0.01900269991407792,0.018439299737413723,0.017892499919980764,0.017362000110248726,0.016847300343215466,0.01634780007104079,0.015863200028737385,0.015392900134126345,0.014936600035677353,0.014493900040785471,0.01406430002922813,0.01364739992034932,0.01324290013872087,0.01285039990519484,0.012469599877173701,0.01209999993443489,0.011741400075455507,0.011393499871095022,0.011055900016799569,0.010728299928208193,0.010410400029892722,0.010101900125543276,0.009802610070134202,0.009512190086146196,0.009230369934812188,0.008956919967507323,0.008691570178295175,0.008434100076556206,0.008184260067840418,0.007941829894358913,0.007706589996814728,0.007478329973916213,0.007256829955925544,0.0070418999530375,0.006833350014251967,0.006630970009913047,0.00643459998536855,0.006244049989618361,0.006059150056292613,0.005879729986190796,0.005705630057491362,0.005536690043906371,0.005372750029588739,0.005213680017429094,0.005059319975165029,0.004909540022102495,0.004764189982476334,0.004623150064920385,0.0044862999736020965,0.004353489998417596,0.004224629956297576,0.004099579993635416,0.003978240032059451,0.003860489969762663,0.0037462300000091395,0.003635360005622109,0.0035277699741224446,0.0034233699940765896,0.003322059967710326,0.0032237500223952034,0.0031283599867795906,0.003035789995919913,0.002945960014282415,0.0028587999986484647,0.002774209987061719,0.0026921299868263304,0.0026124800012136498,0.0025351900258101523,0.0024601899979946515,0.002387410029768944,0.002316789992619306,0.002248259998547534,0.002181750004334996,0.002117220040721198,0.0020545999868772924,0.0019938300053278604,0.0019348599986794095,0.0018776300227424751,0.0018220999918412417,0.0017682099908900757,0.0017159200021220993,0.0016651800057540338,0.001615939991703878,0.0015681499886947374,0.001521780010079965,0.0014767899992875755,0.0014331199927255511,0.001390750005763645,0.0013496299895147483,0.0013097300252411515,0.0012710099884619315,0.001233429987526809,0.0011969699892991532,0.0011615799836969625,0.0011272500172102202,0.0010939300118479878,0.0010615900003661711,0.0010302099981345236,0.0009997599894025673,0.0009702109916058058,0.000941534997158063,0.0009137079953992119,0.0008867039966086546,0.0008604989998275414,0.0008350689943957453,0.0008103920020706331,0.0007864440024908012,0.0007632040020932133,0.000740651996845069,0.0007187670077352474,0.000697528996776479,0.0006769190028232212,0.0006569190009031445,0.0006375099959162375,0.0006186750009267902,0.0006003969998952622,0.0005826600002668177,0.0005654470054044699,0.000548742997731703,0.0005325320040962348,0.0005168019997654483,0.000501535992952995,0.0004867209984998529,0.000472345003800001,0.0004583929937022428,0.00044485400333845365,0.0004317150038938659,0.000418964996545886,0.00040659200021764264,0.00039458399745247635,0.00038293100078590214,0.0003716220041193689,0.00036064799981735024,0.00034999799633321044,0.00033966299815801904,0.00032963400008156896,0.00031990000085594755,0.0003104550002414423,0.00030128799699014053,0.00029239300298892584,0.00028375999924416345,0.00027538200083654374,0.0002672519985935651,0.00025936199866312865,0.00025170500157400966,0.0002442749985978783,0.00023706400194593394,0.00023006600167718716,0.00022327499997724468,0.00021668400101286048,0.000210287998925196,0.00020408099953783676,0.0001980579994172634,0.00019221200030491067,0.00018653899799877158,0.00018103399876660356,0.00017569100236869417,0.00017050600096505755,0.0001654739996107916,0.0001605909989545277,0.0001558520004133849,0.00015125300099801583,0.0001467889997002203,0.00014245799926963323,0.00013825400067920177,0.00013417500182792233,0.00013021599806961603,0.000126374000198363,0.00012264500037417747,0.0001190270013466943,0.00011551500028872397,0.00011210699934357156,0.00010880000081670005,0.00010559000050610241,0.00010247499994875398,9.945239980879705e-05,9.651870035061923e-05,9.367159994629522e-05,9.090849986629716e-05,8.822699965094216e-05,8.562460061511956e-05,8.309909996266167e-05,8.0648099052875e-05,7.826949937831766e-05,7.596109996181137e-05,7.372079926426522e-05,7.154659882265453e-05,6.94366002183718e-05,6.73888989695115e-05,6.540159968911514e-05,6.347290036501363e-05,6.160119968020202e-05,5.978470047314962e-05,5.80218002141919e-05,5.6310900314808045e-05,5.465049980557524e-05,5.3039099839224946e-05,5.1475299490751546e-05,4.995760021605141e-05,4.84847002250414e-05,4.70552004117053e-05,4.566790024303676e-05,4.432160009552414e-05,4.3658499635057524e-05};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.9463373819987,28.906192938486736,29.8445946375529,30.631895860036213,31.211997509002686,31.585798581441242,31.75399859746297,31.810898939768474,31.85029888153076,31.872299035390217,31.876699447631836,31.863799413045246,31.83359956741333,31.786099592844646,31.721299648284912,31.63939968744914,31.540299892425537,31.431299686431885,31.31939967473348,31.204699834187824,31.0872000058492,30.96679989496867,30.843699773152668,30.7176996866862,30.589000066121418,30.457599639892578,30.323299725850422,30.187900066375732,30.052599747975666,29.91770029067993,29.783000151316326,29.648600101470947,29.514400005340576,29.380599975585938,29.24710003534953,29.11389986673991,28.98100010553996,28.848299980163574,28.716000080108643,28.583899815877277,28.452099959055584,28.32070016860962,28.189499696095783,28.058599948883057,27.928100109100342,27.7978998819987,27.66800022125244,27.53849983215332,27.409300009409588,27.28059991200765,27.152299880981445,27.02430009841919,26.896700382232666,26.769500096638996,26.642699877421062,26.516300042470295,26.390300273895264,26.264699935913086,26.139599800109863,26.014800389607746,25.89049990971883,25.766499996185303,25.64299996693929,25.51990016301473,25.397199948628742,25.27500009536743,25.15310001373291,25.03159999847412,24.910400072733562,24.789599736531574,24.669200261433918,24.54920021692912,24.42959992090861,24.310399850209553,24.19160000483195,24.073300043741863,23.955399990081787,23.838000138600666,23.7208997408549,23.604300181070965,23.488100210825603,23.372299989064533,23.25689999262492,23.142000039418537,23.02749999364217,22.91349999109904,22.79990005493164,22.686899820963543,22.574600219726562,22.46279986699422,22.351600011189777,22.241100152333576,22.131099700927734,22.02180004119873,21.912999947865803,21.804799874623615,21.697200298309326,21.590199947357178,21.483799934387207,21.37790012359619,21.272599856058758,21.167899926503498,21.063700040181477,20.960100332895916,20.85700003306071,20.754500071207683,20.65250015258789,20.55109961827596,20.450300216674805,20.349900245666504,20.250099976857502,20.15079975128174,20.052099863688152,19.9539000193278,19.856200059254963,19.758999665578205,19.66230010986328,19.56619993845622,19.470499833424885,19.375399907430012,19.280800024668377,19.18660004933675,19.092999935150146,18.999799887339275,18.90719985961914,18.81499973932902,18.723300298055012,18.632099787394207,18.54139979680379,18.451200008392334,18.361399968465168,18.27209997177124,18.183299859364826,18.09489981333415,18.006999969482422,17.919500192006428,17.832499821980793,17.74600013097127,17.659899870554607,17.574299971262615,17.489000002543133,17.40429989496867,17.31999985376994,17.23609972000122,17.152599970499676,17.069600105285645,16.98700014750163,16.904799938201904,16.823000113169353,16.741700013478596,16.660799821217854,16.580300013224285,16.500199794769287,16.420499801635742,16.341300169626873,16.262399673461914,16.183899879455566,16.105899810791016,16.02820022900899,15.950900077819824,15.874000072479248,15.797499974568685,15.721400101979574,15.645700057347616,15.570399761199951,15.495400031407675,15.420899947484335,15.346700112024942,15.272899945576986,15.199399948120117,15.126299937566122,15.053600072860718,14.981300036112467,14.909299929936727,14.837699969609579,14.766400019327799,14.695500135421753,14.625,14.554800113042196,14.484899997711182,14.4153999487559,14.346299966176352,14.277499834696451,14.208999951680502,14.140900135040283,14.073199987411499,14.00570019086202,13.938600063323975,13.871900081634521,13.805399815241495,13.739300092061361,13.67360003789266,13.608100016911825,13.542999982833862,13.478200117746988,13.41380000114441,13.349599997202555,13.285799900690714,13.222299893697103,13.15909997622172,13.096200068791708,13.033699989318848,12.971399943033854,12.909500042597452,12.847899993260702,12.786500136057535,12.725500027338663,12.664800008138021,12.604400078455607,12.544299999872843,12.484500090281168,12.424999952316284,12.365700006484985,12.3067999680837,12.248200019200643,12.189899921417236,12.131799936294556,12.074100017547607,12.016599973042807,11.959399859110514,11.902499993642172,11.845899979273478,11.789499918619791,11.733500083287558,11.677699963251749,11.622199853261312,11.566999991734823,11.51200008392334,11.457300106684366,11.402900139490763,11.34880002339681,11.294900099436441,11.241299947102865,11.188000122706095,11.134900013605753,11.08210015296936,11.029500007629395,10.977199951807657,10.92519998550415,10.873400131861368,10.821799993515015,10.77049994468689,10.719500064849854,10.668700059254965,10.618100007375082,10.567800203959147,10.517700036366781,10.46779998143514,10.418200016021729,10.368800004323324,10.31969984372457,10.270800034205118,10.222100019454956,10.173699935277304,10.125499884287516,10.077499945958456,10.029800097147623,9.98225998878479,9.934969902038574,9.88791004816691,9.84107001622518,9.794449965159098,9.74806006749471,9.701890071233114,9.65593989690145,9.610209862391153,9.56470012664795,9.519409894943237,9.474330027898153,9.42946982383728,9.384819984436035,9.34038003285726,9.296160062154135,9.252149979273478,9.20834994316101,9.16476003328959,9.121369997660318,9.078190008799234,9.035220066706339,8.99244991938273,8.949889898300171,8.907529989878336,8.86537996927897,8.82341996828715,8.781660000483194,8.74010999997457,8.698749860127768,8.65758983294169,8.616619984308878,8.575850009918213,8.535269975662231,8.494889974594116,8.454699913660685,8.414700110753378,8.374899943669638,8.335279941558838,8.295850118001303,8.25661007563273,8.217559893925985,8.178689877192179,8.140000025431315,8.101509968439737,8.06318990389506,8.025060097376505,7.987110098203023,7.949340025583903,7.911749958992004,7.874340017636617,7.837099989255269,7.800050059954326,7.763170043627421,7.7264699538548784,7.689940055211385,7.653580029805501,7.617400010426839,7.581390023231506,7.545550028483073,7.509880026181539,7.474389950434367,7.439060012499492,7.403899987538655,7.368899901707967,7.334080060323079,7.29941999912262,7.264920035998027,7.230589985847473,7.196419994036357,7.162410060564677,7.128570000330607,7.094889998435974,7.061360001564026,7.027999957402547,6.9948000113169355,6.961749951044719,6.928860028584798,6.896129926045735,6.863549987475078,6.831129948298137,6.79885999361674,6.766740004221599,6.734779993693034,6.702969988187154,6.671309947967529,6.639799992243449,6.608440001805623,6.577230056126912,6.546170035998027,6.515260020891826,6.4844900369644165,6.453870018323262,6.423400044441223,6.393070022265117,6.362879991531372,6.332840005556743,6.302939971288045,6.2731800476710005,6.243570009867351,6.21408998966217,6.184750040372212,6.15555997689565,6.126500089963277,6.097580035527547,6.06879989306132,6.040150046348572,6.011640032132466,5.983270049095154,5.9550299644470215,5.9269299904505415,5.898959994316101,5.871119936307271,5.843410094579061,5.815829952557881,5.788390040397644,5.761079986890157,5.733890016873677,5.706839958826701,5.679909984270732,5.653109987576802,5.626440008481343,5.599889953931172,5.573480010032654,5.547179977099101,5.521010080973308,5.494970003763835,5.469050010045369,5.4432499806086225,5.417569915453593,5.392019947369893,5.366589983304341,5.341270049413045,5.316080053647359,5.291009942690532,5.2660499811172485,5.241219957669576,5.216500004132588,5.19189989566803,5.167419950167338,5.143050034840901,5.118799924850464,5.0946600039800005,5.070640007654826,5.046730041503906,5.0229300657908125,4.999250014623006,4.975679993629456,4.95222004254659,4.928880055745442,4.905640045801799,4.88250998655955,4.859500010808309,4.836590011914571,4.81378988424937,4.791099985440572,4.768509944279988,4.746039986610413,4.72367000579834,4.70140000184377,4.679250001907349,4.657190004984538,4.635239998499553,4.613399982452393,4.591659982999166,4.570020039876302,4.548479994138082,4.527049978574117,4.505720059076945,4.484479983647664,4.463349978129069,4.442320028940837,4.421390016873677,4.400560021400452,4.379830042521159,4.359190066655477,4.338650027910869,4.318209966023763,4.297869960467021,4.277619957923889,4.257470051447551,4.237420002619426,4.217459956804912,4.197589993476868,4.1778199672698975,4.158139944076538,4.138550003369649,4.119060079256694,4.099660078684489,4.0803500811258955,4.061130086580913,4.042009909947713,4.022970000902812,4.004019995530446,3.9851700266202292,3.9663999676704407,3.9477199713389077,3.9291299978892007,3.9106299678484597,3.8922199606895447,3.8738900224367776,3.8556499679883323,3.837500055631002,3.8194300134976706,3.80144997437795,3.7835500041643777,3.765739997227987,3.748009999593099,3.7303600311279297,3.7128000259399414,3.6953199903170266,3.677930017312368,3.660610020160675,3.6433799862861633,3.626230001449585,3.60915998617808,3.592180013656616,3.5752699772516885,3.5584399898846946,3.541690011819204,3.5250200033187866,3.508430023988088,3.491919994354248,3.4754899938901267,3.459130028883616,3.4428499738375344,3.426650027434031,3.4105299909909568,3.4024800260861716};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.14046497022112212,0.14906380325555801,0.1592738317946593,0.17081482087572417,0.1837118056913217,0.1979587897658348,0.21354778607686362,0.22976978619893393,0.24591878925760588,0.2619957874218623,0.27799978852272034,0.2939307913184166,0.30979079008102417,0.32557978729406994,0.3412967845797539,0.3569417893886566,0.372514804204305,0.3873298267523448,0.4006978397568067,0.41262785345315933,0.42312587052583694,0.4321968878308932,0.4398489048083623,0.44608792414267856,0.4509229411681493,0.4543599560856819,0.4564039533336957,0.45768996079762775,0.45885095993677777,0.45988796403010684,0.46080096314350766,0.4615909631053607,0.46225696553786594,0.4627999688188235,0.463221974670887,0.4635229706764221,0.46370596686999005,0.4638419722517331,0.46400196850299835,0.46418597052494687,0.4643959701061249,0.46462997049093246,0.4648879716793696,0.4651719679435094,0.4654799699783325,0.46581196536620456,0.46616796652475995,0.46654996524254483,0.46695996324221295,0.4673969695965449,0.4678589676817258,0.4683469608426094,0.4688609664638837,0.4694019655386607,0.469969963033994,0.47056396305561066,0.4711839680870374,0.47182796398798627,0.4724959656596184,0.4731869672735532,0.4739009588956833,0.4746369644999504,0.4753989577293396,0.476182962457339,0.47698896129926044,0.47781796008348465,0.4786679595708847,0.47953495879968006,0.48040995995203656,0.48129695653915405,0.48219296087821323,0.48309796303510666,0.48401395976543427,0.48493896176417667,0.4858749558528264,0.48682095607121784,0.4877779583136241,0.4887309620777766,0.48966796199480694,0.4905899589260419,0.4914959594607353,0.49238795787096024,0.49326395740111667,0.49412495642900467,0.49497196078300476,0.49580395966768265,0.49662195642789203,0.49742095669110614,0.49819596360127133,0.4989469622572263,0.49967195838689804,0.5003719578186671,0.5010489573081335,0.5016999741395315,0.5023279637098312,0.5029319624106089,0.503509963552157,0.5040659656127294,0.5045979619026184,0.5051049639781316,0.5055879553159078,0.5060469706853231,0.5064839671055476,0.5068969627221426,0.507286955912908,0.5076539615790049,0.5079979648192724,0.5083189656337103,0.5086179624001185,0.5088929682970047,0.5091469685236613,0.5093789547681808,0.5095869700113932,0.5097739547491074,0.5099389652411143,0.510080968340238,0.5102019608020782,0.5103019624948502,0.5103789766629537,0.5104349652926127,0.510470966498057,0.5104829569657644,0.5104749699433645,0.5104469706614813,0.5103969623645147,0.5103239715099335,0.5102309733629227,0.5101179778575897,0.5099829683701197,0.5098279764254888,0.5096529672543207,0.5094569673140844,0.5092409799496332,0.5090059687693914,0.5087489634752274,0.5084729741017023,0.5081769724686941,0.5078609883785248,0.5075249721606573,0.507170965274175,0.5067959775527319,0.5064009775718054,0.5059879869222641,0.5055549740791321,0.5051029721895853,0.504631981253624,0.5041409780581793,0.5036319742600123,0.5031039714813232,0.5025569746891657,0.5019889722267786,0.5014029840628306,0.5007999787727991,0.5001769761244456,0.49953598032395047,0.4988769789536794,0.4981989786028862,0.49750297764937085,0.49678998192151386,0.49605797479550046,0.495307981967926,0.4945409794648488,0.4937559763590495,0.49295298010110855,0.4921329816182454,0.4912939816713333,0.49043898036082584,0.48956697682539624,0.48867597927649814,0.4877689803640048,0.4868449817101161,0.4859029824535052,0.48494498431682587,0.48396998395522434,0.4829779888192813,0.4819669822851817,0.4809399868051211,0.4798969825108846,0.47883598258097965,0.47775998959938687,0.47666798780361813,0.4755579854051272,0.4744319866100947,0.47329098731279373,0.47213298330704373,0.47095898042122525,0.4697709878285726,0.4685639863212903,0.46734298517306644,0.46610698848962784,0.4648539870977402,0.4635859876871109,0.46230298777421314,0.46100298563639325,0.4596889888246854,0.4583599915107091,0.4570149878660838,0.45565499116977054,0.45428099234898883,0.4528909871975581,0.4514839897553126,0.45006298770507175,0.4486289868752162,0.447177991271019,0.44571298857529956,0.4442339912056923,0.44273998588323593,0.44123199582099915,0.43970999370018643,0.43817199269930523,0.4366209954023361,0.43505699187517166,0.4334769944349925,0.4318839932481448,0.4302769924203555,0.4286549910902977,0.4270209992925326,0.42537299791971844,0.4237099935611089,0.42203399290641147,0.4203449934720993,0.41864099353551865,0.41692499568065006,0.415195994079113,0.41345199942588806,0.4116939976811409,0.409922997156779,0.40813999871412915,0.4063430031140645,0.4045329988002777,0.4027099957068761,0.4008739988009135,0.3990260014931361,0.3971650004386902,0.39528999974330264,0.3934039995074272,0.39150500545899075,0.38960399975379306,0.3877130001783371,0.38583000004291534,0.3839569961031278,0.38209299991528195,0.38023899495601654,0.3783930043379466,0.3765559991200765,0.3747280016541481,0.3729100003838539,0.37109999855359393,0.3692989995082219,0.367507000764211,0.36572299897670746,0.3639490033189456,0.3621829996506373,0.3604249929388364,0.35867700229088467,0.3569359978040059,0.3552049994468689,0.35348200301329297,0.35176699856917065,0.35005999604860943,0.3483620012799899,0.34667300681273144,0.3449910009900729,0.3433179979523023,0.3416529968380928,0.3399959976474444,0.3383469954133034,0.336707000931104,0.33507399757703143,0.33344899614651996,0.33183200160662335,0.33022400240103406,0.3286219984292984,0.3270289972424507,0.3254439979791641,0.32386599729458493,0.32229599356651306,0.3207339992125829,0.3191789959867795,0.3176319971680641,0.31609299778938293,0.314560999472936,0.3130360022187233,0.31151900192101795,0.3100090026855469,0.30850700040658313,0.3070119967063268,0.30552500238021213,0.3040439983208974,0.30257099618514377,0.301105002562205,0.2996460075179736,0.2981949970126152,0.2967500016093254,0.2953120023012161,0.2938819999496142,0.29245800028244656,0.29104200253884,0.28963200002908707,0.2882289985815684,0.286832998196284,0.2854440013567607,0.2840620006124179,0.2826860000689824,0.28131700058778125,0.2799549972017606,0.27859899898370105,0.277249996860822,0.275907002389431,0.2745720023910205,0.27324200173219043,0.27191899965206784,0.2706029986341794,0.26929299781719845,0.26798900216817856,0.2666920026143392,0.2654009958108266,0.2641159991423289,0.2628379985690117,0.261564997335275,0.26029899964729947,0.2590399980545044,0.25778599828481674,0.2565380011995633,0.2552970002094905,0.2540609985589981,0.25283199797074,0.2516079992055893,0.25039099901914597,0.24917900189757347,0.24797399838765463,0.24677399918437004,0.24558000142375627,0.24439199765523276,0.24320999905467033,0.24203299855192503,0.24086199949185053,0.23969699939092,0.23853700359662375,0.2373839976886908,0.23623500019311905,0.23509300127625465,0.2339560016989708,0.23282399897774061,0.2316980001827081,0.230578001588583,0.22946199650565782,0.2283530036608378,0.22724799936016402,0.22614999984701475,0.22505600129564604,0.22396800170342127,0.2228850002090136,0.22180699929594994,0.2207350010673205,0.21966800093650818,0.21860600262880325,0.217549001177152,0.21649699906508127,0.21544999877611795,0.21440899992982546,0.2133720008035501,0.21234099939465523,0.21131499980886778,0.21029299994309744,0.20927700276176134,0.2082649990916252,0.20725899934768677,0.20625700056552887,0.20525999988118807,0.20426800101995468,0.20328100149830183,0.20229899883270264,0.2013210008541743,0.2003490005930265,0.19937999794880548,0.19841700047254562,0.19745800147453943,0.19650400057435036,0.19555500025550523,0.19460999965667725,0.1936699996391932,0.19273400058348975,0.1918030008673668,0.19087700173258781,0.1899549998342991,0.18903700013955435,0.18812399978439012,0.18721499914924303,0.18631100033720335,0.18541100000341734,0.18451599900921187,0.18362399811546007,0.18273799990614256,0.1818550005555153,0.18097699930270514,0.1801030014952024,0.17923299968242645,0.17836799969275793,0.1775059998035431,0.17664899801214537,0.1757959984242916,0.1749469997982184,0.1741029992699623,0.17326200008392334,0.17242600147922835,0.1715929980079333,0.17076500008503595,0.16993999977906546,0.16911999881267548,0.16830299918850264,0.1674909976621469,0.16668199996153513,0.16587800035874048,0.1650769996146361,0.16427999983231226,0.16348699728647867,0.16269799942771593,0.16191300004720688,0.1611319991449515,0.1603540008266767,0.15957999974489212,0.15881000086665154,0.15804299836357436,0.15728100016713142,0.15652200082937875,0.15576700121164322,0.15501500169436136,0.15426700189709663,0.15352300057808557,0.15278199935952821,0.15204500034451485,0.15131100018819174,0.15058099975188574,0.14985399941603342,0.14913100004196167,0.14841200038790703,0.1476959983507792,0.14698399727543196,0.1462740016480287,0.14556900039315224,0.14486699923872948,0.14416799942652384,0.1434719997147719,0.1427799972395102,0.14209199820955595,0.1414059984187285,0.14072400083144507,0.14004600048065186,0.13937000185251236,0.13869799921909967,0.13802899916966757,0.1373629979789257,0.13670100147525469,0.13604200010498366,0.13538600007692972,0.13473300139109293,0.13408299908041954,0.133437001456817,0.132792999347051,0.1321530006825924,0.1315159983932972,0.13088200117150942,0.13025100032488504,0.12962299957871437,0.12899800017476082,0.12837600087126097,0.12775700042645136,0.12714100008209547,0.12652799859642982,0.12591800093650818,0.12531099965174994,0.1247069990883271,0.12410599986712138,0.12350799950460593,0.1229130004843076,0.12232000008225441,0.12173100064198177,0.12114400106171767,0.12056000096102555,0.11997899909814198,0.11940099981923898,0.1188249991585811,0.11825300008058548,0.11768299962083499,0.11739800001184146};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2238450050354004,2.4407403071721396,2.631120244661967,2.8966302474339805,3.1973002354303994,3.528540313243866,3.8863202730814614,4.2339803377787275,4.539560278256734,4.808200279871623,5.044400294621785,5.252050280570984,5.434590379397075,5.5949902931849165,5.735870321591695,5.859520395596822,5.967950304349263,6.02957018216451,6.0167001485824585,5.938490231831868,5.803000171979268,5.617330153783162,5.387720108032227,5.119650204976399,4.81798009077708,4.486950119336446,4.130310078461965,3.7815900643666587,3.470180034637451,3.1915400425593057,2.941670060157776,2.717060069243113,2.5146300196647644,2.3316500584284463,2.1657300194104514,2.014780024687449,1.8769600590070088,1.7539600531260173,1.6473000347614288,1.5550100306669872,1.4753300448258717,1.4067300458749135,1.3478700419267018,1.2975400388240814,1.2547000348567963,1.2184300522009532,1.1879200438658397,1.1625200510025024,1.1416500508785248,1.1247600416342418,1.1113400359948475,1.100950042406718,1.0932100613911946,1.0877800484498341,1.0843700567881267,1.0827200313409169,1.0826000571250916,1.08377006649971,1.0860200623671215,1.0892000595728557,1.0931900640328724,1.0978800455729167,1.1031800508499146,1.1090100606282551,1.1152800520261128,1.1219500601291656,1.1289500693480174,1.1359100540479024,1.142510066429774,1.148820052544276,1.154900054136912,1.1607800523440044,1.1665100554625194,1.172120064496994,1.1776400605837505,1.1831000645955403,1.188520073890686,1.1932600637276967,1.196770042181015,1.199220061302185,1.2007600565751393,1.2015200555324554,1.2016100585460663,1.2011200586954753,1.2001500527064006,1.1987500588099163,1.1970700720945995,1.1949200630187988,1.1920900543530781,1.1886500815550487,1.1846800645192463,1.1802700559298198,1.1754600902398427,1.1703100601832073,1.1648700435956318,1.1591600676377614,1.1532400647799175,1.1471100648244221,1.14082004626592,1.1343700587749481,1.127800037463506,1.1211100618044536,1.1143200397491455,1.107440044482549,1.100480059782664,1.0934500594933827,1.086370050907135,1.0792200366655986,1.0720300376415253,1.0648000339667003,1.057530055443446,1.0502300361792247,1.042890061934789,1.035530040661494,1.0281400382518768,1.0207200348377228,1.0132800439993541,1.005830039580663,0.9983560492595037,0.9908670485019684,0.9833610405524572,0.9758390486240387,0.968304047981898,0.9607570419708887,0.9531960437695185,0.9456220467885336,0.93803704281648,0.9304430484771729,0.922837033867836,0.9152190436919531,0.9075930317242941,0.8999560376008352,0.8923110365867615,0.8846540451049805,0.876985048254331,0.8693070362011591,0.8616200387477875,0.8539210309584936,0.8462110360463461,0.8384920308987299,0.8307650337616602,0.823028028011322,0.8152810384829839,0.8075230369965235,0.7997570335865021,0.791984036564827,0.7842000325520834,0.7764060298601786,0.768604040145874,0.7607960353295008,0.7529780318339666,0.745150034626325,0.7373150239388148,0.7294740329186121,0.721626028418541,0.7137680351734161,0.7059020350376765,0.6980290313561758,0.6901500374078751,0.6822630365689596,0.6743670354286829,0.6664640257755915,0.6585560292005539,0.6506420324246088,0.6427200237909952,0.6347890347242355,0.6268530289332072,0.6189110179742178,0.6109620233376821,0.6030040283997854,0.5950420300165812,0.5870740314324697,0.579101026058197,0.5711210320393244,0.5631330261627833,0.5551400184631348,0.5471420188744863,0.5391370256741842,0.5311250239610672,0.5231090188026428,0.5150890251000723,0.5070620179176331,0.499029020468394,0.49099302291870117,0.4829540227850278,0.47491101920604706,0.4668620203932126,0.4588090181350708,0.45075201988220215,0.44269301493962604,0.4346280172467232,0.4265590161085129,0.41848701735337573,0.4104120184977849,0.4023350179195404,0.39425301800171536,0.386166013777256,0.37807601193586987,0.3699840158224106,0.36188702036937076,0.35378601650396985,0.34568201502164203,0.3375760093331337,0.32946501423915225,0.32134900987148285,0.3132310137152672,0.30511100838581723,0.296988012890021,0.2888600106040637,0.2807270089785258,0.27259300649166107,0.26445500801006955,0.2563130060831706,0.24816700940330824,0.24001800765593848,0.23186600704987845,0.22371200720469156,0.21555300801992416,0.20738900701204935,0.19922300800681114,0.19105500852068266,0.18288100386659303,0.17470300445954004,0.16652200495203337,0.15834000706672668,0.15015200401345888,0.14195900410413742,0.13376500457525253,0.1255670034637054,0.1173680021117131,0.10916300242145856,0.10095300152897835,0.09274160116910934,0.08452720132966836,0.07630790024995804,0.06808390157918136,0.05985760036855936,0.052159300073981285,0.04545130021870136,0.03960620022068421,0.034512900126477085,0.030074800209452707,0.026207600099345047,0.022837699856609106,0.019901300159593422,0.017342500233401854,0.015112900097543994,0.013169900048524141,0.011476800000915924,0.010001499981929859,0.008715839978928367,0.007595499977469444,0.0066192099669327336,0.005768439926517506,0.005027049997200568,0.004380979963267843,0.0038179599990447364,0.003327319980598986,0.00289975000002111,0.0025271300110034645,0.0022024099986689785,0.0019194299917823325,0.0016728100017644465,0.0014578899814902495,0.0012705900007858872,0.0011073599841135244,0.0009651080035837367,0.0008411319965186218,0.0007330859953071922,0.0006389220022053147,0.0005568570049945265,0.0004853349964832887,0.00042300199856981635,0.0003686760028358549,0.00032132900135669235,0.00028006499633193016,0.00024410000332864001,0.00021275500087843588,0.0001854369996484214,0.00016162700194399804,0.00014087400146915266,0.00012278699917563549,0.00010702300035821584,9.328340032273748e-05,8.130799930465098e-05,7.087030098773539e-05,6.177280010888353e-05,5.384350000288881e-05,4.693220034823753e-05,4.090829952474451e-05,3.565769990624782e-05,3.1081199419228746e-05,2.709219991932817e-05,2.3615299899878057e-05,2.0584699996106792e-05,1.7943099768065924e-05,1.564060001631636e-05,1.3633599943811229e-05,1.1884199996832953e-05,1.035939991803995e-05,9.030200089910068e-06,7.871609947566563e-06,6.86171006236691e-06,5.981399984496723e-06,5.21404998229021e-06,4.545170024054339e-06,3.962120028215092e-06,3.453870040933301e-06,3.0108400134546778e-06,2.624650013179538e-06,2.2879999619362934e-06,1.9945499900586583e-06,1.738739996426375e-06,1.5157399957388407e-06,1.32135000778059e-06,1.1519000035301967e-06,1.0041800114398332e-06,8.754110041309104e-07,7.631569900468094e-07,6.653009971084126e-07,5.799949983990397e-07,5.056290106608685e-07,4.4080000094481875e-07,3.842850020419064e-07,3.3501799852804953e-07,2.920680017837185e-07,2.546259996923557e-07,2.2198399918238465e-07,1.9352799895955286e-07,1.687210016143581e-07,1.470939992032072e-07,1.2823999995248414e-07,1.1180300063529103e-07,3.398725745284992e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834424575169882,12.709800799687704,13.16670036315918,13.879200379053751,13.80020014444987,13.067200263341268,11.793600082397461,10.381800095240274,9.163100163141886,8.102729956309,7.172160069147746,6.34811011950175,5.61149005095164,4.946710030237834,4.341000040372212,3.7838800152142844,3.2667499780654907,2.8058000206947327,2.414500037829081,2.080790013074875,1.7947400013605754,1.548090010881424,1.3340300222237904,1.1469300190607707,0.9821280141671499,0.8357529938220978,0.7046299974123637,0.5909369985262553,0.4964480052391688,0.4178029994169871,0.3522299999992053,0.2974329963326454,0.25151200344165164,0.21290400127569833,0.1803220013777415,0.1527059997121493,0.12918100071450075,0.10933200021584828,0.092823700979352,0.07907480125625928,0.06760400099058946,0.05801280060162147,0.049977000802755356,0.0432182007158796,0.03751170045385758,0.03267700085416436,0.028555100318044424,0.025051500493039686,0.02209840016439557,0.019601100279639166,0.01747250013674299,0.015648000175133348,0.014073300252979001,0.012698700108254949,0.011488500206420818,0.010418500130375227,0.009463720178852478,0.008619200127820173,0.007880840140084425,0.007229510112665594,0.006654700109114249,0.006142610024350385,0.005676770000718534,0.005248870079716046,0.004857290148114164,0.004495510094178219,0.004153040121309459,0.0038365801059020064,0.0035516800708137453,0.0032927700667642057,0.0030604200825716057,0.002844730062255015,0.0026427600532770157,0.002452130060798178,0.0022708300578718386,0.0021024200250394642,0.001939410043026631,0.001780800036309908,0.001630940018609787,0.0014882700246137877,0.0013515300233848393,0.0012196700263302773,0.0010918600116080295,0.000962219011853449,0.0008311730052810162,0.0007042040039474765,0.0005806499975733459,0.00047028500557644293,0.0003809359986917116,0.00030859400430927053,0.00025001700002273236,0.00020257899814168923,0.0001641589988139458,0.00013303900050232187,0.00010782999985773738,8.740599938998155e-05,7.085779967989463e-05,5.744830014009494e-05,4.65811996643121e-05,3.777339952648617e-05,3.063409955454214e-05,2.4846499854902504e-05,2.015429996996924e-05,1.6349799807358067e-05,1.3264699797825111e-05,1.076269995792245e-05,8.733539971217397e-06,7.0875800020075985e-06,5.752360001073005e-06,4.669109936609554e-06,3.7901900213910267e-06,3.077009997317267e-06,2.4982500311428644e-06,2.0285300100416257e-06,1.6472699921147675e-06,1.337790005588128e-06,1.0865500049324812e-06,8.825670031834912e-07,7.169439915818051e-07,5.824520030728308e-07,4.73229998002959e-07,3.845230030682008e-07,3.12471001961967e-07,2.539410009679462e-07,2.0639300046809694e-07,1.6776100035068944e-07,1.3637199813842926e-07,1.1086500014319729e-07,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708229462305704,0.9575200627247492,1.0297000606854756,1.1014700730641682,1.1728200614452362,1.2437200645605724,1.3141300976276398,1.3765700658162434,1.4244500696659088,1.4593800604343414,1.4827900727589924,1.4959400693575542,1.4999500413735707,1.4958200454711914,1.48443004488945,1.4665800432364147,1.4429600536823273,1.4122300346692402,1.3732400337855022,1.326900045077006,1.2740500370661418,1.2154500385125477,1.1517500082651775,1.083540012439092,1.0113600095113118,0.935668001572291,0.8568860044082006,0.7807250122229258,0.7122470041116079,0.6506040046612421,0.5950329999128977,0.5448570052782694,0.49947500228881836,0.4583480084935824,0.42100000381469727,0.38700800637404126,0.35599300265312195,0.3280470023552577,0.30325500667095184,0.28126900643110275,0.26177900781234104,0.24451100329558054,0.22921600316961607,0.21567600592970848,0.20369500542680422,0.19310100376605988,0.18373900527755418,0.1754910039405028,0.16825700302918753,0.1619230049351851,0.15638200441996256,0.1515480031569799,0.1473390037814776,0.1436820055047671,0.1405160054564476,0.1377820037305355,0.13543200741211572,0.13344000279903412,0.13178500284751257,0.13042800625165304,0.12933600569764772,0.12847700715065002,0.12782200674215952,0.12734600404898325,0.12703000257412592,0.1268520044783751,0.1267980063954989,0.12683500597874323,0.12693800404667854,0.1271010053654512,0.12731700266400972,0.12758300577600798,0.12789400418599448,0.12824700648585954,0.1286340057849884,0.12905500705043474,0.1295070064564546,0.1299270043770472,0.1302600068350633,0.130519005159537,0.13071000576019287,0.13084300607442856,0.13092500468095145,0.13096400598684946,0.13096800446510315,0.1309380071858565,0.13088700796167055,0.13078400368491808,0.1305940051873525,0.13032800455888113,0.12999600544571877,0.1296050064265728,0.12916300569971403,0.12867700681090355,0.12815400585532188,0.12759400655825934,0.1270040050148964,0.1263860066731771,0.1257430041829745,0.1250790065775315,0.12439500602583091,0.12369500597318013,0.12298000479737918,0.1222520067046086,0.12151200572649638,0.12076200544834137,0.12000200587014358,0.11923600547015667,0.11846400424838066,0.11768500444789727,0.11690000506738822,0.11610900486509006,0.11531300532321136,0.11451200519998868,0.11370800559719403,0.1128990047921737,0.1120870045075814,0.1112720047434171,0.11045400363703568,0.10963300429284573,0.10881000384688377,0.10798700526356697,0.10716300457715988,0.10633700403074424,0.10550900486608346,0.10467800373832385,0.10384600423276424,0.10301200486719608,0.10217700339853764,0.10133900493383408,0.1005010058482488,0.09966050398846467,0.09881890440980594,0.09797590412199497,0.09713350360592206,0.09629150542120139,0.09544770233333111,0.09460230295856793,0.09375540415445964,0.09290690471728642,0.09205690398812294,0.09120560437440872,0.09035290405154228,0.08949900294343631,0.08864380232989788,0.08778740279376507,0.08693000425895055,0.08607140307625134,0.08521370279292266,0.0843567034850518,0.08349830284714699,0.08263840277989705,0.08177730192740758,0.08091490219036739,0.08005130290985107,0.07918660404781501,0.07832080187896888,0.07745400257408619,0.07658610368768375,0.07571730390191078,0.07484750263392925,0.07397680232922237,0.07310720284779866,0.07223850240310033,0.07136840249101321,0.07049720237652461,0.06962480209767818,0.06875130285819371,0.06787680213650067,0.06700130179524422,0.06612490241726239,0.06524750217795372,0.06436930224299431,0.06349020265042782,0.06261030243088801,0.06173160175482432,0.060853902560969196,0.05997490230947733,0.0590949027488629,0.05821390232692162,0.05733190197497606,0.05644900258630514,0.05556530226022005,0.05468090188999971,0.05379570213456949,0.052909902296960354,0.052023401794334255,0.05113630214085182,0.05024860116342703,0.049362401788433395,0.048477401646474995,0.04759150184690952,0.046704601806898914,0.04581700203319391,0.044928601322074734,0.044039501808583736,0.043149701630075775,0.0422593013693889,0.04136820168544849,0.040476600639522076,0.0395845016464591,0.03869180132945379,0.03780060106267532,0.03691060064981381,0.03601970120022694,0.03512800112366676,0.03423540107905865,0.03334220095227162,0.032448200819393,0.03155350095281998,0.03065830050036311,0.029762400469432276,0.028865900977204244,0.027968900899092358,0.02707140085597833,0.026173400847862165,0.025276800617575645,0.024381500979264576,0.023485300752023857,0.02258830051869154,0.02169050058970849,0.020791900499413412,0.019892600520203512,0.0189927004588147,0.01809210019807021,0.017191000593205292,0.016289200478543837,0.01538700028322637,0.014484100121383866,0.013580800189326206,0.012679000229885181,0.011778400201971332,0.010876900128399333,0.009974600048735738,0.009071480017155409,0.008167610115682086,0.00726304998776565,0.006411229958757758,0.00565932997657607,0.0049956400180235505,0.004409799973169963,0.0038926799704010286,0.0034362200337151685,0.0030332999886013567,0.0026776400239517293,0.0023636999928082028,0.002086569981959959,0.0018419499780672293,0.0016260099946521223,0.001435400015907362,0.001267130011304592,0.00111859999014996,0.0009874879809406896,0.0008717449964024127,0.0007695730018895119,0.000679380003324089,0.0005997599946567789,0.0005294739967212081,0.000467427996530508,0.00041265400068368763,0.0003643010010515961,0.0003216160015047838,0.0002839329996883559,0.000250666998908855,0.00022129900025902316,0.00019537399930413812,0.0001724859988219881,0.00015227999877727902,0.00013444200279385163,0.00011869400016924676,0.00010479199954716023,9.251769976496386e-05,8.168189985250744e-05,7.211549988520953e-05,6.366989994906665e-05,5.621360044945808e-05,4.963069992906336e-05,4.38190002872337e-05,3.868789978393276e-05,3.415790009360838e-05,3.015850006704568e-05,2.662740007508546e-05,2.3509900074714096e-05,2.075749974513504e-05,1.8327400084672263e-05,1.6181899961035622e-05,1.4287599924500682e-05,1.261509987671161e-05,1.1138499985463568e-05,9.834699919034998e-06,8.683589991657451e-06,7.667240007928436e-06,6.769880049735851e-06,5.977580030958052e-06,5.278020012156048e-06,4.660359991248697e-06,4.114989981947777e-06,3.6334600016137606e-06,3.208300010252666e-06,2.8328899854083525e-06,2.5014300225241945e-06,2.208759970775039e-06,1.9503300260718484e-06,1.7221599838042796e-06,1.5206800014766486e-06,1.3427799861650176e-06,1.1856999909317285e-06,1.047000002548278e-06,9.245230027469612e-07,8.163799994539053e-07,7.208900001387519e-07,6.365710021327686e-07,5.62118003699652e-07,4.963739925756272e-07,4.383219973647101e-07,3.870610025084413e-07,3.417960006875849e-07,3.018260012292255e-07,2.6653100348994485e-07,2.3536400206580765e-07,2.0784299910777312e-07,1.8354000038319404e-07,1.6208000038394252e-07,1.4313000088842878e-07,1.2639599944463953e-07,1.1161900026479543e-07,4.256457645605375e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.2528575286269188,0.2655299554268519,0.27518197397391003,0.2846839750806491,0.2938299799958865,0.3026319816708565,0.3110999787847201,0.3184339851140976,0.32388698558012646,0.3275719831387202,0.32959598302841187,0.3300589869419734,0.3290539930264155,0.32666798681020737,0.3229839876294136,0.3180809865395228,0.31203099091847736,0.3050539940595627,0.2973569979270299,0.2889869933327039,0.2799859916170438,0.2703939924637477,0.26024900128444034,0.24958899741371474,0.23844599723815918,0.22685199851791063,0.21483799939354262,0.20295899733901024,0.1917359990378221,0.18112999821702638,0.1711039977769057,0.16162299861510596,0.15265400211016336,0.14416600142916045,0.1361289992928505,0.12851499766111374,0.1212999988347292,0.11448799942930539,0.10808799974620342,0.10207399850090344,0.09642389913400014,0.09111669970055421,0.08613189992805322,0.08145019908746083,0.07705359968046348,0.07292500076194604,0.06904829914371173,0.06541039856771629,0.0619989987462759,0.0588001993795236,0.055800798969964184,0.052988498782118164,0.05035170012464126,0.04787939911087354,0.04556149958322445,0.04338839929550886,0.041350899574657284,0.03944189908603827,0.037654599795738854,0.03598139931758245,0.03441489953547716,0.032948498924573265,0.0315756993368268,0.030290599291523296,0.02908769917363922,0.027961599174886942,0.02690759937589367,0.025920099578797817,0.024994099667916696,0.0241258991882205,0.023312099433193605,0.022549499291926622,0.021834899205714464,0.021165299384544294,0.020538099575787783,0.019950499137242634,0.0194001995647947,0.018882199345777433,0.018391999416053295,0.01792789933582147,0.017488299248119194,0.017071599295983713,0.016676499197880428,0.01630139925206701,0.01594529937331875,0.015606899512931705,0.01528539943198363,0.014980499477436146,0.014692499457548061,0.014420299557968974,0.014161399488026897,0.013914899512504538,0.013681199479227265,0.013459599576890469,0.01324779943873485,0.0130449995243301,0.012852199375629425,0.01266859945220252,0.012492099466423193,0.012322299337635437,0.012160199306284388,0.01200509948345522,0.01185519954500099,0.011710099643096328,0.01157089943687121,0.0114372995061179,0.01130729952516655,0.011180799687281251,0.011058899651591977,0.010941299609839916,0.010826299355054895,0.010713699584205946,0.010604699530328313,0.010499099579950174,0.010395299488057693,0.010293199525525173,0.01019389950670302,0.010097299547245106,0.01000189951931437,0.009907529456540942,0.009815509586284557,0.009725699434056878,0.009636539422596494,0.009547969636817774,0.009461359508956472,0.009376569651067257,0.009292069744939605,0.009207829600200057,0.009125239526232084,0.009044169681146741,0.008963119549055895,0.00888208975084126,0.008802449563518167,0.008724119591837129,0.008645599630350867,0.008566889523838958,0.008489409694448113,0.008413059714560708,0.008336359557385245,0.00825932971201837,0.00818338974689444,0.008108459723492464,0.008033059692631165,0.007957229623571038,0.007882379616300264,0.0078084495617076755,0.007733969677550097,0.007658969688539703,0.007584879640489817,0.007511639695925017,0.007437789618658523,0.007363359676674008,0.007289779682954152,0.007216999734130998,0.0071435597104330855,0.00706949969753623,0.006996239729536076,0.006923749732474486,0.006850559768887858,0.006776709691621363,0.006703649725144108,0.006631319721539815,0.006558259716257453,0.0064859197397405905,0.006414259745118518,0.006341809639707208,0.006268629765448471,0.006196169725929697,0.00612436980009079,0.006051779763462643,0.005978459725156426,0.00590584974270314,0.005833899757514398,0.005761149805039167,0.005687669773275654,0.005614899836170177,0.005542779807001352,0.00546986978345861,0.005396219707715015,0.005323279765434563,0.005250989808700979,0.00517791979170094,0.005104099866002798,0.00503099977504462,0.004958559836571415,0.004885329864919186,0.004811359802260995,0.004738109807173411,0.004665509797632694,0.004592139855958521,0.00451802978447328,0.004444639819363753,0.0043719097739085555,0.004298399901017547,0.004224149859510362,0.00415061980796357,0.004077759804204106,0.004004109922486047,0.003929739856782059,0.003856079866333554,0.003783089865464717,0.003709309850819409,0.003634809865616262,0.0035610198974609375,0.0034879098917978504,0.0034140099111633995,0.0033393798706432185,0.0032654698782910905,0.0031922298949211836,0.003118199878372252,0.003043449930070589,0.0029694199135216572,0.002896049952444931,0.002821899931101749,0.0027470299197981753,0.002672869925542424,0.002599379940268894,0.002525119964654247,0.002450119936838746,0.002375839937788745,0.002302229947720965,0.0022278399555943906,0.0021527199811923006,0.002078319957945496,0.002004589963083466,0.0019300799952664722,0.0018548299558460712,0.001780309956908847,0.0017064599863563974,0.0016318299846413236,0.0015564599986343335,0.0014818199949028592,0.001407839988435929,0.001333089981926605,0.0012576100028430421,0.0011828400117034714,0.0011087399907410145,0.001036670000758022,0.0009692799794720486,0.0009062739942843715,0.0008473669974288592,0.0007922900064537922,0.0007407949985160182,0.0006926490023033693,0.0006476340010218943,0.0006055460059239218,0.0005661950029510384,0.0005294029979268089,0.0004950029979227111,0.0004628400007883708,0.0004327670006508318,0.000404649998624033,0.000378361000912264,0.00035377999787063646,0.00033079799565409,0.00030930900053742033,0.00028921700140926987,0.0002704310027183965,0.00025286599702667445,0.000236443000176223,0.00022108599781252755,0.0002067279977685151,0.0001933029998326674,0.00018074999752570875,0.00016901300114113837,0.000158037998820267,0.00014777600154047832,0.00013818099857113944,0.00012920999749136777,0.00012082099783583544,0.00011297699954108491,0.00010564300040035353,9.878489981929306e-05,9.237240010406822e-05,8.637640045587129e-05,8.076979853891923e-05,7.552729888023653e-05,7.06252006542248e-05,6.604150075872894e-05,6.175549939750151e-05,5.774770003578548e-05,5.400019957354137e-05,5.049599955479304e-05,4.721929993441639e-05,4.415539994321686e-05,4.129030063874476e-05,3.861130032116004e-05,3.610619963486291e-05,3.376369992717324e-05,3.1573199824682284e-05,2.9524899976725767e-05,2.7609599783318117e-05,2.5818600079219323e-05,2.4143800146703143e-05,2.2577700140876306e-05,2.111330013576662e-05,1.9743900035488576e-05,1.846330011782508e-05,1.726590001756752e-05,1.6146099975837085e-05,1.5098999710971839e-05,1.4119800046804206e-05,1.3204199907098276e-05,1.2348000154815963e-05,1.1547300042972589e-05,1.0798600063329408e-05,1.0098399949735418e-05,9.443670023756567e-06,8.831400009512436e-06,8.258839973980988e-06,7.723420026195527e-06,7.222730080987579e-06,6.754510006127627e-06,6.316659967827339e-06,5.907199958225344e-06,5.5243000360860606e-06,5.166230001426205e-06,4.831379972832413e-06,4.5182500419590115e-06,4.22540999049185e-06,3.951569965465751e-06,3.695479999047772e-06,3.4560000206814343e-06,3.2320400009666628e-06,3.022600007322277e-06,2.8267400011827704e-06,2.643580008528564e-06,2.4722899828096465e-06,2.3120999988653543e-06,2.162300006602891e-06,2.0222100071502305e-06,1.8911900004544198e-06,1.768670008080638e-06,1.6541000036340847e-06,1.5469399935833887e-06,1.4467299820353219e-06,1.3530200059600854e-06,1.2653800164722877e-06,1.1834199919273185e-06,1.1067700048291347e-06,1.0350799944565854e-06,9.680429921369675e-07,9.053490022855234e-07,8.467160057534784e-07,7.918820064863515e-07,7.406010051151194e-07,6.926419947224834e-07,6.477899934983119e-07,6.058439983765614e-07,5.666150002525683e-07,5.299269929537331e-07,4.956159974274973e-07,4.635279987989331e-07,4.3351699948364814e-07,4.0545100195762035e-07,3.792020043154783e-07,3.54654000981706e-07,3.3169500331572027e-07,3.102230010654239e-07,2.9014200227569137e-07,2.713610006329266e-07,2.537959981433839e-07,2.3736900208367237e-07,2.2200500045717794e-07,2.0763699855782156e-07,1.941979993110484e-07,1.8163000111333835e-07,1.6987499999269554e-07,1.5888200148121237e-07,1.4859999926860232e-07,1.3898399942036122e-07,1.2999000039333927e-07,1.215790004967706e-07,1.1371200040836509e-07,1.0635399938507817e-07,4.225702336195051e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3649137218793232,1.4759700099627178,1.5901099940141041,1.6944600145022075,1.7942799925804138,1.889569987853368,1.9803499976793926,2.067080001036326,2.15024999777476,2.229860027631124,2.305910050868988,2.37841002146403,2.4473699927330017,2.512790044148763,2.5746899843215942,2.6330599983533225,2.687909960746765,2.739860018094381,2.7895100116729736,2.8368799686431885,2.8819599946339927,2.9247699975967407,2.9653000036875405,3.0035599867502847,3.039550006389618,3.0732800364494324,3.104760011037191,3.1347699960072837,3.164119998613993,3.1928199927012124,3.2208500107129416,3.2482300400733948,3.2749600211779275,3.301030000050863,3.326439996560415,3.3512099981307983,3.375319997469584,3.3989200393358865,3.422119994958242,3.4449400107065835,3.467359960079193,3.4893999497095742,3.5110400319099426,3.5323100487391152,3.5531800190607705,3.573669989903768,3.593769987424215,3.6134999791781106,3.632850011189779,3.651840031147003,3.670459965864817,3.68871001402537,3.706599990526835,3.724109967549642,3.74125999212265,3.7580499847730002,3.7744800051053367,3.790529986222585,3.806180000305176,3.8214499751726785,3.8363199830055237,3.8508199652036033,3.8649200002352395,3.8786399761835733,3.8919699788093567,3.904920001824697,3.917479991912842,3.9296799898147583,3.9415199756622314,3.953010002772013,3.964140017827352,3.9749200145403543,3.9853499929110208,3.9954299926757812,4.005160013834636,4.014530022939046,4.023560047149658,4.032230059305827,4.040539979934692,4.048499981562297,4.056099971135457,4.063339908917745,4.070220033327739,4.076750000317891,4.0829200347264605,4.088739951451619,4.094199975331624,4.099449992179871,4.104590018590291,4.109650015830994,4.114609877268474,4.119479974110921,4.124259988466899,4.128949999809265,4.133540034294128,4.1380399862925215,4.142449975013733,4.146770000457764,4.151000062624614,4.155129949251811,4.159179965655009,4.163130005200704,4.166999975840251,4.170769890149434,4.174450000127156,4.178040027618408,4.181539972623189,4.184949994087219,4.188270012537639,4.191499988238017,4.194650014241536,4.197700063387553,4.200659950574239,4.203529993693034,4.2063199281692505,4.209009965260823,4.211620052655538,4.214140017827352,4.216570019721985,4.218910018603007,4.221159934997559,4.223329981168111,4.22540005048116,4.227390090624492,4.229300022125244,4.231119990348816,4.232849995295207,4.234500050544739,4.23605998357137,4.237540006637573,4.238929907480876,4.240229964256287,4.241439978281657,4.242570002873738,4.2436100244522095,4.244569977124532,4.2454400062561035,4.246219992637634,4.246920069058736,4.247530023256938,4.248059988021851,4.2484999895095825,4.248859961827596,4.249129851659139,4.249319950739543,4.249420007069905,4.24943995475769,4.249379992485046,4.249229947725932,4.248989979426066,4.248680035273234,4.248269995053609,4.247790018717448,4.247219999631246,4.246569991111755,4.245829979578654,4.245009978612264,4.244110027949016,4.243130008379619,4.242059985796611,4.240910053253174,4.2396799723307295,4.238360047340393,4.236970027287801,4.2354899644851685,4.2339299122492475,4.232280015945435,4.2305599848429365,4.228750030199687,4.226870020230611,4.224900086720784,4.22284996509552,4.220720012982686,4.218499978383382,4.216209967931111,4.213840007781982,4.211390018463135,4.208849986394246,4.2062400579452515,4.203550060590108,4.200770020484924,4.197920044263204,4.194980065027873,4.191969990730286,4.18888000647227,4.185709993044536,4.182460069656372,4.17913003762563,4.175719976425171,4.172229965527852,4.168670058250427,4.165029962857564,4.16130002339681,4.157499988873799,4.153629978497823,4.149669965108235,4.145639975865682,4.141529997189839,4.137339949607849,4.133079965909322,4.128740032513936,4.124329964319865,4.119839986165364,4.115279992421468,4.110640009244283,4.105920036633809,4.10113004843394,4.096250017484029,4.091310063997905,4.086290001869202,4.08118999004364,4.07600998878479,4.070770104726155,4.065440018971761,4.06003999710083,4.054569999376933,4.049019972483317,4.043389995892842,4.037699977556865,4.031919956207275,4.02606999874115,4.020149985949199,4.0141600370407104,4.008089939753215,4.00194005171458,3.995730002721151,3.9894299705823264,3.9830699960390725,3.9766300121943154,3.9701200326283774,3.963540017604828,3.956880033016205,3.950149973233541,3.9433499773343406,3.936470011870066,3.9295300245285034,3.922510008017222,3.915459990501404,3.9084200064341226,3.901400009791056,3.8943899869918823,3.8873900175094604,3.880400002002716,3.8734300335248313,3.8664699594179788,3.8595200379689536,3.8525899847348533,3.845669984817505,3.838759978612264,3.8318600257237754,3.8249799807866416,3.8181100289026895,3.8112499713897705,3.8043999870618186,3.7975700298945108,3.790750006834666,3.783939997355143,3.777139981587728,3.770359992980957,3.7635799845059714,3.7568299770355225,3.7500799894332886,3.743339955806732,3.73662002881368,3.729909976323446,3.7232099771499634,3.716529985268911,3.7098499536514282,3.7031899889310202,3.6965399980545044,3.689900000890096,3.6832799911499023,3.6766599814097085,3.6700600186983743,3.6634700099627175,3.656890014807383,3.6503300070762634,3.643780012925466,3.6372299989064536,3.6306999723116555,3.6241899927457175,3.617679993311564,3.611180007457733,3.604699989159902,3.598229984442393,3.5917699734369912,3.585319976011912,3.5788899858792624,3.5724599957466125,3.5660500129063926,3.559649964173635,3.5532599488894143,3.5468900005022683,3.5405200123786926,3.5341699719429016,3.5278200109799704,3.521489997704824,3.5151699781417847,3.508860011895498,3.5025699933369956,3.496279994646708,3.4900099833806357,3.4837400118509927,3.477489988009135,3.471249977747599,3.465020000934601,3.458810031414032,3.4525999824206033,3.446400006612142,3.440219978491465,3.434049963951111,3.4278900027275085,3.421740015347799,3.4156000216801963,3.4094699819882712,3.403349975744883,3.397249976793925,3.3911499778429666,3.385070006052653,3.3789999882380166,3.3729299902915955,3.3668799996376038,3.3608399828275046,3.354819973309835,3.3487999637921653,3.3427900274594626,3.3368000189463296,3.330810010433197,3.324840009212494,3.318870027860006,3.312920033931732,3.306980013847351,3.301049987475077,3.295129974683126,3.2892199754714966,3.2833200097084045,3.277429978052775,3.2715499798456826,3.2656799952189126,3.2598300178845725,3.2539800008138022,3.2481499711672464,3.2423200011253357,3.2365100185076394,3.230699976285299,3.224910000960032,3.219129979610443,3.2133599718411765,3.207600017388662,3.2018399834632874,3.1960999965667725,3.190369963645935,3.1846500039100647,3.178940018018087,3.173240005970001,3.167550027370453,3.1618799964586892,3.1562099854151406,3.1505500276883445,3.1448999842007956,3.1392600337664285,3.133640011151632,3.1280199885368347,3.122409999370575,3.1168099840482077,3.11122997601827,3.105649987856547,3.1000799934069314,3.094530006249746,3.0889799992243447,3.0834400057792664,3.0779199798901877,3.072399993737539,3.066890001296997,3.061399976412455,3.0559100111325583,3.0504299998283386,3.044969995816549,3.0395100116729736,3.034059981505076,3.0286200046539307,3.023199995358785,3.017779986063639,3.012370010217031,3.0069699883461,3.001579980055491,2.996209979057312,2.990839978059133,2.9854799707730613,2.9801299969355264,2.974790016810099,2.9694599906603494,2.9641399582227073,2.958830018838247,2.9535199999809265,2.948229968547821,2.9429499904314675,2.9376800060272217,2.9324099818865457,2.9271600047747293,2.921920041243235,2.9166799982388816,2.911459982395172,2.906240006287893,2.9010299841562905,2.8958399891853333,2.890649994214376,2.8854700128237405,2.8803000251452127,2.8751400113105774,2.8699899911880493,2.864850024382273,2.85971999168396,2.8546000123023987,2.8494799931844077,2.844379981358846,2.8392800092697144,2.8342000444730124,2.8291199803352356,2.824050009250641,2.818999985853831,2.8139500419298806,2.8089100122451782,2.8038800160090127,2.7988499999046326,2.793840010960897,2.7888400157292685,2.78383998076121,2.7788599928220115,2.7738799850145974,2.768910010655721,2.7639500300089517,2.759000023206075,2.754059990247091,2.7491299907366433,2.7442100246747336,2.739290018876394,2.7343900005022683,2.729490021864573,2.7246100306510925,2.719729999701182,2.7148600021998086,2.709999998410543,2.705139974753062,2.7002999981244407,2.695460001627604,2.6906399925549827,2.685819983482361,2.6810100277264914,2.676210045814514,2.6714199980099997,2.666639963785807,2.6618600289026895,2.657099962234497,2.652339975039164,2.647590001424154,2.6428499619166055,2.6381199757258096,2.633400022983551,2.6286799709002175,2.6239799857139587,2.619279980659485,2.614589969317118,2.609909991423289,2.6052400271097818,2.600580016771952,2.595919986565908,2.5912699898084006,2.586639960606893,2.5820099910100303,2.5773800015449524,2.5727699995040894,2.5681699911753335,2.5635700027147927,2.5589800079663596,2.554400006930033,2.5498299797376,2.545260012149811,2.540709992249807,2.5361600120862327,2.5316200256347656,2.5270899732907615,2.522570013999939,2.518049975236257,2.5135499636332193,2.511300027370453};
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480095783869426,4.563908696174622,4.607059081395467,4.679479122161865,4.755329012870789,4.834629058837891,4.917379180590312,4.999519149462382,5.077009201049805,5.149829268455505,5.217999339103699,5.281519333521525,5.340379476547241,5.394579490025838,5.44413944085439,5.48902956644694,5.529279589653015,5.56585967540741,5.599769671758016,5.6310096979141235,5.659589687983195,5.685489694277446,5.708719770113627,5.729279796282451,5.747179826100667,5.762409885724385,5.7749598026275635,5.785939852396647,5.796409885088603,5.806389888127645,5.815869927406311,5.824849883715312,5.833329916000366,5.841309865315755,5.848789930343628,5.855769872665405,5.862259944279988,5.868359883626302,5.874189933141072,5.879769881566365,5.885069926579793,5.890109936396281,5.894879976908366,5.899389942487081,5.9036299387613935,5.907609939575195,5.911319891611735,5.914829969406128,5.918189962704976,5.92139991124471,5.924469908078511,5.927389979362488,5.93015988667806,5.932789921760559,5.935279965400696,5.937609990437825,5.939800024032593,5.941879987716675,5.943870027860005,5.945769985516866,5.9475899537404375,5.949319998423259,5.950969934463501,5.95252001285553,5.953999956448873,5.955379923184712,5.956689953804016,5.957910021146138,5.959059993426005,5.960130016009013,5.961139996846517,5.962070027987163,5.96291987101237,5.963710029919942,5.964420040448506,5.965059955914815,5.965619921684265,5.9661100308100385,5.966530005137126,5.966879963874817,5.967150052388509,5.967350006103516,5.967479944229126,5.96754002571106,5.967519998550415,5.967429995536804,5.967269976933797,5.967060009638469,5.966860016187032,5.966650009155273,5.966440002123515,5.966230034828186,5.966019988059998,5.965800046920776,5.965579986572266,5.965359965960185,5.965129971504211,5.964899977048238,5.964669903119405,5.9644399881362915,5.964209993680318,5.963970025380452,5.963729977607727,5.963479995727539,5.963239947954814,5.962990005811055,5.962740023930867,5.962490042050679,5.96222996711731,5.9619700113932295,5.961709976196289,5.961449980735779,5.961180011431376,5.960910081863403,5.960639953613281,5.960360010464986,5.960080027580261,5.959809978802999,5.959520022074382,5.959240039189656,5.958950002988179,5.958659927050273,5.958370010058085,5.958069960276286,5.957769989967346,5.957470019658406,5.957169969876607,5.956860105196635,5.9565500020980835,5.956239978472392,5.9559299548467,5.955609997113545,5.955289999643962,5.954970002174377,5.954649964968364,5.954320033391316,5.953990022341411,5.953660011291504,5.953319986661275,5.952980041503906,5.952640016873677,5.952299992243449,5.951949954032898,5.951609969139099,5.951260010401408,5.950899998346965,5.950549999872844,5.9501899878184,5.949829975763957,5.949460069338481,5.949100097020467,5.948729991912842,5.948359966278076,5.947989980379741,5.947609941164653,5.947229941685994,5.946849981943767,5.946459968884786,5.946079969406128,5.945689956347148,5.945289969444275,5.944899996121724,5.944499969482422,5.94409994284312,5.943699995676677,5.9432899951934814,5.942890048027039,5.942480007807414,5.9420599937438965,5.941649993260701,5.941230018933614,5.940810004870097,5.9403800169626875,5.9399599234263105,5.93953005472819,5.93909998734792,5.938660025596619,5.93822995821635,5.937789996465047,5.937349955240886,5.936900019645691,5.936450004577637,5.936010003089905,5.9355500141779585,5.935099959373474,5.934639970461528,5.934179981549581,5.933720032374064,5.933259924252828,5.932789961496989,5.93231999874115,5.9318400621414185,5.93136998017629,5.930890003840129,5.930410027503967,5.929930051167806,5.929440021514893,5.928950031598409,5.928460041681926,5.9279699722925825,5.927470048268636,5.9269700050354,5.926470081011455,5.925969958305359,5.9254599412282305,5.9249500433603925,5.924440105756124,5.9239199956258135,5.923409978548686,5.922889947891235,5.922369996706645,5.921839992205302,5.921309987703959,5.920789996782939,5.920250058174133,5.919719974199931,5.919180075327556,5.91863997777303,5.918089985847473,5.917549967765808,5.91700001557668,5.916450023651123,5.915900031725566,5.915340065956116,5.914780060450236,5.914219975471497,5.913660009702046,5.913089990615845,5.912519971529643,5.9119499524434405,5.911379973093669,5.910800019900004,5.9102199872334795,5.909639994303386,5.909060001373291,5.908469994862874,5.907880067825317,5.907289981842041,5.906700015068054,5.906109968821208,5.905520002047221,5.904930035273234,5.904339989026387,5.903749982515971,5.903160015741984,5.902569969495137,5.901979962984721,5.901390035947164,5.9008000294367475,5.9002099831899,5.899620016415914,5.8990300099054975,5.89843996365865,5.897849996884664,5.8972599903742475,5.896669983863831,5.896080017089844,5.895490050315857,5.894899964332581,5.894309997558594,5.893720030784607,5.893129944801331,5.892539978027344,5.891950011253357,5.891359965006511,5.890769958496094,5.890179951985677,5.88958998521169,5.889009952545166,5.888420025507609,5.887830018997192,5.887240012486775,5.886650085449219,5.886059959729512,5.885469992955525,5.884880026181539,5.884300033251445,5.883710026741028,5.883119901021321,5.882529973983765,5.881940046946208,5.881350040435791,5.880770007769267,5.88017996152242,5.879589994748433,5.878999988238017,5.87841002146403,5.877829988797505,5.877239982287089,5.876649936040242,5.876059929529826,5.875480016072591,5.874890089035034,5.874299963315328,5.873710036277771,5.8731300830841064,5.8725399573644,5.871950030326843,5.871359984079997,5.870779951413472,5.870189944903056,5.869600017865499,5.869019985198975,5.868429978688558,5.867840011914571,5.867259979248047,5.86667001247406,5.866080005963643,5.865499973297119,5.8649100462595625,5.8643200397491455,5.863739927609761,5.863150080045064,5.862559994061788,5.861980001131694,5.861389994621277,5.860810001691182,5.860219995180766,5.859629988670349,5.859049956003825,5.858459989229838,5.8578799565633135,5.857290029525757,5.856699983278911,5.856119990348816,5.855530023574829,5.854949990908305,5.854360024134318,5.8537799914677935,5.853189984957377,5.852609992027283,5.852019906044006,5.851439952850342,5.850850025812785,5.850269953409831,5.849679986635844,5.84910003344218,5.848510026931763,5.847929954528809,5.847340067227681,5.846759994824727,5.846169988314311,5.8455900351206465,5.844999988873799,5.8444199959437055,5.843829989433289,5.843250036239624,5.84266996383667,5.842080036799113,5.841499964396159,5.840909997622172,5.840330004692078,5.839739958445231,5.839160005251567,5.838580012321472,5.837990005811055,5.837409933408101,5.8368299802144366,5.8362399737040205,5.835660060246785,5.835080027580261,5.834489981333415,5.83390998840332,5.8333200216293335,5.8327399889628095,5.832159956296285,5.83158000310262,5.830989996592204,5.830410003662109,5.829829970995585,5.8292399644851685,5.828660051027934,5.82807997862498,5.827489932378133,5.826909979184468,5.826329946517944,5.82575003306071,5.825159986813863,5.824580033620198,5.823999961217244,5.82342000802358,5.822830041249593,5.822250008583069,5.821670015652974,5.82109002272288,5.820509950319926,5.819919943809509,5.819339990615845,5.818759957949321,5.818179965019226,5.817600051561992,5.817010045051575,5.816429853439331,5.815849979718526,5.815269947052002,5.814689954121907,5.814110000928243,5.813530047734578,5.812940001487732,5.812360048294067,5.811780015627543,5.811200022697449,5.810619990030925,5.8100399573644,5.809460004170735,5.808879971504211,5.808299978574117,5.807709972063701,5.807129939397176,5.806549986203511,5.805970033009847,5.805390000343323,5.804809967676799,5.804230014483134,5.8036500215530396,5.803069988886516,5.802489995956421,5.801910003026326,5.801329970359802,5.800750017166138,5.800170024236043,5.799589991569519,5.799009998639424,5.7984300057093305,5.797849973042806,5.797270019849141,5.796690026919047,5.7961099942525225,5.795530001322429,5.794949968655904,5.794370015462239,5.793789982795715,5.793210029602051,5.7926299174626665,5.792050004005432,5.79148002465566,5.790899991989136,5.790319959322612,5.789739966392517,5.7891600131988525,5.788579980532329,5.788000027338664,5.787420034408569,5.786840001742045,5.786270062128703,5.785690069198608,5.785110076268514,5.78453000386556,5.783950010935466,5.783370018005371,5.782799998919169,5.782219926516215,5.78164005279541,5.781060020128886,5.780479947725932,5.7798999945322675,5.779330054918925,5.778750061988831,5.778170029322307,5.777590036392212,5.77702001730601,5.7764400243759155,5.775859951972961,5.775279998779297,5.774700045585632,5.77413006623586,5.7735499540964765,5.772970000902812,5.77240006128947,5.771820028622945,5.771240035692851,5.7706600824991865,5.770090063412984,5.76950991153717,5.768929998079936,5.768360018730164,5.76777998606364,5.767199993133545,5.766629934310913,5.766050020853679,5.765469988187154,5.7649000485738116,5.764320015907288,5.763739983240764,5.763170003890991,5.762880007425944};
    //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174865216016769,0.6330969333648682,0.643390953540802,0.6585559298594793,0.6744409302870432,0.691046933333079,0.7083739389975866,0.7255739321311315,0.741797943909963,0.7570439428091049,0.7713159422079722,0.7846119552850723,0.7969329605499903,0.8082789530356725,0.8186499625444412,0.8280469675858816,0.8364689747492472,0.844123974442482,0.8512199769417444,0.857756977279981,0.8637349804242452,0.8691529780626297,0.8740119884411494,0.8783109833796819,0.8820519894361496,0.8852329899867376,0.8878569900989532,0.8901499956846237,0.8923379927873611,0.8944210012753805,0.8963989913463593,0.8982729911804199,0.9000419974327087,0.9017060051361719,0.9032659828662872,0.9047209868828455,0.9060709923505783,0.9073420117298762,0.9085579862197241,0.9097179919481277,0.910821999112765,0.9118709961573283,0.9128639946381251,0.9137999961773554,0.9146809975306193,0.915505995353063,0.9162760029236475,0.9170020073652267,0.9176990042130152,0.9183649917443594,0.9189999997615814,0.9196049968401591,0.9201789945363998,0.9207219928503036,0.9212339967489243,0.9217169930537542,0.9221670031547546,0.9225939909617106,0.9230039964119593,0.9233939995368322,0.9237670004367828,0.9241220007340113,0.9244589954614639,0.924777994553248,0.9250790029764175,0.9253619958957037,0.9256269981463751,0.9258760015169779,0.9261089960734049,0.9263260066509247,0.9265279968579611,0.9267150014638901,0.9268879890441895,0.9270449976126353,0.9271870106458664,0.9273120065530142,0.9274219969908396,0.9275170018275579,0.9275979896386465,0.9276640017827352,0.927713006734848,0.9277470062176386,0.9277659952640533,0.9277709970871607,0.9277610033750534,0.9277339975039164,0.9276920010646185,0.9276419927676519,0.927590991059939,0.9275400042533875,0.9274859974781672,0.9274329990148544,0.9273800005515417,0.9273259987433752,0.9272730052471161,0.9272179951270422,0.9271610130866369,0.9271049996217092,0.927047997713089,0.9269919991493225,0.926936000585556,0.9268770068883896,0.9268180032571157,0.9267579962809881,0.9266990025838217,0.9266390005747477,0.9265800019105276,0.9265179981788,0.926455999414126,0.9263929973045985,0.9263300001621246,0.9262680063645045,0.9262029975652695,0.9261370003223419,0.9260720014572144,0.9260060042142868,0.9259399970372518,0.9258739997943243,0.925806999206543,0.9257379919290543,0.925668994585673,0.925599992275238,0.9255309998989105,0.9254619975884756,0.9253920068343481,0.9253200044234594,0.9252479871114095,0.9251750012238821,0.9251029988129934,0.9250310063362122,0.9249579956134161,0.9248829980691274,0.9248079905907313,0.9247319996356964,0.924656997124354,0.9245819946130117,0.9245049903790156,0.9244270026683807,0.924348995089531,0.9242710024118423,0.9241920014222463,0.9241129954655966,0.9240310043096542,0.9239499966303507,0.9238689988851547,0.923786997795105,0.9237060050169627,0.9236229906479517,0.923538992802302,0.9234539916117986,0.9233699987332026,0.9232849975426992,0.9232010046641032,0.9231149951616923,0.9230269988377889,0.9229400008916855,0.9228519996007284,0.9227649917205175,0.9226769953966141,0.9225880056619644,0.9224979976812998,0.9224070012569427,0.9223160048325857,0.9222260067860285,0.9221329937378565,0.9220400005578995,0.9219459990660349,0.9218519975741705,0.9217589994271597,0.9216650029023489,0.9215699930985769,0.9214729964733124,0.9213759998480479,0.9212789932886759,0.9211820016304652,0.9210859884818395,0.9209869901339213,0.9208870033423106,0.9207870016495386,0.9206879933675131,0.9205880016088486,0.9204879999160767,0.9203860064347585,0.9202829847733179,0.9201799978812536,0.9200770010550817,0.9199750026067098,0.9198699990908304,0.9197639971971512,0.9196580002705256,0.9195519934097925,0.9194460014502207,0.9193399995565414,0.919231986006101,0.9191229989131292,0.9190140018860499,0.9189050048589706,0.9187960028648376,0.9186870008707047,0.9185760021209717,0.9184639950593313,0.9183509995539983,0.9182389974594116,0.9181270003318787,0.9180150081713995,0.9179009993871053,0.9177859971920649,0.917671004931132,0.9175549944241842,0.9174400021632513,0.9173249950011572,0.9172080010175705,0.9170900036891302,0.9169709881146749,0.916853000720342,0.916734998424848,0.9166150043408076,0.9164930035670599,0.9163720011711121,0.9162509987751642,0.9161289980014166,0.9160080005725225,0.915884996453921,0.9157600005467733,0.9156359980503718,0.9155109971761703,0.9153869996468226,0.9152630021174749,0.9151370127995809,0.9150090018908182,0.9148809959491094,0.9147540032863617,0.9146259973446528,0.9144989997148514,0.9143700003623962,0.9142389943202337,0.914108986655871,0.9139780004819235,0.9138480027516683,0.9137170116106669,0.9135869989792506,0.913455992937088,0.9133260051409403,0.9131950040658315,0.9130650063355764,0.9129339953263601,0.912803997596105,0.9126730014880499,0.912542998790741,0.9124130060275396,0.9122819950183233,0.9121520072221756,0.9120219945907593,0.9118909935156504,0.9117610057195028,0.9116310079892477,0.911501000324885,0.9113699992497762,0.9112399965524673,0.9111099988222122,0.9109800010919571,0.9108499983946482,0.9107200006643931,0.9105899979670843,0.9104600002368292,0.9103299975395203,0.9101989964644114,0.9100689937671026,0.9099390059709549,0.909809003273646,0.9096799939870834,0.9095499962568283,0.9094199985265732,0.909290000796318,0.9091600080331167,0.9090299954017004,0.9088999976714452,0.9087700049082438,0.9086400071779887,0.9085110078255335,0.9083809852600098,0.9082510024309158,0.9081210047006607,0.9079920003811518,0.907861997683843,0.9077319949865341,0.907602995634079,0.9074729979038239,0.9073429902394613,0.9072140008211136,0.9070839981238047,0.9069550087054571,0.9068250060081482,0.9066950033108393,0.9065659940242767,0.9064360012610754,0.9063069919745127,0.9061779926220576,0.9060479998588562,0.9059190005064011,0.9057890027761459,0.9056599885225296,0.9055300007263819,0.9054009964068731,0.905271997054418,0.9051420092582703,0.9050129999717077,0.9048839956521988,0.9047549962997437,0.9046249936024348,0.9044960041840872,0.9043669998645782,0.9042380005121231,0.904109001159668,0.9039789984623591,0.9038499941428503,0.9037209997574488,0.9035920004049937,0.9034630010525385,0.9033340017000834,0.9032049973805746,0.9030760029951731,0.9029469986756643,0.9028179993232092,0.902688999970754,0.9025600055853525,0.9024310012658437,0.9023020019133886,0.9021730025609335,0.902044008175532,0.9019159972667694,0.901787002881368,0.9016579985618591,0.901528999209404,0.9013999948898951,0.9012719939152399,0.9011430044968923,0.9010139952103297,0.9008849958578745,0.9007569998502731,0.900628000497818,0.9004989961783091,0.9003710101048151,0.9002420057853063,0.9001139948765436,0.899985005458196,0.8998559961716334,0.8997279951969782,0.8995990057786306,0.8994709948698679,0.899342010418574,0.8992140044768652,0.89908500512441,0.8989569991827011,0.898828998208046,0.8987000038226446,0.8985720028479894,0.898443008462588,0.8983150025208791,0.898187001546224,0.8980589956045151,0.8979299912850062,0.897801990310351,0.8976739992698034,0.8975449999173483,0.8974170039097468,0.8972890029350916,0.8971609969933828,0.8970330109198889,0.8969050000111262,0.8967760056257248,0.8966479947169622,0.8965200036764145,0.8963919977347056,0.8962639917929968,0.896136000752449,0.8960079997777939,0.895879993836085,0.8957519829273224,0.8956240018208822,0.8954959859450659,0.8953680048386256,0.8952399988969167,0.8951130112012228,0.8949849903583527,0.8948569993178049,0.8947289983431498,0.8946009973684946,0.8944730013608932,0.8943460086981455,0.8942180027564367,0.8940900017817816,0.8939619958400726,0.8938350031773249,0.8937069972356161,0.8935789962609609,0.8934519986311594,0.8933239976565043,0.8931970000267029,0.8930689990520477,0.8929410030444463,0.8928139954805374,0.8926859945058823,0.8925589968760809,0.8924310008684794,0.8923040082057317,0.8921759972969691,0.8920490046342214,0.8919209937254587,0.8917940060297648,0.891666998465856,0.8915389974912008,0.8914120097955068,0.8912849922974905,0.8911570062239965,0.8910300036271414,0.8909030059973398,0.8907750050226847,0.8906479924917221,0.8905209998289744,0.890394002199173,0.8902669996023178,0.8901390085617701,0.8900120009978613,0.8898850033680598,0.8897580007712046,0.8896310031414032,0.889504000544548,0.8893769979476929,0.8892500003178915,0.88912300268809,0.8889959951241811,0.8888690024614334,0.8887419998645782,0.8886149972677231,0.8884879996379217,0.8883610020081202,0.8882340043783188,0.8881070017814636,0.8879800091187159,0.8878529965877533,0.8877269923686981,0.8875999947388967,0.8874729971090952,0.8873460044463476,0.8872189968824387,0.8870929926633835,0.8869659950335821,0.8868390023708344,0.8867129981517792,0.8865860005219778,0.8864589929580688,0.8863330036401749,0.8862060060103735,0.8860790034135183,0.8859529991944631,0.885825996597608,0.8857000023126602,0.885572999715805,0.8854470004638036,0.8853200078010559,0.8851940085490545,0.8850670059521993,0.8849410067001978,0.8848150024811426,0.8846879998842875,0.8845620006322861,0.8844349980354309,0.8843089938163757,0.884182999531428,0.8840559969345728,0.8839299976825714,0.8838040083646774,0.8836780041456223,0.8835510015487671,0.8834250072638193,0.8832989980777105,0.8831730037927628,0.8830469995737076,0.8829210003217062,0.8827940026919047,0.8826679984728495,0.8825419942537943,0.8824159999688467,0.8822900056838989,0.8822269986073176};
    //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194626147548357,0.18438400203982988,0.18693500136335692,0.18957200025518736,0.19233599926034609,0.19522600000103316,0.19824199999372163,0.20123599966367087,0.20405899981657663,0.20671100169420242,0.20919200032949448,0.2115010010699431,0.21363899980982146,0.2156050018966198,0.21739999949932098,0.21902400006850561,0.2204779994984468,0.221796998133262,0.22301799803972244,0.22414100294311842,0.22516499956448874,0.22609199956059456,0.22692099958658218,0.22765100002288818,0.22828400135040283,0.22881900270779928,0.2292550007502238,0.2296340006093184,0.22999399776260057,0.23033400004108748,0.23065700257817903,0.2309609999259313,0.23124799877405167,0.23151699950297674,0.23176699752608934,0.23199700067440668,0.23221000035603842,0.23240800077716509,0.23259799803296724,0.23277800033489862,0.23294900233546892,0.23310900231202444,0.23325800150632858,0.23339800039927164,0.23352900023261705,0.23365000014503798,0.23376199851433435,0.2338659999271234,0.23396400113900503,0.23405799766381583,0.2341459977130095,0.23422900214791298,0.23430600141485533,0.23437700172265372,0.23444200058778128,0.2345029997328917,0.2345579999188582,0.23460900162657103,0.2346580016116301,0.23470300187667212,0.2347439986964067,0.2347820003827413,0.23481800158818564,0.23484999934832254,0.23487899949153265,0.23490400115648905,0.23492800196011862,0.23494799931844076,0.23496599992116293,0.23498199880123138,0.2349929983417193,0.2350010002652804,0.23500699922442436,0.23500899970531464,0.23500999932487807,0.2350070004661878,0.23500200112660727,0.23499500130613646,0.2349849989016851,0.2349720001220703,0.2349570021033287,0.23493999863664308,0.23491900165875754,0.23489700009425482,0.23487100129326186,0.23484399914741516,0.23481300100684166,0.23478100076317787,0.2347500001390775,0.23471799865365028,0.23468700051307678,0.23465499778588614,0.2346230000257492,0.23459200064341226,0.23456000164151192,0.23452899729212126,0.2344969982902209,0.2344650017718474,0.2344339999059836,0.2344010000427564,0.23436700304349264,0.2343329998354117,0.23429900035262108,0.2342640000085036,0.23423000052571297,0.2341959998011589,0.23416199907660484,0.23412799959381422,0.23409400011102358,0.2340599981447061,0.23402600114544234,0.2339920016626517,0.2339579996963342,0.23392400021354356,0.23389000073075294,0.23385600000619888,0.23382199928164482,0.2337879997988542,0.23375400031606355,0.23371999834974608,0.23368600010871887,0.23365199814240137,0.2336180011431376,0.23358399917682013,0.23354899883270264,0.23351200173298517,0.23347599928577742,0.2334389997025331,0.23340299973885217,0.2333660013973713,0.23333000019192696,0.23329300060868263,0.2332569994032383,0.23322000106175741,0.23318399861454964,0.2331480011343956,0.23311099906762442,0.23307500034570694,0.23303800200422606,0.23300200079878172,0.23296600207686424,0.23292900249361992,0.23289299756288528,0.23285599797964096,0.23282000174125037,0.23278400053580603,0.2327469972272714,0.23271099974711737,0.23267499978343645,0.23263700058062872,0.23259800175825754,0.23255900045235953,0.2325199991464615,0.23248199746012688,0.23244299987951914,0.23240399981538454,0.23236499975124994,0.23232599968711534,0.23228800048430762,0.23224899793664613,0.23221000035603842,0.23217099905014038,0.23213200022776923,0.23209400102496147,0.23205499971906343,0.23201599965492883,0.23197699834903082,0.23193899790445963,0.23189999908208847,0.23186100025971731,0.23182200019558272,0.23178399975101152,0.23174499720335007,0.2317059983809789,0.23166599993904433,0.23162500063578287,0.23158399884899458,0.2315429983039697,0.23150199900070825,0.2314600000778834,0.2314189982910951,0.23137799898783365,0.23133699968457222,0.2312960003813108,0.23125500107804933,0.23121299967169762,0.2311720003684362,0.23113100106517473,0.23108999927838644,0.23104900121688843,0.23100800067186356,0.23096700012683868,0.23092600082357725,0.23088499903678894,0.23084300011396408,0.2308019995689392,0.23076100026567778,0.2307199997206529,0.23067900041739145,0.23063700025280318,0.23059300084908804,0.2305499998231729,0.23050600041945776,0.23046299691001573,0.2304190012315909,0.23037600268920264,0.23033200204372406,0.23028900101780891,0.23024499913056692,0.23020200182994208,0.2301579974591732,0.2301149989167849,0.23007100075483322,0.23002800097068152,0.22998400032520294,0.22994100054105124,0.2298969974120458,0.22985399886965752,0.22981100156903267,0.2297670009235541,0.22972399865587553,0.2296799992521604,0.22963700195153555,0.22959399968385696,0.229548999418815,0.22950299829244614,0.22945699840784073,0.22941100100676218,0.22936499988039336,0.2293200008571148,0.22927400097250938,0.22922799984614053,0.2291819987197717,0.22913599759340286,0.2290899989505609,0.22904499992728233,0.22899900004267693,0.22895299891630808,0.2289070002734661,0.22886100163062414,0.22881600012381872,0.22877000023921332,0.22872399787108103,0.2286780004700025,0.2286330002049605,0.22858699907859167,0.22854100043574968,0.22849500055114427,0.22844999904433885,0.22840399915973345,0.22835799803336462,0.2283130002518495,0.2282669978837172,0.2282210004826387,0.22817600021759668,0.22813000033299127,0.22808500130971274,0.22803900142510733,0.22799300029873848,0.22794799755016962,0.2279020001490911,0.2278569998840491,0.22781100248297056,0.22776500011483827,0.22771999736626944,0.22767399872342745,0.22762900094191232,0.22758299857378006,0.2275379995505015,0.22749200090765953,0.2274469994008541,0.2274009995162487,0.22735600173473358,0.22731000060836473,0.2272649991015593,0.22721900045871735,0.22717400019367537,0.22712899868686995,0.22708299880226454,0.22703799853722254,0.22699199989438057,0.22694699838757515,0.22690199936429659,0.22685600196321806,0.2268109992146492,0.22676600019137064,0.22671999782323837,0.2266750012834867,0.2266289989153544,0.22658399865031242,0.22653899962703386,0.22649399936199188,0.22644800071914992,0.2264030004541079,0.2263579989473025,0.22631199906269708,0.22626700128118196,0.22622200101613998,0.22617699826757112,0.22613099838296571,0.22608600184321404,0.22604100281993547,0.22599599758783975,0.22595100228985152,0.2259049986799558,0.2258599984149138,0.22581500063339868,0.2257700003683567,0.22572500010331473,0.2256799985965093,0.22563499957323074,0.22558900093038878,0.22554399818181992,0.22549899791677794,0.22545399889349937,0.2254089986284574,0.22536400084694228,0.22531900058190027,0.22527399907509485,0.2252290000518163,0.22518400102853775,0.22513899952173233,0.22509399925669035,0.22504900147517523,0.2250039999683698,0.2249589984615644,0.22491400068004927,0.22486900041500726,0.22482399890820184,0.2247789998849233,0.22473400086164474,0.22468899935483932,0.22464400033156076,0.22459900006651878,0.2245539998014768,0.22450900077819824,0.22446400051315626,0.2244190014898777,0.22437399998307228,0.2243299980958303,0.22428500155607858,0.22424000004927316,0.22419499854246774,0.22414999827742577,0.2241049992541472,0.2240610010921955,0.22401599834362665,0.2239709993203481,0.2239259990553061,0.22388100003202757,0.22383700187007585,0.22379200036327043,0.22374700009822845,0.22370199983318648,0.22365800167123476,0.22361300140619278,0.22356799989938736,0.2235230008761088,0.22347900023063025,0.22343400120735168,0.22338899970054626,0.22334500029683113,0.22330000003178915,0.22325499852498373,0.223211000363032,0.22316600009799004,0.22312199945251146,0.22307699918746948,0.22303200140595436,0.22298799827694893,0.22294299801190695,0.22289800023039183,0.2228539983431498,0.2228090005616347,0.2227649986743927,0.22272000089287758,0.2226759990056356,0.22263100246588388,0.22258699933687845,0.22254199783007303,0.2224980021516482,0.22245299940307936,0.22240900248289108,0.2223639984925588,0.2223200003306071,0.2222750000655651,0.22223099693655968,0.22218599915504456,0.22214199850956598,0.22209799910585085,0.22205299884080887,0.22200900067885718,0.22196399917205176,0.22191999852657318,0.22187599912285805,0.22183100134134293,0.22178699945410094,0.22174199794729552,0.22169800102710724,0.22165399913986525,0.22160900011658669,0.22156500071287155,0.22152100006739298,0.22147599856058756,0.2214320016403993,0.22138799851139387,0.2213440015912056,0.22129899884263673,0.22125500192244849,0.2212110012769699,0.22116699938972792,0.2211219978829225,0.22107799972097078,0.22103399907549223,0.2209899996717771,0.22094600026806197,0.22090099876125655,0.22085700059930483,0.2208130011955897,0.22076899806658426,0.22072499866286913,0.22068099801739058,0.22063600023587546,0.22059200083216032,0.2205479989449183,0.22050399954120317,0.22046000137925148,0.2204159994920095,0.22037200008829436,0.22032800068457922,0.22028400003910065,0.22023999939362207,0.22019599998990694,0.2201520005861918,0.22010800118247667,0.22006399929523468,0.2200199986497561,0.2199760004878044,0.21993200108408928,0.21988800168037415,0.2198439985513687,0.21979999914765358,0.21975599974393845,0.2197120003402233,0.21966800093650818,0.2196239990492662,0.2195799984037876,0.21953600024183592,0.21949199959635735,0.21944799895087877,0.21940399954716364,0.21936099976301193,0.2193170003592968,0.21927299971381822,0.21922899906833967,0.21918499966462454,0.2191410002609094,0.21909699961543083,0.21905399983127913,0.219010000427564,0.21896600102384886,0.21892199913660684,0.21887800097465515,0.21883500119050345,0.21879099806149802,0.2187469998995463,0.21870299925406775,0.21866000071167946,0.21861600006620088,0.21857199942072233,0.21852900087833405,0.21848500023285547,0.21844100082914034,0.2183969977001349,0.2183539979159832,0.2183099997540315,0.2182660015920798,0.21822300180792809,0.2181790011624495,0.21813599889477095,0.21809199824929237,0.21804800257086754,0.2180050015449524,0.2179609996577104,0.21791699901223183,0.2178959995508194};
    //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.1268943833808104,0.12773999944329262,0.1286780002216498,0.12961400051911673,0.1305949998398622,0.13162299742301306,0.13269499937693277,0.1337589994072914,0.13476200277606645,0.13570299992958704,0.13658200080196062,0.13740000128746033,0.13815499966343245,0.13884800051649412,0.13947899887959161,0.14004800096154213,0.14055499931176504,0.14101399978001913,0.14143799990415573,0.14182500168681145,0.14217700064182281,0.14249399676918983,0.14277500038345656,0.1430209999283155,0.1432309982677301,0.14340599874655405,0.143545001745224,0.14366300031542778,0.1437740003069242,0.1438790000975132,0.14397799968719482,0.14407000069816908,0.1441550018886725,0.14423400163650513,0.14430499946077666,0.14436999956766763,0.1444300003349781,0.14448400090138117,0.14453400174776712,0.14458199962973595,0.14462499817212424,0.14466499785582224,0.14470000068346658,0.14473200092713037,0.1447600002090136,0.14478499939044318,0.14480600009361902,0.14482500031590462,0.14484200129906336,0.1448570005595684,0.14487100020051003,0.14488299811879793,0.144891998420159,0.14489899824062982,0.1449039988219738,0.14490700016419092,0.14490899940331778,0.14490900188684464,0.14490799978375435,0.14490600054462752,0.14490299920241037,0.14489799986282983,0.14489300176501274,0.14488599946101507,0.14487800126274428,0.14486899971961975,0.14485899979869524,0.14484800025820732,0.14483599861462912,0.1448229985932509,0.14480900019407272,0.14479399969180426,0.14477899918953577,0.14476100107034048,0.14474299922585487,0.14472400024533272,0.14470400040348372,0.1446840005616347,0.14466199899713197,0.144640002399683,0.14461599911252657,0.14459099993109703,0.14456500113010406,0.14453800270954767,0.14451099808017412,0.14448199793696404,0.1444530002772808,0.1444230005145073,0.14439300075173378,0.14436299974719682,0.1443329999844233,0.1443030002216498,0.14427299921711287,0.14424300069610277,0.14421299969156584,0.14418299992879233,0.1441530001660188,0.1441230004032453,0.14409300064047179,0.14406299963593483,0.14403299987316132,0.1440030001103878,0.1439730003476143,0.14394300058484077,0.14391299958030382,0.1438829985757669,0.14385300129652023,0.14382300029198328,0.14379299928744635,0.14376300076643625,0.14373299976189932,0.1437029999991258,0.143672996511062,0.1436409999926885,0.14360900099078813,0.14357799788316092,0.14354599888126054,0.14351499949892363,0.14348299925525984,0.14345200111468634,0.14342000087102255,0.14338900024692217,0.14335699876149496,0.14332500100135803,0.14329399913549423,0.1432620001335939,0.1432309995094935,0.1431989980240663,0.14316799864172935,0.1431370029846827,0.14310499901572862,0.1430739996333917,0.14304200063149133,0.14301100000739098,0.1429789997637272,0.14294800038139024,0.1429160013794899,0.1428849995136261,0.14285400013128915,0.14282199988762537,0.142790999263525,0.14275900150338808,0.14272799963752428,0.14269699901342392,0.14266500001152357,0.14263399690389633,0.1426030012468497,0.14257099851965904,0.1425399991373221,0.14250900348027548,0.1424770007530848,0.142445998887221,0.14241499826312065,0.1423829992612203,0.14235199987888336,0.142320999254783,0.14228899901111922,0.14225799962878227,0.14222700024644533,0.14219599962234497,0.14216399813691774,0.14213200161854425,0.14209900051355362,0.14206700026988983,0.1420339991648992,0.14200100054343542,0.1419680006802082,0.141935000816981,0.14190199971199036,0.14186899984876314,0.14183600122729936,0.14180300136407217,0.1417699990173181,0.14173800125718117,0.14170500015219054,0.14167199904719988,0.14163899794220924,0.14160599932074547,0.1415729969739914,0.14154099921385446,0.14150800183415413,0.14147499948740005,0.14144200086593628,0.14140900100270906,0.14137699951728186,0.14134400089581808,0.14131099979082742,0.14127799992760023,0.14124600092569986,0.14121299982070923,0.141179999957482,0.14114800095558167,0.14111499985059103,0.14108199874560037,0.14104900136590004,0.1410169998804728,0.14098400001724562,0.14095100263754526,0.14091900115211806,0.14088600128889084,0.14085400104522705,0.14082099745670953,0.14078799883524576,0.14075600107510886,0.1407229999701182,0.14069000134865442,0.14065800110499063,0.14062499875823656,0.14059299727280936,0.140559999893109,0.1405279996494452,0.14049399892489114,0.14046000192562738,0.14042600244283676,0.14039099837342897,0.1403570013741652,0.14032300064961115,0.14028899868329367,0.14025399958093962,0.14021999885638556,0.1401859993735949,0.1401519998908043,0.14011800164977709,0.14008400092522302,0.14004899933934212,0.1400150010983149,0.13998100037376085,0.13994699840744337,0.13991300016641617,0.1398789994418621,0.1398450012008349,0.13981000209848085,0.1397759976486365,0.13974200064937273,0.1397079974412918,0.13967400044202805,0.13963999847571054,0.13960600023468336,0.13957200075189272,0.13953799878557524,0.1395039993027846,0.13946999981999397,0.1394359990954399,0.1394019996126493,0.13936800137162209,0.13933400064706802,0.13929999992251396,0.13926600043972334,0.1392320009569327,0.13919799899061522,0.13916399950782457,0.1391300012667974,0.1390959993004799,0.13906199981768927,0.13902800157666206,0.138994000852108,0.13896100223064423,0.13892700026432672,0.13889299829800925,0.13885900129874548,0.13882500057419142,0.13879100233316422,0.1387570003668467,0.13872400298714638,0.13869000102082887,0.1386559990545114,0.13862199832995734,0.13858800008893013,0.13855399936437607,0.1385210007429123,0.13848700126012167,0.13845300301909447,0.13841899981101355,0.13838599994778633,0.13835199798146883,0.1383180022239685,0.13828400149941444,0.13825100163618723,0.13821700091163316,0.1381830001870791,0.13815000280737877,0.13811599711577097,0.13808200135827065,0.13804799939195314,0.13801499952872595,0.1379810000459353,0.13794700180490813,0.13791400069991747,0.13788000121712685,0.13784700011213621,0.1378129981458187,0.1377789999047915,0.13774600004156431,0.13771200055877367,0.13767899945378304,0.13764499997099242,0.13761100048820177,0.13757799938321114,0.13754400238394737,0.1375110000371933,0.13747700055440268,0.13744399944941202,0.13741000120838484,0.13737700010339418,0.13734300062060356,0.13730999951561293,0.13727600127458572,0.13724299892783165,0.13720899944504103,0.1371759995818138,0.1371420013407866,0.13710899899403253,0.13707499826947847,0.1370419996480147,0.13700900102655092,0.13697499906023344,0.13694199919700623,0.13690800095597902,0.1368750035762787,0.13684200247128805,0.1368079992632071,0.13677499939997992,0.1367419995367527,0.13670800005396208,0.136674997707208,0.13664200032750765,0.13660799960295358,0.1365750009814898,0.13654200111826262,0.13650799915194511,0.1364749992887179,0.1364419994254907,0.13640799994270006,0.13637500007947287,0.13634200021624565,0.13630900035301843,0.13627499962846437,0.13624199976523718,0.13620899990200996,0.1361760012805462,0.13614299893379211,0.1361090006927649,0.13607599834601083,0.13604299972454706,0.13601000110308328,0.13597699999809265,0.1359429992735386,0.13591000189383826,0.13587699830532074,0.13584399968385696,0.1358110010623932,0.13577799995740256,0.13574500133593878,0.13571200023094812,0.1356779970228672,0.13564500088493028,0.13561199977993965,0.13557899867494902,0.13554599756995836,0.13551300019025803,0.1354799990852674,0.13544700170556703,0.1354140006005764,0.13538099949558577,0.13534799963235855,0.13531499976913133,0.13528199990590414,0.13524900004267693,0.1352160001794497,0.13518300031622252,0.13514999921123186,0.13511699934800467,0.1350840007265409,0.13505099962155023,0.13501799975832304,0.13498500113685927,0.1349520000318686,0.13491900016864142,0.13488700240850449,0.13485399881998697,0.13482100144028664,0.13478799909353256,0.1347550004720688,0.13472199936707815,0.1346889982620875,0.13465600088238716,0.13462399815519652,0.1345910020172596,0.13455799842874208,0.1345249998072783,0.13449200118581453,0.13446000218391418,0.13442700107892355,0.13439400121569633,0.1343610001107057,0.13432800024747849,0.13429600124557814,0.13426300014058748,0.1342300002773603,0.13419699917236963,0.13416500017046928,0.13413200030724207,0.13409899920225143,0.1340670002003511,0.13403399909536043,0.13400099923213324,0.133968997746706,0.13393599912524223,0.13390300422906876,0.13387100026011467,0.13383800039688745,0.13380500177542368,0.13377300028999647,0.13374000042676926,0.13370700056354204,0.13367499907811484,0.13364199921488762,0.13360999897122383,0.13357700034976006,0.13354400172829628,0.13351200024286905,0.13347900162140527,0.13344700013597807,0.1334139990309874,0.13338199878732362,0.1333490014076233,0.13331699868043265,0.13328400005896887,0.13325199981530508,0.13321899995207787,0.13318699970841408,0.13315399984518686,0.13312200084328651,0.13308899973829588,0.1330569994946321,0.13302400211493173,0.13299200062950453,0.13295899952451387,0.13292699928085008,0.1328949990371863,0.13286199669043222,0.13283000265558562,0.13279700030883154,0.13276500130693117,0.13273299982150397,0.13269999995827675,0.13266799847284952,0.13263499860962233,0.13260299836595854,0.13257099936405817,0.13253799950083098,0.1325060004989306,0.13247400149703026,0.13244200001160303,0.13240900014837584,0.1323770023882389,0.13234499966104826,0.1323120010395845,0.1322800007959207,0.13224799931049347,0.13221599658330283,0.13218299920360246,0.13215100144346556,0.13211899995803833,0.13208699971437454,0.13205399985114732,0.13202200084924698,0.1319900006055832,0.13195799912015596,0.13192600011825562,0.13189399987459183,0.1318610000113646,0.13182899976770082,0.13179699704051018,0.13176499928037325,0.13173299903670946,0.1317010000348091,0.13166900103290877,0.1316359999279181,0.13160399968425432,0.13157199944059053,0.13154000043869019,0.13150800143678984,0.1314759999513626,0.13144399970769882,0.13142800082763037};
    C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.2843470374743144,0.28996000190575916,0.29544300337632495,0.30197900036970776,0.308828001221021,0.3159899984796842,0.32346299787362415,0.3308789978424708,0.33786900093158084,0.3444330021739006,0.35057299832503,0.35628799597422284,0.3615779976050059,0.36644300321737927,0.37088300039370853,0.3748989999294281,0.37849099934101105,0.3817489991585414,0.384762999912103,0.3875330040852229,0.3900600001215935,0.3923429995775223,0.3943830033143361,0.39617999643087387,0.3977339987953504,0.3990439996123314,0.40011099725961685,0.4010329991579056,0.40191000203291577,0.4027419959505399,0.40352799991766614,0.4042679990331332,0.404961995780468,0.40561000009377796,0.4062129979332288,0.4067699958880742,0.4072819997866948,0.40776000171899796,0.4082129995028178,0.4086409981052081,0.4090460017323494,0.4094259962439537,0.4097819949189822,0.41011399775743484,0.41042199979225796,0.4107059985399246,0.41096499810616177,0.4112050011754036,0.4114320029815038,0.4116449976960818,0.41184400022029877,0.41203099737564725,0.41220499326785404,0.41236599783102673,0.41251299778620404,0.4126469964782397,0.4127670004963875,0.41287700086832047,0.41297799348831177,0.41307199994723004,0.41315900534391403,0.41323699802160263,0.41330799957116443,0.4133709991971652,0.4134270002444585,0.4134740009903908,0.4135140006740888,0.41354699929555255,0.413572000960509,0.41359099994103116,0.4136030028263728,0.41360799719889957,0.4136069988210996,0.41359900186459225,0.41358500222365063,0.4135649998982747,0.41353699813286465,0.4135030036171277,0.41346200555562973,0.41341399649779004,0.41336000214020413,0.41329900175333023,0.4132319986820221,0.41315799951553345,0.4130780001481374,0.412991002202034,0.4128969957431157,0.41280099997917813,0.4127040033539136,0.41260800262292224,0.4125099976857503,0.41241200268268585,0.4123139977455139,0.4122149993975957,0.41211699942747754,0.41201899697383243,0.411920003592968,0.41182200113932294,0.4117230052749316,0.4116230010986328,0.4115230043729146,0.4114230001966159,0.4113230034708977,0.41122299432754517,0.41112300256888074,0.4110230008761088,0.41092299669981003,0.41082100321849185,0.41071900477011997,0.41061800221602124,0.41051600128412247,0.41041399786869687,0.4103130002816518,0.4102109993497531,0.4101089984178543,0.41000500073035556,0.40990199893713,0.4097989996274312,0.40969499945640564,0.4095920001467069,0.4094889983534813,0.40938599904378253,0.40928200135628384,0.4091769978404045,0.40907199680805206,0.4089670032262802,0.4088619997104009,0.4087569937109947,0.40865200012922287,0.40854700406392414,0.408440999686718,0.40833500524361926,0.4082279975215594,0.4081210022171338,0.4080150028069814,0.40790800005197525,0.4078020031253497,0.4076950003703435,0.40758800009886426,0.407479003071785,0.40737099945545197,0.40726299583911896,0.40715500215689343,0.40704600264628726,0.40693800151348114,0.40682999541362125,0.40672100087006885,0.40661100546518963,0.4065010001262029,0.4063909997542699,0.4062810018658638,0.40617099901040393,0.40606199701627094,0.40595199912786484,0.40584100286165875,0.4057289982835452,0.40561800201733905,0.4055059974392255,0.4053949962059657,0.40528299659490585,0.40517200777928036,0.4050600007176399,0.4049480011065801,0.4048350006341934,0.4047209993004799,0.40460800379514694,0.4044950008392334,0.40438199788331985,0.40426899989446,0.4041550010442734,0.40403999636570614,0.40392500162124634,0.40380999942620593,0.4036950021982193,0.4035799950361252,0.40346600363651913,0.40335100144147873,0.4032349983851115,0.40311900277932483,0.40300199886163074,0.4028859982887904,0.40276900430520374,0.4026530012488365,0.4025359998146693,0.4024199992418289,0.40230300029118854,0.40218500296274823,0.4020659998059273,0.4019479975104332,0.401829997698466,0.40171199788649875,0.40159399559100467,0.4014760007460912,0.4013570000727971,0.40123800188302994,0.4011180028319359,0.4009979988137881,0.40087799976269406,0.4007590015729268,0.40063900252183277,0.400518998503685,0.40039899945259094,0.4002770036458969,0.40015599876642227,0.40003499885400134,0.3999130030473073,0.39979200065135956,0.3996710032224655,0.3995499983429909,0.39942799756924313,0.39930399507284164,0.39918100585540134,0.3990590025981267,0.39893599847952527,0.39881300181150436,0.39868999769290286,0.398567001024882,0.3984430010120074,0.3983189985156059,0.39819399764140445,0.39806900173425674,0.39794500172138214,0.39782000333070755,0.39769599586725235,0.39757199833790463,0.39744599908590317,0.3973199973503749,0.3971940030654271,0.39706799884637195,0.39694099873304367,0.3968149969975154,0.3966890002290408,0.39656299849351245,0.3964359983801842,0.396307997405529,0.39618099977572757,0.3960529988010724,0.39592499782641727,0.3957970043023427,0.3956699992219607,0.39554199824730557,0.39541499813397724,0.39528699964284897,0.3951600020130475,0.39503200352191925,0.3949050009250641,0.39477699746688205,0.39464999735355377,0.3945229972402255,0.39439500123262405,0.3942680011192958,0.39414100100596744,0.39401400089263916,0.393886998295784,0.39376000314950943,0.39363300055265427,0.3935059979557991,0.39337900280952454,0.3932520002126694,0.3931250000993411,0.39299799501895905,0.39287200570106506,0.3927449931701024,0.39261799802382785,0.3924920012553533,0.3923649961749713,0.3922389994064967,0.39211199929316837,0.39198600004116696,0.3918589949607849,0.39173299570878345,0.39160599807898205,0.3914799988269806,0.39135399957497913,0.39122799535592395,0.3911009952425957,0.390975000957648,0.3908490017056465,0.39072299748659134,0.39059700071811676,0.39047099898258847,0.3903450022141139,0.39021899551153183,0.39009299874305725,0.3899679978688558,0.3898420011003812,0.3897159993648529,0.38959000011285144,0.38946499675512314,0.38933899501959485,0.38921400159597397,0.3890880023439725,0.3889629940191905,0.3888369972507159,0.38871199637651443,0.38858600209156674,0.3884609987338384,0.38833599785963696,0.3882100010911624,0.3880850002169609,0.38795999934275943,0.38783499598503113,0.38770999759435654,0.38758500168720883,0.38745999832948047,0.38733500242233276,0.3872100015481313,0.387084998190403,0.3869599997997284,0.3868349964420001,0.3867109989126523,0.386585995554924,0.3864609996477763,0.3863370046019554,0.3862120012442271,0.38608700533707935,0.38596300035715103,0.3858380044500033,0.38571400195360184,0.38559000194072723,0.38546499858299893,0.3853409985701243,0.3852169985572497,0.38509200016657513,0.38496800263722736,0.3848440001408259,0.38471999764442444,0.38459599763154984,0.38447200258572894,0.38434799760580063,0.384223997592926,0.3841000000635783,0.3839760000507037,0.38385200252135593,0.3837280000249545,0.3836050008734067,0.3834809983770053,0.3833569958806038,0.3832330008347829,0.38310999671618146,0.38298600415388745,0.38286300251881283,0.38273900002241135,0.3826160008708636,0.382492000857989,0.3823689992229144,0.3822459975878398,0.382122000058492,0.38199900339047116,0.38187599927186966,0.38175300012032193,0.381630003452301,0.3815069993336995,0.3813839976986249,0.3812609985470772,0.38113799691200256,0.38101500272750854,0.3808920035759608,0.38076899697383243,0.3806460003058116,0.3805230036377907,0.38040099541346234,0.38027800371249515,0.3801549995938937,0.3800330013036728,0.37991000215212506,0.37978799889485043,0.3796649972597758,0.3795429989695549,0.37941999981800717,0.37929800152778625,0.3791760007540385,0.3790529991189639,0.3789309983452161,0.37880900005499524,0.37868699928124744,0.3785640026132266,0.3784419968724251,0.37832000106573105,0.3781979978084564,0.3780759970347087,0.3779540037115415,0.37783200045426685,0.3777110030253728,0.3775889997680982,0.37746699899435043,0.3773449957370758,0.37722400079170865,0.37710199505090714,0.37698000172774,0.3768589993317922,0.37673699607451755,0.3766160011291504,0.37649400035540265,0.37637299795945484,0.3762509971857071,0.37613000224033993,0.3760089973608653,0.37588700155417126,0.37576599915822345,0.3756450017293294,0.37552399933338165,0.3754030019044876,0.3752820019920667,0.3751609995961189,0.3750400021672249,0.37491899977127713,0.3747979998588562,0.37467699746290845,0.3745560000340144,0.37443500260512036,0.37431400020917255,0.3741940011580785,0.3740730012456576,0.3739520013332367,0.3738319973150889,0.373710997402668,0.37359100331862766,0.3734700009226799,0.37335000435511273,0.3732289969921112,0.37310900042454404,0.3729880054791768,0.37286799649397534,0.3727479974428813,0.37262800087531406,0.37250800182422,0.37238700439532596,0.3722669978936513,0.37214699884255725,0.3720270022749901,0.3719069982568423,0.37178699920574826,0.3716670001546542,0.37154700110356015,0.3714280004302661,0.371308001379172,0.3711879973610242,0.3710680032769839,0.3709490050872167,0.3708290010690689,0.37070899456739426,0.3705899988611539,0.37047000229358673,0.37035100162029266,0.3702309976021449,0.37011199692885083,0.36999300370613736,0.3698730046550433,0.36975400149822235,0.36963499585787457,0.3695160001516342,0.3693960060675939,0.3692770053942998,0.369157999753952,0.3690389965971311,0.368919995923837,0.3688009977340698,0.36868199954430264,0.3685629988710086,0.36844400068124133,0.36832500249147415,0.36820700019598007,0.3680880020062129,0.36796899884939194,0.36785100400447845,0.3677319983641307,0.36761300017436344,0.3674950028459231,0.36737600217262906,0.367257999877135,0.3671390041708946,0.36702099690834683,0.36690200368563336,0.3667840013901393,0.36666600157817203,0.36654800176620483,0.3664289986093839,0.3663109963138898,0.3661930014689763,0.36607499917348224,0.36595699687798816,0.36583900451660156,0.3657210022211075,0.3656029999256134,0.36554399877786636};
    //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.1294005922973156,0.132747999082009,0.13621399799982706,0.1400279998779297,0.14402399957180023,0.14820099994540215,0.15255899727344513,0.15688399970531464,0.16096199924747148,0.164792001247406,0.168374997874101,0.17170999820033708,0.1747980018456777,0.17763799925645193,0.18023200208942095,0.18257800117135048,0.1846779982248942,0.18658299992481867,0.1883470006287098,0.18996800109744072,0.19144699970881143,0.19278399894634882,0.19398099929094315,0.19503499940037727,0.19594900061686835,0.19672000159819922,0.1973509999612967,0.19789699837565422,0.19841599961121878,0.1989089995622635,0.19937499860922495,0.19981599847475687,0.200229000300169,0.20061499749620756,0.20097600047787031,0.20131000007192293,0.20161699876189232,0.20190400009353957,0.2021769993007183,0.20243500173091888,0.2026800016562144,0.20291000107924143,0.20312700048089027,0.20332899813850722,0.20351700112223625,0.2036910019814968,0.2038499986131986,0.2039990002910296,0.20414100090662637,0.20427399997909865,0.20440000047286352,0.2045179990430673,0.20462900027632713,0.20473199958602586,0.20482699945569038,0.20491399864355722,0.2049939992527167,0.20506700004140535,0.20513600235184035,0.20519999787211418,0.2052600011229515,0.20531499882539114,0.2053659980495771,0.20541099831461906,0.20545299847920737,0.20548900092641512,0.2055209974447886,0.20554900045196214,0.20557300249735513,0.20559300109744072,0.20560899997750917,0.2056210016210874,0.2056289998193582,0.20563299829761186,0.20563399915893874,0.20563000068068504,0.2056229996184508,0.20561200131972632,0.20559700081745783,0.2055789977312088,0.20555599903066954,0.20553000022967657,0.20550000046690306,0.205465999742349,0.20542800053954124,0.2053859978914261,0.20534100010991096,0.2052939993639787,0.20524699985980988,0.20520000159740448,0.20515300085147223,0.20510599886377653,0.2050580009818077,0.20501000061631203,0.2049619990090529,0.20491300026575723,0.20486499865849814,0.20481600115696588,0.2047679995497068,0.2047199991842111,0.20467200006047884,0.20462300007541975,0.20457499970992407,0.20452599848310152,0.20447600136200586,0.2044260005156199,0.20437700177232423,0.20432699968417486,0.20427700007955232,0.20422799761096636,0.2041780004898707,0.20412799840172133,0.20407900214195251,0.20402799919247627,0.20397700121005377,0.20392599950234094,0.203875000278155,0.2038239985704422,0.2037730005880197,0.2037220001220703,0.2036709984143575,0.20362000043193498,0.20356900244951248,0.20351800074179968,0.20346599941452345,0.20341400181253752,0.20336100086569786,0.20330899953842163,0.2032559998333454,0.20320400098959604,0.2031510000427564,0.20309900119900703,0.2030469998717308,0.20299400140841803,0.20294199883937836,0.20288899913430214,0.2028349998096625,0.20278099924325943,0.2027279995381832,0.202674001455307,0.20261999840537706,0.20256600032250086,0.20251299689213434,0.20245899880925813,0.20240500072638193,0.20235099891821542,0.20229599997401237,0.20224099978804588,0.20218499998251596,0.20212999855478606,0.20207500085234642,0.20202000190814337,0.20196500172217688,0.2019099990526835,0.201854998866717,0.2018000011642774,0.20174400011698404,0.2016879990696907,0.2016310008863608,0.20157499983906746,0.2015179991722107,0.2014620006084442,0.20140499994158745,0.20134900013605753,0.20129300033052763,0.20123599966367087,0.2011800010999044,0.20112299919128418,0.20106500138839087,0.20100699986020723,0.20094900205731392,0.2008919989069303,0.2008339986205101,0.20077599957585335,0.20071900015076002,0.2006609986225764,0.20060300081968307,0.20054500177502632,0.2004870002468427,0.20042800034085909,0.20036899919311205,0.2003100017706553,0.20025100062290827,0.2001920019586881,0.20013199870785078,0.20007300128539404,0.200014000137647,0.19995499898989996,0.19989599908391634,0.19983499869704247,0.1997750016550223,0.19971400002638498,0.19965399925907454,0.19959300011396408,0.1995329993466536,0.19947300106287003,0.19941200067599615,0.19935199866692224,0.19929200038313866,0.1992310012380282,0.1991689975063006,0.1991070012251536,0.19904499997695288,0.19898400207360586,0.19892200082540512,0.19886000081896782,0.19879799957076708,0.19873700166742006,0.1986749991774559,0.19861399879058203,0.19855099668105444,0.19848800202210745,0.19842500115434328,0.19836200028657913,0.198298999418815,0.1982360010345777,0.1981730026503404,0.19811000178257623,0.19804699967304865,0.1979839988052845,0.19791999955972037,0.1978559990723928,0.19779200106859207,0.1977269984781742,0.19766300171613693,0.1975980003674825,0.19753399988015494,0.19747000063459078,0.19740599890549979,0.19734100128213564,0.19727700079480806,0.19721199944615364,0.1971459984779358,0.19708099837104479,0.19701500112811723,0.19694900264342627,0.1968840000530084,0.19681800281008086,0.19675200060009956,0.19668699925144514,0.1966209957997004,0.19655599941809973,0.1964899996916453,0.19642499958475432,0.19635899737477303,0.1962939997514089,0.1962280012667179,0.19616299867630005,0.19609799981117249,0.1960320013264815,0.19596699997782707,0.19590199987093607,0.1958360013862451,0.19577100003759065,0.19570599993069968,0.19564099982380867,0.19557500009735426,0.1955100012322267,0.19544499864180884,0.19537999853491783,0.1953149971862634,0.19524999956289926,0.19518499945600828,0.19511999934911728,0.19505500048398972,0.19499000161886215,0.19492500151197115,0.19485999643802643,0.19479499757289886,0.1947299987077713,0.19466499984264374,0.19459999973575273,0.19453500087062517,0.19446999952197075,0.19440600027640662,0.19434099892775217,0.19427600130438805,0.19421100119749704,0.19414599984884262,0.19408199936151505,0.19401700049638748,0.19395199914773306,0.1938879999021689,0.19382300227880478,0.19375899930795035,0.1936940016845862,0.19362900033593178,0.19356500109036764,0.1934999997417132,0.1934360017379125,0.19337099914749464,0.19330700238545737,0.1932429981728395,0.19317799930771193,0.19311400006214777,0.1930489999552568,0.19298499822616577,0.1929209977388382,0.19285599887371063,0.19279199714461961,0.19272799914081892,0.19266399865349135,0.19260000064969063,0.19253500178456306,0.19247100005547205,0.19240699832638106,0.19234300156434378,0.19227899983525276,0.19221500058968863,0.19215100010236105,0.19208699961503348,0.19202300036946932,0.19195899988214174,0.1918950006365776,0.19183100014925003,0.1917670009036859,0.19170299917459488,0.19163900117079416,0.19157500068346658,0.191511000196139,0.19144699970881143,0.19138400008281073,0.19131999959548315,0.191256000349919,0.191191998620828,0.19112900147835413,0.19106499974926314,0.19100099926193556,0.19093799963593483,0.19087399914860725,0.19081000114480653,0.19074699903527895,0.19068299854795137,0.19062000016371408,0.19055600091814995,0.19049300129214922,0.19042900080482164,0.19036600242058435,0.19030200193325678,0.19023899858196577,0.1901749980946382,0.1901120034356912,0.19004899884263673,0.1899849995970726,0.1899220012128353,0.18985900158683458,0.189795001099507,0.18973199898997942,0.18966900060574213,0.18960599849621454,0.18954200049241385,0.18947900210817656,0.18941600124041238,0.1893529991308848,0.1892900007466475,0.1892270011206468,0.18916400025288263,0.18910100062688193,0.1890380010008812,0.1889749988913536,0.18891200174887976,0.18884899963935217,0.18878600001335144,0.1887230003873507,0.18865999951958656,0.18859700237711272,0.18853399902582169,0.18847099939982095,0.18840900187691054,0.18834599976738295,0.18828299889961878,0.18822000175714493,0.18815800175070763,0.1880949983994166,0.18803200125694275,0.1879690003891786,0.1879070003827413,0.18784399951497713,0.18778200075030327,0.18771900112430254,0.1876560002565384,0.1875940002501011,0.18753100062410036,0.18746899937589964,0.1874059997498989,0.1873439997434616,0.1872819997370243,0.18721899762749672,0.18715700010458627,0.18709400172034898,0.18703200047214827,0.18696999922394753,0.18690700083971024,0.18684500083327293,0.18678300206859907,0.1867209995786349,0.18665799871087074,0.18659599746267,0.18653399993975958,0.18647199993332228,0.18641000365217528,0.1863469990591208,0.18628500029444695,0.18622300028800964,0.18616100028157234,0.18609900027513504,0.18603700026869774,0.18597500150402388,0.18591300025582314,0.18585100024938583,0.18578900148471197,0.1857270027200381,0.18566500023007393,0.18560400108496347,0.18554199983676276,0.185479998588562,0.1854179985821247,0.18535599733392397,0.18529399981101355,0.1852330006659031,0.18517099817593893,0.1851090006530285,0.18504800150791803,0.18498600025971731,0.18492400025328,0.1848629998664061,0.1848009998599688,0.1847389998535315,0.18467800070842108,0.1846159982184569,0.18455499907334647,0.18449299906690916,0.18443200116356215,0.1843699999153614,0.18430899952848753,0.1842469982802868,0.18418600037693977,0.1841249999900659,0.18406299874186516,0.1840019983549913,0.18394099672635397,0.18387900044520697,0.18381800005833307,0.1837569996714592,0.18369599928458533,0.18363399927814802,0.18357300013303757,0.18351199850440025,0.1834509993592898,0.18339000021417937,0.18332800020774206,0.18326699857910475,0.18320600067575774,0.18314499904712042,0.1830840011437734,0.18302299827337265,0.18296200037002563,0.18290099874138832,0.18283999959627786,0.18277899796764055,0.18271800006429353,0.18265799805521965,0.1825969989101092,0.18253599976499876,0.18247499813636145,0.18241400023301443,0.18235299984614053,0.18229300156235695,0.18223200117548308,0.18217099954684576,0.18211000164349875,0.18204999963442484,0.1819890004893144,0.18192800134420395,0.18186800057689348,0.18180700143178305,0.18174699942270914,0.18168599903583527,0.1816249998907248,0.18156499912341437,0.18150399749477705,0.18144400045275688,0.18138300130764642,0.1813229980568091,0.18126199891169867,0.18123200039068857};
    //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09222368150949478,0.09350250040491422,0.09476710110902786,0.09621809981763363,0.09773850068449974,0.09932910030086835,0.10098999987045924,0.10263800000150998,0.10418999878068765,0.10564700017372768,0.10700999945402145,0.10827699986596902,0.10944899978737037,0.11052599921822548,0.11150900026162465,0.11239700081447761,0.11318900001545747,0.11390699942906697,0.11456999989847343,0.11517800018191338,0.11573200114071369,0.11623199967046578,0.11667799949645996,0.11706999937693278,0.11740699969232082,0.11769000006218751,0.117917999625206,0.11811400018632412,0.11829900058607261,0.11847399920225143,0.11863899976015091,0.11879399977624416,0.11893800025184949,0.11907300104697545,0.11919800005853176,0.11931200015048186,0.11941699932018916,0.11951300005118053,0.11960299996038277,0.11968799990912278,0.11976799989740054,0.11984199906388919,0.1199109988907973,0.11997399851679802,0.12003200066586335,0.12008400013049443,0.12013100025554498,0.1201740000396967,0.12021400158603986,0.12025100054840247,0.12028599965075652,0.12031799865265687,0.12034599979718526,0.12037199983994167,0.12039400016268094,0.12041400000452995,0.12043000074724357,0.1204450000077486,0.12045700040956338,0.12046799995005131,0.12047600063184898,0.12048300107320149,0.12048800041278203,0.12049200013279915,0.120493999371926,0.12049399875104427,0.12049299975236256,0.12048999903102715,0.1204860011736552,0.1204800009727478,0.120471000050505,0.1204619991282622,0.120451000208656,0.12043900042772293,0.12042499954501788,0.12041000028451283,0.12039399954179923,0.12037600018084049,0.12035700057943662,0.12033600049714248,0.12031399955352147,0.12028899975121021,0.12026399994889896,0.120236000046134,0.12020800014336903,0.12017799975971381,0.12014700099825859,0.1201150007545948,0.12008300051093102,0.1200509996463855,0.12001899878184001,0.11998699853817622,0.119955999776721,0.11992400077482064,0.11989200053115685,0.11985999966661136,0.119828000664711,0.11979700004061063,0.11976499979694684,0.11973199993371964,0.11969900007049243,0.11966600082814693,0.11963299972315629,0.11959999985992908,0.11956699999670188,0.11953400013347466,0.11950100027024746,0.11946799978613853,0.11943499930202961,0.11940200005968411,0.11936900019645691,0.1193360003332297,0.11930299984912078,0.11926999998589356,0.11923699950178464,0.11920400025943916,0.11917099915444851,0.1191379992912213,0.11910500004887581,0.11907199956476688,0.11903900094330311,0.11900600045919418,0.1189740002155304,0.11894099973142147,0.11890700024863084,0.11887299952407678,0.11883900004128616,0.1188049999376138,0.11877000021437804,0.11873600073158741,0.11870200000703335,0.11866799990336101,0.11863400042057037,0.11860000031689803,0.1185660008341074,0.11853200010955334,0.1184980006267627,0.11846400052309036,0.11842899955809116,0.11839500131706397,0.11836099997162819,0.11832699986795585,0.1182929997642835,0.11825900090237458,0.11822499955693881,0.1181910013159116,0.11815799959003925,0.11812400072813034,0.118090000624458,0.11805500090122223,0.11801999993622303,0.11798399997254212,0.11794900024930637,0.11791399990518887,0.1178789995610714,0.11784399983783563,0.11780799925327301,0.11777300077180068,0.11773799918591976,0.11770299946268399,0.11766799973944823,0.11763300063709418,0.11759700005253156,0.11756199970841408,0.11752699998517831,0.11749200026194255,0.11745699991782506,0.11742199833194415,0.11738699985047181,0.11735200074811776,0.11731700040400028,0.1172820000598828,0.11724700033664703,0.11721199999252956,0.11717600002884865,0.11713999944428603,0.11710300048192342,0.1170669998973608,0.11703100055456161,0.11699499934911728,0.11695800038675468,0.11692199980219205,0.11688599921762943,0.11685000049571197,0.1168129996707042,0.11677700032790501,0.11674099912246068,0.11670500040054321,0.1166689998159806,0.11663200085361798,0.11659599964817365,0.11655999968449275,0.11652400034169356,0.11648800099889438,0.11645199917256832,0.11641599982976913,0.11637999924520652,0.1163430002828439,0.11630699969828129,0.11627100097636382,0.11623299929002921,0.11619599970678489,0.11615899950265884,0.11612099967896938,0.11608400009572506,0.11604599965115388,0.11600900006790955,0.11597200048466523,0.11593499903877576,0.11589699983596802,0.11586000087360541,0.11582300004859765,0.11578600046535333,0.11574799939990044,0.11571100043753783,0.11567400023341179,0.11563700002928574,0.11559900020559628,0.11556200000147025,0.11552499979734421,0.11548800021409988,0.11545099938909213,0.11541400042672952,0.11537700022260348,0.11533900039891402,0.1152999997138977,0.11526199989020824,0.11522400006651878,0.1151850006232659,0.11514700017869473,0.11510800011456013,0.11507000029087067,0.1150320004671812,0.11499299916128318,0.11495500057935715,0.11491699951390426,0.11487799944976966,0.1148400002469619,0.11480199918150902,0.11476399935781956,0.11472499991456668,0.11468699884911378,0.11464900026718776,0.11461099920173486,0.11457299999892712,0.11453400055567424,0.11449600011110306,0.1144580002874136,0.11441999984284242,0.11438200064003468,0.11434400081634521,0.11430599975089233,0.11426700092852116,0.11422899924218655,0.11419099941849709,0.1141529989739259,0.11411500039199989,0.1140769999474287,0.11403899950285752,0.1140010009209315,0.1139629998554786,0.11392499879002571,0.1138870008289814,0.11384900100529194,0.11381100118160248,0.1137730007370313,0.11373500029246013,0.1136980007092158,0.1136599996437629,0.11362199919919173,0.11358399937550227,0.11354599955181281,0.11350800096988678,0.11346999990443389,0.11343300032118957,0.1133950004975001,0.11335700067381065,0.11331899898747604,0.11328100040555,0.11324399958054225,0.1132060003777345,0.11316800055404504,0.11313000073035558,0.11309299990534782,0.11305499946077664,0.11301699901620547,0.11297999943296115,0.1129420002301534,0.11290400040646394,0.11286699958145618,0.11282899975776672,0.1127920001745224,0.11275400035083294,0.11271599990626176,0.11267900094389915,0.11264099987844627,0.11260400029520194,0.11256599985063076,0.11252900026738644,0.11249099982281525,0.11245399961868922,0.11241599979499976,0.11237899834911029,0.11234100038806598,0.11230399956305821,0.11226600036025047,0.112228998914361,0.1121919999519984,0.11215400012830894,0.11211699992418289,0.11207899885873,0.11204200051724911,0.11200500031312306,0.11196699924767017,0.11192999966442585,0.11189300008118153,0.1118560004979372,0.11181800005336602,0.11178099984923999,0.11174400026599567,0.11170599982142448,0.11166899899641673,0.11163199941317241,0.11159499982992808,0.11155799962580204,0.1115200004229943,0.11148299959798653,0.11144600063562393,0.11140900043149789,0.11137199960649014,0.11133500064412753,0.11129799857735634,0.11126100085675716,0.11122300041218598,0.11118600020805995,0.1111490000039339,0.11111199979980786,0.11107499959568183,0.11103800001243751,0.11100100042919318,0.11096399960418542,0.11092699940005939,0.11088999981681506,0.1108529989918073,0.11081599940856297,0.11077899982531865,0.11074300048251946,0.11070599903662999,0.11066899945338567,0.11063199987014134,0.11059499966601531,0.11055799884100755,0.11052100049952666,0.1104839996745189,0.11044800095260143,0.11041099888583024,0.11037400054434936,0.11033699971934159,0.11030000013609727,0.11026400017241637,0.11022699996829033,0.110190000385046,0.1101530014226834,0.11011700021723907,0.11008000063399474,0.1100430004298687,0.11000699922442436,0.10997000088294347,0.10993300067881744,0.10989700071513653,0.10985999989012878,0.10982400054732959,0.10978699972232182,0.1097500001390775,0.10971400079627831,0.10967699997127056,0.10964100062847137,0.10960400042434533,0.10956799983978271,0.10953099901477496,0.10949499967197578,0.10945800008873145,0.10942199888328712,0.10938499930004279,0.1093489999572436,0.10931199913223584,0.10927599978943665,0.10923900144795577,0.10920300086339314,0.10916699965794881,0.10912999945382278,0.10909399949014187,0.10905699990689754,0.10902099994321664,0.10898499997953574,0.10894800039629142,0.10891200105349223,0.1088759998480479,0.10883999988436699,0.1088030015428861,0.10876700033744176,0.10873099975287914,0.10869499978919824,0.1086579995850722,0.1086219996213913,0.10858599903682868,0.1085499996940295,0.10851400035123031,0.10847700014710426,0.10844100018342336,0.10840499959886074,0.10836900025606155,0.10833300153414409,0.10829699970781803,0.10826099912325542,0.10822500040133794,0.10818799895544846,0.108152000233531,0.10811599964896838,0.10807999968528748,0.10804400034248829,0.10800800037880738,0.10797200041512649,0.10793600045144558,0.10790000048776467,0.10786399990320206,0.10782799931863944,0.10779300021628539,0.10775699963172276,0.10772099966804187,0.10768499970436096,0.10764900036156178,0.10761299977699916,0.10757700043419997,0.10754099984963734,0.10750499988595645,0.10747000016272068,0.10743399957815807,0.10739799961447716,0.10736200089255969,0.10732600030799706,0.10729100120564301,0.10725500000019868,0.10721899941563606,0.10718299945195515,0.1071480003496011,0.10711199976503849,0.10707600104312102,0.1070409994572401,0.1070049994935592,0.10696899890899658,0.10693400042752425,0.10689800046384335,0.10686200050016244,0.10682699891428153,0.10679100019236405,0.10675600109001,0.10672000050544739,0.10668399930000305,0.10664900081853072,0.10661299961308639,0.10657800113161404,0.10654200054705143,0.10650700020293395,0.10647100023925304,0.10643599989513557,0.10639999993145466,0.10636500082910061,0.10632899962365627,0.1062939999004205,0.10625900079806645,0.10622299897174041,0.10618799924850464,0.10615199928482373,0.10611699956158797,0.10608199921747048,0.10604600049555302,0.1060109989096721,0.10597600042819977,0.10594000046451886,0.10590500012040138,0.10586999915540218,0.105833999812603,0.10579900071024895,0.10576399974524975,0.10574599914252758};
    CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.83401044209798,82.68911743164062,83.15021260579427,83.91901270548503,84.71141370137532,85.5274149576823,86.3671137491862,87.20191383361816,88.00341351826985,88.77161343892415,89.50651168823242,90.20801226298015,90.87631034851074,91.51130930582683,92.11300977071126,92.68140856424968,93.21650822957356,93.71990712483723,94.19330724080403,94.63650703430176,95.0496056874593,95.43270556131999,95.7856051127116,96.10850461324056,96.40130424499512,96.6640027364095,96.89660326639812,97.11090405782063,97.31850306193034,97.51950454711914,97.71390279134114,97.90170351664226,98.0828030904134,98.2573013305664,98.42520205179851,98.58640225728352,98.74100176493327,98.89090220133464,99.03780110677083,99.1818021138509,99.32290204366048,99.46110153198242,99.59640185038249,99.72880172729492,99.85830116271973,99.98480224609375,100.10800298055013,100.23000208536784,100.35000165303548,100.46800104777019,100.58500226338704,100.70000139872234,100.81400108337402,100.927001953125,101.03700192769368,101.14700190226237,101.25400161743164,101.3610013326009,101.46600087483723,101.57000096638997,101.67200152079265,101.77400143941243,101.87400182088216,101.97200139363606,102.07000160217285,102.16600100199382,102.26100158691406,102.35500144958496,102.44600168863933,102.53600184122722,102.62500127156575,102.71200116475423,102.79700088500977,102.88000106811523,102.96200180053711,103.04200108846028,103.1200008392334,103.19600041707356,103.27100118001302,103.34400113423665,103.41600163777669,103.4860013326009,103.55400149027507,103.62000147501628,103.6850020090739,103.74799982706706,103.80900065104167,103.86900075276692,103.9290002187093,103.9880002339681,104.04700152079265,104.10600090026855,104.16400146484375,104.22200012207031,104.27899996439616,104.33600107828777,104.39300155639648,104.44900004069011,104.50400161743164,104.56000137329102,104.61400032043457,104.6690018971761,104.72300084431966,104.77600161234538,104.82900047302246,104.8820006052653,104.93400065104167,104.9860013326009,105.0380007425944,105.08900133768718,105.1390012105306,105.19000053405762,105.23900032043457,105.28900210062663,105.33800061543782,105.38600158691406,105.43400192260742,105.48200098673503,105.52899932861328,105.57600084940593,105.6230017344157,105.66900126139323,105.7140007019043,105.76000022888184,105.80400085449219,105.84900029500325,105.89300028483073,105.93600145975749,105.97899945576985,106.02200126647949,106.06400044759114,106.1059996287028,106.14800135294597,106.18900108337402,106.22899945576985,106.26900100708008,106.30900001525879,106.34800020853679,106.38700040181477,106.42599995930989,106.4640007019043,106.50200017293294,106.53899955749512,106.57600021362305,106.61200014750163,106.64800071716309,106.68400128682454,106.7189998626709,106.75400098164876,106.7880007425944,106.82200113932292,106.85600026448567,106.88899993896484,106.92100016276042,106.95400110880534,106.98499997456868,107.01700083414714,107.04800160725911,107.07800038655598,107.10800043741862,107.13800112406413,107.16800053914388,107.19600105285645,107.22500101725261,107.25300025939941,107.28100077311198,107.30800120035808,107.33499972025554,107.36100006103516,107.38700040181477,107.4130007425944,107.43800099690755,107.46300061543782,107.48700141906738,107.51100095113118,107.53399976094563,107.55700047810872,107.5800011952718,107.6019999186198,107.6240005493164,107.64600054423015,107.66599909464519,107.6870002746582,107.70699946085612,107.72700055440266,107.74600028991699,107.76500002543132,107.78400039672852,107.80200131734212,107.81900024414062,107.83699989318848,107.85300064086914,107.87000020345052,107.88600158691406,107.90100034077962,107.91600036621094,107.93100102742513,107.94500096638997,107.95900090535481,107.9729995727539,107.98600006103516,107.99899991353352,108.01100031534831,108.0230000813802,108.03400039672852,108.04500007629395,108.0549996693929,108.06599934895833,108.07500012715657,108.08499972025554,108.09299977620442,108.1019999186198,108.11000061035156,108.11800003051758,108.12499936421712,108.13199996948242,108.13799985249837,108.14400100708008,108.15000025431316,108.15500005086263,108.15899976094563,108.164000193278,108.16800117492676,108.17100079854329,108.1740010579427,108.17700004577637,108.1790002187093,108.18099975585938,108.18199984232585,108.1830005645752,108.18400065104167,108.1839993794759,108.18299929300944,108.18299992879231,108.1820011138916,108.17999903361003,108.17800013224284,108.17599932352702,108.17400042215984,108.17199961344402,108.16900062561035,108.16700045267741,108.1649996439616,108.16300010681152,108.16099993387859,108.15900039672852,108.15600077311198,108.15399996439616,108.1520004272461,108.15000025431316,108.14799944559734,108.14600054423015,108.14399909973145,108.14099947611491,108.13899930318196,108.1369997660319,108.13499959309895,108.1330000559489,108.13100115458171,108.12800153096516,108.1259994506836,108.12399991353352,108.1219991048177,108.11999956766765,108.1179993947347,108.11499913533528,108.11300150553386,108.11100069681804,108.10899925231934,108.10699971516927,108.10500017801921,108.10199928283691,108.10000038146973,108.09800020853679,108.09600003560384,108.0939998626709,108.09200096130371,108.08899943033855,108.0869992574056,108.08499972025554,108.08300081888835,108.0810006459554,108.07899920145671,108.07600021362305,108.07400004069011,108.07199986775716,108.07000096638997,108.06800079345703,108.06600125630696,108.06400044759114,108.06100018819173,108.0589993794759,108.05699984232585,108.05500030517578,108.05300076802571,108.05099995930989,108.04799906412761,108.04600016276042,108.04400062561035,108.04199918111165,108.04000027974446,108.0380007425944,108.03499921162923,108.03299903869629,108.0310001373291,108.02899996439616,108.02699979146321,108.02500025431316,108.02199999491374,108.01999982198079,108.01800028483073,108.01600074768066,108.0140012105306,108.01199913024902,108.01000022888184,108.00699996948242,108.0049991607666,108.00300025939941,108.00100008646648,107.99899927775066,107.99700037638347,107.99399948120117,107.99200057983398,107.98999913533528,107.98800086975098,107.98600069681804,107.98399988810222,107.98099899291992,107.97899945576985,107.9769999186198,107.97500038146973,107.9729995727539,107.97100003560384,107.96799977620442,107.96600023905437,107.9640007019043,107.96199989318848,107.9600003560384,107.95800081888835,107.95600001017253,107.95299975077312,107.95100021362305,107.94900004069011,107.94700050354004,107.94499905904134,107.94299952189128,107.93999989827473,107.93800099690755,107.93600018819173,107.93400001525879,107.93199857076009,107.9299996693929,107.92700004577637,107.92499987284343,107.92299906412761,107.92099952697754,107.91899998982747,107.91699918111165,107.91500091552734,107.91200065612793,107.90999984741211,107.90800031026204,107.9060001373291,107.90399996439616,107.9020004272461,107.89900016784668,107.89699872334798,107.89499918619792,107.89299964904785,107.89100074768066,107.88899930318196,107.88600031534831,107.88399887084961,107.88199996948242,107.8799991607666,107.8780008951823,107.87600008646648,107.8740005493164,107.87100028991699,107.86900011698405,107.8669999440511,107.86499913533528,107.86299959818523,107.86099942525227,107.85800043741862,107.8559996287028,107.85400072733562,107.85200055440266,107.85000038146973,107.84799893697102,107.84500058492024,107.8430004119873,107.84100023905437,107.83900006612141,107.8369992574056,107.83500099182129,107.83300018310547,107.82999928792317,107.82799975077312,107.82599957784016,107.82400067647298,107.82200050354004,107.81999969482422,107.81700070699056,107.81499989827473,107.81300099690755,107.81099955240886,107.80900065104167,107.80699984232585,107.80399958292644,107.80199940999348,107.8000005086263,107.79800033569336,107.79599952697754,107.79399871826172,107.79199918111165,107.789000193278,107.78700002034505,107.78499984741211,107.78300094604492,107.78100140889485,107.77899996439616,107.77599970499675,107.77399889628093,107.77199872334798,107.77000045776367,107.76800028483073,107.76600011189778,107.76400057474773,107.76100031534831,107.75899887084961,107.75699996948242,107.7549991607666,107.75299898783366,107.7509994506836,107.74799982706706,107.74600028991699,107.74400011698405,107.74199867248535,107.73999977111816,107.7380002339681,107.73599942525227,107.73300043741862,107.7309996287028,107.72899945576985,107.72700055440266,107.72499974568684,107.7229995727539,107.71999931335449,107.7180004119873,107.71600087483723,107.7140007019043,107.71200052897136,107.70999972025554,107.70799954732259,107.70499928792317,107.70299975077312,107.70100021362305,107.69900067647298,107.69700050354004,107.69499905904134,107.69200007120769,107.68999989827473,107.68800099690755,107.68599955240886,107.68400001525879,107.68200047810872,107.68000030517578,107.67700004577637,107.6750005086263,107.67299969991048,107.67100016276042,107.66899998982747,107.66699981689453,107.66400082906087,107.66200065612793,107.66000111897786,107.65799967447917,107.65600077311198,107.65399932861328,107.65199915568034,107.64900016784668,107.64699935913086,107.64500045776367,107.64299901326497,107.64200019836426};
    //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761748274167378,1.4129199981689453,1.4510700205961864,1.4901300072669983,1.5303899844487507,1.5718500018119812,1.6145099997520447,1.6569099922974904,1.6975899934768677,1.7365399996439617,1.773779998222987,1.809299995501836,1.8431000113487244,1.8751799861590068,1.9055399894714355,1.9341900050640106,1.9611299932003021,1.9864299992720287,2.010179986556371,2.032389998435974,2.0530399878819785,2.072140018145243,2.0896899700164795,2.105699976285299,2.1201600233713784,2.1330699920654297,2.1444300214449563,2.1548499862353006,2.164930005868276,2.1746599872907004,2.1840500036875405,2.19309002161026,2.201799988746643,2.21016001701355,2.218180000782013,2.2258500258127847,2.2331899801890054,2.240280012289683,2.247219999631246,2.2539999882380166,2.2606399854024253,2.2671199838320413,2.27346001068751,2.2796299854914346,2.2856599489847818,2.291539986928304,2.2972700198491416,2.3028800090154014,2.308410028616587,2.3138699928919473,2.3192400137583413,2.3245400190353394,2.3297500212987265,2.33488001426061,2.339939991633097,2.344919999440511,2.349819997946421,2.354640026887258,2.359399974346161,2.3640900254249573,2.36871999502182,2.3732799887657166,2.377769966920217,2.3821899692217507,2.386560022830963,2.3908499479293823,2.395080029964447,2.3992300232251487,2.403290013472239,2.407260000705719,2.4111499786376953,2.4149499932924905,2.41865998506546,2.422280013561249,2.425819993019104,2.4292699893315635,2.432629962762197,2.4358999927838645,2.4390800396601358,2.442170004049937,2.445180038611094,2.448099990685781,2.4509399930636087,2.4536799987157187,2.4563399950663247,2.4589099486668906,2.4613899985949197,2.4638100067774453,2.4662099877993264,2.468589981396993,2.4709500074386597,2.4732799927393594,2.4755899906158447,2.4778899947802224,2.480149984359741,2.4824000000953674,2.484630008538564,2.486830015977224,2.489009996255239,2.4911699891090393,2.49331001440684,2.4954300125439963,2.4975200096766152,2.4996000130971274,2.5016499757766724,2.5036799907684326,2.505680024623871,2.5076599717140198,2.5096200108528137,2.511560022830963,2.513470013936361,2.515369971593221,2.517239987850189,2.5190899769465127,2.5209200183550515,2.522729972998301,2.524519979953766,2.5262799859046936,2.5280200044314065,2.5297399957974753,2.531440019607544,2.5331199963887534,2.534779985745748,2.5364099939664206,2.5380199750264487,2.539609988530477,2.5411700010299683,2.5427200396855674,2.5442399779955545,2.545739988485972,2.547220011552175,2.548680007457733,2.5501100222269693,2.551519989967346,2.5529199639956155,2.554289996623993,2.5556400219599404,2.5569600065549216,2.55827001730601,2.559560000896454,2.560820003350576,2.562059978644053,2.563280006249746,2.5644800066947937,2.56564998626709,2.566799978415171,2.567930003007253,2.5690400203069053,2.570130010445913,2.5711899995803833,2.5722399751345315,2.573259969552358,2.5742600162823996,2.5752400159835815,2.576199988524119,2.5771299799283347,2.5780499974886575,2.578939994176229,2.5798099835713706,2.5806599855422974,2.5814900398254395,2.582299987475077,2.5830900271733603,2.583850006262461,2.584589978059133,2.5853099822998047,2.5860000252723694,2.5866799553235373,2.5873300035794577,2.587970018386841,2.588579992453257,2.589169998963674,2.589739978313446,2.5902900099754333,2.5908100406328836,2.591320017973582,2.5917999744415283,2.5922599832216897,2.592710018157959,2.5931299726168313,2.5935199658075967,2.5938899715741477,2.5942399899164834,2.594580034414927,2.594880004723867,2.595169981320699,2.5954399704933167,2.5956900119781494,2.5959100325902305,2.5961099664370217,2.5962999860445657,2.596459984779358,2.5965999960899353,2.5967200001080832,2.596809983253479,2.5968899925549827,2.596939980983734,2.596980015436808,2.5969900091489158,2.5969799955685935,2.596939961115519,2.5968899925549827,2.596809983253479,2.596719980239868,2.5965999960899353,2.596460004647573,2.5962999860445657,2.596119999885559,2.5959200263023376,2.5956900318463645,2.595449964205424,2.595180014769236,2.594890018304189,2.5945900082588196,2.594260017077128,2.593909978866577,2.5935400128364563,2.593150019645691,2.5927300254503884,2.592290004094442,2.59182999531428,2.591350018978119,2.590850015481313,2.5903299848238626,2.5897799928983054,2.5892200072606406,2.5886399944623313,2.58802996079127,2.5873999993006387,2.586750010649363,2.586090008417765,2.5854000051816306,2.584689974784851,2.5839500029881797,2.5832000176111856,2.5824299852053323,2.581630011399587,2.5808299779891968,2.580019990603129,2.5792199969291687,2.578410009543101,2.5775999625523887,2.576799988746643,2.5759900212287903,2.57519002755483,2.5743800004323325,2.573579967021942,2.5727800130844116,2.571969985961914,2.5711700121561685,2.570360004901886,2.5695599913597107,2.568760017553965,2.567959984143575,2.5671499967575073,2.5663500229517617,2.565549989541372,2.5647500356038413,2.563950022061666,2.5631499687830606,2.562340021133423,2.5615400075912476,2.5607399940490723,2.559939960638682,2.5591400464375815,2.558340013027191,2.557540019353231,2.556749999523163,2.5559499859809875,2.555150032043457,2.5543499986330667,2.5535500248273215,2.552749991416931,2.551960011323293,2.551159977912903,2.5503600041071572,2.549560030301412,2.5487699707349143,2.5479699969291687,2.5471799770991006,2.54638002316157,2.545579969882965,2.5447900096575418,2.5439900159835815,2.5432000160217285,2.542399982611338,2.5416100223859153,2.5408199429512024,2.540019989013672,2.539229989051819,2.5384299755096436,2.5376399755477905,2.5368499755859375,2.5360599954922995,2.5352599819501243,2.534470021724701,2.533679982026418,2.53289000193278,2.5321000019709268,2.5313100020090737,2.5305099884668985,2.5297199885050454,2.5289300084114075,2.5281400084495544,2.5273500283559165,2.5265599687894187,2.5257700284322104,2.5249900023142495,2.5242000023523965,2.5234099626541138,2.5226200421651206,2.521829982598623,2.5210400025049844,2.5202600161234536,2.5194700161616006,2.5186800360679626,2.517889976501465,2.517109990119934,2.516319990158081,2.515530010064443,2.5147500038146973,2.5139600038528442,2.5131799976030984,2.5123900175094604,2.511609971523285,2.510819991429647,2.510040024916331,2.509249985218048,2.5084700187047324,2.507689972718557,2.5068999926249185,2.506120026111603,2.5053399999936423,2.5045500000317893,2.5037699937820435,2.5029900272687278,2.5022099812825522,2.501419961452484,2.500640014807383,2.4998600085576377,2.499080022176107,2.498300015926361,2.4975199898084006,2.49674000342687,2.495959997177124,2.4951800107955933,2.494399984677633,2.4936200181643167,2.492839992046356,2.4920600056648254,2.4912800192832947,2.490500013033549,2.4897300203641257,2.48894997437795,2.488170007864634,2.4873900214831033,2.486620008945465,2.4858399828275046,2.485059976577759,2.4842899640401206,2.4835100173950195,2.482729991277059,2.4819599986076355,2.4811800122261047,2.480410019556681,2.4796300133069358,2.478860000769297,2.4780800541241965,2.477310001850128,2.4765299956003823,2.475760022799174,2.4749900102615356,2.474209984143575,2.4734399914741516,2.472669998804728,2.4719000260035195,2.471119999885559,2.470349987347921,2.4695800145467124,2.468809982140859,2.4680399894714355,2.4672599832216897,2.466490010420481,2.465719978014628,2.4649500052134194,2.464179972807566,2.463409960269928,2.4626399676005044,2.461870034535726,2.4610999623934426,2.4603399634361267,2.4595700105031333,2.4588000178337097,2.4580300052960715,2.457259992758433,2.4564900199572244,2.4557299812634787,2.454959988594055,2.4541899959246316,2.4534299969673157,2.452660063902537,2.451889971892039,2.451129992802938,2.4503600200017295,2.449600021044413,2.44883002837499,2.4480599761009216,2.4472999970118203,2.446530024210612,2.445770005385081,2.44500998655955,2.4442400137583413,2.4434799750645957,2.4427199761072793,2.441950003306071,2.44118998448054,2.440429985523224,2.4396600127220154,2.4388999740282693,2.4381399750709534,2.4373799761136374,2.436619997024536,2.4358500242233276,2.4350899855295816,2.4343300461769104,2.4335700074831643,2.4328100085258484,2.4320500095685325,2.431290010611216,2.430529991785685,2.429769992828369,2.429010033607483,2.428249994913737,2.427500009536743,2.426739990711212,2.425979971885681,2.42521999279658,2.4244600335756936,2.4237100084622702,2.422950029373169,2.422189990679423,2.421429991722107,2.420679966608683,2.419920007387797,2.4191700220108032,2.418410003185272,2.417649984359741,2.4168999989827475,2.416140000025431,2.4153900146484375,2.4146300156911216,2.4138799905776978,2.413130005200704,2.412369986375173,2.4116199811299643,2.410859982172648,2.4101099769274392,2.4093599915504456,2.4085999727249146,2.4078500072161355,2.4071000019709268,2.406350036462148,2.4056000312169394,2.4048400123914084,2.4040900071461997,2.403340001900991,2.402589996655782,2.4018399914105735,2.4010899662971497,2.4003400007883706,2.399590015411377,2.398839990297953,2.3980900247891745,2.397340019543966,2.396589994430542,2.3958400090535483,2.3950900038083396,2.394349972407023,2.393600026766459,2.3928500016530356,2.3921000162760415,2.391360024611155,2.3906100193659463,2.3898600339889526,2.389109989007314,2.3887400229771933};
    SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568542242050171,8.88445552190145,9.174676418304443,9.479785601298014,9.77232567469279,10.052305301030477,10.31970500946045,10.575904846191406,10.82220466931661,11.058704455693563,11.285304148991903,11.502004067103067,11.708903789520264,11.905903736750284,12.093003511428833,12.27030340830485,12.437702973683676,12.597102959950766,12.75000294049581,12.896702686945597,13.036902586619059,13.170902411142984,13.298502365748087,13.419702370961508,13.534602085749308,13.643102089564005,13.745301882425943,13.843502044677734,13.93990182876587,14.034501711527506,14.127301851908365,14.218401908874512,14.307801723480225,14.395301739374796,14.481101751327515,14.565101703008017,14.647401650746664,14.728301525115967,14.808201551437378,14.887001593907675,14.964801470438639,15.041601578394571,15.117401440938314,15.19210155804952,15.265901565551758,15.338601271311441,15.410301446914673,15.481001297632853,15.550701459248861,15.619401375452677,15.687201182047525,15.753901243209839,15.819701274236044,15.884501218795776,15.94840137163798,16.01120114326477,16.07310136159261,16.13400109608968,16.193801085154217,16.252501010894775,16.310201168060303,16.366800944010418,16.422400951385498,16.476900895436604,16.53040091196696,16.58280086517334,16.634200890858967,16.684600989023846,16.733900864919026,16.78230094909668,16.829801082611084,16.876200993855793,16.92170063654582,16.966200669606526,17.009700934092205,17.052300453186035,17.093900839487713,17.13450066248576,17.174101034800213,17.212700525919598,17.25030056635539,17.286900997161865,17.322400728861492,17.357000827789307,17.39060068130493,17.423200766245525,17.454800923665363,17.485700607299805,17.516400655110676,17.546900749206543,17.577100435892742,17.60700050989787,17.63670031229655,17.66610050201416,17.695300738016766,17.7242005666097,17.75290012359619,17.781400362650555,17.80950053532918,17.837400436401367,17.865100701649983,17.892500559488933,17.919700781504314,17.946600755055744,17.973300615946453,17.99970022837321,18.025800387064617,18.051700592041016,18.07740084330241,18.102800528208416,18.127900282541912,18.152800401051838,18.177500406901043,18.201900641123455,18.226000785827637,18.249900341033936,18.273600419362385,18.297000567118328,18.32010046641032,18.343000570933025,18.36560042699178,18.38800032933553,18.410200595855713,18.43210045496623,18.45370038350423,18.47510035832723,18.496200243632,18.5171004931132,18.53770049413045,18.558100541432697,18.57830047607422,18.59820048014323,18.61780055363973,18.637200196584065,18.65630054473877,18.675200303395588,18.693800449371338,18.712200164794922,18.73040024439494,18.748300393422443,18.765900293986004,18.78330071767171,18.80050039291382,18.81730016072591,18.83400026957194,18.85040028889974,18.86649990081787,18.882400671641033,18.89810021718343,18.913500150044758,18.9287002881368,18.943600177764893,18.958200295766193,18.97260046005249,18.98680051167806,19.000700155893963,19.014400164286297,19.0278000831604,19.041000525156658,19.053900082906086,19.06660000483195,19.079000155131023,19.09120003382365,19.103100458780926,19.114800135294598,19.126200199127197,19.13739999135335,19.14840014775594,19.15910005569458,19.169500192006428,19.17970021565755,19.18970012664795,19.199400107065838,19.208900451660156,19.21810022989909,19.227100531260174,19.23580010732015,19.244300206502277,19.25250021616618,19.26050027211507,19.268200238545734,19.275700092315674,19.283000151316326,19.290000120798748,19.29670015970866,19.303300221761067,19.309500058492024,19.315500259399414,19.321299870808918,19.326899846394856,19.332100073496502,19.337199846903484,19.342000166575115,19.346500237782795,19.350800037384033,19.354899883270264,19.358700116475422,19.36230007807414,19.36559995015462,19.368699709574383,19.37150001525879,19.37410004933675,19.376499970753986,19.378600120544434,19.380399862925213,19.381999969482422,19.383399963378906,19.38449986775716,19.38539997736613,19.386099974314373,19.386499881744385,19.386600017547607,19.386500199635822,19.386200110117596,19.385600090026855,19.38480011622111,19.383699893951416,19.382400194803875,19.380899906158447,19.379100163777668,19.377000013987224,19.374799887339275,19.372200171152752,19.369500001271565,19.36650021870931,19.363199869791668,19.359699885050457,19.35599994659424,19.35200007756551,19.34779977798462,19.343300183614094,19.338599999745686,19.333699862162273,19.32849995295207,19.323100090026855,19.317399819691975,19.31149975458781,19.305399735768635,19.299399852752686,19.293399651845295,19.28729995091756,19.281299750010174,19.27530002593994,19.269299666086834,19.26329978307088,19.25719992319743,19.251200040181477,19.24519968032837,19.239200274149578,19.23319975535075,19.227200031280518,19.22119967142741,19.215199947357178,19.209199905395508,19.203099886576336,19.197100003560383,19.191199779510498,19.18519989649455,19.179199695587158,19.17319965362549,19.167199929555256,19.161199887593586,19.1551996866862,19.149199803670246,19.143199920654297,19.13729985555013,19.131299654642742,19.12529993057251,19.11929972966512,19.11329984664917,19.107399940490723,19.101399739583332,19.095399856567383,19.089499632517498,19.083499590555828,19.077499866485596,19.071599801381428,19.06559960047404,19.05969985326131,19.05369997024536,19.047799905141193,19.041800022125244,19.03589963912964,19.029900074005127,19.023999849955242,19.017999807993572,19.012099742889404,19.006099859873455,19.000199953715008,18.99429972966512,18.98829984664917,18.982399781545002,18.976499716440838,18.970499833424885,18.964599927266438,18.95870018005371,18.952799956003826,18.946799914042156,18.94089984893799,18.934999624888103,18.929099877675373,18.92319981257121,18.91729974746704,18.91129986445109,18.905399799346924,18.899499893188477,18.89359982808431,18.88769992192586,18.881799697875977,18.875900109608967,18.870000044504803,18.864099820454914,18.85819975535075,18.85230000813802,18.846399625142414,18.84060001373291,18.834700107574463,18.828799883524578,18.82289981842041,18.816999912261963,18.811099688212078,18.805299917856853,18.799399852752686,18.79349994659424,18.787599722544353,18.781800111134846,18.77589988708496,18.770000139872234,18.76419973373413,18.758299827575684,18.752399921417236,18.746599833170574,18.740700085957844,18.73489999771118,18.728999932607014,18.723200003306072,18.717300256093342,18.711499849955242,18.705600102742512,18.69979985555013,18.69389994939168,18.68810002009074,18.682300090789795,18.67639970779419,18.670600096384685,18.66479953130086,18.658899784088135,18.65309985478719,18.647299925486248,18.64139970143636,18.635599772135418,18.629799842834473,18.623999913533527,18.61810000737508,18.612299919128418,18.606499989827473,18.60069974263509,18.594899972279865,18.589099566141766,18.58329979578654,18.577499866485596,18.571699778238933,18.56590000788371,18.560099760691326,18.5542999903361,18.548499902089436,18.542699654897053,18.53689988454183,18.531099796295166,18.52530002593994,18.519499619801838,18.513700167338055,18.50789992014567,18.502099990844727,18.496399879455566,18.49059995015462,18.484800179799397,18.478999932607014,18.473299821217854,18.467499891916912,18.461700121561687,18.45590003331502,18.450200080871582,18.44439967473348,18.43869972229004,18.432899951934814,18.427099863688152,18.42139991124471,18.415599664052326,18.409899711608887,18.404099941253662,18.398399829864502,18.39259974161784,18.386899789174397,18.381099700927734,18.375399748484295,18.36959966023763,18.363900025685627,18.358200073242188,18.352399667104084,18.346699873606365,18.341000080108643,18.33519983291626,18.329500039418537,18.32379976908366,18.317999839782715,18.312299728393555,18.306599775950115,18.300899982452393,18.295200030008953,18.28939978281657,18.28369967142741,18.277999877929688,18.272299766540527,18.266599973042805,18.260899861653645,18.255200068155926,18.249500115712483,18.243799845377605,18.238099733988445,18.232399940490723,18.226699829101562,18.220999717712402,18.21529992421468,18.209599653879803,18.20389970143636,18.1981995900472,18.192499955495197,18.186899820963543,18.18120002746582,18.17549975713094,18.16979996363322,18.16409985224406,18.158499717712402,18.15279992421468,18.147099653879803,18.14139986038208,18.135799884796143,18.130099614461262,18.12440013885498,18.118799686431885,18.113099892934162,18.107500076293945,18.101799964904785,18.096199830373127,18.090499877929688,18.084799925486248,18.07919979095459,18.073499997456867,18.06789954503377,18.062300046284992,18.056599617004395,18.050999800364178,18.045300006866455,18.03969971338908,18.03410005569458,18.02839994430542,18.022799809773762,18.017199834187824,18.011499722798664,18.005899906158447,18.00029993057251,17.99459997812907,17.989000002543133,17.983399868011475,17.977800051371258,17.97220007578532,17.966599941253662,17.96089967091878,17.955300013224285,17.949700037638348,17.944099585215252,17.93849976857503,17.932900110880535,17.927299976348877,17.92169984181722,17.916099707285564,17.910499731699627,17.904899915059406,17.899299780527752,17.893700122833252,17.888099829355877,17.88249985376994,17.87690003712972,17.871400038401287,17.868599732716877};
    //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.1294586857159934,2.220409353574117,2.2991870840390525,2.388396958510081,2.4798371394475303,2.5734272797902427,2.6691070397694907,2.7611867785453796,2.844146490097046,2.9182462294896445,2.9837158918380737,3.040785630544027,3.0896953344345093,3.1306650241216025,3.1639047463734946,3.1896344423294067,3.2080642183621726,3.2196939984957376,3.225023706754049,3.224243402481079,3.2175032099088035,3.204982896645864,3.1868226726849875,3.163192411263784,3.134242137273153,3.1001219749450684,3.060961822668711,3.019241750240326,2.977351705233256,2.935291667779287,2.8930715521176658,2.8507015307744346,2.8081814845403037,2.765511433283488,2.7227114041646323,2.679781357447306,2.636711299419403,2.593871295452118,2.551631212234497,2.5099512338638306,2.468831201394399,2.42826118071874,2.388211170832316,2.3486811319986978,2.3096510966618857,2.271111090977987,2.233051081498464,2.195581038792928,2.1588510274887085,2.122821013132731,2.087480982144674,2.052800973256429,2.0187809665997825,1.985390971104304,1.9526109596093495,1.9204409221808116,1.8888409336407979,1.857840895652771,1.8274409174919128,1.7976208925247192,1.7683808902899425,1.7396808763345082,1.711530864238739,1.6839008629322052,1.6567808489004772,1.6301608284314473,1.6040208041667938,1.5783008138338726,1.5529507994651794,1.5279607772827148,1.5033207635084789,1.4790307382742565,1.4550707240899403,1.431430697441101,1.408110688130061,1.3851006925106049,1.362390677134196,1.3399806519349415,1.3178506394227345,1.2959906160831451,1.2744006216526031,1.253070592880249,1.2320005893707275,1.211180587609609,1.1905905703703563,1.1702405313650768,1.1501205364863079,1.1303605337937672,1.1110705236593883,1.0922305285930634,1.0738405287265778,1.0558805267016094,1.0383404990037282,1.0212205151716869,1.004490499695142,0.9881425102551779,0.9721724987030029,0.956570491194725,0.9413224955399832,0.9264184832572937,0.9118494937817255,0.8976054837306341,0.8836794793605804,0.8700614720582962,0.8567404597997665,0.8437104672193527,0.830962469180425,0.818490465482076,0.8062844574451447,0.7943374464909235,0.7826414505640665,0.7711904396613439,0.7599794417619705,0.7489984383185705,0.7382424374421438,0.7277044256528219,0.7173774292071661,0.7072604298591614,0.6973424206177393,0.6876194179058075,0.6780844082434972,0.6687334080537161,0.6595644106467565,0.6505683958530426,0.6417403966188431,0.6330763945976893,0.6245713879664739,0.6162243833144506,0.6080283919970194,0.599977379043897,0.5920683791240057,0.5842983722686768,0.5766643683115641,0.5691603670517603,0.5617833534876505,0.5545293639103571,0.5473953485488892,0.5403803487618765,0.5334773461023966,0.5266843438148499,0.5199983417987823,0.5134163349866867,0.5069373299678167,0.5005563373366991,0.49427032470703125,0.4880763217806816,0.4819723169008891,0.47595831751823425,0.4700293143590291,0.4641823098063469,0.45841530462106067,0.4527262995640437,0.44711630046367645,0.44157929221789044,0.4361132929722468,0.4307172894477844,0.42538828154404956,0.4201272800564766,0.4149302765727043,0.4097952718536059,0.4047202666600545,0.3997032667199771,0.3947462663054466,0.38984426359335583,0.3849952593445778,0.38019825518131256,0.3754522477587064,0.37075824042161304,0.36611224214235943,0.3615122338136037,0.35695723195870716,0.35244522988796234,0.34798022856314975,0.3435552194714546,0.3391702224810918,0.33482521027326584,0.3305172125498454,0.3262492095430692,0.32201720774173737,0.3178192004561424,0.31365520010391873,0.3095241958896319,0.3054281895359357,0.30136218915383023,0.2973271906375885,0.2933211773633957,0.2893431733051936,0.28539517273505527,0.28147516896327335,0.277580164372921,0.273710161447525,0.26986515522003174,0.2660471498966217,0.26225215196609497,0.25847914814949036,0.25472914427518845,0.2509991377592087,0.2472931370139122,0.24360713238517442,0.2399401292204857,0.23629212627808252,0.23266312355796495,0.22905411571264267,0.22546211505929628,0.22188711042205492,0.21832910676797232,0.2147861048579216,0.21126109982530275,0.20775209863980612,0.20425709461172423,0.20077509060502052,0.19730808585882187,0.19385708247621855,0.19041807949543,0.18699207405249277,0.18357807149489722,0.18017606685558954,0.1767880655825138,0.17341106260816255,0.1700440583129724,0.16668905317783356,0.1633430508275827,0.16001004725694656,0.15668604522943497,0.15337203815579414,0.15006603424747786,0.14677003274361292,0.14348402991890907,0.14020702242851257,0.13693801934520403,0.13367601856589317,0.13042201350132623,0.12717701122164726,0.1239400077611208,0.12071000350018342,0.11748600068191688,0.11426799992720287,0.11110000063975652,0.10801899991929531,0.10502400000890096,0.10211200018723805,0.0992807000875473,0.09652800112962723,0.09385159984230995,0.09124940012892087,0.08871939964592457,0.08625959977507591,0.08386790007352829,0.08154259932537873,0.0792818001161019,0.07708370002607505,0.07494660094380379,0.0728687010705471,0.07084839915235837,0.06888420010606448,0.0669744002322356,0.0651175994426012,0.06331230079134305,0.06155710077534119,0.05985049996525049,0.05819130036979914,0.05657800007611513,0.05500950043400129,0.05348449945449829,0.05200179976721605,0.050560200276474156,0.04915860015898943,0.04779579987128576,0.04647079948335886,0.04518260030696789,0.04393009996662537,0.04271230008453131,0.04152829976131519,0.04037709999829531,0.039257799896101155,0.03816950010756651,0.03711149996767441,0.036082700515786804,0.03508250042796135,0.034110099698106446,0.033164599910378456,0.03224529977887869,0.03135150019079447,0.030482399898270767,0.029637500333289307,0.028815999782333773,0.028017199753473204,0.027240700088441372,0.02648559973264734,0.02575150008002917,0.025037700155129034,0.02434369983772437,0.023668999783694744,0.023012899948904913,0.022375099671383698,0.021754900148759287,0.021152000098178785,0.02056569963072737,0.019995700102299452,0.019441499840468168,0.018902600121994812,0.01837869981924693,0.01786939986050129,0.017374100008358557,0.016892600028465193,0.01642439995581905,0.015969200059771538,0.015526600026835998,0.01509629989353319,0.014677900122478604,0.014271100051701069,0.013875600028162202,0.013491100010772547,0.013117199996486306,0.012753600099434456,0.012400199969609579,0.01205650003006061,0.011722400008390347,0.011397499979163209,0.01108170005803307,0.010774600086733699,0.010475999986131987,0.010185700142756104,0.00990341006157299,0.009628960009043416,0.00936212002610167,0.009102680021896958,0.00885042998318871,0.008605169986064235,0.008366710040718317,0.008134860157345733,0.00790942991928508,0.0076902500198533135,0.007477149988214175,0.0072699500403056545,0.007068499961557488,0.0068726300572355585,0.006682189957549174,0.0064970199794818955,0.006316990009509027,0.0061419499494756264,0.005971759984580179,0.005806279989580314,0.00564539999080201,0.005488969967700541,0.005336870012494425,0.0051889899574841065,0.005045209972498317,0.004905420006252825,0.0047694999957457185,0.0046373399284978705,0.004508849970685939,0.004383920071025689,0.004262450073535244,0.004144349950365722,0.004029520011196534,0.003917870014750709,0.0038093200031047067,0.0037037700143021843,0.0036011500051245093,0.0035013799788430333,0.003404360012306521,0.003310039988718927,0.0032183299966466925,0.0031291599734686315,0.0030424699846965573,0.0029581699830790362,0.0028762099876378975,0.0027965300056772926,0.0027190500404685736,0.0026437100023031235,0.0025704699995306632,0.0024992499772148826,0.0024300100243029497,0.0023626899734760323,0.002297230006661266,0.0022335899993777275,0.0021717099783321223,0.0021115400401564934,0.0020530399827597043,0.0019961599997865656,0.001940859976457432,0.0018870899997030695,0.0018348100032502164,0.0017839799887345482,0.0017345600062981248,0.0016865099993689607,0.0016397800160727154,0.0015943599864840508,0.0015501899858160566,0.001507239988616978,0.0014654900005552918,0.001424890001847719,0.0013854199981627364,0.0013470400105385731,0.0013097199941209208,0.0012734400030846398,0.0012381700022766988,0.001203870012735327,0.0011705200110251706,0.0011380900202008586,0.0011065600071257602,0.0010759099968709052,0.0010461099930883695,0.0010171299994302292,0.0009889540039390947,0.0009615590000369897,0.0009349229997800043,0.0009090250047544638,0.0008838450012262911,0.0008593620004830882,0.0008355570074248438,0.00081241199222859,0.0007899079937487841,0.0007680280056471626,0.000746754002951396,0.0007260690035764128,0.0007059570004154617,0.0006864030049958577,0.0006673900012780601,0.0006489040000208964,0.0006309299933491275,0.0006134540017228574,0.0005964619922451675,0.0005799410040102279,0.0005638769895692045,0.000548259005881846,0.0005330730006486798,0.000518308001725624,0.0005039509948498259,0.0004899930039149089,0.00047642100010610494,0.00046322500323488686,0.00045039499673293903,0.00043791999875490245,0.0004257910016652507,0.0004139980034475836,0.0004025309972348623,0.00039138199887626496,0.00038054199831094593,0.0003700020000299749,0.0003597549972861695,0.0003497909977644061,0.00034010299471750233,0.0003306829967186786,0.0003215239994460717,0.0003126189985778183,0.00030396099706801277,0.00029554199863923714,0.00028735699743265286,0.0002793990012529927,0.00027166100092775497,0.00026413699621722725,0.00025682100143361214,0.00024970900267362595,0.0002427929988092122,0.00023606900019027913,0.00022953099930115664,0.000223173999984283,0.00021699299880613884,0.00021098400247865357,0.00020514099863551868,0.00019945899960778965,0.0001939350004249718,0.00018856499931037737,0.00018334199921810068,0.00017826500091662942,0.00017332800052827224,0.00016852800157115175,0.00016386099984326089,0.0001593229996312099,0.00015491100081514256,0.00015062099919305183,0.00014644999949571988,0.00014239399994645888,0.00013845099844426537,0.00013461700048840916,0.00013088899747041674,0.00012726399897170873,0.00012374000046596242,0.00012031300078281977,0.00011698100085292633,0.00011374199978793816,0.00011059200005547609,0.00010752899955453661,0.00010601999989982384};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11867141723633,80.86898803710938,79.52129300435384,78.11839421590169,76.66879590352376,75.18019803365071,73.65989939371745,72.1143004099528,70.54940223693848,68.97070376078288,67.38320287068684,65.79140408833821,64.19950612386067,62.61110623677572,61.02960618336996,59.458007176717125,57.89900779724121,56.35510857899984,54.82850901285807,53.320908864339195,51.83410898844401,50.36960951487223,48.92870903015137,47.51240952809652,46.1217098236084,44.75750986735026,43.420210202534996,42.110609690348305,40.8289098739624,39.575609842936196,38.3508103688558,37.15460968017578,35.98710982004801,34.84830983479818,33.73800913492838,32.65600903828939,31.60230890909831,30.576508680979412,29.57830874125163,28.607508818308514,27.663508415222168,26.746208031972248,25.85490830739339,24.98930788040161,24.14900779724121,23.333507855733234,22.54220740000407,21.774706840515137,21.03050708770752,20.309106667836506,19.6100066502889,18.932606379191082,18.276506106058758,17.641106128692627,17.025905927022297,16.430505911509197,15.85420568784078,15.296605428059896,14.757205327351889,14.235505183537802,13.73100487391154,13.243204911549887,12.77170459429423,12.316004594167074,11.875604391098022,11.450104395548502,11.03900416692098,10.64190403620402,10.258403857549032,9.888133843739828,9.53057368596395,9.185373544692993,8.852153460184732,8.530523379643759,8.220113277435303,7.920583128929138,7.631553053855896,7.352702895800273,7.083692828814189,6.8241926829020185,6.573892553647359,6.33248249689738,6.09966246287028,5.875162323315938,5.658682306607564,5.449952244758606,5.244022210439046,5.041112343470256,4.846082170804341,4.658622105916341,4.478441993395488,4.305251955986023,4.138781865437825,3.978781779607137,3.824971695741018,3.6771416862805686,3.5350315968195596,3.398441513379415,3.2671414812405906,3.1409313877423606,3.019601364930471,2.9029813408851624,2.7908812363942466,2.6831212043762207,2.5795311331748962,2.479951103528341,2.3842210372289023,2.292201062043508,2.2037410140037537,2.1187109549840293,2.0369609196980796,1.958380897839864,1.8828308482964833,1.8102108041445415,1.740400791168213,1.6732807556788127,1.6087607145309448,1.5467306971549988,1.4871006707350414,1.429780642191569,1.3746706247329712,1.321680595477422,1.2707505722840626,1.2217805584271748,1.174700528383255,1.1294505099455516,1.0859404702981312,1.0441004733244579,1.0038904547691345,0.9652244299650192,0.928053413828214,0.8923154026269913,0.8579573879639307,0.824924369653066,0.7931653459866842,0.7626323302586874,0.7332753290732702,0.7050513128439585,0.6779152999321619,0.6518252938985825,0.6267412801583608,0.6026232788960139,0.5794352541367213,0.5571412493785223,0.5357052435477575,0.5150952339172363,0.4952802260716756,0.4762282148003578,0.4579092115163803,0.44029619296391803,0.4233611896634102,0.40707918256521225,0.39142317573229474,0.3763701717058818,0.36189716806014377,0.34798115988572437,0.3346001481016477,0.32173514117797214,0.3093641400337219,0.2974701349933942,0.28603313118219376,0.27503711978594464,0.2644631216923396,0.2542971173922221,0.2445211112499237,0.23512110486626625,0.22608410194516182,0.2173930952946345,0.2090370940665404,0.20100309078892073,0.19327708457907042,0.18584808334708214,0.17870508134365082,0.17183708027005196,0.16523307313521704,0.15888207157452902,0.15277606869737306,0.14690506582458815,0.1412590630352497,0.1358310580253601,0.13061105708281198,0.12559105766316256,0.12076505459845066,0.11612405255436897,0.11166104922691981,0.10737004814048608,0.10324404761195183,0.09927714491883914,0.09546224276224773,0.09179394195477168,0.0882666390389204,0.08487493731081486,0.0816136362651984,0.07847763473788898,0.07546213393410046,0.0725626324613889,0.06977453082799911,0.06709353066980839,0.06451562854150932,0.06203682813793421,0.05965322659661373,0.05736132555951675,0.05515742519249519,0.05303822364658117,0.05100052338093519,0.049041121887664,0.047157020618518196,0.045345320366322994,0.043603219712773957,0.04192811871568362,0.04031731809178988,0.03876851747433344,0.037279216572642326,0.0358471159512798,0.034470014895002045,0.0331458148236076,0.03187261428683996,0.03064821350077788,0.029470913112163544,0.028338912564019363,0.02725031226873398,0.026203611865639687,0.025197011418640614,0.024229210956643026,0.02329851035028696,0.022403710211316746,0.02154310963427027,0.020715709154804546,0.01992000887791316,0.01915490875641505,0.018419208315511543,0.01771180781846245,0.017031607528527577,0.016377407126128674,0.015748506877571344,0.015143606889372071,0.01456210653608044,0.014002806351830563,0.013465106099223098,0.012948005848253766,0.012450805477177104,0.011972605405996243,0.011512905126437545,0.01107080498089393,0.010645704654355844,0.010236904568349322,0.009843884346385797,0.00946592423133552,0.009102474121997753,0.008752994006499648,0.008416933783640465,0.008093793643638492,0.007783053481640915,0.007484253263100982,0.007196933186302583,0.006920643073196213,0.00665496305252115,0.006399492927206059,0.00615383277181536,0.005917602645543714,0.00569045248751839,0.005472022419174512,0.00526197231374681,0.0050600022077560425,0.0048657822189852595,0.004679012073514362,0.004499422075847785,0.004326731936695675,0.004160661793624361,0.0040009818427885575,0.0038474217096033194,0.0036997616407461464,0.0035577715995411077,0.0034212315416273973,0.0032899314731669924,0.003163671412039548,0.003042271399560074,0.0029255213060726724,0.0028132512622202435,0.00270530121633783,0.002601481198022763,0.002501661113152901,0.0024056610806534686,0.0023133510258048773,0.0022245909979877374,0.0021392309572547674,0.002057150898811718,0.001978210872039199,0.0019023108664744843,0.0018293207976967096,0.001759140781359747,0.0016916407621465623,0.001626740723925953,0.001564330702725177,0.0015043106589776774,0.0014466006541624665,0.0013911006099078804,0.0013377306070954849,0.0012864105810876936,0.0012370605739609648,0.0011896105327953894,0.0011439704976510257,0.0011000904778484255,0.0010578904863602172,0.001017310443179061,0.0009782854370617617,0.0009407594237321367,0.0009046734097258499,0.0008699723839526996,0.0008366023685084656,0.0008045133678630615,0.0007736553476812938,0.000743981329530167,0.0007154453196562827,0.000688004307448864,0.0006616173001627127,0.0006362412871870523,0.0006118392775533721,0.0005883742657412464,0.0005658092462302496,0.000544109241066811,0.0005232422360374281,0.0005031752225477248,0.00048387821880169213,0.0004653222082803647,0.0004474771994864568,0.0004303171905727747,0.00041381618454276275,0.0003979471803177148,0.00038268717617029324,0.0003680121638656904,0.0003539001603106347,0.0003403301549648556,0.00032728014533252764,0.00031473114116427797,0.0003026631335766676,0.00029105712989500415,0.0002798971254378557,0.0002691661211429164,0.0002588451194848555,0.0002489211134767781,0.0002393771064816974,0.0002301991031951426,0.000221373098611366,0.00021288609423208982,0.00020472409232752398,0.00019687508756760508,0.00018932708432354653,0.0001820690837727549,0.000175089076947188,0.00016837707395704152,0.00016192207234174324,0.0001557150693164052,0.00014974506727109352,0.00014400506430926421,0.00013848506083983617,0.00013317605892855985,0.0001280710578915508,0.0001231620559944228,0.00011844105332177908,0.00011390104979606501,0.00010953504958403452,0.00010533604715116478,8.46746164218833e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45186487833658,229.5926081339518,226.30971908569336,223.64171091715494,220.94770940144858,218.23170598347983,215.496706644694,212.74670537312826,209.98370615641275,207.21270370483398,204.4347038269043,201.65270360310873,198.87070083618164,196.08970387776694,193.31170145670572,190.54070536295572,187.77770614624023,185.0237070719401,182.2817064921061,179.5527089436849,176.83871205647787,174.1407152811686,171.45971552530924,168.7987149556478,166.15672175089517,163.5357208251953,160.9367243448893,158.3607292175293,155.80872853597006,153.28073374430338,150.77773666381836,148.30174128214517,145.85074106852213,143.42774454752603,141.0307502746582,138.66274897257486,136.32175064086914,134.00875600179037,131.72575887044272,129.46976470947266,127.24376551310222,125.04676818847656,122.87877146402995,120.73977533976237,118.6297779083252,116.5497817993164,114.49778429667155,112.47578684488933,110.48278935750325,108.51879374186198,106.5837968190511,104.6777998606364,102.80080286661784,100.95180638631184,99.13140869140625,97.339111328125,95.57481384277344,93.83831787109375,92.12932014465332,90.44772402445476,88.79322624206543,87.16562970479329,85.56463241577148,83.99003410339355,82.44143740336101,80.9187405904134,79.42154248555501,77.94964408874512,76.50274721781413,75.08045069376628,73.6826540629069,72.30875587463379,70.9587574005127,69.63216082255046,68.3286641438802,67.04806582132976,65.78986740112305,64.55397033691406,63.33987267812093,62.1472749710083,60.97597726186117,59.82547918955485,58.695581118265785,57.58598391215006,56.49638589223226,55.4262892405192,54.39679463704427,53.40669600168864,52.43349806467692,51.476999600728355,50.53690147399902,49.61310323079427,48.70530478159586,47.813206354777016,46.93650817871094,46.07510916392008,45.22871112823486,44.39711284637451,43.5800142288208,42.77731577555338,41.98861757914225,41.213818868001304,40.452619870503746,39.70492172241211,38.97042338053385,38.24882443745931,37.54012584686279,36.84402720133463,36.160228411356606,35.48862934112549,34.829030990600586,34.18113168080648,33.5449333190918,32.92003504435221,32.306435902913414,31.703836758931477,31.112038135528564,30.53093942006429,29.96033986409505,29.400041421254475,28.849942366282146,28.30974356333415,27.77934455871582,27.258545398712158,26.747246424357098,26.245147387186687,25.75234842300415,25.268449465433758,24.793350219726562,24.326951503753662,23.869152069091797,23.419652938842773,22.978453795115154,22.545254548390705,22.120055357615154,21.70275640487671,21.293057123819988,20.890857696533203,20.496158281962078,20.108659426371258,19.728260040283203,19.354960918426514,18.988561630249023,18.628862222035725,18.27586301167806,17.929463545481365,17.589464505513508,17.255664984385174,16.928165594736736,16.60676654179891,16.291266759236652,15.981667677561441,15.677868207295736,15.379668792088827,15.086969375610352,14.799870014190674,14.518070538838705,14.24147097269694,13.970071713129679,13.703772147496542,13.442472775777182,13.185973087946573,12.934373617172241,12.687474091847738,12.44517469406128,12.207475026448568,11.974175532658895,11.745275974273682,11.520676533381144,11.30027691523234,11.083977301915487,10.871877829233805,10.663678169250488,10.459378639856974,10.258978843688965,10.062379280726114,9.869459788004557,9.680190165837606,9.494500557581583,9.312320868174234,9.133581320444742,8.958211660385132,8.786182165145874,8.617392222086588,8.451802651087442,8.289342959721884,8.12997325261434,7.973613699277242,7.820223967234294,7.669744253158569,7.522124528884888,7.3773148854573565,7.235265254974365,7.09591539700826,6.959215680758159,6.825115879376729,6.6935562292734785,6.564516464869182,6.437946756680806,6.313777009646098,6.191977302233378,6.072507460912068,5.955317735671997,5.840357979138692,5.727598230044047,5.616998513539632,5.508508602778117,5.40208884080251,5.297709067662557,5.195329308509827,5.094929496447246,4.996449788411458,4.89985994497935,4.80511999130249,4.712200323740642,4.621050437291463,4.531660636266072,4.443970839182536,4.357960939407349,4.273601134618123,4.190851370493571,4.10970155398051,4.030121644337972,3.9520618319511414,3.8754920164744058,3.8004021644592285,3.726762314637502,3.65452241897583,3.5836825569470725,3.5142027139663696,3.4460728565851846,3.379253009955088,3.3137231270472207,3.2494632999102273,3.186433414618174,3.1246235370635986,3.0640036861101785,3.0045537749926248,2.9462439020474753,2.8890640139579773,2.832974116007487,2.777994235356649,2.724074363708496,2.671184460322062,2.6193146109580994,2.5684346755345664,2.5185548265775046,2.4696348905563354,2.421654979387919,2.3746150732040405,2.3284951647122702,2.2832652926445007,2.2388953963915506,2.1953954100608826,2.1527255376180015,2.1108756264050803,2.069845716158549,2.029615819454193,1.9901858468850453,1.9514959653218586,1.9135460257530212,1.876346121231715,1.8398661812146504,1.8041062553723652,1.7690263390541077,1.7346064150333405,1.7008664707342784,1.667796532313029,1.6353666086991627,1.6035666763782501,1.5723767379919689,1.5417668024698894,1.5117668807506561,1.4823569258054097,1.4535169899463654,1.4252370397249858,1.3975170850753784,1.3703271349271138,1.3436372180779774,1.3174772560596466,1.2918173174063365,1.2666773796081543,1.2420174181461334,1.2178474764029186,1.1941475073496501,1.1709075570106506,1.1481276055177052,1.1257776618003845,1.1038376986980438,1.08232777317365,1.061237782239914,1.0405678451061249,1.0202978948752086,1.0004279216130574,0.9809399594863256,0.9618380069732666,0.9431100388367971,0.9247490813334783,0.906747117638588,0.8890981525182724,0.8717951873938242,0.8548302302757899,0.8381762554248174,0.8218272924423218,0.8057983219623566,0.7900823553403219,0.7746753891309103,0.7595684230327606,0.7447584569454193,0.7302384823560715,0.7160025089979172,0.7020445366700491,0.6883605718612671,0.6749446044365565,0.6617906242609024,0.6488946477572123,0.6362506796916326,0.6238537033398946,0.6117007434368134,0.5997847517331442,0.5881017794211706,0.5766478081544241,0.5654178261756897,0.5544078449408213,0.543612872560819,0.5330298990011215,0.5226539174715678,0.5124799311161041,0.5025059630473455,0.4927269791563352,0.48313899834950763,0.47373901804288227,0.4645230347911517,0.45548705756664276,0.44662807136774063,0.43792108694712323,0.42936310172080994,0.42097212622563046,0.412745142976443,0.4046791543563207,0.3967711726824443,0.3890181879202525,0.3814162115255992,0.37396322190761566,0.36665624131759006,0.3594922497868538,0.35246826708316803,0.3455812806884448,0.33882929384708405,0.33220930645863217,0.32571931928396225,0.3193553388118744,0.3131163492798805,0.3069993630051613,0.3010013774037361,0.29512138416369754,0.28935639808575314,0.28370340913534164,0.2781614189346631,0.27272843072811764,0.26740144441525143,0.26217744996150333,0.25705646226803464,0.2520354713002841,0.24711348613103232,0.24228649462262788,0.23755450546741486,0.2329145185649395,0.22836552436153093,0.2239055335521698,0.21953354155023894,0.2152455523610115,0.21104256063699722,0.2069205678999424,0.20287957911690077,0.1989185872177283,0.1950335937241713,0.19122560073932013,0.18749161064624786,0.1838306188583374,0.18024062241117159,0.1767216312388579,0.17327063903212547,0.1698876457909743,0.16657065227627754,0.16331866011023521,0.16012966632843018,0.15700367217262587,0.15393867964545885,0.1509326845407486,0.14798669392863908,0.14509769777456918,0.14226470390955606,0.13948770985007286,0.13676471635699272,0.13409472008546194,0.13147772724429765,0.1289107340077559,0.1263947387536367,0.12392774224281311,0.12150874733924866,0.11913675193985303,0.11681175728638966,0.11453176165620486,0.11229576667149861,0.11010477133095264,0.10795577553411324,0.10584878052274387,0.10378278481463592,0.10175678879022598,0.0997712928801775,0.09782419539988041,0.09591520080963771,0.09404340448478858,0.09220820913712184,0.09040881258745988,0.08864461568494637,0.08691481935481231,0.08521882258355618,0.08355592687924702,0.08192552936573823,0.08032703213393688,0.07875963486731052,0.07722293958067894,0.07571624281505744,0.07423894541958968,0.07279044886430104,0.0713702520976464,0.0699778546889623,0.06861255628367265,0.06727396013836066,0.0659615620970726,0.06467466553052266,0.06341296869019668,0.0621759711454312,0.06096297316253185,0.05977377543846766,0.05860777758061886,0.05746448040008545,0.05634358276923498,0.05524448460588852,0.05416688726594051,0.05311028907696406,0.05207439170529445,0.051058693788945675,0.05006279579053322,0.04908629786223173,0.048128899497290455,0.047190201779206596,0.04626980392883221,0.045367405439416565,0.04448260739445686,0.04361510959764322,0.042764511269827686,0.04193051314602295,0.04111271444708109,0.040311015831927456,0.03952491811166207,0.03875411953777075,0.037998421117663383,0.037257422072192035,0.036530823446810246,0.035818525279561676,0.035120027139782906,0.03443522844463587,0.0337638296186924,0.033105431124567986,0.03245993237942457,0.03182703380783399,0.031206535175442696,0.030598036323984463,0.03000143760194381,0.029416538930187624,0.028843039957185585,0.02828064126272996,0.027729342846820753,0.027188743309428293,0.026658644434064627,0.026138945793112118,0.02562934656937917,0.025129747732232015,0.024639848930140335,0.024159449928750593,0.02368854886541764,0.023226764984428883,0.022998180861274403};
    CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452774047852,71.41004053751628,70.57014719645183,69.81614049275716,69.06644058227539,68.32154083251953,67.58183987935384,66.84753926595052,66.1189416249593,65.39613914489746,64.67943954467773,63.968939463297524,63.26473871866862,62.566938400268555,61.875538190205894,61.190737088521324,60.51253732045492,59.84093697865804,59.1759360631307,58.51753616333008,57.86583550771078,57.22073491414388,56.582234700520836,55.950234731038414,55.324934005737305,54.7061341603597,54.093833923339844,53.488133112589516,52.888732274373375,52.29583231608073,51.70933214823405,51.129231770833336,50.55533091227213,49.98763084411621,49.42623074849447,48.87083085378011,48.32162952423096,47.77842998504639,47.24122969309489,46.70992946624756,46.18452898661295,45.6649284362793,45.151028633117676,44.64292812347412,44.14042822519938,43.643527348836265,43.152126948038735,42.66622670491537,42.18582661946615,41.71072578430176,41.241025606791176,40.77662499745687,40.317325592041016,39.86332480112711,39.41442457834879,38.97052447001139,38.53162415822347,38.09782409667969,37.66882292429606,37.24472300211588,36.82542324066162,36.410922368367515,36.001123110453285,35.596022605895996,35.19552199045817,34.79952176411947,34.40822156270345,34.02132097880045,33.63882064819336,33.26072025299072,32.887020111083984,32.51752026875814,32.15232022603353,31.791319847106934,31.43451913197835,31.081719398498535,30.733119010925293,30.388418674468994,30.04771852493286,29.71091826756795,29.377918402353924,29.048818111419678,28.723517894744873,28.401917616526287,28.08391761779785,27.769617239634197,27.45901695887248,27.151817003885906,26.84821653366089,26.548016389211018,26.25131622950236,25.95801607767741,25.668016115824383,25.3813157081604,25.097915649414062,24.817815621693928,24.540815194447834,24.26701482137044,23.996214707692463,23.728614330291748,23.464014530181885,23.202414353688557,22.943814277648926,22.688214143117268,22.4354141553243,22.185513814290363,21.93841330210368,21.694113572438557,21.452613194783527,21.213812987009685,20.977712790171307,20.74431260426839,20.51351261138916,20.285412470499676,20.059812545776367,19.836812019348145,19.616212050120037,19.39821179707845,19.18261178334554,18.96951166788737,18.758811632792156,18.550411383310955,18.344411373138428,18.140711307525635,17.939311027526855,17.740210851033527,17.54331064224243,17.348610719045002,17.156110286712646,16.965810616811115,16.777610143025715,16.591610113779705,16.407609939575195,16.225710074106853,16.045809745788574,15.867909749348959,15.69210966428121,15.51820961634318,15.346209287643433,15.176209290822348,15.008109331130981,14.841909170150757,14.677509228388468,14.515008767445883,14.354208707809448,14.195308764775595,14.038208564122518,13.882808526357016,13.729108413060507,13.57710830370585,13.426908334096273,13.278308073679606,13.131407976150513,12.986107985178629,12.842407703399658,12.70040766398112,12.55990751584371,12.421007553736368,12.283607482910156,12.147707462310791,12.013407468795776,11.88060720761617,11.749207099278768,11.619307041168213,11.490807056427002,11.363807121912638,11.238106807072958,11.113906780878702,10.991106748580933,10.869606653849283,10.749406655629477,10.630606412887573,10.513106425603231,10.39690645535787,10.28200634320577,10.168406009674072,10.05600611368815,9.944876114527384,9.834975957870483,9.726295948028564,9.618815819422403,9.512525876363119,9.407415707906088,9.303465684254965,9.200665632883707,9.099005619684855,8.998465458552042,8.899045467376709,8.800715366999308,8.703485409418741,8.607325315475464,8.512225151062012,8.418185075124105,8.325185139973959,8.233214934666952,8.142254908879599,8.0523149172465,7.96335490544637,7.875394741694133,7.788394769032796,7.7023647626241045,7.617284615834554,7.533144593238831,7.449944655100505,7.367654482523601,7.286284486452739,7.205804308255513,7.126224319140117,7.047514279683431,6.96968428293864,6.892714182535808,6.816594163576762,6.741314133008321,6.666874090830485,6.593254089355469,6.5204440752665205,6.44844392935435,6.377243876457214,6.306823809941609,6.237193862597148,6.168323755264282,6.1002137660980225,6.032863696416219,5.966263651847839,5.900393565495809,5.835253596305847,5.770833492279053,5.707123478253682,5.644123514493306,5.581813414891561,5.520193378130595,5.459263364473979,5.399003267288208,5.33940331141154,5.280473152796428,5.222183108329773,5.164543151855469,5.107543110847473,5.051173090934753,4.995433052380879,4.9403029680252075,4.885782917340596,4.831873019536336,4.778552850087483,4.725822885831197,4.673682848612468,4.6221128304799395,4.571122805277507,4.520692706108093,4.470822771390279,4.421502669652303,4.372722665468852,4.324492613474528,4.276792605717977,4.229612668355306,4.182962536811829,4.136832515398662,4.09120253721873,4.046082456906636,4.001462439695994,3.9573323925336203,3.9136924346288047,3.8705323735872903,3.8278523286183677,3.7856523195902505,3.7439022858937583,3.7026222944259644,3.6618022322654724,3.6214322050412497,3.5815021793047586,3.542022148768107,3.502972106138865,3.464352091153463,3.4261621236801147,3.388402044773102,3.3510520458221436,3.3141120274861655,3.277581969896952,3.2414519985516868,3.205731987953186,3.170391937096914,3.135451932748159,3.1009018619855246,3.0667218565940857,3.0329318245251975,2.99951179822286,2.9664518237113953,2.933761795361837,2.901441772778829,2.8694717288017273,2.8378517429033914,2.806581695874532,2.7756616870562234,2.745081663131714,2.7148316502571106,2.6849216421445212,2.6553515990575156,2.6260915795962014,2.5971615314483643,2.568551480770111,2.5402615666389465,2.512281517187754,2.484601537386576,2.457241475582123,2.430171489715576,2.4034114480018616,2.3769314885139465,2.3507614135742188,2.3248714208602905,2.299261430899302,2.2739413579305015,2.2489013671875,2.2241313258806863,2.1996413469314575,2.175421337286631,2.1514613231023154,2.127771317958832,2.1043413082758584,2.0811712543169656,2.058261275291443,2.035601238409678,2.0131911834081015,1.9910212059815724,1.9691011905670166,1.9474211931228638,1.9259811838467915,1.9047811528046925,1.8838111360867817,1.863081117471059,1.8425711194674175,1.8222911059856415,1.802231103181839,1.782391091187795,1.762771060069402,1.7433710594971974,1.7241810460885365,1.7052110433578491,1.6864410440127056,1.6678810119628906,1.6495210230350494,1.6313710113366444,1.6134210030237834,1.5956609745820363,1.5781009594599407,1.5607409576574962,1.5435609420140584,1.526580919822057,1.5097809135913849,1.4931709071000416,1.4767409066359203,1.4604909022649128,1.4444208939870198,1.428530861934026,1.412820855776469,1.3972708483537037,1.3819008072217305,1.3667008181413014,1.3516608079274495,1.3368008136749268,1.3220908045768738,1.3075507879257202,1.2931608060995738,1.2789407670497894,1.264870782693227,1.250960757335027,1.237200766801834,1.2235907514890034,1.2101407448450725,1.196830729643504,1.1836607158184052,1.1706507007280986,1.1577706933021545,1.1450406809647877,1.1324506898721058,1.1199906865755718,1.1076806684335072,1.0955006579558055,1.0834506551424663,1.071540653705597,1.0597606499989827,1.0481006403764088,1.0365806221961975,1.0251806378364563,1.0139106214046478,1.0027605990568798,0.9917396108309428,0.9808366000652313,0.9700525949398676,0.9593885838985443,0.9488415718078613,0.9384105602900187,0.9280945658683777,0.9178925603628159,0.907802551984787,0.8978235522905985,0.8879545331001282,0.878194530804952,0.8685415337483088,0.8589945236841837,0.8495535055796305,0.8402155091365179,0.8309814929962158,0.8218485017617544,0.8128154923518499,0.803882489601771,0.7950474818547567,0.786310464143753,0.7776694794495901,0.7691234648227692,0.760671466588974,0.7523124615351359,0.7440454612175623,0.7358694523572922,0.7277834415435791,0.7197864353656769,0.7118774255116781,0.7040554334719976,0.6963194260994593,0.6886684199174246,0.6811024149258932,0.6736184110244116,0.6662184099356333,0.6588984032471975,0.6516593992710114,0.6445003896951675,0.6374193926652273,0.6304173817237219,0.6234913716713587,0.6166423757870992,0.6098683774471283,0.6031693667173386,0.5965433567762375,0.5899903575579325,0.5835103591283163,0.5771003464857737,0.5707613478104273,0.5644923398892084,0.5582923293113708,0.5521603375673294,0.5460963249206543,0.5400983244180679,0.5341663211584091,0.5283003250757853,0.5224973261356354,0.5167593111594518,0.5110843032598495,0.5054713040590286,0.4999213044842084,0.49443130443493527,0.4890012989441554,0.4836312954624494,0.47832128902276355,0.4730682869752248,0.46787428359190625,0.4627362787723541,0.45765527337789536,0.45263027648131055,0.44766027480363846,0.44274526834487915,0.43788426617781323,0.43307626495758694,0.4283222605784734,0.4236192579070727,0.4189682553211848,0.41436925282080966,0.4098202511668205,0.4053202494978905,0.40087124705314636,0.39647024124860764,0.39211824039618176,0.3878132378061612,0.38355623682339984,0.37934622913599014,0.37518222630023956,0.3710642258326213,0.36699122190475464,0.36296222110589343,0.3589782143632571,0.35503821820020676,0.35114121188720065,0.3472872128089269,0.34347621103127796,0.3397062048316002,0.3359772016604741,0.332290214796861,0.33045704414447147};
    CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.29770040512085,16.274217287699383,16.217710494995117,16.17810853322347,16.132907072703045,16.083006540934246,16.02880573272705,15.971005042394003,15.909904400507608,15.84610382715861,15.779903491338095,15.711603005727133,15.641602754592896,15.570002476374308,15.4971022605896,15.423101902008057,15.348101695378622,15.272401332855225,15.196101427078247,15.119201183319092,15.042000929514566,14.96440084775289,14.886600812276205,14.808700720469156,14.730700651804606,14.652600606282553,14.574600299199423,14.49660038948059,14.418800354003906,14.341100295384726,14.26360042889913,14.186300357182821,14.109200239181519,14.032400051752726,13.955900271733602,13.879600286483765,13.803600152333578,13.728000084559122,13.652600129445394,13.577600081761679,13.503000100453695,13.428600072860718,13.354700167973837,13.281000137329102,13.207799990971884,13.134899934132894,13.062400023142496,12.99020004272461,12.918400128682455,12.847000042597452,12.776000102361044,12.705300013224283,12.634999910990397,12.565100113550821,12.495600064595541,12.426399946212769,12.357599973678589,12.289199988047281,12.221199989318848,12.153500080108643,12.08619999885559,12.019299983978271,11.952800035476685,11.88670015335083,11.820899963378906,11.755499998728434,11.690499941507975,11.625800053278605,11.561499993006388,11.497599919637045,11.433999935785929,11.370799938837687,11.308000087738037,11.245500008265177,11.18340007464091,11.121699968973795,11.06030003229777,10.999200026194254,10.938599983851114,10.878200054168701,10.818199952443441,10.758600076039633,10.699299971262613,10.640299956003824,10.581700007120768,10.52339998881022,10.465500036875406,10.407899856567383,10.350599924723307,10.293600082397461,10.236999988555908,10.180699904759726,10.124699910481771,10.06909982363383,10.013699928919474,9.95870010058085,9.903990109761557,9.849589904149374,9.795510053634644,9.741730054219564,9.688250064849854,9.635089953740438,9.58221991856893,9.529650211334229,9.477389971415201,9.4254199663798,9.373739957809448,9.322349945704142,9.271260023117065,9.220459858576456,9.169939915339151,9.119710048039755,9.069760004679361,9.020099957784018,8.970710039138794,8.921610037485758,8.872780005137125,8.824220101038614,8.77593986193339,8.727929910024008,8.680190086364746,8.632719993591309,8.585520029067993,8.538580020268759,8.491900046666464,8.44549004236857,8.3993399143219,8.353439966837565,8.307809988657633,8.26243003209432,8.217299938201904,8.172429958979288,8.127799908320108,8.083430051803589,8.039309978485107,7.995430072148641,7.951790014902751,7.908400058746338,7.865249991416931,7.822340091069539,7.779670039812724,7.737239956855774,7.695039947827657,7.653079986572266,7.6113399267196655,7.569850007692973,7.528579990069072,7.487540086110433,7.446720043818156,7.406129956245422,7.365770022074382,7.3256300290425616,7.2857100168863935,7.246009985605876,7.206539988517761,7.167279958724976,7.128229975700378,7.089399973551433,7.050790031750997,7.012380043665568,6.97418995698293,6.936209956804912,6.898440003395081,6.860879937807719,6.823520024617513,6.786370038986206,6.749420007069905,6.712670008341472,6.676130016644795,6.639780084292094,6.603640000025432,6.5676900545756025,6.53193998336792,6.496380011240642,6.46101991335551,6.425860007603963,6.390880028406779,6.3561000029246015,6.321509957313538,6.287099997202556,6.2528800169626875,6.218849976857503,6.185009996096293,6.151350061098735,6.1178799867630005,6.084579984347026,6.051469961802165,6.018540064493815,5.985790014266968,5.953220009803772,5.920819997787476,5.888609965642293,5.85657000541687,5.824700037638347,5.793009996414185,5.7614900668462115,5.730140010515849,5.698970039685567,5.667959968249003,5.637120048205058,5.606460054715474,5.575960079828898,5.5456200043360395,5.5154500007629395,5.4854499499003095,5.455609997113545,5.4259300629297895,5.396419962247212,5.367069999376933,5.337870081265767,5.308839996655782,5.279960036277771,5.251239935557048,5.222680012385051,5.194280068079631,5.1660300095876055,5.137930075327556,5.109989960988362,5.0821999708811445,5.0545601050059,5.027069965998332,4.99974004427592,4.97255011399587,4.9455099900563555,4.9186199108759565,4.891870021820068,4.865270018577576,4.838819980621338,4.812510013580322,4.786339958508809,4.7603200276692705,4.734439969062805,4.708699981371562,4.683100024859111,4.657639980316162,4.632320006688436,4.607140064239502,4.582090059916179,4.557180047035217,4.532410025596619,4.507780035336812,4.483269969622294,4.45890998840332,4.434669931729634,4.41057010491689,4.386599898338318,4.362759947776794,4.339060068130493,4.315480033556621,4.292030056317647,4.268710017204285,4.2455100218455,4.222449978192647,4.199510018030803,4.176689982414246,4.153999924659729,4.13143002986908,4.108989993731181,4.086670001347859,4.064470012982686,4.042390028635661,4.020429968833923,3.9986000259717307,3.976879974206289,3.9552799661954245,3.9338000218073526,3.9124299685160318,3.8911799987157187,3.870050032933553,3.8490399916966758,3.8281399806340537,3.8073500196139016,3.786669969558716,3.7661100029945374,3.7456599871317544,3.7253300150235495,3.7050999999046326,3.684980014959971,3.6649799942970276,3.645080010096232,3.6252899765968323,3.6056100130081177,3.586039960384369,3.566569983959198,3.5472099979718528,3.5279500087102256,3.508799990018209,3.4897600213686624,3.4708200097084045,3.45198001464208,3.433240016301473,3.414609968662262,3.3960800170898438,3.377650022506714,3.3593199849128723,3.3410900036493936,3.3229599793752036,3.304920037587484,3.2869900465011597,3.2691499988238015,3.2514100074768066,3.2337699731191,3.2162299752235413,3.198770006497701,3.181420008341471,3.1641600131988525,3.1469899614652,3.129920025666555,3.112939993540446,3.0960500041643777,3.079249997933706,3.0625499884287515,3.0459400018056235,3.0294100046157837,3.012980024019877,2.9966400265693665,2.9803799788157144,2.9642199873924255,2.94814000527064,2.9321499864260354,2.9162499705950418,2.9004300038019815,2.884699980417887,2.8690600593884787,2.853500008583069,2.8380200266838074,2.822630008061727,2.807330012321472,2.7921000123023987,2.776960015296936,2.7619099617004395,2.7469300031661987,2.732039988040924,2.7172199885050454,2.702489972114563,2.6878399650255838,2.6732600132624307,2.658769985040029,2.6443599859873452,2.630020002524058,2.615760028362274,2.601580003897349,2.5874799887339273,2.573449989159902,2.55949999888738,2.5456299980481467,2.5318300127983093,2.5181100368499756,2.504460016886393,2.490879992643992,2.477380017439524,2.4639500180880227,2.450599988301595,2.4373199939727783,2.4241099754969277,2.4109700520833335,2.397910018761953,2.384910007317861,2.371989985307058,2.359130005041758,2.3463499744733176,2.3336299856503806,2.320989966392517,2.3084100087483725,2.295900026957194,2.2834599812825522,2.2710899909337363,2.258790055910746,2.2465500235557556,2.234379986921946,2.2222699721654258,2.210230012734731,2.198260009288788,2.1863499681154885,2.174499988555908,2.162719984849294,2.151009976863861,2.139360030492147,2.1277700066566467,2.1162400046984353,2.1047799984614053,2.093380014101664,2.082040011882782,2.0707600116729736,2.0595499873161316,2.048390010992686,2.0372999707857766,2.026259978612264,2.0152900218963623,2.00437002380689,1.9935199916362762,1.982720007499059,1.9719800154368083,1.9613100091616313,1.9506799976030986,1.940119981765747,1.9296100040276845,1.9191700021425884,1.9087699949741364,1.8984400033950806,1.8881600101788838,1.8779299954573314,1.867769996325175,1.8576500117778778,1.8475999931494396,1.8375899990399678,1.8276400069395702,1.8177499771118164,1.8079099853833516,1.7981200019518535,1.7883800268173218,1.7787000040213268,1.7690699994564056,1.759500006834666,1.7499699989954631,1.740499993165334,1.7310800155003865,1.7217100163300831,1.7123900055885315,1.7031200031439464,1.6938999891281128,1.6847299933433533,1.6756099959214528,1.666540006796519,1.6575200061003368,1.6485499838987987,1.6396299997965496,1.6307500004768372,1.6219299932320912,1.613149990638097,1.604420006275177,1.5957399904727936,1.5871000091234844,1.5785099963347118,1.569970001777013,1.5614800055821736,1.553029994169871,1.544620007276535,1.5362599988778431,1.527949998776118,1.519679993391037,1.5114600161711376,1.503279983997345,1.4951499899228413,1.487060010433197,1.479010005791982,1.4710100094477336,1.4630499978860219,1.4551399846871693,1.4472600122292836,1.4394299884637196,1.4316500027974446,1.4239000181357067,1.4161999921003978,1.408540000518163,1.4009200036525726,1.393339991569519,1.3858000040054321,1.3783000111579895,1.3708500067392986,1.363429993391037,1.3560599982738495,1.3487199942270915,1.3414299984773,1.3341700037320454,1.3269599974155426,1.3197800020376842,1.3126400013764699,1.3055400153001149,1.2984799941380818,1.2914600173632305,1.284470001856486,1.2775300045808156,1.2706199884414673,1.2637499968210857,1.256910006205241,1.2501099904378254,1.2433499991893768,1.2366300125916798,1.2299399971961975,1.2232899864514668,1.2166800101598103,1.210099995136261,1.203549991051356,1.1970499853293102,1.193800002336502};
    CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.46001704533895,8.488823334376017,8.531164328257242,8.575854221979776,8.618204037348429,8.65830397605896,8.696223974227905,8.732073624928793,8.765913565953573,8.797813415527344,8.827853123346964,8.85610318183899,8.882633129755655,8.907502969106039,8.930762767791748,8.952492713928223,8.972742636998495,8.991572459538778,9.009032408396402,9.025172313054403,9.040042320887247,9.05369202295939,9.066162109375,9.07751210530599,9.087772051493326,9.096992015838623,9.105211814244589,9.112451712290445,9.118761698404947,9.124191602071127,9.128751516342163,9.132471481959024,9.135411500930786,9.137591361999512,9.139031251271566,9.139761288960775,9.139811277389526,9.13922127087911,9.138001124064127,9.136181116104126,9.133771022160849,9.130801121393839,9.127310991287231,9.123300949732462,9.118790864944458,9.113810857137045,9.108370860417685,9.102500756581625,9.096210877100626,9.089520692825317,9.082440773646036,9.074980656305948,9.067180713017782,9.059040546417236,9.050570487976074,9.041780710220337,9.032700697580973,9.023320515950521,9.013670523961386,9.003760496775309,8.993590434392294,8.98318044344584,8.972540537516275,8.961670557657877,8.950580358505249,8.939300298690796,8.927820285161337,8.916160424550375,8.904320319493612,8.892310380935669,8.88014038403829,8.867810408274332,8.855340242385864,8.84272027015686,8.829960187276205,8.81708025932312,8.804080327351889,8.79097024599711,8.777750333150228,8.76442019144694,8.750990311304728,8.737460136413574,8.723840157190958,8.710140148798624,8.696350336074829,8.682480017344156,8.667210022608439,8.650610049565634,8.634039878845215,8.617499907811483,8.60099999109904,8.584529956181845,8.568099896113077,8.55171004931132,8.535339991251627,8.519009987513224,8.502719958623251,8.486459970474243,8.470230023066202,8.454039971033732,8.437879880269369,8.421760002772013,8.405669927597046,8.389609893163046,8.373580058415731,8.357590039571127,8.341629981994629,8.32570997873942,8.30982001622518,8.293950001398722,8.278129975001017,8.262329975763956,8.246569871902466,8.230839967727661,8.215140024820963,8.199469963709513,8.183840115865072,8.168239990870157,8.152659893035889,8.13713010152181,8.121620098749796,8.106139977773031,8.090699990590414,8.075279951095581,8.059900045394897,8.04455010096232,8.029230038324991,8.013940016428629,7.998690048853557,7.983460028966268,7.968269944190979,7.953099966049194,7.937970002492269,7.922859986623128,7.907789985338847,7.89274001121521,7.877730011940002,7.862750053405762,7.847790042559306,7.83286992708842,7.817969957987468,7.8031100034713745,7.788269956906636,7.773470004399617,7.758690079053243,7.743949969609578,7.729229927062988,7.714540044466655,7.699879964192708,7.685249964396159,7.670639991760254,7.6560700337092085,7.641529997189839,7.627010027567546,7.612519979476929,7.5980600118637085,7.583629926045735,7.569230039914449,7.554849942525228,7.540500005086263,7.526180068651835,7.511890014012654,7.497630039850871,7.483390053113301,7.469190001487732,7.455010016759236,7.440850019454956,7.426729957262675,7.412630081176758,7.398559967676799,7.384509960810344,7.370490034421285,7.356499950091044,7.342539985974629,7.3285999695460005,7.314689993858337,7.300810019175212,7.286950031916301,7.273119966189067,7.259319980939229,7.245540062586467,7.231789906819661,7.218069990475972,7.204370021820068,7.190700093905131,7.177049994468689,7.163430015246074,7.149839997291565,7.136270006497701,7.122730016708374,7.109210014343262,7.095720012982686,7.082260052363078,7.068819959958394,7.055409948031108,7.0420200030008955,7.02866001923879,7.015320022900899,7.002009908358256,6.9887300332387285,6.975469986597697,6.96223000685374,6.949019988377889,6.9358400503794355,6.922680020332336,6.909549951553345,6.896440029144287,6.883360107739766,6.870300014813741,6.857270002365112,6.844259937604268,6.831279953320821,6.818319956461589,6.8053799867630005,6.792480031649272,6.779590090115865,6.766729990641276,6.753899971644084,6.741089979807536,6.728299975395203,6.715540011723836,6.702799995740254,6.69008998076121,6.67740003267924,6.664739966392517,6.6520999272664385,6.639490008354187,6.626889944076538,6.614330013593038,6.601779977480571,6.589269995689392,6.576769987742106,6.564299980799357,6.551850001017253,6.539430022239685,6.527030070622762,6.514650026957194,6.502299984296163,6.489969968795776,6.477669994036357,6.465389966964722,6.453130006790161,6.440900007883708,6.428689996401469,6.416500051816304,6.404340028762817,6.392199993133545,6.380080024401347,6.367990016937256,6.35591999689738,6.343870043754578,6.331849972407023,6.319850047429402,6.307869950930278,6.295920014381409,6.283979972203572,6.272080024083455,6.260189970334371,6.248329997062683,6.236489931742351,6.224670052528381,6.2128799756368,6.201099991798401,6.189349969228108,6.177630027135213,6.16591997941335,6.154239972432454,6.142579992612203,6.130950053532918,6.119329969088237,6.1077399253845215,6.096169988314311,6.084619998931885,6.0730899175008135,6.061589956283569,6.0501099824905396,6.038650035858154,6.027209997177124,6.0157999992370605,6.004399975140889,5.993029952049255,5.981679995854695,5.970350066820781,5.95904008547465,5.947759985923767,5.936490019162496,5.925250013669332,5.914029955863953,5.902830044428508,5.891660054524739,5.880499958992004,5.869360009829204,5.858249982198079,5.84715994199117,5.836090008417766,5.825039982795715,5.81401006380717,5.802999973297119,5.792009989420573,5.781049966812134,5.770099918047587,5.759179989496867,5.748279929161072,5.737399935722351,5.726530035336812,5.715689977010091,5.7048700253168745,5.694079955418904,5.683300058046977,5.672539949417114,5.661800026893616,5.651090025901794,5.640390078226726,5.629710038503011,5.6190599997838335,5.608420014381409,5.59780999024709,5.587219953536987,5.576639970143636,5.566090027491252,5.555559953053792,5.545040011405945,5.534549991289775,5.5240700244903564,5.513620058695476,5.5031899611155195,5.492780049641927,5.482380032539368,5.472009976704915,5.461650013923645,5.4513200124104815,5.441010038057963,5.4307100375493365,5.420439998308818,5.4101799329121905,5.39995002746582,5.389730016390483,5.379530032475789,5.369359970092773,5.35920004049937,5.3490599393844604,5.338939984639485,5.328839977582295,5.318759957949321,5.308700084686279,5.2986600796381635,5.28862996896108,5.278629978497823,5.268649935722351,5.258679986000061,5.248729983965556,5.238809982935588,5.228899955749512,5.21901007493337,5.209140022595723,5.199290037155151,5.1894499858220415,5.179639975229899,5.169839978218079,5.160069942474365,5.150310039520264,5.140570004781087,5.130849997202556,5.121149977048238,5.111460049947103,5.101800004641215,5.09215001265208,5.082519968350728,5.072909990946452,5.06331996122996,5.0537499984105425,5.044189969698588,5.034649928410848,5.025129993756612,5.015630046526591,5.006149927775065,4.996690034866333,4.987239996592204,4.9778099457422895,4.968400001525879,4.959010004997253,4.94962998231252,4.940280000368754,4.93094007174174,4.92162009080251,4.912310004234314,4.903029998143514,4.893759926160176,4.884510000546773,4.875279982884725,4.866059978802999,4.856859962145488,4.847679972648621,4.838520010312398,4.829380035400391,4.820249994595845,4.8111400206883745,4.802040060361226,4.792970021565755,4.783910036087036,4.774869958559672,4.7658499876658125,4.756839950879415,4.747849980990092,4.738880077997844,4.729919989903768,4.720980008443196,4.71205993493398,4.703160007794698,4.694270054499309,4.685400009155273,4.676550070444743,4.667710026105245,4.658889929453532,4.650090018908183,4.641300042470296,4.632529973983765,4.623780091603597,4.615039944648743,4.6063201030095415,4.597620010375977,4.588940064112346,4.580269972483317,4.571609973907471,4.562980095545451,4.554350018501282,4.54574994246165,4.5371599594752,4.528590003649394,4.520040074984233,4.511499961217244,4.50297999382019,4.494470040003459,4.485979994138082,4.47751001516978,4.46904997030894,4.460609992345174,4.452179988225301,4.443769971529643,4.435380021731059,4.427000006039937,4.41863997777303,4.410290002822876,4.401959975560506,4.393649975458781,4.385349988937378,4.37706998984019,4.368800004323323,4.360549966494243,4.352319955825806,4.344099958737691,4.335890054702759,4.327699979146321,4.319530049959819,4.311369975407918,4.303230047225952,4.295110026995341,4.2869999806086225,4.278899947802226,4.2708200216293335,4.262760082880656,4.254710038503011,4.246669928232829,4.23865004380544,4.230649987856547,4.2226600249608355,4.2146899700164795,4.206730047861735,4.198790033658345,4.1908600727717085,4.182950019836426,4.1750500202178955,4.16717004776001,4.159300009409587,4.151449998219808,4.143610000610352,4.13579003016154,4.127979914347331,4.120189984639485,4.1124099890391035,4.104639927546184,4.096900065739949,4.089160005251567,4.081440011660258,4.073740045229594,4.069890022277832};
    CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192311604818,514.5848337809244,508.81993611653644,504.2629089355469,499.6569112141927,495.01691182454425,490.35491434733075,485.6819101969401,481.0079116821289,476.3389078776042,471.680913289388,467.03991444905597,462.4209162394206,457.82591247558594,453.2579167683919,448.71991475423175,444.2139129638672,439.7409159342448,435.30391184488934,430.9019190470378,426.5359166463216,422.20792388916016,417.9179204305013,413.6659215291341,409.45192464192706,405.2769241333008,401.1409225463867,397.0439224243164,392.98592376708984,388.96692657470703,384.9859263102214,381.04492441813153,377.14192454020184,373.2769292195638,369.450927734375,365.6619288126628,361.91092681884766,358.19693247477215,354.5209325154622,350.8809305826823,347.27793375651044,343.7119318644206,340.1809361775716,336.68593343098956,333.22593180338544,329.8019332885742,326.4119364420573,323.05694071451825,319.7359364827474,316.4489339192708,313.1959406534831,309.97593943277997,306.7889404296875,303.63394419352215,300.51294199625653,297.4229380289714,294.3659439086914,291.33994547526044,288.3449478149414,285.38094329833984,282.4479446411133,279.5459467569987,276.6739451090495,273.83094278971356,271.0189437866211,268.2349497477214,265.480951944987,262.7559458414714,260.05994923909503,257.39094797770184,254.75094985961914,252.1389528910319,249.5539525349935,246.99595260620117,244.4649518330892,241.96095275878906,239.48295211791992,237.03095499674478,234.60495376586914,232.20495478312174,229.8289566040039,227.4789555867513,225.152956644694,222.85195668538412,220.57495752970377,218.3209571838379,216.09195836385092,213.88595835367838,211.7039566040039,209.5439592997233,207.40596135457358,205.29095967610678,203.19796244303384,201.1269620259603,199.07696406046549,197.0489616394043,195.04196166992188,193.05596542358398,191.089963277181,189.14496358235678,187.21996434529623,185.31496556599936,183.42996470133463,181.56396611531576,179.71796671549478,177.8909657796224,176.08296839396158,174.29296493530273,172.52196629842123,170.76896794637045,169.03496932983398,167.3179677327474,165.61896896362305,163.93796920776367,162.27397028605142,160.62696965535483,158.9979680379232,157.38497161865234,155.78797149658203,154.2079709370931,152.6449712117513,151.0969696044922,149.56597264607748,148.0499725341797,146.54997126261392,145.06497065226236,143.59597142537436,142.14097468058267,140.70197550455728,139.27697372436523,137.8669751485189,136.47197596232095,135.0909741719564,133.72397486368814,132.3709716796875,131.0309715270996,129.70597712198892,128.39397430419922,127.09597524007161,125.81097602844238,124.53897603352864,123.27997716267903,122.0339781443278,120.7999776204427,119.57897631327312,118.37097676595052,117.1749776204427,115.99097887674968,114.81897799173991,113.65997823079427,112.51197878519694,111.37497965494792,110.25097910563152,109.13697942097981,108.03497886657715,106.94397989908855,105.86498006184895,104.79597981770833,103.73797988891602,102.69098154703777,101.6549809773763,100.62898190816243,99.61328125,98.60808118184407,97.61308161417644,96.62808163960774,95.65318171183269,94.68808301289876,93.73288091023763,92.78728167215984,91.85118166605632,90.92468325297038,90.00748380025227,89.09958267211914,88.2008825937907,87.31128311157227,86.43058395385742,85.55888366699219,84.695982615153,83.84178415934245,82.99618466695149,82.15918477376302,81.33058420817058,80.51038487752278,79.69848569234212,78.89478492736816,78.09928448994954,77.3116849263509,76.53208478291829,75.76038551330566,74.99648602803548,74.24028587341309,73.49168586730957,72.75068537394206,72.01718775431316,71.2910868326823,70.57238578796387,69.86088689168294,69.15658632914226,68.4593874613444,67.76918665568034,67.0859858194987,66.40968767801921,65.74028714497884,65.07758776346843,64.4215882619222,63.772287686665855,63.129388173421226,62.49308840433756,61.86328856150309,61.23968823750814,60.62248865763346,60.011488596598305,59.40668869018555,58.80798880259196,58.21528911590576,57.62868881225586,57.04788907368978,56.472989082336426,55.90388933817545,55.34058984120687,54.782989501953125,54.23098913828532,53.68448956807455,53.14358997344971,52.60809008280436,52.07808971405029,51.55339050292969,51.03399054209391,50.51979033152262,50.01089096069336,49.50709088643392,49.00829060872396,48.514591217041016,48.02589098612467,47.542091369628906,47.06319077809652,46.58919111887614,46.11989116668701,45.65539137522379,45.19549147288004,44.74039204915365,44.28979206085205,43.84379164377848,43.4022912979126,42.96519184112549,42.532592137654625,42.10429255167643,41.68039162953695,41.26079177856445,40.84539222717285,40.43419233957926,40.027092615763344,39.624192555745445,39.22529252370199,38.83039251963297,38.43959299723307,38.05269273122152,37.66969267527262,37.29049301147461,36.91519323984782,36.54369322458903,36.17589282989502,35.811893145243324,35.45149326324463,35.09479331970215,34.74159336090088,34.39199352264404,34.0459934870402,33.703393618265785,33.36429405212402,33.02869415283203,32.69639364878336,32.36739412943522,32.04179382324219,31.719494183858234,31.400394439697266,31.08449411392212,30.77179416020711,30.462294101715088,30.15589427947998,29.85259437561035,29.55239454905192,29.255094528198242,28.960894266764324,28.669594287872314,28.38129456837972,28.095894654591877,27.813395023345947,27.533694903055828,27.256794770558674,26.98269494374593,26.711394945780437,26.442794799804688,26.176994800567627,25.91379515329997,25.653195063273113,25.395295302073162,25.139995098114014,24.887295405069988,24.63709529240926,24.38939555486043,24.144195397694904,23.901495297749836,23.661295572916668,23.423395315806072,23.187995592753094,22.954895496368408,22.7241956392924,22.495795567830402,22.2696959177653,22.04589589436849,21.824395815531414,21.604995727539062,21.387896060943604,21.172996044158936,20.960196018218994,20.74959595998128,20.541096210479736,20.334696133931477,20.130396048227947,19.928096612294514,19.72789653142293,19.529696305592854,19.33349625269572,19.139196395874023,18.94689671198527,18.756596565246582,18.568196455637615,18.381596565246582,18.196996847788494,18.014196395874023,17.83319679896037,17.654096762339275,17.4767967859904,17.301196734110516,17.12749656041463,16.955396334330242,16.785096645355225,16.616596857706707,16.4496971766154,16.284496784210205,16.120896975199383,15.958997170130411,15.798796892166138,15.64009698232015,15.483097076416016,15.327597061793009,15.173697153727213,15.021297216415405,14.870497306187948,14.721197207768759,14.573397318522135,14.42709732055664,14.28219731648763,14.138797283172607,13.996897379557291,13.85639731089274,13.717297395070394,13.579597552617392,13.44319740931193,13.308297554651896,13.174697478612265,13.042397499084473,12.911497513453165,12.78189754486084,12.653597513834635,12.526597499847412,12.40089758237203,12.276397784550985,12.153197765350342,12.03129776318868,11.910497744878134,11.790997664133707,11.67269778251648,11.555497805277506,11.439597765604654,11.324797789255777,11.211097796758017,11.098598003387451,10.987297852834066,10.876997947692871,10.767897923787435,10.65979806582133,10.552898009618124,10.44699796040853,10.342198133468628,10.2383979956309,10.135698000590006,10.033998171488443,9.933348178863525,9.83369811375936,9.735048135121664,9.637388149897257,9.54070814450582,9.445008198420206,9.350258111953735,9.256468375523886,9.163628339767456,9.07170828183492,8.98071837425232,8.89063835144043,8.80146837234497,8.713188409805298,8.625808397928873,8.53928836186727,8.453648328781128,8.368868271509806,8.28493849436442,8.201858520507812,8.119608481725058,8.038178443908691,7.9575785001118975,7.87777853012085,7.798778573671977,7.72057859102885,7.643168489138286,7.566528518994649,7.490658561388652,7.415558576583862,7.3411985238393145,7.267598668734233,7.19472857316335,7.1225987275441485,7.051188707351685,6.980498711268107,6.910518646240234,6.841238697369893,6.772658745447795,6.7047587633132935,6.637548724810283,6.571008761723836,6.505138635635376,6.439928809801738,6.375378847122192,6.311478813489278,6.24820876121521,6.1855788230896,6.123588760693868,6.062208930651347,6.00144890944163,5.941298921902974,5.881748874982198,5.822798887888591,5.764448881149292,5.706678946812947,5.649478912353516,5.59286896387736,5.536818981170654,5.481328924496968,5.426408966382344,5.372028986612956,5.318198959032695,5.264899015426636,5.212148984273274,5.159919023513794,5.108219027519226,5.057039062182109,5.00636903444926,4.956199010213216,4.906549135843913,4.857389132181804,4.808719078699748,4.760539134343465,4.712849140167236,4.665629108746846,4.618889093399048,4.572619080543518,4.526809136072795,4.481459140777588,4.4365692138671875,4.39211920897166,4.348129192988078,4.3045692046483355,4.261449217796326,4.2187691529591875,4.176509181658427,4.134669224421184,4.093259215354919,4.052259246508281,4.011669258276622,3.9714892307917276,3.931719263394674,3.8923392494519553,3.85334974527359,3.8339595794677734};
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.89794731140137,40.045278231302895,40.47242069244385,37.29266325632731,38.491790771484375,39.727073987325035,40.96656004587809,41.07982063293457,39.94056638081869,38.6923573811849,37.43660799662272,36.17980559666952,34.9232234954834,33.66631507873535,32.410021464029946,31.152411778767902,29.897422154744465,28.363178730010986,26.51943588256836,24.648409843444824,22.77566687266032,20.902716000874836,19.02956183751424,17.156925280888874,15.282990455627441,13.411940415700277,11.534268220265707,10.440377076466879,10.214625676472982,10.066011985143026,9.921822865804037,9.778643687566122,9.635322411855062,9.49208656946818,9.348760684331259,9.205630858739218,9.061979373296102,8.9861851533254,8.985534032185873,8.991629441579184,8.9980575243632,9.004597345987955,9.01111920674642,9.017642974853516,9.024169921875,9.03069575627645,9.037208477656046,9.047016302744547,9.060479879379272,9.074267148971558,9.088073253631592,9.101895014444986,9.11570429801941,9.129514535268148,9.143333435058594,9.157147328058878,9.170944213867188,9.187569777170816,9.207336664199829,9.227383931477865,9.24743946393331,9.26751176516215,9.287570635477701,9.307631254196167,9.327701091766357,9.34776004155477,9.36782685915629,9.386083046595255,9.40231760342916,9.418362696965536,9.43440580368042,9.450443903605143,9.466485261917114,9.482524236043295,9.498565673828125,9.51459034283956,9.530659039815268,9.53839079538981,9.536823829015097,9.534420490264893,9.53199871381124,9.5295356909434,9.52710517247518,9.524648110071817,9.522213776906332,9.519750992457071,9.51733128229777,9.50878103574117,9.493392785390219,9.477401733398438,9.461382389068604,9.44535223642985,9.429322560628256,9.41328231493632,9.397252321243286,9.381222248077393,9.365192413330078,9.349162260691324,9.333132266998291,9.317102193832397,9.301072438557943,9.28504220644633,9.269012292226156,9.252972523371378,9.236942291259766,9.22091237703959,9.204882383346558,9.188852310180664,9.17282239596049,9.156792481740316,9.140762329101562,9.124732414881388,9.108702500661215,9.092662413914999,9.076632420221964,9.06060242652893,9.044572353363037,9.028542439142862,9.012512365976969,8.996482372283936,8.98045245806376,8.964422424634298,8.948392351468405,8.93236251672109,8.916322549184164,8.90029239654541,8.884262402852377,8.868232448895773,8.852202455202738,8.836172262827555,8.820142467816671,8.804112315177917,8.788082520167032,8.77205240726471,8.756022532780966,8.73998256524404,8.723952452341715,8.707922498385111,8.691892425219217,8.675862471262613,8.65983247756958,8.643802483876547,8.627772331237793,8.611742377281189,8.595712423324585,8.579672574996948,8.563642422358194,8.547612428665161,8.531582554181417,8.515552441279093,8.49952256679535,8.483492374420166,8.467462460199991,8.451432267824808,8.435402313868204,8.41937255859375,8.403332591056824,8.38730231920878,8.371272524197897,8.355242411295572,8.339212457338968,8.323182503382364,8.307152469952902,8.291122476259867,8.275092403093973,8.25906244913737,8.243032574653625,8.226992646853128,8.210962494214376,8.194932460784912,8.178902506828308,8.162872592608133,8.14684247970581,8.130812565485636,8.114782571792603,8.09875245889028,8.082722663879395,8.066682696342468,8.050652464230856,8.034622629483541,8.018592397371927,8.002562602361044,7.986532529195149,7.970502495765686,7.954472343126933,7.938442349433899,7.922412594159444,7.906372507413228,7.890342553456624,7.874312520027161,7.8582825263341265,7.8422525723775225,7.8262226184209185,7.810192545255025,7.794162591298421,7.778132478396098,7.762102683385213,7.746062636375427,7.7300325234731035,7.7140025695164995,7.697972575823466,7.681942582130432,7.665912588437398,7.649882594744365,7.633852601051331,7.617822488149007,7.601792693138123,7.585752646128337,7.569722692171733,7.553692658742269,7.537662585576375,7.521632631619771,7.505602637926738,7.489572564760844,7.47354257106781,7.457512617111206,7.4414825439453125,7.425452709197998,7.409412701924642,7.393382628758748,7.377352674802144,7.3613226016362505,7.345292687416077,7.329262653986613,7.313232620557149,7.297202706336975,7.281172593434651,7.265142758687337,7.249102711677551,7.233072559038798,7.217042605082194,7.201012810071309,7.1849821011225385,7.168954133987427,7.152918696403503,7.136903484662374,7.1208328406016035,7.112016399701436,7.111250519752502,7.111202955245972,7.111197392145793,7.111199657122294,7.111198703447978,7.1111990213394165,7.111198862393697,7.111198981602986,7.111198941866557,7.111198941866557,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666904846827189,6.884192784627278,6.613007028897603,6.674983938535054,6.7453261613845825,6.816614389419556,6.886801083882649,6.898052374521892,6.834463278452556,6.749304175376892,6.657492558161418,6.563291748364766,6.467930237452189,6.371819774309794,6.27511727809906,6.177898804346721,6.080240766207377,5.996280113855998,5.930141131083171,5.868989904721578,5.809259096781413,5.749938408533732,5.6907773812611895,5.6316771904627485,5.572635134061177,5.513647397359212,5.4547081391016645,5.412416855494182,5.391448577245076,5.37659768263499,5.3635977904001875,5.351237456003825,5.339187304178874,5.327327052752177,5.315626899401347,5.304056644439697,5.292616526285808,5.2812864780426025,5.270066301027934,5.258996208508809,5.248096028963725,5.237345973650615,5.226755817731221,5.216315666834514,5.2060054540634155,5.195835550626119,5.185784816741943,5.176924109458923,5.169504125912984,5.162514090538025,5.155653953552246,5.148853937784831,5.142083923021953,5.135343909263611,5.128613789876302,5.12191383043925,5.115223526954651,5.109133164087932,5.103783130645752,5.098603169123332,5.093463063240051,5.088313023249309,5.08314315478007,5.077953060468038,5.072753071784973,5.067523002624512,5.062273184458415,5.056573351224263,5.050433238347371,5.044413089752197,5.0386730035146075,5.033232847849528,5.02806278069814,5.023172537485759,5.018542528152466,5.014142354329427,5.00997253259023,5.005552689234416,5.000752568244934,4.995962460835774,4.991262475649516,4.9866723616917925,4.982192357381185,4.9778222640355425,4.973542292912801,4.969342072804769,4.966090838114421,4.965020219484965,4.965570370356242,4.966550310452779,4.967650294303894,4.968780358632405,4.969910343488057,4.971040368080139,4.972170313199361,4.9732902844746905,4.97441037495931,4.975510358810425,4.976610382397969,4.977700432141622,4.978790362675984,4.979860345522563,4.980930368105571,4.981990337371826,4.983050346374512,4.984100381533305,4.985140323638916,4.986170331637065,4.987200339635213,4.98822037378947,4.989230354626973,4.990240375200908,4.991240342458089,4.992240349451701,4.99323042233785,4.994210322697957,4.995190382003784,4.996170361836751,4.997140367825826,4.998100320498149,4.999060392379761,5.000010371208191,5.000960389773051,5.001900355021159,5.0028403997421265,5.003770351409912,5.004700342814128,5.005630373954773,5.006550391515096,5.007460355758667,5.008360346158345,5.009250322977702,5.010140419006348,5.011000394821167,5.011860370635986,5.012700319290161,5.013530453046163,5.0143504937489825,5.0151604016621905,5.0159504016240435,5.0167404015858965,5.017510414123535,5.018280466397603,5.019040425618489,5.019780357678731,5.0205204884211225,5.021250446637471,5.021980404853821,5.022690335909526,5.02340038617452,5.02409040927887,5.0247803926467896,5.025460481643677,5.026130477587382,5.026790459950765,5.027450482050578,5.028090516726176,5.028730471928914,5.02936049302419,5.0299904346466064,5.030600428581238,5.031210462252299,5.031800429026286,5.032390475273132,5.032970428466797,5.033550540606181,5.034110466639201,5.03467043240865,5.035220503807068,5.0357604424158735,5.036290526390076,5.036820491154988,5.037330508232117,5.0378404060999555,5.038340449333191,5.038830478986104,5.039320468902588,5.039790391921997,5.040260434150696,5.040720502535502,5.041180491447449,5.041650454203288,5.0421104828516645,5.042570392290751,5.0430305401484175,5.043490529060364,5.043950438499451,5.044420440991719,5.0448804299036665,5.045350591341655,5.045810421307881,5.04628050327301,5.046740492184957,5.047210534413655,5.047680417696635,5.048140486081441,5.04861056804657,5.049080491065979,5.049550493558248,5.050020496050517,5.050490538279216,5.050960461298625,5.0514304637908936,5.051900466283162,5.052370508511861,5.0528404712677,5.0533104340235395,5.0537904898325605,5.05426041285197,5.054730455080668,5.055200417836507,5.055680473645528,5.056150396664937,5.056620438893636,5.057090401649475,5.057570457458496,5.058040539423625,5.058510422706604,5.058990399042766,5.059460520744324,5.059930443763733,5.060410459836324,5.060880382855733,5.061360438664754,5.061830480893453,5.062300403912862,5.062780459721883,5.063250422477722,5.063730478286743,5.064200401306152,5.064670443534851,5.065150499343872,5.065620422363281,5.066100438435872,5.066570440928142,5.067050417264302,5.067530473073323,5.067870616912842,5.0680205424626665,5.06812059879303,5.068220575650533,5.068320631980896,5.068420608838399,5.068520545959473,5.068630536397298,5.068730513254802,5.068840583165486,5.0689505736033125,5.069060564041138,5.069160540898641,5.069270531336467,5.0693806409835815,5.069490512212117,5.069600582122803,5.069710652033488,5.069810589154561,5.069920579592387,5.0700306097666425,5.070140600204468,5.070240577061971,5.070350646972656,5.07045050462087,5.070560654004415,5.070660551389058,5.070770621299744,5.070870598157247,5.07097053527832,5.071070591608684,5.071180621782939,5.071280638376872,5.071380575497945,5.071480631828308,5.071580608685811,5.071680545806885,5.071780641873677,5.071870565414429,5.071970502535502,5.072070558865865,5.072170575459798,5.072260578473409,5.072360595067342,5.072450637817383,5.072550535202026,5.072640538215637,5.07274055480957,5.072830557823181,5.072930614153544,5.073020617167155,5.073110659917195,5.0732106765111284,5.07330063978831,5.073390523592631,5.073480606079102,5.073570609092712,5.073660651842753,5.073750575383504,5.073840498924255,5.073930581410726,5.074020663897197,5.074110547701518,5.074200630187988,5.074290633201599,5.074380556742351,5.074470599492391,5.074550588925679,5.074640552202861,5.074730594952901,5.07481054464976,5.0749005873998,5.074990550676982,5.0750705401102705,5.075160582860311,5.07524053255717,5.07533061504364,5.075410604476929,5.0755006074905396,5.075580596923828,5.075670639673869,5.075750549634297,5.075840592384338,5.075920581817627,5.0760005712509155,5.0760906140009565,5.076170603434245,5.0762505531311035,5.076340635617574,5.076420585314433,5.076500574747722,5.07658064365387,5.076660593350728,5.076750636100769,5.0768305857976275,5.076910535494487,5.076990564664205,5.077070554097493,5.077150543530782,5.0772305727005005,5.077310562133789,5.077400644620259,5.077480594317119,5.077560583750407,5.077640533447266,5.077720602353414,5.077800591786702,5.0778805414835615,5.077960570653279,5.0780406792958575,5.078120589256287,5.078190525372823,5.078270634015401,5.07835058371226,5.078430612881978,5.078510562578837,5.078580538431804,5.0786605676015215,5.07874059677124,5.078810493151347,5.0788906415303545,5.078970551490784,5.079040606816609,5.079120596249898,5.079190611839294,5.079270561536153,5.079340577125549,5.079420646031697,5.079490582148234,5.079560558001201,5.079640666643779,5.079710563023885,5.079780578613281,5.079860607783,5.079930543899536,5.080000638961792,5.08008058865865,5.0801505247751875,5.080220540364583,5.08029059569041,5.080360571543376,5.0804305871327715,5.080500562985738,5.080580631891887,5.080650528271993,5.080720583597819,5.080790599187215,5.080860614776611,5.080930630366008,5.081000566482544,5.08107062180837,5.081130663553874,5.08120059967041,5.0812705755233765,5.081340591112773,5.0814106067021685,5.0814805428187055,5.081550598144531,5.081610600153605,5.081680576006572,5.081750591595967,5.081820527712504,5.081880648930867,5.081950545310974,5.082020560900371,5.082080642382304,5.08215057849884,5.082220633824666,5.082280516624451,5.0823506116867065,5.082410613695781,5.082480589548747,5.082540551821391,5.082610567410787,5.082680583000183,5.082740545272827,5.082800666491191,5.082870602607727,5.082930564880371,5.083000620206197,5.083060622215271,5.083130598068237,5.083190560340881,5.0832505623499555,5.083320617675781,5.083380540211995,5.083440542221069,5.083510637283325,5.083570599555969,5.083630561828613,5.083690603574117,5.083760539690654,5.083820621172587,5.083880583445231,5.083940585454305,5.084000627199809,5.084070563316345,5.084130565325419,5.084190567334493,5.084250569343567,5.0843106508255005,5.084370573361714,5.084430654843648,5.084490577379863,5.084550658861796,5.08461062113444,5.084670623143514,5.08474059899648,5.084800601005554,5.084860523541768,5.084910591443379,5.0849705537160235,5.085030555725098,5.085090597470601,5.085150599479675,5.0852106014887495,5.085270524024963,5.085330565770467,5.085390567779541,5.085450569788615,5.085500597953796,5.08556056022644,5.085620562235515,5.085680564244588,5.0857406457265215,5.085800607999166,5.085850556691487,5.085910598436992,5.085970560709636,5.08603052298228,5.086080551147461,5.086140592892964,5.086200475692749,5.0862505833307905,5.086310625076294,5.086370627085368,5.08642057577769,5.086480577786763,5.086540579795837,5.086590568224589,5.086650609970093,5.086700638135274,5.086760600407918,5.086820602416992,5.086870551109314,5.086930592854817,5.086980541547139,5.087040623029073,5.08707054456075};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.221918523311615,2.603925089041392,2.0364588598410287,1.6553413172562916,1.3458987474441528,1.0940843174854915,0.8893640240033468,0.7228913257519404,0.5877473006645838,0.4779457872112592,0.388721523185571,0.3161863659818967,0.2572087583442529,0.20924032106995583,0.17022151748339334,0.13847651208440462,0.11264861809710662,0.0916247982531786,0.0745115348448356,0.060575989385445915,0.049242389698823295,0.040011233960588775,0.032513520369927086,0.026403383196642,0.021447619733711083,0.017407696306084592,0.014134103277077278,0.011466933724780878,0.009306364692747593,0.0075485019866998,0.0061237414289886756,0.004966189192297558,0.004027524109308918,0.003265672014094889,0.002647784926618139,0.0021465811296366155,0.0017401212826371193,0.001410306605976075,0.0011425335833337158,0.000925231366030251,0.0007489733980037272,0.0006060492693601797,0.0004902398698808005,0.00039638453017687425,0.0003204300980238865,0.00025888284168710624,0.000209155622239147,0.00016885359582374804,0.00013635111463372596,8.626502191570277e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8251800537109,563.0181783040365,559.2124532063802,563.8481597900391,568.0144500732422,571.8699696858724,575.4913075764974,576.2033081054688,573.1667989095052,568.862559000651,564.0934041341146,559.1227976481119,554.0380605061849,548.874277750651,543.6444295247396,538.3576456705729,533.0216623942057,527.7243957519531,522.5082499186198,517.3182245890299,512.1361923217773,506.96120198567706,501.7891311645508,496.62324778238934,491.46092987060547,486.3046188354492,481.15284220377606,477.3010838826497,475.17486572265625,473.6202341715495,472.2628428141276,470.9837290445964,469.7406463623047,468.5215810139974,467.321528116862,466.1364974975586,464.9664357503255,463.8233362833659,462.7122548421224,461.6241989135742,460.55613962809247,459.5080846150716,458.4760386149089,457.46199289957684,456.4629364013672,455.4789225260417,454.5107676188151,453.6473337809245,452.9160690307617,452.2300262451172,451.5599899291992,450.896977742513,450.23797098795575,449.5819625854492,448.928949991862,448.27795155843097,447.62891387939453,447.008794148763,446.4257176717122,445.85172780354816,445.27871958414715,444.7047297159831,444.1287333170573,443.5507405598958,442.9707489013672,442.38873291015625,441.8058217366536,441.14117431640625,440.3853123982747,439.6272150675456,438.89515177408856,438.1940460205078,437.5239613850911,436.88486735026044,436.27378845214844,435.68970489501953,435.13067626953125,434.5478286743164,433.92489369710285,433.30084737141925,432.6858367919922,432.08477783203125,431.49475860595703,430.9167124430339,430.34969838460285,429.79163360595703,429.33304087320965,429.1182556152344,429.09996541341144,429.14088185628253,429.20086161295575,429.26484934488934,429.3308512369792,429.39685312906903,429.4618555704753,429.526860555013,429.5908610026042,429.65386454264325,429.7168655395508,429.7788619995117,429.838872273763,429.89886474609375,429.95887756347656,430.01687876383465,430.0738703409831,430.1308822631836,430.18687693277997,430.2428792317708,430.29688517252606,430.35088602701825,430.4038899739583,430.45588938395184,430.5078938802083,430.55889892578125,430.60889943440753,430.65890248616535,430.70789845784503,430.75689697265625,430.8049062093099,430.8519109090169,430.89890543619794,430.9449055989583,430.9909083048503,431.0359166463216,431.07991790771484,431.1249135335286,431.1679204305013,431.21091715494794,431.25391642252606,431.2959264119466,431.33592987060547,431.3749287923177,431.4139353434245,431.44994099934894,431.48594156901044,431.5199457804362,431.5529530843099,431.5839538574219,431.61395772298175,431.6429697672526,431.6709671020508,431.6969706217448,431.7229690551758,431.7479782104492,431.77098083496094,431.7939758300781,431.8159815470378,431.8369827270508,431.8569869995117,431.87598927815753,431.8939946492513,431.9099985758464,431.92699178059894,431.94200134277344,431.9560089111328,431.96900939941406,431.9820073445638,431.99300893147785,432.0040105183919,432.01401774088544,432.0230178833008,432.03102111816406,432.0380223592122,432.04402414957684,432.0490315755208,432.0540313720703,432.0570373535156,432.06003824869794,432.06104278564453,432.0620396931966,432.06204986572266,432.06104278564453,432.06005096435547,432.0570576985677,432.05305735270184,432.04805755615234,432.0430603027344,432.0360692342122,432.02906545003253,432.0220642089844,432.0140660603841,432.0060679117839,431.99806722005206,431.9900716145833,431.98206837972003,431.97406514485675,431.966064453125,431.9580663045247,431.95006561279297,431.9430618286133,431.9350763956706,431.9270655314128,431.9200668334961,431.9120635986328,431.9050649007161,431.8970642089844,431.8900731404622,431.88206736246747,431.8750635782878,431.8680674235026,431.8600667317708,431.85306549072266,431.8460693359375,431.8380635579427,431.83106740315753,431.8240661621094,431.81705983479816,431.81006622314453,431.80306243896484,431.7960688273112,431.7880681355794,431.7810643513997,431.7740732828776,431.7670618693034,431.76007080078125,431.75205993652344,431.74506123860675,431.7380625406901,431.73106384277344,431.7240626017253,431.71706136067706,431.7100652058919,431.7020670572917,431.69506581624347,431.6880645751953,431.6810607910156,431.67406463623047,431.6670608520508,431.6600697835286,431.65206654866535,431.6450678507487,431.63805898030597,431.6310679117839,431.6230697631836,431.6160608927409,431.60906473795575,431.60205841064453,431.60103607177734,431.6070200602214,431.6150182088216,431.62501525878906,431.63501230875653,431.64600880940753,431.6570103963216,431.66801198323566,431.6790084838867,431.6910095214844,431.70201619466144,431.71400960286456,431.72600809733075,431.7370122273763,431.7490056355794,431.7610092163086,431.7720082600911,431.7840067545573,431.79601287841797,431.80701446533203,431.8190104166667,431.83001708984375,431.84100850423175,431.8530095418294,431.86401621500653,431.87500762939453,431.88700612386066,431.89801534016925,431.9090092976888,431.9200134277344,431.93100992838544,431.9420166015625,431.95301055908203,431.9640121459961,431.9740168253581,431.9850133260091,431.9960174560547,432.00601450602215,432.01701100667316,432.0280125935872,432.0380172729492,432.0480092366536,432.0590082804362,432.0690155029297,432.07901255289715,432.09000905354816,432.1000162760417,432.1100133260091,432.12001546223956,432.1300099690755,432.1400146484375,432.15001678466797,432.1600163777669,432.17001088460285,432.18001556396484,432.1900151570638,432.2000096638997,432.21001688639325,432.2190170288086,432.22901153564453,432.23902130126953,432.24801381429035,432.25802357991535,432.2670135498047,432.27702077229816,432.2860107421875,432.29602305094403,432.30501556396484,432.31502024332684,432.32401275634766,432.3340123494466,432.343017578125,432.3520228068034,432.3610127766927,432.3710199991862,432.38001505533856,432.38901774088544,432.3980178833008,432.40702056884766,432.416015625,432.42601776123047,432.4350229899089,432.4440180460612,432.45301818847656,432.4620132446289,432.4710235595703,432.4790217081706,432.48801676432294,432.4970219930013,432.50601959228516,432.51501719156903,432.52401479085285,432.53301493326825,432.5420176188151,432.5500233968099,432.5590184529622,432.5680185953776,432.57701873779297,432.58502197265625,432.5940119425456,432.60301717122394,432.6110204060872,432.6200180053711,432.62901814778644,432.6370162963867,432.64601643880206,432.65502166748047,432.6630223592122,432.67201741536456,432.6800231933594,432.68902079264325,432.697021484375,432.7060190836589,432.7140172322591,432.7230173746745,432.7310256958008,432.739018758138,432.7480163574219,432.75601959228516,432.7640202840169,432.7720209757487,432.78001658121747,432.78901926676434,432.7970199584961,432.8050181070964,432.81302134195965,432.8210194905599,432.8290201822917,432.8370183308919,432.8450190226237,432.85301971435547,432.8610153198242,432.86902109781903,432.8770217895508,432.88402303059894,432.89202372233075,432.90002187093097,432.90802001953125,432.91602325439453,432.9230270385742,432.93101755777997,432.9390233357747,432.9460194905599,432.95401763916016,432.96102650960285,432.9690119425456,432.9770253499349,432.98402404785156,432.99202728271484,432.999018351237,433.0070215861003,433.0140202840169,433.0220209757487,433.0290222167969,433.03602600097656,433.04402414957684,433.05102793375653,433.05802154541016,433.0660222371419,433.0730209350586,433.0800247192383,433.08702341715497,433.0950190226237,433.1020228068034,433.10902150472003,433.11602274576825,433.1230163574219,433.13101959228516,433.13802337646484,433.145024617513,433.15202077229816,433.1590220133464,433.16602325439453,433.1730194091797,433.18002065022785,433.18702443440753,433.1940282185872,433.2010243733724,433.2080256144206,433.21502176920575,433.2220204671224,433.22902425130206,433.2350260416667,433.2420196533203,433.24902089436847,433.2560221354167,433.26301829020184,433.27002207438153,433.2760289510091,433.2830225626628,433.29001871744794,433.29703013102215,433.3030293782552,433.31002044677734,433.31702423095703,433.3230234781901,433.3300196329753,433.33702850341797,433.34302520751953,433.3500264485677,433.3560256958008,433.3630193074544,433.36902618408203,433.3760223388672,433.38202412923175,433.38902537027997,433.39502207438153,433.4020233154297,433.40802510579425,433.4150212605794,433.4210255940755,433.4280242919922,433.4340286254883,433.4410222371419,433.447026570638,433.4530258178711,433.46002705891925,433.46602630615234,433.4720204671224,433.47901916503906,433.4850260416667,433.49102274576825,433.4970245361328,433.50402577718097,433.5100275675456,433.5160217285156,433.5220235188802,433.5290247599284,433.53502655029297,433.54102579752606,433.54703013102215,433.5530242919922,433.55902608235675,433.56602478027344,433.572026570638,433.5780258178711,433.58402760823566,433.5900243123372,433.5960235595703,433.6020228068034,433.6080271402995,433.61402638753253,433.6200230916341,433.6260223388672,433.6320266723633,433.63802337646484,433.64402770996094,433.6500295003255,433.6530354817708};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.44710397720337,9.763456424077352,10.082476933797201,9.438741683959961,9.623534282048544,9.814011891682943,10.00458033879598,9.990699847539267,9.754372437795004,9.49944837888082,9.243069092432657,8.986558119455973,8.730035702387491,8.473520676294962,8.216989676157633,7.960491021474202,7.703934629758199,7.497422297795613,7.34532109896342,7.197783788045247,7.050598820050557,6.903440594673157,6.756288607915242,6.609142104784648,6.461983879407247,6.314852356910706,6.167665799458821,6.075238625208537,6.042342980702718,6.014441768328349,5.986914197603862,5.959436734517415,5.931955734888713,5.904476245244344,5.8769956429799395,5.849517027537028,5.822043617566426,5.800432443618774,5.785220543543498,5.770543138186137,5.755911986033122,5.741272409756978,5.72664217154185,5.712012410163879,5.697382052739461,5.68275260925293,5.668111244837443,5.656500180562337,5.648153980573018,5.640095512072246,5.632044792175293,5.624005039532979,5.615964889526367,5.607925017674764,5.599884907404582,5.591845154762268,5.583804527918498,5.577268838882446,5.572385708491008,5.5676365693410235,5.562906106313069,5.55816634496053,5.553436199824016,5.548696358998616,5.543966253598531,5.539226293563843,5.534496068954468,5.53008500734965,5.526034156481425,5.522014498710632,5.517994324366252,5.51397442817688,5.509944359461467,5.505924304326375,5.501904408137004,5.497884392738342,5.493864297866821,5.48984432220459,5.485824346542358,5.481804410616557,5.477784315745036,5.473764260609944,5.469744324684143,5.465724388758342,5.461694359779358,5.457674860954285,5.453653812408447,5.451406717300415,5.451084136962891,5.450924237569173,5.4507841269175215,5.450634280840556,5.450484077135722,5.450344204902649,5.450194199879964,5.450054208437602,5.449904163678487,5.449754158655803,5.44961420694987,5.449464162190755,5.449324170748393,5.449174165725708,5.449034134546916,5.4488842487335205,5.448734164237976,5.4485942125320435,5.448444128036499,5.448304176330566,5.448154171307881,5.448004126548767,5.447864254315694,5.44771420955658,5.447574138641357,5.447424213091533,5.4472741683324175,5.447134176890056,5.446984171867371,5.446844140688579,5.446694215138753,5.446544090906779,5.446404178937276,5.446254173914592,5.44611410299937,5.445964177449544,5.44581413269043,5.445674220720927,5.445524175961812,5.44538418451945,5.445234139760335,5.44508421421051,5.4449442227681475,5.444794178009033,5.44465418656667,5.444504181543986,5.444364150365193,5.444214264551799,5.444064219792684,5.443924109141032,5.443774183591207,5.4436341524124146,5.44348422686259,5.443334142367045,5.443194190661113,5.443044106165568,5.442904194196065,5.442754189173381,5.442604223887126,5.442464152971904,5.442314108212789,5.442174196243286,5.442024191220601,5.441884120305379,5.441734155019124,5.441584189732869,5.441444198290507,5.441294113794963,5.441144188245137,5.441004196802775,5.44085415204366,5.440714200337728,5.440564235051473,5.4404241641362505,5.440274159113566,5.440124154090881,5.439984122912089,5.439834237098694,5.439694046974182,5.439544161160787,5.4393941561381025,5.43925416469574,5.439104159673055,5.4389640887578325,5.438814163208008,5.438664158185323,5.438524166742961,5.438374161720276,5.438234051068624,5.438084165255229,5.437934160232544,5.437794129053752,5.437644163767497,5.437504132588704,5.437354207038879,5.437214136123657,5.437064250310262,5.436914165814717,5.436774174372355,5.43662412961324,5.436484098434448,5.436334212621053,5.436184128125508,5.436044176419576,5.435894171396892,5.435754060745239,5.4356041351954145,5.43545416990916,5.435314218203227,5.435164133707683,5.43502414226532,5.434874176979065,5.434734145800273,5.434584140777588,5.434434175491333,5.434294144312541,5.434144218762715,5.433994174003601,5.433854103088379,5.433704177538554,5.433564146359761,5.433414181073506,5.433274149894714,5.43312422434489,5.432974179585774,5.432834108670552,5.432684222857158,5.432534138361613,5.432394186655681,5.4322441418965655,5.432104190190633,5.431954224904378,5.4318141142527265,5.431664148966472,5.431514143943787,5.431374152501424,5.43122414747874,5.4310840765635175,5.430934190750122,5.430784145991008,5.430644154548645,5.43049414952596,5.430354158083598,5.4302042325337725,5.430054148038228,5.429914116859436,5.429764231046041,5.429624120394389,5.429474155108134,5.429393847783406,5.429393649101257,5.429383953412374,5.429383754730225,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.22537612915039,24.52680730819702,24.88600730895996,25.24800745646159,25.62370729446411,26.007407506306965,26.394007364908855,26.749407450358074,27.04540729522705,27.289007504781086,27.48640727996826,27.64320707321167,27.728607018788654,27.71700668334961,27.62290620803833,27.45900599161784,27.236505667368572,26.930805524190266,26.52140537897746,26.026404857635498,25.461604754130047,24.840904871622723,24.176404158274334,23.478504180908203,22.75640360514323,22.017903804779053,21.26970338821411,20.515403270721436,19.757803122202557,19.002003351847332,18.252302805582683,17.512102286020916,16.78440237045288,16.071502447128296,15.375502268473307,14.697702089945475,14.039501905441284,13.400301853815714,12.779801686604818,12.178801695505777,11.598001639048258,11.037801583607992,10.498401323954264,9.97978130976359,9.481931209564209,9.004631201426188,8.547571023305258,8.110471169153849,7.692921002705892,7.294390956560771,6.914300918579102,6.5520708958307905,6.2070707480112715,5.878700693448384,5.566330711046855,5.269340713818868,4.987110575040181,4.7190806070963545,4.464650591214498,4.2232305606206255,3.9942305286725364,3.777080476284027,3.5712204575538635,3.376120448112488,3.1912604371706643,3.0161604086558023,2.8503403464953103,2.6932503382364907,2.544420301914215,2.4034903248151145,2.270110289255778,2.143930276234945,2.024610251188278,1.911820262670517,1.8052302499612172,1.7045302093029022,1.6094102164109547,1.5195402105649312,1.4346001942952473,1.3543601830800374,1.2785501678784688,1.2069401641686757,1.139330158631007,1.0754801233609517,1.0151901443799336,0.9582791378100713,0.9067741433779398,0.8615701446930567,0.8211421370506287,0.7849471420049667,0.7525021384159724,0.7233781268199285,0.697199136018753,0.6736281315485636,0.6523661265770594,0.6331521322329839,0.6157541324694952,0.5999631235996882,0.5855981310208639,0.5724971244732538,0.5605141272147497,0.5495211184024811,0.5394081224997839,0.5300741195678711,0.521431123216947,0.5133991241455078,0.5059101233879725,0.4989011163512866,0.4923161193728447,0.48610811680555344,0.4802351122101148,0.47465811173121136,0.4693441167473793,0.46426110963026684,0.45938511192798615,0.45468810945749283,0.4501541083057721,0.44576210528612137,0.4414961114525795,0.4373421048124631,0.4332871064543724,0.4293201019366582,0.4254271040360133,0.42160310596227646,0.41783909996350604,0.4141291007399559,0.41046510140101117,0.4068400984009107,0.40325209746758145,0.39969609926144284,0.3961680978536606,0.392664094765981,0.38918109486500424,0.3857161005338033,0.3822650909423828,0.37882809589306515,0.3754020929336548,0.37198709199825924,0.36858009298642475,0.36518008758624393,0.3617860898375511,0.3583940888444583,0.3550070871909459,0.35162309060494107,0.3482420817017555,0.34486208111047745,0.34148408224185306,0.33810708423455554,0.33472808202107746,0.33135007818539935,0.32797107845544815,0.32459207624197006,0.32121207813421887,0.3178310791651408,0.31444907436768216,0.3110630710919698,0.3076760719219844,0.3042880694071452,0.30089807013670605,0.29750606666008633,0.29411306728919345,0.2907170703013738,0.2873180682460467,0.28391606609026593,0.2805130605896314,0.2771070599555969,0.2737000659108162,0.2702910602092743,0.26687905937433243,0.26346305509408313,0.2600450615088145,0.25662505626678467,0.2532030592362086,0.24978005761901537,0.24635305628180504,0.24292505532503128,0.23949305589000383,0.23605905597408613,0.23262205347418785,0.22918405259648958,0.22574505085746446,0.22230305025974909,0.21886004755894342,0.2154130476216475,0.2119640459616979,0.2085140459239483,0.20506304502487183,0.20161004612843195,0.19815604264537492,0.19470104202628136,0.19124204168717066,0.18778204172849655,0.18432004004716873,0.1808580383658409,0.17739503582318625,0.17393003652493158,0.1704640363653501,0.16699503486355147,0.16352503498395285,0.16005303213993707,0.15658103302121162,0.15310703093806902,0.14963103085756302,0.14615303029616675,0.14267403011520705,0.1391950286924839,0.13571402678887048,0.13223202526569366,0.12874902412295341,0.1252630235006412,0.12177602325876553,0.1182870219151179,0.11479802181323369,0.11130802147090435,0.10781701902548473,0.1043240192035834,0.10082801741858323,0.09733151644468307,0.09383371658623219,0.09033491524557273,0.08683501432339351,0.08333411316076915,0.0798319112509489,0.07632641183833282,0.07282000904281934,0.06931251101195812,0.06580400777359803,0.06229440743724505,0.05878380655000607,0.05527190584689379,0.05175670422613621,0.04824050422757864,0.0447233027468125,0.04120500199496746,0.037685701002677284,0.034165299807985626,0.030643700311581295,0.027311899699270725,0.024342500139027834,0.021696000049511593,0.019337300055970747,0.01723520007605354,0.01536159993459781,0.013691800025602182,0.012203499830017487,0.01087700001274546,0.009694829815998673,0.008641150081530213,0.007702030086268981,0.006865000003017485,0.006118969991803169,0.005454039938437442,0.004861390024113159,0.004333160002715886,0.0038623400420571366,0.003442700020968914,0.003068670048378408,0.0027352899972659848,0.0024381300124029317,0.002173270001852264,0.0019372000048557918,0.001726769997427861,0.0015392100225047518,0.0013720299951576938,0.0012230100110173225,0.0010901799929949145,0.0009717870125314221,0.0008662519879483929,0.0007721820002188906,0.0006883300035648668,0.0006135870110786831,0.0005469619985281801,0.00048757400024139014,0.0004346360025616984,0.0003874480025842786,0.0003453839987438793,0.00030788799631409347,0.0002744639981150006,0.00024466999821015634,0.00021811100062526143,0.00019443599982575202,0.00017333100064812848,0.00015451799966588928,0.00013774699861338982,0.00012279700058570597,0.00010947000009764452,2.5458399250055663e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050132274627686,22.259799321492512,22.13029956817627,22.131999333699543,22.105199019114178,22.053999265034992,21.98229916890462,21.877599398295086,21.730199337005615,21.54819917678833,21.338399410247803,21.10689942042033,20.837899525960285,20.51849953333537,20.159199396769207,19.768999576568604,19.35539960861206,18.90489975611369,18.40619993209839,17.87079970041911,17.308199882507324,16.726799805959065,16.133599917093914,15.534399827321371,14.934199810028076,14.337199926376343,13.746899922688803,13.16439970334371,12.591000000635782,12.028999964396158,11.480299870173136,10.946399847666422,10.428499857584635,9.927280028661093,9.44340991973877,8.97724986076355,8.52895998954773,8.098139882087708,7.6843399206797285,7.287479956944783,6.907410065333049,6.543880025545756,6.196559985478719,5.865099946657817,5.549080014228821,5.248049974441528,4.96154002348582,4.689079999923706,4.430200020472209,4.184370040893555,3.9510599772135415,3.729770004749298,3.5199700196584067,3.321179986000061,3.132879992326101,2.9546000361442566,2.7858699758847556,2.626259982585907,2.4753300150235495,2.332659979661306,2.197819968064626,2.070430020491282,1.9500999947388966,1.8364800016085308,1.7292100091775258,1.6279599964618683,1.5324200093746185,1.442250003417333,1.3571500182151794,1.2768699924151103,1.2011700073877971,1.1298000017801921,1.0625300010045369,0.999142994483312,0.9394359936316808,0.8832059999306997,0.8302620003620783,0.7804130017757416,0.7334729929765066,0.6892819950977961,0.6476869980494181,0.6085400034983953,0.5717030068238577,0.5370480020840963,0.5044510066509247,0.47379499673843384,0.4455289989709854,0.4195299943288167,0.3951229949792226,0.37221000095208484,0.3506939982374509,0.3304910014073054,0.3115209961930911,0.29370899746815365,0.2769789968927701,0.2612670014301936,0.24651199703415236,0.2326509989798069,0.21963099762797356,0.2074009987215201,0.19590899969140688,0.18511099740862846,0.17496500040094057,0.16543199742833772,0.1564719999829928,0.14805199826757112,0.14013799776633581,0.13269699985782304,0.12570000005265078,0.11912299878895283,0.11293899826705456,0.1071229986846447,0.10165299971898396,0.09650889908274014,0.09166829846799374,0.08711480038861434,0.08283099966744582,0.07879799976944923,0.07500059964756171,0.07142659897605579,0.06806239982446034,0.06489289986590545,0.06190849840641022,0.059097999396423496,0.05644849967211485,0.05394999931255976,0.051595899276435375,0.049377199883262314,0.047283499812086426,0.04530929929266373,0.04344759974628687,0.04168899947156509,0.040027398926516376,0.038459098897874355,0.036978499653438725,0.035577899776399136,0.0342548992484808,0.03300459962338209,0.031820399686694145,0.030700599464277428,0.02964119954655568,0.028636399656534195,0.027682699573536713,0.02677939956386884,0.025923499682297308,0.025109799423565466,0.024337999522686005,0.02360559906810522,0.02290799965461095,0.022242899518460035,0.021610799555977184,0.021009699751933415,0.020435299413899582,0.01988839978973071,0.019367399780700605,0.018868299511571724,0.018392099688450497,0.017937499564141035,0.017500899266451597,0.017080999445170164,0.016679399646818638,0.016294799745082855,0.015923899598419666,0.015568199645106992,0.015226799606656035,0.014896499458700418,0.014576599622766176,0.014268799684941769,0.01397249948543807,0.013684499620770415,0.013406699678550163,0.01313849980942905,0.012876999642079076,0.012624099617823958,0.01237929977166156,0.012139699732263884,0.011905099730938673,0.011677499705304703,0.011456399612749616,0.011239199666306376,0.01102789972598354,0.010822199750691652,0.010619299796720346,0.010419199708849192,0.010223999774704376,0.010033399797976017,0.009844809770584106,0.00966040991867582,0.009479969662303725,0.00930089969187975,0.009125469718128443,0.008953459716091553,0.008782299856344858,0.008611959793294469,0.008444709858546654,0.008280389864618579,0.008116459784408411,0.007955239852890372,0.007796569882581632,0.007637949815640847,0.0074793698731809855,0.007323169809145232,0.007169209886342287,0.007015009915145735,0.006862919816436867,0.006712809787131846,0.006562229789172609,0.006411179861364265,0.006262049893848598,0.0061147199012339115,0.005966719860831897,0.005820449946137766,0.005675799873036643,0.005530309863388538,0.0053863999200984836,0.005243949902554353,0.005100529834938546,0.004956199903972447,0.004813349999797841,0.004671889939345419,0.004529389940823118,0.004388259956613183,0.004248409920061628,0.004107409932961066,0.003965329883309702,0.003824579956320425,0.0036850699495213726,0.003544379937617729,0.0034049299623196325,0.003266629995778203,0.0031270799809135497,0.0029886799942081175,0.0028513700235635042,0.002712729969061911,0.0025728399438473084,0.0024341099391070506,0.002296470028037826,0.0021621999718869724,0.0020357799755098918,0.0019167600160775085,0.0018047000048682094,0.0016991999873425812,0.0015998699818737805,0.001506350003182888,0.001418290000098447,0.001335389989738663,0.0012573399969066183,0.0011838599942469348,0.001114670002910619,0.0010495299842053403,0.0009881930018309504,0.0009304469955774645,0.0008760779989340032,0.0008248880039900541,0.0007766910033145299,0.0007313120004255325,0.0006885860008575643,0.0006483579927589744,0.0006104819961668303,0.0005748200007171059,0.0005412420044497898,0.0005096280025706316,0.0004798610001065147,0.00045183399682476494,0.0004254449959262274,0.0004005979984261406,0.00037720299830349785,0.00035517599947828177,0.00033443499948286143,0.000314907003485132,0.00029651899967575446,0.00027920600162663806,0.0002629040027386509,0.00024755499907769263,0.0002331020004930906,0.00021949399888399057,0.0002066810011456255,0.00019461600095382892,0.00018325599861176065,0.0001725590009300504,0.0001624869995187813,0.000153002999771464,0.0001440740015823394,0.00013566500153198527,0.00012774800052284263,0.00012029299978166819,0.00011327299944241531,0.00010666299992105148,5.932193198532332e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.69509251912436,237.72884241739908,240.99087524414062,243.5059076944987,245.3059310913086,246.5479393005371,247.35199864705405,247.10907618204752,245.40610885620117,242.67713673909506,239.25614166259766,235.3931973775228,230.58026758829752,224.46429061889648,217.51330947875977,210.07730992635092,202.42035166422525,194.07440694173178,184.71341705322266,174.7804272969564,164.6084213256836,154.44041315714517,144.45439910888672,134.77438354492188,125.48636309305827,116.64534250895183,108.28232447306316,100.36130968729655,92.84649022420247,85.75957298278809,79.10795402526855,72.88953717549641,67.09491920471191,61.709903399149574,56.71688747406006,52.096274058024086,47.827060063680015,43.88474814097086,40.24533653259277,36.88962586720785,33.79861545562744,30.95430612564087,28.338997840881348,25.93588987986247,23.729382197062176,21.70437526702881,19.847068786621094,18.144363403320312,16.584157943725586,15.155153195063273,13.846548716227213,12.64864452679952,11.552440643310547,10.549437363942465,9.631874163945517,8.792761007944742,8.025518337885538,7.324155966440837,6.683183868726094,6.097481727600098,5.562369863192241,5.073548078536987,4.627066532770793,4.219325065612793,3.847013751665751,3.507092555363973,3.196781496206919,2.913470466931661,2.6547995607058206,2.418688734372457,2.203237990538279,2.0066972772280374,1.8274466196695964,1.663996030886968,1.5149954954783122,1.3791950245698292,1.2554445564746857,1.1426741778850555,1.0398937910795212,0.9462434450785319,0.8609281480312347,0.7832158654928207,0.7124386231104533,0.6479853789011637,0.5893031607071558,0.5358809580405554,0.4875717634956042,0.4439206048846245,0.40416546662648517,0.36794933180014294,0.3349752152959506,0.30497510482867557,0.2776750052968661,0.2528029220799605,0.23016383250554404,0.20955375954508781,0.1907866932451725,0.17369563008348146,0.1581275723874569,0.1439705230295658,0.13109647668898106,0.11936043327053387,0.1086603943258524,0.09892865891257922,0.09007682589193185,0.08202509644130866,0.07470096958180268,0.06803844558695953,0.06197732469687859,0.05643630617608627,0.05136808597793182,0.046756769840916,0.04256115419169267,0.03874354064464569,0.0352696276580294,0.03210841631516814,0.029231705858061712,0.026613696323086817,0.024231087726851303,0.02206267975270748,0.02008897252380848,0.018292566140492756,0.016657360053310793,0.015168854889149467,0.013813950043792525,0.012580445424343148,0.011457541414226094,0.010435237704465786,0.009504474389056364,0.008657041316231092,0.007885438506491482,0.007182855896341304,0.006543093593791127,0.005960521521046758,0.005429989619491001,0.004946847795508802,0.004506836257254084,0.00410608477735271,0.003741093445569277,0.003408652284027388,0.00310584115019689,0.0028300201520323753,0.0025787692672262588,0.0023498984325366714,0.002141397698627164,0.0019514470380575706,0.0017784063917739938,0.0016207558122308303,0.0014771153025018673,0.0013462448356828343,0.0012270044050334643,0.0011183440025585394,0.0010193436658785988,0.000929131322967199,0.000846923033047157,0.0007720087693693737,0.0007037385124325132,0.0006415212992578745,0.000584819097033081,0.0005331419088179246,0.00048604273615637794,0.00044311458623269573,0.000403987445073047,0.0003683243169992541,0.00033581619694208104,0.0003061850948142819,0.0002791739971144125,0.0002545519055274781,0.00023210682896509147,0.0002116447564427896,0.0001929906878406958,0.0001759836292573406,0.0001604795725143049,0.00014634452478882545,0.00013345647676032968,0.00012170643276476767,0.00011099239479032501,6.853075137769338e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527332067489624,3.5471805334091187,3.4357604384422302,3.3270604610443115,3.2169204552968345,3.1060704588890076,2.995140473047892,2.8846704363822937,2.77515039841334,2.6669603983561196,2.560460388660431,2.4559303919474282,2.353620409965515,2.2537203828493753,2.156390368938446,2.061750372250875,1.969900369644165,1.8809203306833904,1.794830322265625,1.7116803030172985,1.6314702828725178,1.5541802843411763,1.4798102676868439,1.4083202580610912,1.3396602272987366,1.273780236641566,1.2106402317682903,1.1501702268918355,1.092290202776591,1.0369502007961273,0.9840611865123113,0.9335571726163229,0.8853561679522196,0.8393831650416056,0.7955601513385773,0.7538081357876459,0.7140501389900843,0.6762081235647202,0.6402081201473871,0.6059741228818893,0.5734341144561768,0.5425181041161219,0.5131551027297974,0.48527709394693375,0.45881809045871097,0.4337140868107478,0.4099050809939702,0.38733207682768506,0.36593707650899887,0.34566206733385724,0.32645606497923535,0.30826706687609357,0.29104606062173843,0.27474605292081833,0.25932104885578156,0.24472604940334955,0.2309220482905706,0.2178670441110929,0.2055240422487259,0.1938560369114081,0.1828280376891295,0.17240803564588228,0.16256203378240267,0.15326103071371713,0.14447802926103273,0.13618402803937593,0.12835302700599036,0.12096202435592811,0.1139850231508414,0.10740102144579093,0.10118802078068256,0.09532572018603484,0.08979601909716924,0.08458021717766921,0.07966051623225212,0.07502221626540025,0.07064961579938729,0.0665262130399545,0.0626383125782013,0.058974912079672016,0.05552211124449968,0.05226671105871598,0.049200210409859814,0.046310809440910816,0.04358750923226277,0.04102190863341093,0.03869130710760752,0.036569107013444103,0.03456040658056736,0.032658206609388195,0.03085600584745407,0.0291475059154133,0.0275269056049486,0.026006305124610662,0.024562005264063675,0.023189404513686895,0.021901404485106468,0.020675304035345714,0.019507403951138258,0.01841140367711584,0.01738300345217188,0.016418003166715305,0.015495003201067448,0.014611402914548913,0.013782302771384517,0.01300420262850821,0.012274102540686727,0.011588902212679386,0.01094590212839345,0.010325002173582712,0.009724991939341029,0.009161881792048613,0.008633431668082872,0.008137511787936091,0.007672111503779888,0.007235361495986581,0.006825481308624148,0.006440831309494873,0.0060798412111277384,0.0057410611771047115,0.005423131049610674,0.005124750973967214,0.0048447308751444025,0.004581930853116016,0.004317861011562248,0.004052590928040445,0.003803630805729578,0.003569970741712799,0.003350690705701709,0.003144880679125587,0.0029517306247726083,0.0027704506064765155,0.002600310583754132,0.002440620524187883,0.002290760457981378,0.002150100461828212,0.0020180804228099682,0.0018941703892778605,0.0017778803885448724,0.001668730362628897,0.0015662903412400435,0.001470140307598437,0.001379900291794911,0.001295200267729039,0.0012157002735572557,0.0011410802447547515,0.0010710502392612398,0.0010053102159872651,0.0009436152079918733,0.0008857061863333607,0.0008313531725434586,0.000780336165917106,0.0007324521575355902,0.0006875081550485144,0.0006453221285482869,0.0006057261295306186,0.0005685611249646172,0.0005336771137081087,0.0005009330949784877,0.00047020009757640463,0.00044135309387153637,0.00041427608812227845,0.00038886107843912515,0.0003650060801495177,0.0003426140732093093,0.0003215960702315594,0.00030186906224116683,0.00028335106374773506,0.0002659700548974797,0.0002496550575112148,0.00023434104999372116,0.0002199670476935959,0.00020647504303876,0.00019381004070358662,0.00018192203909469148,0.00017076403552588695,0.0001602900338184554,0.0001504590327385813,0.0001412300298397895,0.0001325680289786154,0.00012443702568513496,0.00011680502514839948,0.0001096410220876957,9.457998567086179e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.28441854317983,3.2989591360092163,3.3043991525967917,3.3077891866366067,3.3092092076937356,3.3087692658106485,3.306569278240204,3.3026893536249795,3.297219375769297,3.29023939371109,3.2818293968836465,3.2720693945884705,3.26103945573171,3.248799463113149,3.235419432322184,3.2209695180257163,3.2055095434188843,3.1890995502471924,3.1717995603879294,3.1536596020062766,3.134729584058126,3.115069627761841,3.0947296420733132,3.0737396081288657,3.0521596868832908,3.0300296346346536,3.0073896646499634,2.984269678592682,2.9607197046279907,2.936769704023997,2.9124597311019897,2.8878097534179688,2.8628597259521484,2.8376397689183555,2.8121697505315146,2.78648974498113,2.760609765847524,2.7345697482426963,2.708369771639506,2.6820597847302756,2.6556398073832193,2.6291398207346597,2.602569798628489,2.5759598215421042,2.5493198235829673,2.522669812043508,2.496019800504049,2.4693798422813416,2.442779858907064,2.416209876537323,2.3897098700205484,2.3632798393567405,2.3369198640187583,2.310659865538279,2.284489870071411,2.2584398786226907,2.2324998577435813,2.2066898544629416,2.181009908517202,2.1554798682530723,2.1300899585088096,2.1048598686854043,2.079789916674296,2.0548899372418723,2.030159910519918,2.0056099196275077,1.9812399347623189,1.9570499261220295,1.9330599407354991,1.90925994515419,1.88565993309021,1.8622599244117737,1.8390499353408813,1.8160599370797474,1.79326993227005,1.7706899344921112,1.7483199536800385,1.7261699636777241,1.7042199671268463,1.6824899812539418,1.6609799563884735,1.6396799683570862,1.61858997742335,1.597719967365265,1.5770699679851532,1.5566299955050151,1.5356399814287822,1.5141299962997437,1.4929200112819672,1.4719899892807007,1.451339989900589,1.4309599995613098,1.4108599821726482,1.3910399973392487,1.3714800079663594,1.3521699905395508,1.3331300020217896,1.3143599927425385,1.2958400050799053,1.2775699893633525,1.259550005197525,1.2417699893315632,1.2242499788602192,1.2069600125153859,1.1899099946022034,1.1730999847253163,1.1565099954605103,1.1401500006516774,1.1240299940109253,1.1081299881140392,1.0924499928951263,1.0769799848397572,1.061730017264684,1.046700010697047,1.0318799912929535,1.0172700087229412,1.0028399874766667,0.9886219948530197,0.9746099909146627,0.9607999920845032,0.9471889982620875,0.9337559938430786,0.9204959919055303,0.9074280013640722,0.8945489972829819,0.8818549960851669,0.8693449993928274,0.857014000415802,0.8448620041211446,0.8328850020964941,0.8210799992084503,0.8094249914089838,0.7979190001885096,0.7865780045588812,0.7753999928633372,0.7643829981486002,0.7535239905118942,0.7428220063447952,0.7322729925314585,0.7218749970197678,0.7116269965966543,0.7015260010957718,0.6915699938933054,0.6817560096581777,0.6720839937527975,0.6625500023365021,0.653152992328008,0.6438900033632914,0.6347600072622299,0.6257610023021698,0.6168910016616186,0.6081479986508688,0.5995290031035742,0.5910149961709976,0.5826019992431005,0.5743099947770437,0.5661359975735346,0.558078999320666,0.5501369933287302,0.5423090010881424,0.53459199766318,0.5269859979550043,0.5194880018631617,0.5120980044205984,0.504812995592753,0.4976319993535678,0.49055299907922745,0.4835750013589859,0.47669700036446255,0.4699169993400574,0.46323399990797043,0.45664599786202115,0.4501510014136632,0.443750003973643,0.437439002096653,0.4312190016110738,0.4250869999329249,0.41904200116793316,0.4130839978655179,0.40720999985933304,0.4014200021823247,0.3957120006283124,0.39008500178654987,0.38453900068998337,0.3790720005830129,0.37368200222651166,0.3683690031369527,0.3631319999694824,0.3579690034190814,0.35288000106811523,0.3478640044728915,0.3429180011153221,0.3380429993073146,0.33323799818754196,0.32850099603335065,0.3238310019175212,0.3192279984553655,0.314690001308918,0.3102170005440712,0.305807001888752,0.30146100372076035,0.2971759960055351,0.2929520010948181,0.2887880007425944,0.2846840023994446,0.28063799689213437,0.27664900322755176,0.27271799743175507,0.2688419967889786,0.2650210012992223,0.26125499854485196,0.2575430025657018,0.2538829942544301,0.2502749984463056,0.2467190014819304,0.24321300039688745,0.23975700015823045,0.23634999866286913,0.23299200211962065,0.2296819972495238,0.22641799971461296,0.22320199881990752,0.22002999857068062,0.21690400317311287,0.2138229993482431,0.21078500151634216,0.20779099936286607,0.20483899985750517,0.20192900051673254,0.19906000047922134,0.19623300060629845,0.1934449995557467,0.190696998188893,0.18798899898926416,0.18531900147596994,0.18268599982062975,0.1800919994711876,0.1775340015689532,0.17501200114687285,0.17252699782450995,0.17007699981331825,0.16766099880139032,0.1652810014784336,0.1629340002934138,0.1606199989716212,0.1583390012383461,0.1560909984012445,0.15387500077486038,0.15169100215037665,0.1495369995633761,0.14741399884223938,0.1453209991256396,0.14325899754961333,0.14122499898076057,0.13921999807159105,0.1372439960638682,0.13529599954684576,0.1333760010699431,0.13148300101359686,0.12961700186133385,0.12777700275182724,0.12596399833758673,0.12417599931359291,0.12241399909059207,0.12067699991166592,0.11896500115593274,0.1172769982367754,0.1156129992256562,0.11397199891507626,0.1123550006498893,0.11076099860171477,0.10918900060156982,0.10764000006020069,0.10611300108333428,0.10460800118744373,0.10312399951120217,0.10166100102166335,0.1002190001308918,0.09879730083048344,0.09739590001602967,0.09601440032323201,0.09465260058641434,0.09331009909510612,0.09198660030961037,0.09068199930091699,0.08939590056737264,0.0881280992180109,0.08687830033401649,0.08564620092511177,0.08443170040845871,0.0832344014197588,0.08205409968892734,0.08089049967626731,0.07974350017805894,0.07861280006666978,0.07749819941818714,0.07639940020938714,0.07531619941194852,0.07424830086529255,0.07319570022324721,0.07215790015955766,0.07113500001529853,0.0701264999806881,0.06913240005572636,0.06815239849189918,0.06718630033234756,0.06623390068610509,0.06529499900837739,0.06436949968338013,0.06345709909995396,0.0625577000901103,0.061670999974012375,0.06079690003146728,0.05993520033856233,0.05908580031245947,0.05824840006728967,0.05742289995153745,0.05660910035173098,0.05580690006415049,0.05501599951336781,0.05423639963070551,0.05346790018181006,0.05271019972860813,0.05196329982330402,0.051227000231544174,0.05050119974960884,0.049785700316230454,0.04908030045529207,0.04838490020483732,0.04769939991335074,0.04702360027780136,0.04635739978402853,0.04570060037076473,0.04505320048580567,0.04441499958435694,0.043785800226032734,0.04316549965490898,0.042554099733630814,0.04195129995544752,0.041356999737521015,0.0407712006320556,0.04019369992117087,0.039624400126437344,0.03906320004413525,0.03850990037123362,0.037964499865969024,0.0374267998461922,0.03689679969102144,0.036374199825028576,0.03585910021016995,0.035351299991210304,0.034850699827075005,0.034357200066248574,0.0338705995430549,0.033390999771654606,0.03291819989681244,0.032452099956572056,0.03199259967853626,0.03153959972163042,0.03109299996867776,0.030652800264457863,0.030218799753735464,0.029790999988714855,0.02936919980371992,0.02895339981963237,0.02854350007449587,0.028139399830251932,0.027741100018223126,0.027348299821217854,0.026961200094471376,0.026579500020792086,0.02620330002779762,0.02583239988113443,0.025466700084507465,0.025106199861814577,0.024750899833937485,0.024400600076963503,0.024055199852834146,0.023714700092871983,0.023379100176195305,0.023048199868450563,0.022721999945739906,0.022400399825225275,0.022083399817347527,0.02177089996015032,0.021462800136456888,0.021159099725385506,0.02085960004478693,0.020564499932030838,0.020273400004953146,0.019986599994202454,0.019703799858689308,0.019424999753634136,0.019150099872301023,0.01887910021468997,0.01861200000469883,0.018348700056473415,0.018089100097616512,0.01783310016617179,0.017580800068875153,0.017332099998990696,0.017086900149782498,0.016845200210809708,0.01660679963727792,0.016371900215744972,0.016140300159653027,0.015911999779442947,0.01568690004448096,0.015464999945834279,0.01524619998720785,0.015030599975337585,0.014817900179574886,0.014608299902950725,0.014401700192441544,0.014197999999547998,0.013997199945151806,0.01379920014490684,0.013604100017497936,0.013411599987496933,0.013221999940772852,0.013035000069066882,0.012850600061938167,0.012668899958953261,0.012489699836199483,0.012313100043684244,0.012138999998569489,0.011967299971729517,0.011798100157951316,0.011631200167660912,0.011466699885204434,0.011304600009073814,0.01114469999447465,0.010987199998150269,0.010831800134231647,0.010678599821403623,0.010527700030555328,0.01037880009971559,0.010232100108017525,0.01008740005393823,0.009944770097111663,0.00980416995783647,0.0096655598996828,0.009528910120328268,0.009394189963738123,0.009261389961466193,0.009130460054924091,0.009001379987845818,0.00887413004723688,0.0087486799651136,0.008625010028481483,0.008503089969356855,0.00838289006302754,0.008264389898007115,0.00814756991652151,0.00803241009513537,0.007918869921316704,0.007806939965424438,0.007696589998280008,0.00758780996936063,0.0074805600646262365,0.007374830000723402,0.007270599987047414,0.0071678400272503495,0.00706653999319921,0.0069666700437664986,0.0068682100002964335,0.00677114996748666,0.006675460026599467,0.0065811199601739645,0.006488119950518012,0.006396429962478578,0.006306040023143093,0.00621692999266088,0.006129080041622122,0.006042469952565928,0.005957079973692696,0.005872909988587101,0.0057899199503784375,0.005708110014287134,0.0056274600404625135,0.005547949927859008,0.005469560002287229,0.0053922800191988545,0.005316089993963639,0.005240980070084333,0.005203699925914407};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261275927225749,0.4188620373606682,0.41084803144137066,0.4034990221261978,0.396086019774278,0.38862302154302597,0.38112902641296387,0.3736160198847453,0.3660990198453267,0.35858802249034244,0.3510960191488266,0.343632015089194,0.33620601892471313,0.3288280169169108,0.3215050126115481,0.31424401452143985,0.30705201377471286,0.2999350155393283,0.2928990150491397,0.2859490141272545,0.27908900876839954,0.27232301235198975,0.26565401007731754,0.2590850094954173,0.25261800984541577,0.24625700960556665,0.24000400925676027,0.23386000717679659,0.22782500957449278,0.22190300623575845,0.21609200909733772,0.21039400498072305,0.20480800544222197,0.1993360072374344,0.19397500654061636,0.188727006316185,0.18359200780590376,0.17856900642315546,0.17365600789586702,0.16885200267036757,0.1641590048869451,0.15957200651367506,0.15509200592835745,0.1507180059949557,0.14644800126552582,0.14228100577990213,0.13821500539779663,0.13424900298317274,0.1303810030221939,0.12661000030736128,0.12293400305012862,0.11935200293858846,0.11586200383802255,0.11246100254356861,0.10914900278051694,0.10592500306665897,0.10278600205977757,0.09973050157229106,0.09675700155397256,0.09386350152393182,0.09104820216695468,0.08830940226713817,0.08564650143186252,0.08305810205638409,0.080541401480635,0.07809480217595895,0.0757172020773093,0.07340580100814502,0.07115950124959151,0.06897700143357118,0.06685720073680083,0.06479880089561145,0.0627996011947592,0.060857400919000305,0.05897140068312486,0.05714050121605396,0.05536280075709025,0.05363750116278728,0.05196360064049562,0.05033950041979551,0.04876310067872206,0.04723280016332865,0.04574800034364065,0.04430820078899463,0.042911700593928494,0.04155690005669991,0.040151298977434635,0.03870100031296412,0.03730350018789371,0.03595660006006559,0.0346585006142656,0.03340750032414993,0.03220189983646075,0.031039999953160684,0.02992010038966934,0.02884090008834998,0.027800700161606073,0.026798200017462175,0.02583189991613229,0.024900699965655804,0.024003099805365007,0.023138000008960564,0.0223042001016438,0.021500600191454094,0.02072600011403362,0.01997940040503939,0.01925980020314455,0.01856620004400611,0.01789769995957613,0.017253300175070763,0.016632199753075838,0.016033500122527283,0.015456499997526407,0.014900199991340438,0.014364099983746806,0.013847299929087361,0.013349199978013834,0.012868999969214201,0.012406100053340197,0.011960000032559037,0.011529899900779128,0.011115400043005744,0.010715799949442347,0.010330599965527654,0.009959249990060925,0.009601320062453548,0.009256279949719707,0.008923689912383756,0.008603070008878907,0.008293999979893366,0.007996070043494305,0.007708859979175031,0.007432000013068318,0.0071650999986256165,0.0069078099525844055,0.006659780008097489,0.00642066999959449,0.006190169990683596,0.005967959955645104,0.005753750020327668,0.0055472300155088305,0.0053481500362977386,0.005156219975712399,0.004971189928861956,0.004792810068465769,0.004620849969796836,0.004455059999600053,0.004295239962326984,0.004141150003609558,0.0039926000172272325,0.003849390021059662,0.0037113300058990717,0.0035782200090276697,0.0034498900058679283,0.0033261699912448726,0.003206899952298651,0.003091900007954488,0.0029810399864800274,0.0028741499797130623,0.00277109999054422,0.0026717500295490026,0.002575969983202716,0.0024836200173012912,0.002394590002950281,0.002308750020650526,0.0022259900191177926,0.0021462000246780613,0.0020692700248522065,0.0019950999800736704,0.0019235900059963267,0.0018546500068623573,0.0017881800013128668,0.001724090000304083,0.001662300016808634,0.0016027299958902101,0.0015452899970114231,0.001489910006057471,0.001436519999212275,0.0013850399991497397,0.0013354100131740172,0.0012875600077677518,0.0012414199979199718,0.001196929990934829,0.0011540400058341522,0.0011126900014157097,0.0010728200043862064,0.0010343799949623644,0.0009973130169479798,0.0009615769910548503,0.0009271229985946169,0.0008939040029266229,0.0008618749949770669,0.0008309949965526661,0.0008012209921920052,0.0007725140021648258,0.0007448369966975102,0.0007181510106117154,0.0006924219972764453,0.0006676139989091704,0.0006436959956772625,0.0006206349983888989,0.0005984010009948785,0.000576964002296639,0.0005562939962449794,0.0005363660020520911,0.0005171509983483702,0.0004986259979583944,0.00048076400222877663,0.00046354199973090243,0.000446936998438711,0.00043092799751320854,0.0004154920025030151,0.00040060900209937245,0.000386259004396076,0.00037242400139803067,0.00035908499800522503,0.00034622300396828604,0.0003338220000538665,0.00032186599855776876,0.0003103380076936446,0.00029922300260902074,0.0002885060045324887,0.0002781729999696836,0.00026821100133626413,0.0002586049983316722,0.0002493440018345912,0.0002404140007759755,0.00023180499799006307,0.00022350300059770234,0.0002154989997507073,0.0002077819978391441,0.0002003420001225701,0.0001931669988456027,0.0001862500018129746,0.00017958099973232797,0.0001731510007327112,0.00016695000037240484,0.00016097300006852797,0.00015520899857316786,0.00014965199928459091,0.0001442929994179091,0.00013912699917758195,0.0001341459998608722,0.0001293440000154078,0.00012471299972579195,0.00012024799859015427,0.00011594400045093305,0.00011179299993576326,0.00010779100011859555,0.00010393300059755954,5.89010675563865e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1797917683919,329.0759760538737,329.77097574869794,330.48597208658856,331.17797597249347,331.8479766845703,332.4959716796875,333.1209767659505,333.72297922770184,334.3009770711263,334.85597229003906,335.38797760009766,335.8979771931966,336.38397725423175,336.8489761352539,337.29098256429035,337.7109781901042,338.11297607421875,338.5029780069987,338.8799743652344,339.2449773152669,339.59797922770184,339.93797810872394,340.26598358154297,340.5819803873698,340.88597869873047,341.1789805094401,341.4619827270508,341.73998006184894,342.010981241862,342.27698008219403,342.5359853108724,342.7899805704753,343.0379816691081,343.2809753417969,343.5179850260417,343.7489827473958,343.9759801228841,344.19897715250653,344.41897837320965,344.635981241862,344.8499806722005,345.0599772135417,345.26698048909503,345.4709777832031,345.67098236083984,345.86898040771484,346.06397755940753,346.2579828898112,346.4499791463216,346.64098358154297,346.8299814860026,347.01697794596356,347.20398203531903,347.3889846801758,347.5719757080078,347.7539774576823,347.9359817504883,348.11997985839844,348.3039779663086,348.48998260498047,348.677978515625,348.865971883138,349.0559794108073,349.2469838460286,349.4399770100911,349.6339797973633,349.8309783935547,350.03397878011066,350.24198150634766,350.4559834798177,350.6749801635742,350.8989791870117,351.1289800008138,351.3639831542969,351.6039810180664,351.8499806722005,352.09598032633465,352.33797454833984,352.5759785970052,352.8089828491211,353.03797658284503,353.26298268636066,353.4839782714844,353.7009811401367,353.9129816691081,354.1219762166341,354.3269805908203,354.5289840698242,354.7289810180664,354.9259745279948,355.11898040771484,355.3109842936198,355.4989827473958,355.6849848429362,355.8679835001628,356.04797617594403,356.2259801228841,356.40098063151044,356.573979695638,356.74398549397785,356.9109802246094,357.0759785970052,357.23798116048175,357.39798227945965,357.5549825032552,357.7099787394206,357.8629786173503,358.0119806925456,358.1599807739258,358.3049774169922,358.44798278808594,358.5879847208659,358.7259775797526,358.8609797159831,358.9939778645833,359.1249771118164,359.2539800008138,359.3799819946289,359.5049794514974,359.625981648763,359.74598185221356,359.8639856974284,359.9789784749349,360.0919825236003,360.20298767089844,360.3119862874349,360.41798400878906,360.5229797363281,360.62598673502606,360.7259826660156,360.82398223876953,360.92098236083984,361.0149866739909,361.1069844563802,361.1969807942708,361.2859802246094,361.3719787597656,361.4559783935547,361.53898366292316,361.6189829508464,361.6969807942708,361.77398173014325,361.8489812215169,361.9219792683919,361.9919840494792,362.0619862874349,362.12898508707684,362.19397989908856,362.2579828898112,362.3199818929036,362.3799794514974,362.437983194987,362.49398549397785,362.5489781697591,362.60198465983075,362.6529795328776,362.70298258463544,362.750981648763,362.79698181152344,362.8409830729167,362.8839874267578,362.9249852498372,362.96497853597003,363.0029830932617,363.0389811197917,363.07398478190106,363.1069819132487,363.13798268636066,363.16798146565753,363.1959813435872,363.2229817708333,363.24798583984375,363.27198537190753,363.2939809163411,363.31498463948566,363.333984375,363.3519821166992,363.3679835001628,363.3829828898112,363.39698537190753,363.40797932942706,363.4189860026042,363.42798105875653,363.4359817504883,363.44198354085285,363.44697825113934,363.44998423258465,363.4519805908203,363.4529851277669,363.45198313395184,363.4509811401367,363.4469858805339,363.44298553466797,363.4369837443034,363.4299850463867,363.42098236083984,363.41197967529297,363.40098571777344,363.3879801432292,363.37497965494794,363.3599802652995,363.34398142496747,363.3269805908203,363.3089853922526,363.28897857666016,363.2689844767253,363.24698130289715,363.22398376464844,363.19897715250653,363.17398325602215,363.14798736572266,363.11998494466144,363.0909830729167,363.06097920735675,363.0299809773763,362.99798075358075,362.96497853597003,362.9309895833333,362.8949839274089,362.8589833577474,362.8209813435872,362.7829844156901,362.7429835001628,362.7019856770833,362.66097768147785,362.61798095703125,362.57398223876953,362.5299809773763,362.4839808146159,362.4369812011719,362.3899841308594,362.34098561604816,362.2909800211589,362.24098205566406,362.18897755940753,362.1369857788086,362.08398183186847,362.031977335612,361.979985555013,361.9289830525716,361.8779805501302,361.82698313395184,361.77698008219403,361.72698465983075,361.6769765218099,361.6279805501302,361.5799789428711,361.5309804280599,361.4829788208008,361.4359817504883,361.3889745076497,361.3419825236003,361.29498291015625,361.2489827473958,361.2039845784505,361.1579844156901,361.1129862467448,361.06897989908856,361.02398681640625,360.9809824625651,360.9369812011719,360.89398193359375,360.8509826660156,360.8079833984375,360.76597849527997,360.72398376464844,360.6829783121745,360.64098866780597,360.60098520914715,360.5599848429362,360.51998138427734,360.479985555013,360.43998463948566,360.40098571777344,360.3619842529297,360.32298533121747,360.28497823079425,360.24698130289715,360.20898183186847,360.17198181152344,360.1339848836263,360.09798431396484,360.06097920735675,360.0249837239583,359.9889856974284,359.9529851277669,359.91698201497394,359.8819808959961,359.8469823201497,359.81297556559247,359.7779795328776,359.74398549397785,359.7109832763672,359.67698669433594,359.64398193359375,359.61098225911456,359.57798767089844,359.54598236083984,359.5129852294922,359.4809850056966,359.44998423258465,359.41798400878906,359.3869857788086,359.3559850056966,359.3249816894531,359.29498291015625,359.2649790445964,359.23498280843097,359.2049814860026,359.1749852498372,359.14598083496094,359.1169789632161,359.0879847208659,359.0589828491211,359.03098551432294,359.0029805501302,358.97498321533203,358.9469858805339,358.9199803670247,358.8929850260417,358.8659845987956,358.8389841715495,358.81197865804035,358.7859827677409,358.7599843343099,358.7339808146159,358.7079823811849,358.6819763183594,358.65697987874347,358.6319859822591,358.6069844563802,358.5819829305013,358.5569814046224,358.5329844156901,358.50897725423175,358.48498280843097,358.4609832763672,358.4369812011719,358.4139887491862,358.39098358154297,358.3679835001628,358.34498087565106,358.3219807942708,358.2999852498372,358.27698008219403,358.2549870808919,358.2329788208008,358.21098073323566,358.1899770100911,358.16797892252606,358.14698282877606,358.12598419189453,358.10497792561847,358.083984375,358.06398010253906,358.04298146565753,358.02298736572266,358.0029805501302,357.9829813639323,357.9629821777344,357.94398498535156,357.92398325602215,357.9049835205078,357.88597869873047,357.86698150634766,357.8479817708333,357.8289845784505,357.8109817504883,357.79198455810547,357.7739842732747,357.75598398844403,357.73798116048175,357.71998341878253,357.70198313395184,357.6849822998047,357.66797892252606,357.64998626708984,357.6329854329427,357.6159845987956,357.5989812215169,357.5829823811849,357.56598409016925,357.5499852498372,357.5329869588216,357.51698048909503,357.500981648763,357.48498280843097,357.46998087565106,357.4539845784505,357.43798065185547,357.4229787190755,357.4079869588216,357.3929850260417,357.3779830932617,357.3629786173503,357.3479868570964,357.33298746744794,357.31898498535156,357.3039830525716,357.2899856567383,357.2759831746419,357.26198323567706,357.2479832967122,357.2339833577474,357.21998341878253,357.2059809366862,357.1929880777995,357.1799850463867,357.1659851074219,357.1529795328776,357.1399841308594,357.1269810994466,357.1139856974284,357.1009826660156,357.0889841715495,357.0759811401367,357.06398518880206,357.0509796142578,357.0389862060547,357.0269826253255,357.0149790445964,357.00298563639325,356.99097951253253,356.9789861043294,356.96797943115234,356.9559860229492,356.94498443603516,356.93298594156903,356.92198181152344,356.9109802246094,356.89998118082684,356.8889846801758,356.8779830932617,356.8669789632161,356.85597737630206,356.84498341878253,356.8349838256836,356.82398732503253,356.81397755940753,356.8039855957031,356.79297892252606,356.7829767862956,356.77298227945965,356.76298268636066,356.75298563639325,356.7439829508464,356.7339859008789,356.72397867838544,356.71498107910156,356.7049814860026,356.69598388671875,356.6859842936198,356.67698160807294,356.66798146565753,356.6589813232422,356.6499837239583,356.64097849527997,356.63197835286456,356.62298075358075,356.61398061116535,356.6059824625651,356.5969823201497,356.58897908528644,356.57997639973956,356.57198333740234,356.56298573811847,356.5549825032552,356.54698689778644,356.53898366292316,356.5309829711914,356.5229797363281,356.5149866739909,356.5069808959961,356.4989827473958,356.4919840494792,356.4839833577474,356.47598520914715,356.46897888183594,356.46098073323566,356.45398203531903,356.4469807942708,356.43898518880206,356.4319839477539,356.4249801635742,356.42198689778644};
}

void set_concs_ssp534_over() //from year 1700 to year 2500
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.665241152,9.603058728,9.540876303,9.478693879,9.416511454,9.318521072,9.22053069,9.122540308,9.024549926,8.926559544,8.828569162,8.73057878,8.632588398,8.534598016,8.436607634,8.399193441,8.361779249,8.324365056,8.286950864,8.249536671,8.212122479,8.174708286,8.137294094,8.099879901,8.062465709,7.812736341,7.563006973,7.313277604,7.063548236,6.813818868,6.5640895,6.314360132,6.064630764,5.814901396,5.565172027,5.472894625,5.380617223,5.288339821,5.196062418,5.103785016,5.011507614,4.919230212,4.826952809,4.734675407,4.642398005,4.547445921,4.452493836,4.357541752,4.262589668,4.167637584,4.0726855,3.977733416,3.882781332,3.787829248,3.692877163,3.611722597,3.53056803,3.449413464,3.368258897,3.287104331,3.205949764,3.124795197,3.043640631,2.962486064,2.881331498,2.834081757,2.786832017,2.739582276,2.692332536,2.645082796,2.597833055,2.550583315,2.503333575,2.456083834,2.408834094,2.385737614,2.362641134,2.339544654,2.316448174,2.293351694,2.270255214,2.247158734,2.224062254,2.200965774,2.177869294,2.173168035,2.168466775,2.163765516,2.159064257,2.154362998,2.149661738,2.144960479,2.14025922,2.135557961,2.130856701,2.126155442,2.121454183,2.116752924,2.112051664,2.107350405,2.102649146,2.097947887,2.093246628,2.088545368,2.083844109,2.07914285,2.074441591,2.069740331,2.065039072,2.060337813,2.055636554,2.050935294,2.046234035,2.041532776,2.036831517,2.032130258,2.027428998,2.022727739,2.01802648,2.013325221,2.008623961,2.003922702,1.999221443,1.994520184,1.989818924,1.985117665,1.980416406,1.975715147,1.971013887,1.966312628,1.961611369,1.95691011,1.952208851,1.947507591,1.942806332,1.938105073,1.933403814,1.928702554,1.924001295,1.919300036,1.914598777,1.909897517,1.905196258,1.900494999,1.89579374,1.891092481,1.886391221,1.881689962,1.876988703,1.872287444,1.867586184,1.862884925,1.858183666,1.853482407,1.848781147,1.844079888,1.839378629,1.83467737,1.82997611,1.825274851,1.820573592,1.815872333,1.811171074,1.806469814,1.801768555,1.797067296,1.792366037,1.787664777,1.782963518,1.778262259,1.773561,1.76885974,1.764158481,1.759457222,1.754755963,1.750054704,1.745353444,1.740652185,1.735950926,1.731249667,1.726548407,1.721847148,1.717145889,1.71244463,1.70774337,1.703042111,1.698340852,1.693639593,1.688938333,1.684237074,1.679535815,1.674834556,1.670133297,1.665432037,1.660730778,1.656029519,1.65132826,1.646627,1.641925741,1.637224482,1.632523223,1.627821963,1.623120704,1.618419445,1.613718186,1.609016926,1.604315667,1.599614408,1.594913149,1.59021189,1.58551063,1.580809371,1.576108112,1.571406853,1.566705593,1.562004334,1.557303075,1.552601816,1.547900556,1.543199297,1.538498038,1.533796779,1.52909552,1.52439426,1.519693001,1.514991742,1.510290483,1.505589223,1.500887964,1.496186705,1.491485446,1.486784186,1.482082927,1.477381668,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409,1.472680409};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,33.98323709,33.22044995,32.4576628,31.69487566,30.93208852,30.27921928,29.62635004,28.9734808,28.32061156,27.66774232,27.01487307,26.36200383,25.70913459,25.05626535,24.40339611,24.09682947,23.79026283,23.48369619,23.17712955,22.87056291,22.56399627,22.25742963,21.95086299,21.64429635,21.3377297,21.06832212,20.79891453,20.52950694,20.26009935,19.99069176,19.72128417,19.45187658,19.18246899,18.9130614,18.64365381,18.48889459,18.33413537,18.17937615,18.02461692,17.8698577,17.71509848,17.56033926,17.40558004,17.25082081,17.09606159,16.99116814,16.88627468,16.78138123,16.67648777,16.57159432,16.46670086,16.36180741,16.25691395,16.1520205,16.04712704,15.99919844,15.95126984,15.90334124,15.85541265,15.80748405,15.75955545,15.71162685,15.66369825,15.61576965,15.56784105,15.50546172,15.44308238,15.38070305,15.31832372,15.25594439,15.19356505,15.13118572,15.06880639,15.00642706,14.94404772,14.92930272,14.91455772,14.89981271,14.88506771,14.8703227,14.8555777,14.8408327,14.82608769,14.81134269,14.79659769,14.78584103,14.77508438,14.76432773,14.75357108,14.74281443,14.73205778,14.72130113,14.71054448,14.69978783,14.68903118,14.67827453,14.66751788,14.65676123,14.64600458,14.63524793,14.62449128,14.61373463,14.60297798,14.59222133,14.58146468,14.57070803,14.55995138,14.54919473,14.53843808,14.52768143,14.51692478,14.50616813,14.49541148,14.48465483,14.47389818,14.46314153,14.45238488,14.44162823,14.43087158,14.42011492,14.40935827,14.39860162,14.38784497,14.37708832,14.36633167,14.35557502,14.34481837,14.33406172,14.32330507,14.31254842,14.30179177,14.29103512,14.28027847,14.26952182,14.25876517,14.24800852,14.23725187,14.22649522,14.21573857,14.20498192,14.19422527,14.18346862,14.17271197,14.16195532,14.15119867,14.14044202,14.12968537,14.11892872,14.10817207,14.09741542,14.08665877,14.07590212,14.06514547,14.05438881,14.04363216,14.03287551,14.02211886,14.01136221,14.00060556,13.98984891,13.97909226,13.96833561,13.95757896,13.94682231,13.93606566,13.92530901,13.91455236,13.90379571,13.89303906,13.88228241,13.87152576,13.86076911,13.85001246,13.83925581,13.82849916,13.81774251,13.80698586,13.79622921,13.78547256,13.77471591,13.76395926,13.75320261,13.74244596,13.73168931,13.72093266,13.71017601,13.69941936,13.68866271,13.67790605,13.6671494,13.65639275,13.6456361,13.63487945,13.6241228,13.61336615,13.6026095,13.59185285,13.5810962,13.57033955,13.5595829,13.54882625,13.5380696,13.52731295,13.5165563,13.50579965,13.495043,13.48428635,13.4735297,13.46277305,13.4520164,13.44125975,13.4305031,13.41974645,13.4089898,13.39823315,13.3874765,13.37671985,13.3659632,13.35520655,13.3444499,13.33369325,13.3229366,13.31217994,13.30142329,13.29066664,13.27990999,13.26915334,13.25839669,13.24764004,13.23688339,13.22612674,13.21537009,13.20461344,13.19385679,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014,13.18310014};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,96.64709616,92.52302535,88.39895453,84.27488372,80.1508129,79.28668059,78.42254827,77.55841596,76.69428365,75.83015133,74.96601902,74.10188671,73.23775439,72.37362208,71.50948976,71.5059388,71.50238784,71.49883688,71.49528592,71.49173496,71.488184,71.48463303,71.48108207,71.47753111,71.47398015,68.14134378,64.8087074,61.47607103,58.14343465,54.81079828,51.4781619,48.14552553,44.81288915,41.48025278,38.14761641,36.89102343,35.63443045,34.37783747,33.12124449,31.86465151,30.60805853,29.35146555,28.09487257,26.83827959,25.58168661,24.82835112,24.07501563,23.32168014,22.56834466,21.81500917,21.06167368,20.30833819,19.5550027,18.80166722,18.04833173,17.63930437,17.23027702,16.82124967,16.41222231,16.00319496,15.59416761,15.18514025,14.7761129,14.36708555,13.95805819,13.77962578,13.60119337,13.42276096,13.24432855,13.06589614,12.88746373,12.70903132,12.53059891,12.3521665,12.17373409,12.08968251,12.00563092,11.92157934,11.83752775,11.75347617,11.66942458,11.585373,11.50132141,11.41726982,11.33321824,11.2702454,11.20727256,11.14429973,11.08132689,11.01835405,10.95538121,10.89240837,10.82943554,10.7664627,10.70348986,10.64051702,10.57754418,10.51457135,10.45159851,10.38862567,10.32565283,10.26268,10.19970716,10.13673432,10.07376148,10.01078864,9.947815806,9.884842969,9.821870131,9.758897293,9.695924455,9.632951617,9.569978779,9.507005942,9.444033104,9.381060266,9.318087428,9.25511459,9.192141752,9.129168915,9.066196077,9.003223239,8.940250401,8.877277563,8.814304726,8.751331888,8.68835905,8.625386212,8.562413374,8.499440536,8.436467699,8.373494861,8.310522023,8.247549185,8.184576347,8.121603509,8.058630672,7.995657834,7.932684996,7.869712158,7.80673932,7.743766483,7.680793645,7.617820807,7.554847969,7.491875131,7.428902293,7.365929456,7.302956618,7.23998378,7.177010942,7.114038104,7.051065266,6.988092429,6.925119591,6.862146753,6.799173915,6.736201077,6.67322824,6.610255402,6.547282564,6.484309726,6.421336888,6.35836405,6.295391213,6.232418375,6.169445537,6.106472699,6.043499861,5.980527023,5.917554186,5.854581348,5.79160851,5.728635672,5.665662834,5.602689997,5.539717159,5.476744321,5.413771483,5.350798645,5.287825807,5.22485297,5.161880132,5.098907294,5.035934456,4.972961618,4.90998878,4.847015943,4.784043105,4.721070267,4.658097429,4.595124591,4.532151754,4.469178916,4.406206078,4.34323324,4.280260402,4.217287564,4.154314727,4.091341889,4.028369051,3.965396213,3.902423375,3.839450537,3.7764777,3.713504862,3.650532024,3.587559186,3.524586348,3.461613511,3.398640673,3.335667835,3.272694997,3.209722159,3.146749321,3.083776484,3.020803646,2.957830808,2.89485797,2.831885132,2.768912294,2.705939457,2.642966619,2.579993781,2.517020943,2.454048105,2.391075268,2.32810243,2.265129592,2.202156754,2.139183916,2.076211078,2.013238241,1.950265403,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565,1.887292565};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,156.9508471,158.3812442,159.8116413,161.2420384,162.6724355,162.6421968,162.6119582,162.5817196,162.5514809,162.5212423,162.4910036,162.460765,162.4305264,162.4002877,162.3700491,163.0956038,163.8211585,164.5467132,165.272268,165.9978227,166.7233774,167.4489321,168.1744868,168.9000415,169.6255963,165.0789735,160.5323508,155.9857281,151.4391053,146.8924826,142.3458598,137.7992371,133.2526144,128.7059916,124.1593689,121.2136798,118.2679906,115.3223014,112.3766123,109.4309231,106.485234,103.5395448,100.5938557,97.64816654,94.70247739,92.13943112,89.57638485,87.01333859,84.45029232,81.88724605,79.32419978,76.76115351,74.19810725,71.63506098,69.07201471,67.58255602,66.09309732,64.60363862,63.11417992,61.62472123,60.13526253,58.64580383,57.15634514,55.66688644,54.17742774,53.62302461,53.06862149,52.51421836,51.95981523,51.4054121,50.85100898,50.29660585,49.74220272,49.18779959,48.63339647,48.26051951,47.88764255,47.5147656,47.14188864,46.76901168,46.39613473,46.02325777,45.65038082,45.27750386,44.9046269,44.77517791,44.64572891,44.51627991,44.38683091,44.25738191,44.12793291,43.99848392,43.86903492,43.73958592,43.61013692,43.48068792,43.35123893,43.22178993,43.09234093,42.96289193,42.83344293,42.70399394,42.57454494,42.44509594,42.31564694,42.18619794,42.05674894,41.92729995,41.79785095,41.66840195,41.53895295,41.40950395,41.28005496,41.15060596,41.02115696,40.89170796,40.76225896,40.63280997,40.50336097,40.37391197,40.24446297,40.11501397,39.98556497,39.85611598,39.72666698,39.59721798,39.46776898,39.33831998,39.20887099,39.07942199,38.94997299,38.82052399,38.69107499,38.56162599,38.432177,38.302728,38.173279,38.04383,37.914381,37.78493201,37.65548301,37.52603401,37.39658501,37.26713601,37.13768702,37.00823802,36.87878902,36.74934002,36.61989102,36.49044202,36.36099303,36.23154403,36.10209503,35.97264603,35.84319703,35.71374804,35.58429904,35.45485004,35.32540104,35.19595204,35.06650305,34.93705405,34.80760505,34.67815605,34.54870705,34.41925805,34.28980906,34.16036006,34.03091106,33.90146206,33.77201306,33.64256407,33.51311507,33.38366607,33.25421707,33.12476807,32.99531908,32.86587008,32.73642108,32.60697208,32.47752308,32.34807408,32.21862509,32.08917609,31.95972709,31.83027809,31.70082909,31.5713801,31.4419311,31.3124821,31.1830331,31.0535841,30.92413511,30.79468611,30.66523711,30.53578811,30.40633911,30.27689011,30.14744112,30.01799212,29.88854312,29.75909412,29.62964512,29.50019613,29.37074713,29.24129813,29.11184913,28.98240013,28.85295114,28.72350214,28.59405314,28.46460414,28.33515514,28.20570614,28.07625715,27.94680815,27.81735915,27.68791015,27.55846115,27.42901216,27.29956316,27.17011416,27.04066516,26.91121616,26.78176717,26.65231817,26.52286917,26.39342017,26.26397117,26.13452217,26.00507318,25.87562418,25.74617518,25.61672618,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718,25.48727718};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,66.16008017,67.0404572,67.92083423,68.80121127,69.6815883,70.42946495,71.1773416,71.92521824,72.67309489,73.42097154,74.16884819,74.91672483,75.66460148,76.41247813,77.16035477,77.5339096,77.90746443,78.28101926,78.65457409,79.02812892,79.40168375,79.77523858,80.1487934,80.52234823,80.89590306,80.92310566,80.95030826,80.97751086,81.00471346,81.03191607,81.05911867,81.08632127,81.11352387,81.14072647,81.16792907,81.91865415,82.66937923,83.42010431,84.17082939,84.92155447,85.67227955,86.42300462,87.1737297,87.92445478,88.67517986,89.12949597,89.58381208,90.03812819,90.49244429,90.9467604,91.40107651,91.85539262,92.30970873,92.76402483,93.21834094,93.06940868,92.92047641,92.77154415,92.62261188,92.47367962,92.32474736,92.17581509,92.02688283,91.87795056,91.7290183,91.91239774,92.09577717,92.27915661,92.46253605,92.64591549,92.82929493,93.01267436,93.1960538,93.37943324,93.56281268,93.40017003,93.23752738,93.07488473,92.91224208,92.74959943,92.58695678,92.42431413,92.26167148,92.09902883,91.93638618,91.862731,91.78907581,91.71542063,91.64176545,91.56811027,91.49445508,91.4207999,91.34714472,91.27348954,91.19983435,91.12617917,91.05252399,90.97886881,90.90521362,90.83155844,90.75790326,90.68424808,90.61059289,90.53693771,90.46328253,90.38962735,90.31597216,90.24231698,90.1686618,90.09500662,90.02135143,89.94769625,89.87404107,89.80038589,89.7267307,89.65307552,89.57942034,89.50576516,89.43210997,89.35845479,89.28479961,89.21114443,89.13748924,89.06383406,88.99017888,88.9165237,88.84286851,88.76921333,88.69555815,88.62190297,88.54824778,88.4745926,88.40093742,88.32728224,88.25362705,88.17997187,88.10631669,88.03266151,87.95900632,87.88535114,87.81169596,87.73804078,87.66438559,87.59073041,87.51707523,87.44342005,87.36976486,87.29610968,87.2224545,87.14879932,87.07514413,87.00148895,86.92783377,86.85417859,86.7805234,86.70686822,86.63321304,86.55955786,86.48590267,86.41224749,86.33859231,86.26493713,86.19128194,86.11762676,86.04397158,85.9703164,85.89666121,85.82300603,85.74935085,85.67569566,85.60204048,85.5283853,85.45473012,85.38107493,85.30741975,85.23376457,85.16010939,85.0864542,85.01279902,84.93914384,84.86548866,84.79183347,84.71817829,84.64452311,84.57086793,84.49721274,84.42355756,84.34990238,84.2762472,84.20259201,84.12893683,84.05528165,83.98162647,83.90797128,83.8343161,83.76066092,83.68700574,83.61335055,83.53969537,83.46604019,83.39238501,83.31872982,83.24507464,83.17141946,83.09776428,83.02410909,82.95045391,82.87679873,82.80314355,82.72948836,82.65583318,82.582178,82.50852282,82.43486763,82.36121245,82.28755727,82.21390209,82.1402469,82.06659172,81.99293654,81.91928136,81.84562617,81.77197099,81.69831581,81.62466063,81.55100544,81.47735026,81.40369508,81.3300399,81.25638471,81.18272953,81.10907435,81.03541917,80.96176398,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088,80.8881088};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,227.6426909,228.0405626,228.4384342,228.8363058,229.2341774,228.1913852,227.148593,226.1058008,225.0630086,224.0202165,222.9774243,221.9346321,220.8918399,219.8490477,218.8062555,217.8821935,216.9581315,216.0340695,215.1100075,214.1859455,213.2618835,212.3378215,211.4137595,210.4896975,209.5656355,206.4640066,203.3623777,200.2607488,197.1591198,194.0574909,190.955862,187.8542331,184.7526042,181.6509753,178.5493464,176.5609104,174.5724745,172.5840386,170.5956027,168.6071668,166.6187309,164.630295,162.6418591,160.6534231,158.6649872,156.2269268,153.7888663,151.3508059,148.9127454,146.4746849,144.0366245,141.598564,139.1605036,136.7224431,134.2843826,132.3561168,130.4278509,128.499585,126.5713191,124.6430532,122.7147873,120.7865214,118.8582555,116.9299896,115.0017237,114.1759161,113.3501085,112.5243008,111.6984932,110.8726856,110.0468779,109.2210703,108.3952627,107.569455,106.7436474,106.5424534,106.3412595,106.1400655,105.9388716,105.7376776,105.5364836,105.3352897,105.1340957,104.9329017,104.7317078,104.4359833,104.1402589,103.8445345,103.54881,103.2530856,102.9573611,102.6616367,102.3659122,102.0701878,101.7744634,101.4787389,101.1830145,100.88729,100.5915656,100.2958412,100.0001167,99.70439229,99.40866785,99.1129434,98.81721896,98.52149452,98.22577008,97.93004564,97.6343212,97.33859676,97.04287232,96.74714788,96.45142344,96.155699,95.85997456,95.56425012,95.26852568,94.97280124,94.6770768,94.38135236,94.08562792,93.78990348,93.49417904,93.1984546,92.90273016,92.60700572,92.31128128,92.01555684,91.71983239,91.42410795,91.12838351,90.83265907,90.53693463,90.24121019,89.94548575,89.64976131,89.35403687,89.05831243,88.76258799,88.46686355,88.17113911,87.87541467,87.57969023,87.28396579,86.98824135,86.69251691,86.39679247,86.10106803,85.80534359,85.50961915,85.21389471,84.91817027,84.62244583,84.32672138,84.03099694,83.7352725,83.43954806,83.14382362,82.84809918,82.55237474,82.2566503,81.96092586,81.66520142,81.36947698,81.07375254,80.7780281,80.48230366,80.18657922,79.89085478,79.59513034,79.2994059,79.00368146,78.70795702,78.41223258,78.11650814,77.8207837,77.52505926,77.22933482,76.93361037,76.63788593,76.34216149,76.04643705,75.75071261,75.45498817,75.15926373,74.86353929,74.56781485,74.27209041,73.97636597,73.68064153,73.38491709,73.08919265,72.79346821,72.49774377,72.20201933,71.90629489,71.61057045,71.31484601,71.01912157,70.72339713,70.42767269,70.13194825,69.83622381,69.54049936,69.24477492,68.94905048,68.65332604,68.3576016,68.06187716,67.76615272,67.47042828,67.17470384,66.8789794,66.58325496,66.28753052,65.99180608,65.69608164,65.4003572,65.10463276,64.80890832,64.51318388,64.21745944,63.921735,63.62601056,63.33028612,63.03456168,62.73883724,62.4431128,62.14738835,61.85166391,61.55593947,61.26021503,60.96449059,60.66876615,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171,60.37304171};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9459635416667,1851.5940653483074,1873.6891988118489,1886.6609802246094,1898.5905456542969,1909.5405680338542,1919.5606282552083,1929.5707600911458,1940.4107869466145,1952.0108337402344,1964.3208618164062,1977.2809041341145,1990.8409322102864,2004.950927734375,2019.5609944661458,2034.6310017903645,2050.1110636393228,2066.461222330729,2084.0512491861978,2102.801310221354,2122.621378580729,2143.4113972981772,2165.0914713541665,2187.581502278646,2210.821492513021,2234.731730143229,2259.240966796875,2278.769816080729,2288.1194661458335,2288.0489501953125,2279.2485148111978,2262.3481648763022,2237.9577433268228,2206.617390950521,2168.847127278646,2125.1067097981772,2075.8468627929688,2024.4472351074219,1974.0472106933594,1924.6072591145833,1876.0573018391926,1828.3473612467449,1781.4473876953125,1735.3074035644531,1689.867451985677,1645.107442220052,1600.9676513671875,1558.6179097493489,1519.1180521647136,1482.2581583658855,1447.8482564290364,1415.6883748372395,1385.6084696451824,1357.4585367838542,1331.0786437988281,1306.3387145996094,1283.0987955729167,1261.4089050292969,1241.3089701334636,1222.6690470377605,1205.3890991210938,1189.3591715494792,1174.469217936198,1160.6392618815105,1147.7793273925781,1135.819356282552,1124.6794026692708,1114.2294108072917,1104.3494364420574,1094.9994608561199,1086.1394856770833,1077.7095031738281,1069.6995035807292,1062.0695292154949,1054.7695719401042,1047.9096069335938,1041.5296223958333,1035.5896402994792,1030.0796508789062,1024.9296569824219,1020.0996907552084,1015.5696970621744,1011.2897135416666,1007.2397308349609,1003.3997294108073,999.7277323404948,996.2207489013672,992.9727834065756,990.0687866210938,987.4728037516276,985.1488189697266,983.0688323974609,981.204833984375,979.5338439941406,978.0348561604818,976.6888631184896,975.4778747558594,974.3868764241537,973.4038747151693,972.5158843994141,971.7118886311849,970.9818878173828,970.3178914388021,969.7118886311849,969.1568908691406,968.6469014485677,968.1768951416016,967.7399088541666,967.3329010009766,966.9518992106119,966.5919087727865,966.2519073486328,965.9369049072266,965.6459045410156,965.3779093424479,965.128916422526,964.8979034423828,964.6829121907552,964.4809112548828,964.2899068196615,964.1099192301432,963.9379018147787,963.7739003499349,963.6149037679037,963.4619089762369,963.3119099934896,963.1659138997396,963.0219116210938,962.87890625,962.7349192301432,962.5889231363932,962.4389088948568,962.2839101155599,962.1209055582682,961.9489135742188,961.7679087320963,961.5739034016927,961.3669077555338,961.1489105224609,960.9239044189453,960.6958974202474,960.4659067789713,960.2319081624349,959.9928995768229,959.7478993733724,959.4949035644531,959.2348988850912,958.9659067789713,958.6878967285156,958.3989003499349,958.0998992919922,957.7889048258463,957.4658915201823,957.1308949788412,956.7829030354818,956.4219004313151,956.0478922526041,955.6598968505859,955.2578887939453,954.8428955078125,954.4158935546875,953.9768829345703,953.5268910725912,953.066884358724,952.5968882242838,952.1178894042969,951.629892985026,951.1338806152344,950.6288859049479,950.1168874104818,949.5978851318359,949.0708872477213,948.5398864746094,948.0068868001302,947.4768931070963,946.9508819580078,946.4298858642578,945.9138844807943,945.4018961588541,944.8928883870443,944.3878733317057,943.8858947753906,943.3858846028646,942.8878885904948,942.3928782145182,941.8988901774088,941.4068806966146,940.9148864746094,940.4258829752604,939.9368845621744,939.4478861490885,938.9608917236328,938.473876953125,937.9868825276693,937.5008850097656,937.0138804117838,936.5278879801432,936.0418802897135,935.5548909505209,935.0688883463541,934.5818939208984,934.0938720703125,933.6058909098307,933.1178792317709,932.6288909912109,932.1388854980469,931.6488800048828,931.1568857828776,930.6648813883463,930.1718800862631,929.6768900553385,929.1818796793619,928.6848805745443,928.1868896484375,927.6878763834635,927.1868896484375,926.6848805745443,926.1808776855469,925.6758778889974,925.1678822835287,924.6588897705078,924.1478830973307,923.6338806152344,923.1188761393229,922.6008758544922,922.0808766682943,921.5578867594401,921.0318806966146,920.5038808186849,919.9748789469401,919.4458872477213,918.9168853759766,918.3898874918619,917.8648834228516,917.3458760579427,916.8318786621094,916.3228759765625,915.8418884277344,915.4098917643229,915.0228983561198,914.6758982340494,914.3638966878256,914.0848999023438,913.8348999023438,913.6109059651693,913.409901936849,913.2309010823568,913.0699005126953,912.9269053141276,912.7979024251302,912.6829071044922,912.5809071858724,912.4889017740885,912.4079182942709,912.3349100748698,912.2699127197266,912.211903889974,912.159901936849,912.1139170328776,912.0729166666666,912.0369110107422,912.0049031575521,911.9759165445963,911.9499155680338,911.9279123942057,911.9079182942709,911.8899230957031,911.8739064534506,911.8599090576172,911.8469085693359,911.8359171549479,911.8259124755859,911.8169148763021,911.8089192708334,911.8009084065756,911.794911702474,911.7879079182943,911.7829030354818,911.7769165039062,911.7729187011719,911.7679036458334,911.7629089355469,911.7589060465494,911.7549082438151,911.7499135335287,911.7459004720052,911.7409159342448,911.7369079589844,911.7319132486979,911.7269134521484,911.7219085693359,911.7169189453125,911.711903889974,911.7059173583984,911.6999053955078,911.6929066975912,911.6869049072266,911.679921468099,911.6719156901041,911.6639099121094,911.6559143066406,911.6469167073568,911.6379140218099,911.6279144287109,911.6169128417969,911.6059163411459,911.5949045817057,911.5829162597656,911.5699106852213,911.5569152832031,911.5429077148438,911.5279134114584,911.5119171142578,911.4959055582682,911.4789174397787,911.4609120686849,911.4429117838541,911.4229075113932,911.4029134114584,911.3809051513672,911.3589121500651,911.3359120686849,911.3109029134115,911.2849070231119,911.2589009602865,911.2308959960938,911.201904296875,911.1709136962891,911.1389109293619,911.1059112548828,911.0709025065104,911.034912109375,910.9969075520834,910.9579060872396,910.9179128011068,910.87890625,910.8399098714193,910.8029022216797,910.7659098307291,910.7279052734375,910.6919148763021,910.6579132080078,910.6279093424479,910.6009012858073,910.5769195556641,910.5569152832031,910.5388997395834,910.5239054361979,910.5099080403646,910.4989064534506,910.4889068603516,910.4809061686198,910.4739125569662,910.4679158528646,910.4639078776041,910.4599049886068,910.4569091796875,910.4559173583984,910.4539133707682,910.4539082845052,910.4529113769531,910.4539184570312,910.4549153645834,910.4559224446615,910.4569040934244,910.4589131673177,910.4609120686849,910.4629160563151,910.4659220377604,910.4689076741537,910.4709014892578,910.4739074707031,910.4769134521484,910.4799092610677,910.4839121500651,910.4869079589844,910.4899241129557,910.4939015706381,910.4969024658203,910.4999033610026,910.5039113362631,910.5069071451823,910.5109202067057,910.513916015625,910.5179138183594,910.5209096272787,910.524912516276,910.5279134114584,910.5309092203776,910.5349070231119,910.5379130045573,910.5409138997396,910.544911702474,910.5479075113932,910.5509134928385,910.5539143880209,910.5579071044922,910.5609130859375,910.5639088948568,910.566904703776,910.5699106852213,910.5729064941406,910.5749053955078,910.5779113769531,910.5809020996094,910.5839080810547,910.5869191487631,910.5889180501302,910.5919138590494,910.5939076741537,910.5969187418619,910.5989074707031,910.6019185384115,910.6039072672526,910.6059163411459,910.6089121500651,910.6109059651693,910.6129150390625,910.6149139404297,910.6169179280599,910.6189117431641,910.6209106445312,910.6229146321615,910.6249135335287,910.6259155273438,910.6279144287109,910.6299184163412,910.6309102376302,910.6329091389974,910.6339111328125,910.6359100341797,910.6369120279948,910.6379089355469,910.6399078369141,910.6409200032552,910.6419118245443,910.6429138183594,910.6439107259115,910.6449178059896,910.6449025472006,910.6459147135416,910.6469065348307,910.6479085286459,910.6479085286459,910.6489054361979,910.6489105224609,910.6489105224609,910.6489105224609,910.64990234375,910.649912516276,910.649912516276,910.6499074300131,910.6489105224609,910.648915608724,910.648915608724,910.6479085286459,910.6479187011719,910.6469217936198,910.6468963623047,910.6459096272787,910.6449178059896,910.6438954671224,910.6429138183594,910.6419118245443,910.6399078369141,910.638905843099,910.6369120279948,910.6359151204427,910.6339111328125,910.6319020589193,910.6299133300781,910.6279093424479,910.6259206136068,910.6229197184244,910.6209106445312,910.6179046630859,910.6149190266927,910.6129150390625,910.6099090576172,910.6059112548828,910.6029154459635,910.5989074707031,910.5959065755209,910.5919087727865,910.5879109700521,910.5859069824219};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.94872283935547,403.11696370442706,405.7999547322591,408.78296152750653,411.8409601847331,414.9819564819336,418.20496368408203,421.5299580891927,424.9689585367839,428.5199508666992,432.18195088704425,435.9539489746094,439.83495076497394,443.8239517211914,447.92395273844403,452.13194783528644,456.45194753011066,460.8939488728841,465.4699452718099,470.1789372762044,475.0209426879883,479.9949366251628,485.1019337972005,490.3439356486003,495.71993255615234,501.2329330444336,506.8829345703125,512.4729334513346,517.8179423014323,522.9369405110677,527.8389434814453,532.5319366455078,537.022939046224,541.3159383138021,545.4139455159506,549.3189544677734,553.0349527994791,556.4659576416016,559.5239562988281,562.2169596354166,564.5509694417318,566.5299682617188,568.1599731445312,569.4429880777994,570.3839874267578,570.9859873453776,571.2519887288412,571.2559865315756,571.0649973551432,570.6769968668619,570.0880025227865,569.2990061442057,568.3090057373047,567.1170043945312,565.7240142822266,564.1300099690756,562.3370107014974,560.4280039469401,558.4830067952474,556.4950052897135,554.4620107014974,552.3800201416016,550.2470092773438,548.0620066324869,545.8230133056641,543.5280202229818,541.1780141194662,538.8040059407552,536.4390106201172,534.0780181884766,531.7190246582031,529.3610076904297,527.0030110677084,524.6420135498047,522.2770182291666,519.9070180257162,517.5310211181641,515.1600189208984,512.8050181070963,510.4640197753906,508.13501993815106,505.8180185953776,503.5110168457031,501.2140197753906,498.9250208536784,496.6440200805664,494.3700180053711,492.1150182088216,489.89001719156903,487.6930236816406,485.5240173339844,483.3800226847331,481.26201883951825,479.1690216064453,477.09901936848956,475.05201721191406,473.02702077229816,471.0240173339844,469.041020711263,467.0790150960286,465.1360168457031,463.2120183308919,461.30702209472656,459.4200210571289,457.5500183105469,455.697021484375,453.8610204060872,452.041015625,450.2360153198242,448.44701894124347,446.6720199584961,444.91202036539715,443.1670227050781,441.437016805013,439.7210210164388,438.0190175374349,436.3310190836589,434.65702056884766,432.9960225423177,431.3480173746745,429.7130177815755,428.09002176920575,426.4800211588542,424.88201904296875,423.2950210571289,421.7210210164388,420.15701548258465,418.6460138956706,417.2220204671224,415.88001505533856,414.6190185546875,413.4330062866211,412.3210169474284,411.28101348876953,410.3090133666992,409.40401458740234,408.5630111694336,407.7850087483724,407.0670166015625,406.4080123901367,405.8080088297526,405.2640101114909,404.77701059977215,404.34600830078125,403.96800994873047,403.64500681559247,403.37400817871094,403.15500895182294,402.98800404866535,402.8710072835286,402.8050053914388,402.78800201416016,402.8200047810872,402.9010009765625,403.0300038655599,403.2070007324219,403.4310022989909,403.66200002034503,403.8630015055339,404.03900146484375,404.1919987996419,404.3249969482422,404.43999735514325,404.5399983723958,404.62499745686847,404.69800059000653,404.75900014241535,404.80899810791016,404.8500010172526,404.88200124104816,404.90599822998047,404.9220021565755,404.9320017496745,404.9350001017253,404.93299865722656,404.9260025024414,404.91600290934247,404.9010009765625,404.8829981486003,404.8610026041667,404.8360010782878,404.8090006510417,404.7789993286133,404.7469991048177,404.7120005289714,404.6759999593099,404.63700103759766,404.5970001220703,404.5550003051758,404.5119984944661,404.4670003255208,404.4209950764974,404.37400309244794,404.3260014851888,404.2760009765625,404.2260004679362,404.1749954223633,404.1230010986328,404.07000223795575,404.01600392659503,403.96199798583984,403.90700276692706,403.85099538167316,403.7949981689453,403.73900349934894,403.6809997558594,403.6239980061849,403.5649998982747,403.50700124104816,403.447998046875,403.38899993896484,403.3290023803711,403.26899973551434,403.20800018310547,403.1470006306966,403.0860010782878,403.02500406901044,402.96299743652344,402.9010009765625,402.83799235026044,402.7749989827474,402.71199798583984,402.6489995320638,402.5850016276042,402.52100372314453,402.45599873860675,402.39200083414715,402.3270009358724,402.26099650065106,402.19500223795575,402.1290003458659,402.06300354003906,401.99600474039715,401.92899831136066,401.8620071411133,401.7950032552083,401.72900136311847,401.66200256347656,401.59600321451825,401.52899678548175,401.46299997965497,401.39599609375,401.3289972941081,401.26099904378253,401.1940002441406,401.12699635823566,401.05899810791016,400.9909973144531,400.9230016072591,400.85500081380206,400.7879994710286,400.7200012207031,400.65199788411456,400.58399709065753,400.51600138346356,400.447998046875,400.3799997965495,400.31199645996094,400.2450002034505,400.17699940999347,400.1100031534831,400.041997273763,399.9750010172526,399.90799713134766,399.84099833170575,399.7730000813802,399.7070032755534,399.64000193277997,399.573003133138,399.50600179036456,399.4399998982747,399.3740056355794,399.3070017496745,399.2410024007161,399.1750030517578,399.10999806722003,399.04400126139325,398.9779917399089,398.9129994710286,398.8469975789388,398.78199768066406,398.71700286865234,398.65199788411456,398.5870005289714,398.5229975382487,398.458002726237,398.39399973551434,398.3290049235026,398.2649968465169,398.2009989420573,398.13699595133465,398.07299550374347,398.00900014241535,397.94600168863934,397.8819986979167,397.81900278727215,397.7550048828125,397.69200388590497,397.6290003458659,397.56600189208984,397.5030008951823,397.4399998982747,397.3779983520508,397.3149998982747,397.2529983520508,397.18999735514325,397.1279983520508,397.06599680582684,397.00399525960285,396.94199625651044,396.8799997965495,396.81800333658856,396.75600179036456,396.6939977010091,396.63300069173175,396.57100168863934,396.51000213623047,396.44800059000653,396.38700103759766,396.3249994913737,396.26399993896484,396.20300038655597,396.14099884033203,396.07999928792316,396.0189971923828,395.95800018310547,395.8969980875651,395.83599853515625,395.7739969889323,395.71299997965497,395.65199788411456,395.5909957885742,395.5299987792969,395.468999226888,395.40699768066406,395.3460006713867,395.2849985758464,395.2229995727539,395.16200256347656,395.1000010172526,395.03900146484375,394.9779968261719,394.91600036621094,394.85500081380206,394.79500071207684,394.73399861653644,394.6739959716797,394.61299896240234,394.5530014038086,394.4930013020833,394.43399810791016,394.3739954630534,394.3149998982747,394.25600179036456,394.1959991455078,394.1379979451497,394.0790023803711,394.0199966430664,393.96200307210285,393.9029998779297,393.8449986775716,393.78700002034503,393.72900136311847,393.67100016276044,393.6139958699544,393.5559997558594,393.4989980061849,393.44200134277344,393.38499959309894,393.32800038655597,393.27099863688153,393.21399943033856,393.1580047607422,393.1010004679362,393.0450032552083,392.98900095621747,392.9330012003581,392.87699635823566,392.82100677490234,392.76500193277997,392.71000417073566,392.6540044148763,392.59899648030597,392.5439961751302,392.48900349934894,392.4340006510417,392.3790028889974,392.3239974975586,392.26899973551434,392.2150014241536,392.1599985758464,392.10600026448566,392.052001953125,391.9979985555013,391.9439977010091,391.88999938964844,391.8360010782878,391.78299713134766,391.72899627685547,391.6759999593099,391.62300364176434,391.56900278727215,391.51600138346356,391.46300252278644,391.40999603271484,391.3579966227214,391.3050003051758,391.2519989013672,391.2000020345052,391.1469980875651,391.0950012207031,391.04300181070965,390.99099985758465,390.9389953613281,390.8870035807292,390.8350016276042,390.7839991251628,390.7320022583008,390.68099721272785,390.6290028889974,390.5779978434245,390.5269953409831,390.4760004679362,390.4250005086263,390.37400309244794,390.322998046875,390.27200571695965,390.2209981282552,390.17100016276044,390.1209996541341,390.0699946085612,390.0199966430664,389.9700012207031,389.92000071207684,389.8700002034505,389.8199971516927,389.76999918619794,389.72000376383465,389.6709976196289,389.6209996541341,389.5720036824544,389.5219980875651,389.47300211588544,389.4239985148112,389.37500254313153,389.3259963989258,389.27699788411456,389.2280019124349,389.1790008544922,389.13100179036456,389.08199818929035,389.03299713134766,388.98500061035156,388.93700408935547,388.88800048828125,388.8399963378906,388.79199981689453,388.7440007527669,388.6959991455078,388.6479975382487,388.6010030110677,388.5529963175456,388.50499725341797,388.45800018310547,388.40999603271484,388.3630015055339,388.31600189208984,388.26800028483075,388.2210006713867,388.1740010579427,388.12699635823566,388.07999420166016,388.0339991251628,387.98700459798175,387.9399998982747,387.89399973551434,387.84700266520184,387.8009974161784,387.7539978027344,387.70800018310547,387.66200002034503,387.61500295003253,387.5689977010091,387.5230000813802,387.4769999186198,387.4539972941081};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.753957668940227,21.18809413909912,23.582992712656658,28.04559103647868,33.292689641316734,39.29698880513509,46.03138796488444,53.39228661855062,61.27998574574789,69.67638524373372,78.56398391723633,87.92568270365398,97.74518140157063,108.00697962443034,118.69397799173991,129.79397837320963,141.28997675577799,152.99097951253256,164.70797856648764,176.44097646077475,188.18897501627603,199.95197550455728,211.72997283935547,223.5199737548828,235.3239720662435,247.13897196451822,258.96597417195636,270.2729771931966,280.54597727457684,289.8099772135417,298.08997853597003,305.40897878011066,311.78897857666016,317.25398508707684,321.82298278808594,325.51697794596356,328.3569819132487,330.08298746744794,330.4509862263997,329.50898996988934,327.2999903361003,323.86999766031903,319.2619908650716,313.5179926554362,306.6800003051758,298.78599802652997,289.87699635823566,280.61899820963544,271.65599568684894,262.9860026041667,254.60499954223633,246.50799814860025,238.68999735514322,231.14599990844727,223.87200037638345,216.85999806722006,210.10599772135416,203.59499740600586,197.31499735514322,191.25999959309897,185.42599868774414,179.80799992879233,174.40099970499674,169.19799931844076,164.19600041707358,159.38699849446616,154.76699829101562,150.31999969482422,146.03299967447916,141.900998433431,137.91899744669595,134.0819994608561,130.3859952290853,126.82699775695801,123.39999707539876,120.10599899291992,116.94499842325847,113.90899848937988,110.99199930826823,108.18699773152669,105.4919974009196,102.90199788411458,100.4119987487793,98.01869773864746,95.71829668680827,93.50729688008626,91.38199806213379,89.33379809061687,87.35459836324056,85.44169743855794,83.59249750773112,81.80459912618001,80.07559712727864,78.40329869588216,76.78549702962239,75.22009913126628,73.70509783426921,72.23849805196126,70.81869888305664,69.44359842936198,68.11169815063477,66.82129859924316,65.57069905598958,64.35859807332356,63.183397928873696,62.04369831085205,60.938198725382485,59.86559899648031,58.82449817657471,57.81389904022217,56.83259836832682,55.879398345947266,54.95339870452881,54.053297996520996,53.178399403889976,52.327598571777344,51.499999046325684,50.69469896952311,49.91089916229248,49.14779885609945,48.404598236083984,47.68049875895182,46.97489865620931,46.286898612976074,45.61609808603922,44.961599032084145,44.322898864746094,43.699399630228676,43.090599060058594,42.49569924672445,41.91439882914225,41.345998446146645,40.79009819030762,40.245999018351235,39.71349906921387,39.19199879964193,38.680999437967934,38.18019803365072,37.68909899393717,37.20739905039469,36.73459815979004,36.27039941151937,35.814498583475746,35.366498947143555,34.926198641459145,34.493099212646484,34.06709893544515,33.64779885609945,33.23489920298258,32.82819779713949,32.42749945322672,32.032499154408775,31.64289919535319,31.258599122365315,30.879398981730144,30.50489886601766,30.13509925206502,29.76979907353719,29.408799171447754,29.051799138387043,28.69879913330078,28.349699179331463,28.004199345906574,27.66219886144002,27.323699315388996,26.988499482472736,26.656499067942303,26.327499230702717,26.00149933497111,25.678398927052815,25.357999483744305,25.04029893875122,24.725099245707195,24.412399291992188,24.102099418640137,23.79409948984782,23.488199551900227,23.184499740600586,22.882899443308514,22.583299318949383,22.28549925486247,21.989599386850994,21.695499420166016,21.40299924214681,21.112199465433758,20.822999477386475,20.535399436950684,20.249199390411377,19.964399496714275,19.680999596913654,19.39889939626058,19.117999871571858,18.838399410247803,18.559999624888103,18.282599767049152,18.006399313608807,17.731199582417805,17.457099437713623,17.18389956156413,16.91159963607788,16.640199820200603,16.369699478149414,16.09999942779541,15.831099589665731,15.562999725341797,15.29569959640503,15.02899972597758,14.762999614079794,14.497699737548828,14.232999722162882,13.968899726867676,13.705399751663208,13.442499796549479,13.180099646250406,12.91819961865743,12.656799793243408,12.395899772644043,12.13539981842041,11.875399669011435,11.615799824396769,11.356599966684977,11.097699880599976,10.83929975827535,10.581199884414673,10.323399941126505,10.065999825795492,9.80886975924174,9.55204995473226,9.295509974161783,9.039230028788248,8.783219814300537,8.52744992574056,8.271919965744019,8.016619880994162,7.761529962221782,7.506649971008301,7.251950025558472,7.001760045687358,6.760199983914693,6.526990016301473,6.301830013593038,6.084440032641093,5.87456997235616,5.671939969062805,5.4763100147247314,5.2874399820963545,5.105090022087097,4.929030021031697,4.759060064951579,4.594950000445048,4.436510006586711,4.2835400104522705,4.135849992434184,3.993250012397766,3.8555800318717957,3.722670018672943,3.5943400065104165,3.470429996649424,3.3508099913597107,3.235309978326162,3.123799959818522,3.0161399841308594,2.9121899803479514,2.81182998418808,2.714930017789205,2.621370017528534,2.531049986680349,2.4438299934069314,2.359630028406779,2.2783300280570984,2.199839989344279,2.1240500013033548,2.050879975159963,1.9802299837271373,1.9120099941889446,1.846150000890096,1.7825599908828735,1.7211699883143108,1.6618800262610118,1.6046500007311504,1.54939000805219,1.4960299928983052,1.4445099929968517,1.3947700063387554,1.3467399974664052,1.3003699878851573,1.2555900116761525,1.212359994649887,1.1706200142701466,1.1303199927012126,1.0914100011189778,1.0538400014241536,1.0175599853197734,0.98253300289313,0.9487120111783346,0.9160579989353815,0.8845279961824417,0.8540839950243632,0.8246899992227554,0.7963079959154129,0.76890400548776,0.7424440036217371,0.7168949991464615,0.6922259976466497,0.6684070030848185,0.6454089979330698,0.623201996088028,0.6017610083023707,0.5810570021470388,0.5610670000314713,0.5417650043964386,0.5231280078490576,0.5051320021351179,0.48775699983040494,0.4709790050983429,0.4547790015737216,0.4391369968652725,0.4240329985817273,0.409450002014637,0.3953680023550987,0.3817710032065709,0.36864199737707776,0.3559650008877118,0.3437250033020973,0.3319049999117851,0.3204930027325948,0.3094730004668236,0.2988329976797104,0.2885580013195674,0.27863799780607224,0.2690580040216446,0.2598089973131816,0.2508770003914833,0.24225300177931786,0.23392599945267042,0.22588500132163367,0.2181209996342659,0.21062399819493294,0.20338499918580055,0.1963949998219808,0.18964499731858572,0.18312700216968855,0.1768339996536573,0.17075700064500174,0.1648900012175242,0.15922400106986365,0.15375199913978577,0.14846899981300035,0.14336800078550974,0.13844200099507967,0.1336859998603662,0.12909299756089845,0.12465800034503143,0.12037499931951363,0.11624000035226345,0.11224700013796489,0.10839100119968255,0.10466799947122733,0.10107299995919068,0.09760129948457082,0.09424910073479016,0.09101199917495251,0.0878863005588452,0.08486789961655934,0.08195340012510617,0.07913899980485439,0.07642129994928837,0.07379700057208538,0.07126290040711562,0.06881589939196904,0.06645300053060055,0.06417129933834076,0.06196809963633617,0.05984049973388513,0.057785999650756516,0.05580210002760092,0.05388639991482099,0.05203649960458279,0.05025009997189045,0.04852519960453113,0.046859499998390675,0.04525099974125624,0.043697700214882694,0.042197899582485356,0.04074949957430363,0.039350900488595165,0.03800039986769358,0.03669619963814815,0.03543680006017288,0.03422070015221834,0.03304629990210136,0.03191230011483034,0.03081719980885585,0.029759699789186318,0.028738599891463917,0.027752500027418137,0.026800199877470732,0.02588070013249914,0.024992700200527906,0.0241353001135091,0.02330719990034898,0.022507599865396816,0.02173550007864833,0.02098980002726118,0.020269799667100113,0.019574500154703856,0.018902999969820183,0.01825459999963641,0.01762850008284052,0.017023800096164148,0.016439899957428377,0.01587610024337967,0.015331599938993653,0.014805699931457639,0.014297999907284975,0.01380759997603794,0.013334099979450306,0.012876899912953377,0.01243530004285276,0.012008899978051582,0.011597099946811795,0.011199400139351686,0.01081540008696417,0.010444600057477752,0.010086500008280078,0.009740639943629503,0.009406680008396506,0.009084179997444153,0.008772750074664751,0.008472000015899539,0.008181560008476177,0.007901089964434505,0.007630249989839892,0.0073686900626247125,0.007116100052371621,0.006872179956796269,0.006636629967639844,0.006409149966202676,0.006189480035876234,0.005977339964980881,0.005772480042651296,0.005574640003032982,0.005383589964670439,0.005199089995585382,0.0050209199932093425,0.004848860048999389,0.004682700033299625,0.004522229932869474,0.004367269963646929,0.00421761996888866,0.004073110021029909,0.003933549975045025,0.0037987699809794626,0.00366861002597337,0.0035429199730666974,0.003421540022827685,0.003304319999491175,0.0031911099795252085,0.0030817899969406426,0.002976219965300212,0.0028742599921921888,0.0027757999875272312,0.00268070997359852,0.002588890007852266,0.002500209976763775,0.0024145699959869185,0.0023318600142374635,0.0022519999959816537,0.0021748600023177764,0.00210038002114743,0.0020284400088712573,0.0019589699901795634,0.00189187999543113,0.001827089989092201,0.0017645199938366811,0.001704089993533368,0.0016457399857851367,0.0015893799912494917,0.0015349600095457088,0.0014823999857374777,0.0014316400047391653,0.0013826199865434319,0.001335280006363367,0.0012895600132954617,0.0012454099875564377,0.0012237199989613146};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76680437723796,90.27675247192383,96.32146898905437,101.78744506835938,107.53894869486491,113.54829216003418,119.79457982381184,126.05045000712077,132.11316045125326,137.99692916870117,143.71370569864908,149.27650451660156,154.69731267293295,159.9851417541504,165.14996973673502,170.20083618164062,175.14567438761392,179.8723055521647,184.27685419718424,188.3834660847982,192.2150993347168,195.79477055867514,199.1404546101888,202.27117665608725,205.20289738972983,207.94968287150064,210.5254135131836,212.63760375976562,213.99952697753906,214.64659118652344,214.6096674601237,213.91979598999023,212.6069564819336,210.70116806030273,208.2294019063314,205.21969604492188,201.69799041748047,197.51299413045248,192.53289286295572,186.82093938191733,180.43504079182944,173.43122355143228,165.85947291056314,157.7677853902181,149.20216496785483,140.20257059733072,130.80909856160483,121.57363382975261,113.00967597961426,105.07545153299968,97.73056538899739,90.93778800964355,84.66097831726074,78.8657169342041,73.51921526590984,68.59046999613444,64.05058670043945,59.86815865834554,56.014695167541504,52.46750291188558,49.20518143971761,46.20753256479899,43.45545895894369,40.93126106262207,38.61804167429606,36.50030040740967,34.563340187072754,32.78855164845785,31.15894317626953,29.663522084554035,28.29228623708089,27.03583876291911,25.88547960917155,24.833109378814697,23.871129194895428,22.994744459788006,22.199151515960693,21.4758456548055,20.81713056564331,20.21760892868042,19.672380924224854,19.17704709370931,18.72750775019328,18.320063591003418,17.95121431350708,17.617761611938477,17.316904226938885,17.039931138356526,16.778651396433514,16.53177038828532,16.298288345336914,16.077004273732502,15.86691927909851,15.66713261604309,15.476745049158732,15.295056660970053,15.12136729558309,14.9549769560496,14.795285622278849,14.641693830490112,14.49380119641622,14.351108312606812,14.213214556376139,14.079620281855265,13.95002563794454,13.824130535125732,13.701634963353476,13.582139015197754,13.465542872746786,13.351546128590902,13.23984924952189,13.13035217920939,13.022854804992676,12.917157093683878,12.813159545262655,12.710661252339682,12.609463214874268,12.509664932886759,12.410866101582846,12.313267946243286,12.216568867365519,12.120670239130655,12.025671243667603,11.93127179145813,11.837573130925497,11.744473695755005,11.651874462763468,11.559775034586588,11.468075593312582,11.376776138941446,11.285776456197103,11.194976727167765,11.104477246602377,11.014077266057333,10.923877477645874,10.833677450815836,10.743677854537964,10.65357748667399,10.5635777314504,10.473477522532145,10.383377631505331,10.293177286783854,10.202877203623453,10.11247722307841,10.021977027257284,9.931346734364828,9.840566714604696,9.749626239140829,9.658526102701822,9.567255894343058,9.475805600484213,9.384165445963541,9.292335112889608,9.200314919153849,9.108094612757364,9.015674432118734,8.923044125239054,8.83022371927897,8.73719342549642,8.643973191579184,8.550573031107584,8.457002798716227,8.363272587458292,8.269402265548706,8.175372123718262,8.08122213681539,7.986941695213318,7.892541686693828,7.7980415026346845,7.703441341718038,7.608731230099996,7.513941168785095,7.419060985247294,7.324110984802246,7.229070822397868,7.1339707771937055,7.038800676663716,6.943560560544332,6.848260402679443,6.752900401751201,6.657480239868164,6.562010208765666,6.466480135917664,6.370910127957662,6.275279998779297,6.179609934488933,6.083889921506246,5.988119840621948,5.892309745152791,5.7964597543080645,5.7005696296691895,5.604639569918315,5.508669535319011,5.4126594463984175,5.3166093826293945,5.2205192645390825,5.124399344126384,5.0282392501831055,4.932039181391398,4.835809230804443,4.73953910668691,4.643229087193807,4.546888987223308,4.45051896572113,4.354118903477986,4.257678906122844,4.161208828290303,4.064708809057872,3.9681687553723655,3.871588706970215,3.77498867114385,3.6783486008644104,3.581678549448649,3.4849785566329956,3.388238469759623,3.2914684216181436,3.194668412208557,3.097848335901896,3.0009882847468057,2.904088258743286,2.807168205579122,2.7102081576983132,2.61322812239329,2.516208072503408,2.419148027896881,2.32206799586614,2.2249579628308616,2.127807935078939,2.0306278467178345,1.933417836825053,1.8361877898375194,1.738917738199234,1.6416176855564117,1.5442876120408375,1.4469276865323384,1.3495373825232189,1.2521077891190846,1.1583248774210613,1.0715751747290294,0.9913234263658524,0.9170845647652944,0.8484078794717789,0.7848777323961258,0.7261070311069489,0.6717388778924942,0.6214432766040167,0.5749162783225378,0.5318749050299326,0.4920571794112523,0.45522113144397736,0.4211447983980179,0.38962118575970334,0.360457311073939,0.3334782098730405,0.308519887427489,0.28542937089999515,0.2640686606367429,0.24430778622627258,0.22602574775616327,0.20911256223917007,0.19346524154146513,0.17898979658881822,0.16559823602437973,0.15320856496691704,0.1417467954258124,0.13114293292164803,0.12133198541899522,0.11225596070289612,0.10385885834693909,0.09609069675207138,0.08890356495976448,0.08225428002576034,0.0761025386552016,0.07041105007131894,0.06514551521589358,0.06027383729815483,0.05576672125607729,0.05159676757951578,0.04773878181974093,0.044169364807506405,0.04086691855142514,0.037811546586453915,0.034984750362734,0.03236932990451654,0.029949590253333252,0.027710730209946632,0.025639351457357407,0.0237228578577439,0.02194974757730961,0.020309123521049816,0.018791285964349907,0.01738683708632986,0.016087476008882124,0.014885205232227841,0.013772924275447926,0.012743734754621983,0.011791436544929942,0.010910331271588802,0.010095218662172556,0.009340909387295445,0.008643014201273521,0.007997293335696062,0.007399837331225474,0.006847026602675517,0.006335531439011295,0.005862272111698985,0.005424369087753196,0.0050192024403562146,0.004644302612481018,0.004297419839228193,0.0039764542210226255,0.0036794759798794985,0.003404675478426119,0.003150412677011142,0.002915147905393193,0.002697461226489395,0.0024960327427834272,0.002309652743861079,0.002137201197911054,0.0019776283006649464,0.0018299741107815255,0.001693338737823069,0.001566922301814581,0.001449944810398544,0.0013416964017475645,0.0012415371020324528,0.0011488570501872648,0.0010631062420240294,0.0009837497200351208,0.0009103215949532265,0.0008423768643600246,0.000779504596721381,0.0007213278246733049,0.0006674935866612941,0.000617679911859644,0.0005715838439452151,0.0005289304147784909,0.0004894606366481943,0.0004529375461667466,0.00041914016037480906,0.000387866510815608,0.00035892660525860265,0.0003321474772140694,0.0003073661234035778,0.00028443558160991717,0.0002632158502819948,0.0002435789477506963,0.000225408894038992,0.0002085936903313268,0.00019303435935095573,0.0001786358977066508,0.00016531132011247487,0.0001529806419663752,0.0001415708647982683,0.0001310119902579269,0.00012124103704991285,0.00011219900322127312,0.00010383189934752106,9.608872642274946e-05,8.892319359195729e-05,8.229220293287653e-05,7.615585915724903e-05,7.047736714109003e-05,6.522232797578909e-05,6.035924828514302e-05,5.58589293480812e-05,5.16942742857888e-05,4.784028715221211e-05,4.4273668208916206e-05,4.097302068354717e-05,3.7918647649348713e-05,3.509194933333978e-05,3.247602974928062e-05,3.0055188138552087e-05,2.7814927761937724e-05,2.5741649399909267e-05,2.3822954669109702e-05,2.2047344373277156e-05,2.040411997465223e-05,1.8883482728900464e-05,1.747613274953134e-05,1.6173671762468682e-05,1.4968400970853205e-05,1.3852919967879037e-05,1.2820630521067264e-05,1.1865232409036253e-05,1.0981127161358017e-05,1.0162914425867106e-05,9.405635258493325e-06,8.704830330922656e-06,8.056259503064211e-06,7.456023619549039e-06,6.900533018476078e-06,6.386437917171861e-06,5.910648800030079e-06,5.470325845635671e-06,5.062809350420139e-06,4.685669599287697e-06,4.3366269058727385e-06,4.013591440828653e-06,3.714633370085115e-06,3.4379429318202406e-06,3.1818702458015955e-06,2.944885541940797e-06,2.7255490143337133e-06,2.522560710834417e-06,2.334690748284629e-06,2.1608093258388785e-06,1.99989648308474e-06,1.8509623960956862e-06,1.7131271192738495e-06,1.5855507532099484e-06,1.4674833532050495e-06,1.3582150396966124e-06,1.257075808780428e-06,1.1634758247206871e-06,1.0768450711869566e-06,9.966726205827097e-07,9.224675447209544e-07,8.537878718091937e-07,7.902236660584094e-07,7.313939486645419e-07,6.769447603952964e-07,6.265501374021672e-07,5.799081227072141e-07,5.367397240737167e-07,4.967859936755303e-07,4.5980693622974894e-07,4.2558058765962414e-07,3.9390397669573457e-07,3.6458509811154727e-07,3.3744899970618764e-07,3.123336801043782e-07,2.89088158448673e-07,2.675724554516516e-07,2.476595805471031e-07,2.292285472549338e-07,2.121693671123618e-07,1.96380049999334e-07,1.8176661242819137e-07,1.6824105723382368e-07,1.557223908340196e-07,1.4413462542014108e-07,1.3340977152627906e-07,1.2348383056822362e-07,1.1429580955753711e-07,1.0579171672020493e-07,2.488267014655321e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.742682456970215,19.401511828104656,20.785216808319092,23.29181973139445,26.184622446695965,29.45532496770223,33.09562683105469,37.07562859853109,41.366231282552086,45.96103318532308,50.853535970052086,56.03753821055094,61.50704002380371,67.2559420267741,73.27834574381511,79.56844584147136,86.12064870198567,92.86024983723958,99.7140515645345,106.68005307515462,113.75505383809407,120.93705558776855,128.2250576019287,135.6140594482422,143.10505803426108,150.69306055704752,158.3780606587728,165.85805638631186,172.83805465698242,179.32505416870117,185.32604853312174,190.84804916381836,195.8970489501953,200.48004150390625,204.60204569498697,208.2710418701172,211.49103800455728,214.1080322265625,215.97402826944986,217.1030248006185,217.51102193196616,217.21401977539062,216.2250124613444,214.55901082356772,212.2320073445638,209.25800069173178,205.65000279744467,201.7660001118978,197.95700327555338,194.2230021158854,190.56600062052408,186.98400243123373,183.4800033569336,180.05200322469076,176.70100275675455,173.42700576782227,170.22900263468424,167.1030019124349,164.04600397745767,161.057004292806,158.13600158691406,155.2820027669271,152.49700419108072,149.77800369262695,147.12600072224936,144.53900273640951,142.01800282796225,139.55500284830728,137.14600245157877,134.78800328572592,132.48200352986655,130.22600301106772,128.02100245157877,125.86500422159831,123.75700251261394,121.69900512695312,119.69400405883789,117.73900413513184,115.83100573221843,113.96900367736816,112.15200424194336,110.3780034383138,108.64800262451172,106.95900472005208,105.31100463867188,103.70200475056966,102.13200441996257,100.59700393676758,99.09290504455566,97.61880302429199,96.17410532633464,94.75810368855794,93.37020428975423,92.00950304667155,90.67560450236003,89.36770439147949,88.08520380655925,86.82760302225749,85.59410285949707,84.38430404663086,83.19760513305664,82.03340403238933,80.89120356241862,79.77050399780273,78.67070388793945,77.59140396118164,76.53200403849284,75.49210421244304,74.47130330403645,73.46910413106282,72.48490206400554,71.5186030069987,70.56940333048503,69.63720385233562,68.72150293986003,67.82180277506511,66.93790245056152,66.06930224100749,65.21570269266765,64.3767032623291,63.552002906799316,62.74120330810547,61.944003105163574,61.16020361582438,60.38930320739746,59.63110319773356,58.88530286153158,58.15160274505615,57.429703076680504,56.71920235951742,56.020002683003746,55.331802686055504,54.65420309702555,53.9870023727417,53.32990233103434,52.682702700297035,52.0451021194458,51.4169028600057,50.797902743021645,50.18770281473795,49.58620262145996,48.99320284525553,48.40850257873535,47.83180300394694,47.2629025777181,46.70170243581136,46.14790280659994,45.601402282714844,45.061902364095054,44.52940273284912,44.00360234578451,43.48440170288086,42.971502939860024,42.46500205993652,41.964502016703285,41.469902674357094,40.981101989746094,40.49800237019857,40.02040163675944,39.54820156097412,39.08120187123617,38.619401613871254,38.16260210673014,37.710801124572754,37.26380221048991,36.821502049764,36.38380209604899,35.95070266723633,35.521902084350586,35.09750207265218,34.67730172475179,34.26120185852051,33.84920152028402,33.44120184580485,33.037001609802246,32.636701583862305,32.24000104268392,31.847001711527508,31.457501729329426,31.071401596069336,30.688801447550457,30.309501489003498,29.933501561482746,29.560601393381756,29.190901279449463,28.824201265970867,28.460401217142742,28.09960142771403,27.741601308186848,27.386401017506916,27.034001350402832,26.68420108159383,26.337001005808514,25.992400964101154,25.650201002756756,25.310500939687092,24.973200798034668,24.638200918833416,24.305500984191895,23.975001017252605,23.646701018015545,23.320600986480713,22.996501127878826,22.674500942230225,22.35450092951457,22.03640079498291,21.720201174418133,21.405900637308758,21.093400478363037,20.78270085652669,20.473800500233967,20.166500727335613,19.861000696818035,19.557000478108723,19.254700819651287,18.953900655110676,18.654700597127277,18.356900374094646,18.060600598653156,17.765700499216717,17.472200393676758,17.180100599924724,16.88930034637451,16.599900086720783,16.311700344085693,16.02470024426778,15.739000161488852,15.454400062561035,15.171000242233276,14.888800064722696,14.60760005315145,14.327600240707397,14.048600117365519,13.770700057347616,13.49370018641154,13.21779998143514,12.942799806594849,12.671199957529703,12.405300060907999,12.144999980926514,11.890100081761679,11.640700022379557,11.396400054295858,11.157299995422363,10.923199971516928,10.69409998257955,10.469699939092001,10.250100056330362,10.035099824269613,9.824620087941488,9.618549982706705,9.41681989034017,9.219319979349772,9.025969902674357,8.836689949035645,8.651379982630411,8.469969908396402,8.292360146840414,8.118489901224772,7.948270042737325,7.781629999478658,7.618490020434062,7.4587699969609575,7.302410006523132,7.149330059687297,6.999459981918335,6.852750023206075,6.7091100215911865,6.568489948908488,6.430820067723592,6.296040018399556,6.164099971453349,6.0349200169245405,5.90845000743866,5.784639954566956,5.663430015246074,5.54475998878479,5.428580005963643,5.3148499727249146,5.2034900188446045,5.094479997952779,4.987749973932902,4.883260051409404,4.780970056851705,4.680820027987163,4.582769989967346,4.486780047416687,4.392809947331746,4.300800045331319,4.2107300360997515,4.12253999710083,4.036200026671092,3.951679984728495,3.868929942448934,3.787910004456838,3.708600024382273,3.6309399803479514,3.554919977982839,3.4804900089899697,3.4076199928919473,3.3362799882888794,3.2664300203323364,3.198050002257029,3.1311000188191733,3.065559983253479,3.001390020052592,2.9385600288709006,2.87704998254776,2.8168399930000305,2.7578800121943154,2.7001599868138633,2.643650015195211,2.588319977124532,2.534159998099009,2.4811300237973533,2.4292100071907043,2.378370006879171,2.3286099831263223,2.2798799872398376,2.2321799596150718,2.185480018456777,2.1397599577903748,2.0949900150299072,2.051159977912903,2.0082499980926514,1.9662399888038635,1.925109992424647,1.8848399817943573,1.8454100092252095,1.8068100015322368,1.7690199812253316,1.7320200105508168,1.695799986521403,1.6603300074736278,1.6256099740664165,1.5916099945704143,1.5583300093809764,1.5257399876912434,1.4938399990399678,1.4625999927520752,1.4320200085639954,1.4020699958006542,1.3727599879105885,1.3440599938233693,1.3159600098927815,1.2884499927361805,1.261510004599889,1.2351400057474773,1.2093199988206227,1.1840400099754333,1.1592899958292644,1.1350499987602234,1.1113299826780956,1.088100016117096,1.06535999973615,1.043090005715688,1.02128999431928,0.9999470065037409,0.9790489971637726,0.9585890024900436,0.9385569989681244,0.9189440061648687,0.8997410039107004,0.8809400051832199,0.8625329881906509,0.8445100039243698,0.826864997545878,0.8095889985561371,0.7926739901304245,0.7761140018701553,0.7598990052938461,0.7440239985783895,0.7284809996684393,0.7132630000511805,0.698363001147906,0.6837750027577082,0.6694920013348261,0.6555080016454061,0.6418160001436869,0.6284099966287613,0.6152849942445755,0.6024349927902222,0.5898529986540476,0.5775340050458908,0.5654730051755905,0.5536640038092931,0.5421009957790375,0.5307809958855311,0.5196970005830129,0.5088450014591217,0.49822000165780383,0.48781699935595196,0.4776320035258929,0.46765899906555813,0.45789499829212826,0.44833500186602276,0.4389750013748805,0.4298100024461746,0.4208369975288709,0.41205200056235,0.40345000227292377,0.3950280025601387,0.38678200046221417,0.37870799750089645,0.37080400188763935,0.3630639985203743,0.35548600057760876,0.3480660021305084,0.3408010005950928,0.33368899921576184,0.32672400524218875,0.3199059988061587,0.31322899957497913,0.3066930025815964,0.3002920001745224,0.2940259998043378,0.2878899996479352,0.28188299636046094,0.2760010013977687,0.27024200061957043,0.2646030013759931,0.2590829978386561,0.25367700060208637,0.24838400135437647,0.2432019996146361,0.23812800024946532,0.2331599990526835,0.22829599926869074,0.22353299831350645,0.2188700015346209,0.214304997275273,0.20983400071660677,0.20545700192451477,0.20117199793457985,0.19697499896089235,0.19286700089772543,0.1888439990580082,0.18490499878923097,0.1810489979883035,0.1772730015218258,0.1735760010778904,0.1699559986591339,0.16641099999348322,0.16294100135564804,0.1595430001616478,0.15621599927544594,0.1529580019414425,0.1497689994672934,0.1466459979613622,0.14358799904584885,0.14059400061766306,0.137663001815478,0.1347920000553131,0.13198200116554895,0.12923000007867813,0.12653599927822748,0.12389800014595191,0.12131499933699767,0.11878599847356479,0.11630999979873498,0.1138849997272094,0.1115109995007515,0.10918600112199783,0.10691000086565812,0.10468199973305066,0.10250000096857548,0.10036300122737885,0.09827160028119881,0.09622329970200856,0.09421779898305734,0.09225410036742687,0.09033140043417613,0.08844880076746146,0.08660550105075042,0.08480060038467248,0.08303340089817841,0.08130309979120891,0.07960880113144715,0.07794989955921967,0.07632560034592946,0.07473520003259182,0.07317790078620116,0.07165309910972913,0.0701601995776097,0.0686982994278272,0.06797510012984276};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473158200581868,7.644383549690247,7.721264561017354,7.842247645060222,7.984724243481954,8.13667631149292,8.29219647248586,8.382592598597208,8.373160044352213,8.312881151835123,8.226985971132914,8.128377199172974,8.023597796758017,7.915971875190735,7.807144323984782,7.69792366027832,7.588754773139954,7.475737293561299,7.357118129730225,7.236390391985576,7.115220785140991,6.994349439938863,6.874048630396525,6.7543760140736895,6.635297417640686,6.51671024163564,6.398518880208333,6.251451690991719,6.057153979937236,5.832626978556315,5.5874290863672895,5.327198505401611,5.055512030919393,4.77482012907664,4.486935456593831,4.193295816580455,3.895097573598226,3.585060795148214,3.2609588305155435,2.9313343365987143,2.6006051699320474,2.2709912260373435,1.9435955584049225,1.6189299325148265,1.297200749317805,0.9785086909929911,0.6628250330686569,0.42673027763764065,0.3084702243407567,0.24979813769459724,0.2209852064649264,0.20716041202346483,0.20081751917799315,0.19822219014167786,0.1975144607325395,0.19776904955506325,0.1985260657966137,0.19941908617814383,0.20026719445983568,0.20112810408075651,0.20202403515577316,0.2029669110973676,0.2039657918115457,0.20501767471432686,0.206120565533638,0.20727743084232012,0.20848535746335983,0.20930370191733041,0.20951399207115173,0.2094462737441063,0.20925955846905708,0.20902955159544945,0.20879258960485458,0.2085645372668902,0.20835251112778982,0.20828303694725037,0.2084136332074801,0.20851893350481987,0.20848820234338442,0.20839627335468927,0.2082743470867475,0.20813835163911185,0.20799637213349342,0.2078463857372602,0.20769438768426576,0.20754333958029747,0.20739240696032843,0.20697034522891045,0.2061470883587996,0.20512841269373894,0.20401058346033096,0.2028456541399161,0.2016577012836933,0.20045273130138716,0.1992417350411415,0.1980267489949862,0.19680476312836012,0.19558076312144598,0.19435477380951247,0.1931237814327081,0.19189177950223288,0.19065779075026512,0.18941779931386313,0.18817779421806335,0.18693580602606139,0.18568781887491545,0.18443981061379114,0.1831908201177915,0.18193583562970161,0.18067982917030653,0.17942283923427263,0.17815984909733137,0.17689684654275575,0.17563185468316078,0.1743618610004584,0.17309186110893884,0.1718198706706365,0.17054187754789987,0.16926387573281923,0.1679848829905192,0.16670089463392893,0.16541588803132376,0.16412989671031633,0.16283790891369185,0.16154690459370613,0.1602529138326645,0.15895492086807886,0.15765591834982237,0.1563559261461099,0.15504894157250723,0.1537399416168531,0.15242795273661613,0.15110797310868898,0.14978397389252981,0.14845698326826096,0.1471220018963019,0.14578400428096452,0.1444410185019175,0.14309103538592657,0.1417380372683207,0.14038105060656866,0.13901706412434578,0.13764907171328863,0.13627807920177779,0.13490009680390358,0.1335200940569242,0.13213610897461572,0.1307451253135999,0.12935212440788746,0.12795613147318363,0.12655314803123474,0.12514914634327093,0.12374215697248776,0.12232817212740581,0.12091316841542721,0.11949617726107438,0.11807219435771306,0.11664718886216481,0.11522119554380576,0.11379020661115646,0.11235920091470082,0.11092720925807953,0.10949321029086907,0.10805920884013176,0.10662620638807614,0.10519021563231945,0.10375520711143811,0.10232120752334595,0.1008842159062624,0.09944840706884861,0.09801331038276355,0.09657511860132217,0.09513830952346325,0.09370201205213864,0.09226271882653236,0.09082471206784248,0.08938721443216006,0.08794662170112133,0.08650741229454677,0.08506881569822629,0.08362702404459317,0.08218661323189735,0.08074671650926273,0.0793037253121535,0.07786201623578866,0.07642082000772159,0.07497642499705155,0.07353341827789943,0.07209082320332527,0.07064512744545937,0.0692007193962733,0.06775672485431035,0.06630963024993737,0.0648638221124808,0.06341852682332198,0.06197003244111935,0.06052282452583313,0.059076130079726376,0.057626234057048954,0.056177626363933086,0.05472943155715863,0.05327813668797413,0.051828128596146904,0.05037853339066108,0.04892573785036802,0.047474331222474575,0.04602333530783653,0.0445691409210364,0.04311633327354988,0.04166393758108219,0.04020824314405521,0.03875403571873903,0.0373001399760445,0.03584314541270336,0.034387338596085705,0.03293204183379809,0.03147364718218645,0.03001644043251872,0.028559743737181027,0.02709984950100382,0.025641242507845163,0.024183145879457395,0.022721752058714628,0.021261744511624176,0.01980214814345042,0.018339453730732203,0.01687794706473748,0.015416949987411499,0.01395275630056858,0.012489849391082922,0.011027352108309666,0.00956170936115086,0.008097349355618158,0.006633420436022182,0.005166305229067802,0.0037005554574231305,0.002235073179084187,0.0011295806762063876,0.0005705305496424747,0.00028829938916411874,0.0001456381602717253,7.359225522426034e-05,3.718044066166234e-05,1.8788003671943443e-05,9.492995521516908e-06,4.797182801515494e-06,2.4240630030665975e-06,1.2250367925995913e-06,6.190660760315344e-07,3.1287067988235623e-07,1.5811925753913178e-07,1.7614166125667907e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911460916201274,1.2003816664218903,1.2822915315628052,1.3921616474787395,1.5122217734654744,1.6421418885389965,1.781611979007721,1.9277320603529613,2.0777121583620706,2.2314421931902566,2.388812303543091,2.5497123996416726,2.714022437731425,2.881652534008026,3.052502612272898,3.226462701956431,3.403452714284261,3.5801127552986145,3.7532127499580383,3.9228527545928955,4.089142799377441,4.252182841300964,4.412072817484538,4.568902810414632,4.722762823104858,4.8737428188323975,5.021922747294108,5.161282579104106,5.285882472991943,5.3959724108378095,5.4918222824732466,5.5736622015635175,5.641752044359843,5.696331938107808,5.73764185110728,5.7659117380778,5.781391580899556,5.781721393267314,5.764731248219808,5.73094101746877,5.680860837300618,5.614980737368266,5.533790588378906,5.437770446141561,5.327390193939209,5.203110218048096,5.065370122591655,4.922850131988525,4.783980091412862,4.648750066757202,4.517160097757976,4.38916011651357,4.264730056126912,4.1438301006952925,4.026410102844238,3.9124300877253213,3.8018301129341125,3.6944501201311746,3.5901401241620383,3.4888501167297363,3.3905500570933023,3.2951901157697043,3.2027000983556113,3.113040109475454,3.026150087515513,2.941970109939575,2.860440115133921,2.781400124231974,2.704680105050405,2.6302401224772134,2.5580200950304666,2.487950086593628,2.420000116030375,2.3540901144345603,2.2901901404062905,2.2283101081848145,2.168470084667206,2.1105700929959617,2.0545500914255777,2.000330130259196,1.9478601117928822,1.897060106197993,1.847900112469991,1.8003000915050507,1.7542201081911724,1.7096100946267445,1.6664100885391235,1.6245600978533428,1.5840000907580059,1.544680118560791,1.5065700908501942,1.4696201086044312,1.4337900976339977,1.3990500966707866,1.3653700947761536,1.3326900998751323,1.3010100920995076,1.2702700992425282,1.2404500842094421,1.2115200857321422,1.1834600865840912,1.1562200983365376,1.129790077606837,1.104140082995097,1.079240083694458,1.055060088634491,1.0315900941689808,1.0088000893592834,0.9866740852594376,0.9651820957660675,0.9443070888519287,0.9240280836820602,0.9043270945549011,0.8851830810308456,0.8665770838658015,0.8484930743773779,0.8309160868326823,0.8138270825147629,0.7972130825122198,0.781057079633077,0.7653440833091736,0.7500600715478262,0.7351910769939423,0.7207240760326385,0.7066430747509003,0.6929370810588201,0.6795940846204758,0.6666050752003988,0.6539560705423355,0.6416360785563787,0.6296360641717911,0.617943063378334,0.606549064318339,0.595443069934845,0.5846150716145834,0.574054072300593,0.5637520651022593,0.5537020663420359,0.5438950757185618,0.5343230664730072,0.5249790698289871,0.5158560623725256,0.5069450587034225,0.49824006607135135,0.4897340660293897,0.4814190591375033,0.47328806668519974,0.4653370603919029,0.45756006489197415,0.44995306183894473,0.4425080592433612,0.4352210536599159,0.42808705816666287,0.42110005766153336,0.41425705204407376,0.4075520584980647,0.40097805360953015,0.39453205466270447,0.38821105162302655,0.3820120518406232,0.3759300534923871,0.3699630523721377,0.36410605162382126,0.3583570470412572,0.35271205256382626,0.3471670498450597,0.3417200446128845,0.33636604497830075,0.33110204587380093,0.3259270489215851,0.3208390474319458,0.3158350462714831,0.3109120453397433,0.3060670420527458,0.3013000388940175,0.29660604149103165,0.29198404401540756,0.2874320422609647,0.28294503937164944,0.2785220369696617,0.27416203667720157,0.2698650434613228,0.26562603811422986,0.2614460339148839,0.2573220406969388,0.253253032763799,0.24923603236675262,0.24527003367741904,0.24135203287005424,0.23748003070553145,0.23365503052870432,0.22987502937515578,0.22613902886708578,0.22244502852360407,0.21879302834471068,0.21518103033304214,0.21160702655712763,0.20807102570931116,0.2045720269282659,0.2011060230433941,0.19767202312747637,0.19427102183302244,0.19090202450752258,0.1875650224586328,0.18425802141427994,0.18098002299666405,0.17773101975520453,0.17450902114311853,0.17131401474277178,0.16814501956105232,0.16499901687105498,0.16187501698732376,0.15877501542369524,0.15569801504413286,0.15264301498730978,0.14960901315013567,0.1465970128774643,0.1436040128270785,0.14063101386030516,0.13767801225185394,0.13474000742038092,0.1318180114030838,0.12891400853792825,0.1260260088990132,0.12315500775973003,0.12030000736316045,0.11746000622709592,0.11463400535285473,0.111823004980882,0.10902600424985091,0.10624300440152486,0.10347000323235989,0.10070800160368283,0.09795800161858399,0.09522010013461113,0.09249389978746574,0.08977880018452804,0.08710950054228306,0.08451969921588898,0.08200699960192044,0.07956909947097301,0.07720380028088887,0.07490890038510163,0.0726822999616464,0.07052200039227803,0.0684258999923865,0.06639229940871398,0.06441920002301534,0.06250480003654957,0.060647399785617985,0.058845200265447296,0.057096700804928936,0.05540020018815994,0.05375419991711775,0.05215709997961918,0.05060760024935007,0.049104099782804646,0.04764540089915196,0.04623009947439035,0.044856900038818516,0.043524499982595444,0.04223169976224502,0.04097739979624748,0.03976039960980415,0.03857959993183613,0.03743389993906021,0.03632230032235384,0.03524370056887468,0.03419720040013393,0.033181799575686455,0.03219659999012947,0.03124069965754946,0.03031320000688235,0.029413299945493538,0.028540100281437237,0.02769290019447605,0.02687080002700289,0.026073200007279713,0.025299299973994493,0.024548399883011978,0.02381980000063777,0.023112900089472532,0.022427000105381012,0.021761400004227955,0.021115599976231653,0.020488999939213198,0.019881100083390873,0.019291100092232227,0.018718699924647808,0.018163399926076334,0.017624500052382547,0.017101600145300228,0.016594200084606808,0.016101999829212826,0.015624299955864748,0.015160799880201617,0.014711099987228712,0.014274799963459373,0.01385139999911189,0.01344049993592004,0.01304190008280178,0.012655099931483468,0.012279799984147152,0.01191560000491639,0.011562300069878498,0.01121940005881091,0.010886700047800938,0.010563899918148914,0.010250699939206243,0.00994676995712022,0.00965186992349724,0.009365710041796168,0.009088049953182539,0.008818629896268249,0.008557199966162443,0.00830353998268644,0.008057400196169814,0.007818560077187916,0.007586810000551243,0.007361939991824329,0.007143739998961489,0.006932019993352394,0.006726569961756468,0.006527230027131736,0.006333790059822301,0.006146100000478327,0.005963969975709915,0.005787240030864875,0.005615759951372941,0.005449359964889784,0.005287900023783247,0.0051312300298983855,0.004979210013213257,0.004831689991988242,0.004688550058441858,0.0045496500097215176,0.004414879988568525,0.0042840999861558276,0.0041571900170917315,0.0040340500030045705,0.003914569950817774,0.003798619999239842,0.003686109984604021,0.003576940003161629,0.0034710099765410027,0.003368210008678337,0.0032684600058322153,0.003171669978958865,0.0030777499778196216,0.002986609974565605,0.0028981800035883984,0.0028123600059188902,0.002729089988861233,0.002648289994491885,0.0025698799872770905,0.0024938000133261085,0.0024199699983000755,0.0023483199959931276,0.0022787999866219857,0.00221135001629591,0.002145889991273483,0.002082360015871624,0.002020730016132196,0.0019609099933101484,0.0019028699995639424,0.001846549993691345,0.0017918999947141856,0.001738870011953016,0.0016873999848030508,0.001637470006244257,0.0015890099942528952,0.0015419899912861486,0.0014963599969632924,0.0014520800129200022,0.0014091099825842928,0.0013674100046046078,0.0013269499856202553,0.0012876899951758485,0.0012495900058032323,0.0012126200114532064,0.0011767500060765694,0.0011419300086951505,0.0011081499978899956,0.001075370004400611,0.0010435599930739652,0.0010126900063672413,0.0009827319930385177,0.0009536629998668408,0.0009254540006319681,0.0008980810137776037,0.0008715180010767654,0.0008457419996072227,0.0008207280043279752,0.0007964549974227945,0.0007729010006490474,0.0007500429977274811,0.000727861993558084,0.0007063380035106093,0.0006854510090003411,0.0006651820003753528,0.0006455129963190606,0.0006264260009629652,0.0006079029990360141,0.0005899290117667988,0.0005724870037132254,0.0005555609968723729,0.0005391359930702796,0.0005231969941329832,0.0005077289970358834,0.0004927190020680428,0.00047815299573509645,0.00046401899696017307,0.00045030199786803376,0.0004369909972107659,0.00042407399935958284,0.0004115389989844213,0.00039937499968800694,0.0003875710050730656,0.0003761159993397693,0.0003649990006427591,0.000354212000578021,0.00034374400274828076,0.00033358499786118045,0.0003237269993405789,0.00031415999789411825,0.0003048759972443804,0.0002958670035392667,0.00028712400429261226,0.0002786399976078731,0.0002704070017595465,0.00026241700349297997,0.00025466299848631024,0.0002471389949884421,0.0002398370003599363,0.00023275100102182478,0.0002258750015850334,0.00021920200015301816,0.00021272600133670494,0.00020644199927725518,0.00020034300177940167,0.00019442499857783938,0.00018868200034679225,0.00018310799835793054,0.000177699998554696,0.00017245100146586387,0.00016735699925144823,0.00016241399862337857,0.00015761699978611432,0.00015296199975030808,0.00014844400235839808,0.0001440599977892513,0.00013980600003075475,0.00013567700201141028,0.0001316699987607232,0.0001277819998601141,0.00012400799945074445,0.0001203459996759193,0.00011679299920312285,0.00011334399944947411,0.00010999699952662922,0.00010674999915257406,0.0001035979997444277,0.00010053899920118663,9.757050005039976e-05,9.468979988014325e-05,9.189429996088923e-05,8.918130030603304e-05,8.654849928764936e-05,8.399349887137457e-05,8.151389859752574e-05,7.910760056499082e-05,7.677240076494248e-05,7.450619887094945e-05,7.230690001354863e-05,7.017259910450473e-05,6.810130071244203e-05,6.609119979354243e-05,6.414050039893482e-05,6.22473986974607e-05,6.041019999732574e-05,5.862729994987603e-05,5.689709996659076e-05,5.52178998987074e-05,5.358830003387993e-05,5.200689975026762e-05,5.122799969588717e-05};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.946319580078125,28.906192779541016,29.845894654591877,30.63719606399536,31.22409741083781,31.607298374176025,31.78779872258504,31.8590989112854,31.91429901123047,31.953598976135254,31.976898829142254,31.984399159749348,31.97619915008545,31.952399571736652,31.912999471028645,31.858099460601807,31.78779935836792,31.70859956741333,31.626999537150066,31.54319938023885,31.45709975560506,31.368699709574383,31.27809985478719,31.185299555460613,31.09019962946574,30.993099530537922,30.893699645996094,30.792500019073486,30.689499855041504,30.58459981282552,30.477499802907307,30.368299802144367,30.25659974416097,30.14239962895711,30.025499661763508,29.90589984258016,29.783499717712402,29.658899943033855,29.532999833424885,29.405800024668377,29.277199586232502,29.147300243377686,29.016200065612793,28.883700052897137,28.750100135803223,28.615100224812824,28.478999932607014,28.34220027923584,28.20539967219035,28.068699836730957,27.932000001271565,27.79550011952718,27.659200191497803,27.523200035095215,27.387499809265137,27.252099990844727,27.117199897766113,26.982500235239666,26.848200003306072,26.714200019836426,26.580499807993572,26.44729995727539,26.31450017293294,26.182100137074787,26.050299962361652,25.919000148773193,25.788300037384033,25.658099969228108,25.52839994430542,25.399099826812744,25.270300070444744,25.14199988047282,25.01419989267985,24.886900107065838,24.760200023651123,24.63410011927287,24.508899847666424,24.384400208791096,24.260700066884358,24.137800057729084,24.01570002237956,23.894399960835774,23.773800214131672,23.653899828592937,23.534800052642822,23.416500091552734,23.298899968465168,23.182000001271565,23.06580050786336,22.950200080871582,22.835299968719482,22.721100171407063,22.60759989420573,22.494700113932293,22.382500171661377,22.270899931589764,22.159899711608887,22.04959996541341,21.940000375111897,21.830899715423584,21.72249984741211,21.614699999491375,21.50749985376994,21.401000022888184,21.295000076293945,21.18970012664795,21.084900220235188,20.980799674987793,20.87719996770223,20.774199962615967,20.671799818674724,20.570000012715656,20.46879990895589,20.368200143178303,20.268100261688232,20.16859992345174,20.069600264231365,19.97120014826457,19.87340021133423,19.77609984079997,19.67929983139038,19.583100001017254,19.487500190734863,19.392399946848553,19.297799905141193,19.203700065612793,19.11019976933797,19.017199993133545,18.924700260162354,18.83270009358724,18.741300264994305,18.650300184885662,18.55989996592204,18.46989981333415,18.380499680836994,18.291499773661297,18.20300006866455,18.1150000890096,18.02739969889323,17.940399805704754,17.85379981994629,17.767600218454998,17.681900183359783,17.596700191497803,17.511899789174397,17.4275000890096,17.343599796295166,17.26010004679362,17.177099863688152,17.094500223795574,17.01230001449585,16.93049971262614,16.84910011291504,16.768099784851074,16.687599976857502,16.607399781545002,16.5277001063029,16.44830020268758,16.369400183359783,16.290800094604492,16.212599913279217,16.13480011622111,16.057400226593018,15.98039976755778,15.903700033823648,15.827499945958456,15.75159994761149,15.675999959309896,15.600900014241537,15.526099999745687,15.45170005162557,15.377600034077963,15.30400005976359,15.230700095494589,15.157699982325235,15.085100015004477,15.01289995511373,14.940999984741211,14.869499921798706,14.79830002784729,14.727500041325888,14.657000144322714,14.586899995803833,14.517100016276041,14.447700023651123,14.378599961598715,14.309800148010254,14.241400082906088,14.17329994837443,14.105600039164225,14.03820013999939,13.971100012461344,13.90440003077189,13.837999900182089,13.771900018056234,13.70610006650289,13.640700181325277,13.575599988301596,13.510799964269003,13.446299950281778,13.382100105285645,13.318300088246664,13.254699945449829,13.191499948501587,13.128599961598715,13.066000064214071,13.003699938456217,12.941799879074097,12.880099852879843,12.818700075149536,12.757599910100302,12.696900049845377,12.636400063832602,12.576200008392334,12.516299962997437,12.456700086593628,12.39739982287089,12.338399966557821,12.2796999613444,12.221299886703491,12.16319998105367,12.105300029118856,12.047699928283691,11.990399916966757,11.93339999516805,11.876700083414713,11.820299943288168,11.764099995295206,11.708199898401896,11.652599970499674,11.59719999631246,11.542099952697754,11.487300078074137,11.432799816131592,11.37849990526835,11.324499924977621,11.270800034205118,11.217300017674765,11.164100090662638,11.11109987894694,11.05839991569519,11.005899985631308,10.953700065612793,10.901700019836426,10.850000063578287,10.798500061035156,10.747300068537394,10.696300029754639,10.645600001017252,10.595099925994873,10.544800043106079,10.494800170262655,10.44509998957316,10.39549978574117,10.346199909845987,10.297200043996176,10.24839997291565,10.19980001449585,10.151400089263916,10.103300094604492,10.055400053660074,10.007700045903524,9.960269927978516,9.913060029347738,9.866070032119751,9.819310029347738,9.772770007451376,9.726450045903524,9.680349985758463,9.634479999542236,9.588819980621338,9.54337994257609,9.498160123825073,9.453150113423666,9.40836008389791,9.363779783248901,9.319420019785563,9.275270064671835,9.231329997380575,9.187589963277182,9.144069910049438,9.100759983062744,9.057650089263916,9.014739990234375,8.972050031026205,8.929550011952719,8.88726003964742,8.84516986211141,8.803280035654703,8.761589924494425,8.720100164413452,8.678810040156046,8.637719949086508,8.596819957097372,8.55610998471578,8.515600124994913,8.475290060043335,8.435160080591837,8.395230054855347,8.35548988978068,8.315929889678955,8.276570002237955,8.237390120824179,8.198400100072226,8.159600098927816,8.120980024337769,8.082540194193522,8.04428998629252,8.006219943364462,7.9683299859364825,7.930630048116048,7.893100023269653,7.85575000445048,7.8185800313949585,7.781579971313477,7.744759917259216,7.708119988441467,7.671649972597758,7.6353600025177,7.599239945411682,7.563289999961853,7.527510007222493,7.491899927457173,7.4564599593480425,7.421190023422241,7.386090000470479,7.351160089174907,7.316389997800191,7.281789978345235,7.247349937756856,7.213080048561096,7.178969979286194,7.145020047823588,7.11123005549113,7.077609936396281,7.044140021006267,7.0108299652735395,6.977689981460571,6.944699923197429,6.91186002890269,6.879179994265239,6.846660017967224,6.814299980799357,6.782079974810283,6.750019987424214,6.718120018641154,6.686359961827596,6.654760003089905,6.623300035794576,6.5920000076293945,6.560840010643005,6.529840071996053,6.498979965845744,6.468270023663838,6.437700072924296,6.407279968261719,6.3769999742507935,6.346869945526123,6.316880027453105,6.287029981613159,6.257330020268758,6.227759957313538,6.198340018590291,6.169050017992656,6.139909982681274,6.110899964968364,6.082039952278137,6.053299943606059,6.024709979693095,5.996250033378601,5.96793007850647,5.939740061759949,5.911679943402608,5.88375997543335,5.855969985326131,5.828319986661275,5.800790031750997,5.773400028546651,5.746130029360454,5.718999981880188,5.6919899781545,5.665110031763713,5.638359983762105,5.611739993095398,5.5852400461832685,5.558870037396749,5.53263000647227,5.506499965985616,5.480509996414185,5.454630017280579,5.428879976272583,5.403250058492024,5.377749999364217,5.352360049883525,5.32709002494812,5.301949977874756,5.276919921239217,5.252020001411438,5.227229952812195,5.202550053596497,5.178000013033549,5.153559962908427,5.129239996274312,5.105029980341594,5.080939968427022,5.056960026423137,5.033100008964539,5.009349981943767,4.985710024833679,4.962189952532451,4.938770055770874,4.915470043818156,4.892280062039693,4.869189977645874,4.846220016479492,4.823359966278076,4.800600012143453,4.777950008710225,4.755409995714824,4.732980012893677,4.710650046666463,4.688429951667786,4.66631003220876,4.6442999839782715,4.622400005658467,4.600590030352275,4.578889966011047,4.5573000113169355,4.535800019900004,4.514410098393758,4.493119994799296,4.471930066744487,4.450839996337891,4.429849942525228,4.408959984779358,4.388170003890991,4.367480039596558,4.3468799988428755,4.326390027999878,4.305989940961202,4.285680015881856,4.265480001767476,4.245359977086385,4.225350022315979,4.205430070559184,4.18559992313385,4.165869951248169,4.146230101585388,4.126680056254069,4.107230067253113,4.087870001792908,4.068600018819173,4.04941999912262,4.030329982439677,4.0113299290339155,3.992430031299591,3.9736099441846213,3.9548799792925515,3.936240037282308,3.9176899790763855,3.8992199897766113,3.880849997202555,3.862559974193573,3.8443599740664163,3.826239983240763,3.808209995428721,3.7902599970499673,3.77239998181661,3.754629989465078,3.7369399666786194,3.7193300326665244,3.7018000284830728,3.6843599677085876,3.6669999957084656,3.6497300068537393,3.6325300137201944,3.6154199838638306,3.598379969596863,3.5814299980799356,3.5645599961280823,3.547770003477732,3.5310500065485635,3.514419992764791,3.4978700081507363,3.4813899993896484,3.473170022169749};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.1404640463491281,0.14906380077203116,0.159404826660951,0.1713378131389618,0.18488479405641556,0.20003977169593176,0.2167927511036396,0.23509473229448,0.25489571193854016,0.2761886914571126,0.2989666710297267,0.32322365790605545,0.348950631916523,0.37614161521196365,0.4047885959347089,0.43488457302252453,0.466424564520518,0.49915354202191037,0.532820537686348,0.5674235224723816,0.6029555102189382,0.6394134908914566,0.6767934809128443,0.7150874634583791,0.7542934517065684,0.7944074422121048,0.8354244579871496,0.8760914703210195,0.9151554902394613,0.9526225129763285,0.9884975353876749,1.0227795441945393,1.0554795662562053,1.0865995784600575,1.1161396106084187,1.1440996130307515,1.1704996526241302,1.1945796807607014,1.2156397104263306,1.2336897750695546,1.2487298051516216,1.2607898314793904,1.2698798477649689,1.275999903678894,1.2791899542013805,1.2794399658838909,1.276779979467392,1.272679994503657,1.2686399618784587,1.2646499872207642,1.2606999675432842,1.2568199634552002,1.2529899577299755,1.2492099702358246,1.245499978462855,1.2418499688307445,1.23826997478803,1.2347399592399597,1.2312599817911785,1.227839966615041,1.2244699597358704,1.2211499611536663,1.2178999682267506,1.214699963728587,1.2115599513053894,1.2084799706935883,1.2054599523544312,1.202489972114563,1.1995399594306946,1.196629951397578,1.1937499443689983,1.190889964501063,1.1880699396133423,1.185269961754481,1.1825099686781566,1.1797899504502614,1.1771099269390106,1.1744699478149414,1.1718599498271942,1.1692699392636616,1.1667199631532033,1.164199968179067,1.16170996427536,1.159239947795868,1.1568099558353424,1.154399961233139,1.1520199577013652,1.1496499578158061,1.1472799479961395,1.1448999643325806,1.142509937286377,1.1401099761327107,1.1377099553744,1.1352999607721965,1.1328899661699932,1.1304599543412526,1.1280299425125122,1.125589946905772,1.1231499512990315,1.1206999619801838,1.1182399491469066,1.1157699426015217,1.113299955924352,1.1108199656009674,1.1083399554093678,1.1058499614397685,1.1033499538898468,1.1008399526278179,1.0983299513657887,1.0958099762598674,1.0932799577713013,1.0907499690850575,1.0881999731063843,1.085659960905711,1.0830999612808228,1.0805399616559346,1.0779699385166168,1.0753999551137288,1.072819968064626,1.0702299773693085,1.0676299631595612,1.0650299787521362,1.062419980764389,1.059809962908427,1.0571899712085724,1.0545599659283955,1.051919957002004,1.04926997423172,1.046619971593221,1.0439599653085072,1.0412999590237935,1.0386299590269725,1.035949965318044,1.0332699517409007,1.0305799543857574,1.0278799732526143,1.0251699686050415,1.0224599639574687,1.0197399655977886,1.0170099834601085,1.0142699678738911,1.0115199585755665,1.008769949277242,1.006009966135025,1.0032399892807007,1.0004599591096242,0.9976759701967239,0.9948819776376089,0.9920809715986252,0.9892709751923879,0.9864539802074432,0.98362797498703,0.9807929744323095,0.9779509752988815,0.9750979741414388,0.972233975927035,0.9693619757890701,0.9664819687604904,0.9635929812987646,0.9606949736674627,0.9577889790137609,0.9548739790916443,0.9519499838352203,0.9490179866552353,0.946077972650528,0.9431289782126745,0.9401719818512598,0.9372069736321768,0.9342329849799474,0.9312489877144495,0.9282549719015757,0.9252529839674631,0.9222429792086283,0.9192249874273936,0.9161989788214365,0.9131639748811722,0.9101219872633616,0.9070719828208288,0.9040139764547348,0.9009479880332947,0.897873987754186,0.8947929789622625,0.8917039831479391,0.8886069854100546,0.885500987370809,0.8823849807182947,0.8792609920104345,0.8761299848556519,0.8729919840892156,0.8698459813992182,0.866691991686821,0.8635309835275015,0.8603629916906357,0.8571879963080088,0.8540050039688746,0.8508139948050181,0.8476169854402542,0.8444119890530905,0.8412009874979655,0.8379799822966257,0.8347499966621399,0.8315129925807317,0.8282689899206161,0.8250169853369395,0.821758990486463,0.8184939920902252,0.8152219951152802,0.811942994594574,0.8086579938729604,0.8053649961948395,0.8020659983158112,0.798759991923968,0.7954469869534174,0.7921269983053207,0.7887989977995554,0.7854620019594828,0.782118002573649,0.7787680079539617,0.7754119882980982,0.7720489899317423,0.7686790029207865,0.7653029958407084,0.7619200001160303,0.758531004190445,0.7551349947849909,0.751733993490537,0.7483249952395757,0.744910995165507,0.7414900014797846,0.73806099096934,0.7346239934364954,0.7311799923578898,0.7277309944232305,0.7242749979098638,0.7208130011955897,0.7173449993133545,0.7138710021972656,0.7104029953479767,0.7069509873787562,0.7035160064697266,0.7000989963610967,0.6966980050007502,0.693312997619311,0.6899449974298477,0.6865940093994141,0.6832589954137802,0.6799400051434835,0.6766380071640015,0.673351988196373,0.6700820028781891,0.6668280015389124,0.663590004046758,0.6603669921557108,0.6571609973907471,0.653969998160998,0.6507950027783712,0.6476349979639053,0.6444909969965616,0.6413619965314865,0.6382490048805872,0.6351510037978491,0.632068008184433,0.6290000031391779,0.6259469985961914,0.6229090044895808,0.6198860009511312,0.6168770045042038,0.6138839920361837,0.6109049965937933,0.6079399983088175,0.6049900054931641,0.6020549982786179,0.5991340031226476,0.5962270051240921,0.5933340042829514,0.590456003944079,0.5875909974177679,0.5847410013278326,0.5819040089845657,0.5790819923082987,0.5762729942798615,0.5734780033429464,0.5706959913174311,0.5679279963175455,0.565173993508021,0.5624330043792725,0.5597060024738312,0.5569910009702047,0.5542900065581003,0.5516029844681422,0.5489279975493749,0.5462670028209686,0.5436179985602697,0.5409819980462393,0.538360004623731,0.5357499967018763,0.5331520040829977,0.5305679986874262,0.5279959936936697,0.525437002380689,0.5228900114695231,0.5203550110260645,0.517833004395167,0.5153239965438843,0.5128260006507238,0.5103409985701243,0.5078679968913397,0.5054059972365698,0.5029570112625757,0.5005199958880743,0.49809499830007553,0.49568100025256473,0.49327999850114185,0.4908900012572606,0.48851100107034046,0.4861450021465619,0.48378900190194446,0.48144600292046863,0.47911400347948074,0.47679300357898075,0.474482998251915,0.47218500077724457,0.46989799787600833,0.4676219969987869,0.4653569981455803,0.46310300131638843,0.4608600015441577,0.4586280013124148,0.456406998137633,0.4541969994703929,0.4519979978601138,0.4498090023795764,0.44763100147247314,0.44546400010585785,0.44330699493487674,0.4411599983771642,0.4390240013599396,0.43689900388320285,0.43478399763504666,0.43267900000015896,0.43058399856090546,0.4285000016291936,0.4264259959260623,0.4243620013197263,0.42230800290902454,0.42026399821043015,0.41822900623083115,0.4162049988905589,0.41419100016355515,0.4121860017379125,0.4101920003692309,0.4082069968183835,0.40623099853595096,0.4042649989326795,0.40230899800856906,0.4003629982471466,0.39842499792575836,0.3964979996283849,0.39457900325457257,0.39266999810934067,0.39077000071605045,0.38887999951839447,0.3869980002442996,0.3851259996493657,0.383262999355793,0.3814089968800545,0.37956399967273075,0.3777279977997144,0.375900998711586,0.3740830024083455,0.3722739989558856,0.3704730023940404,0.36868099868297577,0.3668979952732722,0.3651239996155103,0.3633580033977826,0.36160099506378174,0.35985200107097626,0.35811200241247815,0.35638100157181424,0.35465699682633084,0.35294200231631595,0.3512360006570816,0.3495379959543546,0.34784799565871555,0.3461659972866376,0.34449199835459393,0.34282700220743817,0.34116899718840915,0.33952000240484875,0.3378790045777957,0.33624599874019623,0.33462000141541165,0.33300300190846127,0.33139300098021823,0.32979100197553635,0.32819700489441556,0.3266109973192215,0.32503200074036914,0.32346199701229733,0.32189800093571347,0.3203429977099101,0.31879500051339466,0.3172539994120598,0.315721000234286,0.3141949996352196,0.3126769959926605,0.3111660033464432,0.30966300268967945,0.3081660022338231,0.3066770037015279,0.30519600212574005,0.30372099826733273,0.3022539938489596,0.30079300204912823,0.2993399997552236,0.2978940010070801,0.2964550008376439,0.29502299924691516,0.2935980036854744,0.29217999925216037,0.29076800247033435,0.28936400016148883,0.2879659980535507,0.28657499700784683,0.28519100199143094,0.28381400058666867,0.28244299938281375,0.2810789992411931,0.2797210017840068,0.2783710037668546,0.2770260001222293,0.275688000023365,0.27435700098673504,0.27303199966748554,0.2717139994104703,0.2704019968708356,0.2690959970156352,0.2677969957391421,0.2665039971470833,0.26521699875593185,0.26393700391054153,0.26266200095415115,0.26139399657646817,0.26013199736674625,0.2588759983579318,0.2576270004113515,0.2563830042878787,0.25514500339825946,0.2539140035708745,0.2526879931489627,0.2514680003126462,0.25025499736269313,0.2490470012029012,0.2478450002769629,0.2466479962070783,0.2454579994082451,0.244273000707229,0.24309399972359338,0.24192099645733833,0.24075399960080782,0.23959199960033098,0.23843500018119812,0.23728500182429949,0.23614000156521797,0.235000000645717,0.2338660011688868,0.23273799816767374,0.23161499947309494,0.23049700011809668,0.22938499972224236,0.2282780036330223,0.22717700029412904,0.22608099753657976,0.2249900003274282,0.22390500083565712,0.22282499944170317,0.2217499998708566,0.2206799996395906,0.21961500123143196,0.21855600054065386,0.21750199794769287,0.21645200004180273,0.21540799861152968,0.21436900024612746,0.21385099987188974};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2238617142041526,2.4407403270403543,2.636750260988871,2.918510297934214,3.244560261567434,3.609040319919586,4.006760378678639,4.431700388590495,4.878770470619202,5.345120390256246,5.828280488650004,6.32606053352356,6.836560487747192,7.358100573221843,7.8892306089401245,8.42866047223409,8.975270509719849,9.515970627466837,10.039300600687662,10.547600746154785,11.04270068804423,11.52630066871643,12.000000794728598,12.46500070889791,12.922400712966919,13.373100757598877,13.817900816599527,14.204500834147135,14.486000855763754,14.673300743103027,14.77630082766215,14.803500652313232,14.762300729751587,14.65950059890747,14.501000563303629,14.292200565338135,14.03790052731832,13.705500523249308,13.26770027478536,12.738400300343832,12.129800160725912,11.452900330225626,10.717000246047974,9.930780092875162,9.10152006149292,8.235750158627829,7.339209993680318,6.487110058466594,5.745000084241231,5.0997300545374555,4.539550065994263,4.054050068060557,3.633970061937968,3.2711400787035623,2.958340048789978,2.689230044682821,2.4582300583521524,2.2600200176239014,2.090000053246816,1.9446000556151073,1.8206500609715779,1.7154100735982258,1.626440058151881,1.5516300698121388,1.4891400436560314,1.4373400509357452,1.3948400517304738,1.3596400717894237,1.330000062783559,1.3052000602086384,1.2846100628376007,1.267670065164566,1.253920078277588,1.242920070886612,1.234340061744054,1.2280300656954448,1.223870058854421,1.2212400535742443,1.2196200788021088,1.2188500662644703,1.218840052684148,1.2194600601991017,1.220630059639613,1.22229007879893,1.2243600686391194,1.226790060599645,1.2295300761858623,1.231730063756307,1.232630044221878,1.232410063346227,1.231230080127716,1.229220062494278,1.2264800469080608,1.2231100698312123,1.2192100683848064,1.2148200571537018,1.210030049085617,1.2048900524775188,1.1994400521119435,1.1937100688616435,1.1877500514189403,1.181590050458908,1.1752500335375469,1.168740063905716,1.162110060453415,1.1553500493367512,1.148480047782262,1.1415200531482697,1.1344800690809886,1.1273600657780964,1.1201800505320232,1.1129400531450908,1.105640063683192,1.0983000596364338,1.0909100572268169,1.0834900339444478,1.0760200520356495,1.0685300529003143,1.0610100428263347,1.0534500479698181,1.0458800494670868,1.0382700363794963,1.0306500494480133,1.0230000217755635,1.015330046415329,1.0076500475406647,0.9999420543511709,0.9922180424133936,0.9844760398070017,0.9767170449097952,0.9689380476872126,0.9611380497614542,0.9533150394757589,0.9454680482546488,0.9375970462958018,0.9297010451555252,0.9217810481786728,0.9138350387414297,0.9058630367120107,0.8978630503018697,0.8898370365301768,0.8817860434452692,0.873707041144371,0.8656010379393896,0.857468048731486,0.8493080387512842,0.8411240329345068,0.8329140345255533,0.8246780385573705,0.8164170384407043,0.8081300357977549,0.7998210340738297,0.7914880265792211,0.7831300298372904,0.7747490406036377,0.7663460373878479,0.757922038435936,0.7494760354359945,0.7410090317328771,0.7325230340162913,0.7240200291077296,0.7155020286639532,0.7069710344076157,0.6984270264705023,0.6898710330327352,0.6813060243924459,0.6727310319741567,0.6641480227311453,0.6555600265661875,0.646965021888415,0.6383640219767889,0.6297580301761627,0.6211460282405218,0.6125320245822271,0.6039120405912399,0.5952890167633692,0.5866610258817673,0.5780290216207504,0.5693960140148798,0.5607590277989706,0.5521190265814463,0.5434750219186147,0.5348280270894369,0.5261790255705515,0.5175280173619589,0.5088730255762736,0.5002150212725004,0.49155402183532715,0.48289202402035397,0.47422702113787335,0.4655580172936122,0.45688701421022415,0.44821201761563617,0.4395350192983945,0.43085401753584546,0.42217301577329636,0.41348901639382046,0.40480101853609085,0.39611101895570755,0.3874170159300168,0.37872301290432614,0.37002601474523544,0.3613260140021642,0.35262201229731244,0.3439150129755338,0.33520801613728207,0.32649801423152286,0.31778401633103687,0.3090670183300972,0.30034800867239636,0.2916270097096761,0.2829030081629753,0.2741760065158208,0.2654460122187932,0.25671300540367764,0.24797901138663292,0.23924200981855392,0.23050100853045782,0.22175800800323486,0.21301100899775824,0.20426400502522787,0.19551300381620726,0.18676000585158667,0.17800300319989523,0.16924300168951353,0.16048000504573187,0.1517140045762062,0.14294700448711714,0.13417700305581093,0.1254040033866962,0.11662800175448258,0.10784900064269702,0.0990686013052861,0.09028540054957072,0.08149900039037068,0.07270940020680428,0.06391680023322503,0.05568990049262842,0.04852220012495915,0.042277200147509575,0.03683619977285465,0.03209570003673434,0.027965300095578034,0.0243666999352475,0.021231199769924086,0.01849940000101924,0.016119099920615554,0.014045200077816844,0.012238199900214871,0.010663700057193637,0.009291870053857565,0.008096560020931065,0.007055050033765535,0.006147549992116789,0.005356819989780585,0.0046678199820841355,0.004067469989725699,0.003544349999477466,0.0030885299978156886,0.002691339992452413,0.0023452499881386757,0.0020436699754403285,0.0017808900059511263,0.001551899981374542,0.0013523599870192509,0.0011784899979829788,0.001026979991972136,0.0008949479961302131,0.0007798969988167906,0.000679641006475625,0.0005922750036309784,0.0005161429920311397,0.00044979999802308157,0.00039198600279632956,0.0003416049973263095,0.0002977009983927322,0.0002594409985855843,0.00022609900285412246,0.00019704399892361835,0.00017172299946347872,0.0001496559986359595,0.0001304259991835958,0.00011366800026735291,9.906300025856278e-05,8.633519973955117e-05,7.524309997582652e-05,6.55764009328171e-05,5.715190006109575e-05,4.980989979230799e-05,4.341139932269774e-05,3.783489986138496e-05,3.297500006738119e-05,2.8739500066876644e-05,2.5048100117904443e-05,2.1830999988499872e-05,1.9027200020597473e-05,1.6583499927946832e-05,1.4453799925225516e-05,1.2597600061781122e-05,1.0979900101422876e-05,9.569909934725729e-06,8.34105003377772e-06,7.270029982464621e-06,6.336559939275806e-06,5.5229699379803305e-06,4.8138699639821425e-06,4.195830001663126e-06,3.6571500459103845e-06,3.1876500277879436e-06,2.778430011100378e-06,2.4217599730036454e-06,2.1108900038295055e-06,1.8399299979895052e-06,1.6037600119034323e-06,1.397910011746717e-06,1.2184800084469316e-06,1.0621000020213007e-06,9.257830081802846e-07,8.069690030273099e-07,7.034069966493917e-07,6.131379990392816e-07,5.344560018253711e-07,4.6587299825281053e-07,4.060929962671859e-07,3.539850036797058e-07,3.085649969610434e-07,2.689740009979384e-07,2.3446300427091651e-07,2.0438200110106663e-07,1.7816099884271352e-07,1.5530400195492197e-07,1.3538100063215097e-07,1.1801399857347405e-07,7.014009698972738e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834426800409952,12.709800720214844,13.166900475819906,13.88070034980774,13.804700295130411,13.07799998919169,11.81660008430481,10.421200275421143,9.221779982248941,8.183950066566467,7.279430071512858,6.484790047009786,5.780700087547302,5.151180028915405,4.58309002717336,4.065560042858124,3.5896900296211243,3.1692200303077698,2.8154900272687278,2.5166900555292764,2.263110021750132,2.046720008055369,1.8608800172805786,1.7001500229040782,1.5600500305493672,1.4368799924850464,1.3276000221570332,1.2296100358168285,1.1404600044091542,1.058040012915929,0.9807160248359045,0.9072770128647486,0.8367760082085928,0.7684980084498724,0.7018970102071762,0.636567011475563,0.5722030103206635,0.5116110071539879,0.4571790024638176,0.4079110001524289,0.3629700019955635,0.3216650038957596,0.28346500049034756,0.24786599973837534,0.21439500028888384,0.1827199993034204,0.15256499871611595,0.12573900011678538,0.10371300019323826,0.08564320144553979,0.07082820062836011,0.05868630080173413,0.048735800199210644,0.04057439975440502,0.03388050043334564,0.0283848000690341,0.023866300005465746,0.020151000159482162,0.01709230011329055,0.014569300149256984,0.012487700131411353,0.01076540001668036,0.009329940114791194,0.008127450050475696,0.007119180091346304,0.006268400155628721,0.005540089992185433,0.00492063001729548,0.0043990200307841105,0.003956740042970826,0.0035787300439551473,0.003252800030168146,0.0029638800187967718,0.002704960041834662,0.002475490056288739,0.002270320119957129,0.002085220029888054,0.0019161500288949658,0.0017547200065261375,0.0015993700071703643,0.001448840038695683,0.001302110031247139,0.0011635200159313779,0.0010262900080609445,0.0008900660031940788,0.0007545960009641325,0.0006196600006660447,0.0005005150039020615,0.0004043500011903234,0.0003267199984596421,0.00026403999921361293,0.00021342299927103645,0.00017254000097940056,0.00013951199798611924,0.00011282599916739855,9.126079991498652e-05,7.38299992614581e-05,5.9738800094540544e-05,4.8345299849946365e-05,3.91314000201722e-05,3.167889993468028e-05,2.5650099814811256e-05,2.07720998635826e-05,1.6824599773220445e-05,1.3629600061904057e-05,1.1043100054545599e-05,8.948959930421552e-06,7.253140021627284e-06,5.879640032920482e-06,4.76703000155491e-06,3.8655899932867515e-06,3.1351200201849374e-06,2.5431000191626176e-06,2.063210028306154e-06,1.6741500038127317e-06,1.358670004947271e-06,1.1028199935481098e-06,8.952969968352894e-07,7.269380072708979e-07,5.903329925634656e-07,4.79476002605376e-07,3.8949800303574494e-07,3.1645600036730076e-07,2.5715200043426495e-07,2.0899500086102307e-07,1.6988299951966232e-07,1.38112999555536e-07,1.123009999067411e-07,8.352018336192183e-09,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708101063966751,0.9575140625238419,1.0310900658369064,1.1069300770759583,1.1846900880336761,1.2640700737635295,1.3447900811831157,1.423490087191264,1.497230072816213,1.5665900905927022,1.6320601006348927,1.694090078274409,1.7530800998210907,1.8093700806299846,1.8632800877094269,1.9150701065858204,1.964990109205246,2.0113800962766013,2.0527800917625427,2.089790105819702,2.122940103212992,2.1526900927225747,2.179460108280182,2.203610082467397,2.2254401246706643,2.2452301184336343,2.26321009794871,2.2748800913492837,2.2760300636291504,2.2674900690714517,2.2500601013501487,2.224430044492086,2.1912600795427957,2.151170035203298,2.1047200759251914,2.0524200995763144,1.9947500725587208,1.9294400612513225,1.8546100358168285,1.7714500427246094,1.6810200313727062,1.5842700203259785,1.4820400377114613,1.3750700255235035,1.2640400131543477,1.1495400071144104,1.0321000168720882,0.9202060103416443,0.8213520050048828,0.7341290016969045,0.6572670092185339,0.5896170089642206,0.5301460027694702,0.4779290035367012,0.43213900675376254,0.3920360083381335,0.3569600060582161,0.32629700501759845,0.2995060086250305,0.2761400068799655,0.25580100218455,0.23813500627875328,0.22282900537053743,0.2096020057797432,0.1982050041357676,0.1884200063844522,0.18005400523543358,0.17287500451008478,0.16667300586899123,0.1613330071171125,0.15675300483902296,0.15284200633565584,0.14951900765299797,0.1467130072414875,0.1443600058555603,0.14242400725682577,0.14087400709589323,0.13963300734758377,0.13863500704367956,0.1378490055600802,0.13724800447622934,0.13680900633335114,0.13651200383901596,0.1363390050828457,0.13627500583728155,0.13630600521961847,0.13642000406980515,0.1365140068034331,0.13649600620071092,0.1363810064891974,0.1361820064485073,0.13590600341558456,0.13556300476193428,0.1351630079249541,0.13471300651629767,0.13421700646479925,0.13368100548783937,0.13311100751161575,0.13251100480556488,0.1318830040593942,0.13123000537355742,0.13055700436234474,0.12986600523193678,0.12915800387660661,0.1284330040216446,0.1276950053870678,0.12694600348671278,0.12618800501028696,0.12541900326808295,0.1246410043289264,0.1238570058097442,0.12306700584789117,0.12226900520424049,0.12146500560144584,0.12065700503687064,0.1198460062344869,0.11902900412678719,0.11820700454215209,0.11738000561793645,0.11655200521151225,0.11572200494507949,0.11488700471818447,0.11404900501171748,0.11321000382304192,0.11236900463700294,0.11152500472962856,0.11067700448135535,0.10982900361220042,0.10898000498612721,0.10812700477739175,0.10727100384732087,0.10641200405855973,0.10555200402935346,0.1046900035192569,0.10382500352958839,0.10295600506166618,0.10208600449065368,0.1012130044400692,0.10033700366814931,0.09945740488668282,0.0985757044206063,0.09769210343559583,0.0968045045932134,0.09591300350924332,0.09501990427573521,0.09412480394045512,0.09322590380907059,0.09232310516138871,0.09141680411994457,0.09050890368719895,0.08959940324227016,0.0886863029251496,0.0877696027358373,0.08685150494178136,0.0859320027132829,0.08500890309611957,0.0840825034926335,0.08315480252106984,0.08222600258886814,0.08129390267034371,0.08035900319616,0.07942340336740017,0.07848730248709519,0.07754870255788167,0.0766079022238652,0.07566510202984016,0.07472240303953488,0.07378000331421693,0.07283560124536355,0.07188960164785385,0.07094410248100758,0.06999900316198666,0.06905220200618108,0.06810390204191208,0.06715630181133747,0.066209202632308,0.06526060154040654,0.06431060160199802,0.06335940212011337,0.06240900233387947,0.061459402553737164,0.06050830272336801,0.05955610269059738,0.05860470266391834,0.057654001750051975,0.0567019023001194,0.055748602375388145,0.05479610183586677,0.05384440099199613,0.052891301922500134,0.0519369017953674,0.05098340132584175,0.050030601831773915,0.04907640162855387,0.04812090160946051,0.04716430169840654,0.0462087020277977,0.045253801780442394,0.04429770167917013,0.04334030207246542,0.04238380088160435,0.04142810093859831,0.040471101800600685,0.03951280129452547,0.038555401687820755,0.03759870088348786,0.03664070088416338,0.03568140106896559,0.03472100136180719,0.033761500691374145,0.03280290092031161,0.03184290137141943,0.030881800844023626,0.02992150125404199,0.028962100856006145,0.028001200562963884,0.027039200843622286,0.026078000664711,0.025117600647111733,0.024155800696462393,0.02319270061949889,0.022228600612531107,0.02126540057361126,0.020302900578826666,0.01933920041968425,0.018374300406624872,0.017410300361613434,0.016447100477914017,0.015482500350723663,0.01451670021439592,0.013551800201336542,0.012587600077191988,0.011622000330438217,0.010655200108885765,0.009689240017905831,0.008724000149716934,0.007757369972144564,0.006846879958175123,0.00604326999746263,0.005334019971390565,0.00470801997774591,0.004155520000495017,0.0036678699931750693,0.0032374600414186716,0.0028575800048808255,0.0025222799934757254,0.0022263399829777577,0.0019651300099212676,0.0017345800103309255,0.001531090005300939,0.0013514700112864375,0.0011929299992819626,0.001053000014508143,0.000929485002416186,0.0008204619953176007,0.0007242320037524527,0.0006392910096716756,0.0005643150119188552,0.0004981350042119933,0.0004397189986775629,0.00038815499768437195,0.0003426390006400955,0.0003024629986612126,0.0002669979997638923,0.00023569299931599139,0.00020805999884032644,0.00018366700169281103,0.0001621350008160031,0.0001431279997632373,0.00012634900122066028,0.00011153899928710113,9.84642999052691e-05,8.6923000102009e-05,7.673489926673938e-05,6.774119962453067e-05,5.980189992745485e-05,5.279339984554099e-05,4.660640054983863e-05,4.114470023826774e-05,3.632319991690262e-05,3.206689992415098e-05,2.8309400173990678e-05,2.4992400085466215e-05,2.2064099842585467e-05,1.947899954757304e-05,1.719679994494072e-05,1.5182100090290382e-05,1.3403499830625757e-05,1.183329997426578e-05,1.0447100066812709e-05,9.223369867565149e-06,8.14298997890243e-06,7.189189962749272e-06,6.347130048804199e-06,5.603730073744373e-06,4.947430018849748e-06,4.368000039297233e-06,3.856460049670811e-06,3.4048300108224794e-06,3.0061100346756575e-06,2.6540899777198015e-06,2.343310029573331e-06,2.068920006574141e-06,1.8266700010372006e-06,1.6128000008090264e-06,1.423969990810292e-06,1.2572500054375269e-06,1.110060007173767e-06,9.801040098030474e-07,8.653659998950994e-07,7.640629983522255e-07,6.746220009290482e-07,5.956529965563581e-07,5.259310000838013e-07,4.6437100564844513e-07,4.1001899594069374e-07,3.6203000301308447e-07,3.1965799962563324e-07,2.8224699851383167e-07,2.492160030935035e-07,2.200510008284103e-07,1.9429999890500463e-07,1.7156299965866614e-07,1.514869995370797e-07,1.3376099990599263e-07,1.181100000025026e-07,8.779690692980087e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.2528558212021987,0.2655299554268519,0.2753569756944974,0.2853819752732913,0.2953789755702019,0.3053389812509219,0.3152589773138364,0.32464798043171567,0.33305197954177856,0.3405359759926796,0.3471599817276001,0.35297897706429165,0.35804397612810135,0.36240598062674206,0.3661079779267311,0.3691929777463277,0.3717029814918836,0.37364498525857925,0.3750309819976489,0.3759009862939517,0.3762899811069171,0.37623098244269687,0.3757549822330475,0.3748899847269058,0.3736639817555745,0.37209898233413696,0.37021798143784207,0.36782698333263397,0.3647239878773689,0.3609189838171005,0.35642898579438526,0.3512689893444379,0.3454589893420537,0.3390189881126086,0.3319689879814784,0.32433098802963894,0.3161259889602661,0.30731099595626193,0.29785699645678204,0.2878119970361392,0.2772189974784851,0.26612099756797153,0.2545579969882965,0.24256599818666777,0.23018099864323935,0.21743399649858475,0.20435799906651178,0.1915330005188783,0.17950600013136864,0.16823400060335794,0.15768000235160193,0.14780200148622194,0.13856499890486398,0.12993100037177405,0.12186599957446258,0.11433599951366584,0.10730999956528346,0.10075099890430768,0.0946268979460001,0.08891099939743678,0.08357939993341763,0.07860879848400752,0.07397700039048989,0.06966299811999004,0.06564659873644511,0.061909098799029984,0.0584322993333141,0.055194299668073654,0.05217469887187084,0.04935929893205563,0.04673509951680899,0.04428939986974001,0.04201059943685929,0.03988759902616342,0.03791019941369692,0.036071198992431164,0.0343635988732179,0.03277699928730726,0.031301699268321194,0.02992969937622547,0.028653599321842194,0.027466599363833666,0.02636219949151079,0.025334699389835198,0.024378499171386164,0.023488499379406374,0.022660099280377228,0.021886599560578663,0.021161599395175774,0.020481999187419813,0.019845799387743075,0.019249999585251015,0.01869039935991168,0.018164399545639753,0.017669699465235073,0.017204099489996832,0.016765499487519264,0.016352099366486073,0.015963499589512747,0.015597999561578035,0.015252499530712763,0.014925699448212981,0.014616199458638826,0.014322899281978607,0.014044599374756217,0.013781599700450897,0.013532999437302351,0.013296199341615042,0.013070499446863929,0.012855099514126778,0.01264929942165812,0.012452399513373772,0.0122637995518744,0.01208429946564138,0.011913299560546875,0.011748699626574913,0.01159019962263604,0.01143729966133833,0.01128959950680534,0.011146799428388476,0.011009899588922659,0.01087849959731102,0.010750799595067898,0.010626499463493625,0.010505499706293145,0.010387499583885074,0.010272199598451456,0.010159499555205306,0.010050599463284016,0.009945229549581805,0.009841709630563855,0.009739919565618038,0.009639699555312594,0.009540939625973502,0.009443519481768211,0.009348729625344276,0.00925637975645562,0.009164879641806086,0.009074159509812793,0.008984149588892857,0.008894779486581683,0.008805989675844709,0.008717719620714584,0.008631329673031965,0.008546669657031694,0.008462219654272,0.008377939695492387,0.00829379966792961,0.008209789792696634,0.008125879724199573,0.008043439670776328,0.007962379759798447,0.007881179607162872,0.007799839639725785,0.007718359702266753,0.007636729666652779,0.007554949649299185,0.007473019727816184,0.0073923397188385325,0.007312839656757812,0.0072330096348499255,0.007152889699985583,0.0070724797357494635,0.006991819633791844,0.0069108996540308,0.006831159737582008,0.006752509662571053,0.006673479646754761,0.006594089713568489,0.006514359770032267,0.00643431981249402,0.00635398974797378,0.006273369731691976,0.006193899743569394,0.006115499689864616,0.006036689737811685,0.0059574997673432035,0.005877939751371741,0.00579805967087547,0.005717849708162248,0.005638759816065431,0.005560699772710602,0.005482189784136911,0.005403279753712316,0.005323979809569816,0.005244319831642012,0.0051643197269489365,0.005083999751756589,0.005004789757852753,0.004926599794998765,0.0048479697822282715,0.004768929871109624,0.004689499852247536,0.00460969974907736,0.004529559868387878,0.00445049989502877,0.004372459875109295,0.004293939836012821,0.004214999886850516,0.004135649806509416,0.0040559199017783,0.0039758398197591305,0.003895409832087656,0.0038160799109997847,0.0037377598540236554,0.003658979859513541,0.0035797798773273826,0.0035001798532903194,0.003420199869045367,0.003339869901537895,0.0032605998761331043,0.003182339908865591,0.003103609875931094,0.0030244399094954133,0.0029448499359811344,0.0028648798858436444,0.0027845399260210493,0.0027038599364459515,0.002624259931811442,0.0025456699077039957,0.002466619946062565,0.0023871399268197515,0.002307249951021125,0.0022269899297195175,0.002146359959927698,0.002066809955673913,0.001988249927914391,0.0019092099779906373,0.001829739970465501,0.0017498399829491973,0.0016695599964198966,0.001588909993491446,0.0015079099975991994,0.0014279999886639416,0.0013490899873431772,0.0012697199902807672,0.0011899199841233592,0.0011125100039256115,0.001040129999940594,0.0009724739987480765,0.0009092170027239869,0.0008500769957511997,0.0007947850050792719,0.0007430930030144131,0.0006947640116171291,0.0006495809987730657,0.0006073369974425683,0.0005678430025000125,0.0005309180123731494,0.0004963950050296262,0.0004641189977216224,0.0004339430039787355,0.0004057299981165367,0.0003793519960405926,0.0003546900018894424,0.0003316320022956158,0.00031007400442225236,0.00028991900277712074,0.0002710739960699963,0.0002534550003474578,0.00023698099782147133,0.0002215790021485494,0.00020717900042654946,0.00019371500093257055,0.00018112600082531571,0.0001693559994843478,0.00015835100081555234,0.00014806200124439783,0.00013844200051001584,0.00012944699725873457,0.0001210370004021873,0.00011317300049995538,0.00010582100003375672,9.894619870465249e-05,9.251860016471862e-05,8.650870040582959e-05,8.088950077459837e-05,7.563540081415947e-05,7.072280034966146e-05,6.612939917734668e-05,6.18344993199571e-05,5.781869973967938e-05,5.406379993170655e-05,5.055290057498496e-05,4.727009976098392e-05,4.420060031407047e-05,4.133060004581542e-05,3.864689976277683e-05,3.613760024260652e-05,3.3791400104140244e-05,3.159750000728915e-05,2.9546099843476743e-05,2.7628000073794585e-05,2.5834399821178522e-05,2.4157400275726104e-05,2.258930029105007e-05,2.112299974517858e-05,1.975189995088537e-05,1.8469900169293396e-05,1.727109990194246e-05,1.6150199977952678e-05,1.5101999906619312e-05,1.4121899918488149e-05,1.3205500029774461e-05,1.2348499997945813e-05,1.154720007434662e-05,1.0797899903991492e-05,1.0097199947267654e-05,9.442069995202473e-06,8.829440048430115e-06,8.256569950996587e-06,7.720890115100095e-06,7.219979996383093e-06,6.75157999315464e-06,6.3135800398110104e-06,5.9040099813501e-06,5.521029985781449e-06,5.162889995820781e-06,4.8279999873557244e-06,4.51483996736594e-06,4.221999991690002e-06,3.9481700090012355e-06,3.692099994623277e-06,3.452649991686485e-06,3.228739975232505e-06,3.019350003796717e-06,2.823550024307527e-06,2.6404499825124126e-06,2.4692299878855315e-06,2.3091200015793825e-06,2.1593899646177306e-06,2.0193800006988263e-06,1.8884499866089755e-06,1.7660100013472402e-06,1.6515200040127336e-06,1.5444500055158035e-06,1.444319982131977e-06,1.350689994220981e-06,1.2631300023713266e-06,1.1812499944123072e-06,1.1046799954783637e-06,1.0330799966595805e-06,9.661149960038529e-07,9.034949925990077e-07,8.44936996221198e-07,7.901749986179615e-07,7.38964004654008e-07,6.910729932011842e-07,6.462869919232617e-07,6.044049977541969e-07,5.652379968523746e-07,5.286109872789287e-07,4.94356986754004e-07,4.623249978408239e-07,4.323679997734568e-07,4.0435399976483194e-07,3.781549982780537e-07,3.536549992115094e-07,3.307429992105426e-07,3.0931500087187186e-07,2.892759998947743e-07,2.7053699843312035e-07,2.530109976343435e-07,2.3662099598216932e-07,2.2129400060559115e-07,2.069599993603788e-07,1.935540000867301e-07,1.810170005001055e-07,1.692930015432618e-07,1.5832799959980548e-07,1.480739998764117e-07,1.384839987868721e-07,1.2951500139024574e-07,1.2112799889033946e-07,1.1328400025452841e-07,1.0594800059493537e-07,3.3768769114317365e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.3640321493148804,1.4751599927743275,1.5928399960199993,1.7053600052992504,1.8187900086243947,1.933129996061325,2.0483700136343637,2.164590001106262,2.281839986642202,2.4001200000445047,2.5194299618403115,2.6397700111071267,2.761140008767446,2.883530020713806,3.0069399873415628,3.1313699881235757,3.2568299969037375,3.3831300139427185,3.5101199547449746,3.637810011704763,3.7661799987157187,3.895240008831024,4.0249800483385725,4.155389944712321,4.2864900430043535,4.418259978294373,4.550719976425171,4.680690010388692,4.805050015449524,4.923800071080525,5.036950031916301,5.144509951273601,5.246499975522359,5.3429200649261475,5.433789968490601,5.519110004107158,5.598899960517883,5.672469973564148,5.739120006561279,5.798870046933492,5.851729949315389,5.897719979286194,5.93684999148051,5.969120025634766,5.994569977124532,6.0131999254226685,6.0250100294748945,6.033329963684082,6.04144008954366,6.049360036849976,6.057090083758037,6.064620057741801,6.071950038274129,6.079089959462483,6.086030006408691,6.092769980430603,6.099329948425293,6.105680068333943,6.111840009689331,6.117800037066142,6.123570005098979,6.129140019416809,6.134519974390666,6.139699935913086,6.144680023193359,6.149470130602519,6.154070019721985,6.158469994862874,6.162649989128113,6.166620055834453,6.170390009880066,6.1739299694697065,6.17727001508077,6.180389920870463,6.183310031890869,6.186019976933797,6.188519994417827,6.190790017445882,6.192830006281535,6.194640000661214,6.196209987004598,6.197550018628438,6.198659936587016,6.199529965718587,6.200170000394185,6.20058000087738,6.20075003306071,6.200780034065247,6.200730045636495,6.200609962145488,6.200409968694051,6.200149933497111,6.199820041656494,6.199420015017192,6.198939919471741,6.198399980862935,6.1977799733479815,6.1970899899800616,6.196329951286316,6.195500095685323,6.194590051968892,6.19363001982371,6.192589998245239,6.191480000813802,6.190300027529399,6.189040025075276,6.187719941139221,6.186330000559489,6.184859951337178,6.1833300193150835,6.181740005811055,6.180070002873738,6.178329984347026,6.176520069440206,6.174649953842163,6.172700007756551,6.170680006345113,6.1686000029246015,6.166450023651123,6.164230108261108,6.161950031916301,6.159589966138204,6.157159964243571,6.154669960339864,6.152109980583191,6.1494700113932295,6.146780014038086,6.144020001093547,6.141190052032471,6.138289968172709,6.135319987932841,6.132290005683899,6.129189968109131,6.126009941101074,6.122770031293233,6.119470079739888,6.116099993387858,6.112660010655721,6.10915994644165,6.105589946111043,6.101939996083577,6.098230044047038,6.094449957211812,6.090609947840373,6.086690068244934,6.082719961802165,6.078669985135396,6.074560006459554,6.070380091667175,6.066130002339681,6.06181005636851,6.057419935862224,6.0529699722925825,6.048449993133545,6.043859998385112,6.039209961891174,6.0344899495442705,6.029700040817261,6.024840037027995,6.019909977912903,6.014919996261597,6.009849985440572,6.004730025927226,5.9995399713516235,5.994279940923055,5.98895001411438,5.983559966087341,5.978099981943767,5.972569982210795,5.966970006624858,5.961309949556987,5.955589969952901,5.9497999747594195,5.943950057029724,5.938029964764913,5.932039976119995,5.925990025202434,5.919869979222615,5.9136799573898315,5.907430013020833,5.901120026906331,5.894750038782756,5.888310035069783,5.881799976030986,5.875230034192403,5.868589957555135,5.861889998118083,5.855120023091634,5.848299980163574,5.841410001118978,5.834449966748555,5.827440023422241,5.8203500509262085,5.813209970792134,5.805999954541524,5.798720002174377,5.791380047798157,5.783989985783895,5.776529987653096,5.769010027249654,5.761420011520386,5.753769954045613,5.746060013771057,5.738289952278137,5.73044999440511,5.72254999478658,5.7145899931589765,5.706569949785869,5.698490063349406,5.69035001595815,5.682139992713928,5.673869967460632,5.665539979934692,5.657150030136108,5.648700038592021,5.640190005302429,5.6316200494766235,5.622989972432454,5.614300012588501,5.605549971262614,5.59672999382019,5.587850054105123,5.578919967015584,5.569919983545939,5.560870051383972,5.551760037740071,5.542579968770345,5.533350030581157,5.524060010910034,5.5147000551223755,5.5052900314331055,5.495810031890869,5.486280004183452,5.476699948310852,5.4670499960581465,5.457350015640259,5.447580019632976,5.437789996465047,5.4280299345652265,5.4182798862457275,5.40853997071584,5.398830016454061,5.3891299565633135,5.379450003306071,5.3697900374730425,5.360139966011047,5.350520014762878,5.340909997622172,5.331319967905681,5.321739951769511,5.312190016110738,5.302650014559428,5.29312006632487,5.283619999885559,5.274130026499431,5.264660040537517,5.255209922790527,5.24577001730601,5.236349940299988,5.22694996992747,5.217569986979167,5.208200057347615,5.198849995930989,5.189520041147868,5.180200020472209,5.170899987220764,5.161619981129964,5.152350028355916,5.143099904060364,5.133870005607605,5.124649961789449,5.11546003818512,5.106269995371501,5.097109993298848,5.087959965070088,5.078830003738403,5.06970997651418,5.060610016187032,5.051529963811238,5.04247001806895,5.033420046170552,5.024379928906758,5.015369971593221,5.006369948387146,4.997379978497823,4.988409956296285,4.979460040728251,4.970530033111572,4.961609999338786,4.952709952990214,4.943820039431254,4.934949994087219,4.926090041796367,4.9172600110371905,4.908429980278015,4.899630069732666,4.89083997408549,4.882060011227925,4.873300035794576,4.864559968312581,4.855829993883769,4.84712000687917,4.838429967562358,4.829750100771586,4.821080009142558,4.812440037727356,4.803799986839294,4.79518993695577,4.786590099334717,4.778000036875407,4.769430001576741,4.760870019594829,4.752339959144592,4.743809938430786,4.735300024350484,4.726810018221538,4.718330065409343,4.709869980812073,4.701429963111877,4.692989945411682,4.684580008188884,4.6761800448099775,4.667790015538533,4.659419973691304,4.65106999874115,4.642730037371318,4.634400010108948,4.626089970270793,4.617799957593282,4.609520037968953,4.601249972979228,4.592999974886577,4.58477000395457,4.576539993286133,4.568339943885803,4.560149987538655,4.55196996529897,4.54381004969279,4.535670002301534,4.527539968490601,4.519420027732849,4.511319994926453,4.503230015436809,4.495160023371379,4.487100084622701,4.479060053825378,4.471029957135518,4.4630100329717,4.455010016759236,4.4470300277074175,4.439060012499492,4.431099971135457,4.423159996668498,4.41522999604543,4.407319982846578,4.3994200229644775,4.391529997189839,4.3836599588394165,4.375799973805745,4.367959976196289,4.360129912694295,4.352319995562236,4.3445199728012085,4.3367399374643965,4.328959941864014,4.321209987004598,4.313459992408752,4.305729985237122,4.298019965489705,4.290319959322612,4.282630046208699,4.27495002746582,4.267289956410726,4.259649991989136,4.252020080884297,4.2444000244140625,4.23678998152415,4.229199926058452,4.221620003382365,4.214060028394063,4.206509987513225,4.19897997379303,4.191449960072835,4.183939973513286,4.17645001411438,4.168969949086507,4.1615000168482466,4.154039978981018,4.146600008010864,4.139170010884603,4.131760001182556,4.124359965324402,4.116969982783,4.1095900138219195,4.102230032285054,4.094880024592082,4.087549924850464,4.0802299578984575,4.072920004526774,4.065630038579305,4.0583399931589765,4.051070014635722,4.043819983800252,4.036580006281535,4.0293500026067095,4.022129972775777,4.014929970105489,4.007740020751953,4.000560025374095,3.9933899641036987,3.986240009466807,3.979099988937378,3.9719799955685935,3.964869976043701,3.957769989967346,3.9506799777348838,3.9435999989509583,3.9365400075912476,3.929490009943644,3.9224599798520408,3.9154299894968667,3.908419966697693,3.901419977347056,3.8944400350252786,3.887470006942749,3.880500018596649,3.8735600312550864,3.8666199843088784,3.85970002412796,3.8527899781862893,3.845889985561371,3.8389999866485596,3.8321299950281777,3.8252699772516885,3.8184200127919516,3.811589996019999,3.804759979248047,3.797950029373169,3.791149993737539,3.784370005130768,3.777590036392212,3.770829975605011,3.764080007870992,3.7573400139808655,3.7506100138028464,3.7438999811808267,3.7372000018755593,3.7305099964141846,3.723830004533132,3.717170000076294,3.710509995619456,3.7038699785868325,3.6972400148709617,3.690629998842875,3.684019982814789,3.677429993947347,3.670840005079905,3.664270023504893,3.6577200094858804,3.651169995466868,3.6446400086085,3.6381100018819175,3.631600042184194,3.625099996725718,3.6186100045839944,3.6121399799982705,3.605669995148977,3.5992199977238974,3.59277997414271,3.5863499840100608,3.5799300273259482,3.5735299785931907,3.567129969596863,3.560749967892965,3.5543799996376038,3.5480200250943503,3.5416699846585593,3.5353300174077353,3.529010017712911,3.522689998149872,3.516390045483907,3.51010000705719,3.503819982210795,3.4975499908129373,3.491289973258972,3.488159994284312};
    C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.4800931215286255,4.563908696174622,4.607269088427226,4.680289109547933,4.757159074147542,4.837888995806376,4.9224690198898315,5.007549126942952,5.0897791385650635,5.169159173965454,5.245689233144124,5.319379250208537,5.3902192910512285,5.458209196726481,5.523349324862163,5.5856393575668335,5.645089348157247,5.702199339866638,5.757489363352458,5.810959378878276,5.862599492073059,5.912419517834981,5.960409482320149,6.0065895318984985,6.050939559936523,6.093459566434224,6.134169618288676,6.172779520352681,6.209039568901062,6.242929657300313,6.274469653765361,6.303649663925171,6.330479780832927,6.354949712753296,6.377049843470256,6.396809816360474,6.4141998291015625,6.429729859034221,6.443859855333964,6.456599831581116,6.467959801355998,6.477919936180115,6.486499945322673,6.493679920832316,6.4994800090789795,6.503889958063762,6.506900032361348,6.509179949760437,6.511349995930989,6.513419985771179,6.515379985173543,6.517250021298726,6.519009947776794,6.520669897397359,6.522220015525818,6.523679971694946,6.525030016899109,6.5262999931971235,6.527519981066386,6.528679966926575,6.52977995077769,6.530830025672913,6.531820098559062,6.532749970753987,6.533629973729451,6.534440040588379,6.535210013389587,6.535919984181722,6.536580006281535,6.5371900002161665,6.537749965985616,6.538259983062744,6.538720051447551,6.539129972457886,6.539479931195577,6.539789954821269,6.540050029754639,6.540279905001323,6.5404999653498335,6.5406999985377,6.540899991989136,6.541079998016357,6.541249990463257,6.541409969329834,6.541550000508626,6.541689912478129,6.541809995969136,6.5419299602508545,6.54203995068868,6.542140046755473,6.542240023612976,6.54233992099762,6.54243004322052,6.5425099929173784,6.542590022087097,6.542659958203633,6.54272989432017,6.542790015538533,6.542849977811177,6.5429099798202515,6.542950073877971,6.54298992951711,6.543030063311259,6.543069998423259,6.543090025583903,6.5431199471155805,6.543129960695903,6.543149987856547,6.543150067329407,6.5431599617004395,6.543150027592977,6.543139894803365,6.543130000432332,6.543110013008118,6.543089985847473,6.5430599848429365,6.543020009994507,6.542979995409648,6.542939941088359,6.542889952659607,6.542839964230855,6.542770028114319,6.542710065841675,6.542640010515849,6.54255998134613,6.542479991912842,6.542399962743123,6.542309959729512,6.542209943135579,6.542110045750936,6.541999975840251,6.541889985402425,6.541770060857137,6.54164997736613,6.541519999504089,6.54138998190562,6.541260004043579,6.541109999020894,6.540970007578532,6.540820042292277,6.54065998395284,6.5404999653498335,6.540329972902934,6.540149966875712,6.539979934692383,6.5398000081380205,6.539610028266907,6.5394099950790405,6.539209961891174,6.539010047912598,6.538799961407979,6.538589994112651,6.538369973500569,6.538139979044597,6.537909984588623,6.53767991065979,6.537440101305644,6.5371900002161665,6.536939978599548,6.5366900364557905,6.53643000125885,6.536159992218018,6.535889983177185,6.535620013872783,6.535339991251628,6.53505007425944,6.534759918848674,6.534469962120056,6.534160017967224,6.533859968185425,6.533549984296163,6.533229947090149,6.532909909884135,6.532580018043518,6.532250006993611,6.531909982363383,6.531570037206014,6.531230052312215,6.530870079994202,6.530519962310791,6.530150016148885,6.529789924621582,6.529420057932536,6.5290400584538775,6.528650005658467,6.52827000617981,6.527869979540507,6.527470072110494,6.527070005734761,6.526660005251567,6.526249925295512,6.525830030441284,6.525410056114197,6.524980028470357,6.524540026982625,6.524109999338786,6.523659984270732,6.52321994304657,6.5227599541346235,6.522299885749817,6.52184001604716,6.521369934082031,6.52088995774587,6.520409941673279,6.519929965337117,6.519439975420634,6.518939971923828,6.5184400876363116,6.517939964930217,6.5174299875895185,6.516909996668498,6.5163900057474775,6.515870054562886,6.515340010325114,6.514799912770589,6.514260013898213,6.513709982236226,6.513159990310669,6.512609998385112,6.512039979298909,6.51147997379303,6.510900060335795,6.510329961776733,6.509750008583069,6.509160041809082,6.508570035298665,6.507969975471497,6.507370034853618,6.506770054499309,6.506149967511495,6.505539933840434,6.504909912745158,6.504290024439494,6.503660003344218,6.50301996866862,6.5023800532023115,6.50173004468282,6.5010799964269,6.50043002764384,6.499780019124349,6.499129970868428,6.498480002085368,6.497829993565877,6.497179985046387,6.4965299765268965,6.495880047480266,6.495229999224345,6.494579990704854,6.493929982185364,6.493280013402303,6.4926300048828125,6.491979996363322,6.491329948107402,6.490679979324341,6.49003001054128,6.489389975865682,6.4887400070826216,6.488089958826701,6.48743999004364,6.48678994178772,6.486139973004659,6.4854899644851685,6.484839955965678,6.48419992129008,6.483549952507019,6.482899943987529,6.482249935468038,6.481600006421407,6.480950037638347,6.480310042699178,6.479660073916118,6.479009985923767,6.478360056877136,6.477720022201538,6.477070013682048,6.476420005162557,6.475769996643066,6.475120027860005,6.474479953447978,6.473829944928487,6.473180015881856,6.472530047098796,6.471890012423198,6.471240003903707,6.470589955647786,6.469950040181478,6.469299952189128,6.468649943669637,6.468009988466899,6.467360019683838,6.4667099714279175,6.466070016225179,6.465419967969258,6.464769999186198,6.4641299645106,6.463479995727539,6.462829987208049,6.46218999226888,6.46154002348582,6.460889935493469,6.460249940554301,6.45959997177124,6.458959976832072,6.458310008049011,6.457669973373413,6.457019964853923,6.456370035807292,6.455730001131694,6.455079992612203,6.454439997673035,6.453789949417114,6.453150073687236,6.452499985694885,6.4518600304921465,6.451209982236226,6.450570027033488,6.449920018513997,6.449279983838399,6.448630015055339,6.44799002011617,6.44734005133311,6.446699937184651,6.4460500081380205,6.4454100131988525,6.444759964942932,6.444120009740193,6.443470001220703,6.442830006281535,6.442190011342366,6.441539923350017,6.440899968147278,6.440250078837077,6.439610004425049,6.438969969749451,6.43831996122996,6.4376799662907915,6.437030037244161,6.436390121777852,6.435750087102254,6.435099959373474,6.434459924697876,6.4338200489679975,6.433170040448506,6.4325300852457685,6.43189001083374,6.43123996257782,6.430599927902222,6.429960052172343,6.429310003916423,6.428670008977254,6.428029974301656,6.427389979362488,6.426740050315857,6.426100015640259,6.4254599412282305,6.42481005191803,6.4241699775060015,6.4235299825668335,6.4228899876276655,6.422250032424927,6.421599984169006,6.420959949493408,6.4203200340271,6.4196799993515015,6.4190400044123335,6.418389995892842,6.417749961217244,6.417110006014506,6.416470011075337,6.415829976399739,6.415189981460571,6.41454005241394,6.413900017738342,6.413260022799174,6.412619988123576,6.411979993184407,6.411339998245239,6.410700003306071,6.41005007425944,6.409410039583842,6.408770044644673,6.408129970232646,6.407489975293477,6.406850020090739,6.4062100648880005,6.405569990475972,6.404929995536804,6.404290000597636,6.403650005658467,6.403010010719299,6.402370015780131,6.401729981104533,6.401089986165364,6.400449991226196,6.3998100360234575,6.399170001347859,6.398530006408691,6.397890011469523,6.397249976793925,6.3966100215911865,6.395969986915588,6.39533003171285,6.394689957300822,6.3940500020980835,6.393410046895345,6.392769972483317,6.3921299775441485,6.3914899826049805,6.3908499876658125,6.390209992726644,6.389580051104228,6.38894001642863,6.388299981753032,6.387659986813863,6.387020071347554,6.386380036671956,6.385740001996358,6.38510000705719,6.384469985961914,6.383829991022746,6.383189956347148,6.382549961407979,6.38191004594167,6.381269971529643,6.380639950434367,6.379999995231628,6.37936000029246,6.378719965616862,6.378079970677693,6.377449989318848,6.3768099546432495,6.376169999440511,6.375530004501343,6.374900062878926,6.374259948730469,6.37362003326416,6.372979998588562,6.372349977493286,6.371709982554118,6.371069987614949,6.3704400062561035,6.369800051053365,6.369159976641337,6.368519941965739,6.367890000343323,6.367250005404155,6.366610050201416,6.36598002910614,6.365340034166972,6.364699959754944,6.364070097605388,6.363429983456929,6.362800041834514,6.362159927686055,6.361519972483317,6.360890030860901,6.360249996185303,6.359610040982564,6.358980059623718,6.35834002494812,6.357709964116414,6.357070008913676,6.3564399878184,6.3557999928792315,6.3551599979400635,6.354530056317647,6.35388998190562,6.353260080019633,6.352620005607605,6.351989984512329,6.351349989573161,6.350720047950745,6.3500800132751465,6.349449992179871,6.3488099575042725,6.348179976145427,6.347539981206258,6.346910039583842,6.346269925435384,6.3456400235493975,6.344999988873799,6.344370007514954,6.343739986419678,6.34309995174408,6.342469970385234,6.342150052388509};
    //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174860845009486,0.6330969432989756,0.6434339483579,0.6587269405523936,0.674825926621755,0.6917289396127065,0.7094389349222183,0.7272539287805557,0.7444709440072378,0.7610909342765808,0.7771139393250147,0.7925389359394709,0.8073669423659643,0.8215979486703873,0.8352319498856863,0.8482709527015686,0.8607139587402344,0.8726669549942017,0.8842359632253647,0.8954239586989085,0.9062289545933405,0.9166519542535146,0.9266929626464844,0.9363519648710886,0.9456289609273275,0.954522967338562,0.9630369742711385,0.971111978093783,0.9786919752756754,0.9857789675394694,0.9923729747533798,0.9984729836384455,1.0040799776713054,1.0091899832089741,1.013809969027837,1.0179299811522167,1.0215599934260051,1.0247999926408131,1.0277499854564667,1.0304099818070729,1.0327699879805248,1.0348399976889293,1.0366299947102864,1.0381199816862743,1.0393199920654297,1.0402299960454304,1.0408499936262767,1.0413100024064381,1.0417500138282776,1.0421800116697948,1.04257998863856,1.0429499944051106,1.0433099965254466,1.0436400175094604,1.0439599752426147,1.0442500114440918,1.0445200006167095,1.0447700023651123,1.0450099905331929,1.045240004857381,1.0454599956671398,1.0456699927647908,1.0458600123723347,1.0460500121116638,1.0462200045585632,1.046379993359248,1.0465200046698253,1.0466599961121876,1.0467899839083354,1.0469000140825908,1.0470100045204163,1.0470999975999196,1.0471799969673157,1.0472600162029266,1.047320008277893,1.0473699967066448,1.047409991423289,1.0474499960740407,1.0474799970785778,1.0475099980831146,1.047540009021759,1.0475600063800812,1.0475899974505107,1.0476099948088329,1.0476199984550476,1.0476400057474773,1.047650009393692,1.0476700166861217,1.047679990530014,1.047679990530014,1.0476900041103363,1.047700007756551,1.047709991534551,1.047709991534551,1.0477200051148732,1.0477200051148732,1.0477200150489807,1.0477199951807659,1.0477200051148732,1.0477200051148732,1.0477199852466583,1.0477100014686584,1.0477099816004436,1.0476999978224437,1.0476900041103363,1.0476900140444438,1.0476800004641216,1.0476699968179066,1.047659993171692,1.047650009393692,1.0476300021012623,1.0476199984550476,1.0476000010967255,1.0475899875164032,1.047570010026296,1.0475500027338664,1.0475300053755443,1.0475099782148998,1.0474799970785778,1.047459989786148,1.047439992427826,1.0474100013573964,1.0473800003528595,1.047359973192215,1.0473300019900005,1.047299971183141,1.0472699999809265,1.0472299953301747,1.0471999943256378,1.047169993321101,1.047130008538564,1.047100007534027,1.0470600028832753,1.0470199882984161,1.0469799935817719,1.04693998893102,1.0468999942143757,1.0468600193659465,1.0468100011348724,1.0467699964841206,1.0467200080553691,1.0466799835364025,1.0466300050417583,1.046580006678899,1.0465299983819325,1.046480009953181,1.0464300215244293,1.0463800132274628,1.0463200112183888,1.0462700029214222,1.046209990978241,1.046150008837382,1.0460899869600933,1.0460399985313416,1.0459699928760529,1.045909990866979,1.0458499987920125,1.0457899967829387,1.0457200010617573,1.0456599990526836,1.0455899834632874,1.045520007610321,1.045460005601247,1.0453899999459584,1.0453100005785625,1.045240004857381,1.0451699992020924,1.0450899998346965,1.0450200041135151,1.0449399948120117,1.0448599855105083,1.0447799861431122,1.0446999967098236,1.044620007276535,1.044540007909139,1.044450004895528,1.0443699955940247,1.0442799925804138,1.0441999832789104,1.0441099901994069,1.044020007054011,1.0439299941062927,1.0438399811585743,1.043750007947286,1.0436599949995677,1.043560008207957,1.043469985326131,1.0433699985345204,1.0432799955209096,1.0431800087292988,1.0430799921353657,1.0429799954096477,1.0428799986839294,1.0427799920241039,1.042669991652171,1.042569984992345,1.042469988266627,1.042360007762909,1.0422499974568684,1.042140007019043,1.04203000664711,1.0419199963410695,1.0418099959691365,1.0416999955972035,1.041590005159378,1.0414699912071228,1.0413600007692974,1.0412399967511494,1.0411200026671092,1.0409999787807465,1.0408799946308136,1.0407600104808807,1.040640006462733,1.040520002444585,1.04039000471433,1.0402599970499675,1.0401399930318196,1.0400100151697795,1.0398800075054169,1.0397499998410542,1.039620002110799,1.0394899944464366,1.0393500129381816,1.0392199854056041,1.0390799939632416,1.038950006167094,1.0388099948565166,1.038670023282369,1.0385300020376842,1.0383900006612141,1.0382500092188518,1.0381099979082744,1.0379599928855896,1.0378200113773346,1.0376700063546498,1.0375299950440724,1.0373800198237102,1.0372299949328105,1.0370800197124481,1.0369400084018707,1.0367899934450786,1.0366399983565013,1.036490023136139,1.0363399883111317,1.0361899932225545,1.0360500017801921,1.0359000066916149,1.0357500116030376,1.035599986712138,1.0354599952697754,1.0353099902470906,1.0351600050926208,1.0350100199381511,1.034859985113144,1.0347199738025665,1.0345699886480968,1.0344200034936268,1.0342700084050496,1.0341199934482574,1.0339799920717876,1.0338300069173176,1.0336800316969554,1.0335300068060558,1.0333900153636932,1.033240020275116,1.0330900053183238,1.032940000295639,1.032800018787384,1.0326499938964844,1.0325000087420146,1.032349983851115,1.03221000234286,1.0320599973201752,1.0319100121657054,1.0317599872748058,1.0316199958324432,1.031470000743866,1.0313199957211812,1.0311700105667114,1.031029999256134,1.0308799942334492,1.030730019013087,1.0305900077025096,1.0304400126139324,1.0302899877230327,1.0301399926344554,1.0300000210603077,1.0298500061035156,1.0297000110149384,1.0295600096384685,1.0294100145498912,1.0292599896589916,1.0291100045045216,1.0289700130621593,1.0288200080394745,1.0286700129508972,1.0285300016403198,1.0283800065517426,1.0282300015290577,1.0280900200208027,1.0279400050640106,1.0277899901072185,1.0276400049527485,1.0275000135103862,1.0273499985535939,1.0272000034650166,1.0270600120226543,1.026910016934077,1.0267599920431774,1.0266200105349224,1.02646999557813,1.0263200004895527,1.0261799891789753,1.0260300139586132,1.0258800188700359,1.025739997625351,1.0255899926026661,1.0254399975140889,1.025299996137619,1.0251500109831493,1.025009999672572,1.024860014518102,1.0247099896272023,1.0245700081189473,1.0244200030962627,1.0242699980735779,1.024129996697108,1.0239800016085308,1.0238300164540608,1.023689995209376,1.0235400001207988,1.0234000086784363,1.0232500036557515,1.0230999986330669,1.0229600071907043,1.0228100021680195,1.0226699809233348,1.02252001563708,1.0223700006802876,1.0222300092379253,1.0220800042152405,1.021939992904663,1.0217899978160858,1.021640012661616,1.021500011285146,1.0213499963283539,1.0212100048859913,1.0210599899291992,1.0209100147088368,1.020769993464152,1.0206199785073597,1.0204799969991047,1.0203300019105275,1.0201800068219502,1.0200400153795879,1.0198900004227955,1.0197499990463257,1.019600013891856,1.019459992647171,1.0193099975585938,1.019169996182124,1.019020011027654,1.0188699861367543,1.0187300046284993,1.0185799996058147,1.0184400081634521,1.0182899832725525,1.0181500017642975,1.0179999768733978,1.0178599953651428,1.017709990342458,1.0175600051879883,1.0174199938774109,1.0172699987888336,1.0171299974123638,1.0169800023237865,1.0168400009473164,1.0166899859905243,1.0165499945481618,1.0163999994595845,1.016259988149007,1.0161099930604298,1.01596999168396,1.0158200065294902,1.0156799852848053,1.0155300001303356,1.0153900186220806,1.0152400135993958,1.0150999824206035,1.014950007200241,1.0148099958896637,1.014659990866979,1.0145199795564015,1.0143700043360393,1.0142299830913544,1.0140799780686696,1.0139399866263072,1.01378999153773,1.0136500000953674,1.0134999950726826,1.0133600036303203,1.013210008541743,1.013070007165273,1.0129199922084808,1.0127800007661183,1.012630005677541,1.0124899943669636,1.0123499830563862,1.012200007836024,1.0120599865913391,1.0119099915027618,1.011769990126292,1.0116200149059296,1.0114800135294597,1.0113299985726674,1.0111899971961975,1.0110399822394054,1.0109000007311504,1.0107600092887878,1.0106099943319957,1.0104700128237407,1.0103200177351634,1.0101799964904785,1.0100300113360088,1.0098900000254314,1.0097500085830688,1.0096000134944916,1.0094599922498066,1.009309987227122,1.0091699957847595,1.0090200106302898,1.0088799993197124,1.008739988009135,1.0085899929205577,1.0084500114123027,1.0082999964555104,1.008160005013148,1.0080199837684631,1.0078699986139934,1.007729987303416,1.0075800120830536,1.0074400007724762,1.0073000093301137,1.007150004307429,1.0070099929968517,1.0068599780400593,1.0067200064659119,1.0065799951553345,1.0064300000667572,1.0062899887561798,1.0061500072479248,1.0060000121593475,1.0058599909146626,1.0057100057601929,1.0055700143178303,1.005430003007253,1.0052800178527832,1.0051399966080983,1.005000005165736,1.0048500001430511,1.0047100087006886,1.0045700073242188,1.004420002301534,1.0042800108591716,1.0041399995485942,1.003990004460017,1.0038500030835469,1.003710001707077,1.0035599768161774,1.00342000524203,1.003270000219345,1.0031300087769826,1.0029899875322978,1.0028499861558278,1.002700001001358,1.0025600095589955,1.002419998248418,1.0022700031598408,1.002130001783371,1.0019900004069011,1.0018400053183238,1.0017000039418538,1.001560002565384,1.001409997542699,1.0012699862321217,1.0012000103791554};
    //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194267277916273,0.18438099945584932,0.18694199994206429,0.18960299963752428,0.1924040007094542,0.19534699991345406,0.1984309988717238,0.20153299843271574,0.2045300006866455,0.20742199942469597,0.21020800123612085,0.2128900003929933,0.2154660001397133,0.21793799847364426,0.22030699998140335,0.22257000083724657,0.22472899903853735,0.22680100177725157,0.22880699982245764,0.23074500014384589,0.23261500149965286,0.2344179997841517,0.2361540012061596,0.23782399917642275,0.23942700028419495,0.24096399918198586,0.2424319994946321,0.2438229980568091,0.24512699991464615,0.2463459993402163,0.24747799833615622,0.24852300062775612,0.24948099876443544,0.25035199771324795,0.2511370008190473,0.2518339976668358,0.2524459982911746,0.2529889990886052,0.25348200152317685,0.2539240022500356,0.2543149987856547,0.25465400020281476,0.25494199991226196,0.255180003742377,0.2553660000363986,0.25550100207328796,0.2555849974354108,0.2556410034497579,0.2556940019130707,0.25574200103680295,0.2557860016822815,0.25582699726025265,0.2558639993270238,0.25589799632628757,0.25592900067567825,0.2559550032019615,0.2559779981772105,0.2559969996412595,0.2560140018661817,0.25602900236845016,0.2560429995258649,0.25605400154987973,0.2560630018512408,0.25606900205214816,0.25607399890820187,0.25607699900865555,0.25607799738645554,0.25607699900865555,0.25607399890820187,0.25607000042994815,0.25606400271256763,0.25605500241120654,0.2560439979036649,0.25603300084670383,0.2560179978609085,0.25600199898084003,0.25598400086164474,0.2559650018811226,0.25594599545001984,0.2559260005752246,0.2559049998720487,0.25588399916887283,0.2558640018105507,0.25584299862384796,0.25582200040419895,0.2557979996005694,0.25577500214179355,0.255751999715964,0.25572900225718814,0.2557059998313586,0.2556829998890559,0.2556599974632263,0.2556370000044505,0.25561299671729404,0.25558699915806454,0.2555609966317813,0.2555360049009323,0.25551000485817593,0.25548499822616577,0.2554590006669362,0.2554329956571261,0.25540799895922345,0.2553820013999939,0.2553569972515106,0.25533099969228107,0.2553060029943784,0.25527999301751453,0.25525300453106564,0.25522500028212863,0.2551970010002454,0.2551689992348353,0.2551409999529521,0.25511299818754196,0.2550850013891856,0.25505700210730237,0.25502900034189224,0.2550010035435359,0.25497300426165265,0.25494500001271564,0.2549169957637787,0.25488900393247604,0.25485900044441223,0.254829004406929,0.2547980025410652,0.2547679990530014,0.2547370021541913,0.2547069986661275,0.2546760017673175,0.25464599827925366,0.2546149988969167,0.25458500037590664,0.25455399602651596,0.25452399998903275,0.25449299812316895,0.25446099787950516,0.25442800174156827,0.2543950006365776,0.25436200201511383,0.25432900091012317,0.25429599980513257,0.2542629987001419,0.25423000007867813,0.25419699897368747,0.2541640003522237,0.2541310017307599,0.2540980006257693,0.25406499703725177,0.254031998415788,0.25399800141652423,0.25396300107240677,0.2539270023504893,0.2538919970393181,0.25385599831740063,0.25382100045681,0.25378500173489255,0.2537499989072482,0.25371500104665756,0.2536789998412132,0.2536439970135689,0.25360800077517826,0.2535730004310608,0.25353699674208957,0.25350099553664523,0.2534630025426547,0.2534250045816104,0.2533870041370392,0.25334900120894116,0.25331100076436996,0.25327300528685254,0.25323499987522763,0.2531980002919833,0.253160002330939,0.2531220018863678,0.2530840039253235,0.25304600099722546,0.2530069996913274,0.2529670000076294,0.25292599697907764,0.25288600226243335,0.25284499923388165,0.2528049995501836,0.2527649998664856,0.2527239993214607,0.2526839996377627,0.25264399995406467,0.2526029994090398,0.2525629997253418,0.2525230000416438,0.2524819994966189,0.2524410014351209,0.2523980016509692,0.25235499689976376,0.25231200208266574,0.25226999819278717,0.2522270008921623,0.25218399862448376,0.25214099884033203,0.2520979990561803,0.2520560026168823,0.2520129978656769,0.25197000056505203,0.25192799667517346,0.25188300013542175,0.25183800359567005,0.2517929971218109,0.2517479980985324,0.2517020031809807,0.25165700167417526,0.25161200513442356,0.25156699617703754,0.251521997153759,0.2514759972691536,0.25143099824587506,0.25138600418965024,0.2513410026828448,0.2512960011760394,0.2512489954630534,0.2512020021677017,0.2511540005604426,0.25110600143671036,0.25105899820725125,0.2510110040505727,0.2509630024433136,0.2509159992138545,0.25086799760659534,0.2508199984828631,0.25077300270398456,0.2507249986131986,0.2506780003507932,0.2506299962600072,0.250580998758475,0.25053100287914276,0.2504810020327568,0.25043099870284397,0.250380997856458,0.25033099949359894,0.25028100113073987,0.250230997800827,0.2501810019214948,0.2501310010751088,0.25007999936739606,0.2500299985210101,0.24997999891638756,0.2499300017952919,0.24988100056846937,0.24983100096384683,0.24978100135922432,0.24973100051283836,0.2496809996664524,0.2496310000618299,0.24958100045720735,0.2495309996108214,0.24948100000619888,0.24943099915981293,0.24938099831342697,0.24933100119233131,0.2492820012072722,0.24923199911912283,0.2491819995145003,0.24913199990987778,0.24908199906349182,0.2490319994588693,0.24898300071557364,0.24893299986918768,0.24888300150632858,0.24883299941817918,0.2487830010553201,0.24873399982849756,0.2486840027074019,0.24863400061925253,0.24858500063419342,0.24853499978780746,0.24848499769965807,0.2484350005785624,0.24838600183526674,0.24833599850535393,0.24828600014249483,0.2482370026409626,0.24818700179457664,0.2481370009481907,0.24808800096313158,0.24803800135850906,0.24798900013168654,0.24793899928530058,0.24788899719715118,0.24783999845385551,0.24779000133275986,0.24774100010593733,0.24769100174307823,0.2476420005162557,0.2475919984281063,0.24754299720128378,0.24749300132195154,0.247444000095129,0.2473940017322699,0.24734499926368395,0.24729499965906143,0.24724600091576576,0.24719600255290666,0.24714700256784758,0.24709699799617132,0.2470479980111122,0.24699899926781654,0.2469489984214306,0.24689999843637148,0.2468500000735124,0.2468010000884533,0.24675200010339418,0.24670200049877167,0.24665300051371256,0.24660399928689003,0.24655399844050407,0.2465049996972084,0.2464559997121493,0.24640700096885362,0.24635699888070425,0.24630799889564514,0.24625899891058603,0.24620999892552695,0.246159998079141,0.24611099933584532,0.24606200183431307,0.2460129993657271,0.24596300100286803,0.24591399853428206,0.2458649997909864,0.24581599856416383,0.2457670010626316,0.2457180010775725,0.24566800023118654,0.24561900148789087,0.2455699990193049,0.24552100275953612,0.24547200029095015,0.24542300403118134,0.24537399783730507,0.2453249990940094,0.24527600407600403,0.24522699664036432,0.2451779991388321,0.24512900412082672,0.245079996685187,0.24503099918365479,0.24498200416564941,0.2449329967300097,0.24488399922847748,0.2448350042104721,0.2447859967748324,0.24473699927330017,0.2446880042552948,0.2446389968196551,0.24458999931812286,0.2445410043001175,0.24449200183153152,0.24444300308823586,0.2443940006196499,0.24434499815106392,0.24429699902733168,0.244248000284036,0.2441990002989769,0.2441500003139178,0.24410099908709526,0.2440520003437996,0.24400399749477705,0.2439549999932448,0.24390600249171257,0.24385699878136316,0.24380799879630408,0.2437599996725718,0.24371099968751272,0.2436619997024536,0.24361300095915794,0.24356499935189882,0.24351600060860315,0.24346699938178062,0.2434189977745215,0.24337000027298927,0.24332099904616675,0.24327299868067107,0.24322400242090225,0.24317500119407973,0.2431269995868206,0.24307799835999808,0.2430300017197927,0.24298099925120673,0.24293200050791106,0.24288400262594223,0.24283499891559282,0.24278699979186058,0.2427380010485649,0.24268999819954237,0.2426409994562467,0.24259199822942415,0.24254400158921877,0.24249500160415968,0.24244699875513712,0.24239800001184145,0.24234999840458235,0.24230200052261353,0.24225300177931786,0.24220500141382217,0.24215600142876306,0.24210799982150397,0.24205899983644485,0.24201100195447603,0.24196300034721693,0.24191400036215782,0.24186599999666214,0.24181699628631273,0.24176899964610735,0.24172099928061166,0.24167200177907944,0.2416240026553472,0.24157600104808807,0.24152699982126555,0.24147899821400642,0.2414310003320376,0.24138300120830536,0.24133400122324625,0.24128600085775057,0.24123800173401833,0.24118899926543236,0.24114099889993668,0.241092998534441,0.24104500065247217,0.2409970002869765,0.24094799906015396,0.24090000117818514,0.24085200081268945,0.24080399920543036,0.24075600132346153,0.2407079997162024,0.24065899724761644,0.24061099936564764,0.24056300024191538,0.2405149998764197,0.240466999510924,0.24041900038719177,0.2403710000216961,0.2403229996562004,0.24027500053246817,0.2402270001669725,0.2401789998014768,0.24013100067774454,0.24008299907048544,0.24003500118851662,0.2399869995812575,0.23993900045752525,0.23989100009202957,0.2398429997265339,0.23979500060280165,0.23974699899554253,0.2396990011135737,0.2396509995063146,0.23960300038258234,0.23955500001708666,0.23950700089335442,0.23945900052785873,0.23941100016236305,0.23936299855510393,0.23931600277622542,0.23926799992720285,0.2392200008034706,0.23917199795444807,0.2391239988307158,0.23907599846522012,0.23902900020281473,0.23898099983731905,0.23893299947182337,0.23888499910632768,0.238836998740832,0.2387900004784266,0.23874200011293092,0.23869399974743524,0.238646000623703,0.23859900111953417,0.23855099951227507,0.2385029991467794,0.238456000884374,0.23840799803535143,0.23836000015338263,0.23831299816568693,0.2382650002837181,0.23821699867645899,0.2381700004140536,0.23814600085218748};
    //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12689304103453955,0.12773900106549263,0.1286800019443035,0.1296250025431315,0.13061999902129173,0.13166500007112822,0.1327619987229506,0.1338659996787707,0.13493100057045618,0.13595799977580705,0.13694700226187706,0.137899000197649,0.1388119993110498,0.13968700170516968,0.1405249983072281,0.14132499943176904,0.1420880009730657,0.14281999692320824,0.14352700114250183,0.14421100045243898,0.1448690009613832,0.1455020010471344,0.14611099908749262,0.14669500042994818,0.14725599934657416,0.147792000323534,0.14830399925510088,0.14878899976611137,0.14924200251698494,0.14966400091846785,0.15005499745408693,0.1504139962295691,0.1507409984866778,0.15103799849748611,0.15130299950639406,0.1515370011329651,0.15173900251587233,0.1519169993698597,0.1520759997268518,0.1522169994811217,0.1523390014966329,0.15244300166765848,0.15252800037463507,0.1525949997206529,0.1526430000861486,0.15267300109068552,0.15268399690588316,0.15268599862853685,0.15268599862853685,0.15268400187293688,0.15268199890851974,0.15267900129159293,0.15267300109068552,0.15266599878668785,0.1526579993466536,0.1526490015288194,0.1526390016078949,0.1526269999643167,0.15261500204602876,0.15260200078288713,0.15258800238370895,0.15257300063967705,0.15255700051784515,0.15254000077644983,0.15252399941285452,0.15250599881013235,0.15248800069093704,0.15246900046865144,0.15244900062680244,0.15242900078495344,0.15240800008177757,0.1523859997590383,0.152363999436299,0.1523400011161963,0.1523169999321302,0.1522930016120275,0.15226799870530763,0.15224300076564154,0.15221699823935828,0.15219200029969215,0.15216699987649918,0.1521410010755062,0.1521149997909864,0.15208799888690314,0.1520609992245833,0.15203400080402693,0.15200699989994368,0.15198099985718727,0.15195399771134058,0.15192700053254762,0.15189999962846437,0.1518740008274714,0.15184699992338815,0.15182000026106834,0.15179399773478508,0.15176700055599213,0.15173999716838202,0.15171300123135248,0.15168699870506921,0.15165900066494942,0.15163100138306618,0.1516020012398561,0.15157400195797285,0.15154600143432617,0.15151700004935265,0.15148899952570596,0.15146100148558617,0.15143200010061264,0.1514040008187294,0.15137600029508272,0.1513470026353995,0.15131899962822595,0.15129099786281586,0.15126200020313263,0.15123399843772253,0.151205995430549,0.15117700149615607,0.15114899724721909,0.1511210004488627,0.1510929986834526,0.15106399978200594,0.15103599801659584,0.15100799997647604,0.15098000317811966,0.1509510005513827,0.15092100203037262,0.15089099978407225,0.15086100002129874,0.15083099901676178,0.1508010004957517,0.15077099949121475,0.15074099972844124,0.15071100120743117,0.15068099771936735,0.15065099795659384,0.15062200278043747,0.15059199929237366,0.15056200077136359,0.15053199728329977,0.15050199876228967,0.15047199775775275,0.15044300133983293,0.150413000335296,0.1503830018142859,0.15035299956798553,0.15032300104697546,0.15029400090376535,0.15026399989922842,0.15023399889469147,0.1502029982705911,0.15017200137178102,0.15013999988635382,0.15010899802049002,0.15007799987991652,0.15004600087801614,0.15001499901215234,0.149983000010252,0.14995200311144194,0.14991999914248785,0.14988900224367777,0.14985799913605055,0.14982599889238676,0.14979500075181326,0.1497630017499129,0.1497319998840491,0.14970099925994873,0.1496690014998118,0.14963800087571144,0.14960699900984764,0.1495750012497107,0.14954400062561035,0.14951299875974655,0.1494809997578462,0.14944999913374582,0.14941800013184547,0.1493850015103817,0.14935199916362762,0.1493189993004004,0.14928599943717322,0.14925300081570944,0.14921999971071878,0.14918699860572815,0.14915399998426437,0.1491210013628006,0.14908799901604652,0.1490550016363462,0.14902200053135553,0.14899000028769174,0.14895699669917425,0.14892400180300078,0.1488909994562467,0.14885799959301949,0.14882500221331915,0.1487920011083285,0.14875899876157442,0.14872699975967407,0.1486940011382103,0.14866100127498308,0.1486280014117559,0.14859400068720183,0.14855999872088432,0.14852500086029372,0.14849100013573965,0.14845600227514902,0.14842200030883154,0.1483869987229506,0.14835299675663313,0.1483180026213328,0.14828399941325188,0.14825000117222467,0.14821500206987062,0.14818100134531656,0.1481460022429625,0.14811200151840845,0.14807799955209097,0.14804300293326378,0.14800899972518286,0.14797399938106537,0.1479399986565113,0.14790600165724754,0.14787100007136664,0.14783699934681258,0.14780299986402193,0.14776799951990446,0.14773299917578697,0.14769700169563293,0.14766099924842516,0.1476250005265077,0.14758900056282678,0.14755300184090933,0.147517000635465,0.14748099943002066,0.14744499946633974,0.14740900074442229,0.14737299953897795,0.14733699957529703,0.147301002095143,0.14726499964793524,0.14722899968425432,0.14719400058190027,0.14715800061821938,0.14712200065453848,0.14708600069085756,0.14704999948541322,0.1470139982799689,0.14697799707452455,0.14694199959437051,0.14690699925025305,0.14687100052833557,0.14683500056465468,0.14679900060097376,0.14676299939552942,0.14672800029317537,0.14669200157125792,0.14665599912405014,0.1466200016438961,0.14658499881625175,0.14654900009433428,0.14651300137241682,0.1464770014087359,0.14644199858109155,0.14640599737564722,0.14637000113725662,0.1463339999318123,0.14629899834593138,0.1462629996240139,0.146226999660333,0.14619200055797896,0.14615600183606148,0.14611999814709029,0.14608499904473624,0.1460490015645822,0.14601399997870126,0.14597800001502037,0.14594199880957603,0.14590700094898543,0.1458709997435411,0.1458359993994236,0.14580000067750612,0.14576500033338866,0.14572900036970773,0.1456929991642634,0.1456580013036728,0.1456220025817553,0.14558699975411096,0.14555099854866663,0.14551599944631258,0.14548000196615854,0.14544499789675078,0.1454089991748333,0.14537400007247925,0.1453389972448349,0.14530299976468086,0.1452680006623268,0.14523199821511903,0.14519700159629187,0.1451610028743744,0.14512600128849348,0.14509099970261255,0.14505499973893166,0.14502000187834105,0.1449840006728967,0.14494900032877922,0.14491399998466173,0.14487800126274428,0.14484299967686334,0.1448080005745093,0.1447720006108284,0.14473700150847435,0.14470199992259344,0.14466699957847595,0.14463100085655847,0.144596000512441,0.14456100016832352,0.14452599982420603,0.14448999986052513,0.14445500075817108,0.14441999917229018,0.14438500006993613,0.14434900134801865,0.14431399976213774,0.1442790019015471,0.1442440003156662,0.1442089999715487,0.14417300124963126,0.14413799966375032,0.14410300056139627,0.1440680002172788,0.14403299987316132,0.1439980020125707,0.14396299918492636,0.14392699922124544,0.14389200136065483,0.14385699977477392,0.14382200067241988,0.14378700032830238,0.1437519999841849,0.14371699964006743,0.14368199929594994,0.1436470001935959,0.14361200109124184,0.14357699950536093,0.14354199916124344,0.1435070000588894,0.1434719997147719,0.14343700061241785,0.14340200026830038,0.1433669999241829,0.1433319995800654,0.14329699923594794,0.1432620001335939,0.14322700103123984,0.1431919994453589,0.14315700034300485,0.14312199875712395,0.1430869996547699,0.14305300017197928,0.14301800231138864,0.14298300072550774,0.14294799913962683,0.14291300003727278,0.1428779996931553,0.14284299810727438,0.14280899986624718,0.14277399952212969,0.14273899669448534,0.14270400007565817,0.14266900097330412,0.14263400062918663,0.14259999866286913,0.14256500080227852,0.1425299992163976,0.14249499887228012,0.1424609993894895,0.142425999045372,0.14239099994301796,0.14235599959890047,0.14232200011610985,0.14228699853022894,0.1422519994278749,0.14221799994508424,0.14218300208449364,0.14214800049861273,0.14211399977405867,0.14207900191346803,0.14204400032758713,0.1420100008447965,0.14197500050067902,0.14193999767303467,0.14190599943200746,0.14187099908789,0.14183699960509935,0.14180200174450874,0.14176700015862784,0.1417330006758372,0.14169800157348314,0.14166400084892908,0.14162900050481161,0.14159499729673067,0.14156000191966692,0.14152599995334944,0.14149099960923195,0.14145700136820474,0.14142199729879698,0.14138799905776978,0.14135299995541573,0.1413190004726251,0.14128400012850761,0.14124999940395355,0.1412150003015995,0.1411810020605723,0.14114599799116453,0.14111199975013733,0.14107800275087357,0.14104299868146578,0.14100899919867516,0.1409740000963211,0.1409399981300036,0.14090600113073984,0.14087100078662237,0.1408370000620683,0.14080300057927767,0.14076799775163332,0.14073400075236955,0.14069999878605208,0.14066499968369803,0.14063100020090738,0.14059699947635332,0.14056199913223585,0.1405279996494452,0.1404940001666546,0.14045999944210052,0.14042500033974648,0.14039100085695586,0.1403570013741652,0.1403229981660843,0.1402879978219668,0.14025399958093962,0.14022000009814897,0.1401859981318315,0.14015200113256773,0.14011699830492338,0.14008300130565962,0.14004899933934212,0.14001499861478806,0.13998099913199744,0.13994700089097023,0.13991199930508932,0.13987800230582556,0.13984400033950806,0.13981000085671744,0.1397760013739268,0.13974200189113617,0.13970799868305525,0.13967400044202805,0.13963999971747398,0.13960600023468336,0.13957200075189272,0.13953799878557524,0.1395039993027846,0.13946999981999397,0.1394359990954399,0.1394019996126493,0.13936800137162209,0.13933400064706802,0.13929999992251396,0.13926600043972334,0.1392320009569327,0.13919799899061522,0.13916399950782457,0.13913000002503395,0.1390959993004799,0.13906199857592583,0.13902800033489862,0.138994000852108,0.13895999764402708,0.13892599816123644,0.13889199992020926,0.13885900129874548,0.13882500057419142,0.13879099860787392,0.13875699788331985,0.1387230008840561,0.1386889989177386,0.1386560027798017,0.13863899682958922};
    C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.28434206545352936,0.28995800018310547,0.2954609990119934,0.3020529995361964,0.3089950035015742,0.31628500173489255,0.32392499844233197,0.33160799741744995,0.33903099844853085,0.34619300067424774,0.3530930032332738,0.3597329979141553,0.36611200124025345,0.37223099917173386,0.3780889982978503,0.38368599861860275,0.38902400185664493,0.39414799710114795,0.3991050024827321,0.40389499564965564,0.4085180014371872,0.41297300159931183,0.417261004447937,0.4213829959432284,0.42533699919780094,0.42912499854962033,0.4327460005879402,0.43617499619722366,0.43939100454250973,0.44239099820454914,0.44517500698566437,0.4477440019448598,0.45009800295035046,0.45223799844582874,0.45416299998760223,0.455872006714344,0.4573659996191661,0.45869000256061554,0.45988599956035614,0.4609559973080953,0.461898997426033,0.4627160007754962,0.4634069974223773,0.46397000054518384,0.4644060010711352,0.46471699823935825,0.46490100026130676,0.46501800169547397,0.4651250019669533,0.46522200107574463,0.4653099998831749,0.4653880000114441,0.4654580006996791,0.4655189986030261,0.46556999534368515,0.46561099588871,0.4656430010994275,0.4656680077314377,0.46568800260623294,0.46570299317439395,0.46571200092633563,0.46571700026591617,0.46571599940458935,0.46570999920368195,0.465699998040994,0.4656830032666524,0.4656620000799497,0.4656359975536664,0.4656059965491295,0.465570996205012,0.46553100148836773,0.46548700084288913,0.46543800085783005,0.46538400153319043,0.4653270021080971,0.4652640024820964,0.46519700189431507,0.46512699375549954,0.4650559996565183,0.4649839997291565,0.46491099894046783,0.4648369997739792,0.46476199477910995,0.46468599637349445,0.4646100004514058,0.4645320052901904,0.46445300181706745,0.4643719991048177,0.4642919997374217,0.46420999864737195,0.46412800004084903,0.4640459915002187,0.46396300196647644,0.4638800049821536,0.4637960021694501,0.4637119993567467,0.46362799902757007,0.46354300032059353,0.46345699826876324,0.4633709987004598,0.46328500161568326,0.463198001186053,0.46310999741156894,0.46302299946546555,0.46293500314156216,0.4628459985057513,0.46275699883699417,0.4626669983069102,0.46257800112167996,0.46248700469732285,0.46239600082238513,0.4623049994309743,0.4622130021452904,0.46212200323740643,0.46203000098466873,0.46193600197633106,0.4618430013457934,0.46175000071525574,0.46165599673986435,0.46156100183725357,0.4614660019675891,0.4613710045814514,0.4612760047117869,0.4611790006359418,0.4610819990436236,0.4609850024183591,0.46088800330956775,0.460788997511069,0.46069000164667767,0.46059199919303256,0.46049300332864124,0.4603919982910156,0.4602919965982437,0.4601909965276718,0.4600900014241536,0.4599880004922549,0.45988599956035614,0.45978399862845737,0.45968200266361237,0.4595790008703868,0.4594749982158343,0.459370993077755,0.45926700035731,0.4591620018084844,0.4590570032596588,0.4589510013659795,0.45884500443935394,0.4587389975786209,0.4586309964458148,0.45852399865786236,0.45841600000858307,0.4583080013593038,0.45819799850384396,0.4580890014767647,0.4579799969991048,0.4578699991106987,0.45775900036096573,0.45764799416065216,0.4575369978944461,0.45742499828338623,0.4573120002945264,0.45719899982213974,0.4570860018332799,0.45697300136089325,0.4568599984049797,0.4567450061440468,0.45663099735975266,0.45651600261529285,0.4564009979367256,0.456284003953139,0.4561679984132449,0.4560520003239314,0.45593400051196414,0.45581600069999695,0.45569800088802975,0.4555799985925357,0.4554609979192416,0.4553410013516744,0.4552209998170535,0.45510099828243256,0.4549799958864848,0.45485899845759076,0.45473700016736984,0.4546149969100952,0.4544929986198743,0.4543689986069997,0.4542460044225057,0.45412300775448483,0.45399900277455646,0.453875000278155,0.45374999692042667,0.45362499604622525,0.45349899927775067,0.4533730000257492,0.4532459999124209,0.45311899731556576,0.4529930005470912,0.45286499957243603,0.4527360027035077,0.45260699838399887,0.4524789998928706,0.4523489996790886,0.45221900443236035,0.45208799839019775,0.4519580006599426,0.4518260012070338,0.45169400175412494,0.4515619973341624,0.4514300028483073,0.45129699756701785,0.4511629988749822,0.4510289976994197,0.4508949965238571,0.4507610003153483,0.4506260007619858,0.4504909962415695,0.45035500079393387,0.45021900286277133,0.4500829999645551,0.44994499782721203,0.4498079965511958,0.4496700043479602,0.44953199724356335,0.44939300417900085,0.44925399621327716,0.44911500066518784,0.4489749992887179,0.44883399953444797,0.44869300723075867,0.4485519975423813,0.44841000189383823,0.44826700041691464,0.44812499980131787,0.44798199584086734,0.44783900181452435,0.44769400109847385,0.4475500012437503,0.44740500052769977,0.4472609981894493,0.4471169983347257,0.4469729984800021,0.4468290035923322,0.44668400039275485,0.4465399980545044,0.44639600068330765,0.446252000828584,0.44610800097386044,0.4459649994969368,0.44582099715868634,0.4456770022710164,0.44553299993276596,0.4453890025615692,0.44524600108464557,0.445102001229922,0.44495900223652524,0.4448150048653285,0.44467199842135113,0.4445280010501544,0.44438499708970386,0.44424200306336087,0.44409800320863724,0.4439550042152405,0.4438119977712631,0.44366900126139325,0.4435259997844696,0.44338300079107285,0.4432399993141492,0.44309700032075244,0.44295399636030197,0.4428110023339589,0.44266800085703534,0.4425249993801117,0.4423829987645149,0.44223999977111816,0.4420970057447751,0.44195499767859775,0.441811998685201,0.4416700005531311,0.44152699410915375,0.44138500342766446,0.4412420019507408,0.44109999636809033,0.44095800071954727,0.4408160025874774,0.4406730035940806,0.44053100049495697,0.4403889998793602,0.44024699678023654,0.44010500113169354,0.439962995549043,0.4398209999005,0.43967900176843006,0.43953799953063327,0.4393959989150365,0.4392539958159129,0.43911200016736984,0.43897100041309994,0.43882900228103,0.4386880000432332,0.43854600191116333,0.43840499718983966,0.4382629990577698,0.4381219993034999,0.4379809995492299,0.43783899893363315,0.43769799669583637,0.43755699942509335,0.4374159996708234,0.4372749999165535,0.4371340001622836,0.4369930028915405,0.43685200065374374,0.43671100089947384,0.4365699936946233,0.4364289964238803,0.4362890000144641,0.4361479977766673,0.4360070005059242,0.4358669991294543,0.43572599937518436,0.43558499962091446,0.43544500569502514,0.43530499935150146,0.4351640020807584,0.4350240007042885,0.4348830034335454,0.4347430020570755,0.4346030006806056,0.4344629993041356,0.4343229979276657,0.4341830015182495,0.4340430001417796,0.4339030012488365,0.4337629998723666,0.43362299849589664,0.4334829996029536,0.43334299822648364,0.43320300430059433,0.43306400378545123,0.4329239974419276,0.43278400351603824,0.43264499803384143,0.4325049991408984,0.4323659961422284,0.4322260022163391,0.4320870041847229,0.4319469978411992,0.431807999809583,0.4316690017779668,0.4315299987792969,0.4313900023698807,0.43125099937121075,0.43111199885606766,0.43097299834092456,0.43083400030930835,0.4306949997941653,0.4305559992790222,0.4304169962803523,0.4302789991100629,0.4301400010784467,0.43000099807977676,0.42986200004816055,0.42972400039434433,0.4295849973956744,0.4294470027089119,0.4293080021937688,0.42916999757289886,0.42903099954128265,0.42889299988746643,0.4287550027171771,0.4286159997185071,0.4284780025482178,0.42833999792734784,0.42820200075705844,0.4280640011032422,0.427926001449426,0.42778700093428296,0.42765000214179355,0.4275120024879773,0.4273739978671074,0.42723600566387177,0.42709799855947495,0.42696000387271243,0.4268230025966962,0.42668500045935315,0.42654699583848316,0.4264099970459938,0.42627199987570447,0.42613500108321506,0.42599700142939884,0.4258600026369095,0.42572300632794696,0.42558499922355014,0.4254479979475339,0.42531100412209827,0.4251740053296089,0.425036000708739,0.42489899943272275,0.4247619981567065,0.424625001847744,0.42448800057172775,0.42435100426276523,0.424215001364549,0.4240779976050059,0.4239410012960434,0.42380400002002716,0.4236679996053378,0.4235310008128484,0.4233939970533053,0.4232580016056697,0.42312100032965344,0.4229849974314372,0.4228480060895284,0.4227120007077853,0.42257600277662277,0.4224390039841334,0.4223030010859172,0.4221669981877009,0.4220310002565384,0.42189500232537586,0.4217589994271596,0.42162300149599713,0.4214869985977809,0.42135100066661835,0.421215000251929,0.42107899735371274,0.4209430019060771,0.42080700397491455,0.4206719994544983,0.42053600152333576,0.4203999986251195,0.420264999071757,0.4201289986570676,0.41999400158723194,0.41985800365606946,0.4197229991356532,0.4195869987209638,0.4194520016511281,0.4193170020977656,0.4191809991995494,0.41904599716265994,0.41891099512577057,0.4187760005394618,0.4186410034696261,0.4185060014327367,0.4183710018793742,0.41823600232601166,0.4181010002891223,0.41796600073575974,0.41783099869887036,0.4176969975233078,0.417562002936999,0.41742699841658276,0.4172929997245471,0.41715800017118454,0.41702400396267575,0.4168890019257863,0.4167550007502238,0.41662000119686127,0.4164860000212987,0.4163510004679362,0.41621699929237366,0.416083000600338,0.4159490019083023,0.41581500073273975,0.41568000117937726,0.4155459975202878,0.415412001311779,0.41527800261974335,0.41514399896065396,0.415011003613472,0.4148769974708557,0.4147430012623469,0.41460900257031125,0.4144750013947487,0.414342001080513,0.41420799990495044,0.41407399872938794,0.41394100338220596,0.4138070022066434,0.4136740018924077,0.41354100157817203,0.41340700288613635,0.41327400008837384,0.413141002257665,0.41307399918635684};
    //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12939697379867235,0.13274599984288216,0.136223999162515,0.1400709996620814,0.1441200003027916,0.1483719994624456,0.1528280017276605,0.15730899944901466,0.161636999497811,0.1658139998714129,0.16983900095025697,0.17371200025081635,0.17743399987618128,0.1810039977232615,0.18442299962043762,0.187689999739329,0.19080499932169914,0.19379600013295809,0.19668999935189882,0.1994869994620482,0.20218600084384283,0.2047870010137558,0.2072920004526774,0.20969999954104424,0.2120099999010563,0.21422399953007698,0.21633999918897948,0.2183459997177124,0.22022599851091704,0.2219810001552105,0.22361000130573908,0.2251140003403028,0.22649399812022844,0.22774799913167953,0.22887599964936575,0.22988000139594078,0.23075900226831436,0.23153799772262573,0.2322420005997022,0.23287300268809,0.23343100026249886,0.23391499991218248,0.23432600125670433,0.23466299970944723,0.2349269986152649,0.23511699959635735,0.23523300141096115,0.2353100006779035,0.2353810009857019,0.23544700195391974,0.23550700147946677,0.23556199918190637,0.23561099916696548,0.23565600191553435,0.23569399987657866,0.23572799935936928,0.2357549990216891,0.2357779989639918,0.23579900215069452,0.2358170027534167,0.23583199828863144,0.23584400117397308,0.23585300023357073,0.23585900167624155,0.23586099843184152,0.23586100215713182,0.23585799833138785,0.23585099975268045,0.23584099983175597,0.23583000029126802,0.235815001030763,0.23579800004760423,0.23577900230884552,0.2357570007443428,0.23573200156291327,0.23570399979750314,0.23567400127649307,0.23564200227459273,0.23560900116960207,0.23557600006461143,0.23554199934005737,0.23550799985726675,0.23547299951314926,0.2354380004107952,0.23540099834402403,0.23536400000254312,0.23532699917753538,0.23528999959429106,0.23525300001104674,0.23521500080823898,0.23517699912190437,0.23513799905776978,0.23509999985496202,0.235060998549064,0.23502299934625626,0.23498400176564851,0.23494399959842363,0.23490400115648905,0.2348640002310276,0.23482399806380272,0.23478300124406815,0.23474200069904327,0.23469999680916467,0.23465899874766669,0.23461699858307838,0.23457600052158037,0.23453399911522865,0.23449099933107695,0.23444799954692522,0.23440500100453696,0.23436200122038522,0.23431899895270666,0.23427600041031837,0.23423199852307638,0.23418700198332468,0.2341430000960827,0.234099001934131,0.2340539979437987,0.23400799930095673,0.23396200065811476,0.2339159995317459,0.23387000088890395,0.23382499938209853,0.2337779998779297,0.23373100037376085,0.23368400211135545,0.23363600050409636,0.23358900099992752,0.2335409993926684,0.23349299902717272,0.2334440015256405,0.23339499781529108,0.23334699869155884,0.23329800243179002,0.23324899996320406,0.2331979994972547,0.23314799989263216,0.23309800028800964,0.2330479994416237,0.2329970014592012,0.23294599975148836,0.23289399966597557,0.23284300044178963,0.23279099787274996,0.2327400023738543,0.2326869989434878,0.23263400048017502,0.23258099829157194,0.23252800231178603,0.23247500012318292,0.2324220004181067,0.2323670027156671,0.2323130009075006,0.23225799947977066,0.2322040026386579,0.2321500008304914,0.23209399978319803,0.23203799997766814,0.23198299979170164,0.23192700122793516,0.23187100142240524,0.23181500161687532,0.23175900181134543,0.2317010002831618,0.23164399961630502,0.23158700143297514,0.2315289999047915,0.23147099961837134,0.23141300057371458,0.23135400066773096,0.23129500076174736,0.23123700047532716,0.23117799932758012,0.23111900066335997,0.2310580015182495,0.23099800075093904,0.23093799874186516,0.23087799921631813,0.23081700007120767,0.2307559996843338,0.23069400216142336,0.23063200091322264,0.23057100176811218,0.23050900176167488,0.23044700051347414,0.23038400088747343,0.23032099877794585,0.23025800039370856,0.23019500076770782,0.2301320011417071,0.23006699979305267,0.2300029993057251,0.22993799671530724,0.22987399871150652,0.22981000070770582,0.22974499935905138,0.22967899963259697,0.22961299866437912,0.22954700017968813,0.22948100417852402,0.22941500196854273,0.2293479988972346,0.22927999993165335,0.22921299934387207,0.2291460024813811,0.22907900189359984,0.22901099920272827,0.22894199937582016,0.2288740004102389,0.22880499934156737,0.22873599951465926,0.22866699968775114,0.22859699899951616,0.22852699955304465,0.2284570001065731,0.22838700066010156,0.2283169999718666,0.22824600090583166,0.22817500059803328,0.22810299942890802,0.22803200284639993,0.22796000043551126,0.22788899888594946,0.22781699895858765,0.22774399941166243,0.22767100110650063,0.22759799907604852,0.22752600039045015,0.2274519999821981,0.227377999573946,0.22730400040745735,0.22722900162140527,0.22715499872962633,0.22708100080490112,0.22700599829355875,0.22692999988794327,0.22685499861836433,0.2267789989709854,0.22670400142669678,0.22662799805402756,0.22655199964841208,0.22647700086236,0.2264020008345445,0.22632599994540215,0.22625099991758665,0.2261749990284443,0.2260999990006288,0.2260240005950133,0.2259490005671978,0.22587400178114572,0.2257990005115668,0.22572300086418787,0.22564800207813582,0.22557300080855688,0.22549799953897795,0.22542299951116243,0.22534700110554695,0.22527200107773146,0.22519699732462564,0.22512200102210045,0.22504699975252151,0.22497199972470602,0.22489700093865395,0.22482199842731157,0.22474700088302293,0.224671999613444,0.2245980016887188,0.22452299917737642,0.22444799914956093,0.22437299912174544,0.22429800033569336,0.22422299906611443,0.22414899989962578,0.2240739973882834,0.22399899984399477,0.22392500191926956,0.22384999940792719,0.22377499813834825,0.2237009977300962,0.2236259989440441,0.2235520010193189,0.22347699850797653,0.22340300058325133,0.2233279993136724,0.2232539989054203,0.2231800022224585,0.22310499971111616,0.22303099930286407,0.22295700137813887,0.22288200135032335,0.2228079984585444,0.22273400177558264,0.2226590005060037,0.22258500009775162,0.22251099968949953,0.22243699803948402,0.22236299887299538,0.2222889984647433,0.22221500054001808,0.22213999927043915,0.2220660001039505,0.2219919996956984,0.22191799928744635,0.2218449997405211,0.2217710018157959,0.2216970001657804,0.22162300099929175,0.22154900059103966,0.22147499894102415,0.2214009997745355,0.22132700060804686,0.2212539998193582,0.2211800031363964,0.22110600024461746,0.22103299821416536,0.2209589978059133,0.22088499988118807,0.2208119990924994,0.22073799868424734,0.2206639995177587,0.22059099997083345,0.2205169995625814,0.2204440012574196,0.22036999960740408,0.22029699757695198,0.22022400051355362,0.22015000010530153,0.2200770005583763,0.22000300015012422,0.21993000184496245,0.21985699981451035,0.21978400150934854,0.2197099986175696,0.21963700031240782,0.21956400076548258,0.21949099997679392,0.21941799918810526,0.2193440000216166,0.21927099923292795,0.21919800092776617,0.2191250001390775,0.21905199935038885,0.2189789998034636,0.2189060002565384,0.2188330019513766,0.21875999867916107,0.21868699913223585,0.21861499920487404,0.21854199965794882,0.21846899638573328,0.21839599932233492,0.21832300101717314,0.21825000022848448,0.21817799905935922,0.218104999512434,0.2180319999655088,0.21796000003814697,0.21788700049122176,0.2178140009442965,0.21774199977517128,0.21766900147000948,0.2175969978173574,0.21752400075395903,0.21745199834307036,0.21737900003790855,0.21730699886878332,0.21723400056362152,0.21716200187802315,0.21709000070889792,0.21701700116197267,0.216944998751084,0.21687300006548563,0.21680000176032385,0.21672799810767174,0.21665600190560022,0.21658399949471155,0.21651099994778633,0.21643900002042452,0.21636700009306273,0.2162950001657009,0.21622299775481224,0.21615099906921387,0.21607900162537894,0.21600700045625368,0.21593499928712845,0.21586300060153008,0.21579099943240485,0.21571899950504303,0.2156470020612081,0.21557499965031943,0.21550300096472105,0.21543199941515923,0.215359998246034,0.21528800080219904,0.2152160033583641,0.21514499932527542,0.21507299691438675,0.21500100071231523,0.21492900078495344,0.21485800047715506,0.2147859980662664,0.21471499900023142,0.21464299783110619,0.21457199876507124,0.21450000132123628,0.21442899977167448,0.2143570010860761,0.21428600202004114,0.21421399960915247,0.21414300054311752,0.21407100185751915,0.2139999990661939,0.21392900124192238,0.2138579972088337,0.21378599976499876,0.21371499945720038,0.213643999149402,0.21357300132513046,0.21350100139776865,0.21342999984820685,0.21335899954040846,0.21328800171613693,0.2132170001665751,0.21314599985877672,0.21307500079274178,0.2130040004849434,0.21293299769361815,0.21286199986934662,0.21279100328683853,0.2127200017372767,0.21264899894595146,0.21257799987991652,0.2125069983303547,0.2124370001256466,0.21236600105961165,0.21229500075181326,0.21222399920225143,0.2121530001362165,0.21208300068974495,0.21201199914018312,0.21194099883238474,0.21187100062767664,0.21180000031987825,0.2117299996316433,0.21165900180737177,0.21158899863560995,0.21151799956957498,0.21144700050354004,0.21137699981530508,0.2113069991270701,0.21123600378632545,0.2111659993728002,0.21109500154852867,0.21102499961853027,0.21095499893029532,0.21088399986426035,0.21081400041778883,0.21074400221308073,0.21067400028308234,0.2106029987335205,0.21053300177057585,0.21046299984057745,0.2103930003941059,0.2103230021893978,0.21025300025939941,0.21018299957116446,0.21011299888292947,0.21004299943645796,0.20997300123174986,0.20990300178527832,0.20983299985527992,0.20976299792528152,0.20969300096233687,0.20962300151586533,0.20955299958586693,0.2094830001393954,0.20941300069292387,0.20934400086601576,0.20927399893601736,0.20920400197307268,0.20913399880131087,0.20906500021616617,0.20899500076969466,0.20892500008145967,0.208856001496315,0.2088209999104341};
    //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.0922222329924504,0.09350149954358737,0.09477110020816326,0.09623499897619088,0.09777659984926383,0.0993956991781791,0.10109299918015797,0.1028010006994009,0.10445000045001507,0.10603999967376392,0.10757300009330113,0.10904599974552791,0.11046200059354305,0.1118200005342563,0.11311899994810422,0.11436000031729539,0.11554299977918465,0.11667800073822339,0.11777500001092751,0.1188360011825959,0.11985900066792965,0.12084499994913737,0.12179200164973736,0.12270299966136615,0.12357700057327747,0.12441399941841762,0.12521199757854143,0.12596799929936728,0.12667700027426085,0.127336997538805,0.12794799854358038,0.12851200252771378,0.12902799993753433,0.12949599946538606,0.12991500149170557,0.13028700153032938,0.1306109999616941,0.13089699919025102,0.13115400075912476,0.13138299932082495,0.1315830002228419,0.13175499687592188,0.13189899921417236,0.13201499978701273,0.132102000216643,0.13216000174482664,0.13219099988540015,0.13220700000723204,0.13222099840641022,0.13223199918866158,0.13224099949002266,0.13224799806873003,0.13225299989183745,0.1322559987505277,0.13225599999229112,0.13225500161449114,0.13225200151403746,0.13224600007136664,0.13223999862869582,0.13223399966955185,0.13222499936819077,0.13221600030859312,0.13220500076810518,0.13219299912452698,0.1321799991031488,0.13216499984264374,0.13215100020170212,0.1321340004603068,0.13211699947714806,0.1320989988744259,0.1320800023774306,0.1320590004324913,0.13203799724578857,0.13201600313186646,0.13199299946427345,0.13196800028284392,0.13194300110141435,0.1319160001973311,0.13188999767104784,0.13186400135358176,0.13183699920773506,0.13181099916497865,0.131782998641332,0.13175499935944876,0.13172800093889236,0.13169999917348227,0.13167199989159903,0.1316450002292792,0.13161699970563254,0.1315900000433127,0.13156199951966605,0.1315349986155828,0.13150699933369955,0.1314790000518163,0.1314499986668428,0.13142099976539612,0.1313920021057129,0.13136299699544907,0.13133500019709268,0.1313060000538826,0.13127699991067251,0.1312479997674624,0.13121899962425232,0.13119100034236908,0.131162000199159,0.13113199919462204,0.13110200067361197,0.131071999669075,0.1310419999063015,0.13101200014352798,0.13098200038075447,0.13095200061798096,0.130921999613444,0.1308919998506705,0.13086200008789697,0.13083199659983316,0.13080200056234995,0.13077199955781302,0.13074100017547607,0.13071000079313913,0.1306779980659485,0.13064700116713843,0.13061600178480148,0.1305840015411377,0.13055300091703734,0.1305219978094101,0.13049000004927316,0.1304589994251728,0.130427997559309,0.1303969994187355,0.13036500041683516,0.13033200055360794,0.1303000015517076,0.13026700168848038,0.1302339993417263,0.13020200158158937,0.13016900171836218,0.1301370014746984,0.13010399912794432,0.1300720013678074,0.13003900026281676,0.13000699877738953,0.12997400015592575,0.12994099905093512,0.12990700205167136,0.12987399846315384,0.12984000022212663,0.129806000739336,0.12977200001478195,0.12973900015155473,0.12970499818523726,0.12967099994421005,0.12963799883921942,0.12960400183995566,0.12957000359892845,0.12953600039084753,0.12950100004673004,0.129466000944376,0.1294310006002585,0.12939599777261415,0.12936099991202354,0.12932599832614264,0.1292909992237886,0.12925600012143454,0.12922099977731705,0.12918599943319956,0.1291509990890821,0.12911600122849146,0.1290809984008471,0.12904399881760278,0.12900800009568533,0.128971998890241,0.12893600016832352,0.12890000144640604,0.1288640002409617,0.12882700314124426,0.12879100069403648,0.128755001972119,0.12871900076667467,0.12868299956123033,0.128645999977986,0.12860899915297827,0.12857099870840707,0.12853399912516275,0.12849600116411844,0.12845900158087412,0.12842200075586638,0.12838399906953177,0.12834700072805086,0.12830999866127968,0.1282719982167085,0.12823500235875449,0.12819800029198328,0.1281599998474121,0.12812100102504095,0.12808200096090636,0.12804399927457175,0.128005001693964,0.12796700124939284,0.12792800118525824,0.12788900112112364,0.1278510019183159,0.12781199937065443,0.12777399768431982,0.12773500134547552,0.12769600003957748,0.1276560015976429,0.12761600191394487,0.12757700060804686,0.12753700092434883,0.1274969999988874,0.12745700031518936,0.12741799900929132,0.12737799808382988,0.1273379996418953,0.1272980011999607,0.12725899989406267,0.12721899896860123,0.12717900052666664,0.12713799998164177,0.1270969994366169,0.12705600013335547,0.1270149995883306,0.12697400028506914,0.1269330009818077,0.1268919991950194,0.12685100237528482,0.12681000183025995,0.12676899880170822,0.12672800198197365,0.1266859993338585,0.12664400041103363,0.12660200148820877,0.1265599988400936,0.12651799991726875,0.1264750026166439,0.1264330012102922,0.1263910010457039,0.12634899963935217,0.12630700320005417,0.126265000551939,0.1262229991455873,0.12618100146452585,0.12613900005817413,0.12609699989358583,0.12605500097076097,0.12601299832264581,0.12597100188334784,0.12592899923523268,0.12588700031240782,0.12584500014781952,0.1258029987414678,0.12576100106040636,0.12571899965405464,0.12567699700593948,0.12563500180840492,0.1255930004020532,0.12555099899570146,0.12550999969244003,0.12546800076961517,0.1254260018467903,0.1253840004404386,0.12534199903408685,0.12530099973082542,0.12525899708271027,0.12521700064341226,0.12517499923706055,0.12513399745027223,0.12509200101097426,0.1250499996046225,0.1250090009222428,0.1249670001367728,0.1249249999721845,0.12488400066892306,0.12484199926257133,0.12479999971886475,0.1247589997947216,0.12471699963013332,0.12467599970599015,0.12463399892052014,0.12459300085902214,0.12455100069443385,0.1245089986672004,0.12446799936393897,0.12442700068155925,0.12438499989608924,0.1243440005928278,0.12430200042823951,0.12426100112497807,0.12421900096038978,0.12417799979448318,0.12413699987034003,0.12409500032663345,0.12405399978160858,0.12401199899613857,0.12397099907199542,0.1239300003896157,0.12388899860282739,0.12384700030088425,0.12380599975585938,0.12376500107347965,0.12372300028800964,0.12368200036386649,0.12364100043972333,0.12360000051558018,0.12355900121231873,0.12351700104773045,0.12347600050270557,0.12343500057856242,0.12339400003353755,0.12335300010939439,0.12331199956436951,0.12327100026110809,0.12322999971608321,0.12318800017237663,0.12314700024823348,0.12310600032409032,0.12306499977906545,0.1230239998549223,0.12298299993077914,0.1229420006275177,0.1229009988407294,0.12286000015834968,0.12281900085508823,0.12277899992962678,0.12273800000548363,0.12269700070222218,0.12265600015719731,0.12261500085393588,0.12257400092979272,0.12253299976388614,0.1224920004606247,0.12245199953516324,0.12241100023190181,0.12236999968687694,0.1223290003836155,0.1222879992177089,0.12224799953401089,0.12220700023074944,0.12216600030660629,0.12212499976158142,0.12208499945700169,0.12204399953285854,0.12200300022959709,0.12196300054589908,0.12192199937999249,0.12188100069761276,0.12184100039303303,0.1218000017106533,0.12176000016431014,0.12171900024016698,0.12167799845337868,0.12163799939056237,0.12159699946641922,0.12155699916183949,0.12151600047945976,0.12147600017488003,0.12143499962985516,0.12139499994615714,0.12135399940113227,0.12131399971743424,0.12127400003373623,0.12123299948871136,0.12119300042589505,0.12115199988087018,0.12111200019717216,0.12107199927171071,0.12103099934756756,0.12099100090563297,0.12095099935928981,0.12091000005602837,0.12086999913056691,0.12083000006775062,0.12078900014360745,0.12074899921814601,0.12070899953444798,0.12066900047163169,0.12062800054748853,0.12058799962202708,0.12054799931744735,0.12050799963374932,0.12046800057093303,0.1204280002663533,0.12038699972132842,0.1203470000376304,0.12030699973305066,0.12026700004935265,0.12022699974477291,0.1201870000610749,0.12014700037737687,0.12010700007279713,0.12006700038909912,0.12002699946363767,0.11998699977993965,0.11994700009624164,0.11990700041254361,0.11986700010796388,0.11982700042426586,0.1197869994988044,0.11974699981510639,0.11970700013140838,0.11966700044771035,0.11962700076401234,0.11958800069987774,0.11954799977441628,0.11950800071159999,0.11946800040702026,0.11942800010244052,0.1193880004187425,0.11934899973372619,0.11930900005002816,0.11926899974544843,0.11922900006175041,0.11918999999761581,0.1191500003139178,0.11911000000933807,0.11907000032564004,0.11903099964062373,0.11899099871516228,0.11895099965234597,0.11891199958821137,0.11887199990451336,0.11883299921949704,0.11879300077756245,0.11875299923121929,0.11871399978796641,0.11867399948338668,0.11863500066101551,0.11859499973555405,0.11855599967141946,0.11851599998772144,0.11847699992358685,0.11843699961900711,0.11839799893399079,0.11835799925029278,0.11831899918615818,0.11827899888157845,0.11824000005920728,0.11820000037550926,0.11816100031137466,0.11812199962635835,0.11808200056354205,0.11804299987852573,0.11800400043527286,0.1179639995098114,0.11792500068744023,0.11788600062330563,0.1178460003187259,0.1178069996337096,0.1177680001904567,0.1177289995054404,0.11768899982174237,0.11764999913672607,0.11761099845170975,0.11757200087110202,0.1175330001860857,0.11749299988150597,0.11745399981737137,0.11741500037411849,0.11737599968910217,0.117337000866731,0.11729799956083298,0.11725899949669838,0.11722000067432721,0.11717999974886577,0.1171410009264946,0.11710200024147828,0.11706299955646197,0.11702400011320908,0.11698500066995621,0.11694599998493989,0.11690700054168701,0.11686800047755241,0.1168289997925361,0.11679099934796493,0.11675199990471204,0.11671299984057744,0.11667400039732456,0.11663500033318996,0.11659600088993709,0.11655699958403905,0.11651799889902274,0.11647999969621499,0.11644099963208039,0.11640199894706409,0.1163820003469785};
    CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.8340072631836,82.68911743164062,83.15111351013184,83.92251396179199,84.71921412150066,85.54141553243001,86.38881429036458,87.24091466267903,88.07681401570638,88.89651425679524,89.70011329650879,90.48751386006673,91.2587121327718,92.01381301879883,92.75271161397298,93.4755121866862,94.18211110432942,94.87551053365071,95.55851173400879,96.2313117980957,96.89381090799968,97.54591051737468,98.1878096262614,98.81930987040202,99.44050979614258,100.05100949605306,100.65200932820638,101.23300997416179,101.78600883483887,102.31000836690266,102.80600802103679,103.27300707499187,103.71200688680013,104.12200609842937,104.50300598144531,104.8560053507487,105.18100420633952,105.47900454203288,105.75300407409668,106.0030034383138,106.22800191243489,106.43000221252441,106.60800298055013,106.76100158691406,106.89000193277995,106.99600156148274,107.07700157165527,107.14500172932942,107.21200180053711,107.27900123596191,107.34400113423665,107.40800094604492,107.47100194295247,107.53300094604492,107.59400113423665,107.65300114949544,107.71200052897136,107.77000109354655,107.82600084940593,107.88300132751465,107.93800163269043,107.99300130208333,108.04700152079265,108.10000165303548,108.15300051371257,108.20500055948894,108.25600115458171,108.30600102742513,108.35600153605144,108.40500005086263,108.45300038655598,108.50000190734863,108.54700088500977,108.59300168355306,108.638001759847,108.68200238545735,108.72599983215332,108.76900164286296,108.81100082397461,108.85300127665202,108.89399846394856,108.93500137329102,108.97499974568684,109.01399993896484,109.05300076802571,109.09100023905437,109.12900225321452,109.16600036621094,109.20300038655598,109.23900032043457,109.27500025431316,109.31100018819173,109.34700202941895,109.3830000559489,109.41800117492676,109.45300038655598,109.48800150553386,109.52200063069661,109.55600166320801,109.59000142415364,109.62400182088216,109.65700085957845,109.6900011698405,109.72300084431966,109.75600051879883,109.78800010681152,109.81999969482422,109.85200055440266,109.88400014241536,109.91500091552734,109.94600105285645,109.97700119018555,110.00699996948242,110.03700065612793,110.06700007120769,110.09700202941895,110.12700080871582,110.1560001373291,110.18500137329102,110.21299997965495,110.24199930826823,110.27000045776367,110.29800033569336,110.32499885559082,110.35300127665202,110.38000106811523,110.40700022379558,110.4330005645752,110.45900090535481,110.48600006103516,110.51100031534831,110.53700002034505,110.5620002746582,110.58699989318848,110.61200014750163,110.63600031534831,110.66000048319499,110.68400001525879,110.70799954732259,110.73100090026855,110.75400034586589,110.7770004272461,110.79999987284343,110.82200050354004,110.8439998626709,110.86599985758464,110.8879992167155,110.90900039672852,110.93000030517578,110.95100084940593,110.9710013071696,110.9919999440511,111.01200040181477,111.0310001373291,111.05099932352702,111.06999969482422,111.08900006612141,111.10699971516927,111.12600072224934,111.14400164286296,111.16200002034505,111.17900149027507,111.19700050354004,111.21400006612141,111.2309996287028,111.24700101216634,111.2640012105306,111.28000068664551,111.29500071207683,111.31100082397461,111.32600021362305,111.34100087483723,111.3559996287028,111.37000020345052,111.38399887084961,111.3980000813802,111.41200129191081,111.42499987284343,111.43900044759114,111.45099957784016,111.4640007019043,111.47599919637044,111.48899904886882,111.5,111.51199913024902,111.5230000813802,111.53400039672852,111.54500007629395,111.5549996693929,111.56599934895833,111.57600021362305,111.58499972025554,111.59499931335449,111.60400009155273,111.61299959818523,111.62200037638347,111.63000043233235,111.63800112406413,111.64599990844727,111.65399932861328,111.66099993387859,111.66800053914388,111.67500114440918,111.68199984232585,111.6879997253418,111.69400151570638,111.70000139872234,111.70499992370605,111.70999972025554,111.71500015258789,111.71999994913737,111.72500101725261,111.72899945576985,111.73299916585286,111.73600069681804,111.74000040690105,111.74300130208333,111.74599965413411,111.74899991353352,111.7509994506836,111.75300153096516,111.75499979654948,111.75600051879883,111.75800069173177,111.75900014241536,111.75999959309895,111.76000022888184,111.75999959309895,111.76000022888184,111.76000022888184,111.76000022888184,111.75900014241536,111.75800196329753,111.75600051879883,111.75499979654948,111.75300025939941,111.75100072224934,111.74899991353352,111.74600092569987,111.74400075276692,111.74200057983398,111.73999977111816,111.7370007832845,111.73499997456868,111.73299916585286,111.73100026448567,111.72899945576985,111.72600110371907,111.72399965922038,111.72199948628743,111.71999994913737,111.71700032552083,111.71500015258789,111.71299997965495,111.71100044250488,111.70800081888835,111.7060006459554,111.70399983723958,111.70200030008952,111.69899940490723,111.69699923197429,111.69499969482422,111.69299952189128,111.69099934895833,111.68799908955891,111.68600018819173,111.68399874369304,111.68199984232585,111.6790002187093,111.67699940999348,111.67499987284343,111.67300033569336,111.67000007629395,111.66800053914388,111.66599909464519,111.664000193278,111.66199938456218,111.6590010325114,111.65700022379558,111.65500005086263,111.65300051371257,111.64999961853027,111.64799880981445,111.64599927266438,111.64399909973145,111.64100011189778,111.63899993896484,111.6369997660319,111.63499959309895,111.63199996948242,111.63000043233235,111.62800025939941,111.6259994506836,111.6240005493164,111.62099901835124,111.61900011698405,111.6169999440511,111.61499849955241,111.61200014750163,111.61000061035156,111.60800043741862,111.6059996287028,111.60300000508626,111.6010004679362,111.59899965922038,111.59700012207031,111.59500058492024,111.59200032552083,111.59000015258789,111.58799997965495,111.58600044250488,111.58299891153972,111.5810006459554,111.57899920145671,111.57700030008952,111.57400004069011,111.57199986775716,111.56999969482422,111.56800079345703,111.56599998474121,111.5629997253418,111.56099955240886,111.55900065104167,111.55700047810872,111.55400085449219,111.55200068155925,111.54999923706055,111.54799969991048,111.54500071207683,111.54300117492676,111.54099973042806,111.53899955749512,111.53700002034505,111.53400039672852,111.53200085957845,111.52999941507976,111.52800051371257,111.52500025431316,111.52300071716309,111.52100054423015,111.5190003712972,111.51599947611491,111.51399930318196,111.5119997660319,111.51000022888184,111.50800069173177,111.5049991607666,111.50299898783366,111.5009994506836,111.49899991353352,111.49599965413411,111.49400011698405,111.49200057983398,111.49000040690105,111.4870007832845,111.48499997456868,111.48300043741862,111.4809996287028,111.47900009155273,111.47600173950195,111.47399965922038,111.47199948628743,111.46999994913737,111.46699968973796,111.46499951680501,111.46299997965495,111.46100107828777,111.45800081888835,111.45600001017253,111.45400047302246,111.45199966430664,111.45000139872234,111.44699986775716,111.44499969482422,111.4429988861084,111.44099998474121,111.43800036112468,111.43599891662598,111.43400128682454,111.43199984232585,111.42900149027507,111.42699940999348,111.42500114440918,111.42299906412761,111.42099952697754,111.41800053914388,111.41599909464519,111.41400082906087,111.41200002034505,111.40899976094563,111.40700022379558,111.40500068664551,111.40300051371257,111.40099970499675,111.39799944559734,111.39599927266438,111.39400100708008,111.39200019836426,111.38899993896484,111.38699913024902,111.38500022888184,111.38299942016602,111.38000043233235,111.3780008951823,111.37600072224934,111.3740005493164,111.37200037638347,111.36900075276692,111.36700057983398,111.36499977111816,111.36299959818523,111.35999997456868,111.35799980163574,111.35600026448567,111.35399945576985,111.35200055440266,111.34900029500325,111.3470007578532,111.34499994913737,111.34299977620442,111.33999888102214,111.33799997965495,111.33600044250488,111.33399963378906,111.33099937438965,111.32899983723958,111.32700030008952,111.32500012715657,111.32299995422363,111.3200003306071,111.31800015767415,111.31599871317546,111.31400044759114,111.31100018819173,111.30900128682454,111.30700047810872,111.30500030517578,111.30299949645996,111.30000114440918,111.29799969991048,111.29600016276042,111.2939993540446,111.29099973042806,111.28899892171223,111.28699938456218,111.28499984741211,111.2819995880127,111.28000068664551,111.27800051371257,111.2760009765625,111.27400016784668,111.27099990844727,111.2690003712972,111.26699956258138,111.26499938964844,111.26199849446614,111.26000086466472,111.2580000559489,111.25599988301595,111.25400034586589,111.25100008646648,111.24899927775066,111.24699974060059,111.24500020345052,111.2419999440511,111.24000104268391,111.2380002339681,111.23600069681804,111.23399925231934,111.2309996287028,111.22900009155273,111.2269999186198,111.22500101725261,111.22199948628743,111.21999931335449,111.2180004119873,111.21599960327148,111.21399943033855,111.21100044250488,111.20900026957194,111.20700009663899,111.20500055948894,111.20200030008952,111.20000076293945,111.19799931844075,111.19699923197429};
    //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761542737483978,1.4129000008106232,1.4511199990908306,1.4903099934260051,1.530790001153946,1.5725699961185455,1.6156300107638042,1.658920019865036,1.7013599872589111,1.7429600059986115,1.7837199966112773,1.8236399988333385,1.862720012664795,1.9009600182374318,1.9383500119050343,1.9749100009600322,2.0106300115585327,2.0456600189208984,2.080150067806244,2.1141000191370645,2.147509972254435,2.1803899804751077,2.2127299904823303,2.244529962539673,2.275789976119995,2.306510011355082,2.336699962615967,2.365880012512207,2.3935900131861367,2.4198399782180786,2.4446100195248923,2.4679100116093955,2.489739994208018,2.510099987188975,2.528990010420481,2.546410004297892,2.56237002213796,2.576960027217865,2.5903199911117554,2.6024399995803833,2.613309999306997,2.6229400038719177,2.631339987119039,2.6385000149408975,2.644409974416097,2.6490899523099265,2.652530014514923,2.655330002307892,2.6580599745114646,2.6607399781545005,2.6633600195248923,2.6659200191497803,2.668429990609487,2.6708800196647644,2.673270026842753,2.675600012143453,2.6778800090154014,2.6801100174585977,2.6823099851608276,2.684460004170736,2.6865800420443215,2.6886600255966187,2.6907099882761636,2.692710002263387,2.6946800152460733,2.696600000063578,2.6984899838765464,2.70033997297287,2.7021600008010864,2.7039300203323364,2.7056600054105124,2.7073599894841514,2.709019978841146,2.710629959901174,2.71220999956131,2.7137500246365867,2.7152600089708963,2.7167199850082397,2.718160013357798,2.719559987386068,2.720929980278015,2.7222700119018555,2.723579982916514,2.7248599926630654,2.7261100014050803,2.7273199955622354,2.728510002295176,2.72967000802358,2.730809986591339,2.731950044631958,2.7330700159072876,2.73417999347051,2.7352700233459473,2.7363400061925254,2.7374099691708884,2.7384600241978965,2.7394999861717224,2.740519960721334,2.7415199478467307,2.742519994576772,2.743499994277954,2.7444699803988137,2.745429972807566,2.746370017528534,2.747289995352427,2.748209993044535,2.749109983444214,2.749990006287893,2.7508699893951416,2.7517199913660684,2.7525699536005654,2.753399988015493,2.7542200088500977,2.755020022392273,2.755810042222341,2.7565800150235495,2.7573400139808655,2.758089999357859,2.7588299910227456,2.7595499952634177,2.7602500319480896,2.760949989159902,2.7616299986839294,2.7622900207837424,2.762939989566803,2.763580063978831,2.764209965864817,2.7648199597994485,2.7654199997584024,2.765999992688497,2.766569972038269,2.7671200037002563,2.767669995625814,2.7682000001271567,2.7687099973360696,2.769219994544983,2.769700010617574,2.7701799670855203,2.770640015602112,2.771090010801951,2.771530012289683,2.771940032641093,2.772350013256073,2.7727399667104087,2.7731200059254966,2.773490051428477,2.7738399704297385,2.774179995059967,2.7745099862416587,2.774820029735565,2.7751200000445047,2.775400002797445,2.775669972101847,2.7759299874305725,2.7761699755986533,2.7764000296592712,2.7766199906667075,2.7768200039863586,2.7770100037256875,2.7771899898846946,2.7773500084877014,2.777500013510386,2.7776400049527488,2.7777600288391113,2.777870019276937,2.7779600024223328,2.7780500253041587,2.77811998128891,2.7781699895858765,2.7782100240389505,2.7782400051752725,2.7782500187555947,2.7782600124677024,2.778239985307058,2.778219997882843,2.7781800031661987,2.77811998128891,2.778059979279836,2.7779799898465476,2.777880012989044,2.777780016263326,2.7776600122451782,2.777520020802816,2.777369956175486,2.777210017045339,2.7770400047302246,2.7768499851226807,2.776649991671244,2.776429990927378,2.7762099504470825,2.7759599884351096,2.7757100264231362,2.775439977645874,2.775159994761149,2.7748700181643167,2.77456001440684,2.774240016937256,2.7739099860191345,2.773560027281443,2.773200035095215,2.772820015748342,2.7724300026893616,2.772029995918274,2.771619975566864,2.771190027395884,2.770750025908152,2.7702899972597756,2.7698300083478293,2.7693399786949158,2.768850008646647,2.768339991569519,2.7678199807802835,2.7672800024350486,2.7667400240898132,2.7661799589792886,2.765600005785624,2.7650099992752075,2.7644099990526834,2.763790011405945,2.763169984022776,2.7625199953715005,2.761870006720225,2.7612000107765198,2.7605199813842773,2.759820024172465,2.759119987487793,2.7583999832471213,2.7576599717140198,2.7569199601809182,2.7561599810918174,2.7553800145785012,2.7545999884605408,2.753800014654795,2.7529799739519754,2.7521599928538003,2.751320004463196,2.7504700223604837,2.7496099869410195,2.7487500111262,2.747889995574951,2.747030019760132,2.7461700240770974,2.7453200022379556,2.7444600065549216,2.7436000307401023,2.742740035057068,2.7418899734814963,2.7410300175348916,2.7401700019836426,2.739320000012716,2.7384599844614663,2.7376100222269693,2.736749986807505,2.7358999848365784,2.735039989153544,2.7341900070508323,2.733329991499583,2.732480009396871,2.7316200137138367,2.7307700316111245,2.7299200097719827,2.7290600140889487,2.728209992249807,2.72736003001531,2.726510008176168,2.7256500124931335,2.7247999906539917,2.7239500085512796,2.723100006580353,2.722250004609426,2.721399982770284,2.720550000667572,2.71969997882843,2.718849996725718,2.718000034491221,2.7171499927838645,2.7162999709447226,2.7154499888420105,2.7145999868710837,2.713759978612264,2.7129100561141968,2.71205997467041,2.711210012435913,2.7103700240453086,2.7095199823379517,2.7086700002352395,2.70782999197642,2.706979990005493,2.7061299681663513,2.7052899996439614,2.7044399778048196,2.703599969546,2.7027499675750732,2.7019100189208984,2.701069990793864,2.700220008691152,2.6993799805641174,2.6985300183296204,2.697690029939016,2.6968500216801963,2.6960099935531616,2.6951599717140198,2.69432000319163,2.6934799750645957,2.692640006542206,2.6918000181516013,2.6909600098927817,2.6901100079218545,2.689269999663035,2.6884299914042153,2.687590022881826,2.6867499947547913,2.6859099864959717,2.6850800116856894,2.68424000342687,2.683400015036265,2.6825600067774453,2.6817199985186257,2.6808800101280212,2.680049995581309,2.6792100270589194,2.6783699989318848,2.6775300105412803,2.676700015862783,2.6758599877357483,2.6750200192133584,2.674190024534861,2.673349996407827,2.672520021597544,2.67167999347051,2.6708499987920127,2.670009990533193,2.669179995854696,2.668350021044413,2.6675100127855935,2.6666799982388816,2.665850023428599,2.6650099555651345,2.6641799807548523,2.6633500258127847,2.6625199715296426,2.6616799434026084,2.6608499884605408,2.660020033518473,2.659190018971761,2.6583599845568338,2.6575300097465515,2.656699995199839,2.655870020389557,2.65503998597463,2.6542099912961326,2.6533799966176352,2.652550001939138,2.6517200469970703,2.650889972845713,2.650059958299001,2.649240016937256,2.648409982522329,2.6475799679756165,2.646750013033549,2.645930012067159,2.6450999776522317,2.6442700028419495,2.6434499820073447,2.642620007197062,2.6418000062306723,2.64096999168396,2.6401400367418923,2.6393200159072876,2.6384900212287903,2.6376700003941855,2.6368499795595803,2.636020024617513,2.635200003782908,2.6343800028165183,2.633549988269806,2.632730007171631,2.6319100062052407,2.6310800313949585,2.6302600105603537,2.6294399897257485,2.628619988759359,2.6277999877929688,2.6269800265630088,2.6261600255966187,2.625339984893799,2.624520003795624,2.623699982961019,2.6228800415992737,2.622060000896454,2.621240019798279,2.620419979095459,2.6195999582608542,2.618779997030894,2.617960035800934,2.617139975229899,2.6163300275802612,2.6155099868774414,2.6146900057792664,2.6138700246810913,2.6130599975585938,2.6122399965922036,2.611429989337921,2.6106099685033164,2.609790007273356,2.6089800000190735,2.6081599990526834,2.607349991798401,2.606530030568441,2.6057200034459433,2.604899982611338,2.6040899554888406,2.603280007839203,2.6024600068728128,2.6016499400138855,2.6008400321006775,2.60003000497818,2.59921000401179,2.5984000166257224,2.597589989503225,2.596780021985372,2.5959699749946594,2.5951499740282693,2.5943400065104165,2.593530019124349,2.5927199125289917,2.5919100046157837,2.591099997361501,2.5902900298436484,2.589480002721151,2.58868000904719,2.587869962056478,2.5870599945386252,2.5862500270207724,2.58543998003006,2.584629992643992,2.5838299989700317,2.583019971847534,2.5822100043296814,2.5814000169436135,2.5805999636650085,2.579790016015371,2.57899002234141,2.5781799952189126,2.57737002770106,2.57656999429067,2.575760026772817,2.574959953625997,2.574149966239929,2.5733500321706138,2.572550038496653,2.571739991505941,2.5709399978319802,2.570140024026235,2.569330016771952,2.568530023097992,2.5677299896876016,2.566920002301534,2.566119988759359,2.565319995085398,2.5645199616750083,2.5637200077374778,2.5629199941953025,2.562120000521342,2.5613200068473816,2.5605199734369912,2.559719999631246,2.5589200059572854,2.558120012283325,2.55731999874115,2.5565199851989746,2.555720011393229,2.554920017719269,2.554119964440664,2.5533200105031333,2.552529990673065,2.5517300168673196,2.5509299437204995,2.550129989782969,2.549339989821116,2.5485399961471558,2.547750016053518,2.546950022379557,2.546149969100952,2.545360008875529,2.5449599424997964};
    SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.568445841471354,8.884455839792887,9.182517131169638,9.511126597722372,9.84283677736918,10.17760682106018,10.515506982803345,10.856706857681274,11.201407194137573,11.549506982167562,11.901207208633423,12.256307204564413,12.614907344182333,12.9769074122111,13.342507441838583,13.711507558822632,14.084007660547892,14.459507624308268,14.837507724761963,15.21810777982076,15.60130778948466,15.987007935841879,16.375207901000977,16.766008059183758,17.159307956695557,17.555107911427815,17.953507741292317,18.345407485961914,18.72180716196696,19.08260663350423,19.427806854248047,19.75760618845622,20.07180579503377,20.370505332946777,20.65370527903239,20.92130486170451,21.1735045115153,21.408104101816814,21.62320391337077,21.818803469340008,21.994903087615967,22.15150260925293,22.28850253423055,22.4061017036438,22.504101594289143,22.582701047261555,22.64180072148641,22.690900961558025,22.73940086364746,22.787400881449383,22.834800561269123,22.88170099258423,22.928101062774658,22.97390079498291,23.019200960795086,23.06390078862508,23.10810089111328,23.151701132456463,23.19480101267497,23.237301031748455,23.279200553894043,23.320600986480713,23.361400763193767,23.40170081456502,23.44140100479126,23.480600833892822,23.519200801849365,23.55720090866089,23.594600836435955,23.63140042622884,23.667500813802082,23.70310052235921,23.73810084660848,23.77240053812663,23.806100845336914,23.839200655619305,23.871700445810955,23.90360101064046,23.934700806935627,23.965200583140057,23.9950008392334,24.024100462595623,24.05250056584676,24.08030064900716,24.107300599416096,24.133700370788574,24.159300645192463,24.184600512186687,24.2096004486084,24.23430061340332,24.2589004834493,24.28320074081421,24.30720059076945,24.331100304921467,24.354700406392414,24.378100554148357,24.401300589243572,24.42430067062378,24.44700034459432,24.46950054168701,24.49180046717326,24.513800462086994,24.535600662231445,24.55720027287801,24.57860056559245,24.599700291951496,24.620600541432697,24.641300519307453,24.661800543467205,24.682000001271565,24.70200030008952,24.721800168355305,24.741400559743244,24.760700225830078,24.779800573984783,24.7987003326416,24.817400614420574,24.835800329844158,24.854000409444172,24.872000376383465,24.88980023066203,24.9073003133138,24.92460012435913,24.941700140635174,24.958600521087646,24.975200335184734,24.991700490315754,25.007800261179607,25.023800532023113,25.039600213368733,25.055100282033283,25.07040007909139,25.085400422414143,25.100300312042236,25.114900430043537,25.129300276438396,25.143500169118244,25.157400131225586,25.17120059331258,25.18470033009847,25.19790045420329,25.211000124613445,25.223800500233967,25.23640028635661,25.248799959818523,25.26099983851115,25.272900104522705,25.284700234731037,25.296200434366863,25.307400544484455,25.31850020090739,25.32930024464925,25.33990017573039,25.350300312042236,25.36050033569336,25.370400110880535,25.38010040918986,25.38960027694702,25.398900190989178,25.40790017445882,25.416800181070965,25.425400098164875,25.43380006154378,25.4419002532959,25.449900309244793,25.457600116729736,25.465100288391113,25.472400347391766,25.479400157928467,25.486200014750164,25.492900053660076,25.499199867248535,25.505400498708088,25.5114000638326,25.517099857330322,25.522600173950195,25.527899901072185,25.53290049235026,25.5377999941508,25.542400360107422,25.546799818674724,25.551000118255615,25.55500014623006,25.55869992574056,25.562199592590332,25.565499941507976,25.568600018819172,25.571500142415363,25.574100017547607,25.576499938964844,25.578700065612793,25.580700238545734,25.582499821980793,25.58400011062622,25.585299968719482,25.586400032043457,25.587300141652424,25.588000138600666,25.58839988708496,25.58859984079997,25.588599999745686,25.58839988708496,25.58799997965495,25.587300300598145,25.586499849955242,25.585400104522705,25.584100087483723,25.582499980926514,25.58080005645752,25.578799883524578,25.576600074768066,25.57419999440511,25.571599801381428,25.56879981358846,25.56570021311442,25.562399864196777,25.558900038401287,25.555199940999348,25.551299730936687,25.547200043996174,25.54279963175456,25.53820006052653,25.53339958190918,25.5283997853597,25.523199876149494,25.517699877421062,25.51199992497762,25.506099700927734,25.499999682108562,25.4936998685201,25.487199783325195,25.48039960861206,25.47339979807536,25.46620003382365,25.458799839019775,25.451200008392334,25.443399747212727,25.435400009155273,25.427499771118164,25.41949987411499,25.41159995396932,25.403599898020428,25.395699977874756,25.387799739837646,25.379799683888752,25.371900240580242,25.36399968465169,25.35610008239746,25.34809970855713,25.3402001063029,25.332300027211506,25.324399789174397,25.316500027974445,25.308599948883057,25.300599733988445,25.292699813842773,25.284799734751385,25.276899973551433,25.26899989446004,25.261099815368652,25.253300189971924,25.245399951934814,25.237500031789143,25.229599793752033,25.221699873606365,25.213799794514973,25.205899874369305,25.198099772135418,25.190200010935467,25.182299613952637,25.174499829610188,25.16659990946452,25.158699989318848,25.1509002049764,25.14299964904785,25.135199546813965,25.127299626668293,25.119399706522625,25.111599604288738,25.10379997889201,25.0958997408549,25.08809995651245,25.080199718475342,25.072399934132893,25.06459967295329,25.056699752807617,25.04889980951945,25.04109986623128,25.033199946085613,25.025399843851726,25.01759974161784,25.00979979832967,25.001999855041504,24.994200070699055,24.98639980951945,24.9785000483195,24.970699628194172,24.962899843851726,24.955100059509277,24.94729979832967,24.93959967295329,24.93180004755656,24.923999945322674,24.916200002034504,24.9083997408549,24.90059979756673,24.892800013224285,24.88510004679362,24.877299944559734,24.869499524434406,24.861699899037678,24.854000091552734,24.846199830373127,24.838399569193523,24.830700079600017,24.82289997736613,24.815200010935467,24.80739959081014,24.799699783325195,24.79189984003703,24.784200032552082,24.776399612426758,24.76869996388753,24.760900020599365,24.753199736277264,24.7454997698466,24.73769982655843,24.729999860127766,24.7222998936971,24.714599609375,24.70679982503255,24.69909969965617,24.691400051116943,24.68369960784912,24.676000277201336,24.668299833933514,24.66059970855713,24.65279992421468,24.645099957784016,24.637399673461914,24.62969986597697,24.622099717458088,24.614399909973145,24.60669994354248,24.598999977111816,24.591299692789715,24.58360004425049,24.575899918874104,24.56820011138916,24.56059964497884,24.552899678548176,24.545199712117512,24.53760004043579,24.529899915059406,24.522200266520183,24.514599800109863,24.5068998336792,24.499199708302815,24.491599877675373,24.483899752298992,24.47629960378011,24.468600114186604,24.460999965667725,24.453399658203125,24.4457000096639,24.43810002009074,24.430400053660076,24.422799746195476,24.415200074513752,24.40749979019165,24.39989995956421,24.392300128936768,24.384700139363606,24.377099831899006,24.369399706522625,24.361799875895183,24.354199568430584,24.34659989674886,24.33899974822998,24.3313995997111,24.323799928029377,24.316199779510498,24.308600107828777,24.300999959309895,24.293399969736736,24.285799821217854,24.278199990590412,24.270599842071533,24.263099988301594,24.255499839782715,24.247899691263836,24.240299860636394,24.232699871063232,24.225200176239014,24.217599550882976,24.209999879201252,24.202499866485596,24.194900035858154,24.187399705251057,24.179800033569336,24.172200043996174,24.16469971338908,24.157100041707356,24.1496000289917,24.142000039418537,24.134499708811443,24.126999855041504,24.119399865468342,24.111899852752686,24.10439984003703,24.096799691518147,24.08929951985677,24.08179982503255,24.07420015335083,24.066699981689453,24.059199810028076,24.051699956258137,24.04419994354248,24.036699771881104,24.02909978230794,24.021599928538006,24.014099597930908,24.00659990310669,23.999099890391033,23.991600036621094,23.984099864959717,23.976600011189777,23.96909999847412,23.961699803670246,23.95419994990031,23.946699460347492,23.939199924468994,23.931699752807617,23.9242000579834,23.916800022125244,23.909299850463867,23.90179983774821,23.894399801890057,23.88689947128296,23.8794002532959,23.871999740600586,23.864499886830647,23.857099850972492,23.849599838256836,23.84209982554118,23.834699948628742,23.82729975382487,23.81979990005493,23.812400023142498,23.8048996925354,23.797499815622967,23.790099620819092,23.782599608103435,23.77519989013672,23.767800013224285,23.760300000508625,23.75290012359619,23.7454997698466,23.738099733988445,23.730599880218506,23.72319984436035,23.715799808502197,23.708399454752605,23.70099973678589,23.693599859873455,23.686199982961018,23.678799788157146,23.67139991124471,23.663999716440838,23.6565998395284,23.64919964472453,23.641799767812092,23.634399731953938,23.627099990844727,23.61969979604085,23.612299760182697,23.604899724324543,23.59749984741211,23.590199947357178,23.582799911499023,23.57539987564087,23.568099975585938,23.560699780782063,23.55329990386963,23.546000003814697,23.54230006535848};
    //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.1294618248939514,2.2204293807347617,2.2993471225102744,2.3890169858932495,2.481217165788015,2.5758573412895203,2.672877311706543,2.7680971225102744,2.8574770291646323,2.9411568641662598,3.0193167130152383,3.092106580734253,3.1596664587656655,3.2221363186836243,3.2796661853790283,3.3323960105578103,3.380445917447408,3.424535870552063,3.4653357664744058,3.502955694993337,3.5374655723571777,3.568965494632721,3.5975353916486106,3.6232653061548867,3.6462152202924094,3.666485150655111,3.6841349005699158,3.69748463233312,3.704904397328695,3.7065341671307883,3.7025339007377625,3.69302366177241,3.678143401940664,3.6580331722895303,3.632832964261373,3.6026726961135864,3.5676724712053933,3.528372287750244,3.4853220780690513,3.438631852467855,3.388391653696696,3.33471143245697,3.2776812314987183,3.2174110213915506,3.153980851173401,3.087480664253235,3.018010596434275,2.947920580705007,2.8795105814933777,2.8127505580584207,2.7475905815760293,2.683990557988485,2.6219205260276794,2.5613405307133994,2.50221053759257,2.4444905122121177,2.3881505330403647,2.3331904808680215,2.2795905073483786,2.2273404796918235,2.1763804952303567,2.126700480779012,2.07824045419693,2.0310004552205405,1.9849204520384471,1.9399904608726501,1.8961704472700756,1.8534204562505086,1.811710427204768,1.771020422379176,1.731320430835088,1.6925704181194305,1.6547504166762035,1.6178504129250844,1.5818304022153218,1.546670377254486,1.5123603840668995,1.4788903792699177,1.4462503790855408,1.414410392443339,1.3833603759606679,1.3530603647232056,1.3235003451506298,1.2946503361066182,1.2665003438790639,1.2390303413073223,1.212210347255071,1.1860603392124176,1.1605903506278992,1.1358003218968709,1.1116503179073334,1.088120311498642,1.065210332473119,1.0428903301556904,1.0211403171221416,0.9999523013830185,0.9793093105157217,0.9591953108708063,0.9395953118801117,0.9204943130413691,0.9018793056408564,0.88373630742232,0.8660513063271841,0.8488122969865799,0.8320062905550003,0.8156202981869379,0.7996432880560557,0.7840612928072611,0.7688622872034708,0.7540382941563925,0.7395792752504349,0.7254752715428671,0.7117152760426203,0.6982892751693726,0.6851892669995626,0.6724052727222443,0.6599292755126953,0.6477512667576472,0.6358632644017538,0.6242572714885076,0.612925261259079,0.6018562614917755,0.5910442570845286,0.5804832577705383,0.5701662550369898,0.5600882470607758,0.5502402484416962,0.5406172424554825,0.5312122454245886,0.522019237279892,0.5130322525898615,0.5042462348937988,0.49565323690573376,0.4872502312064171,0.4790272240837415,0.4709802220265071,0.4631072257955869,0.4554022202889125,0.4478612169623375,0.44047921895980835,0.433252215385437,0.42617521186669666,0.4192442124088605,0.4124552036325137,0.4058042069276174,0.39928720394770306,0.3929001986980438,0.38664019852876663,0.3805001974105835,0.374476191898187,0.3685691903034846,0.362775186697642,0.35709018508593243,0.351512186229229,0.34603818009297055,0.34066518147786456,0.33539018034935,0.330209178229173,0.3251221751173337,0.32012417415777844,0.3152141695221265,0.31038516759872437,0.3056371659040451,0.300969161093235,0.296379158894221,0.29186516255140305,0.2874251554409663,0.28305714825789136,0.2787591516971588,0.2745291516184807,0.270365151266257,0.2662651439507802,0.262227142850558,0.2582501371701558,0.25433313846588135,0.2504691357413928,0.2466591348250707,0.2429031307498614,0.23919912924369177,0.2355481262008349,0.23194612314303717,0.2283921204507351,0.22488611936569214,0.22142611940701803,0.21801011388500532,0.21463811273376146,0.21130811050534248,0.2080181079606215,0.20476910720268884,0.20155610516667366,0.19837710137168565,0.19523509964346886,0.1921290966371695,0.18905809397498766,0.18602009490132332,0.18301508948206902,0.18004209051529566,0.17710008472204208,0.17418908327817917,0.1713060811161995,0.16845307871699333,0.16562607636054358,0.16282407566905022,0.16004607329765955,0.15729307010769844,0.15456506858269373,0.15186106537779173,0.1491800658404827,0.14652306213974953,0.14388705790042877,0.14127405608693758,0.1386810541152954,0.13610905160506567,0.1335560493171215,0.13102304811278978,0.12850904588898024,0.12601004292567572,0.12352604046463966,0.12105903774499893,0.11861003500719865,0.11617603339254856,0.11375903089841206,0.11135702890654404,0.10897102765738964,0.10659902480741341,0.10424102221926053,0.10189701989293098,0.09956681728363037,0.09724951597551505,0.0949450135231018,0.09265001180271308,0.09036420906583469,0.08809030552705129,0.0858279038220644,0.08357670344412327,0.08133639891942342,0.07910669967532158,0.07691310035685699,0.07478030025959015,0.07270659940938155,0.0706905002395312,0.06873029905060928,0.06682440017660458,0.06497150100767612,0.06316990063836177,0.06141830049455166,0.05971520021557808,0.058059400568405785,0.05644959987451633,0.054884299635887146,0.05336250023295482,0.05188289967676004,0.05044429997603098,0.049045699958999954,0.04768579980979363,0.04636360021928946,0.045078100015719734,0.043828299889961876,0.042613100881377854,0.041431600227952003,0.04028290013472239,0.03916600036124388,0.038080100590984024,0.03702440050741037,0.03599789987007777,0.03499979991465807,0.0340295002485315,0.03308600001037121,0.0321688000112772,0.031276899855583906,0.030409800199170906,0.029566699638962746,0.02874699995542566,0.027950099979837734,0.027175200326989096,0.026421799945334595,0.025689399956415098,0.024977199888477724,0.024284800204137962,0.023611499927937984,0.022956999950110912,0.022320600071301062,0.021701800171285868,0.021100199936578672,0.02051529986783862,0.019946600155284006,0.019393600057810545,0.018855999999990065,0.01833330001682043,0.017825100105255842,0.017330999796589214,0.01685059970865647,0.016383500304073095,0.015929299872368574,0.015487800119444728,0.015058500071366629,0.014641099997485677,0.014235199972366294,0.013840600072095791,0.013457000100364288,0.013084000054125985,0.012721299892291427,0.012368700156609217,0.012025899874667326,0.011692499974742532,0.011368400184437633,0.011053300074612101,0.01074700003179411,0.01044909997532765,0.010159500020866593,0.009877859925230345,0.009604079959293207,0.009337890039508542,0.009079069985697666,0.00882742996327579,0.008582769893109798,0.008344889851287007,0.008113600003222624,0.007888719827557603,0.007670080095219116,0.007457500013212363,0.007250819976131122,0.007049859967082739,0.006854470004327595,0.006664499950905641,0.0064797899685800076,0.0063002100214362144,0.006125599999601643,0.005955829983577132,0.005790770053863525,0.005630290019325912,0.005474249948747456,0.005322539946064353,0.005175029975362122,0.005031609985356529,0.004892169963568449,0.004756590002216399,0.004624780034646392,0.004496610024943948,0.004371999956977864,0.004250839973489444,0.004133040007824699,0.004018499981611967,0.0039071400339404745,0.003798859989425788,0.0036935899794722595,0.003591240015036116,0.003491720010060817,0.0033949599989379444,0.0033008800237439573,0.0032094100024551153,0.003120469977147877,0.003033999955126395,0.0029499300095873573,0.002868179988581687,0.0027886999887414277,0.0027114300173707306,0.002636289980728179,0.0025632400065660477,0.0024922200245782733,0.002423160030351331,0.002356010004101942,0.002290729976569613,0.0022272500209510326,0.0021655400244829557,0.0021055300215569637,0.002047190035227686,0.001990470006906738,0.001935310021508485,0.0018816899973899126,0.00182955000976411,0.0017788599943742156,0.0017295699993458886,0.0016816399875096977,0.0016350499839366723,0.001589749997947365,0.0015457000020736207,0.0015028699999675155,0.0014612299855798483,0.001420739999351402,0.0013813799984442692,0.0013431099941954017,0.001305890007643029,0.0012697099979656439,0.0012345299959027518,0.001200329987720276,0.0011670700138589989,0.0011347299829746287,0.0011033000094660868,0.0010727300153424342,0.0010430100082885474,0.0010141099919565022,0.0009860129891118656,0.0009586949987957875,0.0009321339894086123,0.0009063090013417726,0.0008812000063092759,0.0008567860058974475,0.0008330489945365116,0.0008099699965290105,0.0007875300070736557,0.0007657120004296303,0.0007444980001309887,0.000723872998302492,0.0007038179998441289,0.0006843199953436852,0.0006653610083352154,0.0006469279954520365,0.0006290059973252937,0.0006115800012291098,0.0005946379969827831,0.0005781640065833926,0.0005621469996791953,0.0005465740153643613,0.0005314320102722073,0.0005167100025573745,0.0005023959965910763,0.000488477996744526,0.0004749460010013233,0.000461789000837598,0.00044899599500543747,0.0004365579976971882,0.00042446500204581145,0.0004127060019527562,0.00040127400279743597,0.0003901579960559805,0.0003793499975775679,0.0003688409997266717,0.00035862400303206715,0.00034868900062671554,0.0003390300043975003,0.0003296390010897691,0.0003205079968514231,0.0003116290002556828,0.000302996998167752,0.00029460400401148945,0.00028644299648779753,0.00027850900126698736,0.0002707939978184489,0.000263292997260578,0.0002559999969283429,0.0002489079997758381,0.00024201399961990924,0.00023531000139579797,0.0002287920009014973,0.0002224549995541262,0.0002162930007519511,0.0002103019990803053,0.00020447600036277436,0.00019881299764771634,0.00019330599995252365,0.00018795099822455086,0.00018274500083255893,0.00017768399993656203,0.0001727620001474861,0.00016797699815166803,0.0001633240002168653,0.00015879999894726401,0.00015440200028630594,0.00015012499958781214,0.00014596700081407712,0.00014192399855043428,0.00013799300116564459,0.00013417100126389414,0.00013045499993798634,0.00012684200191870332,0.00012332900041656103,0.00011991300076867144,0.00011659200087403103,0.0001133620001686116,0.00011022300047140259,0.0001071699995615442,0.00010420100018867136,0.00010131499948329292,9.850939992854062e-05,9.578110014748138e-05,9.312830055326533e-05,9.054900025754857e-05,8.804120019097657e-05,8.560280002711806e-05,8.323199836013373e-05,8.092680036497768e-05,7.86855004359192e-05,7.650630080509775e-05,7.438740006667406e-05,7.334280053328257e-05};
    CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11865997314453,80.86888949076335,79.52099291483562,78.11739349365234,76.66659482320149,75.17629750569661,73.65369860331218,72.10530090332031,70.53720219930013,68.95500373840332,67.36350377400716,65.76730600992839,64.17050552368164,62.57680575052897,60.98940658569336,59.41150792439779,57.845808347066246,56.294708251953125,54.76040840148926,53.24480946858724,51.74960899353027,50.2763090133667,48.826209704081215,47.40040969848633,45.99990971883138,44.62540976206461,43.277709325154625,41.95721022288004,40.66440963745117,39.39980951944987,38.163710276285805,36.9563102722168,35.77770964304606,34.628109296162926,33.50730959574381,32.415409564971924,31.35210943222046,30.31740887959798,29.310908953348797,28.332308451334637,27.381308396657307,26.457608064015705,25.560708045959473,24.69010814030965,23.845507780710857,23.026407559712727,22.232307593027752,21.462607383728027,20.716907183329266,19.994606653849285,19.295206864674885,18.61820650100708,17.9629062016805,17.328906059265137,16.715505917867024,16.122306029001873,15.548705577850342,14.994105418523153,14.458105246225992,13.940105120340982,13.439604918162027,12.956004778544107,12.48890471458435,12.037804444630941,11.602204402287802,11.181604385375977,10.775504032770792,10.383603890736898,10.005303780237833,9.640183607737223,9.287893613179525,8.947993516921997,8.620083332061768,8.303763310114542,7.998663266499837,7.704402923583984,7.420622905095418,7.1469829479853315,6.883142789204915,6.628752589225769,6.383522550264995,6.147122422854106,5.919252435366313,5.699612299601237,5.487942258516948,5.283942143122355,5.082682212193807,4.884352246920268,4.693812171618144,4.510771989822388,4.334921995798747,4.1659819682439165,4.003671805063884,3.8477317094802856,3.6979116598765054,3.5539716283480325,3.4156715671221414,3.282791495323181,3.1551214257876077,3.0324513713518777,2.914581298828125,2.80132124821345,2.6925012270609536,2.5879311760266623,2.487451136112213,2.3909010688463845,2.2981210152308145,2.2089710036913552,2.1233009497324624,2.040970961252848,1.961860865354538,1.8858408431212108,1.8127808173497517,1.7425707777341206,1.6750907401243846,1.6102507213751476,1.5479306876659393,1.488040695587794,1.4304906328519185,1.375170628229777,1.322010596593221,1.2709105809529622,1.2218105693658192,1.1746105253696442,1.1292505264282227,1.085650493701299,1.0437404612700145,1.0034704556067784,0.9647544473409653,0.9275444100300471,0.8917774011691412,0.8573983758687973,0.824352373679479,0.7925873547792435,0.7620523373285929,0.7327003280321757,0.7044833153486252,0.6773583044608434,0.6512822955846786,0.6262152791023254,0.6021162668863932,0.5789472609758377,0.5566742519537607,0.5352602352698644,0.5146732280651728,0.49488022178411484,0.4758502095937729,0.4575532029072444,0.4399621958533923,0.4230481932560603,0.4067861835161845,0.39115017652511597,0.3761161689956983,0.3616611634691556,0.34776115665833157,0.3343971495827039,0.32154614229997,0.3091891383131345,0.2973081370194753,0.2858831286430359,0.27489712337652844,0.2643331165115039,0.2541751141349475,0.24440811077753702,0.2350161075592041,0.2259851023554802,0.21730109800895056,0.20895109449823698,0.20092208807667097,0.19320208579301834,0.1857780839006106,0.17863907913366953,0.17177507653832436,0.1651750740905603,0.15882807100812593,0.1527260666092237,0.14685706545909247,0.14121506238977113,0.1357890603442987,0.13057205950220427,0.12555505645771822,0.12073105449477832,0.11609305255115032,0.1116330511868,0.10734404747684796,0.10322004618744056,0.09925424369672935,0.09544104399780433,0.09177454250554244,0.08824883898099263,0.08485863916575909,0.08159873634576797,0.07846413490672906,0.0754499329874913,0.07255153295894463,0.06976463086903095,0.06708473029235999,0.06450782902538776,0.06202992796897888,0.059647227016588054,0.05735612567514181,0.05515302469333013,0.053034624084830284,0.05099752297004064,0.049038722179830074,0.04715522130330404,0.04534412051240603,0.04360251904775699,0.041927919102211796,0.040317618288099766,0.03876911817739407,0.03728021619220575,0.03584841638803482,0.03447171549002329,0.03314781499405702,0.03187481500208378,0.030650713636229437,0.029473613016307354,0.028341812857737143,0.027253412175923586,0.02620691169674198,0.02520051132887602,0.02423281113927563,0.023302310301611822,0.022407509852200747,0.021547109664728243,0.02071970918526252,0.019924109025547903,0.01915910855556528,0.018423408114661772,0.01771600777283311,0.017035807482898235,0.01638170735289653,0.015752806871508557,0.015148006845265627,0.01456640645240744,0.014007106190547347,0.013469405937939882,0.012952305609360337,0.012455005509157976,0.011976905322323242,0.011517105080808202,0.011075004935264587,0.010649804801990589,0.010241004405543208,0.009847884609674415,0.009469864269097647,0.009106364178781709,0.008756823992977539,0.00842071371152997,0.008097503489504257,0.007786703451226155,0.007487833305882911,0.007200443263476093,0.006924093080063661,0.006658352989082535,0.0064028128593539195,0.006157082699549695,0.005920792658192416,0.005693572573363781,0.005475072422996163,0.005264972258980076,0.0050629222532734275,0.004868642194196582,0.004681812017224729,0.004502161988057196,0.004329401922101776,0.004163271825139721,0.004003531803997855,0.0038499117363244295,0.0037021916553688547,0.0035601415826628604,0.0034235415514558554,0.003292191463212172,0.0031658813823014498,0.0030444113460058966,0.0029276113297479847,0.0028152912661122778,0.002707281227534016,0.0026034211817507944,0.002503541142990192,0.002407501102425158,0.002315141047195842,0.0022263309995954237,0.002140920958481729,0.002058790938463062,0.001979820905641342,0.0019038708414882421,0.0018308408131512504,0.001760610796433563,0.0016930807808724542,0.0016281407345862438,0.0015656806936021894,0.0015056306729093194,0.0014478806503272306,0.0013923506388285507,0.0013389405891454469,0.0012875905764910083,0.0012382105730163555,0.0011907205528890092,0.001145050492292891,0.00110113049352852,0.0010589004668872803,0.0010182904661633074,0.000979241444535243,0.0009416874236194417,0.0009055744061091294,0.000870846391383869,0.0008374503716671219,0.0008053363514288018,0.0007744533407579487,0.0007447553313492487,0.0007161963148973882,0.0006887333147460595,0.0006623232960312938,0.0006369272838734711,0.0006125042758261164,0.0005890182607496778,0.000566433256608434,0.0005447152507258579,0.0005238292360445485,0.0005037442315369844,0.00048443021660204977,0.0004658572094437356,0.000447995204012841,0.0004308191904177268,0.00041430218213160214,0.00039841817973259214,0.00038314316770993173,0.0003684551629703492,0.0003543291580475246,0.00034074515133397654,0.0003276821468413497,0.0003151201429621627,0.0003030401373204465,0.0002914231299655512,0.0002802511250289778,0.0002695081226799327,0.00025917711172951385,0.00024924211417480063,0.00023968810758863887,0.000230500104711003,0.0002216650973423384,0.00021316809337198114,0.00020499709232050614,0.00019714008643253086,0.00018958308404156318,0.00018231708357537477,0.00017532907804707065,0.00016860907514152737,0.00016214707284234464,0.0001559320711142694,0.00014995606761658564,0.00014420806716467874,0.00013868106179870665,0.00013336606086037742,0.00012825505594567707,0.000123340055627826,0.00011861305392812937,0.0001140670507690326,0.00010969604833614237,0.00010549204671406187,8.480077243196622e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45194625854492,229.59260431925455,226.30871963500977,223.63971328735352,220.94271087646484,218.22270711263022,215.48170598347983,212.72470347086588,209.95470428466797,207.17370096842447,204.38470204671225,201.59170150756836,198.7957026163737,196.00070190429688,193.2067019144694,190.41670354207358,187.6337038675944,184.85870361328125,182.09270604451498,179.33870697021484,176.59770965576172,173.87171173095703,171.16071192423502,168.46571477254233,165.78971481323242,163.13272094726562,160.49472045898438,157.87872187296549,155.2837257385254,152.71172968546549,150.16272989908853,147.63873291015625,145.1407330830892,142.66873931884766,140.22373962402344,137.80674616495767,135.41774876912436,133.0577532450358,130.72775268554688,128.42675908406576,126.15576235453288,123.91476376851399,121.70476722717285,119.52577018737793,117.37777328491211,115.26077779134114,113.17477989196777,111.11978530883789,109.09678713480632,107.10479100545247,105.14379437764485,103.21279716491699,101.3138001759847,99.44480387369792,97.60620752970378,95.79771041870117,94.01901308695476,92.27001635233562,90.55042012532552,88.85982131958008,87.19802665710449,85.56472905476888,83.95943196614583,82.38193321228027,80.8317387898763,79.30873998006184,77.8124434153239,76.3425464630127,74.8985481262207,73.48025067647298,72.0873540242513,70.71925481160481,69.37575785319011,68.05646133422852,66.76096471150716,65.48906707763672,64.24016984303792,63.014171282450356,61.81047375996908,60.62887700398763,59.469078381856285,58.33058102925619,57.21308263142904,56.11628500620524,55.03978729248047,53.98339017232259,52.96779600779215,51.99179776509603,51.03309981028239,50.09130128224691,49.16610336303711,48.25740432739258,47.364806493123375,46.48810831705729,45.62700970967611,44.78131103515625,43.95061333974203,43.13491439819336,42.33381589253744,41.5470183690389,40.774518966674805,40.01581986745199,39.270822525024414,38.53922367095947,37.82092412312826,37.11552619934082,36.423027992248535,35.74302895863851,35.07532978057861,34.419931729634605,33.77633253733317,33.144533475240074,32.52423508961996,31.91533676783244,31.317537307739258,30.73063850402832,30.154539585113525,29.589041233062744,29.033941745758057,28.489043076833088,27.9541441599528,27.429144859313965,26.913846333821613,26.408047040303547,25.911547978719074,25.42434899012248,24.94605016708374,24.476651032765705,24.015951951344807,23.5637526512146,23.119953473409016,22.684454282124836,22.25695514678955,21.837456226348877,21.42575693130493,21.021657784779865,20.62505833307902,20.235759417215984,19.853760083516438,19.47886069615682,19.110861619313557,18.749762058258057,18.395262559254963,18.047463575998943,17.706064383188885,17.370965162913006,17.04216543833415,16.71946620941162,16.402766863505047,16.091867605845135,15.786868015925089,15.487468640009562,15.19356926282247,14.90516988436381,14.622170289357504,14.3443710009257,14.071771621704102,13.804272015889486,13.541672468185425,13.283973137537638,13.031073570251465,12.78287402788798,12.539374510447184,12.300375064214071,12.065775553385416,11.835575898488363,11.609776417414347,11.388076782226562,11.17057736714681,10.957177718480429,10.747778018315634,10.542278528213501,10.340678930282593,10.142879486083984,9.94871973991394,9.75825015703837,9.571380297342936,9.388020753860474,9.208131074905396,9.031641642252604,8.858461936314901,8.688562075297037,8.5218825340271,8.358352979024252,8.197893222173056,8.040483514467875,7.886053919792175,7.734554092089335,7.585904439290364,7.440074721972148,7.297025084495544,7.156685312589009,7.019025564193726,6.883975823720296,6.751486142476399,6.621516426404317,6.494006594022115,6.368936936060588,6.246257185935974,6.125897447268168,6.007837613423665,5.8920178810755415,5.778418183326721,5.666978319485982,5.5576686064402265,5.450448791186015,5.3452690442403155,5.242099205652873,5.1408993403116865,5.0416496594746905,4.944299777348836,4.848810076713562,4.7551601727803545,4.6633003155390425,4.573200623194377,4.4848207632700605,4.398140907287598,4.313111146291097,4.229701201121013,4.147891441980998,4.067641496658325,3.988941768805186,3.9117719531059265,3.8360620935757956,3.7618022362391152,3.6889723936716714,3.6175525188446045,3.54748264948527,3.478772819042206,3.4113929867744446,3.3453030784924827,3.280493219693502,3.2169333497683206,3.1545934875806174,3.093453586101532,3.033493717511495,2.9746938347816467,2.917013943195343,2.8604541222254434,2.8049741784731546,2.7505643367767334,2.69722443819046,2.644904534022013,2.5935946106910706,2.5432647665341697,2.4939048091570535,2.4455049435297647,2.3980350494384766,2.351475099722544,2.30583522717158,2.261085311571757,2.2171854178110757,2.1741355260213218,2.1319156090418496,2.0905156334241233,2.049895783265432,2.010075847307841,1.971035937468211,1.932765970627467,1.8952160875002544,1.8583861490090687,1.8222762246926625,1.7868763109048207,1.7521663804848988,1.7181164522965748,1.6847165028254192,1.6519665718078613,1.6198566257953644,1.5883767108122508,1.5575167536735535,1.5272368490695953,1.4975268840789795,1.4684069554011028,1.4398470222949982,1.4118570784727733,1.384407142798106,1.3574972053368886,1.3310972452163696,1.3051872849464417,1.2797873417536418,1.2548773884773254,1.2304674486319225,1.2065275013446808,1.183057536681493,1.1600475907325745,1.137487639983495,1.115377684434255,1.0936677356561024,1.0723677674929302,1.05147780974706,1.0310078461964924,1.0109279056390126,0.9912489453951517,0.9719519863526026,0.9530330250660578,0.9344840596119562,0.9162981063127518,0.8984691401322683,0.8809881756703059,0.8638502061367035,0.8470472445090612,0.8305732756853104,0.8143993069728216,0.7985213398933411,0.7829543749491373,0.7676913986603419,0.7527274290720621,0.7380564709504446,0.7236724942922592,0.7095705171426138,0.6957435558239619,0.6821875820557276,0.6688966204722723,0.6558656444152197,0.6430906603733698,0.6305646946032842,0.6182837188243866,0.6062427461147308,0.5944377680619558,0.582864781220754,0.571516806880633,0.5603908350070318,0.5494828522205353,0.5387888848781586,0.5283038963874181,0.5180229246616364,0.5079439481099447,0.49806197235981625,0.48837298651536304,0.4788740078608195,0.46956103046735126,0.46043004592259723,0.4514770656824112,0.44269907971223194,0.4340930978457133,0.42563411096731824,0.4173191264271736,0.4091671481728554,0.4011741628249486,0.3933371802171071,0.3856532002488772,0.37812021126349765,0.3707342321674029,0.36349324385325116,0.356393260260423,0.3494322746992111,0.3426072845856349,0.33591529975334805,0.32935431351264316,0.32292232910792035,0.3166153406103452,0.3104323521256447,0.30436936765909195,0.2984253764152527,0.2925973857442538,0.286883403857549,0.28128141164779663,0.2757884239157041,0.2704034348328908,0.2651234492659569,0.25994645804166794,0.2548704718550046,0.2498944786687692,0.24501449118057886,0.24023149783412615,0.23554051046570143,0.2309415191411972,0.22643253207206726,0.22201253846287727,0.21767754728595415,0.21342855567733446,0.2092615639170011,0.20517657324671745,0.20117058356602988,0.19724358866612116,0.19339359551668167,0.18961860487858453,0.18591661378741264,0.1822876197596391,0.17872962976495424,0.17524063463012376,0.1718206430474917,0.16846664994955063,0.16517865657806396,0.16195466369390488,0.15879367043574652,0.15569467594226202,0.15265568097432455,0.14967668677369753,0.14675569658478102,0.1438917008539041,0.14108370741208395,0.13832971205314,0.13563071936368942,0.13298372303446135,0.13038872679074606,0.12784473225474358,0.1253497377038002,0.12290374437967937,0.12050574831664562,0.118153752759099,0.1158487598101298,0.11358776316046715,0.11137176863849163,0.10919877265890439,0.10706877770523231,0.10497978081305821,0.10293078608810902,0.10092279004553954,0.0989540945738554,0.09702349888781707,0.09513070185979207,0.09327480631570022,0.09145521000027657,0.08967111259698868,0.08792181747655074,0.08620672052105267,0.08452502389748891,0.08287622903784116,0.08125963062047958,0.07967453387876351,0.07812043776114781,0.07659664129217465,0.07510264466206233,0.07363774813711643,0.07220144880314668,0.07079325243830681,0.06941245682537556,0.06805865901211898,0.0667313610514005,0.06542986320952575,0.06415376688043277,0.06290266973276933,0.06167587172240019,0.06047307482610146,0.059293776440123715,0.05813747892777125,0.05700378150989612,0.0558921837558349,0.054802185855805874,0.053733588506778084,0.052685790384809174,0.05165849253535271,0.05065119452774525,0.049663497135043144,0.04869519857068857,0.04774570092558861,0.04681470307211081,0.04590200415501992,0.04500700657566389,0.044129508237044014,0.04326910991221666,0.0424255117153128,0.04159841345002254,0.04078741526852051,0.03999221666405598,0.03921251899252335,0.03844812015692393,0.03769852127879858,0.03696362332751354,0.03624302459259828,0.035536526081462703,0.0348438269769152,0.03416462894529104,0.03349863023807605,0.03284563155223926,0.03220543327430884,0.03157763400425514,0.030962135487546522,0.030358636906991403,0.02976693833867709,0.029186739431073267,0.028617840415487688,0.028060041678448517,0.027513142830381792,0.02697694394737482,0.026451144833117723,0.025935645836095016,0.02543014707043767,0.024934548418968916,0.024448649181673925,0.023972150093565386,0.023505051309863727,0.023046950654437143,0.02259786582241456,0.02237548151363929};
    CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.0745226542155,71.41004117329915,70.57004737854004,69.81563949584961,69.0654411315918,68.31974093119304,67.57894198099773,66.84324010213216,66.11293919881184,65.38833999633789,64.66953913370769,63.9566396077474,63.24963887532552,62.54883893330892,61.85403792063395,61.16543738047282,60.482937494913735,59.806736628214516,59.13673655192057,58.47293663024902,57.81533590952555,57.16393597920736,56.5187349319458,55.87953535715739,55.24643421173096,54.61943435668945,53.99843406677246,53.383233070373535,52.774033546447754,52.17073345184326,51.57343260447184,50.982032775878906,50.39653174082438,49.817131678263344,49.24363168080648,48.67613124847412,48.114630699157715,47.55923080444336,47.00973033905029,46.46622943878174,45.92872937520345,45.39712905883789,44.87152894337972,44.35182889302572,43.83802890777588,43.330128033955894,42.82802677154541,42.33182684580485,41.841426849365234,41.35682678222656,40.877926190694176,40.4046262105306,39.93702507019043,39.47492504119873,39.01842498779297,38.56732432047526,38.12162399291992,37.68122418721517,37.24622440338135,36.816423416137695,36.39192326863607,35.97242228190104,35.55802313486735,35.14862219492594,34.74412218729655,34.344521840413414,33.94982147216797,33.55982176462809,33.17452081044515,32.793920834859215,32.417820612589516,32.04632012049357,31.679320176442463,31.316719849904377,30.958419640858967,30.604519367218018,30.25481923421224,29.909318923950195,29.568018595377605,29.230718453725178,28.897518316904705,28.568317731221516,28.24301767349243,27.921717643737793,27.604117552439373,27.290417035420734,26.980416933695476,26.67411708831787,26.371416568756104,26.07241614659627,25.77691634496053,25.48491621017456,25.19631592432658,24.911215623219807,24.629515488942463,24.351115226745605,24.075915177663166,23.80411497751872,23.535414536794026,23.269914627075195,23.007514158884685,22.74831422170003,22.492014090220135,22.238813559214275,21.988513469696045,21.74121332168579,21.49681345621745,21.255313396453857,21.016613006591797,20.78061294555664,20.547512849171955,20.317012786865234,20.08931239446004,19.86421251296997,19.641712188720703,19.42191219329834,19.204611937204998,18.989811579386394,18.777511596679688,18.56771119435628,18.360411326090496,18.15541124343872,17.952911218007404,17.752710819244385,17.554810841878254,17.359210809071858,17.16581090291341,16.97481044133504,16.78591028849284,16.599210421244305,16.41471020380656,16.232309977213543,16.05200982093811,15.873709758122763,15.69750968615214,15.523409605026245,15.35120956103007,15.1810093720754,15.012709299723307,14.84640916188558,14.68190892537435,14.519308805465698,14.358508904774984,14.199608643849691,14.042508602142334,13.88710848490397,13.733508507410685,13.581608374913534,13.431408246358236,13.282908121744791,13.136008024215698,12.9908078511556,12.84720786412557,12.705207745234171,12.564807653427124,12.426007588704428,12.288607597351074,12.152907530466715,12.018607298533121,11.885807116826376,11.754407167434692,11.624606927235922,11.49610702196757,11.369106928507486,11.243506987889608,11.119306802749634,10.996406634648642,10.874906619389852,10.754806677500406,10.636006514231363,10.518406311670939,10.402206341425577,10.287306149800619,10.17370613416036,10.061306158701578,9.950146277745565,9.8402259349823,9.731525818506876,9.624035835266113,9.517725785573324,9.412595669428507,9.30862577756246,9.205815633138021,9.104135672251383,9.00358541806539,8.904135386149088,8.805795272191366,8.708545446395874,8.612375179926554,8.517265240351358,8.423205057779947,8.330185095469156,8.238195101420084,8.147225062052408,8.057265122731527,7.968294858932495,7.880314787228902,7.7933047612508135,7.707254767417908,7.622154672940572,7.538004597028096,7.454774578412374,7.372474471728007,7.291084408760071,7.2105943361918134,7.130994359652202,7.052274306615193,6.974424282709758,6.8974341948827105,6.821294109026591,6.746004184087117,6.671544114748637,6.597904006640117,6.525083978970845,6.453063885370891,6.38184388478597,6.31140383084615,6.241753896077474,6.172863682111104,6.104743719100952,6.037373661994934,5.970753630002339,5.904863595962524,5.839703520139058,5.775263547897339,5.7115334669748945,5.648513476053874,5.5861934423446655,5.5245533386866255,5.463603258132935,5.403323292732239,5.343713283538818,5.284753203392029,5.226453145345052,5.168793161710103,5.111773173014323,5.055383086204529,4.99962302049001,4.944473028182983,4.889932990074158,4.835992932319641,4.782652974128723,4.729912916819255,4.677742878595988,4.626152753829956,4.5751428206761675,4.5246827602386475,4.474792679150899,4.425452669461568,4.376652717590332,4.328392585118611,4.280672629674275,4.233472585678101,4.186802585919698,4.140642523765564,4.094992478688558,4.04985245068868,4.00520247220993,3.961052417755127,3.9173924128214517,3.874212384223938,3.8315023382504783,3.7892722686131797,3.7475122809410095,3.706212282180786,3.665362238883972,3.6249622106552124,3.585022211074829,3.5455121596654258,3.506442149480184,3.467802127202352,3.4295921127001443,3.3918020725250244,3.354422072569529,3.3174620270729065,3.2809119820594788,3.2447619636853537,3.209011952082316,3.173661947250366,3.138701915740967,3.1041219234466553,3.069921831289927,3.036111831665039,3.0026618440945945,2.969591816266378,2.9368818203608194,2.904531796773275,2.8725417455037436,2.840901772181193,2.809611678123474,2.7786617279052734,2.7480616768201194,2.7178016702334085,2.6878716548283896,2.658271610736847,2.6289916237195334,2.600041608015696,2.5714115699132285,2.5431015292803445,2.5151015321413674,2.4874014854431152,2.460021495819092,2.4329314629236856,2.406141479810079,2.379651447137197,2.353451410929362,2.3275414307912192,2.3019214073816934,2.276581366856893,2.251521368821462,2.2267313599586487,2.2022213141123452,2.1779813369115195,2.154011289278666,2.130301296710968,2.106851319471995,2.0836612383524575,2.0607312520345054,2.0380512475967407,2.0156212051709494,1.9934312204519908,1.9715011914571126,1.9498011966546376,1.9283411701520283,1.9071211516857147,1.886141151189804,1.865381121635437,1.8448511163393657,1.8245511253674824,1.8044810990492504,1.7846210896968842,1.7649910748004913,1.7455710470676422,1.726361056168874,1.7073710262775421,1.6885910431543987,1.6700110236803691,1.6516410112380981,1.633471022049586,1.6155009766419728,1.5977309544881184,1.5801509817441304,1.5627709527810414,1.5455809434254963,1.5285809338092804,1.511770913998286,1.4951409101486206,1.4786909023920696,1.4624309142430623,1.4463508625825245,1.4304408729076385,1.4147108594576518,1.3991508583227794,1.383760819832484,1.3685508370399475,1.3535008331139882,1.3386108378569286,1.3238908052444458,1.3093407948811848,1.2949407994747162,1.2807007829348247,1.2666207651297252,1.252690742413203,1.23892076810201,1.2253007590770721,1.2118307451407115,1.1985007325808208,1.185330718755722,1.172290712594986,1.1594107051690419,1.1466606954733531,1.1340606808662415,1.1215906739234924,1.1092606782913208,1.0970706741015117,1.085010677576065,1.0730806589126587,1.0612906416257222,1.0496206482251484,1.038080632686615,1.0266706148783367,1.0153906146685283,1.004230613509814,0.99319360156854,0.9822786003351212,0.971483588218689,0.9608065883318583,0.9502475708723068,0.9398055672645569,0.9294775625069936,0.9192635615666708,0.9091615478197733,0.8991715361674627,0.8892915397882462,0.879519542058309,0.8698555280764898,0.8602975209554037,0.8508455107609431,0.8414965172608694,0.8322505156199137,0.8231075058380762,0.814063494404157,0.8051204880078634,0.7962744931379954,0.7875264833370844,0.7788754800955454,0.7703184684117635,0.761856476465861,0.7534874528646469,0.7452104538679123,0.7370244463284811,0.7289284467697144,0.7209214319785436,0.7130024333794912,0.7051704327265421,0.6974254300196966,0.6897654136021932,0.682188406586647,0.6746964206298193,0.6672864009936651,0.6599573989709219,0.6527093897263209,0.6455403914054235,0.6384513924519221,0.6314393828312556,0.6245053758223852,0.6176473697026571,0.6108643710613251,0.604156364997228,0.5975223531325659,0.5909603635470072,0.5844713548819224,0.5780533502499262,0.5717063546180725,0.5654283414284388,0.5592203438282013,0.5530803402264913,0.5470073322455088,0.5410013248523077,0.5350623279809952,0.5291873266299566,0.523377314209938,0.5176313171784083,0.5119483123222986,0.506328304608663,0.5007703055938085,0.4952722986539205,0.48983529955148697,0.4844582974910736,0.4791402866442998,0.4738802909851074,0.4686782856782277,0.46353427817424137,0.4584462766846021,0.45341427624225616,0.44843727101882297,0.4435152659813563,0.4386472627520561,0.43383226295312244,0.42907126247882843,0.42436225960652035,0.41970425595839816,0.4150982548793157,0.41054224967956543,0.4060372437040011,0.4015812426805496,0.3971732407808304,0.392815242211024,0.38850423445304233,0.3842412332693736,0.3800242319703102,0.3758542289336522,0.3717302282651265,0.3676512266198794,0.3636162181695302,0.35962721953789395,0.3556812157233556,0.35177821417649585,0.34791820993026096,0.3441012104352315,0.3403252090017001,0.3365912040074666,0.33289819955825806,0.3292461981376012,0.3256342137853305,0.323838047683239};
    CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297694365183514,16.27421760559082,16.21771017710368,16.178008397420246,16.13280725479126,16.08280658721924,16.02850564320882,15.970505078633627,15.90930445988973,15.845303853352865,15.778803586959839,15.710203091303507,15.639802614847818,15.567902326583862,15.494602044423422,15.420101960500082,15.344701608022055,15.268401463826498,15.191401243209839,15.113901058832804,15.035900990168253,14.957600831985474,14.878900845845541,14.800000667572021,14.721000591913858,14.641900618871054,14.562700351079306,14.483500401178995,14.40440034866333,14.325300296147665,14.246300299962362,14.167400280634562,14.088800112406412,14.010300159454346,13.932000239690145,13.854000171025595,13.776300032933554,13.698800166447958,13.621700048446655,13.54479988416036,13.468300104141235,13.392200072606405,13.316399971644083,13.241000016530355,13.165900071461996,13.091200033823648,13.016899903615316,12.943000157674154,12.86959989865621,12.796500047047934,12.72379994392395,12.651599804560343,12.579700072606405,12.508300065994263,12.437300046284994,12.3667999903361,12.296600103378296,12.226900021235148,12.157600084940592,12.08869997660319,12.02020001411438,11.952200174331665,11.884600003560385,11.817300001780191,11.750499884287516,11.684199889500936,11.618200063705444,11.552600065867106,11.48739997545878,11.42270008722941,11.358299970626831,11.294300079345703,11.230699936548868,11.16759991645813,11.10479998588562,11.042399883270264,10.980299949645996,10.918699900309244,10.857399940490723,10.796600023905436,10.735999981562296,10.675899982452393,10.616099913914999,10.556700070699057,10.497699896494547,10.438999970753988,10.3807000319163,10.322800079981485,10.265199899673462,10.207900047302246,10.150999943415323,10.09440008799235,10.03820006052653,9.982359965642294,9.926829973856607,9.87162987391154,9.816769997278849,9.762239933013916,9.708030064900717,9.654159943262735,9.60061001777649,9.547379891077677,9.494470040003458,9.441879908243815,9.389600038528442,9.337640126546225,9.285989999771118,9.234649976094564,9.18361004193624,9.132879972457886,9.082460085550943,9.03233011563619,8.982499996821085,8.932969888051352,8.883740027745565,8.834800004959106,8.786150137583414,8.737789948781332,8.689719915390015,8.64193026224772,8.594420115152994,8.547199885050455,8.5002601146698,8.453599770863852,8.407209873199463,8.36109987894694,8.315249919891357,8.269690036773682,8.224390109380087,8.179350058237711,8.13457989692688,8.09007994333903,8.045830090840658,8.00184996922811,7.958119988441467,7.914640029271443,7.871410012245178,7.828440030415853,7.785709977149963,7.743229985237122,7.700990080833435,7.658990104993184,7.61722997824351,7.5756999254226685,7.5344200531641645,7.493360002835591,7.452540000279744,7.411939978599548,7.371580044428508,7.331430117289226,7.291519999504089,7.251819928487142,7.212339997291565,7.173090020815532,7.134039958318074,7.095220009485881,7.056600014368693,7.018199960390727,6.9800099929173784,6.942020018895467,6.904240012168884,6.86667005221049,6.829310019810994,6.792139927546184,6.75518004099528,6.718419988950093,6.681869943936666,6.645509998003642,6.609350045522054,6.573379993438721,6.537619988123576,6.502039949099223,6.466670036315918,6.431480010350545,6.396489977836609,6.361689964930217,6.327080011367798,6.292649984359741,6.258420030275981,6.224370002746582,6.190509994824727,6.156829992930095,6.123340010643005,6.0900299946467085,6.056899984677632,6.023950020472209,5.991189996401469,5.958600004514058,5.92619001865387,5.89394998550415,5.861900011698405,5.830010096232097,5.798310041427612,5.766770005226135,5.73541001478831,5.704220016797383,5.673189918200175,5.642339984575908,5.61165992418925,5.581140001614888,5.550789912541707,5.520610054334004,5.49059001604716,5.460739970207214,5.431040008862813,5.401510000228882,5.372139930725098,5.342939972877502,5.313889980316162,5.285000006357829,5.25625999768575,5.227689981460571,5.199270049730937,5.171000003814697,5.142889976501465,5.11493996779124,5.087129990259807,5.05948003133138,5.031979997952779,5.004619995752971,4.977419972419739,4.950369993845622,4.923460046450297,4.896699984868367,4.870090007781982,4.84361998240153,4.817300001780192,4.791119972864787,4.765080014864604,4.7391800085703535,4.713430086771647,4.687819957733154,4.662339965502421,4.637009978294373,4.611809968948364,4.586749990781148,4.5618300040562945,4.5370399951934814,4.51238997777303,4.487880031267802,4.463500022888184,4.4392499923706055,4.415129979451497,4.391150037447612,4.367290099461873,4.343569954236348,4.319980065027873,4.2965099811553955,4.2731800476710005,4.249970038731893,4.226889967918396,4.203930060068767,4.181100010871887,4.1583999792734785,4.135809977849324,4.113360007603963,4.091019988059998,4.068810025850932,4.046710014343262,4.024739940961202,4.00288999080658,3.981159965197245,3.959540009498596,3.93803999821345,3.916670004526774,3.8953999678293862,3.8742600083351135,3.8532299796740213,3.8323100010553994,3.811509986718496,3.7908200224240622,3.770240008831024,3.749779999256134,3.7294299602508545,3.7091799775759378,3.689049998919169,3.6690299908320108,3.6491199930508933,3.6293200055758157,3.609619975090027,3.5900399883588157,3.57055002450943,3.5511799653371177,3.5319100419680276,3.5127500096956887,3.493690013885498,3.4747300148010254,3.4558799862861633,3.437130033969879,3.4184799591700235,3.399930000305176,3.3814899921417236,3.3631400068600974,3.3449000318845115,3.326760013898214,3.308709959189097,3.290760020414988,3.272909998893738,3.2551599939664206,3.237499992052714,3.2199400067329407,3.2024800181388855,3.1851099928220115,3.167829990386963,3.150649984677633,3.1335699955622354,3.116569976011912,3.0996700127919516,3.082859992980957,3.0661399960517883,3.0495200157165527,3.0329800049463906,3.016540010770162,3.0001799861590066,2.983910004297892,2.9677299857139587,2.951640009880066,2.9356399973233542,2.9197199940681458,2.9038900335629783,2.8881499965985618,2.8724900086720786,2.856920003890991,2.8414299885431924,2.8260300159454346,2.8107099731763205,2.795469959576925,2.7803200085957847,2.765250007311503,2.7502599954605103,2.735349973042806,2.7205299735069275,2.7057799895604453,2.691119968891144,2.6765299836794534,2.6620200077692666,2.647599995136261,2.6332499980926514,2.6189800103505454,2.6047900319099426,2.5906699895858765,2.5766299962997437,2.5626700123151145,2.5487799843152366,2.534970005353292,2.521239976088206,2.5075700283050537,2.4939899841944375,2.4804700016975403,2.4670399824778237,2.453670005003611,2.440380016962687,2.427150011062622,2.4139999945958457,2.4009300072987876,2.3879200220108032,2.3749799927075705,2.362119992574056,2.349320034186045,2.3366000056266785,2.323940018812815,2.3113500277201333,2.298829992612203,2.2863800326983132,2.2739999890327454,2.261679987112681,2.2494300405184426,2.237250030040741,2.225130021572113,2.2130800088246665,2.2010899980862937,2.189170002937317,2.177320043245951,2.1655300060908,2.1538000106811523,2.1421300172805786,2.130529999732971,2.11899999777476,2.1075200041135154,2.096110006173452,2.084759990374247,2.0734700361887612,2.062249998251597,2.0510800083478293,2.0399700005849204,2.0289300084114075,2.0179400046666465,2.0070200165112815,1.9961499969164531,1.9853500028451283,1.9745999972025554,1.9639100035031636,1.9532800018787384,1.9427000085512798,1.9321900010108948,1.9217300017674763,1.9113199909528096,1.900979995727539,1.89068998893102,1.8804499904314678,1.8702800075213115,1.8601500193277996,1.850079983472824,1.8400699992974598,1.8301100035508473,1.8202100098133087,1.8103500008583069,1.8005599876244862,1.7908099989096324,1.7811199923356373,1.7714800039927165,1.7618899742762248,1.7523599863052368,1.7428800066312153,1.733439991871516,1.7240599989891052,1.714730014403661,1.705460011959076,1.6962300141652424,1.6870500048001607,1.677919993797938,1.6688400010267894,1.659809986750285,1.6508299907048543,1.641900012890498,1.6330200135707855,1.62417999903361,1.6153900027275085,1.6066500047842662,1.597960005203883,1.589319994052251,1.5807199974854786,1.5721699893474579,1.5636600057284038,1.5552000006039937,1.5467899938424428,1.5384200016657512,1.5300999979178111,1.5218199988206227,1.513590008020401,1.5054000119368236,1.4972600042819977,1.4891600112120311,1.4811099767684937,1.4731000065803528,1.4651299913724263,1.457210014263789,1.4493200083573659,1.4414899945259094,1.4336900015672047,1.4259400069713593,1.4182200034459431,1.4105499982833862,1.402930001417796,1.3953399956226349,1.3877899944782257,1.3802899916966755,1.3728200097878773,1.3653999865055084,1.3580199877421062,1.3506699899832408,1.3433699905872345,1.3361100057760875,1.3288800021012623,1.3216999967892964,1.3145499924818675,1.3074399928251903,1.3003699978192647,1.293339987595876,1.286350001891454,1.2793900072574615,1.2724800010522206,1.2655999859174092,1.2587499916553497,1.2519499858220418,1.2451799909273784,1.238450010617574,1.231749991575877,1.2251000106334686,1.21846999724706,1.2118899921576183,1.2053300042947133,1.1988200048605602,1.1923399964968364,1.1858900090058644,1.1826800008614857};
    CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.460016330083212,8.488823413848877,8.531164248784384,8.575844208399454,8.618184010187784,8.658264001210531,8.696173747380575,8.732003688812256,8.765813509623209,8.79767338434855,8.827673355738321,8.855883121490479,8.882353067398071,8.90716298421224,8.930362860361734,8.952012856801352,8.972172657648722,8.990902503331503,9.008262395858765,9.024282455444336,9.03901219367981,9.05252226193746,9.064842144648233,9.076022068659464,9.08610192934672,9.09512186050415,9.103121836980185,9.11013150215149,9.116191705067953,9.121351480484009,9.125621557235718,9.129061381022135,9.131681283315023,9.133541345596313,9.134641329447428,9.135021130243937,9.134721199671427,9.133771260579428,9.132171312967936,9.129971027374268,9.127190907796225,9.123841047286987,9.11996086438497,9.115560928980509,9.110660950342814,9.10529088973999,9.099470933278402,9.093220710754395,9.08655071258545,9.07948080698649,9.072030703226725,9.064210812250773,9.056050777435303,9.047560612360636,9.038740555445353,9.029610554377237,9.020190636316935,9.010490576426188,9.000520388285318,8.99029048283895,8.979820410410563,8.96911064783732,8.958170493443808,8.947020451227823,8.93565058708191,8.924090385437012,8.912350416183472,8.90043044090271,8.888330300649008,8.87608027458191,8.86366049448649,8.8510901927948,8.838380416234335,8.82554038365682,8.812560240427652,8.79947026570638,8.786250352859497,8.772930145263672,8.759510278701782,8.74599035580953,8.732360124588013,8.718640168507894,8.704840262730917,8.690960248311361,8.677000125249227,8.662970145543417,8.647540092468262,8.63077982266744,8.614050070444742,8.597369909286499,8.580729961395264,8.564120054244995,8.547559976577759,8.53102993965149,8.514540115992228,8.498090028762817,8.481679995854696,8.465309937795004,8.448969999949137,8.432679971059164,8.416420141855875,8.400199969609579,8.384009997049967,8.367869933446249,8.351760069529215,8.335690021514893,8.319649934768677,8.303659836451212,8.287690003712973,8.271770000457764,8.255879878997803,8.24003005027771,8.224219957987467,8.208440144856771,8.192700147628784,8.176990111668905,8.161320050557455,8.145690043767294,8.130089918772379,8.114520072937012,8.098989963531494,8.083499987920126,8.068039894104004,8.052620013554892,8.037240028381348,8.02187999089559,8.006570021311441,7.99127999941508,7.976029992103577,7.960819999376933,7.945640047391255,7.930499990781148,7.915380040804545,7.900300025939941,7.885260025660197,7.870249946912129,7.855270028114319,7.840319991111755,7.825399915377299,7.810520013173421,7.795670072237651,7.780850013097127,7.766059994697571,7.751300017038981,7.736569921175639,7.721869985262553,7.707209984461467,7.692570010821025,7.67796003818512,7.663379987080892,7.648830016454061,7.634310086568196,7.6198199192682905,7.6053599913914995,7.590920011202495,7.576520005861918,7.562139987945557,7.5477800369262695,7.533460060755412,7.5191599527994795,7.504899978637695,7.490649938583374,7.476439952850342,7.462249954541524,7.448089996973674,7.43396000067393,7.419850031534831,7.405770023663838,7.391719977060954,7.3776899973551435,7.3636899789174395,7.349720001220703,7.335769971211751,7.321849942207336,7.307960073153178,7.294100006421407,7.280259966850281,7.266439914703369,7.252659996350606,7.238900025685628,7.225159923235576,7.211449940999349,7.197769999504089,7.184119979540507,7.17048994700114,7.156889994939168,7.143309990564982,7.129760066668193,7.116230050722758,7.10273003578186,7.08925998210907,7.075809955596924,7.062389969825745,7.049000024795532,7.035629987716675,7.022280017534892,7.008960008621216,6.995670000712077,6.982399940490723,6.9691600402196245,6.9559400876363116,6.942749937375386,6.929579973220825,6.916439970334371,6.903319954872131,6.890229980150859,6.87716003259023,6.86411992708842,6.851110100746155,6.838120023409526,6.825150012969971,6.8122100830078125,6.799290021260579,6.7864000002543134,6.773530006408691,6.760689973831177,6.747870008150737,6.735080083211263,6.722309986750285,6.709560036659241,6.696839968363444,6.684149980545044,6.671470046043396,6.658830046653748,6.646200021107991,6.633600036303203,6.6210300127665205,6.608480016390483,6.5959499677022295,6.583450039227803,6.570970018704732,6.558510025342305,6.546080032984416,6.533669988314311,6.521289984385173,6.508930047353108,6.4965900182724,6.484279950459798,6.471990029017131,6.459729949633281,6.447490016619365,6.435269991556804,6.423069993654887,6.4109000364939375,6.3987499078114825,6.386630058288574,6.374529997507731,6.362449924151103,6.3503899574279785,6.338359991709392,6.326350053151448,6.314369996388753,6.302409927050273,6.290469964345296,6.278549989064534,6.266650040944417,6.254780093828837,6.242939988772075,6.231110056241353,6.219310005505879,6.2075300216674805,6.195770025253296,6.184030016263326,6.172320008277893,6.160629987716675,6.148959954579671,6.137320001920064,6.125699996948242,6.114090005556743,6.102519949277242,6.090960065523784,6.079430063565572,6.067910035451253,6.056420048077901,6.044949968655904,6.033510009447734,6.022079984347026,6.010679999987285,5.999299963315328,5.987939993540446,5.976609945297241,5.965289950370789,5.953999916712443,5.942729989687602,5.931469957033793,5.920249978701274,5.909040013949077,5.897849996884664,5.886689980824788,5.875540018081665,5.864419976870219,5.853320002555847,5.84224001566569,5.831180016199748,5.820149938265483,5.809130032857259,5.798140088717143,5.787159999211629,5.776209990183513,5.76527996857961,5.754370053609212,5.74348000685374,5.732609987258911,5.721759955088298,5.710929989814758,5.700120011965434,5.6893400351206465,5.678570071856181,5.667829990386963,5.657099962234497,5.6464000542958575,5.635709961255391,5.625050028165181,5.614410042762756,5.603790005048116,5.593179941177368,5.582600037256877,5.57203992207845,5.561500032742818,5.550980011622111,5.540469964345296,5.529989957809448,5.519530018170674,5.509089986483256,5.498669981956482,5.488269925117493,5.477880001068115,5.467519998550415,5.457179983456929,5.446859955787659,5.436559995015462,5.426270047823588,5.416009982426961,5.405770023663838,5.395539959271749,5.385339975357056,5.375150005022685,5.3649901151657104,5.35483992099762,5.344710071881612,5.3346099853515625,5.324519991874695,5.314449946085612,5.304400006930034,5.294370055198669,5.28436005115509,5.274359941482544,5.264390071233113,5.254440029462178,5.244500041007996,5.234580000241597,5.224690039952596,5.214810053507487,5.204950014750163,5.195110042889913,5.185289939244588,5.175480087598165,5.1656999985377,5.155930002530416,5.146180033683777,5.136449972788493,5.126739978790283,5.1170499722162885,5.107380032539368,5.09772006670634,5.088090022404988,5.07846999168396,5.068869988123576,5.059289971987407,5.049729983011882,5.040179967880249,5.030650019645691,5.02115003267924,5.011660019556682,5.002180020014445,4.992730061213176,4.983289996782939,4.973870038986206,4.964469989140828,4.955090006192525,4.945729970932007,4.93638002872467,4.927050034205119,4.917739987373352,4.90845000743866,4.89916996161143,4.889910022417705,4.880670030911763,4.871449987093608,4.862239996592204,4.853060046831767,4.843889991442363,4.83473006884257,4.825599988301595,4.816480000813802,4.807379921277364,4.79830002784729,4.789229989051819,4.780180017153422,4.77115003267924,4.762139956156413,4.753139972686768,4.744159976641337,4.7351999680201216,4.726249972979228,4.717320005098979,4.708409984906514,4.699509938557942,4.690640012423198,4.681780060132344,4.672930002212524,4.664100011189778,4.655290047327678,4.646500031153361,4.637719988822937,4.628959933916728,4.620220025380452,4.61148997147878,4.602779984474182,4.594090104103088,4.585409998893738,4.576750040054321,4.56810998916626,4.559479991594951,4.550869981447856,4.542269945144653,4.5336900154749555,4.525129993756612,4.516579945882161,4.508050044377645,4.499540050824483,4.491039991378784,4.482559998830159,4.474099953969319,4.465650002161662,4.457209984461467,4.448800007502238,4.440399964650472,4.432009935379028,4.423640052477519,4.415289998054504,4.406949996948242,4.3986300230026245,4.390329996744792,4.382039984067281,4.373760024706523,4.365500013033549,4.35725994904836,4.3490400314331055,4.340819954872131,4.332630038261414,4.324449976285298,4.316280007362366,4.308140118916829,4.300000031789144,4.291879971822103,4.283780018488566,4.275689999262492,4.267620086669922,4.259569883346558,4.251519958178203,4.243500034014384,4.235490004221599,4.227490107218425,4.219509959220886,4.211549997329712,4.20360000928243,4.19565995534261,4.187740008036296,4.179840008417766,4.171949942906697,4.164070129394531,4.15621002515157,4.148369948069255,4.14054000377655,4.132730007171631,4.124930024147034,4.117140014966329,4.109369993209839,4.101609905560811,4.093870083491008,4.08614997069041,4.078429977099101,4.070740024248759,4.063060005505879,4.05921995639801};
    CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192718505859,514.5848388671875,508.81893666585285,504.2599054972331,499.64991505940753,495.00391642252606,490.3349126180013,485.65291086832684,480.96791076660156,476.2859141031901,471.6139170328776,466.9569091796875,462.3189112345378,457.7029113769531,453.1119130452474,448.54791768391925,444.0129140218099,439.50891367594403,435.03692118326825,430.59791564941406,426.1919199625651,421.8209228515625,417.4839146931966,413.18192291259766,408.91491953531903,404.6829198201497,400.48591868082684,396.3239212036133,392.1969223022461,388.1059265136719,384.04992421468097,380.0299301147461,376.0459289550781,372.0979232788086,368.18692779541016,364.31292724609375,360.4759292602539,356.6759312947591,352.91193135579425,349.1859308878581,345.4969304402669,341.84593709309894,338.2309341430664,334.65393320719403,331.11293538411456,327.6089375813802,324.14293162027997,320.7129364013672,317.3189341227214,313.9629389444987,310.6419372558594,307.3579355875651,304.1089375813802,300.8949432373047,297.71693929036456,294.5739466349284,291.4649429321289,288.3899383544922,285.3499476114909,282.3429412841797,279.3689448038737,276.4279429117839,273.5199457804362,270.6439488728841,267.79994201660156,264.98794809977215,262.20594787597656,259.45594533284503,256.73594919840497,254.04594930013022,251.38595072428384,248.75495020548502,246.15295028686523,243.58095169067383,241.03595225016275,238.51995340983072,236.03095372517905,233.56995391845703,231.1359545389811,228.72895685831705,226.34795506795248,223.99395751953125,221.66495513916016,219.36195627848306,217.08395767211914,214.8319574991862,212.6039581298828,210.40095901489258,208.22196197509766,206.06595993041992,203.93396377563477,201.82596079508463,199.73995971679688,197.67596054077148,195.63596471150717,193.61696116129556,191.6199607849121,189.64496231079102,187.69096247355142,185.7579663594564,183.84596506754556,181.95496622721353,180.08396784464517,178.23296483357748,176.4029680887858,174.5909678141276,172.79996871948242,171.0269686381022,169.27396774291992,167.53896713256836,165.82396825154623,164.12596893310547,162.4459686279297,160.78496805826822,159.1409683227539,157.5149688720703,155.90697224934897,154.31496938069662,152.7409693400065,151.18296813964844,149.64197158813477,148.11697260538736,146.6089719136556,145.11597061157227,143.63997268676758,142.17897415161133,140.73397318522134,139.30397415161133,137.88897323608398,136.48897171020508,135.10397466023764,133.73397318522134,132.3779754638672,131.0369758605957,129.7089754740397,128.39597511291504,127.09597524007161,125.8099759419759,124.53697649637859,123.27797762552898,122.03097724914551,120.79797808329265,119.5769780476888,118.36897786458333,117.17297744750977,115.98997751871745,114.81897799173991,113.65997823079427,112.5129788716634,111.37697982788086,110.25397936503093,109.14097913106282,108.03997866312663,106.94998105367024,105.87198003133138,104.80397923787434,103.74698066711426,102.70097986857097,101.66498120625813,100.63998158772786,99.62498156229655,98.62028121948242,97.62578264872234,96.64138221740723,95.6668815612793,94.70218213399251,93.74728266398112,92.80198224385579,91.8662821451823,90.93998273213704,90.02298355102539,89.11528333028157,88.21678225199382,87.32738304138184,86.44698397318523,85.57538414001465,84.71258481343587,83.85858408610027,83.01318422953288,82.17628415425618,81.34788449605306,80.52788543701172,79.71608416239421,78.91258494059245,78.11708577473958,77.32968711853027,76.55028533935547,75.7786865234375,75.01488558451335,74.25878588358562,73.51038678487141,72.76958656311035,72.0361868540446,71.31018575032552,70.59158643086751,69.8801867167155,69.17598660786946,68.47888692220052,67.78878720601399,67.10578791300456,66.42958704630534,65.76018651326497,65.09768740336101,64.44178835550944,63.79248841603597,63.14978853861491,62.5135882695516,61.883788108825684,61.26028823852539,60.6431884765625,60.032288551330566,59.42748864491781,58.82888889312744,58.23628902435303,57.649689356486,57.0689894358317,56.494188944498696,55.92518965403239,55.36188983917236,54.80428918202718,54.25228977203369,53.70588970184326,53.165090243021645,52.62959003448486,52.09959061940511,51.57499027252197,51.05559062957764,50.54149055480957,50.03259118398031,49.52879079182943,49.03009064992269,48.536390940348305,48.0476910273234,47.56389204661051,47.08509095509847,46.61099116007487,46.141791343688965,45.67719109853109,45.21739196777344,44.762191454569496,44.31159210205078,43.86559168497721,43.4240919748942,42.98699188232422,42.55429204305013,42.126091639200844,41.70209217071533,41.28239186604818,40.86699263254801,40.45569292704264,40.04859256744385,39.64559237162272,39.246692975362144,38.85179297129313,38.46089299519857,38.07399272918701,37.69089285532633,37.31169287363688,36.93639310201009,36.56479358673096,36.19699350992838,35.83279259999593,35.47239335378011,35.115593592325844,34.762393951416016,34.41269334157308,34.06659380594889,33.72399361928304,33.38479359944662,33.049093882242836,32.71669356028239,32.387694358825684,32.06199407577515,31.739593823750813,31.420494079589844,31.104494094848633,30.791794300079346,30.482194264729817,30.17569414774577,29.872294584910076,29.571994463602703,29.274694442749023,28.98039436340332,28.688994725545246,28.400594393412273,28.11509434382121,27.832494894663494,27.552794615427654,27.275794982910156,27.00159486134847,26.730194727579754,26.461595058441162,26.195595105489094,25.932394981384277,25.671695232391357,25.413695017496746,25.158295154571533,24.905495166778564,24.655195395151775,24.40749502182007,24.162195682525635,23.91939576466878,23.679095427195232,23.441195646921795,23.205695470174152,22.972495873769123,22.741695562998455,22.513195832570393,22.286995887756348,22.063095887502033,21.841495831807453,21.622095743815105,21.404895623524983,21.189795970916748,20.976996103922527,20.76629622777303,20.557696024576824,20.3511962890625,20.146796226501465,19.94439633687337,19.744096279144287,19.545796553293865,19.349496364593506,19.15519618988037,18.962796529134113,18.772396564483643,18.58389647801717,18.39729642868042,18.212496439615887,18.02959664662679,17.84859625498454,17.669396718343098,17.49199676513672,17.316296736399334,17.142496744791668,16.970396836598713,16.799996852874756,16.631296793619793,16.464397112528484,16.299097061157227,16.13539679845174,15.973496834437052,15.81309715906779,15.654397010803223,15.497197151184082,15.341697136561075,15.187697092692057,15.035197019577026,14.884297291437784,14.734897216161093,14.58709716796875,14.44069735209147,14.295697212219238,14.152297337849935,14.010197480519613,13.86959727605184,13.730397383371988,13.592697540918985,13.456297397613525,13.321197430292765,13.187597433725992,13.055197477340698,12.924197753270468,12.794497728347778,12.666197697321573,12.539097547531128,12.413297573725382,12.288697799046835,12.165497541427612,12.043397744496664,11.922597726186117,11.802997827529907,11.684597810109457,11.567297776540121,11.451297918955484,11.336397886276245,11.222697734832764,11.110097805658976,10.998697837193808,10.888398011525473,10.779198010762533,10.670998016993204,10.563998063405355,10.4580979347229,10.353198051452637,10.249298016230265,10.146598180135092,10.044798135757446,9.944058100382486,9.844328165054321,9.74560809135437,9.647878249486288,9.551128149032593,9.455358187357584,9.360538244247437,9.26667825380961,9.173758347829184,9.081778287887573,8.990718285242716,8.90056824684143,8.811328411102295,8.722988367080688,8.635528405507406,8.548948287963867,8.463238398234049,8.37838864326477,8.294398387273153,8.211248397827148,8.128928581873575,8.047438621520996,7.966768503189087,7.886908570925395,7.807848532994588,7.729578574498494,7.6520986159642534,7.575398564338684,7.499468564987183,7.4242985645929975,7.349888602892558,7.27621869246165,7.203288674354553,7.131098628044128,7.05962872505188,6.9888787269592285,6.9188287655512495,6.849488735198975,6.780848741531372,6.71289877096812,6.645628770192464,6.579028765360515,6.51309875647227,6.44783882300059,6.3832288185755415,6.319258848826091,6.255938808123271,6.193258802096049,6.131198803583781,6.069768865903218,6.0089488824208575,5.948748866717021,5.889148871103923,5.830138921737671,5.771728912989299,5.713908910751343,5.656658967336019,5.59998897711436,5.543888886769612,5.488358934720357,5.433368961016337,5.378939072291057,5.325058976809184,5.271719018618266,5.218909025192261,5.16663904984792,5.114879012107849,5.063648978869121,5.012929042180379,4.962719082832336,4.913009126981099,4.863799095153809,4.815089066823323,4.76685909430186,4.719119151433309,4.67185918490092,4.625069101651509,4.578749140103658,4.532889127731323,4.487499117851257,4.442559123039246,4.398069143295288,4.354029218355815,4.310429175694783,4.267259160677592,4.224529226620992,4.182229200998942,4.140349229176839,4.098899245262146,4.057849208513896,4.017219305038452,3.9769992431004844,3.937179227670034,3.8977592388788858,3.8587392767270408,3.820099194844564,3.7818597157796225,3.762829621632894};
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.921801249186196,40.04995632171631,40.46423053741455,38.038174629211426,39.769005139668785,41.53858884175619,43.307186126708984,44.59110164642334,45.3348274230957,46.0315637588501,46.72508462270101,47.41811339060465,48.111316998799644,48.804320653279625,49.49780591328939,50.19013595581055,50.88486258188883,51.314735094706215,51.451109886169434,51.561662673950195,51.67068608601888,51.779184341430664,51.88806438446045,51.99636777242025,52.10587978363037,52.21244875590006,52.32625071207682,51.584397633870445,49.89486789703369,48.12108929951986,46.342529296875,44.56287479400635,42.7833636601766,41.00364367167155,39.22442309061686,37.44407653808594,35.666534105936684,33.52222458521525,30.971641063690186,28.38461955388387,25.795795440673828,23.206306616465252,20.616990566253662,18.027760187784832,15.437780062357584,12.850366592407227,10.254875659942627,8.847226937611898,8.75551982720693,8.782842795054117,8.815078139305115,8.849940458933512,8.883981029192606,8.918444275856018,8.952709555625916,8.987071832021078,9.021383921305338,9.056163549423218,9.091406027475992,9.126699209213257,9.161987463633219,9.197288195292154,9.232577959696451,9.267867883046469,9.303168853123983,9.338452895482382,9.37378184000651,9.401836236317953,9.421814123789469,9.44106396039327,9.460297584533691,9.479499181111654,9.498714526494345,9.517920891443888,9.537133693695068,9.556339820226034,9.57556422551473,9.59091313680013,9.601952950159708,9.612591981887817,9.62323029836019,9.633854389190674,9.644478956858316,9.655104955037435,9.665738741556803,9.67633589108785,9.687027851740519,9.685144344965616,9.669228792190552,9.652107000350952,9.634908437728882,9.617687940597534,9.600478172302246,9.583257993062338,9.56604806582133,9.548828283945719,9.531617879867554,9.514408191045126,9.497188011805216,9.479978322982788,9.4627579053243,9.445548295974731,9.428328037261963,9.411118268966675,9.393898089726767,9.376688162485758,9.359468142191568,9.342257897059122,9.325048446655273,9.307827949523926,9.290618181228638,9.27339800198873,9.256188233693441,9.238968054453531,9.221758286158243,9.204538027445475,9.187328179677328,9.170108079910278,9.15289831161499,9.13567821184794,9.118467887242636,9.101258277893066,9.084038257598877,9.06682817141215,9.04960815111796,9.032398223876953,9.015178124109903,8.997968117396036,8.980748256047567,8.96353813012441,8.946318109830221,8.929108182589212,8.911888281504313,8.894678036371866,8.877468347549438,8.86024816830953,8.843038320541382,8.825818260510763,8.808608373006185,8.791388193766275,8.774178067843119,8.756958246231079,8.739748279253641,8.722528219223022,8.705318133036295,8.688098311424255,8.670888225237528,8.65367821852366,8.636458237965902,8.619248270988464,8.602028369903564,8.584818085034689,8.567598263422648,8.550388177235922,8.533168315887451,8.515958150227865,8.498738408088684,8.481528162956238,8.464308301607767,8.447098215421041,8.42987847328186,8.412668188412985,8.395458340644836,8.378238320350647,8.36102819442749,8.34380829334259,8.326598127683004,8.309378345807394,8.292168100674948,8.274948477745056,8.25773831208547,8.24051829179128,8.223308086395264,8.206098318099976,8.188878377278646,8.1716681321462,8.15444846947988,8.137238184611002,8.120018601417542,8.102808117866516,8.085588494936625,8.06837797164917,8.051158587137857,8.033948103586832,8.0167285601298,7.999518394470215,7.982298453648885,7.965088168780009,7.94787855943044,7.930658062299092,7.913448611895244,7.896228194236755,7.879018545150757,7.861798206965129,7.844588438669841,7.8273682196935015,7.810158451398213,7.792938311894734,7.775728344917297,7.758508404095967,7.741298198699951,7.724088589350383,7.706868211428325,7.689658482869466,7.672438263893127,7.655228495597839,7.638008236885071,7.620798508326213,7.603578249613444,7.586368401845296,7.569148461023967,7.55193817615509,7.534728487332662,7.517508387565613,7.500298539797465,7.483078320821126,7.4658684730529785,7.4486483335494995,7.431438446044922,7.414218386014302,7.397008498509725,7.379788438479106,7.362578392028809,7.3453584512074785,7.3281484842300415,7.310928463935852,7.293718298276265,7.276508529980977,7.259288350741069,7.242078542709351,7.224858442942302,7.207648714383443,7.190427859624227,7.173219998677571,7.155994296073914,7.138800064722697,7.121536533037822,7.112079779307048,7.111260096232097,7.11120327313741,7.111197193463643,7.111199657122294,7.111198623975118,7.111199061075847,7.111198782920837,7.111198941866557,7.111198941866557,7.111198941866557,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666963418324788,6.884193817774455,6.611278374989827,6.670305530230205,6.737996657689412,6.807396491368611,6.8766283591588335,6.897752443949382,6.857924779256185,6.801615277926127,6.7410339911778765,6.679503281911214,6.617902119954427,6.5564314524332685,6.495140035947164,6.433990438779195,6.373006224632263,6.319060802459717,6.2741709152857466,6.232160011927287,6.191259463628133,6.150908907254537,6.110928138097127,6.071207682291667,6.031686782836914,5.992317120234172,5.953023711840312,5.918380657831828,5.887932340304057,5.855492790540059,5.819783369700114,5.780743718147278,5.7386239767074585,5.693664352099101,5.646104216575623,5.596115191777547,5.543852806091309,5.4946393966674805,5.4509092171986895,5.408978621164958,5.367788076400757,5.327037572860718,5.286617080370585,5.246456623077393,5.206525723139445,5.166796684265137,5.127251823743184,5.096756021181743,5.078076203664144,5.063405712445577,5.050575415293376,5.038964907328288,5.028374592463176,5.01872440179189,5.00995401541392,5.002023537953694,4.994923830032349,4.987504204114278,4.979483763376872,4.9719235102335615,4.965063254038493,4.9589329560597735,4.953522642453511,4.9487924973169966,4.94470230738322,4.9412219524383545,4.938302238782247,4.93478278319041,4.930252591768901,4.925712505976359,4.921402414639791,4.917372226715088,4.913622101147969,4.910142183303833,4.9069011608759565,4.905869841575623,4.907489776611328,4.909969846407573,4.912829756736755,4.915789802869161,4.918769756952922,4.921779791514079,4.924789786338806,4.927809715270996,4.930829683939616,4.93386971950531,4.936899979909261,4.93953013420105,4.941650112469991,4.943630139033,4.945570111274719,4.947500109672546,4.9494102001190186,4.951320171356201,4.9532201290130615,4.95511011282603,4.956990083058675,4.95887017250061,4.960740129152934,4.962610205014546,4.964460174242656,4.966320157051086,4.968160231908162,4.970000147819519,4.971840222676595,4.973670125007629,4.975490132967631,4.977310140927632,4.979130069414775,4.980940103530884,4.982750177383423,4.98455011844635,4.986350178718567,4.988140225410461,4.989930232365926,4.991720199584961,4.993500113487244,4.995280146598816,4.9970500866572065,4.998830159505208,5.000600179036458,5.002370119094849,5.004130005836487,5.005900144577026,5.007660150527954,5.00941018263499,5.011170148849487,5.012920101483663,5.014670133590698,5.0163902044296265,5.018070260683696,5.019710183143616,5.021310210227966,5.0228501955668134,5.024350206057231,5.025800307591756,5.02720042069753,5.028540253639221,5.029840270678203,5.031070311864217,5.032260298728943,5.033400376637776,5.034480373064677,5.0355104605356855,5.036490519841512,5.037410457928975,5.03829038143158,5.039120475451152,5.03989044825236,5.040610512097676,5.041280508041382,5.041910529136658,5.04248050848643,5.04300057888031,5.043470541636149,5.043900529543559,5.044270674387614,5.044590711593628,5.044880668322246,5.045140624046326,5.0453806320826216,5.045620600382487,5.045860648155212,5.046100616455078,5.046330650647481,5.046570618947347,5.046810587247212,5.047050515810649,5.047300616900126,5.047540624936421,5.04779068628947,5.0480406284332275,5.048300623893738,5.048550605773926,5.048810521761577,5.049070596694946,5.049320538838704,5.049580613772075,5.049850583076477,5.0501106182734175,5.050370573997498,5.05064058303833,5.050910631815593,5.051170627276103,5.0514406363169355,5.0517105261484785,5.05198061466217,5.052250583966573,5.052520593007405,5.052790562311809,5.05306061108907,5.053330620129903,5.053600509961446,5.053870598475139,5.054140528043111,5.054420590400696,5.0546906391779585,5.054960648218791,5.055230498313904,5.055510600407918,5.0557806094487505,5.056050618489583,5.056320508321126,5.056600530942281,5.056870500246684,5.057140509287517,5.057420571645101,5.057690501213074,5.057960549990336,5.058240493138631,5.058510581652324,5.058780550956726,5.059060573577881,5.059330542882283,5.0596005121866865,5.059870521227519,5.060150583585103,5.060420513153076,5.0607004563013716,5.060970505078633,5.061240514119466,5.061520536740621,5.061790506045024,5.062070528666179,5.062340537707011,5.062610467274983,5.062890450159709,5.063170591990153,5.0634405215581255,5.063720464706421,5.063990473747253,5.064270575841268,5.064540425936381,5.064820448557536,5.065090497334798,5.065360466639201,5.065640489260356,5.065860589345296,5.065980553627014,5.0660905838012695,5.066190640131633,5.066290577252706,5.066400607426961,5.066500544548035,5.06661057472229,5.066720565160115,5.0668206214904785,5.066930611928304,5.06704060236613,5.067140579223633,5.067250569661458,5.067360599835713,5.067460457483928,5.067570606867473,5.067670543988545,5.067780613899231,5.067880551020305,5.0679905017217,5.068090558052063,5.0682006279627485,5.068300525347392,5.068400541941325,5.0685005982716875,5.068600575129191,5.068700551986694,5.068800568580627,5.068900505701701,5.069000522295634,5.069100538889567,5.06920059521993,5.069300572077434,5.0694005489349365,5.0694905916849775,5.069590608278911,5.069690624872844,5.069780508677165,5.0698806047439575,5.069970568021138,5.0700706243515015,5.070160587628682,5.070250630378723,5.070350646972656,5.070440570513408,5.070530613263448,5.070620536804199,5.07071057955424,5.070810635884603,5.070900599161784,5.070990562438965,5.071080565452576,5.0711705684661865,5.071260571479797,5.071340560913086,5.071430603663127,5.0715205272038775,5.071610530217488,5.071700533231099,5.071780522664388,5.071870525677999,5.0719605684280396,5.072040557861328,5.072130600611369,5.07222060362498,5.072300553321838,5.072390635808309,5.072470625241597,5.072560628255208,5.072640577952067,5.072720567385356,5.072810610135396,5.072890599568685,5.072970549265544,5.073060592015584,5.073140581448873,5.073220570882161,5.073310613632202,5.073390603065491,5.073470592498779,5.073550621668498,5.073640624682109,5.073720614115397,5.073800524075826,5.073880553245544,5.073960582415263,5.074040611584981,5.07412052154541,5.074200630187988,5.0742805401484175,5.074370622634888,5.074450532595317,5.074530601501465,5.074610590934753,5.074690580368042,5.074770569801331,5.074850519498189,5.074930548667908,5.075010617574056,5.075090607007344,5.075170516967773,5.075250665346782,5.075320680936177,5.075400630633037,5.075480500857036,5.075560569763184,5.07563054561615,5.075710614522298,5.075790564219157,5.075860579808553,5.075940569241841,5.07602063814799,5.0760906140009565,5.076170563697815,5.076240619023641,5.076320608456929,5.076390624046326,5.076470573743184,5.07654054959615,5.076610604921977,5.076690594355266,5.076760530471802,5.076830546061198,5.076910614967346,5.076980551083882,5.077050566673279,5.077120502789815,5.077200531959534,5.07727054754893,5.077340602874756,5.077410578727722,5.0774805545806885,5.077550649642944,5.077620625495911,5.077690680821736,5.077760616938273,5.077830632527669,5.077900528907776,5.077970584233602,5.078040639559428,5.078110655148824,5.078180591265361,5.078250567118327,5.078320542971293,5.078380624453227,5.078450640042623,5.0785205364227295,5.078590552012126,5.0786605676015215,5.078720569610596,5.078790585199992,5.078860680262248,5.078920563062032,5.078990499178569,5.0790605545043945,5.079120556513469,5.079190492630005,5.07926066716512,5.079320510228475,5.079390684763591,5.079450607299805,5.079520583152771,5.079580624898274,5.079650640487671,5.079710602760315,5.079780618349711,5.079840620358785,5.079900582631429,5.079970598220825,5.080030600229899,5.080100576082866,5.08016053835551,5.080220500628154,5.080290516217549,5.0803505182266235,5.080410599708557,5.080480655034383,5.080540577570598,5.080600619316101,5.080660581588745,5.080730636914571,5.080790559450786,5.080850601196289,5.080910523732503,5.0809706052144366,5.081030607223511,5.081100583076477,5.0811606248219805,5.081220706303914,5.081280509630839,5.081340670585632,5.081400632858276,5.081460634867351,5.0815205574035645,5.081580638885498,5.081640601158142,5.081700563430786,5.08176068464915,5.081820607185364,5.081880609194438,5.081940611203511,5.0820006132125854,5.0820605754852295,5.082120617230733,5.082180619239807,5.082240621248881,5.082300623257955,5.082360585530599,5.082410573959351,5.082470615704854,5.082530538241069,5.082590579986572,5.0826505819956465,5.082710703214009,5.082760572433472,5.082820653915405,5.082880576451619,5.082940578460693,5.082990566889445,5.083050608634949,5.083110690116882,5.0831706921259565,5.083220561345418,5.083280603090922,5.083340605099996,5.083390553792317,5.083450595537822,5.083510637283325,5.083560625712077,5.083620548248291,5.0836805899937945,5.083730538686116,5.083790580431621,5.083840608596802,5.083900610605876,5.083960612614949,5.084010561307271,5.084070603052775,5.084120591481526,5.084180633227031,5.084230542182922,5.084290663401286,5.084340532620748,5.084400534629822,5.0844606558481855,5.084510604540507,5.0845606327056885,5.084590593973796};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.221917470296224,2.6039249698321023,2.0357476472854614,1.6530796190102894,1.3418570359547932,1.0884128709634144,0.8823929131031036,0.7149645586808523,0.579185833533605,0.46906861911217373,0.37981361150741577,0.3074786538879077,0.2488751895725727,0.20140386248628298,0.1629610943297545,0.13183315532902876,0.10663619327048461,0.08623477692405383,0.069721395149827,0.05635259269426266,0.04554406926035881,0.036793540231883526,0.029728642664849758,0.024006025089571875,0.019392375213404495,0.015653693350031972,0.012641874374821782,0.01020887455282112,0.008258920395746827,0.00668512723253419,0.005417076870799065,0.004390970376941065,0.0035610150080174208,0.0028882237578121326,0.0023426979314535856,0.001899903096879522,0.0015403824606134247,0.0012481197578987728,0.0010104099637828767,0.0008172429418967416,0.0006604381487704813,0.0005332489963620901,0.0004302060018138339,0.00034675348676197854,0.0002792934440852453,0.00022471971533377655,0.00018071682886026488,0.00014513673037678623,0.0001165159070903125,3.530232182432277e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8340708414713,563.0186564127604,558.8184305826823,562.6398518880209,565.9287872314453,568.9655100504557,571.8685404459635,572.7207590738932,570.9481302897135,568.3770548502604,565.5823516845703,562.7393849690756,559.8983408610026,557.0713144938151,554.26220703125,551.46630859375,548.6859385172526,546.1548309326172,543.9601694742838,541.9099070231119,539.9367319742838,538.0136108398438,536.1275177001953,534.2694600423177,532.4323984781901,530.610361735026,528.7973429361979,526.9397379557291,524.8388036092123,522.3260879516602,519.3892822265625,516.0583826700846,512.3673807779948,508.3482971191406,504.0281448364258,499.4269307454427,494.56368255615234,489.4692153930664,484.2593307495117,479.04724884033203,473.8671417236328,468.7270202636719,463.6278940836589,458.56582895914715,453.537602742513,448.5399449666341,443.56946055094403,439.7783025105794,437.56307729085285,435.9224675496419,434.5367736816406,433.3054707845052,432.1941172281901,431.18783315022785,430.28055572509766,429.4652582804362,428.7401402791341,427.9724706013997,427.12353515625,426.31328837076825,425.5760854085286,424.91684977213544,424.33463287353516,423.82741292317706,423.3892313639323,423.0180079142253,422.70896402994794,422.33335876464844,421.84654235839844,421.3514455159505,420.87939453125,420.43528747558594,420.02220662434894,419.6381530761719,419.2808888753255,419.15088907877606,419.30235544840497,419.53336842854816,419.7812779744466,420.0353190104167,420.2912775675456,420.54830169677734,420.80628712972003,421.06529235839844,421.32527923583984,421.5852737426758,421.84530385335285,422.0774434407552,422.2724965413411,422.4565149943034,422.6365203857422,422.8145243326823,422.9915313720703,423.1675338745117,423.3435312906901,423.51853434244794,423.69253794352215,423.86553955078125,424.03754170735675,424.2095438639323,424.3805465698242,424.55154673258465,424.72154998779297,424.8905512491862,425.05954996744794,425.22755940755206,425.39455159505206,425.56255594889325,425.72855885823566,425.8955561319987,426.0615641276042,426.226557413737,426.3915659586589,426.5555648803711,426.71956634521484,426.88356526692706,427.0465672810872,427.2095718383789,427.37156931559247,427.5345687866211,427.69657135009766,427.8585739135742,428.0195795694987,428.1805725097656,428.34157307942706,428.50257873535156,428.6625747680664,428.82357533772785,428.9825795491536,429.1395950317383,429.2916005452474,429.4406204223633,429.58362833658856,429.72264607747394,429.8556594848633,429.98367563883465,430.1056950887044,430.2227096557617,430.33373260498047,430.43874104817706,430.53876241048175,430.63277943929035,430.7207972208659,430.8038101196289,430.8808314005534,430.95284271240234,431.0188624064128,431.0798746744792,431.13489532470703,431.1839090983073,431.2289276123047,431.2669372558594,431.3009516398112,431.32896931966144,431.35099029541016,431.3679962158203,431.38001759847003,431.3870315551758,431.38904062906903,431.38804880777997,431.3860549926758,431.38305409749347,431.3800532023112,431.37705485026044,431.3740539550781,431.3700586954753,431.36705017089844,431.3650487263997,431.362055460612,431.36005147298175,431.35805257161456,431.3560485839844,431.3550491333008,431.3530502319336,431.352045694987,431.3510462443034,431.3500442504883,431.3490473429362,431.34804280598956,431.3480453491211,431.3470509847005,431.3470408121745,431.34704844156903,431.3470408121745,431.3470458984375,431.3470458984375,431.3470408121745,431.3470509847005,431.3470408121745,431.34804280598956,431.3480402628581,431.3480453491211,431.3480402628581,431.3490498860677,431.34904225667316,431.35004170735675,431.3500442504883,431.3500442504883,431.3510437011719,431.3510487874349,431.35103607177734,431.352045694987,431.35203806559247,431.35304768880206,431.35304005940753,431.3540522257487,431.3540395100911,431.35504150390625,431.35504150390625,431.35604604085285,431.3560434977214,431.3560434977214,431.35704549153644,431.35704040527344,431.3580373128255,431.35804748535156,431.35804239908856,431.35904693603516,431.3590443929036,431.36004130045575,431.3600438435872,431.3610432942708,431.36104583740234,431.3620427449544,431.3620427449544,431.36304473876953,431.363042195638,431.3640416463216,431.36504618326825,431.3650436401367,431.3660430908203,431.3670399983724,431.3670476277669,431.3670374552409,431.3680419921875,431.36804453531903,431.3690363566081,431.3730239868164,431.3820088704427,431.3920160929362,431.4020131429036,431.4130121866862,431.4240137736003,431.4350102742513,431.44701385498047,431.45801544189453,431.4700113932292,431.4810104370117,431.49300893147785,431.50401560465497,431.5160090128581,431.52701568603516,431.5380096435547,431.55001068115234,431.5610122680664,431.57201385498047,431.5840123494466,431.59501393636066,431.60601298014325,431.6170120239258,431.62800852457684,431.6390101114909,431.65001169840497,431.66101328531903,431.67200978597003,431.6830113728841,431.6930160522461,431.7040100097656,431.7150166829427,431.72501373291016,431.7360102335612,431.7460123697917,431.7570114135742,431.7670160929362,431.7780125935872,431.7880172729492,431.79801177978516,431.80802154541016,431.81801350911456,431.8290100097656,431.8390197753906,431.84900919596356,431.8590138753255,431.8690185546875,431.8780212402344,431.8880132039388,431.8980178833008,431.9080073038737,431.9180221557617,431.92701212565106,431.93701934814453,431.9460144042969,431.9560139973958,431.9660135904948,431.9750213623047,431.9840138753255,431.99401601155597,432.00301869710285,432.0130157470703,432.0220184326172,432.03101348876953,432.04101308186847,432.05001576741535,432.0590184529622,432.0680185953776,432.07701619466144,432.0860239664714,432.0950164794922,432.1040217081706,432.1130091349284,432.1230214436849,432.1310170491536,432.14001719156903,432.14901479085285,432.1580225626628,432.1670150756836,432.17601521809894,432.18502044677734,432.1940155029297,432.20301818847656,432.21102142333984,432.2200164794922,432.22901916503906,432.23802185058594,432.2460199991862,432.25501759847003,432.26401774088544,432.2720133463542,432.28101603190106,432.2900136311849,432.2990188598633,432.30702209472656,432.3160146077474,432.3250223795573,432.33301798502606,432.3420181274414,432.3500239054362,432.3590138753255,432.3670196533203,432.37601979573566,432.38402048746747,432.3930180867513,432.4010187784831,432.40901947021484,432.4180145263672,432.426020304362,432.43402099609375,432.4420216878255,432.4510218302409,432.45902252197266,432.4670181274414,432.4750213623047,432.48301951090497,432.49102274576825,432.4990234375,432.50702412923175,432.51501719156903,432.5230204264323,432.53102111816406,432.53902435302734,432.54701741536456,432.55502065022785,432.5630187988281,432.57002512613934,432.5780207316081,432.5860188802083,432.5940221150716,432.6010233561198,432.60901896158856,432.61702219645184,432.62402089436847,432.6320114135742,432.63902537027997,432.6470235188802,432.6540247599284,432.6620152791341,432.66902923583984,432.67701721191406,432.6840286254883,432.6920216878255,432.6990280151367,432.70701853434247,432.71403249104816,432.7210235595703,432.72901662190753,432.7360204060872,432.74302927652997,432.7500178019206,432.7580210367839,432.76502482096356,432.7720235188802,432.7790298461914,432.78602091471356,432.7930221557617,432.8000208536784,432.8080291748047,432.81502532958984,432.82202402750653,432.8290252685547,432.83602142333984,432.843022664388,432.8500239054362,432.8570251464844,432.86402384440106,432.8710225423177,432.8780263264974,432.88402557373047,432.8910217285156,432.8980229695638,432.905024210612,432.91202545166016,432.9190266927083,432.9250233968099,432.9320246378581,432.9390182495117,432.94602457682294,432.9520263671875,432.95902252197266,432.9660237630208,432.9730275472005,432.9790267944336,432.98602294921875,432.99302673339844,432.9990234375,433.0060272216797,433.01202392578125,433.0190251668294,433.0260289510091,433.0320231119792,433.03902435302734,433.04502360026044,433.0520248413086,433.05802663167316,433.06502532958984,433.0710220336914,433.0780258178711,433.0840301513672,433.09002176920575,433.0970230102539,433.10302734375,433.11002349853516,433.1160252888997,433.12202707926434,433.12902577718097,433.1350326538086,433.1410217285156,433.1480229695638,433.1540273030599,433.16002400716144,433.16702524820965,433.1730244954427,433.1790237426758,433.1850229899089,433.19202423095703,433.19803110758465,433.2040252685547,433.2100245157878,433.21602630615234,433.22301991780597,433.2290344238281,433.2350260416667,433.2410303751628,433.2470219930013,433.2530263264974,433.25902557373047,433.2660191853841,433.27202860514325,433.2780253092448,433.2840270996094,433.2900212605794,433.29602305094403,433.3020248413086,433.30802663167316,433.3140233357747,433.32003021240234,433.32602945963544,433.332026163737,433.3380304972331,433.34402720133465,433.3500289916992,433.35602315266925,433.3620249430339,433.36802673339844,433.3740234375,433.3800354003906,433.3820393880208};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.448221604029337,9.76348908742269,10.082427342732748,9.470434983571371,9.677613894144693,9.890563090642294,10.103607098261515,10.147454420725504,10.007437149683634,9.852039098739624,9.695418357849121,9.538686990737915,9.381955623626709,9.225218534469604,9.068472703297934,8.911743640899658,8.754984696706137,8.624040762583414,8.521163940429688,8.42063037554423,8.320277889569601,8.219948252042135,8.11961849530538,8.019287586212158,7.918959458669026,7.8186347881952925,7.718313733736674,7.604442318280538,7.475858489672343,7.346033692359924,7.216125408808391,7.08619487285614,6.956264615058899,6.826345324516296,6.696413040161133,6.566498915354411,6.436554869016011,6.331006765365601,6.251987497011821,6.175188302993774,6.098563353220622,6.021955291430156,5.94534416993459,5.868735074996948,5.792123158772786,5.715518593788147,5.638893246650696,5.594744364420573,5.585887670516968,5.580004652341207,5.574335932731628,5.568699796994527,5.563057978947957,5.557418942451477,5.551778435707092,5.546138763427734,5.5404982169469195,5.536013960838318,5.532781561215718,5.529662251472473,5.526541908582051,5.5234220425287885,5.520311911900838,5.517192045847575,5.514071981112163,5.510962009429932,5.507842063903809,5.504891276359558,5.502111117045085,5.499351104100545,5.496590971946716,5.493831038475037,5.4910710255304975,5.488311052322388,5.485551079114278,5.482791066169739,5.48003085454305,5.47823707262675,5.477505167325337,5.476855715115865,5.4762052694956465,5.475565671920776,5.474925359090169,5.474285523096721,5.473645329475403,5.4729955196380615,5.472355445226033,5.471874753634135,5.471574505170186,5.471294482549031,5.471004565556844,5.470724582672119,5.4704445997873945,5.470154484113057,5.469874540964763,5.469584584236145,5.469304482142131,5.469024499257405,5.468734622001648,5.468454480171204,5.468164523442586,5.467884540557861,5.467604557673137,5.467314561208089,5.467034498850505,5.46675459543864,5.466464519500732,5.466184536616008,5.46589454015096,5.465614517529805,5.465334534645081,5.465044538180034,5.464764674504598,5.464474558830261,5.4641945362091064,5.463914513587952,5.463624556859334,5.46334449450175,5.463054537773132,5.462774554888408,5.462494572003682,5.462204575538635,5.46192451318105,5.461634556452434,5.461354573567708,5.461074511210124,5.460784554481506,5.460504492123921,5.460214535395305,5.45993447303772,5.459654609362285,5.459364573160808,5.459084590276082,5.458804567654927,5.45851453145345,5.458234628041585,5.457944591840108,5.457664608955383,5.457384546597798,5.457094589869182,5.4568144877751665,5.456524570782979,5.456244468688965,5.4559645652771,5.455674608548482,5.455394506454468,5.45510454972585,5.454824487368266,5.454544544219971,5.454254508018494,5.453974485397339,5.453694502512614,5.453404506047566,5.453124562899272,5.452834606170654,5.45255446434021,5.452274521191915,5.4519844849904375,5.451704502105713,5.451414505640666,5.4511345227559405,5.450854539871216,5.450564583142598,5.450284520785014,5.4499945640563965,5.449714541435242,5.449434479077657,5.449144562085469,5.448864459991455,5.448574542999268,5.448294520378113,5.448014418284099,5.447724501291911,5.447444518407186,5.447164495786031,5.446874539057414,5.446594516436259,5.446304559707642,5.446024537086487,5.445744514465332,5.445454557736714,5.44517457485199,5.444884578386943,5.444604516029358,5.4443245728810625,5.4440345366795855,5.443754553794861,5.443464597066243,5.443184534708659,5.442904551823934,5.442614555358887,5.442334612210591,5.442044536272685,5.4417645533879595,5.441484610239665,5.441194574038188,5.440914511680603,5.440624634424846,5.440344532330831,5.440064509709676,5.439774513244629,5.439494530359904,5.439214587211609,5.438924551010132,5.438644568125407,5.43835453192393,5.438074509302775,5.43779460589091,5.437504569689433,5.437224467595418,5.436934471130371,5.4366544882456465,5.436374545097351,5.436084548632304,5.435804486274719,5.435514569282532,5.435234427452087,5.434954524040222,5.4346645673116045,5.43438442548116,5.434104522069295,5.433814525604248,5.433534502983093,5.433244585990906,5.432964523633321,5.432684540748596,5.4323945840199785,5.432114481925964,5.431824604670207,5.4315444231033325,5.431264479955037,5.43097452322642,5.4306944608688354,5.4304044644037885,5.430124481519063,5.4298445383707685,5.429554462432861,5.429404060045878,5.429393728574117,5.429393808046977,5.429383794466655,5.429383794466655,5.429383754730225,5.429383834203084,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
    HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225462595621746,24.52680762608846,24.88080708185832,25.22910737991333,25.58390760421753,25.94090747833252,26.296507199605305,26.616607189178467,26.873507340749104,27.07540734608968,27.229907194773357,27.343407313028973,27.386006991068523,27.332706451416016,27.198806444803875,26.99760627746582,26.740705966949463,26.404005527496338,25.967505137125652,25.44980525970459,24.8667049407959,24.23220443725586,23.558204174041748,22.855003992716473,22.131303946177166,21.394703547159832,20.65170367558797,19.913002967834473,19.186203161875408,18.470802783966064,17.766602993011475,17.07390244801839,16.393102486928303,15.724602460861206,15.06910220781962,14.42700203259786,13.798902034759521,13.183701912562052,12.581501881281534,11.9939018090566,11.422401507695517,10.868101517359415,10.331901629765829,9.814351320266724,9.315771341323853,8.836371103922525,8.37618112564087,7.934811035792033,7.5120309591293335,7.107930898666382,6.722430904706319,6.35533086458842,6.006270845731099,5.674820780754089,5.360470692316691,5.062660654385884,4.780790646870931,4.513850569725037,4.260910630226135,4.021490514278412,3.7950804829597473,3.5811304847399392,3.3791004618008933,3.188430448373159,3.008570412794749,2.8389803767204285,2.6791303555170694,2.528320332368215,2.3858903447786965,2.251430332660675,2.1245402892430625,2.0048102935155234,1.8918602565924327,1.7853202521800995,1.6848502457141876,1.5902902285257976,1.5014602144559224,1.4179601967334747,1.3394101858139038,1.2654901842276256,1.1958901584148407,1.1303301652272542,1.068550129731496,1.0103301405906677,0.9554251432418823,0.9036361376444498,0.856948142250379,0.8161651442448298,0.7797441383202871,0.7471781323353449,0.7180201311906179,0.6918761332829794,0.6683951367934545,0.647269124786059,0.6282231311003367,0.6110191295544306,0.5954451312621435,0.5813101232051849,0.5684491246938705,0.5567151258389155,0.5459781239430109,0.5361201216777166,0.5270411173502604,0.5186521261930466,0.5108741174141566,0.503634124994278,0.49687211712201435,0.49053211758534115,0.48456311970949173,0.4789241204659144,0.4735761160651843,0.46848711123069126,0.46362611651420593,0.45896511276563007,0.45448310921589535,0.45015611002842587,0.44596710552771884,0.4419001092513402,0.43794211000204086,0.4340791081388791,0.43030010163784027,0.4265941033760707,0.4229511072238286,0.4193651005625725,0.4158291021982829,0.4123371069629987,0.40888410061597824,0.40546110024054843,0.4020681008696556,0.39870009819666546,0.3953520978490512,0.39202209562063217,0.38870609551668167,0.3854010949532191,0.382102092107137,0.3788090944290161,0.3755220870176951,0.3722370887796084,0.36895309140284854,0.365669089059035,0.36238308995962143,0.3590930898984273,0.3558000847697258,0.35250308364629745,0.34920208404461545,0.34589508175849915,0.3425830850998561,0.33926408489545185,0.3359370802839597,0.332604077955087,0.3292640795310338,0.3259170825282733,0.322563074529171,0.31920207291841507,0.31583407272895175,0.31245607634385425,0.3090720747907956,0.3056800688306491,0.30228207012017566,0.2988770703474681,0.2954660654067993,0.29204907019933063,0.288626067340374,0.2851980651418368,0.28176606446504593,0.27833106368780136,0.27489306529362995,0.27145106593767804,0.2680070648590724,0.2645590603351593,0.2611080581943194,0.2576550592978795,0.25420105705658597,0.2507450580596924,0.24728705609838167,0.24382805451750755,0.24036505445837975,0.2369020531574885,0.23343705385923386,0.22997104997436205,0.2265040489534537,0.22303604955474535,0.2195670468111833,0.2160950464506944,0.21262204771240553,0.20914804562926292,0.2056740460296472,0.20219904432694116,0.19872304424643517,0.195246039579312,0.19176604226231575,0.18828603997826576,0.18480403969685236,0.18132303903500238,0.17784003789226213,0.17435703674952188,0.17087303598721823,0.16738503302137056,0.16389803464214006,0.16040903454025587,0.15692003319660822,0.15343103309472403,0.14993802830576897,0.1464450297256311,0.14295103028416634,0.13945702960093817,0.13596202805638313,0.1324660231669744,0.12897002572814623,0.12547002422312895,0.12197102295855682,0.1184700212130944,0.11496902133027713,0.11146701996525128,0.10796401960154374,0.10446101861695449,0.10095501815279324,0.09744801620642345,0.09394061503310998,0.09043251598874728,0.08692371348539989,0.08341421249012153,0.07990401114026706,0.07639071221152942,0.07287691098948319,0.0693625087539355,0.06584740802645683,0.0623317069063584,0.05881520640105009,0.05529790557920933,0.0517777039979895,0.048256903886795044,0.044735402489701905,0.04121330256263415,0.03769060100118319,0.03416700009256601,0.030642699915915728,0.027308800412962835,0.024337599985301495,0.02168989988664786,0.019330200118323166,0.017227400094270706,0.015353399949769178,0.013683300154904524,0.012194899919753274,0.010868500064437589,0.009686399949714541,0.008632910049830874,0.0076940399982656045,0.006857309994908671,0.00611159997060895,0.005447019978115956,0.004854720047054191,0.004326849981832008,0.00385638993854324,0.003437110009447982,0.0030634200084023178,0.0027303799870423973,0.002433549981409063,0.0021690099965780973,0.0019332299804470192,0.0017230899829883128,0.0015357900022839506,0.001368869988558193,0.0012200900043050449,0.0010874800112408896,0.000969296995511589,0.0008639580046292394,0.0007700710023830956,0.0006863890012027696,0.0006118040037108585,0.0005453250050777569,0.00048607300414005294,0.00043326000013621524,0.00038618699909420684,0.0003442299979118009,0.0003068329994372713,0.00027350000164005905,0.00024378899979637936,0.00021730699882027693,0.000193701998796314,0.00017266199817337716,0.00015390800035675056,0.00013719099903634438,0.000122290998964066,0.00010900899966751847,2.534971099521499e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.05017598470052,22.259799321492512,22.127699216206867,22.122399012247723,22.08479913075765,22.019899368286133,21.931999683380127,21.808899402618408,21.64099931716919,21.43709929784139,21.204699357350666,20.9500994682312,20.657999356587727,20.31599982579549,19.934799512227375,19.52369960149129,19.090499718983967,18.621699651082356,18.106599648793537,17.556599617004395,16.981499830881756,16.38949966430664,15.787699778874716,15.18179980913798,14.576899766921997,13.976799885431925,13.384999910990397,12.805400053660074,12.241000016530355,11.692300081253052,11.159600098927816,10.643199841181437,10.14329997698466,9.660020033518473,9.193319956461588,8.743129968643188,8.309290091196695,7.89109989007314,7.488089958826701,7.1004200379053755,6.728119969367981,6.371129949887593,6.0292900403340655,5.702379981676738,5.390099962552388,5.092129906018575,4.8080999453862505,4.53750999768575,4.279929916063945,4.03503002723058,3.8024799823760986,3.5819000204404197,3.3728699684143066,3.1749800046284995,2.9877899885177612,2.8108699719111123,2.643779993057251,2.4859699805577598,2.3369099696477256,2.1962200005849204,2.0635199745496116,1.9384399851163228,1.8205999930699666,1.7096499900023143,1.6052300035953522,1.5070099929968517,1.4146500031153362,1.3277799884478252,1.2460499902566273,1.1691900094350178,1.0969200034936268,1.0290000140666962,0.9651769995689392,0.9052199920018514,0.8489079922437668,0.796085000038147,0.7465920001268387,0.700216993689537,0.6567560036977133,0.6160279959440231,0.5778580009937286,0.5420830001433691,0.5085519949595133,0.47712399810552597,0.44766899943351746,0.42006199806928635,0.3947329993049304,0.37153299649556476,0.34977899740139645,0.3293779989083608,0.3102420022090276,0.2922919988632202,0.2754549980163574,0.2596610014637311,0.2448410006860892,0.23093700036406517,0.217890997727712,0.2056459995607535,0.19415499766667685,0.18336999788880348,0.17324400072296461,0.16373700027664503,0.15481099983056387,0.1464310015241305,0.13855999832352003,0.13116799915830293,0.124225997676452,0.11770300070444743,0.11157199988762538,0.10581299910942714,0.1004019994288683,0.09531369991600513,0.09053189866244793,0.08603699877858162,0.08180889797707398,0.07783349913855393,0.07409499896069367,0.07057639956474304,0.0672642004986604,0.06414779958625634,0.06121529887119929,0.05845279898494482,0.05585229893525442,0.05340369946012894,0.05109539907425642,0.04891869953523079,0.046867799324293934,0.044934999818603195,0.04311069908241431,0.04139049972097079,0.03976800044377645,0.03823489975184202,0.03678559915473064,0.03541719913482666,0.03412489996602138,0.03290159969280163,0.031745298920820154,0.03065199948226412,0.029615499700109165,0.028634599254777033,0.027705899594972532,0.026823799591511488,0.025985499378293753,0.025190699379891157,0.024436699381719034,0.02371869965766867,0.023036799393594265,0.02238879958167672,0.02177029972275098,0.021179499415059883,0.020617099789281685,0.02008129966755708,0.01956809979553024,0.019078599599500496,0.018611299494902294,0.018162499492367108,0.017733399756252766,0.017322799501319725,0.016927299555391073,0.01654589967802167,0.016180199726174276,0.015829199614624184,0.015489699474225441,0.0151632996276021,0.014849299564957619,0.014544599611933032,0.014248599608739218,0.013963199608648816,0.013687799762313565,0.013419299619272351,0.013159699582805237,0.012908599649866423,0.012662999720002214,0.012424899575610956,0.012193999718874693,0.011967399623245,0.011744899675250053,0.01152859969685475,0.01131809976262351,0.011110699735581875,0.010908599710091949,0.010711499800284704,0.010516699636355042,0.010324099799618125,0.010135899918774763,0.009951769762362042,0.009769229839245478,0.009590489712233344,0.009415319810310999,0.009241149760782719,0.009070279852797588,0.008902509929612279,0.008735299808904529,0.008568609831854701,0.008404769857103625,0.008243599828953544,0.008082589833065867,0.007924079817409316,0.007767919800244272,0.007611619774252176,0.007455189828760922,0.007300969834129016,0.007148839843769868,0.006996319823277493,0.006845779872188966,0.006697099811087052,0.006547829834744334,0.006397979916073382,0.0062499498793234425,0.00610362986723582,0.005956549857122202,0.005811119878975053,0.005667229842705031,0.0055224397995819645,0.00537914988429596,0.005237269836167495,0.00509436991220961,0.004950499899374942,0.004808059854743381,0.004666979890316725,0.004524810006842017,0.004383979947306216,0.004244389943778515,0.004103619993353884,0.0039617498793328805,0.0038211799304311476,0.0036818299364919462,0.003541279952817907,0.003401939970596383,0.0032637499777289727,0.003124289990713199,0.0029859699619313083,0.0028487199645799897,0.0027101399997870126,0.002570299974953135,0.002431609978278478,0.00229400999766464,0.002159779988384495,0.002033410011790693,0.0019144300119175266,0.0018024199913876753,0.0016969699839440484,0.0015976900079598029,0.001504230002562205,0.001416230001874889,0.00133338999391223,0.0012553900208634634,0.0011819699914970745,0.0011128300102427602,0.0010477500036358833,0.0009864739937863003,0.0009287839930038899,0.0008744700025999919,0.00082333399526154,0.0007751910015940666,0.0007298639975488186,0.0006871899968245998,0.0006470119988080114,0.0006091849985144412,0.0005735710001317784,0.000540039996849373,0.0005084709991933778,0.0004787489985271047,0.0004507650010054931,0.0004244169977027923,0.0003996109977985422,0.00037625499923403066,0.0003542660003101143,0.000333561998559162,0.00031406900234287605,0.00029571599831494194,0.0002784359991589251,0.00026216599993252504,0.00024684800155228004,0.00023242499810294248,0.00021884600088621178,0.00020605999937591454,0.0001940220002628242,0.00018268699811111824,0.00017201499940711074,0.0001619669989546916,0.00015250600093471198,0.0001435979999466023,0.0001352099995225823,0.00012731300133358067,0.0001198779991682386,0.00011287699938596536,0.00010628399953323726,5.079168173930763e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.6956329345703,237.72884877522787,240.94988123575845,243.35291290283203,244.98493830362955,246.0109545389811,246.5630137125651,246.0360895792643,244.021120707194,240.96514892578125,237.212158203125,233.02120971679688,227.89127985636392,221.4752960205078,214.24731953938803,206.5633176167806,198.68736012776694,190.15541330973306,180.64442189534506,170.60042826334634,160.35442352294922,150.1504160563151,140.1603978474935,130.50837898254395,121.27435874938965,112.50933837890625,104.24331792195638,96.4655990600586,89.15757942199707,82.31376139322917,75.9224427541097,69.96732584635417,64.42890898386638,59.2860943476359,54.51668039957682,50.09836641947428,46.00865459442139,42.222443262736,38.71723206837972,35.47722180684408,32.486412366231285,29.728803157806396,27.18909517923991,24.852287133534748,22.70398012797038,20.730573813120525,18.919267654418945,17.257261753082275,15.733056624730429,14.33675185839335,13.058847268422445,11.890243291854858,10.822539647420248,9.847706158955893,8.958272775014242,8.147260109583536,7.40818723042806,6.73454491297404,6.120432694753011,5.560930609703064,5.0514687697092695,4.587816993395488,4.166045506795247,3.782534102598826,3.4339427947998047,3.117211620012919,2.829500595728556,2.5680796106656394,2.3304587403933206,2.1145278811454773,1.918367216984431,1.74020653963089,1.5784359375635784,1.4315554002920787,1.298244873682658,1.1773644089698792,1.0678940117359161,0.968718633055687,0.8788612981637319,0.7974379857381185,0.7236487021048864,0.6567674527565638,0.5961402207612991,0.5411730160315832,0.49133483072121936,0.4461416353782018,0.4054524749517441,0.3688073481122653,0.3354712277650833,0.305134117603302,0.2775440141558647,0.2524729259312153,0.22968683888514838,0.2089447615047296,0.19008569543560347,0.17293463026483855,0.15733257432778677,0.1431365224222342,0.13021547347307205,0.11847943067550659,0.10781939389805,0.09810795821249485,0.08925812505185604,0.08121739576260249,0.07391116954386234,0.06727184417347114,0.0612382215137283,0.055754601334532104,0.050770384880403675,0.04621296934783459,0.042043053545057774,0.038252039812505245,0.03480532641212145,0.03167141523833076,0.028821805026382208,0.026230295654386282,0.023873486711333197,0.02172997873276472,0.019780271997054417,0.01800676512842377,0.016393459402024746,0.014925654046237469,0.013590249232947826,0.012375144675994912,0.01126944087445736,0.010263237093264857,0.0093475137061129,0.00851408081750075,0.007755487963246803,0.007064945413731039,0.0064363131920496626,0.005863981127428512,0.005342869165663918,0.0048683676092575,0.00443625597593685,0.004042724516087522,0.003684303218809267,0.0033578320289961994,0.0030604509908395507,0.0027895300105835,0.002542719147944202,0.0023178382931898036,0.002112947559605042,0.0019262368732597679,0.001756096287863329,0.0016010457184165716,0.0014597352031463136,0.0013309347559697926,0.0012135443297059585,0.0011065339591975014,0.0010089936113217846,0.0009200712811434641,0.0008390069948897386,0.0007651017416113367,0.0006977194861974567,0.0006362842686939985,0.0005802680728569006,0.0005291908843598018,0.00048261572131499025,0.0004401465703267604,0.0004014184305560775,0.0003661033066843326,0.00033389818903136376,0.0003045300885181253,0.0002777489911143978,0.0002533259018188498,0.00023105282283116443,0.00021074174946988933,0.00019221768282780735,0.00017532462394835116,0.00015991757027222775,0.00014586652105208486,0.00013305247315050414,0.00012136443365307059,0.00011070539464223354,6.002932362510668e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527342200279236,3.5471805532773337,3.4357404311498008,3.32701047261556,3.216820478439331,3.1059004863103232,2.99487042427063,2.8842904567718506,2.7746404012044272,2.6663204034169516,2.559670408566793,2.4549904068311057,2.352500398953756,2.2524203658103943,2.154900372028351,2.0600603222846985,1.968010316292445,1.8788103262583415,1.792510320742925,1.7091303169727325,1.6286902725696564,1.5511802732944489,1.476580262184143,1.4048502544562023,1.3359702328840892,1.2698702315489452,1.206500232219696,1.1458002030849457,1.0877102116743724,1.0321501990159352,0.9790621846914291,0.9283671826124191,0.8799911687771479,0.8338611622651418,0.7899001638094584,0.7480281442403793,0.708170140782992,0.670249139269193,0.634189118941625,0.5999161253372828,0.567356119553248,0.5364391058683395,0.5070921008785566,0.4792470956842105,0.4528370921810468,0.4277970815698306,0.404065082470576,0.3815820763508479,0.36028706779082614,0.3401230648159981,0.32103606561819714,0.30297406017780304,0.28588705758253735,0.2697250545024872,0.2544410564005375,0.23999104648828506,0.22633404781421027,0.213428046554327,0.20123304054141045,0.18971403812368712,0.17883603647351265,0.1685630331436793,0.15886203199625015,0.1497050312658151,0.14106303080916405,0.13290602962176004,0.12521102651953697,0.11795102432370186,0.11110302371283372,0.10464302202065785,0.098550820723176,0.09280541973809402,0.08738891780376434,0.08228231531878312,0.07746811583638191,0.07293141509095828,0.0686567152539889,0.06462741270661354,0.06083011285712322,0.05725361220538616,0.0538842116172115,0.05070891045033932,0.0477190101519227,0.04490310947100321,0.0422501095260183,0.039751808469494186,0.03748550731688738,0.035424607495466866,0.0334745068103075,0.031628206527481474,0.029879105743020773,0.028221305614958208,0.02664910474171241,0.025174404960125685,0.023773904889822006,0.022442904611428578,0.021194503953059513,0.02000610421722134,0.018874003707120817,0.017812103653947513,0.016816003403315943,0.015881703235208988,0.014987802986676494,0.014131902949884534,0.013329102657735348,0.012575902510434389,0.01186940244709452,0.011206602212041616,0.010584902173529068,0.009984162248050174,0.009403191894913713,0.008858161823203167,0.008346841670572758,0.00786714154916505,0.0074171014518166585,0.006994881434366107,0.006598751293495297,0.006227101276939114,0.005878421089922388,0.005551271140575409,0.005244331123928229,0.004956351011060178,0.004686150816269219,0.004432630880425374,0.004177320942593117,0.003920320906521131,0.0036791807506233454,0.00345291073123614,0.0032405907016557953,0.0030413606436923146,0.002854410617146641,0.0026789705928725502,0.0025143405267347894,0.0023598604990790286,0.0022148804661507406,0.002078830439131707,0.0019511504312201093,0.0018313303783846397,0.0017188803758472204,0.0016133503425711144,0.001514310317967708,0.0014213503163773566,0.0013341102749109268,0.0012522302567958832,0.0011753902460138004,0.0011032602439324062,0.0010355702155114461,0.000972030208989357,0.0009123951943668848,0.0008564221789129078,0.0008038851713839298,0.0007545731593078623,0.0007082881590273852,0.0006648431396267066,0.0006240641329592714,0.0005857881187694147,0.0005498591150778035,0.0005161351097437242,0.00048447910133594024,0.00045476509937240434,0.00042687409101442125,0.00040069308791620034,0.0003761180754130085,0.0003530500762281008,0.00033139807055704296,0.0003110730685875751,0.0002919950614644525,0.00027408705742952105,0.0002572770487555924,0.00024149905463370183,0.00022668804983065152,0.00021278504452008443,0.0001997360389699073,0.0001874860390671529,0.0001759880360623356,0.00016519603498939736,0.00015506503162517524,0.00014555503124332367,0.00013662902832341692,0.00012825002704630606,0.00012038602653774433,0.00011300302382248144,0.0001060730222282776,4.226278967204659e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844189604123435,3.2989591360092163,3.3043891390164695,3.3077592055002847,3.309149225552877,3.3086692690849304,3.3063992659250894,3.302439332008362,3.2968693574269614,3.2897793849309287,3.2812493642171225,3.271349390347799,3.260149439175924,3.247719426949819,3.2341294487317405,3.2194395065307617,3.2037194768587747,3.1870195269584656,3.1693994998931885,3.150919576485952,3.1316195726394653,3.1115495562553406,3.090769648551941,3.0693196256955466,3.047239621480306,3.0245796044667563,3.001359681288401,2.977639655272166,2.9534396727879844,2.9288097421328225,2.903779685497284,2.8783997098604837,2.8526897033055625,2.8266897797584534,2.8004297415415444,2.773939768473307,2.747259775797526,2.720399777094523,2.6933997869491577,2.666279753049215,2.6390697757403054,2.611789802710215,2.5844497879346213,2.55707981189092,2.529709796110789,2.5023398200670877,2.4749998251597085,2.4476898312568665,2.4204498330752053,2.3932798703511557,2.366189877192179,2.3391998410224915,2.3123198548952737,2.2855498592058816,2.2589198549588523,2.2324198484420776,2.2060698866844177,2.1798698902130127,2.153839866320292,2.1279699007670083,2.1022799015045166,2.0767699082692466,2.05144993464152,2.026309907436371,2.001369923353195,1.976629912853241,1.952089915672938,1.9277599155902863,1.903639942407608,1.8797299365202587,1.856039931376775,1.8325599332650502,1.8092999358971913,1.7862499554951985,1.763439933458964,1.7408399482568104,1.7184699376424153,1.6963199575742085,1.6743999520937602,1.6527099609375,1.6312399506568909,1.60998997092247,1.5889799694220226,1.568179965019226,1.5476199587186177,1.5272799829641979,1.5063999990622203,1.4850099782148998,1.463919997215271,1.443129986524582,1.42261998852094,1.4023899932702382,1.3824499944845836,1.3627899785836537,1.3434100051720936,1.3242700099945068,1.3054099877675374,1.2868199944496155,1.2685000101725261,1.2504299879074097,1.232610007127126,1.2150399883588154,1.1977300147215526,1.1806599895159404,1.1638199885686238,1.1472299993038177,1.1308799982070923,1.1147400041421254,1.098850001891454,1.0831900139649708,1.067749987045924,1.0525100032488506,1.0375099976857503,1.0227200090885162,1.008159985144933,0.9937870055437088,0.9796109994252523,0.9656440069278082,0.951884999871254,0.9383300046126047,0.9249750127394994,0.9117979953686396,0.8987949937582016,0.8859850068887075,0.8733640064795812,0.8609289973974228,0.8486780027548472,0.8366069942712784,0.824714000026385,0.8129970033963522,0.8014510075251261,0.7900549918413162,0.7788069993257523,0.767723004023234,0.7568019976218542,0.7460400015115738,0.7354349941015244,0.7249839951594671,0.7146859963734945,0.7045379976431528,0.6945359905560812,0.6846799949804941,0.6749659975369772,0.66539299984773,0.6559590051571528,0.6466600000858307,0.6374960045019785,0.6284630000591278,0.6195599983135859,0.6107850025097529,0.6021370043357214,0.59361199537913,0.585208997130394,0.5769059956073761,0.5687029957771301,0.5606160014867783,0.5526449928681055,0.5447869996229807,0.5370410035053889,0.5294059962034225,0.5218789875507355,0.5144589940706888,0.5071450024843216,0.49993499120076496,0.49282700071732205,0.4858200003703435,0.4789140025774638,0.4721050014098485,0.46539399524529773,0.45877700050671893,0.4522550006707509,0.4458260014653206,0.4394889970620473,0.43324100226163864,0.42708300054073334,0.4210119992494583,0.4150270000100136,0.40912800282239914,0.4033130034804344,0.39758000522851944,0.3919289981325467,0.38635900368293125,0.38086699694395065,0.37545400112867355,0.3701179971297582,0.3648579989870389,0.35967299590508145,0.3545609985788663,0.349522997935613,0.34455600132544834,0.3396590054035187,0.33483300109704334,0.3300749982396762,0.32538499931494397,0.3207610050837199,0.3162040039896965,0.31171099344889325,0.3072820032636325,0.3029160052537918,0.2986120010415713,0.29437000056107837,0.2901879946390788,0.2860649997989337,0.28200100362300873,0.2779950027664502,0.2740460013349851,0.2701529984672864,0.266315000752608,0.26253200074036914,0.25880300005276996,0.2551269978284836,0.25150299693147343,0.24793099984526634,0.2444089986383915,0.24093800286451975,0.23751600086688995,0.23414299885431925,0.23081699758768082,0.22753899917006493,0.2243080014983813,0.22112200036644936,0.21798200036088625,0.2148869993786017,0.21183500190575918,0.20882700135310492,0.2058620018263658,0.20293899873892465,0.20005700116356215,0.19721700126926103,0.19441700105865797,0.19165600091218948,0.18893500169118246,0.18625299632549286,0.1836090013384819,0.18100199972589812,0.1784320001800855,0.17589900021751723,0.17340200021862984,0.17094099769989649,0.16851399838924408,0.16612200190623602,0.16376399993896484,0.16143999993801117,0.1591489998002847,0.15688999990622202,0.1546629990140597,0.15246799836556116,0.1503050004442533,0.14817200104395548,0.14606900016466776,0.14399599904815355,0.1419529989361763,0.13993899896740913,0.13795300076405206,0.13599600022037825,0.1340670014421145,0.1321650023261706,0.13028999914725622,0.12844099973638853,0.1266189975043138,0.1248230009029309,0.12305200037856896,0.12130700051784515,0.11958600021898746,0.11789000034332275,0.11621800002952416,0.11456900027891,0.11294400009016196,0.11134299946328004,0.10976300078133742,0.10820699979861577,0.1066720001399517,0.10515899956226349,0.10366799992819627,0.1021980003764232,0.1007489984234174,0.09932039926449458,0.09791209983328979,0.09652379962305228,0.09515519998967648,0.09380609914660454,0.09247609972953796,0.09116499995191892,0.08987260051071644,0.08859840035438538,0.08734239948292573,0.08610419929027557,0.08488359861075878,0.08368040062487125,0.08249419927597046,0.08132479960719745,0.080172099173069,0.07903569998840491,0.07791550022860368,0.07681120000779629,0.07572250068187714,0.07464930166800816,0.07359130121767521,0.07254839936892192,0.07152020062009494,0.07050670000414054,0.06950750077764194,0.06852259983619054,0.06755160105725129,0.06659429892897606,0.06565070152282715,0.06472049963970979,0.06380340084433556,0.06289940048009157,0.06200819959243139,0.06112969977160295,0.06026360051085552,0.0594097999855876,0.0585680998240908,0.057738399443527065,0.0569204001997908,0.056114000268280506,0.05531909999748071,0.05453549946347872,0.053762999984125294,0.05300140008330345,0.05225059979905685,0.05151049947987,0.05078090044359366,0.0500616996238629,0.04935259930789471,0.04865360011657079,0.047964499332010746,0.04728520040710767,0.0466156005859375,0.045955399982631207,0.04530460014939308,0.04466300054142872,0.04403049933413664,0.04340699966996908,0.042792300383249916,0.042186400232215725,0.04158899995187918,0.04100010016312202,0.04041959966222445,0.03984730007747809,0.039283099584281445,0.03872689977288246,0.03817860006044308,0.03763810017456611,0.037105199880898,0.03657990042120218,0.03606199969847997,0.03555149988581737,0.03504820012797912,0.034552099804083504,0.03406299992154042,0.03358079927663008,0.03310549942155679,0.03263689981152614,0.032174899553259216,0.031719499888519444,0.03127050011729201,0.030827900239576895,0.030391599982976913,0.029961399889240663,0.029537399920324486,0.029119400152315695,0.028707300157596666,0.028300999974211056,0.02790050037826101,0.02750559989362955,0.027116400034477312,0.026732700256009895,0.026354399664948385,0.025981500123937924,0.025613800312081974,0.025251399880896013,0.02489410030345122,0.024541799755146105,0.02419460021580259,0.02385229989886284,0.023514800084133942,0.023182099995513756,0.022854099826266367,0.022530799886832636,0.022211999787638586,0.021897800111522276,0.021588000003248453,0.021282600083698828,0.020981499925255775,0.020684699683139723,0.020392100016276043,0.020103600186606247,0.019819200038909912,0.019538900038848322,0.019262499796847504,0.018989999778568745,0.01872139998401205,0.018456599675118923,0.018195599938432377,0.017938199763496716,0.017684500198811293,0.017434399885435898,0.0171877999479572,0.016944700075934332,0.016705100269367296,0.016468799983461697,0.016235899956276018,0.016006299760192633,0.015780000248923898,0.01555679994635284,0.015336800133809447,0.015120000035191575,0.014906099919850627,0.014695399906486273,0.014487599876398841,0.014282700062418977,0.01408080003845195,0.013881700035805503,0.013685399976869425,0.013491900016864141,0.013301099961002668,0.01311310000407199,0.012927700066938996,0.012744899916773042,0.012564700019235412,0.012387100063885251,0.012212000166376432,0.012039299976701537,0.011869100155308843,0.011701300041750073,0.011535900024076303,0.01137279998511076,0.011212100042030215,0.011053600038091341,0.010897299973294139,0.010743300120035807,0.010591499895478288,0.010441699996590614,0.010294199843580524,0.010148700016240278,0.010005200126518806,0.009863799981152018,0.009724379827578863,0.009586939898629984,0.00945145000393192,0.009317870019003749,0.00918618015324076,0.009056359995156527,0.008928369963541627,0.008802200124288598,0.008677800030757984,0.008555170071000854,0.008434270042926073,0.008315090090036392,0.00819759008785089,0.008081750012934208,0.007967549841850996,0.00785496000510951,0.007743969986525674,0.007634549983777106,0.007526679973428448,0.0074203300367419915,0.007315480033867061,0.007212119991891086,0.007110219992076357,0.007009770061510305,0.006910730036906898,0.006813090061768889,0.00671684000796328,0.006621940022644897,0.006528389911788206,0.006436159989486138,0.006345239972385268,0.0062556000193580985,0.006167230041076739,0.006080110014105837,0.005994219915010035,0.005909539991989732,0.0058260700122142834,0.005743770006423195,0.005662640052226682,0.005582650036861499,0.005503799960327645,0.005426050008585055,0.0053494099993258715,0.005273860064335167,0.005199370090849698,0.005125930028346677,0.0050894800418366986};
    Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261277839541435,0.4188620373606682,0.4108460272351901,0.4034940203030904,0.39607302596171695,0.38860202332337695,0.38109402110179263,0.37356602400541306,0.3660310183962186,0.35850001871585846,0.35098501046498615,0.34349701553583145,0.3360430176059405,0.32863402118285495,0.3212770124276479,0.31398001064856845,0.30674901107947034,0.2995900089542071,0.2925100103020668,0.2855130136013031,0.2786030098795891,0.2717840125163396,0.2650600075721741,0.2584340100487073,0.25190700963139534,0.24548400938510895,0.239166010171175,0.23295500750343004,0.22685100883245468,0.22085800766944885,0.2149760089814663,0.20920600617925325,0.2035480054716269,0.19800500695904097,0.19257600729664168,0.18726200486222902,0.18206200376152992,0.17697700733939806,0.17200600480039915,0.16714800521731377,0.16240400448441505,0.15777100374301276,0.15324700499574342,0.14883400375644365,0.14452900489171347,0.14033100257317224,0.13623900090654692,0.13225100437800089,0.1283650038142999,0.12458000207940738,0.12089400303860505,0.11730600396792094,0.11381300228337447,0.11041200285156567,0.10710400218764941,0.10388600205381711,0.10075600259006023,0.09771290235221386,0.09475380244354407,0.0918770016481479,0.0890804020067056,0.08636220234135787,0.08372160233557224,0.08115700073540211,0.07866540054480235,0.07624520175158978,0.07389480123917262,0.07161180240412553,0.06939450092613697,0.06724170098702113,0.06515200125674407,0.06312430246422689,0.06115610059350729,0.05924530141055584,0.057390800987680755,0.0555916012575229,0.05384560146679481,0.052151901026566826,0.050509800824026264,0.04891730130960544,0.047372400450209774,0.045873500096301235,0.04441990020374457,0.043011000690360866,0.04164519999176264,0.04032080061733723,0.03894530050456524,0.037524900088707604,0.03615689960618814,0.03483920047680537,0.0335699999704957,0.03234739974141121,0.031169800243029993,0.030035399987051885,0.028942699544131756,0.02789009998862942,0.02687619999051094,0.025899400003254414,0.024958400055766106,0.024052000138908625,0.023178699892014265,0.022337400044004124,0.021526900275299948,0.0207461000730594,0.019993800204247236,0.019269100079933803,0.018570800001422565,0.017898099962621927,0.01724989991635084,0.01662540001173814,0.01602369997029503,0.01544390005680422,0.014885300071910024,0.01434710000952085,0.01382850001876553,0.013328800133119026,0.012847300075615445,0.012383299879729748,0.011936200084164739,0.011505400063470006,0.011090299890687069,0.010690299949298302,0.01030479984668394,0.009933320029328266,0.009575340043132504,0.009230370012422403,0.008897919983913502,0.008577550062909722,0.008268800098448992,0.007971250064050158,0.007684479972037177,0.007408109959214926,0.0071417499566450715,0.006885029996434848,0.00663760001771152,0.006399120010125141,0.006169249924520652,0.005947690030249457,0.005734140092196564,0.005528290057554841,0.005329859986280401,0.005138590039374928,0.004954220067399244,0.004776489998524387,0.004605160017187397,0.004440000009102126,0.004280780054007967,0.004127279971726239,0.003979309966477255,0.0038366600250204406,0.0036991299906124673,0.003566540020983666,0.0034387199751411877,0.0033154799796951315,0.0031966599635779858,0.003082110003257791,0.002971659977144251,0.002865179985140761,0.002762509994984915,0.0026635199901647866,0.0025680799929735563,0.00247606000630185,0.002387339986550311,0.002301789994817227,0.0022193199838511646,0.0021397999565427503,0.0020631299703381956,0.0019891999933558204,0.001917929999763146,0.001849209996483599,0.0017829500041746844,0.0017190700067051996,0.0016574799956288189,0.0015981000033207238,0.0015408399825294812,0.0014856300064517807,0.0014324100047815591,0.001381090017578875,0.0013316099939402193,0.0012839100187799584,0.0012379100177592288,0.0011935600098998596,0.0011508000025060028,0.0011095800048982103,0.0010698300029616803,0.0010315099886308114,0.0009945559916862596,0.000958928998443298,0.0009245799980514372,0.0008914609934436157,0.0008595289982622489,0.0008287409970459217,0.0007990570011315867,0.0007704360032221302,0.0007428410074984034,0.0007162339946565529,0.0006905810005264357,0.0006658470034987355,0.0006420000039118653,0.0006190060036412129,0.0005968370048018793,0.0005754619972625127,0.0005548529976901287,0.0005349820081998283,0.0005158230002659062,0.0004973499938690414,0.0004795399994084922,0.00046236699805983034,0.00044581000111065805,0.0004298450003261678,0.0004144530006063481,0.00039961200188069296,0.0003853029969225948,0.000371506003527126,0.0003582039983787884,0.000345378000929486,0.00033301099999031675,0.00032108800223795697,0.0003095909972519924,0.0002985059982165694,0.00028781899891328067,0.00027751399951133254,0.00026757799787446856,0.0002579990007992213,0.0002487619979850327,0.00023985600031058615,0.00023126900002049902,0.00022298999950483753,0.0002150069982841766,0.00020731000040541403,0.0001998880021953179,0.00019273300010051267,0.0001858340013617029,0.00017918100032450943,0.0001727679979618794,0.00016658300228300504,0.00016061999849625863,0.0001548709988128394,0.00014932799967937171,0.00014398300118045881,0.00013883000065106899,0.00013386100060112463,0.00012907000079091327,0.00012445099976806281,0.00011999699927400798,0.0001157020002816959,0.00011156200040810897,0.00010756899973785039,0.00010371999936372352,5.045958096161485e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.1795705159505,329.0759785970052,329.7899805704753,330.56297810872394,331.3509750366211,332.15397389729816,332.9739735921224,333.80397542317706,334.6399739583333,335.4819742838542,336.3279724121094,337.1799723307292,338.03797403971356,338.8999735514323,339.76797739664715,340.6409734090169,341.51997629801434,342.40197499593097,343.2859751383464,344.17297108968097,345.06297302246094,345.95497639973956,346.8499704996745,347.7469736735026,348.64697265625,349.5489756266276,350.4529749552409,351.33097585042316,352.1519775390625,352.91697184244794,353.62597401936847,354.27897389729816,354.8779754638672,355.4219741821289,355.91197967529297,356.34897867838544,356.73197682698566,357.1039759318034,357.5059814453125,357.93797810872394,358.3999786376953,358.89197794596356,359.41497802734375,359.96597544352215,360.5479736328125,361.1579767862956,361.79797617594403,362.4529774983724,363.11097717285156,363.771977742513,364.43497975667316,365.1009750366211,365.7689717610677,366.43897755940753,367.11297607421875,367.78797658284503,368.46597544352215,369.1399739583333,369.80297088623047,370.4559733072917,371.0969772338867,371.7289784749349,372.34897867838544,372.95997365315753,373.55997975667316,374.1489791870117,374.7289784749349,375.29797108968097,375.8559799194336,376.4029769897461,376.9399770100911,377.4659779866536,377.9819742838542,378.4879735310872,378.9829813639323,379.46697489420575,379.9419809977214,380.4079767862956,380.86498006184894,381.31397247314453,381.7559814453125,382.1889826456706,382.6139831542969,383.031977335612,383.4419759114583,383.84397888183594,384.2389831542969,384.6269836425781,385.01097869873047,385.38998158772785,385.76497650146484,386.1349817911784,386.4999745686849,386.86097717285156,387.21797943115234,387.56997934977215,387.91798146565753,388.2619806925456,388.6009750366211,388.93597920735675,389.26698048909503,389.5929768880208,389.91597747802734,390.2339859008789,390.54797617594403,390.85797627766925,391.16397349039715,391.4659830729167,391.76398213704425,392.05898030598956,392.3489812215169,392.6349843343099,392.91697947184247,393.19597880045575,393.4709777832031,393.7419789632161,394.0089797973633,394.27198028564453,394.531982421875,394.78797912597656,395.04098256429035,395.2899805704753,395.5349807739258,395.77698008219403,396.01497650146484,396.2489776611328,396.4809824625651,396.7079772949219,396.93298085530597,397.1539789835612,397.37097930908203,397.5849787394206,397.79598236083984,398.0039825439453,398.2079798380534,398.4089813232422,398.6069793701172,398.8009745279948,398.9919789632161,399.1809794108073,399.36498006184894,399.5469792683919,399.7259801228841,399.9009780883789,400.07297770182294,400.24298095703125,400.4089762369792,400.5719757080078,400.7319793701172,400.88898213704425,401.04297637939453,401.19397735595703,401.3419774373372,401.4869791666667,401.6289774576823,401.7679799397786,401.9049809773763,402.03798421223956,402.16898345947266,402.29698181152344,402.4219792683919,402.5439809163411,402.6629816691081,402.7799809773763,402.89398193359375,403.00498453776044,403.11298116048175,403.21898142496747,403.3219757080078,403.42198181152344,403.5199839274089,403.61598205566406,403.7079772949219,403.79798380533856,403.885981241862,403.97098541259766,404.0539805094401,404.1339848836263,404.2109781901042,404.2859802246094,404.3589859008789,404.4299799601237,404.4979832967122,404.56298828125,404.6269836425781,404.68798065185547,404.74598185221356,404.802978515625,404.8569793701172,404.9089838663737,404.9579798380534,405.0059814453125,405.0509796142578,405.09398142496747,405.1349792480469,405.17298380533856,405.20998128255206,405.24398040771484,405.27698008219403,405.3069814046224,405.33498128255206,405.36098225911456,405.3849843343099,405.40697987874347,405.4269790649414,405.4449818929036,405.4609781901042,405.47498321533203,405.4869791666667,405.49798583984375,405.50597890218097,405.51198323567706,405.51698048909503,405.5189793904622,405.5199839274089,405.51898701985675,405.51597849527997,405.51098378499347,405.5049819946289,405.4969838460286,405.48598225911456,405.47498321533203,405.46098073323566,405.44598388671875,405.4289805094401,405.4099756876628,405.3889795939128,405.3669840494792,405.3429870605469,405.31798299153644,405.29098256429035,405.26197814941406,405.2319844563802,405.1999867757161,405.1659851074219,405.1309763590495,405.09398142496747,405.0569788614909,405.0199788411458,404.9829839070638,404.9469807942708,404.9099833170573,404.8739878336589,404.8389841715495,404.802983601888,404.76798248291016,404.7339808146159,404.69898223876953,404.6649805704753,404.63098398844403,404.5969823201497,404.56398010253906,404.5309829711914,404.49798583984375,404.4659830729167,404.43298085530597,404.40098571777344,404.36898549397785,404.33797963460285,404.3069788614909,404.2759780883789,404.24497985839844,404.21397908528644,404.18398030598956,404.15398661295575,404.12398020426434,404.09498341878253,404.0649820963542,404.0359802246094,404.0069808959961,403.9789810180664,403.9499791463216,403.92198181152344,403.89398193359375,403.86698150634766,403.8389841715495,403.8119837443034,403.7849833170573,403.7579803466797,403.7309799194336,403.70497639973956,403.6789805094401,403.6529820760091,403.6269887288411,403.60198465983075,403.5759811401367,403.55098215738934,403.52598571777344,403.500981648763,403.4769821166992,403.4529851277669,403.42798105875653,403.4039840698242,403.3809763590495,403.3569844563802,403.333979288737,403.31097920735675,403.2879867553711,403.2649841308594,403.24198150634766,403.21998341878253,403.19798787434894,403.17598215738934,403.15398661295575,403.1319834391276,403.10998280843097,403.0889841715495,403.06797790527344,403.04698181152344,403.0259831746419,403.0049819946289,402.9849802652995,402.96498616536456,402.94398244222003,402.92398325602215,402.9039840698242,402.8849868774414,402.86498006184894,402.84598541259766,402.8269805908203,402.80798085530597,402.7889811197917,402.76998138427734,402.75098673502606,402.7329813639323,402.7149836222331,402.6969807942708,402.6789830525716,402.6609802246094,402.64298248291016,402.62597910563153,402.6079839070638,402.5909907023112,402.57398478190106,402.5569839477539,402.53997802734375,402.52298227945965,402.5069834391276,402.489985148112,402.47398630777997,402.4579798380534,402.4419886271159,402.42598215738934,402.4099858601888,402.3939793904622,402.3789825439453,402.3639780680339,402.3479817708333,402.33298746744794,402.31798553466797,402.30298105875653,402.2889862060547,402.27398681640625,402.25898996988934,402.2449900309245,402.2309850056966,402.2169825236003,402.2029851277669,402.18898010253906,402.1749801635742,402.1609802246094,402.1479797363281,402.1339797973633,402.12097930908203,402.1079864501953,402.09398396809894,402.0809834798177,402.06798553466797,402.0559768676758,402.04298146565753,402.0299809773763,402.01798248291016,402.0049794514974,401.9929835001628,401.9809824625651,401.96898651123047,401.9569829305013,401.94497934977215,401.93298085530597,401.92198181152344,401.9099858601888,401.89898173014325,401.8869806925456,401.87598673502606,401.864985148112,401.8529790242513,401.8419825236003,401.8319803873698,401.8209813435872,401.8099822998047,401.7989807128906,401.78898366292316,401.7779795328776,401.76798248291016,401.7579828898112,401.74698638916016,401.73698170979816,401.7269821166992,401.7169825236003,401.7069803873698,401.69798787434894,401.68798065185547,401.67798105875653,401.66898345947266,401.6589838663737,401.64998118082684,401.63998158772785,401.63098398844403,401.6219838460286,401.61298116048175,401.60398356119794,401.59498087565106,401.5859858194987,401.5769856770833,401.56898498535156,401.5599822998047,401.55198669433594,401.54298400878906,401.5349833170573,401.5259831746419,401.5179799397786,401.50997670491535,401.5019785563151,401.4939829508464,401.48597717285156,401.47798411051434,401.4699885050456,401.4619827270508,401.4549814860026,401.4469807942708,401.43898010253906,401.4319839477539,401.42398325602215,401.41698455810547,401.4099807739258,401.4019826253255,401.39498647054035,401.3879801432292,401.38098398844403,401.3739827473958,401.3669840494792,401.3599802652995,401.3529815673828,401.34598541259766,401.3399836222331,401.3329798380534,401.3259811401367,401.31998443603516,401.312983194987,401.3069839477539,401.3009770711263,401.29398345947266,401.2879816691081,401.281977335612,401.2759831746419,401.2699839274089,401.2629801432292,401.2569859822591,401.2519810994466,401.24597930908203,401.239985148112,401.2339833577474,401.22798411051434,401.2229817708333,401.2169774373372,401.21098073323566,401.2059783935547,401.1999791463216,401.1949818929036,401.18898010253906,401.1839828491211,401.1789805094401,401.1739807128906,401.16798146565753,401.16298421223956,401.1579818725586,401.1529846191406,401.1479797363281,401.1429799397786,401.1379801432292,401.1329879760742,401.12798563639325,401.1239827473958,401.11898040771484,401.11398061116535,401.11198170979816};
}

void set_concs_ssp370_lowNTCF() //from year 1700 to year 2500 (AerochemMip, not 'Gidden')
{
    Aero_BC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.097770755,2.072925926,2.064311933,2.071950564,2.099349783,2.099173165,2.068915407,2.147923676,2.12061141,2.117267431,2.127804105,2.137756989,2.101748109,2.107029758,2.071549227,2.123600022,2.110459977,2.112460701,2.18313204,2.137633742,2.139364739,2.100909701,2.087077541,2.092755603,2.154900741,2.148996597,2.112143132,2.170244784,2.198001402,2.159615777,2.189267588,2.1894412,2.160522701,2.15072559,2.140542212,2.165839691,2.158683485,2.185179294,2.255223484,2.207664632,2.216436996,2.172583556,2.161650793,2.153273834,2.213843116,2.202692273,2.153154616,2.213475036,2.234056283,2.207292165,2.215974055,2.21940169,2.202692661,2.180015828,2.197298087,2.215042398,2.222822585,2.239871982,2.311936484,2.26744264,2.279523716,2.252530236,2.228006935,2.231996859,2.291579691,2.287324694,2.261022,2.296180569,2.335490105,2.304129482,2.321048766,2.333483777,2.302515118,2.282471765,2.310947811,2.322703112,2.320968834,2.346337782,2.420774153,2.379376332,2.403159831,2.361347125,2.353863299,2.356959381,2.412445466,2.405456375,2.404187956,2.440210174,2.477311746,2.452638138,2.443877522,2.490489852,2.449170469,2.411136271,2.443825896,2.471371875,2.471198742,2.521115228,2.5773718,2.552394089,2.571124479,2.526692589,2.50763416,2.527811743,2.610048543,2.593264313,2.573430007,2.636452577,2.660122642,2.64820325,2.648404731,2.670268663,2.648564983,2.629269514,2.667755634,2.720201066,2.710298337,2.761022671,2.825140562,2.785004317,2.831200782,2.797830347,2.771292694,2.841633848,2.86805891,2.833489105,2.843125267,2.881579173,2.905036494,2.92925864,2.921172062,2.962877226,2.944345851,2.918084088,2.97815874,2.987658653,3.000148376,3.044590075,3.123484052,3.104668338,3.159194949,3.125180696,3.110528365,3.125430895,3.205110618,3.216163845,3.170768747,3.268702112,3.296870259,3.355831345,3.361821037,3.382952935,3.38154147,3.389386332,3.4640583,3.525334738,3.54932448,3.674457368,3.67587664,3.690048662,3.767608107,3.725917532,3.709100468,3.787939036,3.764418792,3.722337783,3.744207069,3.826396856,3.83059738,3.722641135,3.813010121,3.661222702,3.658333723,3.88124621,3.774809016,3.790606982,3.724383638,3.850357382,3.828134932,3.890215994,3.907622806,3.699193086,3.701120519,3.673991696,3.817622407,3.826763235,3.972008023,3.977215074,3.879546431,4.010820601,4.026253626,4.050294267,4.114193284,4.114085782,4.111269896,3.970406317,3.971696435,4.004289599,4.123520873,4.095746551,4.331260791,4.212336067,4.278249967,4.400134891,4.475107773,4.585745112,4.844401489,5.084522572,5.060488043,5.186762349,5.288213084,5.280187775,5.268371109,5.437875743,5.259909465,5.270010253,5.285174796,5.390458849,5.370373092,5.404091613,5.549708797,5.703748992,5.971153375,5.895831576,5.971643938,5.998431374,6.237496532,6.353178768,6.579044818,6.677231649,6.618387125,6.57778223,6.915258578,6.625402214,6.815018955,6.922761989,7.013703662,7.200139154,7.39663506,7.320233668,7.508271532,8.011536269,7.364888993,7.531122847,7.895732734,7.813189501,7.686339551,8.269788743,8.412226876,7.698162125,7.457347232,7.591758769,8.046474187,8.241697598,8.542465507,8.840128386,8.92564815,9.284494092,9.091850914,9.109514002,9.665129376,9.478876566,9.705285171,9.560553735,9.744379658,9.727423577,9.712768645,9.698113714,9.683458782,9.668803851,9.654148919,9.547306316,9.440463713,9.33362111,9.226778507,9.119935904,9.013093301,8.906250698,8.799408095,8.692565491,8.585722888,8.46686056,8.347998232,8.229135903,8.110273575,7.991411247,7.872548918,7.75368659,7.634824262,7.515961933,7.397099605,7.244964656,7.092829708,6.94069476,6.788559811,6.636424863,6.484289914,6.332154966,6.180020018,6.027885069,5.875750121,5.837390432,5.799030744,5.760671056,5.722311367,5.683951679,5.64559199,5.607232302,5.568872613,5.530512925,5.492153237,5.45220441,5.412255584,5.372306758,5.332357932,5.292409106,5.25246028,5.212511453,5.172562627,5.132613801,5.092664975,5.051624524,5.010584073,4.969543622,4.928503172,4.887462721,4.84642227,4.805381819,4.764341368,4.723300918,4.682260467,4.647395715,4.612530963,4.577666211,4.542801458,4.507936706,4.473071954,4.438207202,4.40334245,4.368477698,4.333612946,4.296966187,4.260319429,4.22367267,4.187025912,4.150379153,4.113732395,4.077085636,4.040438878,4.003792119,3.967145361,3.947754634,3.928363907,3.90897318,3.889582454,3.870191727,3.850801,3.831410273,3.812019546,3.79262882,3.773238093,3.753847366,3.734456639,3.715065912,3.695675186,3.676284459,3.656893732,3.637503005,3.618112278,3.598721552,3.579330825,3.559940098,3.540549371,3.521158645,3.501767918,3.482377191,3.462986464,3.443595737,3.424205011,3.404814284,3.385423557,3.36603283,3.346642103,3.327251377,3.30786065,3.288469923,3.269079196,3.249688469,3.230297743,3.210907016,3.191516289,3.172125562,3.152734835,3.133344109,3.113953382,3.094562655,3.075171928,3.055781201,3.036390475,3.016999748,2.997609021,2.978218294,2.958827567,2.939436841,2.920046114,2.900655387,2.88126466,2.861873933,2.842483207,2.82309248,2.803701753,2.784311026,2.764920299,2.745529573,2.726138846,2.706748119,2.687357392,2.667966665,2.648575939,2.629185212,2.609794485,2.590403758,2.571013031,2.551622305,2.532231578,2.512840851,2.493450124,2.474059398,2.454668671,2.435277944,2.415887217,2.39649649,2.377105764,2.357715037,2.33832431,2.318933583,2.299542856,2.28015213,2.260761403,2.241370676,2.221979949,2.202589222,2.183198496,2.163807769,2.144417042,2.125026315,2.105635588,2.086244862,2.066854135,2.047463408,2.028072681,2.008681954,1.989291228,1.969900501,1.950509774,1.931119047,1.91172832,1.892337594,1.872946867,1.85355614,1.834165413,1.814774686,1.79538396,1.775993233,1.756602506,1.737211779,1.717821052,1.698430326,1.679039599,1.659648872,1.640258145,1.620867418,1.601476692,1.582085965,1.562695238,1.543304511,1.523913784,1.504523058,1.485132331,1.465741604,1.446350877,1.426960151,1.407569424,1.388178697,1.36878797,1.349397243,1.330006517,1.31061579,1.291225063,1.271834336,1.252443609,1.233052883,1.213662156,1.194271429,1.174880702,1.155489975,1.136099249,1.116708522,1.097317795,1.077927068,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341,1.058536341};
    Aero_OC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,15.44766815,15.18871674,15.03447574,15.18254515,15.55877305,15.35818253,15.19577663,15.70481912,15.51461163,15.57401349,15.81906393,15.69191588,15.52593531,15.52676249,14.95869898,15.67992411,15.35883081,15.4005645,16.0637302,15.73509479,15.74271509,15.32197739,15.11418329,15.20466379,15.87559318,15.5891357,15.37007702,15.67345753,15.89945625,15.62745786,16.0183808,15.80695227,15.71282083,15.60726047,15.22814126,15.73271148,15.46715712,15.71033146,16.34335434,16.00040861,16.05674391,15.61644988,15.44666919,15.47797954,16.16525997,15.88313195,15.6283698,15.93865305,16.12667274,16.03734279,16.2421417,16.06373322,16.07582361,15.83103088,15.67624811,16.0941548,15.95144317,16.11756408,16.7315469,16.44016599,16.52538808,16.18886557,15.92905063,16.06491504,16.71992349,16.48749688,16.39503385,16.51722865,16.84964888,16.66519821,16.96356441,16.86010032,16.79629808,16.53271228,16.47072526,16.80867752,16.62077908,16.79991923,17.4805645,17.19408165,17.31425157,16.87772867,16.73898675,16.86449692,17.45428534,17.17048679,17.23500429,17.35383524,17.64153847,17.50517633,17.57513248,17.74554357,17.59096172,17.21821832,17.1801219,17.5993633,17.39887857,17.76051419,18.30069373,18.07478627,18.22682479,17.72630049,17.47926155,17.65848988,18.34043133,17.9916486,17.95411805,18.29156565,18.4792763,18.44950598,18.520468,18.43711983,18.41589321,18.09141101,18.0938173,18.66656838,18.39468019,18.76835617,19.30124757,18.88882504,19.25812075,18.76177377,18.36534165,18.9372989,19.30481072,18.75387609,19.00214066,19.0890591,19.22817131,19.48731539,19.32682128,19.32716624,19.15816229,18.70936137,19.00988998,19.20686906,19.06781958,19.32845364,19.78574643,19.55277705,19.77806486,19.19967303,18.94952176,19.1784562,19.83612848,19.52250048,19.17728772,19.58218288,19.50168111,19.86870993,19.75078793,19.48762217,19.3580615,19.03059788,19.65611973,19.75296716,19.60693136,20.14449075,20.34218955,20.10967131,20.6023284,20.00760743,19.68089243,20.00732869,20.59248109,20.06142458,19.90829861,20.17756104,20.36895158,20.36863821,20.4023951,19.84610877,19.4742784,20.41782521,19.77882376,19.75345484,19.57302011,19.87550986,19.91593076,20.27497394,20.95238859,19.78298346,20.16181555,20.01961331,20.70261784,20.54319704,21.16418654,20.85060471,20.283818,21.02085333,20.56627575,20.46203137,21.01419377,20.76469901,20.91812228,20.63041519,20.3059335,20.19099947,20.65035706,21.08117938,22.10581056,20.39818818,20.95793435,21.60093971,21.65473895,21.61194057,22.72448276,23.82634945,22.2466504,22.13695045,22.06866314,23.37357314,22.55009464,24.60921093,22.37762398,22.64997293,22.43429714,23.58529354,22.82579691,22.10048951,22.78022432,23.19511601,25.52743454,23.45564811,23.59962462,23.12965379,24.40571792,24.38724427,25.01974419,25.21247986,25.23254566,24.87329597,28.27220571,24.45951343,25.32627636,25.83243998,25.91211685,27.25186717,27.18506613,26.33140677,27.36536835,34.39493833,26.64897689,28.11499626,33.14335063,29.71540754,28.71419152,38.34138232,37.8122783,30.44917133,27.9819784,27.87799844,33.80824329,34.36218135,32.33033041,32.72399071,34.3551466,33.27729799,31.61901151,31.77247637,34.61053251,32.51825927,35.82690196,33.24556583,36.14582139,34.74602423,34.6383044,34.53058457,34.42286474,34.31514491,34.20742508,33.98802364,33.7686222,33.54922076,33.32981932,33.11041787,32.89101643,32.67161499,32.45221355,32.23281211,32.01341067,31.55866028,31.10390989,30.6491595,30.19440911,29.73965872,29.28490832,28.83015793,28.37540754,27.92065715,27.46590676,26.94413059,26.42235442,25.90057826,25.37880209,24.85702592,24.33524975,23.81347358,23.29169741,22.76992125,22.24814508,22.11613055,21.98411603,21.85210151,21.72008699,21.58807246,21.45605794,21.32404342,21.1920289,21.06001437,20.92799985,20.79146721,20.65493457,20.51840193,20.38186929,20.24533665,20.10880401,19.97227137,19.83573873,19.69920609,19.56267345,19.43835115,19.31402885,19.18970655,19.06538425,18.94106195,18.81673965,18.69241735,18.56809505,18.44377275,18.31945045,18.20243317,18.08541588,17.96839859,17.85138131,17.73436402,17.61734673,17.50032945,17.38331216,17.26629487,17.14927758,17.03271161,16.91614564,16.79957966,16.68301369,16.56644772,16.44988174,16.33331577,16.2167498,16.10018382,15.98361785,15.93642204,15.88922623,15.84203041,15.7948346,15.74763879,15.70044298,15.65324717,15.60605135,15.55885554,15.51165973,15.46446392,15.41726811,15.3700723,15.32287648,15.27568067,15.22848486,15.18128905,15.13409324,15.08689743,15.03970161,14.9925058,14.94530999,14.89811418,14.85091837,14.80372255,14.75652674,14.70933093,14.66213512,14.61493931,14.5677435,14.52054768,14.47335187,14.42615606,14.37896025,14.33176444,14.28456862,14.23737281,14.190177,14.14298119,14.09578538,14.04858957,14.00139375,13.95419794,13.90700213,13.85980632,13.81261051,13.7654147,13.71821888,13.67102307,13.62382726,13.57663145,13.52943564,13.48223982,13.43504401,13.3878482,13.34065239,13.29345658,13.24626077,13.19906495,13.15186914,13.10467333,13.05747752,13.01028171,12.9630859,12.91589008,12.86869427,12.82149846,12.77430265,12.72710684,12.67991102,12.63271521,12.5855194,12.53832359,12.49112778,12.44393197,12.39673615,12.34954034,12.30234453,12.25514872,12.20795291,12.1607571,12.11356128,12.06636547,12.01916966,11.97197385,11.92477804,11.87758222,11.83038641,11.7831906,11.73599479,11.68879898,11.64160317,11.59440735,11.54721154,11.50001573,11.45281992,11.40562411,11.35842829,11.31123248,11.26403667,11.21684086,11.16964505,11.12244924,11.07525342,11.02805761,10.9808618,10.93366599,10.88647018,10.83927437,10.79207855,10.74488274,10.69768693,10.65049112,10.60329531,10.55609949,10.50890368,10.46170787,10.41451206,10.36731625,10.32012044,10.27292462,10.22572881,10.178533,10.13133719,10.08414138,10.03694557,9.989749754,9.942553942,9.89535813,9.848162318,9.800966506,9.753770695,9.706574883,9.659379071,9.612183259,9.564987448,9.517791636,9.470595824,9.423400012,9.3762042,9.329008389,9.281812577,9.234616765,9.187420953,9.140225142,9.09302933,9.045833518,8.998637706,8.951441895,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083,8.904246083};
    Aero_SOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.440048435,2.408379138,2.397116044,2.410693365,2.462065253,2.442355144,2.419184325,2.507464693,2.479743826,2.473528035,2.497745196,2.509181763,2.466504133,2.480992166,2.421867931,2.497554066,2.484408322,2.482742878,2.585377496,2.542757581,2.551004694,2.456424302,2.431878812,2.437570529,2.528911972,2.497313043,2.466672079,2.521353634,2.560565944,2.503712449,2.545624085,2.551092641,2.518173245,2.513461275,2.478316441,2.529190605,2.523874405,2.558671152,2.648030358,2.597817354,2.605536163,2.565535213,2.555885905,2.549374599,2.642660373,2.610163563,2.568822151,2.640239462,2.684800166,2.661313715,2.698593795,2.688431218,2.727330113,2.675871996,2.691782017,2.729785228,2.736325627,2.775121695,2.846709202,2.801892048,2.823983532,2.803000631,2.785422831,2.796288721,2.893725367,2.881174397,2.89451963,2.939425965,3.001978233,2.956182588,2.995581553,3.007308731,2.99428324,2.994537839,3.021111981,3.071614762,3.059193093,3.127305637,3.231000882,3.189500784,3.406492167,3.316891703,3.316047924,3.342535309,3.437176483,3.431091533,3.560612062,3.590574873,3.677349384,3.680419963,3.742445207,3.826558744,3.856907998,3.853309393,3.976687413,4.154281247,4.138125135,4.301750208,4.401966129,4.4428603,4.544463776,4.506599718,4.548173377,4.645593816,5.0624187,5.055876658,5.188552235,5.28574648,5.361342808,5.522088206,5.787726355,5.933301365,5.94350385,6.11934725,6.376488797,6.643795616,6.765960835,7.119763794,7.325189711,7.571114079,7.762947987,8.019553554,8.487273155,8.932963275,8.750701465,9.090838437,9.266189578,9.510372736,9.597660042,10.09352322,10.93632234,11.29350673,11.7388482,12.25438403,12.46724553,12.57026623,12.68626323,13.19095522,14.34215496,14.33482126,15.43278649,16.02679754,16.30684661,16.21599151,16.79657324,17.66577431,18.15088036,19.01112916,19.98900757,21.64246331,22.66210071,23.51382737,24.16340112,26.0476803,26.50752099,28.15802848,29.48689884,32.47930468,31.13285704,32.69101093,34.19279814,34.43465078,35.92235271,38.0860897,35.13405679,35.09148718,38.07157453,39.75198229,39.4249845,33.93663048,37.54682246,32.04941278,33.84898547,39.38589959,38.98297228,39.41628781,39.55611646,42.21370855,42.06447172,44.73465019,41.51990607,36.63913266,32.25189542,33.93713757,37.30163266,40.09333853,43.12786142,46.39105113,43.01883966,45.94885454,50.23977106,52.14654754,53.32090164,54.13624126,53.07350504,46.75690203,46.20250369,51.87623011,54.2400157,52.31608638,58.2062882,60.66323151,61.44989309,62.68709014,63.10483375,69.00315621,74.12190737,77.62640658,78.56142199,82.51022592,85.80760421,96.59080752,98.59311393,101.6784711,105.4986908,107.9591805,110.366455,109.3551933,113.5595977,116.7534789,122.867878,123.2413271,126.7324979,132.4288265,130.5396034,128.1655913,134.0976169,135.3432378,135.834174,138.0244007,137.3534112,133.1699011,130.860453,128.9037345,130.4163407,130.7442052,130.7545577,133.2343341,134.3653495,134.4161679,133.9791278,132.7375512,128.2477768,126.1942302,123.4484152,121.0821185,119.1142065,119.5500481,117.026167,110.8741189,111.1486043,111.9237249,111.2015633,115.1038782,120.493726,124.9806758,125.8962842,125.087574,122.3606509,117.2593915,116.3174481,117.4857589,115.6695764,114.6481774,114.0086622,100.771167,99.12391053,97.47665408,95.82939763,94.18214118,92.53488473,91.03087417,89.52686361,88.02285305,86.51884249,85.01483193,83.51082137,82.00681081,80.50280024,78.99878968,77.49477912,76.1702387,74.84569828,73.52115786,72.19661744,70.87207702,69.5475366,68.22299618,66.89845577,65.57391535,64.24937493,62.42268103,60.59598713,58.76929324,56.94259934,55.11590544,53.28921155,51.46251765,49.63582375,47.80912986,45.98243596,45.70884882,45.43526169,45.16167455,44.88808741,44.61450027,44.34091314,44.067326,43.79373886,43.52015173,43.24656459,42.97661163,42.70665867,42.43670572,42.16675276,41.8967998,41.62684685,41.35689389,41.08694093,40.81698798,40.54703502,40.2509849,39.95493477,39.65888465,39.36283452,39.0667844,38.77073427,38.47468415,38.17863402,37.8825839,37.58653378,37.32024155,37.05394932,36.78765709,36.52136485,36.25507262,35.98878039,35.72248816,35.45619593,35.1899037,34.92361147,34.63997255,34.35633363,34.07269472,33.7890558,33.50541688,33.22177796,32.93813904,32.65450012,32.3708612,32.08722228,31.88318575,31.67914922,31.47511268,31.27107615,31.06703962,30.86300309,30.65896656,30.45493002,30.25089349,30.04685696,29.84282043,29.63878389,29.43474736,29.23071083,29.0266743,28.82263777,28.61860123,28.4145647,28.21052817,28.00649164,27.8024551,27.59841857,27.39438204,27.19034551,26.98630898,26.78227244,26.57823591,26.37419938,26.17016285,25.96612631,25.76208978,25.55805325,25.35401672,25.14998019,24.94594365,24.74190712,24.53787059,24.33383406,24.12979752,23.92576099,23.72172446,23.51768793,23.31365139,23.10961486,22.90557833,22.7015418,22.49750527,22.29346873,22.0894322,21.88539567,21.68135914,21.4773226,21.27328607,21.06924954,20.86521301,20.66117648,20.45713994,20.25310341,20.04906688,19.84503035,19.64099381,19.43695728,19.23292075,19.02888422,18.82484769,18.62081115,18.41677462,18.21273809,18.00870156,17.80466502,17.60062849,17.39659196,17.19255543,16.9885189,16.78448236,16.58044583,16.3764093,16.17237277,15.96833623,15.7642997,15.56026317,15.35622664,15.15219011,14.94815357,14.74411704,14.54008051,14.33604398,14.13200744,13.92797091,13.72393438,13.51989785,13.31586132,13.11182478,12.90778825,12.70375172,12.49971519,12.29567865,12.09164212,11.88760559,11.68356906,11.47953253,11.27549599,11.07145946,10.86742293,10.6633864,10.45934986,10.25531333,10.0512768,9.847240268,9.643203735,9.439167203,9.235130671,9.031094139,8.827057606,8.623021074,8.418984542,8.21494801,8.010911477,7.806874945,7.602838413,7.398801881,7.194765349,6.990728816,6.786692284,6.582655752,6.37861922,6.174582687,5.970546155,5.766509623,5.562473091,5.358436558,5.154400026,4.950363494,4.746326962,4.542290429,4.338253897,4.134217365,3.930180833,3.726144301,3.522107768,3.318071236,3.114034704,2.909998172,2.705961639,2.501925107,2.297888575,2.093852043,1.88981551,1.685778978,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446,1.481742446};
    Aero_NOx_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,12.73521194,12.59230324,12.59427042,12.53982033,12.63683678,12.76599125,12.41616261,13.1331518,12.97934533,12.75254609,12.71269604,12.96678586,12.49978928,12.63295473,12.57663725,12.73808006,12.76007905,12.74570396,13.26640323,12.85785079,12.89891822,12.62324271,12.52400747,12.46738959,12.78390257,12.86929116,12.40741669,12.93458349,13.20751695,12.69699,12.71506421,12.87790002,12.46113468,12.44438333,12.59751721,12.55248193,12.5678111,12.76091694,13.26480759,12.84626138,12.93202741,12.63941855,12.65272496,12.47524671,12.81634877,12.87258787,12.31586242,12.94441319,13.18985696,12.75367575,12.70371109,12.88157821,12.53033251,12.39498015,12.71613281,12.62431268,12.73432599,12.83197336,13.36938481,12.94143866,13.01213284,12.8714024,12.73096382,12.62618564,12.96379003,13.06602172,12.69818309,13.07654651,13.49727807,13.01846415,13.00218267,13.23594367,12.71501678,12.63263492,12.99566306,12.87246123,12.84794656,13.01608087,13.5204643,13.13944028,13.26451505,12.96555056,12.96149608,12.82735594,13.10235903,13.13355177,12.86713343,13.27038433,13.60526498,13.18858095,12.88954454,13.43207834,12.9286274,12.63268139,13.02434548,12.99992982,12.97255355,13.27153028,13.64758224,13.4241146,13.45657685,13.17243992,13.00181932,13.03425324,13.42199006,13.37365128,12.94614666,13.6609981,13.92945102,13.53148651,13.33856892,13.66780367,13.27771597,13.04474127,13.42555248,13.65613844,13.57734061,13.89761851,14.33158856,13.9440919,14.20074407,14.02316496,13.72527326,14.15646368,14.35225569,14.16158404,14.03711085,14.49647732,14.79085747,14.60701195,14.40860199,14.88509568,14.48444095,14.27050491,14.80607459,14.75707739,14.89467659,15.17142123,15.57510184,15.52671146,15.79194853,15.57973029,15.42330662,15.4875444,16.05810348,16.15737216,15.54914616,16.51075558,16.74484506,16.73482662,16.71573999,17.08681697,17.01305829,17.04726849,17.73743296,18.29801487,18.41936116,19.46355752,19.62614434,19.84444901,20.44725406,20.3822595,20.42827701,21.19823229,21.34701392,21.29313163,21.6836961,23.00419095,23.38021169,22.75197626,24.0391753,23.4746721,23.81984363,26.32202243,25.58778999,26.22160478,26.46434217,27.91811905,28.14557529,29.21456636,29.04143305,26.95423626,26.74457595,26.61269603,28.25939192,28.83665246,30.75030733,31.45184796,30.00000651,31.64022958,32.7188333,33.48198015,33.98048634,34.96119084,36.03881656,35.5096996,35.50602087,37.73867603,40.05786822,38.96806771,43.13346535,43.1993278,44.29775813,46.15027419,47.14223947,50.45064783,53.89237306,56.50215517,55.97930462,57.53015334,59.57552345,61.54958482,63.50039853,67.40220069,69.7992133,72.53323808,75.0452159,79.47428379,83.46364336,85.61259583,91.39020745,93.99546396,99.31304654,102.6103475,102.0759777,101.0543663,106.0477677,108.5856192,112.5596328,115.0059619,114.1861796,112.0545426,112.1881415,109.3274027,112.7424917,114.505137,115.769763,119.6837541,124.1495603,125.267831,125.6585787,130.3728476,127.1693521,130.5411332,132.2742148,132.8622773,132.861569,137.6010869,139.0513188,134.49403,135.5333367,135.9063122,137.6195703,140.1926459,146.3502013,149.8499947,153.1895928,158.089275,157.774666,152.6770747,155.4203535,159.2761931,158.239988,156.0375565,155.6402255,155.52045,155.4517969,155.3831438,155.3144906,155.2458375,155.1771844,152.556527,149.9358696,147.3152123,144.6945549,142.0738975,139.4532402,136.8325828,134.2119254,131.5912681,128.9706107,127.1849684,125.399326,123.6136837,121.8280413,120.042399,118.2567566,116.4711143,114.6854719,112.8998296,111.1141872,108.5965068,106.0788264,103.561146,101.0434655,98.5257851,96.00810467,93.49042424,90.97274381,88.45506338,85.93738295,85.71512237,85.49286178,85.2706012,85.04834061,84.82608003,84.60381945,84.38155886,84.15929828,83.9370377,83.71477711,83.45987648,83.20497585,82.95007522,82.69517459,82.44027396,82.18537333,81.9304727,81.67557207,81.42067144,81.16577081,80.92574202,80.68571323,80.44568444,80.20565565,79.96562686,79.72559807,79.48556928,79.24554049,79.0055117,78.76548291,78.5837214,78.40195988,78.22019836,78.03843684,77.85667533,77.67491381,77.49315229,77.31139077,77.12962926,76.94786774,76.75336596,76.55886418,76.36436239,76.16986061,75.97535883,75.78085705,75.58635527,75.39185349,75.19735171,75.00284992,74.59642239,74.18999485,73.78356732,73.37713978,72.97071225,72.56428471,72.15785718,71.75142964,71.34500211,70.93857457,70.53214703,70.1257195,69.71929196,69.31286443,68.90643689,68.50000936,68.09358182,67.68715429,67.28072675,66.87429922,66.46787168,66.06144414,65.65501661,65.24858907,64.84216154,64.435734,64.02930647,63.62287893,63.2164514,62.81002386,62.40359633,61.99716879,61.59074125,61.18431372,60.77788618,60.37145865,59.96503111,59.55860358,59.15217604,58.74574851,58.33932097,57.93289344,57.5264659,57.12003836,56.71361083,56.30718329,55.90075576,55.49432822,55.08790069,54.68147315,54.27504562,53.86861808,53.46219055,53.05576301,52.64933548,52.24290794,51.8364804,51.43005287,51.02362533,50.6171978,50.21077026,49.80434273,49.39791519,48.99148766,48.58506012,48.17863259,47.77220505,47.36577751,46.95934998,46.55292244,46.14649491,45.74006737,45.33363984,44.9272123,44.52078477,44.11435723,43.7079297,43.30150216,42.89507462,42.48864709,42.08221955,41.67579202,41.26936448,40.86293695,40.45650941,40.05008188,39.64365434,39.23722681,38.83079927,38.42437173,38.0179442,37.61151666,37.20508913,36.79866159,36.39223406,35.98580652,35.57937899,35.17295145,34.76652392,34.36009638,33.95366884,33.54724131,33.14081377,32.73438624,32.3279587,31.92153117,31.51510363,31.1086761,30.70224856,30.29582103,29.88939349,29.48296595,29.07653842,28.67011088,28.26368335,27.85725581,27.45082828,27.04440074,26.63797321,26.23154567,25.82511814,25.4186906,25.01226306,24.60583553,24.19940799,23.79298046,23.38655292,22.98012539,22.57369785,22.16727032,21.76084278,21.35441525,20.94798771,20.54156017,20.13513264,19.7287051,19.32227757,18.91585003,18.5094225,18.10299496,17.69656743,17.29013989,16.88371236,16.47728482,16.07085728,15.66442975,15.25800221,14.85157468,14.44514714,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961,14.03871961};
    Aero_NH3_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.927690091,6.860142185,6.819482037,6.881438529,7.015189224,6.943989043,6.922711557,7.047674129,6.995459768,7.045958325,7.128048286,7.080969808,7.072547337,7.067982584,6.89874574,7.112382325,7.036296531,7.045382427,7.223617821,7.157863703,7.155978284,7.069218405,7.043230562,7.104503735,7.347701469,7.26964482,7.261469977,7.355973763,7.434606067,7.418773457,7.569429121,7.505783353,7.519625788,7.496232273,7.3811564,7.538152323,7.491084254,7.55517197,7.730934741,7.663516243,7.680254371,7.556943543,7.499155045,7.518120739,7.731535991,7.626169221,7.581863097,7.636302582,7.671017716,7.67446285,7.740645322,7.701186978,7.763054085,7.720863757,7.68708673,7.835162209,7.843541453,7.906227329,8.095303457,8.062766978,8.107079152,8.026948341,7.965169636,8.032995952,8.255365792,8.178894558,8.188247477,8.220825384,8.306817108,8.302878859,8.416077975,8.396299171,8.447852069,8.395261064,8.395833943,8.516236489,8.523620414,8.585850324,8.801495947,8.767229394,8.818806446,8.731507392,8.712430009,8.790922957,9.001420472,8.925548286,8.993015086,9.027059824,9.122535895,9.139608329,9.211326299,9.249453202,9.261381852,9.185852612,9.178913526,9.307905911,9.302498358,9.401962019,9.573238567,9.543358834,9.604162557,9.478471328,9.424520247,9.493187126,9.708926054,9.60821845,9.648967408,9.717987449,9.773872717,9.815633788,9.868462594,9.857135646,9.918881972,9.868665854,9.887134077,10.07353478,10.06454912,10.1891331,10.37220092,10.31106127,10.44102397,10.3694977,10.33038424,10.56453512,10.75161101,10.66354523,10.83189303,10.8970216,10.99894534,11.18150569,11.21057035,11.27474846,11.34322096,11.30107278,11.46377857,11.60315357,11.67579747,11.82565523,12.04162329,12.07532791,12.22188071,12.1596402,12.19914652,12.37945386,12.66238559,12.67244423,12.72059369,12.8902171,12.95906823,13.20706844,13.27666955,13.3014099,13.41248803,13.43752052,13.7314717,13.85510547,13.95964537,14.21677499,14.40742286,14.46573428,14.73060447,14.67937454,14.7136648,14.92180765,15.24149746,15.23213103,15.34284718,15.500365,15.70439103,15.91565271,16.03665614,16.0101613,16.07300912,16.4693053,16.41564777,16.84168156,17.14732508,17.43232174,17.62700285,17.86727278,18.10997615,17.9582942,18.10001304,18.14058312,18.32411359,18.31731965,18.65286964,18.735883,18.72062801,18.98792969,18.93380648,19.03403078,19.21018323,19.22648995,19.45467137,19.53099873,19.68948842,19.91609513,20.34906056,20.9091959,21.60140457,21.71096706,22.39378605,23.08627653,23.5182693,23.78869162,24.39548109,25.10938271,25.26871426,25.78456832,26.12794679,26.8897385,27.3913443,28.74464761,28.60741633,29.97215368,31.55306755,33.16777605,34.38157284,34.96181251,37.46957853,38.13342516,39.56446297,39.95714271,40.69211664,41.4767259,42.52135697,43.27485688,44.24089207,45.13478108,45.97852705,46.37436562,47.66689068,47.6454021,48.69349353,49.41563613,50.21167874,51.33101366,51.72677742,52.06403696,52.52170068,54.26130892,52.37759099,52.78275226,54.21042307,53.41671788,53.42127729,56.11803189,56.58934432,54.7693723,54.50959652,54.70989639,57.07665954,57.69037488,58.11358477,58.88341048,60.37974253,60.96582609,61.31644175,61.3779593,62.44447212,62.39874927,63.84845417,63.65097665,65.03685366,65.27970313,65.84949779,66.41929244,66.98908709,67.55888174,68.12867639,68.63386091,69.13904544,69.64422997,70.14941449,70.65459902,71.15978354,71.66496807,72.17015259,72.67533712,73.18052164,73.47421727,73.76791289,74.06160851,74.35530413,74.64899975,74.94269537,75.23639099,75.53008661,75.82378223,76.11747786,76.3286322,76.53978655,76.7509409,76.96209525,77.1732496,77.38440395,77.5955583,77.80671265,78.017867,78.22902135,78.29649848,78.3639756,78.43145273,78.49892986,78.56640698,78.63388411,78.70136124,78.76883837,78.83631549,78.90379262,78.94276045,78.98172828,79.02069611,79.05966394,79.09863178,79.13759961,79.17656744,79.21553527,79.2545031,79.29347093,79.29560118,79.29773144,79.29986169,79.30199195,79.3041222,79.30625245,79.30838271,79.31051296,79.31264322,79.31477347,79.4767239,79.63867432,79.80062474,79.96257517,80.12452559,80.28647601,80.44842644,80.61037686,80.77232729,80.93427771,81.13218484,81.33009198,81.52799911,81.72590625,81.92381338,82.12172051,82.31962765,82.51753478,82.71544191,82.91334905,82.78793979,82.66253053,82.53712126,82.411712,82.28630274,82.16089348,82.03548422,81.91007496,81.78466569,81.65925643,81.53384717,81.40843791,81.28302865,81.15761939,81.03221013,80.90680086,80.7813916,80.65598234,80.53057308,80.40516382,80.27975456,80.15434529,80.02893603,79.90352677,79.77811751,79.65270825,79.52729899,79.40188973,79.27648046,79.1510712,79.02566194,78.90025268,78.77484342,78.64943416,78.52402489,78.39861563,78.27320637,78.14779711,78.02238785,77.89697859,77.77156933,77.64616006,77.5207508,77.39534154,77.26993228,77.14452302,77.01911376,76.89370449,76.76829523,76.64288597,76.51747671,76.39206745,76.26665819,76.14124893,76.01583966,75.8904304,75.76502114,75.63961188,75.51420262,75.38879336,75.26338409,75.13797483,75.01256557,74.88715631,74.76174705,74.63633779,74.51092853,74.38551926,74.26011,74.13470074,74.00929148,73.88388222,73.75847296,73.63306369,73.50765443,73.38224517,73.25683591,73.13142665,73.00601739,72.88060813,72.75519886,72.6297896,72.50438034,72.37897108,72.25356182,72.12815256,72.00274329,71.87733403,71.75192477,71.62651551,71.50110625,71.37569699,71.25028773,71.12487846,70.9994692,70.87405994,70.74865068,70.62324142,70.49783216,70.37242289,70.24701363,70.12160437,69.99619511,69.87078585,69.74537659,69.61996733,69.49455806,69.3691488,69.24373954,69.11833028,68.99292102,68.86751176,68.74210249,68.61669323,68.49128397,68.36587471,68.24046545,68.11505619,67.98964693,67.86423766,67.7388284,67.61341914,67.48800988,67.36260062,67.23719136,67.11178209,66.98637283,66.86096357,66.73555431,66.61014505,66.48473579,66.35932653,66.23391726,66.108508,65.98309874,65.85768948,65.73228022,65.60687096,65.48146169,65.35605243,65.23064317,65.10523391,64.97982465,64.85441539,64.72900613,64.60359686,64.4781876,64.35277834,64.22736908,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982,64.10195982};
    Aero_ENMVOC_em={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,60.02182622,59.08812628,58.63199703,59.0263494,60.26994517,59.82493372,58.94682931,61.263693,60.43461244,60.44526305,61.05172479,60.9842272,60.02708933,60.12706627,58.43835717,60.62945786,59.85878463,59.8910269,62.36582555,60.95040361,60.96602721,59.42424033,58.72495295,58.91656885,61.31335787,60.54083046,59.3811448,60.89349007,61.78348695,60.50081488,61.61859566,61.19330647,60.48572145,60.10171272,59.21225989,60.49447936,59.91468241,60.75335708,63.12433047,61.63229238,61.84599181,60.2187392,59.70568574,59.5849395,62.03822453,61.24273214,59.86424243,61.47137695,62.19763903,61.4962302,62.00320914,61.66564779,61.32615659,60.40434182,60.36470275,61.31991146,61.22344968,61.70646914,64.08195973,62.71002213,62.97351665,61.829606,60.85746997,61.1361302,63.49192823,62.8715757,62.14643252,62.94153101,64.26768049,63.25758927,64.0766433,63.98744909,63.22724653,62.26076437,62.5634338,63.18578955,62.81594151,63.38999011,65.90535949,64.57289824,64.94076179,63.33682174,62.87089656,63.0695837,65.10499264,64.23544317,64.08016333,64.82242714,65.94724657,65.11131218,64.92298176,65.94544518,64.92167359,63.42406091,63.7624543,64.68556723,64.24405153,65.44362075,67.39824375,66.42707154,66.78304875,64.95004659,63.95789986,64.44555418,66.79469522,65.65156398,65.0425347,66.72779877,67.47060376,66.95694734,66.84953493,66.88575551,66.35896016,65.0096354,65.39906664,67.10347351,66.37528156,67.66026449,69.64729381,67.92949559,69.12187694,67.42862358,65.84553711,67.99437045,69.34908007,67.4820886,68.07266489,68.77838073,69.46979574,70.08572002,69.18788119,69.70896889,68.75016749,67.06254476,68.59402326,68.94977818,68.86926284,69.79403942,71.42723744,70.65718772,71.47659717,69.53172191,68.66391959,69.48705802,71.90804381,71.15178658,69.42267706,71.5467325,71.45665952,72.46072256,71.90656631,71.63263161,71.24149846,70.25376393,72.88437625,73.70973522,73.46173851,76.00444514,76.856238,76.4408771,78.48124343,76.73370569,75.83160819,77.5799616,79.77807343,78.35040062,78.27985155,80.45481807,81.61294814,81.67724386,82.96992111,81.18725519,80.53069431,86.27583424,83.21123114,84.06174423,84.16877083,86.52753525,87.11586337,89.37670247,91.59573863,86.48531867,87.90725373,87.73926442,91.49703968,91.90214074,95.83484543,95.84567433,93.23706062,97.34535423,96.49612887,97.09407345,98.65719695,99.48634644,102.0083052,102.3868629,102.6581835,104.1573676,108.0964174,109.1544258,113.8598472,109.0909544,112.6182109,116.7765378,118.7896929,122.5425815,129.82302,135.5915206,129.2085836,131.2104974,133.3368149,143.5652635,140.105892,156.130954,146.4547756,153.4053912,156.4949809,164.7753162,165.0957088,169.6815713,179.6859547,183.5355579,196.6655247,186.5259319,183.6005251,177.5130673,186.2474273,189.2255323,192.9347955,196.0169029,194.391242,189.1686139,206.8844648,183.8358223,189.3335257,190.4568857,195.6652235,203.5851701,203.5322276,200.3165052,203.021231,244.4286341,198.238473,203.7757832,231.0503543,206.4742485,200.8724208,264.6751503,232.3180182,205.1118782,195.3241582,196.1877828,218.4604141,214.4033914,216.6872834,218.7880648,229.8954395,219.7058707,214.695495,218.7581143,224.6021121,218.628754,229.1069362,219.3811793,233.525518,227.2448193,227.4898416,227.7348638,227.9798861,228.2249084,228.4699306,227.3450591,226.2201875,225.0953159,223.9704444,222.8455728,221.7207012,220.5958296,219.4709581,218.3460865,217.2212149,215.1599025,213.0985901,211.0372778,208.9759654,206.914653,204.8533406,202.7920282,200.7307158,198.6694034,196.608091,193.7110968,190.8141026,187.9171084,185.0201142,182.1231201,179.2261259,176.3291317,173.4321375,170.5351433,167.6381491,166.0961878,164.5542264,163.0122651,161.4703037,159.9283423,158.386381,156.8444196,155.3024582,153.7604969,152.2185355,150.6169218,149.0153081,147.4136943,145.8120806,144.2104669,142.6088532,141.0072394,139.4056257,137.804012,136.2023983,134.5323298,132.8622614,131.1921929,129.5221245,127.852056,126.1819876,124.5119191,122.8418507,121.1717822,119.5017138,117.7948386,116.0879635,114.3810884,112.6742133,110.9673382,109.2604631,107.553588,105.8467129,104.1398378,102.4329627,100.5984597,98.7639567,96.9294537,95.09495071,93.26044771,91.42594472,89.59144172,87.75693873,85.92243573,84.08793274,83.75288165,83.41783056,83.08277948,82.74772839,82.4126773,82.07762622,81.74257513,81.40752404,81.07247296,80.73742187,80.40237078,80.0673197,79.73226861,79.39721752,79.06216643,78.72711535,78.39206426,78.05701317,77.72196209,77.386911,77.05185991,76.71680883,76.38175774,76.04670665,75.71165557,75.37660448,75.04155339,74.7065023,74.37145122,74.03640013,73.70134904,73.36629796,73.03124687,72.69619578,72.3611447,72.02609361,71.69104252,71.35599144,71.02094035,70.68588926,70.35083817,70.01578709,69.680736,69.34568491,69.01063383,68.67558274,68.34053165,68.00548057,67.67042948,67.33537839,67.00032731,66.66527622,66.33022513,65.99517405,65.66012296,65.32507187,64.99002078,64.6549697,64.31991861,63.98486752,63.64981644,63.31476535,62.97971426,62.64466318,62.30961209,61.974561,61.63950992,61.30445883,60.96940774,60.63435665,60.29930557,59.96425448,59.62920339,59.29415231,58.95910122,58.62405013,58.28899905,57.95394796,57.61889687,57.28384579,56.9487947,56.61374361,56.27869252,55.94364144,55.60859035,55.27353926,54.93848818,54.60343709,54.268386,53.93333492,53.59828383,53.26323274,52.92818166,52.59313057,52.25807948,51.92302839,51.58797731,51.25292622,50.91787513,50.58282405,50.24777296,49.91272187,49.57767079,49.2426197,48.90756861,48.57251753,48.23746644,47.90241535,47.56736427,47.23231318,46.89726209,46.562211,46.22715992,45.89210883,45.55705774,45.22200666,44.88695557,44.55190448,44.2168534,43.88180231,43.54675122,43.21170014,42.87664905,42.54159796,42.20654687,41.87149579,41.5364447,41.20139361,40.86634253,40.53129144,40.19624035,39.86118927,39.52613818,39.19108709,38.85603601,38.52098492,38.18593383,37.85088274,37.51583166,37.18078057,36.84572948,36.5106784,36.17562731,35.84057622,35.50552514,35.17047405,34.83542296,34.50037188,34.16532079,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697,33.8302697};
    CH4={706.0540211995443,706.2470041910807,706.3750305175781,706.4910024007162,706.6020456949869,706.8570149739584,707.0230102539062,707.0680033365885,706.9670003255209,706.8830312093099,706.7899627685547,706.5970560709635,706.6309865315756,706.6200459798177,706.6699879964193,706.6290435791016,706.729014078776,706.8610585530599,707.1740417480469,707.5340118408203,707.6309661865234,707.5441284179688,708.4482269287109,710.3340148925781,711.8640645345052,713.0370025634766,714.0311584472656,715.5130208333334,716.6720326741537,717.8052062988281,719.6420542399088,721.3950958251953,722.8849131266276,723.5130462646484,723.7628885904948,723.0359141031901,722.0431060791016,721.6849466959635,721.3781127929688,721.6500244140625,722.1611124674479,723.1330718994141,724.3751220703125,725.9170481363932,727.300059000651,728.6180877685547,729.7048746744791,729.8320821126302,730.2330983479818,730.9769846598307,731.405995686849,731.8381652832031,732.8999735514323,733.6340382893881,734.2020212809244,734.7360788981119,735.4210001627604,735.8930308024088,736.2069956461588,736.098887125651,735.4841715494791,735.7630208333334,736.3031056722006,737.1810404459635,738.1030629475912,738.9860382080078,739.8310852050781,740.7289835611979,741.2220560709635,741.7470499674479,742.301015218099,742.8711649576823,744.0189666748047,744.6629842122396,744.8780721028646,745.3670603434244,746.0480702718099,746.7369181315104,746.7510579427084,746.9070231119791,747.2310638427734,747.7660471598307,748.2900187174479,748.6270294189453,748.9340260823568,749.2520395914713,749.5639801025391,749.6690826416016,750.1610209147135,750.6470489501953,751.1640370686849,751.7080535888672,752.2780151367188,752.6820678710938,753.2520446777344,753.841064453125,754.5180511474609,755.2560729980469,756.113047281901,756.9420471191406,757.7620493570963,758.5840606689453,759.507069905599,760.508046468099,761.5410817464193,762.6710561116537,763.7990773518881,765.0220794677734,766.319081624349,767.6550801595052,769.1471150716146,770.7180430094401,772.2101186116537,773.7009938557943,774.828135172526,776.1400197347006,777.3801574707031,778.9910329182943,780.3030497233073,781.4260508219401,782.4270782470703,783.5681304931641,784.9560546875,786.2210744222006,787.4750722249349,788.7140604654948,789.831044514974,790.8700917561849,791.9830423990885,793.0000712076823,793.9600270589193,794.8100738525391,795.5789845784506,796.1241149902344,797.0440368652344,797.8309682210287,798.1060129801432,798.1159820556641,797.9370168050131,797.9220987955729,798.3870493570963,799.0600840250651,800.0011189778646,801.4921824137369,803.6190745035807,805.6650695800781,807.2559560139974,807.9369812011719,808.092041015625,808.2150014241537,808.2490285237631,808.4141082763672,809.1631317138672,810.4040578206381,811.7321421305338,813.3320363362631,814.7961222330729,816.4521179199219,818.3551279703776,820.3960774739584,822.3121185302734,824.3991902669271,827.0292002360026,830.1662139892578,833.6041412353516,836.8942057291666,840.3622080485026,843.9951222737631,847.2491251627604,850.1300862630209,852.4350077311198,853.9930725097656,855.2329915364584,856.1681976318359,857.820078531901,859.4690653483073,860.8591054280599,862.3791147867838,864.139149983724,866.2831624348959,868.6961059570312,870.9841257731119,873.2501373291016,875.6031494140625,878.148203531901,881.0251312255859,883.8392181396484,886.9331359863281,889.9262135823568,893.1561584472656,896.3831837972006,899.6662648518881,903.5341949462891,907.2741190592448,910.4781341552734,913.2259826660156,914.7710927327474,916.2742818196615,919.0172271728516,922.2811838785807,925.5521138509115,928.8003336588541,932.7311604817709,936.7834269205729,942.114267985026,947.4432729085287,953.0924224853516,959.1561177571615,964.0852966308594,969.3983662923177,974.7870890299479,979.465321858724,983.6058603922526,986.2423197428385,988.6108805338541,991.4610799153646,998.4538218180338,1003.5705515543619,1010.1304473876953,1017.6303660074869,1025.070327758789,1032.2003377278645,1039.1002502441406,1045.1300659179688,1049.4500325520833,1052.1599527994792,1053.6001078287761,1055.7705688476562,1060.640360514323,1066.6603291829426,1072.640116373698,1077.4902242024739,1081.960225423177,1086.5403340657551,1091.7702941894531,1097.0801289876301,1101.830301920573,1106.3199869791667,1110.6307983398438,1116.9096781412761,1120.1201782226562,1123.2405090332031,1128.1901550292969,1132.66015625,1136.2700602213542,1139.3203633626301,1143.6604919433594,1149.6402994791667,1155.6301676432292,1160.3499450683594,1163.8205668131511,1168.8101196289062,1174.3108825683594,1183.3606567382812,1194.4306030273438,1206.6509297688801,1221.1007995605469,1235.8001810709636,1247.4204813639324,1257.3200785319011,1264.119873046875,1269.4615275065105,1282.5712890625,1300.7905782063801,1317.3704528808594,1331.060282389323,1342.2405090332031,1354.2715555826824,1371.6504618326824,1389.3417561848958,1411.1005147298176,1431.1209615071614,1449.290018717448,1462.8606770833333,1476.1409098307292,1491.740966796875,1509.1109517415364,1527.6809488932292,1546.8908996582031,1566.1608581542969,1584.9407348632812,1602.6506245930989,1618.7305399576824,1632.6201477050781,1643.5008544921875,1655.9104715983074,1668.7911478678386,1683.7497863769531,1693.9409281412761,1705.6304423014324,1717.4006754557292,1729.3305562337239,1740.1392618815105,1743.1006876627605,1748.6203715006511,1755.2296244303386,1757.1905924479167,1761.5010782877605,1770.2906799316406,1778.1995137532551,1778.0101216634114,1776.5307312011719,1778.9609476725261,1783.5898132324219,1784.2302856445312,1783.3604329427083,1783.4212239583333,1788.9513142903645,1798.4196472167969,1802.1011861165364,1807.8506673177083,1813.0701904296875,1815.26123046875,1822.5808410644531,1831.4709981282551,1841.9326985677083,1851.5941670735676,1874.5094502766926,1889.791280110677,1905.450948079427,1921.4410196940105,1937.7410278320312,1954.3710835774739,1971.4010823567708,1988.7910970052083,2006.5111389160156,2024.5311584472656,2042.8211568196614,2061.371134440104,2080.1512247721353,2099.1412150065103,2118.3211669921875,2137.5512084960938,2156.701171875,2175.7611694335938,2194.751180013021,2213.6611531575522,2232.501180013021,2251.271199544271,2269.9711710611978,2288.5912068684897,2307.151163736979,2325.6511840820312,2344.1011555989585,2362.51123046875,2380.8711547851562,2399.191162109375,2417.4611612955728,2435.691162109375,2453.8711547851562,2472.0011596679688,2490.0811767578125,2508.18115234375,2526.3411865234375,2544.5511881510415,2562.8211466471353,2581.1311848958335,2599.4811808268228,2617.8611857096353,2636.2612101236978,2654.6911824544272,2673.1312255859375,2691.6112060546875,2710.1212158203125,2728.6812337239585,2747.26123046875,2765.8712565104165,2784.5012410481772,2803.1412556966147,2821.8012084960938,2840.4512736002603,2859.1112467447915,2877.791219075521,2896.5212605794272,2915.291259765625,2934.0812784830728,2952.9112345377603,2971.7512817382812,2990.6113077799478,3009.4812622070312,3028.3512573242188,3047.2212931315103,3065.9612426757812,3084.4612426757812,3102.7312215169272,3120.7811686197915,3138.6211547851562,3156.251220703125,3173.701212565104,3190.97119140625,3208.0711669921875,3225.0111694335938,3241.8011881510415,3258.4811401367188,3275.0411580403647,3291.4811401367188,3307.8311564127603,3324.0611572265625,3340.2011515299478,3356.2411295572915,3372.18115234375,3388.031005859375,3402.6807861328125,3415.0906778971353,3425.4506022135415,3433.8904825846353,3440.5804036458335,3445.6503295898438,3449.220255533854,3451.4101765950522,3452.3401082356772,3452.10009765625,3450.789998372396,3448.499959309896,3445.3199259440103,3441.2998860677085,3436.5298665364585,3431.0798543294272,3424.989786783854,3418.329793294271,3411.1397705078125,3403.4797159830728,3395.389689127604,3386.8996785481772,3378.0596923828125,3368.9096883138022,3359.4595947265625,3349.7496134440103,3339.8095906575522,3329.6695963541665,3319.32958984375,3308.839599609375,3298.1995849609375,3287.4295654296875,3276.549560546875,3265.5695597330728,3254.509562174479,3243.3795776367188,3232.1795450846353,3220.9395548502603,3209.6595865885415,3198.3495483398438,3187.009562174479,3175.6595458984375,3164.28955078125,3152.9195556640625,3141.5495402018228,3130.1895751953125,3118.8394978841147,3107.499552408854,3096.1695556640625,3084.869588216146,3073.5895385742188,3062.3295288085938,3051.0995279947915,3039.8995157877603,3028.7295735677085,3017.5895792643228,3006.479532877604,2995.4095458984375,2984.3695475260415,2973.3695271809897,2962.4095662434897,2951.479532877604,2940.5895385742188,2929.7295532226562,2918.9195556640625,2908.1395874023438,2897.3995564778647,2886.6996053059897,2876.029541015625,2865.3995564778647,2854.809529622396,2844.249552408854,2833.729532877604,2823.2496134440103,2812.799560546875,2802.3895670572915,2792.009562174479,2781.6695760091147,2771.3595987955728,2761.089558919271,2750.8395792643228,2740.6295776367188,2730.4495646158853,2720.3095703125,2710.1895548502603,2700.1095581054688,2690.049519856771,2680.0296020507812,2670.029581705729,2660.0695597330728,2650.129597981771,2640.2195434570312,2630.32958984375,2620.4795735677085,2610.6395670572915,2600.839558919271,2591.0595499674478,2581.299560546875,2571.569539388021,2561.859578450521,2552.1695963541665,2542.509562174479,2532.8695678710938,2523.2495320638022,2513.6495564778647,2504.0795694986978,2494.519571940104,2484.9895629882812,2475.4696044921875,2465.9795735677085,2456.4995727539062,2447.0395711263022,2437.5995483398438,2428.1795857747397,2418.7795613606772,2409.3895670572915,2400.0195515950522,2390.6595662434897,2381.319580078125,2371.9995320638022,2362.6895751953125,2353.3895670572915,2344.1095581054688,2334.8495890299478,2325.5895792643228,2316.359578450521,2307.1295572916665,2297.9195353190103,2288.7195638020835,2279.53955078125,2270.3595581054688,2261.1995442708335,2252.0495808919272,2242.9095458984375,2233.7895711263022,2224.6696166992188,2215.5695597330728,2206.4695638020835,2197.3895263671875,2188.3195597330728,2179.2495727539062,2170.1995239257812,2161.1595458984375,2152.1195678710938,2143.0895792643228,2134.079549153646,2125.0695597330728,2116.0695597330728,2107.069539388021,2098.089640299479,2089.4796752929688,2081.5897013346353,2074.3397013346353,2067.69970703125,2061.5997924804688,2055.989786783854,2050.849812825521,2046.119852701823,2041.7798665364583,2037.7798767089844,2034.109883626302,2030.7198994954426,2027.6099039713542,2024.7299296061199,2022.0799255371094,2019.6299336751301,2017.3699442545574,2015.2799580891926,2013.3399861653645,2011.5399576822917,2009.8799743652344,2008.3299967447917,2006.8799947102864,2005.5399881998699,2004.290018717448,2003.1199849446614,2002.019999186198,2000.9900207519531,2000.030008951823,1999.1200256347656,1998.260009765625,1997.4500325520833,1996.6900126139324,1995.9600219726562,1995.2700093587239,1994.6200154622395,1993.9900004069011,1993.3900146484375,1992.8200276692708,1992.2700297037761,1991.7400309244792,1991.2300313313801,1990.7400512695312,1990.260030110677,1989.800028483073,1989.3500569661458,1988.9200337727864,1988.4900410970051,1988.0800374348958,1987.6700236002605,1987.2800598144531,1986.8900451660156,1986.5100402832031,1986.1400248209636,1985.7700500488281,1985.4100240071614,1985.0500386555989,1984.7000325520833,1984.3500467936199,1984.010030110677,1983.6700439453125,1983.3300476074219,1983.0000406901042,1982.6700439453125,1982.3400370279949,1982.020039876302,1981.7000528971355,1981.3800252278645,1981.0600687662761,1980.7500406901042,1980.4300333658855,1980.1200459798176,1979.8100484212239,1979.5000406901042,1979.2000528971355,1978.8900349934895,1978.5900472005208,1978.2900492350261,1977.9900410970051,1977.6900634765625,1977.3900451660156,1977.0900268554688,1976.7900492350261,1976.5000406901042,1976.2000528971355,1975.9100443522136,1975.6200358072917,1975.3300476074219,1975.040059407552,1974.7500508626301,1974.4600423177083,1974.1700439453125,1973.8900451660156,1973.6000671386719,1973.3200378417969,1973.0300394694011,1972.7500610351562,1972.4700317382812,1972.1800435384114,1971.9000549316406,1971.6200459798176,1971.3500264485676,1971.0700378417969,1970.7900288899739,1970.5100402832031,1970.2400410970051,1969.9600524902344,1969.6900329589844,1969.4200337727864,1969.1400451660156,1968.8700358072917,1968.6000467936199,1968.3300476074219,1968.0600484212239,1967.7900492350261,1967.520039876302,1967.260030110677,1966.9900512695312,1966.7300415039062,1966.4600423177083,1966.2000528971355,1965.9300435384114,1965.6700439453125,1965.4100545247395,1965.1500142415364,1964.8900451660156,1964.6300557454426,1964.3700459798176,1964.1100463867188,1963.8600463867188,1963.6000569661458,1963.3500162760417,1963.0900472005208,1962.8400472005208,1962.5800476074219,1962.3300374348958,1962.0800476074219,1961.830057779948,1961.5800374348958,1961.3300374348958,1961.0800374348958,1960.8300476074219,1960.5900573730469,1960.3400370279949,1960.0900573730469,1959.8500264485676,1959.6100463867188,1959.3600362141926,1959.1200358072917,1958.8800354003906,1958.6400553385417,1958.4000447591145,1958.1600443522136,1957.9200541178386,1957.6800231933594,1957.4400634765625,1957.2100321451824,1956.9700622558594,1956.7400512695312,1956.5000406901042,1956.2700602213542,1956.030049641927,1955.8000590006511,1955.570048014323,1955.3400573730469,1955.1100463867188,1954.8800354003906,1954.6500447591145,1954.4200337727864,1954.2000630696614,1953.9700520833333,1953.7400614420574,1953.5200602213542,1953.2900492350261,1953.0700378417969,1952.8500366210938,1952.6300455729167,1952.4000549316406,1952.1800638834636,1951.9600423177083,1951.7400410970051,1951.5200500488281,1951.3100484212239,1951.0900370279949,1950.8700561523438,1950.6600646972656,1950.4400329589844,1950.2300516764324,1950.0100606282551,1949.8000386555989,1949.5900472005208,1949.3700663248699,1949.1600646972656,1948.9500325520833,1948.7400309244792,1948.5300598144531,1948.320048014323,1948.1100362141926,1947.9100240071614,1947.7000528971355,1947.4900817871094,1947.2900390625,1947.0800476074219,1946.8800455729167,1946.6800537109375,1946.4700520833333,1946.270039876302,1946.0700581868489,1945.8700663248699,1945.6700439453125,1945.4700419108074,1945.2700500488281,1945.0700378417969,1944.8700561523438,1944.6700439453125,1944.4800516764324,1944.2800598144531,1944.0900573730469,1943.8900655110676,1943.7000528971355,1943.5000508626301,1943.31005859375,1943.1200358072917,1942.9300638834636,1942.7400614420574,1942.540059407552,1942.3500467936199,1942.1700337727864,1941.9800618489583,1941.790059407552,1941.6000569661458,1941.4100545247395,1941.2300516764324,1941.040059407552,1940.8600362141926,1940.6700541178386,1940.4900512695312,1940.300069173177,1940.1200561523438,1939.9400634765625,1939.7600504557292,1939.580057779948,1939.3900655110676,1939.2100524902344,1939.030049641927,1938.8600362141926,1938.6800638834636,1938.5000610351562,1938.4100545247395};
    CO2={276.7459996541341,276.749994913737,276.7579981486003,276.75700124104816,276.7549997965495,276.74900309244794,276.7430013020833,276.74499766031903,276.73900349934894,276.7360026041667,276.7409947713216,276.7330042521159,276.7310028076172,276.7249984741211,276.7229995727539,276.7170003255208,276.71599833170575,276.71699778238934,276.70999908447266,276.7060038248698,276.6949996948242,276.697998046875,276.7009989420573,276.69999440511066,276.70799763997394,276.71799723307294,276.71899668375653,276.71199798583984,276.70699818929035,276.7149963378906,276.72300211588544,276.7299982706706,276.73299916585285,276.73899841308594,276.7529983520508,276.75999959309894,276.7730000813802,276.79000091552734,276.81199645996094,276.83499908447266,276.85500081380206,276.8759943644206,276.9010009765625,276.9260025024414,276.95300547281903,276.9859975179036,277.01399993896484,277.0439987182617,277.07999928792316,277.10900115966797,277.1470031738281,277.18800099690753,277.22900136311847,277.26300048828125,277.3040033976237,277.3510030110677,277.38899993896484,277.4419987996419,277.48900095621747,277.5399983723958,277.6050033569336,277.6639989217122,277.7320022583008,277.7959976196289,277.8590037027995,277.9129994710286,277.95800018310547,278.0169982910156,278.07799530029297,278.135004679362,278.1939977010091,278.2700017293294,278.33399963378906,278.41199493408203,278.49099985758465,278.58600362141925,278.68299865722656,278.7739969889323,278.86599985758465,278.9590021769206,279.0540033976237,279.14499918619794,279.2430013020833,279.33999888102215,279.4340006510417,279.53200276692706,279.6290003458659,279.72900136311847,279.83099873860675,279.93299865722656,280.03700256347656,280.14099884033203,280.2409973144531,280.33199818929035,280.41500091552734,280.4919967651367,280.5549952189128,280.6230010986328,280.68200429280597,280.7529983520508,280.83399709065753,280.9189987182617,280.9939956665039,281.07299550374347,281.15699768066406,281.23399607340497,281.32200113932294,281.40900166829425,281.4959996541341,281.56599680582684,281.6480026245117,281.71799723307294,281.7899983723958,281.8580017089844,281.9310048421224,281.9919967651367,282.0590006510417,282.1270014444987,282.1999994913737,282.27200571695965,282.3460006713867,282.4150034586589,282.4769999186198,282.54000091552734,282.6179962158203,282.6759999593099,282.6929982503255,282.69299570719403,282.708002726237,282.76099650065106,282.8249994913737,282.8909962972005,282.9219970703125,282.96599833170575,283.0279998779297,283.08599853515625,283.1489995320638,283.19800059000653,283.2530034383138,283.3109995524089,283.38200124104816,283.46699778238934,283.5279998779297,283.56600189208984,283.60899861653644,283.72499593098956,283.8470001220703,283.9359995524089,284.0679982503255,284.20699818929035,284.3169987996419,284.4510040283203,284.59800211588544,284.7309977213542,284.8459981282552,284.9409993489583,285.04899342854816,285.20399983723956,285.3690007527669,285.5449956258138,285.73899332682294,285.9330012003581,286.1000010172526,286.271001180013,286.44200134277344,286.6139958699544,286.78099822998047,286.9550018310547,287.10500081380206,287.2249984741211,287.3549982706706,287.4940007527669,287.66399637858075,287.86000061035156,288.0609995524089,288.29100290934247,288.5199966430664,288.7520014444987,288.9930013020833,289.2210006713867,289.4699986775716,289.7369969685872,290.0190022786458,290.26300048828125,290.5119984944661,290.7969970703125,291.09999593098956,291.4139989217122,291.76300048828125,292.1130015055339,292.45799763997394,292.8159993489583,293.16699981689453,293.4769999186198,293.7909978230794,294.0789972941081,294.36499786376953,294.64599863688153,294.95399983723956,295.2999979654948,295.6749954223633,296.0069986979167,296.3249994913737,296.65399678548175,296.95399475097656,297.28899637858075,297.66199747721356,298.0979944864909,298.5179901123047,298.93599192301434,299.37699635823566,299.82899220784503,300.3529917399089,300.9099934895833,301.4189910888672,301.9369888305664,302.48498789469403,303.01098887125653,303.44898732503253,303.8139877319336,304.24598693847656,304.59998830159503,304.9449818929036,305.27098337809247,305.62998453776044,305.81298065185547,305.9539845784505,306.17698669433594,306.3289794921875,306.49498748779297,306.6199773152669,306.82198333740234,307.09297943115234,307.40198008219403,307.7849833170573,308.2269795735677,309.01197306315106,309.7639745076497,310.2939758300781,310.8509750366211,311.35697682698566,311.81097412109375,312.17197672526044,312.3899790445964,312.41297149658203,312.38497670491535,312.38997141520184,312.48597208658856,312.5209681193034,312.63197072347003,312.8209762573242,313.01397196451825,313.3419774373372,313.72996775309247,314.09496815999347,314.4149703979492,314.6979675292969,314.9919611612956,315.344965616862,315.8069661458333,316.62496693929035,317.29896291097003,318.0439631144206,318.64996337890625,319.3329620361328,319.81596120198566,320.8799565633138,321.4799575805664,322.3889567057292,323.25095621744794,324.78295644124347,325.3999557495117,327.3489532470703,329.90895080566406,330.7559534708659,330.8269551595052,331.5449498494466,333.3529459635417,335.00994873046875,336.60494740804035,338.70494588216144,340.05894978841144,340.64394124348956,342.26594797770184,344.00794728597003,345.4589538574219,346.90294647216797,348.77494557698566,351.2759323120117,352.89392344156903,354.07293192545575,355.35293833414715,356.22894795735675,356.92495981852215,358.2539596557617,360.2389551798503,362.00496164957684,363.25195566813153,365.9329554239909,367.84497833251953,369.1249745686849,370.67298889160156,372.83499399820965,375.41099802652997,376.9870020548503,378.9070078531901,381.01000722249347,382.60301971435547,384.739018758138,386.28002166748047,388.71703084309894,390.9440205891927,393.0159912109375,395.72497812906903,397.5469792683919,399.9484380086263,403.1169662475586,405.8129628499349,408.8319574991862,411.94596099853516,415.1549555460612,418.4609603881836,421.8429590861003,425.28295644124347,428.7839533487956,432.3469518025716,435.9749501546224,439.6699473063151,443.43195088704425,447.262944539388,451.16395060221356,455.1359507242839,459.1659469604492,463.24194590250653,467.36494700113934,471.53894297281903,475.76494852701825,480.0449447631836,484.3799463907878,488.7719421386719,493.220942179362,497.73093668619794,502.2919464111328,506.9009424845378,511.55694580078125,516.2639414469401,521.0209401448568,525.8299357096354,530.6919352213541,535.6089426676432,540.5809377034506,545.6099395751953,550.6909383138021,555.8219350179037,561.0039265950521,566.2389373779297,571.5259399414062,576.867919921875,582.2659403483073,587.7189381917318,593.2299397786459,598.7979329427084,604.4239349365234,610.1069386800131,615.846934000651,621.6469319661459,627.5049285888672,633.4229329427084,639.4019317626953,645.4419301350912,651.5439300537109,657.7079315185547,663.9339294433594,670.221923828125,676.5719350179037,682.9849446614584,689.460927327474,696.0019276936849,702.6059265136719,709.2749277750651,716.0079294840494,722.8079325358073,729.6789296468099,736.6289215087891,743.6569315592448,750.7639312744141,757.9509226481119,765.2159271240234,772.5609334309896,779.9839223225912,787.4879201253256,795.0699157714844,802.7359161376953,810.4889221191406,818.3279113769531,826.2539215087891,834.2669169108073,842.3669179280599,850.5539245605469,858.8289133707682,867.19091796875,875.6399129231771,884.1099141438802,892.5329132080078,900.9109191894531,909.2469126383463,917.5409291585287,925.7929178873698,934.0049235026041,942.1769104003906,950.3079274495443,958.3969268798828,966.4449208577474,974.4519297281901,982.4159240722656,990.3369293212891,998.2139231363932,1006.0499267578125,1013.8399302164713,1021.5799357096354,1029.2699279785156,1036.9199320475261,1044.5199076334636,1052.0799458821614,1059.5799255371094,1067.0299173990886,1074.4399312337239,1081.7899271647136,1089.0899454752605,1096.3299255371094,1103.5299275716145,1110.669942220052,1117.7499389648438,1124.7799479166667,1131.7599385579426,1138.669942220052,1145.5299173990886,1152.3399454752605,1159.0799357096355,1165.7699279785156,1172.3999430338542,1178.959940592448,1185.4699401855469,1191.9199625651042,1198.3099365234375,1204.6299540201824,1210.8899536132812,1217.0899556477864,1223.2299499511719,1229.2999267578125,1235.3199666341145,1241.2599487304688,1247.1499430338542,1252.9699300130208,1258.7399597167969,1264.449951171875,1270.0999450683594,1275.699951171875,1281.2299702962239,1286.6999613444011,1292.1099548339844,1297.4699300130208,1302.7599487304688,1307.9899597167969,1313.1599527994792,1318.2599589029949,1323.3099466959636,1328.2899475097656,1333.2099507649739,1338.0699462890625,1342.8699544270833,1347.5999654134114,1352.2699584960938,1356.8799540201824,1361.4199625651042,1365.8999532063801,1370.3199564615886,1374.6699625651042,1378.9599609375,1383.1799621582031,1387.3399658203125,1391.4399515787761,1395.4699605305989,1399.429951985677,1403.3299662272136,1407.1599731445312,1410.9299825032551,1414.6399637858074,1418.2699584960938,1421.8499755859375,1425.3499654134114,1428.7999674479167,1432.1699625651042,1435.4799702962239,1438.719970703125,1441.8999735514324,1445.0099690755208,1448.0499776204426,1451.0299784342449,1453.939961751302,1456.7899780273438,1459.5699768066406,1462.2799682617188,1464.9199625651042,1467.499979654948,1470.0099690755208,1472.459981282552,1474.8299865722656,1477.1399637858074,1479.3899637858074,1481.5599772135417,1483.6699829101562,1485.719991048177,1487.6899922688801,1489.5999959309895,1491.4399820963542,1493.219970703125,1494.9199930826824,1496.5599873860676,1498.1399943033855,1499.6399841308594,1501.0799763997395,1502.4499816894531,1503.7599792480469,1504.9900004069011,1506.1599934895833,1507.259989420573,1508.2999979654949,1509.269999186198,1510.1699727376301,1510.9999898274739,1511.7699890136719,1512.4700012207031,1513.0999959309895,1513.6699930826824,1514.1700032552083,1514.6000061035156,1514.9700012207031,1515.2699890136719,1515.4999898274739,1515.6600036621094,1515.7599995930989,1515.7899983723958,1515.760009765625,1515.6600036621094,1515.489990234375,1515.2500101725261,1514.9499918619792,1514.5799967447917,1514.1499837239583,1513.6499938964844,1513.0799967447917,1512.4799906412761,1511.8899943033855,1511.2899983723958,1510.6900024414062,1510.1000061035156,1509.5,1508.8899943033855,1508.2899983723958,1507.6800231933594,1507.0799967447917,1506.469991048177,1505.8600056966145,1505.239990234375,1504.6299947102864,1504.010009765625,1503.3899841308594,1502.769999186198,1502.1500040690105,1501.5299886067708,1500.8999837239583,1500.280029296875,1499.6599833170574,1499.0299987792969,1498.3999837239583,1497.7799886067708,1497.1499938964844,1496.519999186198,1495.8900044759114,1495.2699890136719,1494.6400146484375,1494.0099995930989,1493.3799947102864,1492.75,1492.1199951171875,1491.5,1490.8699951171875,1490.2399800618489,1489.6199747721355,1488.990010579427,1488.3600056966145,1487.739990234375,1487.1099955240886,1486.4900004069011,1485.8599955240886,1485.240010579427,1484.6100056966145,1483.990010579427,1483.3700052897136,1482.75,1482.1199849446614,1481.4999898274739,1480.8800048828125,1480.260009765625,1479.6400044759114,1479.0200093587239,1478.4000040690105,1477.7899983723958,1477.1700032552083,1476.5500081380208,1475.9400024414062,1475.3199971516926,1474.709981282552,1474.0899963378906,1473.480000813802,1472.8700052897136,1472.25,1471.6399943033855,1471.0299987792969,1470.4200032552083,1469.8099975585938,1469.1999918619792,1468.5900065104167,1467.980000813802,1467.3800048828125,1466.769999186198,1466.1600036621094,1465.5599975585938,1464.9500020345051,1464.3499959309895,1463.739990234375,1463.1399943033855,1462.5399983723958,1461.9299825032551,1461.3299865722656,1460.730000813802,1460.1300048828125,1459.530008951823,1458.9299926757812,1458.3400065104167,1457.7400004069011,1457.1399943033855,1456.5399881998699,1455.9500122070312,1455.3499959309895,1454.759989420573,1454.1599934895833,1453.5699971516926,1452.9800109863281,1452.3900044759114,1451.7899983723958,1451.2000020345051,1450.6100260416667,1450.0199890136719,1449.4300028483074,1448.8500061035156,1448.2599792480469,1447.6699930826824,1447.0899963378906,1446.5,1445.9100138346355,1445.3300069173176,1444.75,1444.1600036621094,1443.5800170898438,1443.0,1442.4199930826824,1441.8400065104167,1441.259989420573,1440.6800028483074,1440.0999857584636,1439.519999186198,1438.9399820963542,1438.3699951171875,1437.7899881998699,1437.2099914550781,1436.6400146484375,1436.0600077311199,1435.489990234375,1434.9200032552083,1434.3499959309895,1433.7700093587239,1433.1999918619792,1432.6300048828125,1432.0599975585938,1431.4900004069011,1430.9200134277344,1430.3599955240886,1429.7899881998699,1429.219991048177,1428.6600036621094,1428.0899861653645,1427.5299886067708,1426.9600016276042,1426.4000142415364,1425.8400065104167,1425.2799987792969,1424.709981282552,1424.1499938964844,1423.5899861653645,1423.030008951823,1422.480000813802,1421.9199829101562,1421.3599853515625,1420.7999979654949,1420.25,1419.6899820963542,1419.1399943033855,1418.5799865722656,1418.030008951823,1417.4799906412761,1416.9200032552083,1416.3699951171875,1415.8199971516926,1415.2699890136719,1414.7200012207031,1414.1699930826824,1413.6299947102864,1413.0800170898438,1412.5299886067708,1411.9799906412761,1411.4399820963542,1410.8899943033855,1410.3499959309895,1409.8100077311199,1409.260009765625,1408.719991048177,1408.1799926757812,1407.6400044759114,1407.0999959309895,1406.5599873860676,1406.0199788411458,1405.4799906412761,1404.9399820963542,1404.4100036621094,1403.8700052897136,1403.3300069173176,1402.7999979654949,1402.260009765625,1401.730000813802,1401.2000122070312,1400.6599934895833,1400.1300150553386,1399.5999857584636,1399.0699869791667,1398.5400085449219,1398.009989420573,1397.4799906412761,1396.9500122070312,1396.4300028483074,1395.8999938964844,1395.3700052897136,1394.8499959309895,1394.3200073242188,1393.7999979654949,1393.2799987792969,1392.7499898274739,1392.230000813802,1391.7100016276042,1391.1900024414062,1390.6699829101562,1390.1500040690105,1389.6300048828125,1389.1100158691406,1388.5999959309895,1388.0799967447917,1387.5599975585938,1387.0500081380208,1386.5299987792969,1386.0200093587239,1385.5000101725261,1384.990010579427,1384.480000813802,1383.9700012207031,1383.4499918619792,1382.9399922688801,1382.4299926757812,1381.9300028483074,1381.4199930826824,1380.9100036621094,1380.4000040690105,1379.8899943033855,1379.3899943033855,1378.8800048828125,1378.3799947102864,1377.8699951171875,1377.3700052897136,1376.8699951171875,1376.3599955240886,1375.8599955240886,1375.3600056966145,1374.8600260416667,1374.3599853515625,1373.8600056966145,1373.3599955240886,1372.8699849446614,1372.3699951171875,1371.8699849446614,1371.3800048828125,1371.1300048828125};
    HFC125={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2165773692155806e-06,8.557121153292732e-06,1.0061302646136028e-05,1.0390318796756523e-05,1.0719714812997458e-05,1.1049491528562308e-05,1.1379648640286177e-05,1.171018743661989e-05,1.2041107462816095e-05,1.237240955257827e-05,1.1487397311308692e-05,5.5193815645300974e-06,1.075440430516513e-05,1.2755718368377226e-05,1.1691284877694367e-05,3.96903745780719e-06,8.568774148898228e-06,1.2043192891534696e-05,2.903536521140874e-05,3.188543450960424e-05,3.284409467596561e-05,0.002091195086904918,0.03069222376992305,0.09482813626527786,0.19552044942975044,0.32772576560576755,0.4816569561759631,0.6497871528069178,0.8248193363348643,0.9994525363047918,1.2204217116038005,1.603711913029353,1.978332092364629,2.527012268702189,2.9139525095621743,3.5451226830482483,4.231992959976196,4.8289631605148315,5.509383638699849,6.4292839368184405,7.706023693084717,8.963194449742636,10.464804887771606,11.74120569229126,13.946606318155924,15.355007727940878,17.754984617233276,21.18809429804484,23.484392801920574,27.654491901397705,32.42229096094767,37.76749038696289,43.67028967539469,49.88598918914795,56.17848873138428,62.54588921864828,68.9858881632487,75.4966869354248,82.07608731587727,88.72248649597168,95.43378575642903,102.20798619588216,109.0439847310384,115.89598655700684,122.71898587544759,129.5139840443929,136.2829844156901,143.02598571777344,149.74398549397787,156.43998591105142,163.11198298136392,169.7619832356771,176.3919817606608,182.97798538208008,189.49998092651367,195.95998255411783,202.3609822591146,208.70398330688477,214.9899813334147,221.22298304239908,227.40298461914062,233.5329818725586,239.61298116048178,245.61798222859701,251.52198028564453,257.3299814860026,263.0439809163411,268.66698201497394,274.20298767089844,279.6539815266927,285.02298227945965,290.312983194987,295.5269826253255,300.66898345947266,305.7439829508464,310.7549794514974,315.7029800415039,320.59098052978516,325.4199803670247,330.19197845458984,334.9089762369792,339.5719807942708,344.18298085530597,348.74997965494794,353.2809778849284,357.77697499593097,362.2389729817708,366.66697692871094,371.06297810872394,375.4269841512044,379.760981241862,384.0649770100911,388.33897908528644,392.57297770182294,396.7549769083659,400.88798268636066,404.9719721476237,409.00697326660156,412.9949773152669,416.9359766642253,420.8319727579753,424.6839777628581,428.49097951253253,432.2659734090169,436.0179748535156,439.7479756673177,443.45597585042316,447.14198048909503,450.80696868896484,454.4499740600586,458.0719757080078,461.6729736328125,465.2529780069987,468.69897715250653,471.9029719034831,474.86897532145184,477.6029764811198,480.1089782714844,482.39398193359375,484.46297454833984,486.3219757080078,487.9759826660156,489.42997487386066,490.68997446695965,491.76197814941406,492.6499760945638,493.36098225911456,493.8989741007487,494.2689793904622,494.4769770304362,494.5279769897461,494.4259796142578,494.1759770711263,493.78397878011066,493.2539774576823,492.58997599283856,491.79698181152344,490.8789800008138,489.8409779866536,488.68697865804035,487.4209849039714,486.0459849039714,484.5669809977214,482.9879786173503,481.31298065185547,479.54397837320965,477.6849848429362,475.7409845987956,473.7129847208659,471.6059850056966,469.42298126220703,467.16598256429035,464.83797963460285,462.44298299153644,459.9839833577474,457.4619827270508,454.8799819946289,452.24198150634766,449.5489781697591,446.80398813883465,444.0089848836263,441.16598256429035,438.2779820760091,435.3459828694661,432.37398529052734,429.36098225911456,426.3109817504883,423.22498575846356,420.104985555013,416.9529851277669,413.76898701985675,410.5569839477539,407.31697845458984,404.04998779296875,400.7589874267578,397.44398498535156,394.1069869995117,390.74798583984375,387.36998494466144,383.97298940022785,380.5589879353841,377.1269887288411,373.68098704020184,370.218989054362,366.7439905802409,363.25699106852215,359.75699106852215,356.24698638916016,352.72598520914715,349.1949869791667,345.6559880574544,342.1079915364583,338.55298614501953,334.9919891357422,331.42398834228516,327.84999084472656,324.27198537190753,320.68799082438153,317.1009928385417,313.50999450683594,309.9159876505534,306.3189875284831,302.7199935913086,299.11999257405597,295.5169957478841,291.9139912923177,288.3089904785156,284.70399220784503,281.09898630777997,277.49398549397785,273.88999430338544,270.2859929402669,266.68299102783203,263.08098856608075,259.4799982706706,255.8809954325358,252.28399276733398,248.68799209594727,245.0949935913086,241.5039939880371,237.91499201456705,234.32899602254233,230.7449951171875,227.16399256388345,223.58599344889322,220.0119972229004,216.43999481201172,212.87099583943686,209.30599466959634,205.74399439493814,202.18499628702799,198.6309954325358,195.0789934794108,191.53099568684897,187.98699569702148,184.4469960530599,180.90999348958334,177.37699762980142,173.84799448649088,170.32199478149414,166.80099614461264,163.28299713134766,159.76899592081705,156.2599957784017,152.75399907430014,149.2509969075521,145.75299708048502,142.25899505615234,138.76899846394858,135.28199768066406,131.7989985148112,128.32099787394205,124.84599685668945,121.37499936421712,117.9069995880127,114.44399897257487,110.98399988810222,107.5279992421468,104.07599957784016,100.62800025939941,97.18289947509766,93.74179967244466,90.30439949035645,86.93129984537761,83.68120002746582,80.54980087280273,77.53319994608562,74.62750053405762,71.82880020141602,69.13339869181316,66.53769938151042,64.03820006052653,61.63139979044596,59.31409994761149,57.08300050099691,54.9350004196167,52.86710007985433,50.87650012969971,48.9603001276652,47.115699768066406,45.340200424194336,43.631199518839516,41.986300468444824,40.40300019582113,38.87920061747233,37.4127000172933,36.001200358072914,34.64280001322428,33.335400899251304,32.07719977696737,30.866400082906086,29.701199690500896,28.579799969991047,27.50060002009074,26.46209987004598,25.462800184885662,24.500999927520752,23.575599988301594,22.68499994277954,21.82800006866455,21.00339984893799,20.209800084431965,19.446199893951416,18.711300055185955,18.004200140635174,17.32380024592082,16.669099807739258,16.039100011189777,15.432799895604452,14.849499940872192,14.28820006052653,13.747999986012777,13.228300015131632,12.72819995880127,12.247000058492025,11.783900022506714,11.33840004603068,10.909599939982096,10.497100035349527,10.100200096766153,9.718220074971518,9.35069990158081,8.99706999460856,8.656800111134848,8.329380114873251,8.014340003331503,7.711210052172343,7.419529994328816,7.1388799746831255,6.86883004506429,6.60899003346761,6.358969887097676,6.118409991264343,5.886929988861084,5.664210041364034,5.449910044670105,5.243710001309712,5.0453100601832075,4.854399998982747,4.6707199811935425,4.493980050086975,4.323920051256816,4.160300056139628,4.002859989802043,3.8513799905776978,3.705619970957438,3.5653799970944724,3.430449982484182,3.3006100257237754,3.175690015157064,3.055489977200826,2.939839998881022,2.828560014565786,2.7214900056521096,2.6184799671173096,2.5193600058555603,2.423989991346995,2.332229971885681,2.243939995765686,2.158989985783895,2.0772500236829123,1.9986099700133007,1.9229400058587391,1.8501399954160054,1.7800900042057037,1.7126900056997936,1.647839993238449,1.5854500035444896,1.5254200100898743,1.467659999926885,1.4120800097783406,1.3586099743843079,1.3071700036525726,1.257670005162557,1.2100400030612946,1.164220005273819,1.1201299925645192,1.0777100125948589,1.0368900001049042,0.9976250032583872,0.9598420063654581,0.9234899977842966,0.8885129988193512,0.8548609962066015,0.8224829932053884,0.791331003109614,0.7613589962323507,0.7325209975242615,0.7047749906778336,0.6780789891878763,0.6523950000603994,0.6276829987764359,0.6039059907197952,0.5810300062100092,0.5590199927488962,0.5378439972798029,0.5174700071414312,0.49786699811617535,0.4790060023466746,0.4608600015441577,0.44340099891026813,0.4266029993693034,0.41044199963410694,0.39489199966192245,0.3799319962660472,0.36553800106048584,0.3516890009244283,0.33836500098307926,0.3255450005332629,0.31321100393931073,0.30134400228659314,0.28992699831724167,0.2789420038461685,0.26837300260861713,0.25820500155289966,0.24842099845409393,0.2390089991192023,0.22995299970110258,0.22124000142018,0.21285699928800264,0.2047909994920095,0.19703099876642227,0.1895660012960434,0.18238300209244093,0.17547200123469034,0.16882300128539404,0.16242500146230063,0.15627100070317587,0.150348998606205,0.14465200155973434,0.13916999970873198,0.1338970015446345,0.12882299845417342,0.12394100055098534,0.11924399932225545,0.11472600015501182,0.11037799964348476,0.10619499968985717,0.10217100009322166,0.09829909975330035,0.09457399944464366,0.09099000009397666,0.08754180061320464,0.08422430045902729,0.08103250029186408,0.0779617006580035,0.07500720024108887,0.07216460009415944,0.06942979991436005,0.06679870126148064,0.06426720072825749,0.06183159941186508,0.059488399885594845,0.05723389952133099,0.05506489984691143,0.05297810025513172,0.05097030010074377,0.049038700138529144,0.04718019968519608,0.04539220004032055,0.04367189947515726,0.04201689983407656,0.04042449966073036,0.03889250010251999,0.03741859986136357,0.036000500433146954,0.03463610013326009,0.033323499684532486,0.03206059988588095,0.030845599869887035,0.029676600048939388,0.028551900293678045,0.027469899971038103,0.02642880007624626,0.025427200210591156,0.024463600013405085,0.023536500055342913,0.022644500248134136,0.021786299844582874,0.020960699766874313,0.020166300081958372,0.019402099928508203,0.01866680011153221,0.017959400080144405,0.017278799942384165,0.016623900116731722,0.015994000093390543,0.015387800056487322,0.01480470000145336,0.014243600036328038,0.01370390000132223,0.01318450008208553,0.012684900080785155,0.012204200106983384,0.011741699961324533,0.011296700065334639,0.010868599948783716,0.010456799995154142,0.010060500043133894,0.009679249953478575,0.009312450032060346,0.008959560034175714,0.008620039947951833,0.00829338988599678,0.007979120050246516,0.007676760006385545,0.0073858499915028615,0.007105979913224776,0.006836709954465429,0.006577640112179021,0.006328389941093822,0.006206179969012737};
    HFC134a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,7.708864601833436e-05,0.0005449304395976166,0.0077552789346858235,0.07582558194796245,0.19600565483172736,0.36491671949625015,0.6123692641655604,1.649199257294337,3.2318945129712424,5.39930792649587,8.110631505648294,11.121968984603882,14.691894769668579,19.702295621236164,23.51545794804891,27.517083009084065,31.54472287495931,36.60471884409586,40.86165841420492,45.3168420791626,49.719340324401855,52.765931129455566,57.8515370686849,62.84794902801514,67.7508716583252,74.7700621287028,80.51572863260905,84.76873016357422,90.27674547831218,96.15281359354655,101.12263425191243,106.07874488830566,111.01973342895508,115.94567743937175,120.59212239583333,124.71738878885905,128.35975710550943,131.5551643371582,134.33561197916666,136.73210271199545,138.7726287841797,140.48219680786133,141.88477579752603,143.00241216023764,143.93621953328451,144.7761090596517,145.5299924214681,146.2018814086914,146.79878362019858,147.32468795776367,147.78459803263345,148.181516011556,148.52043533325195,148.80436833699545,149.08238983154297,149.40045293172201,149.75349553426108,150.14053853352866,150.55757776896158,151.00261942545572,151.47265116373697,151.96568171183267,152.47970962524414,153.01373418172201,153.5497283935547,154.07471338907877,154.58769353230795,155.08967971801758,155.58166631062826,156.06365331013998,156.53563944498697,156.99863052368164,157.4536158243815,157.89960606892905,158.35763295491537,158.84367497762045,159.35771306355795,159.89574178059897,160.45677439371744,161.03880055745444,161.64082717895508,162.25984827677408,162.8948720296224,163.54389190673828,164.23496627807617,164.9910570780436,165.80913798014322,166.68221028645834,167.60828272501627,168.5813420613607,169.60040918986002,170.66045888264975,171.75851186116537,172.89255650838217,174.06561152140299,175.28167215983072,176.53672409057617,177.82877604166666,179.15281422932944,180.5078582763672,181.8898900349935,183.29692586263022,184.72595342000326,186.17698542277017,187.65602747599283,189.17007700602213,190.71711858113608,192.2941576639811,193.89919662475586,195.52822621663412,197.18025588989258,198.8532854715983,200.54431788126627,202.2523307800293,203.85309219360352,205.23078028361002,206.39650344848633,207.36423619588217,208.14599100748697,208.75275421142578,209.19453557332358,209.48333104451498,209.62613677978516,209.63395818074545,209.51578903198242,209.2776311238607,208.92948277791342,208.4783452351888,207.93021774291992,207.29209645589194,206.56998570760092,205.7698834737142,204.89778518676758,203.95869827270508,202.95661417643228,201.89653778076172,200.78346506754556,199.62039947509766,198.41234079996744,197.16228739420572,195.87423451741537,194.55018742879233,193.19314448038736,191.80710474650064,190.39306767781576,188.95503616333008,187.4950065612793,186.01397959391275,184.51495488484701,182.99993515014648,181.46991348266602,179.92589569091797,178.3708839416504,176.80587005615234,175.23185857137045,173.64984766642252,172.06083806355795,170.46682993570963,168.86782455444336,167.26482137044272,165.65881474812826,164.05081431070963,162.44081115722656,160.8298110961914,159.21881103515625,157.6078109741211,155.9978116353353,154.38781356811523,152.77981440226236,151.17381795247397,149.56982040405273,147.96882502237955,146.36982854207358,144.77483367919922,143.18183390299478,141.59284337361655,140.0068448384603,138.42485173543295,136.84685643513998,135.2728614807129,133.7028694152832,132.13687388102213,130.57487996419272,129.01788520812988,127.46489143371582,125.91589609781902,124.37090174357097,122.8309097290039,121.29491424560547,119.7639217376709,118.23692639668782,116.71493339538574,115.19593620300293,113.68294715881348,112.17294692993164,110.66795794169109,109.16695976257324,107.66996828715007,106.17797533671062,104.68897819519043,103.20498593648274,101.72498766581218,100.24899673461914,98.7765998840332,97.30820528666179,95.84381103515625,94.38321685791016,92.9263203938802,91.47312482198079,90.02353032430013,88.57763608296712,87.13524119059245,85.69624519348145,84.26075045267741,82.82855542500813,81.39975929260254,79.9741636912028,78.55176798502605,77.13257217407227,75.71647707621257,74.30338096618652,72.89318339029948,71.48608716328938,70.08179219563802,68.6802978515625,67.28160031636556,65.88570404052734,64.49240716298421,63.10181109110514,61.71381409962972,60.32831732432047,58.94532044728597,57.564724604288735,56.18652820587158,54.810730934143066,53.43723392486572,52.06603686014811,50.69704023996989,49.3302427927653,47.965545972188316,46.60294882456461,45.24245103200277,43.88395436604818,42.52755641937256,41.172959645589195,39.82036209106445,38.46956411997477,37.120667139689125,35.77366924285889,34.42827129364014,33.084774335225426,31.742876211802166,30.40267848968506,29.064181009928387,27.727283000946045,26.39188512166341,25.05818732579549,23.725889046986897,22.395191351572674,21.06589349110921,19.738094965616863,18.41169786453247,17.086796760559082,15.763204654057821,14.49300773938497,13.324155807495117,12.248574256896973,11.259090503056845,10.34879438082377,9.511601686477661,8.74163031578064,8.033592621485392,7.382558027903239,6.783997615178426,6.233731587727864,5.727890412012736,5.262914419174194,4.835544308026631,4.442749977111816,4.081762154897054,3.750010848045349,3.4451564947764077,3.1650091807047525,2.907589296499888,2.67106693983078,2.453742345174154,2.254055678844452,2.0705971916516623,1.9020468990008037,1.7471950352191925,1.6049317121505737,1.4742370148499806,1.354171097278595,1.2438740034898121,1.1425458788871765,1.0494667887687683,0.9639598280191422,0.885415052374204,0.8132635056972504,0.7469872832298279,0.6861074268817902,0.6301859964927038,0.578819011648496,0.5316355476776758,0.48829563707113266,0.4484873165686925,0.4119216079513232,0.37833554297685623,0.3474871714909871,0.31915150086085003,0.29312555988629657,0.26922136048475903,0.2472649378081163,0.22709831098715463,0.20857648427287737,0.19156348581115404,0.1759383206566175,0.16158600772420564,0.1484055556356907,0.13629897559682527,0.12517928332090378,0.11496648502846558,0.10558658527831237,0.09697199861208598,0.08905982909103234,0.08179298291603725,0.07511876647671063,0.06898898755510648,0.06335925031453371,0.05818875723828872,0.05344001576304436,0.04907872807234526,0.04507319908589125,0.041394531105955444,0.03801592874030272,0.03491309378296137,0.032063328816245,0.029446136361608904,0.027042518990735214,0.02483497823898991,0.02280761720612645,0.02094573558618625,0.019235736845682066,0.017665321628252666,0.016223091321686905,0.014898647166167697,0.013682190096005797,0.012565021558354298,0.011539142346009612,0.010596953021983305,0.009731634830435118,0.00893697856614987,0.00820720405317843,0.007536993051568667,0.006921505439095199,0.0063562620198354125,0.00583717308472842,0.005360459132740895,0.0049226706226666766,0.004520627941625814,0.004151411393346886,0.0038123412523418665,0.0035009579150937498,0.0032150015661803386,0.0029523924846823015,0.0027112408618753157,0.002489766882111629,0.0022863908282791576,0.0020996228364917138,0.0019281030011673768,0.0017705915573363502,0.0016259485855698586,0.001493114201972882,0.0013711385739346345,0.0012591217431084563,0.001156253876009335,0.0010617849766276777,0.0009750342045056944,0.0008953705740471681,0.0008222141817289715,0.0007550340960733593,0.0006933423574082553,0.0006366900245969495,0.0005846651474712417,0.0005368917724505687,0.0004930199332496462,0.00045273368596099317,0.0004157380390097387,0.0003817650431301445,0.0003505677135156778,0.0003219200856013534,0.00029561218252638355,0.00027145402661214274,0.00024926964033511467,0.00022889904357725754,0.0002101912408155234,0.00019301326877515143,0.0001772391248474984,0.00016275383071236624,0.00014945139385721026,0.00013723683635665415,0.00012602015400868064,0.00011572037025568231,0.00010626148165708098,9.757650817239967e-05,8.960094358675026e-05,8.22773102602999e-05,7.555209837543468e-05,6.93765286996495e-05,6.370569493204432e-05,5.849840969555468e-05,5.371667126989147e-05,4.932568905739269e-05,4.529366409163534e-05,4.159120059436342e-05,3.819130051851971e-05,3.5069368702049054e-05,3.220260653809722e-05,2.957011611215421e-05,2.7152801218714256e-05,2.4933062528968247e-05,2.2894802593024604e-05,2.102322332575568e-05,1.930452541879883e-05,1.772631154987418e-05,1.627718180922481e-05,1.4946438871750919e-05,1.3724582989501263e-05,1.2602515046940729e-05,1.1572236492914575e-05,1.0626147892859686e-05,9.75738036383215e-06,8.959654299663574e-06,8.227140597227844e-06,7.554519849387968e-06,6.936882641639386e-06,6.369729400527528e-06,5.848950801616108e-06,5.370747165519181e-06,4.931638917090216e-06,4.5284264539683745e-06,4.1581801042411826e-06,3.818210094171566e-06,3.506026852543679e-06,3.219370626084128e-06,2.956151661237527e-06,2.714450166270884e-06,2.492506249988461e-06,2.2887102962461845e-06,2.101582348738399e-06,1.929752585283495e-06,1.771961194663163e-06,1.6270782718189973e-06,1.4940439522585318e-06,1.3718883546213572e-06,1.259711533900069e-06,1.156713703191296e-06,1.0621348470370624e-06,9.752900732943697e-07,8.955454688930331e-07,8.223200988292471e-07,7.550830218860938e-07,6.933432956657271e-07,6.366509760861542e-07,5.845951089137694e-07,5.367947437662224e-07,4.929039173854713e-07,4.5260066391013726e-07,4.155930308039994e-07,3.8161203264053256e-07,3.504087094559812e-07,3.217570849756157e-07,2.954481862123733e-07,2.7129102875278477e-07,2.491086460073196e-07,2.2873904370612763e-07,2.100362503180501e-07,1.9286227370685083e-07,1.770931336390428e-07,1.6261283638148902e-07,1.4931640516617031e-07,1.3710784330100978e-07,1.2589716528547493e-07,1.1560237744845381e-07,1.0615049224801017e-07,1.6655923455270265e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC143a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,9.679108093981389e-06,6.793739824691632e-05,7.890220331319142e-05,8.037302359298337e-05,8.184554402153783e-05,8.331976338619522e-05,8.637850078230258e-05,0.007432716122517983,0.026895795327921707,0.054136695029834904,0.0849026944488287,0.11494099286695321,0.1399999943872293,0.1600000001490116,0.17999999349315962,0.19999999552965164,0.21999999756614366,0.2599999929467837,0.28999998917182285,0.32999999324480694,0.38999999314546585,0.43999998768170673,0.48999999711910885,0.5199999809265137,0.5699999282757441,0.6399997919797897,0.7599995483954748,0.9399992177883784,1.2099987765153248,1.5299981534481049,1.9399973253409069,2.429996371269226,2.9699952602386475,3.5299941102663674,4.223822851975759,5.00792149702708,5.8813802401224775,6.627838969230652,7.37440820535024,8.326615969340006,9.35536535580953,10.426983912785849,11.92148502667745,12.84508458773295,14.522682428359985,15.25278091430664,16.743229468663532,19.401511351267498,20.73361603418986,23.086318333943684,25.72521988550822,28.644521872202557,31.838222980499268,35.20372327168783,38.640723864237465,42.14782555898031,45.723825772603355,49.367326418558754,53.07722695668539,56.85222816467285,60.69112904866537,64.59282938639323,68.55612881978352,72.5718313852946,76.63113149007161,80.7330322265625,84.87693214416504,89.06203397115071,93.28743362426758,97.55233573913574,101.85603586832683,106.19803682963054,110.57703717549641,114.97803688049316,119.38603846232097,123.80003865559895,128.22103945414224,132.64904022216797,137.0820401509603,141.52204004923502,145.96803919474283,150.42004267374674,154.87704213460287,159.3210423787435,163.73104349772134,168.1080436706543,172.45404179890951,176.76804224650064,181.0520451863607,185.30504353841147,189.53004455566406,193.72604624430338,197.89304478963217,202.04004669189453,206.17204666137695,210.29104868570963,214.39604695638022,218.4880485534668,222.5670483907064,226.6320482889811,230.68504842122397,234.72604751586914,238.75404739379883,242.77205022176108,246.78205108642578,250.78404998779297,254.77704874674478,258.76305135091144,262.74105072021484,266.71205139160156,270.67405192057294,274.6290537516276,278.5760548909505,282.5050532023112,286.40405019124347,290.2740529378255,294.1140492757161,297.9260559082031,301.7090555826823,305.4640528361003,309.19105529785156,312.8910547892253,316.5630569458008,320.2140579223633,323.8500569661458,327.47105407714844,331.0770543416341,334.66905466715497,338.2460581461589,341.80806223551434,345.35505930582684,348.88805898030597,352.4060567220052,355.84605662027997,359.14505767822266,362.30505625406903,365.3270568847656,368.21405537923175,370.96605173746747,373.5870539347331,376.0770543416341,378.43905385335285,380.67505137125653,382.7860565185547,384.7760543823242,386.64505259195965,388.3960494995117,390.0300547281901,391.5510533650716,392.96004994710285,394.258051554362,395.44905344645184,396.53404998779297,397.51404571533203,398.39305369059247,399.1710484822591,399.85204823811847,400.43605041503906,400.9270528157552,401.3250452677409,401.63204701741535,401.852045694987,401.98404184977215,402.03204345703125,401.9970448811849,401.88004302978516,401.68404388427734,401.41104380289715,401.06104278564453,400.6370442708333,400.1410420735677,399.5730438232422,398.936040242513,398.23104095458984,397.4600423177083,396.62504323323566,395.7260386149089,394.7650400797526,393.74403889973956,392.66503651936847,391.52803802490234,390.3350346883138,389.0870361328125,387.7860336303711,386.4330342610677,385.02903238932294,383.57603454589844,382.0750376383464,380.52603403727215,378.93203989664715,377.2930374145508,375.6100387573242,373.8850351969401,372.11903381347656,370.31203206380206,368.4660339355469,366.58203125,364.66103108723956,362.70304107666016,360.7100321451823,358.68302663167316,356.62303415934247,354.53003184000653,352.405029296875,350.249028523763,348.0640284220378,345.8490295410156,343.6070251464844,341.3360290527344,339.0390319824219,336.7160237630208,334.36802927652997,331.9950230916341,329.5980275472005,327.1780293782552,324.7350209554036,322.2710240681966,319.78502655029297,317.2790222167969,314.7520243326823,312.20602162679035,309.6420211791992,307.0590235392253,304.4580256144206,301.84002176920575,299.2050196329753,296.5550231933594,293.88801829020184,291.20601654052734,288.51001993815106,285.79901631673175,283.0740203857422,280.33602142333984,277.58502197265625,274.8210194905599,272.0450134277344,269.25801849365234,266.45801544189453,263.6480127970378,260.82801818847656,257.9960199991862,255.1550153096517,252.30501429239908,249.4440129597982,246.57501220703125,243.6980120340983,240.8110148111979,237.91701126098633,235.015012105306,232.1050148010254,229.1880111694336,226.26401011149088,223.33301289876303,220.3960100809733,217.4520123799642,214.5030059814453,211.5470085144043,208.58600997924805,205.62001037597656,202.64800771077475,199.67100779215494,196.69000879923502,193.70300674438477,190.71300633748373,187.7180061340332,184.71900685628256,181.71600468953451,178.7100067138672,175.70000330607095,172.68600463867188,169.66900507609049,166.6490046183268,163.62700271606445,160.60100428263345,157.57200368245444,154.54100545247397,151.50700251261392,148.47100194295248,145.43300120035806,142.39299901326498,139.34999974568686,136.30599975585938,133.2599983215332,130.24599965413412,127.29799969991048,124.414000193278,121.5930004119873,118.8350003560384,116.1369997660319,113.49899991353352,110.91899998982747,108.39699935913086,105.93099975585938,103.52099990844727,101.16399955749512,98.85989952087402,96.60779889424641,94.4063008626302,92.25429979960124,90.15089988708496,88.09499994913737,86.08550135294597,84.12149874369304,82.20190111796062,80.3257999420166,78.49219957987468,76.70029894510905,74.94890022277832,73.23740005493164,71.56470108032227,69.93010012308757,68.33260091145833,66.77150026957194,65.2459004720052,63.75500075022379,62.2980006535848,60.87429968516032,59.48289998372396,58.12329991658529,56.79469966888428,55.49630037943522,54.22760009765625,52.98780028025309,51.776299476623535,50.59239991505941,49.43550046284994,48.30500030517578,47.200300216674805,46.12080001831055,45.06600030263265,44.035200119018555,43.02800019582113,42.043800354003906,41.08210055033366,40.14229996999105,39.22400029500326,38.326599756876625,37.44980017344157,36.59289995829264,35.75570011138916,34.93759950002035,34.13819948832194,33.35700035095215,32.59369977315267,31.847800254821777,31.11900011698405,30.406800111134846,29.710999965667725,29.0310001373291,28.36650021870931,27.717299938201904,27.082900047302246,26.463000297546387,25.857199827829998,25.265399932861328,24.686999797821045,24.1218999226888,23.569700082143147,23.03010018666585,22.50280014673869,21.98770014444987,21.484300136566162,20.992400010426838,20.511699835459392,20.042099793752033,19.583200136820476,19.13479995727539,18.69660011927287,18.268500169118244,17.850200176239014,17.441399892171223,17.04199981689453,16.651700019836426,16.270400047302246,15.897800048192343,15.533699909845987,15.177899837493896,14.830299933751425,14.490599950154623,14.158700068791708,13.834399859110514,13.517500003178915,13.207899967829386,12.905399878819784,12.609699964523315,12.320899963378906,12.038700024286905,11.762900034586588,11.49340001742045,11.23009999593099,10.972800016403198,10.721499999364218,10.475799878438314,10.23580002784729,10.001299937566122,9.772180080413818,9.548290014266968,9.329519828160604,9.115760087966919,8.906890074412027,8.702809969584147,8.503400007883707,8.308559974034628,8.11817995707194,7.932149926821391,7.75039005279541,7.572789986928304,7.39926000436147,7.229700048764546,7.064030011494954,6.90215003490448,6.743969957033793,6.589420040448506,6.4384100039800005,6.290860056877136,6.146690050760905,6.005819996198018,5.8681700229644775,5.7336799303690595,5.602269967397054,5.473880012830098,5.348420023918152,5.22583011786143,5.106060028076172,4.989029963811238,4.874680002530416,4.76295002301534,4.653780023256938,4.547110001246135,4.442879994710286,4.341040054957072,4.24153999487559,4.144320011138916,4.049319942792256,3.956500013669332,3.865809977054596,3.7771899700164795,3.6906099915504456,3.6060099999109902,3.5233500003814697,3.442580004533132,3.3636600176493325,3.2865599592526755,3.2112199664115906,3.137600004673004,3.0656699935595193,2.995399991671244,2.92672997713089,2.859630008538564,2.7940799792607627,2.730019986629486,2.6674399773279824,2.60629004240036,2.5465399821599326,2.4881499807039895,2.4311099847157798,2.375380019346873,2.320919990539551,2.267710030078888,2.215720017751058,2.1649200518925986,2.115290025870005,2.0668000181516013,2.019409994284312,1.9731099903583527,1.9278799891471863,1.8836799959341686,1.8404900133609772,1.7982900142669678,1.757070004940033,1.716779996951421,1.6774200002352397,1.6389599839846294,1.60139000415802,1.5646699965000153,1.5288000007470448,1.4937500059604645,1.4594999849796295,1.42603999376297,1.3933399816354115,1.3614000082015991,1.3301799992720287,1.2996900180975597,1.2698899904886882,1.240770012140274,1.212330013513565,1.184529999891917,1.157370001077652,1.130840003490448,1.1049099961916606,1.0795799891153972,1.0548300047715504,1.0306399861971538,1.0070100078980129,0.983924999833107,0.961366002758344,0.9393249998490015,0.917789007226626,0.8967470029989878,0.8761870016654333,0.8560990045468012,0.8364710013071696,0.8172930032014847,0.798555001616478,0.7802470028400421,0.7623580098152161,0.7448800007502238,0.7278030018011729,0.7111170093218485,0.6948130031426748,0.6788839995861053,0.6633190015951792,0.6481119990348816,0.6332529981931051,0.6187349955240885,0.6045500040054321,0.5906900018453598,0.5771480003992716,0.5639160027106603,0.5509879936774572,0.5383570045232773,0.5260139952103297,0.5139550020297369,0.5021730040510496,0.4906600018342336,0.4794119993845622,0.4684220030903816,0.4576830019553502,0.4471909950176875,0.4369389961163203,0.4269229993224144,0.42197200159231824};
    //HFC152a={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8166002058090576e-06,2.253280149489001e-05,4.5065603141362466e-05,6.75984044088788e-05,9.013120567639514e-05,0.00011266400724707637,0.0001351968094240874,0.00015772960978210904,0.00018026241256544986,0.0002027952141361311,0.0022496851888718084,0.019787868252024055,0.04636244600017866,0.08110567430655162,0.12386019838352998,0.17620285227894783,0.23694131150841713,0.3071838468313217,0.387410931289196,0.5997305264075597,0.8197319408257803,0.9299358030160269,1.0798835754394531,1.3595912953217824,1.539625773827235,2.1079475581645966,2.3026039203008017,2.9008639256159463,3.488562067349752,3.886517286300659,4.6503645579020185,5.463509798049927,5.803807258605957,6.857228636741638,7.076026717821757,7.47403355439504,7.894731958707173,8.037666201591492,8.094252268473307,7.732658425966899,7.473873655001323,7.644769748051961,7.675466020901998,7.679547429084778,7.670038183530171,7.653460065523784,7.633288621902466,7.551548043886821,7.3779200712839765,7.156467874844869,6.9100520213445025,6.6504156192143755,6.383626659711202,6.112817128499349,5.839595198631287,5.5648205280303955,5.288856307665507,5.056444923082988,4.891088167826335,4.760454018910726,4.647631764411926,4.543886820475261,4.444628874460856,4.347516099611918,4.25130307674408,4.155376374721527,4.0594108899434405,3.9797688722610474,3.9251266519228616,3.883536994457245,3.8486544489860535,3.817198932170868,3.787435988585154,3.7584747076034546,3.7298242648442588,3.7012343406677246,3.672584354877472,3.644492487112681,3.6173006097475686,3.5905001163482666,3.5638298988342285,3.5371400515238443,3.5103602409362793,3.4834705789883933,3.4564307729403176,3.4292315244674683,3.401871065298716,3.3779499530792236,3.3593983252843223,3.3436644474665322,3.3293515841166177,3.3157406051953635,3.302440027395884,3.2892698844273887,3.276099900404612,3.262870272000631,3.2495698730150857,3.2399179538091025,3.2359455823898315,3.234961668650309,3.2355283300081887,3.2368973096211753,3.238636533419291,3.240546405315399,3.242506265640259,3.2444563706715903,3.24635640780131,3.249013841152191,3.2528812487920127,3.2573007345199585,3.261950135231018,3.2666502793629966,3.271310329437256,3.275890588760376,3.2803707917531333,3.284731149673462,3.288981258869171,3.294646362463633,3.3025715152422586,3.311640202999115,3.3212787906328836,3.3311687707901,3.341138402620951,3.351108650366465,3.3610385855038962,3.3708975513776145,3.3806795676549277,3.3825670282046,3.3722405433654785,3.355142335096995,3.33421927690506,3.311073342959086,3.2865758538246155,3.261227468649546,3.235308587551117,3.2089993556340537,3.182409882545471,3.1556203365325928,3.1286606391270957,3.1015908320744834,3.0744409759839377,3.047231078147888,3.019991139570872,2.992741127808889,2.965511123339335,2.938291072845459,2.911110977331797,2.88397083679835,2.856900672117869,2.829890549182892,2.8029603560765586,2.7761101921399436,2.749339997768402,2.7226697405179343,2.6960995395978293,2.66961932182312,2.643259028593699,2.616998811562856,2.5908485452334085,2.5648082892100015,2.5388680696487427,2.5130577882130942,2.4873475631078086,2.461757262547811,2.4362870256106057,2.410916785399119,2.3856665094693503,2.3605262835820517,2.3354960481325784,2.3105857570966086,2.285785496234894,2.261085311571757,2.236495018005371,2.2120147943496704,2.187634547551473,2.163364311059316,2.139194071292877,2.1151338617006936,2.091163625319799,2.067293385664622,2.043513208627701,2.019832988580068,1.9962527354558308,1.9727625747521718,1.949362337589264,1.9260521531105042,1.9028219481309254,1.879681756099065,1.8566315372784932,1.8336613774299622,1.8107711970806122,1.7879609962304432,1.7652308245499928,1.7425706684589386,1.719990462064743,1.697480320930481,1.6750501294930775,1.6526899834473927,1.6303998132546742,1.6081796785195668,1.5860195259253185,1.5639293491840363,1.5419092277685802,1.519939124584198,1.49803892771403,1.4761988123257954,1.454418659210205,1.4326985379060109,1.411038378874461,1.3894382615884144,1.3678881327311199,1.346388041973114,1.3249478737513225,1.3035478095213573,1.2822076479593914,1.2609175542990367,1.2396873831748962,1.2184973259766896,1.1973472038904827,1.176247109969457,1.1551969647407532,1.1341869036356609,1.113226741552353,1.0923067033290863,1.0714265902837117,1.050586501757304,1.0297863880793254,1.009026323755582,0.9883052110671997,0.9676261196533839,0.9469820360342661,0.9263749519983927,0.9058018823464712,0.885263795653979,0.8647637069225311,0.8442986259857813,0.8238645493984222,0.8034614821275076,0.783090407649676,0.7627503275871277,0.7424412568410238,0.7221651673316956,0.7019201169411341,0.681701049208641,0.6615099757909775,0.6413459132115046,0.621208851536115,0.6011027693748474,0.581023707985878,0.5609676589568456,0.540936604142189,0.5209295352300009,0.5009464770555496,0.48098741968472797,0.461055355767409,0.4411473075548808,0.42126025011142093,0.40139420330524445,0.3815491497516632,0.3617260952790578,0.3419260357817014,0.32214898119370144,0.3023899445931117,0.28264889617760974,0.26292784512043,0.24322580049435297,0.2235417552292347,0.2038796991109848,0.1842376527686914,0.16461161648233733,0.14500156790018082,0.12540954040984312,0.10583345654110114,0.08627692051231861,0.06673837763567765,0.04721494329472383,0.027704331713418167,0.013266104506328702,0.006342573440633714,0.0030319815462765596,0.0014478040005390842,0.0006911888849572279,0.00032969493137594935,0.00015722561571844076,7.492675952865586e-05,3.569866369919813e-05,1.6999006447804277e-05,8.09294158443663e-06,3.851087020242024e-06,1.832262123950083e-06,8.713942776239492e-07,4.14363796608086e-07,1.9696823490752044e-07,4.819495498982936e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC227ea={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,5.745499576104152e-09,4.596399853321979e-08,9.192799588220169e-08,1.3789199471148095e-07,1.8385599176440337e-07,2.298199900015637e-07,2.757839894229619e-07,3.2174798529164644e-07,3.6771198589728254e-07,4.136759793974913e-07,4.5963998474007894e-07,5.056039735033361e-07,5.515679741089722e-07,5.975319747146083e-07,6.434959753202444e-07,6.894599664519774e-07,7.354239623206619e-07,7.81387962926298e-07,8.273519635319341e-07,8.733159641375702e-07,9.192799552693032e-07,9.652439748227455e-07,1.011207928058866e-06,1.0571719712970662e-06,1.1031359387440414e-06,1.149099944086629e-06,1.195063968377023e-06,1.2410279168761917e-06,1.286991960114392e-06,1.3329559275613672e-06,1.3789199329039548e-06,1.4248839571943488e-06,1.4708479056935175e-06,1.5168119489317178e-06,1.562775925852596e-06,1.6087399217212806e-06,1.6547039554855776e-06,1.7006678945108433e-06,1.7466319377490436e-06,1.7925959146699217e-06,1.8385599105386063e-06,1.8845239443029034e-06,1.930487997015007e-06,1.976451850775144e-06,2.022415856117732e-06,2.068379899355932e-06,2.1143439425941324e-06,2.1603079858323326e-06,2.20627183959247e-06,2.2522358449350577e-06,2.298199888173258e-06,2.344163931411458e-06,2.3901279746496584e-06,2.4360918284097957e-06,2.4820558337523835e-06,2.5280198769905837e-06,2.573983920228784e-06,2.6199479634669842e-06,2.665911836174928e-06,2.7118758225697093e-06,2.7578398658079095e-06,2.8038039090461098e-06,2.84976795228431e-06,2.8957318249922537e-06,2.941695811387035e-06,2.9876598546252353e-06,3.0336238978634356e-06,3.079587941101636e-06,3.1255518138095795e-06,3.171515800204361e-06,3.217479843442561e-06,3.2634438866807614e-06,3.3094079299189616e-06,3.3553718026269053e-06,3.4013357890216867e-06,3.447299832259887e-06,3.493263875498087e-06,3.5392279187362874e-06,3.585191791444231e-06,3.6311557778390124e-06,3.6771198210772127e-06,3.723083864315413e-06,3.769047907553613e-06,3.815011799209363e-06,3.860975766656338e-06,3.9069398098945385e-06,3.952903853132739e-06,3.998867896370939e-06,4.044831939609139e-06,4.0907959828473395e-06,4.136759950294315e-06,4.182723614576389e-06,4.228687657814589e-06,4.2746517010527896e-06,4.32061574429099e-06,4.36657978752919e-06,4.41254383076739e-06,4.4585078740055906e-06,4.504471917243791e-06,4.550435960481991e-06,4.5963999279289664e-06,4.642363592211041e-06,4.688327635449241e-06,4.734291678687441e-06,4.780255721925641e-06,4.826219765163842e-06,4.872183808402042e-06,4.918147851640242e-06,4.964111894878442e-06,5.010075938116643e-06,5.05603994345923e-06,5.102003569845692e-06,5.1479676130838925e-06,5.193931656322093e-06,5.239895699560293e-06,5.285859742798493e-06,5.3318237860366935e-06,5.377787829274894e-06,5.423751872513094e-06,5.469715915751294e-06,5.515679921093882e-06,5.561643547480344e-06,5.607607590718544e-06,5.653571633956744e-06,5.699535677194945e-06,5.745499720433145e-06,5.791463763671345e-06,5.837427806909545e-06,5.8833918501477456e-06,5.929355893385946e-06,5.975319936624146e-06,6.0212835251149954e-06,6.067247568353196e-06,6.113211611591396e-06,6.159175654829596e-06,6.205139698067796e-06,6.251103741305997e-06,6.297067784544197e-06,6.343031827782397e-06,6.388995871020597e-06,6.434959914258798e-06,6.480923502749647e-06,6.526887545987847e-06,6.5728515892260475e-06,6.618815632464248e-06,6.664779675702448e-06,6.710743718940648e-06,6.7567077621788485e-06,6.802671805417049e-06,6.848635848655249e-06,6.894599891893449e-06,6.9405635182799115e-06,6.986527523622499e-06,7.032491566860699e-06,7.078455610098899e-06,7.1244196533371e-06,7.1703836965753e-06,7.2163477398135e-06,7.2623117830517e-06,7.308275826289901e-06,7.354239869528101e-06,7.400203495914563e-06,7.4461675012571504e-06,7.492131544495351e-06,7.538095587733551e-06,7.584059630971751e-06,7.630023560523114e-06,7.675987490074476e-06,7.721951533312676e-06,7.767915576550877e-06,7.813879619789077e-06,7.859843663027277e-06,7.905807706265477e-06,7.951771749503678e-06,7.997735792741878e-06,8.043699835980078e-06,8.089663500262153e-06,8.135627467709128e-06,8.181591510947328e-06,8.227555554185528e-06,8.273519597423729e-06,8.319483640661929e-06,8.365447683900129e-06,8.41141172713833e-06,8.45737577037653e-06,8.50333981361473e-06,8.549303477896805e-06,8.59526744534378e-06,8.64123148858198e-06,8.68719553182018e-06,8.73315957505838e-06,8.77912361829658e-06,8.82508766153478e-06,8.871051704772981e-06,8.917015748011181e-06,8.962979791249381e-06,9.008943455531456e-06,9.054907422978431e-06,9.100871466216631e-06,9.146835509454831e-06,9.192799552693032e-06,9.238763595931232e-06,9.284727639169432e-06,9.330691682407632e-06,9.376655725645833e-06,9.422619768884033e-06,9.468583508957332e-06,0.0006875001223913083,0.0025000001187436283,0.005062500150719036,0.008000000069538752,0.010937500201786557,0.01350000019495686,0.015312500220413009,0.016000000139077503,0.016000000139077503,0.011000000056810677,0.0030000001109632044,0.0020000001228860733,0.011000000212031106,0.017000000225380063,0.01700000014776985,0.018000000156462193,0.022000000191231567,0.02000000032906731,0.014000000199303031,0.014000000121692816,0.017000000070159633,0.026000000691662233,0.0330000047882398,0.03700000451256832,0.04200000377992789,0.04900001051525275,0.06000001293917497,0.07300002624591191,0.08600003769000371,0.10600005090236664,0.132000050197045,0.15900006766120592,0.1890000912050406,0.23300011828541756,0.28500013550122577,0.3600001533826192,0.4300001785159111,0.5000001961986223,0.5700002362330755,0.650000254313151,0.7400002578894297,0.8300002614657084,0.9300002753734589,1.0056702643632889,1.0911712447802226,1.2003816664218903,1.2800614635149639,1.3833015064398448,1.4924715757369995,1.6073916753133137,1.7279016772905986,1.8495916724205017,1.9682416915893555,2.0839216709136963,2.196731686592102,2.306771695613861,2.4141116937001548,2.518841723601023,2.6210416754086814,2.720781703790029,2.81814173857371,2.913021683692932,3.005341728528341,3.0951716899871826,3.1825817028681436,3.267631689707438,3.350401679674784,3.4309417406717935,3.509321709473928,3.585601727167765,3.659831702709198,3.73233171304067,3.803391714890798,3.873051722844442,3.9413517117500305,4.008321781953176,4.07401172320048,4.138441761334737,4.2016518115997314,4.2636717557907104,4.32453175385793,4.383391817410787,4.439441680908203,4.492761731147766,4.543431679407756,4.591511607170105,4.637081702550252,4.680211702982585,4.7209616502126055,4.759401559829712,4.795591553052266,4.82975161075592,4.862081567446391,4.892651597658793,4.9214915831883745,4.948641538619995,4.974161624908447,4.9980915784835815,5.020461519559224,5.041311581929524,5.060691595077515,5.078921556472778,5.09632150332133,5.112911581993103,5.128701567649841,5.143731514612834,5.1580015023549395,5.171531518300374,5.184351483980815,5.19646139939626,5.207881490389506,5.2186814943949384,5.228891611099243,5.238541444142659,5.247621496518453,5.256151556968689,5.264151453971863,5.271611491839091,5.278541485468547,5.284971515337626,5.290891448656718,5.296451449394226,5.301801482836406,5.306941469510396,5.311861435572307,5.31658148765564,5.321091492970784,5.325401425361633,5.329501549402873,5.333401481310527,5.337101459503174,5.340131441752116,5.341991464296977,5.3426915009816485,5.3422614733378095,5.3406914075215655,5.338001410166423,5.334211508433024,5.329351305961609,5.323421359062195,5.31645139058431,5.308451334635417,5.299461364746094,5.289491335550944,5.278571367263794,5.266721328099568,5.25395127137502,5.24031130472819,5.225791295369466,5.21044127146403,5.194281299908956,5.177321195602417,5.159601251284282,5.141131281852722,5.1219412088394165,5.102041244506836,5.081461191177368,5.0602312088012695,5.038361191749573,5.015881220499675,4.992801149686177,4.969151139259338,4.944951176643372,4.92021111647288,4.894951105117798,4.869201103846232,4.842971086502075,4.816281080245972,4.789151032765706,4.761601010958354,4.733631094296773,4.705281019210815,4.6765410502751665,4.647441069285075,4.618001023928325,4.588231086730957,4.558140993118286,4.527741074562073,4.497060934702556,4.46609099706014,4.434860944747925,4.403380990028381,4.371660947799683,4.33971095085144,4.307540973027547,4.275160908699036,4.24259090423584,4.2098308801651,4.176890850067139,4.14379088083903,4.1105209191640215,4.077110926310222,4.043550888697307,4.009860833485921,3.976050853729248,3.942120830217997,3.9080708424250283,3.873930811882019,3.839680810769399,3.8053508003552756,3.7709407409032187,3.7364407777786255,3.7018807331720986,3.6672407587369285,3.6325507164001465,3.5978007117907205,3.5630006988843284,3.528160730997721,3.493270695209503,3.4583506981531777,3.4233906666437783,3.3884106874465942,3.353400707244873,3.3183706601460776,3.283320645491282,3.2482606371243796,3.2131906350453696,3.178110639254252,3.1430306235949197,3.1079405744870505,3.072860598564148,3.0377805829048157,3.0027005672454834,2.9676305651664734,2.932570517063141,2.897530515988668,2.862500548362732,2.8274805148442588,2.7924905021985373,2.757510503133138,2.722560485204061,2.6876304745674133,2.6527204314867654,2.6178404688835144,2.582980453968048,2.548160433769226,2.5133604208628335,2.478590428829193,2.443860431512197,2.4091503818829856,2.374480366706848,2.3398403922716775,2.3052403926849365,2.2706703543663025,2.2361403107643127,2.201650341351827,2.1671902934710183,2.1327703396479287,2.098390301068624,2.064050257205963,2.029740273952484,1.9954702655474346,1.961250255505244,1.9270602564016979,1.8929102619489033,1.858800232410431,1.8247302174568176,1.7907002369562786,1.756720205148061,1.7227701842784882,1.6888601779937744,1.6549901763598125,1.6211601595083873,1.5873801708221436,1.553630143404007,1.519920140504837,1.4862601359685261,1.4526301225026448,1.4190401136875153,1.3854901095231373,1.3519800901412964,1.3185100952784221,1.2850800553957622,1.2516900499661763,1.2183400392532349,1.1850200394789379,1.1517500380674999,1.118510017792384,1.0853000084559123,1.0521399974822998,1.0190099974473317,0.9864170004924139,0.9548349976539612,0.924235999584198,0.894595002134641,0.8658840010563532,0.838074987133344,0.8111430009206136,0.7850610017776489,0.7598049988349279,0.7353499929110209,0.7116720030705134,0.6887470036745071,0.6665520121653875,0.6450649996598562,0.6242639968792597,0.6041280080874761,0.584636002779007,0.5657690018415451,0.5475059996048609,0.5298289954662323,0.5127190003792444,0.49615900218486786,0.48013099531332654,0.4646179974079132,0.44960400213797885,0.43507400155067444,0.4210110033551852,0.4074010004599889,0.3942290047804515,0.38148200015227,0.3691460018356641,0.3572079986333847,0.34565500169992447,0.3344749982158343,0.32365499436855316,0.3131839980681737,0.3030519982179006,0.2932470018664996,0.2837580020229022,0.27457599838574726,0.26568999886512756,0.2570920040210088,0.24877099692821503,0.24071899925669035,0.23292700201272964,0.22538800040880838,0.21809099987149239,0.21103099981943765,0.20419899995128313,0.19758799920479456,0.19119100024302801,0.18499999990065893,0.17901000007987022,0.17321300134062767,0.167603999376297,0.16217700019478798,0.15692499900857607,0.15184199810028076,0.14692499985297522,0.14216599985957146,0.1375609996418158,0.13310599823792776,0.1287940007944902,0.1246219997604688,0.1205850001424551,0.11667899911602338,0.1128990004460017,0.1092410000662009,0.10570199973881245,0.10227799850205581,0.09896380081772804,0.09575730003416538,0.09265460011859734,0.08965230050186317,0.08674729987978935,0.08393630137046178,0.08121629990637302,0.07858430035412312,0.07603759877383709,0.07357339995602767,0.07118900120258331,0.06888180039823055,0.06664929973582427,0.06448900078733762,0.06239879969507456,0.06037630016605059,0.05841919997086128,0.056525600142776966,0.05469329934567213,0.052920300203065075,0.051204800295333065,0.0495448000729084,0.04793869983404875,0.046384500029186405,0.04488069967677196,0.04342570000638565,0.042017699840168156,0.040655399983127914,0.039337199491759144,0.038061799481511116,0.036827699902156986,0.03563350004454454,0.03447809970627228,0.03336010004083315,0.03227829995254675,0.031231599859893322,0.03021879990895589,0.029238799742112558,0.028290600050240755,0.027373199972013634,0.026485399963955086,0.02562649982670943,0.024795300016800564,0.023991199986388285,0.023212999881555636,0.022460200047741335,0.021731700127323467,0.02102680007616679,0.02034479969491561,0.019684900374462206,0.019046399897585314,0.018428600238015253,0.017830800109853346,0.01725239974136154,0.016692700019727152,0.0161512002038459,0.0156272998234878,0.015120399960627159,0.014629799872636795,0.01415519998408854,0.01369599997997284,0.013251700050507983,0.012821799997861186,0.012405799857030312,0.012003299857800206,0.011613899997125069,0.011237100077172121,0.010872499939675132,0.010519699892029166,0.010178400048365196,0.009848180071761211,0.009528639959171414,0.009219470201060176,0.008920330088585615,0.008630890166386962,0.00835083999360601,0.008079869827876488,0.007817689989072582,0.0075640199550737934,0.0073185700457543135,0.007081089968172212,0.006851309988026817,0.006628989979314308,0.006413879959533612,0.006205740035511553,0.006004359961176912,0.005809509971489509,0.005620990026121338,0.00543858006130904,0.0052620799979195,0.005091320024803281,0.004926090012304485,0.004766230044576029,0.004611549976592262,0.004461890086531639,0.004317089954080681,0.004176980039725701,0.004041419946588576,0.003910259945162882,0.0037833599878164628,0.0036605699957969287,0.0035417700031151376,0.0034268200009440384,0.003315600003891935,0.0032079999994797013,0.0031038800176853933,0.003003139999539902,0.0029056699907717607,0.002811369971216967,0.002720119974886378,0.002631839985648791,0.0025464200104276338,0.0024637700019714734,0.0023838000100416443,0.002306429979701837,0.0022315700189210474,0.002159139975750198,0.0020890600474861762,0.0020212600162873664,0.0019556599921391657,0.001892180007416755,0.0018307699938304722,0.001771339981739099,0.0017138500018821408,0.0016582199993232887,0.0016044000221882015,0.0015523299904695402,0.0015019399870652705,0.0014531899845072378,0.0014060199998008709,0.0013603900054780145,0.00131622997772259,0.0012735099880956113,0.0012321700050961226,0.0011921800032723695,0.0011534799996297807,0.001116039997820432,0.001079819999479999,0.0010447699848252039,0.001010860006014506,0.000978050001625282,0.0009463040041737258,0.0009155890002148226,0.0008858710013252372,0.0008571169989105935,0.0008292970014736056,0.0008023800037335604,0.0007763360093425339,0.0007511379953939468,0.0007267580028080071,0.0007031689892755821,0.0006803460031126937,0.000658264005323872,0.0006368980054200316,0.0006162260057559857,0.0005962249997537583,0.0005768730043200776,0.0005581500008702278,0.0005400339966096605,0.0005225060012890026,0.0005055469955550507,0.0004891389932405824,0.0004732630040962249,0.00045790199995584163,0.00044304000281651196,0.00042866100314616534,0.00041474800430781517,0.0004012870025083733,0.0003882630019991969,0.0003756619989871979,0.00036346899772373337,0.0003516729945355716,0.00034025900095002726,0.0003292160011672725,0.00031853099790168926,0.0003081929971813224,0.00029819099775825936,0.00028851299672775593,0.0002837539990044509};
    HFC23={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0008387752144093005,0.00510867650154978,0.0013775627594441175,0.0006616643853097534,0.0007192010428601255,0.0007817409447549531,0.0008497191738570109,0.0009236086334567517,0.0010039232001872733,0.0010912219295278192,0.0011861117285055418,0.0012892556163327147,0.0014013840700499713,0.0015232670799984287,0.0016557506072179724,0.00179975672896641,0.0019562874901263663,0.002126432334383329,0.0023113751861577234,0.002512403065338731,0.0027309151094717285,0.003054187574889511,0.006885135274690886,0.02087512387273212,0.04651178978383541,0.08213070034980774,0.1274599153548479,0.1822890266776085,0.2464121406277021,0.3196182499329249,0.40169936915238696,0.49244747559229535,0.5916525920232137,0.699107696612676,0.814602812131246,0.9379299183686575,1.0688820282618205,1.2072421511014302,1.352812260389328,1.505382388830185,1.6647424797217052,1.830672601858775,2.0029827058315277,2.181452830632528,2.365882933139801,2.556043048699697,2.7517531315485635,2.9527832667032876,3.1589433749516806,3.3700035015741983,3.7300036549568176,4.130003849665324,4.560003956158956,4.970003763834636,5.270004232724507,5.530004461606343,5.8700045347213745,6.3100047906239825,6.710005084673564,7.220005750656128,7.7600061893463135,8.280006090799967,8.820006291071573,9.340006430943808,9.94000768661499,10.600008169809977,11.270008246103922,11.990008195241293,12.750008503595987,13.540009021759033,14.300010919570923,15.120010137557983,15.880009412765503,16.560010592142742,17.260011196136475,18.06001361211141,18.97001536687215,20.050018151601154,21.274523735046387,22.006818771362305,22.658213933308918,23.296514352162678,24.134215990702312,24.988317330678303,26.02762222290039,26.890435059865315,27.946349143981934,28.906192779541016,29.84339475631714,30.62699604034424,31.20109748840332,31.56669855117798,31.724599202473957,31.77099911371867,31.80199893315633,31.81739902496338,31.817299524943035,31.80199925104777,31.771299521128338,31.725399017333984,31.66439978281657,31.588199774424236,31.49709955851237,31.397799809773762,31.297399520874023,31.19589964548747,31.09309959411621,30.989199956258137,30.88409964243571,30.777900060017902,30.67039982477824,30.561800003051758,30.45199998219808,30.341199556986492,30.229700088500977,30.11739985148112,30.004499753316242,29.89079999923706,29.776299953460693,29.661100069681805,29.545199712117512,29.428500016530354,29.311100006103516,29.193299929300945,29.075500011444092,28.95769993464152,28.839999834696453,28.72219975789388,28.604399998982746,28.486699899037678,28.368899822235107,28.251099745432537,28.1332000096639,28.01549990971883,27.898100058237713,27.7809001604716,27.664000034332275,27.54730002085368,27.43080012003581,27.314600149790447,27.198599974314373,27.082900047302246,26.967300256093342,26.852099895477295,26.737199783325195,26.622700214385986,26.50860007603963,26.39489984512329,26.28150002161662,26.168400128682453,26.055699825286865,25.943399906158447,25.83140007654826,25.71969985961914,25.608399868011475,25.49750010172526,25.386899948120117,25.276700178782146,25.16689984003703,25.057400067647297,24.948200066884358,24.839399655659992,24.730900287628174,24.622700373331707,24.51480007171631,24.407300154368084,24.30010000864665,24.19319995244344,24.08660014470418,23.980300108591717,23.874300003051758,23.76859998703003,23.663200219472248,23.558099905649822,23.453500270843506,23.349299907684326,23.245500087738037,23.14199988047282,23.038899898529053,22.93620014190674,22.833800156911213,22.73169994354248,22.62999979654948,22.528500080108643,22.42739995320638,22.326599915822346,22.226200262705486,22.125999927520752,22.026099999745686,21.92650016148885,21.827199935913086,21.72820011774699,21.629499912261963,21.531099637349445,21.432999928792317,21.335100015004475,21.237600167592365,21.14040009180705,21.043400287628174,20.946699778238933,20.85039981206258,20.754299958546955,20.658499876658123,20.563000202178955,20.46779998143514,20.372899850209553,20.278300126393635,20.18399985631307,20.08999999364217,19.996299902598064,19.902899901072185,19.809800306955974,19.716999848683674,19.624500115712483,19.532299995422363,19.44039996465047,19.34879986445109,19.257500171661377,19.166600068410236,19.075900236765545,18.985599835713703,18.895500024159748,18.80580012003581,18.716400146484375,18.62730010350545,18.53849983215332,18.45010010401408,18.361900329589844,18.274099985758465,18.18660020828247,18.09939972559611,18.012500286102295,17.925900141398113,17.83970006306966,17.75379991531372,17.668199857076008,17.582899888356526,17.497999986012776,17.413300037384033,17.328999837239582,17.245000044504803,17.161399841308594,17.077999750773113,16.995000044504803,16.912299791971844,16.830000082651775,16.74790032704671,16.666199843088787,16.584800084431965,16.50369993845622,16.4229998588562,16.342600345611572,16.262499809265137,16.182699998219807,16.10330041249593,16.024200042088825,15.94539999961853,15.866899967193604,15.788799921671549,15.710899909337362,15.633400122324625,15.556300004323324,15.479400078455607,15.402900060017904,15.32669997215271,15.250799973805746,15.17520006497701,15.099999984105429,15.025000095367432,14.95039987564087,14.876199881235758,14.802200078964233,14.72849996884664,14.655199925104776,14.582200050354004,14.50950002670288,14.437100092569986,14.365099986394247,14.29330007235209,14.22189998626709,14.150800069173178,14.080000003178915,14.00950002670288,13.939299980799357,13.869499921798706,13.79990005493164,13.730699936548868,13.661799907684326,13.593200047810873,13.524800062179565,13.456799983978271,13.389100074768066,13.321700096130371,13.254700104395548,13.187899986902872,13.121400038401285,13.055200020472208,12.989300012588501,12.923799991607666,12.858499924341837,12.793499946594238,12.72890011469523,12.664499759674072,12.60039989153544,12.53659995396932,12.473100105921427,12.409900108973185,12.346999883651733,12.28440006573995,12.222100098927816,12.160099903742472,12.098300059636435,12.03689988454183,11.97570006052653,11.91480008761088,11.854300022125244,11.79390001296997,11.73390007019043,11.674200057983398,11.614700078964233,11.55560008684794,11.496699968973795,11.437999884287516,11.37970002492269,11.321599960327148,11.263699928919474,11.20610006650289,11.14869999885559,11.091599941253662,11.034800052642822,10.97819995880127,10.921799898147583,10.865800142288208,10.81000010172526,10.7543998559316,10.699099858601889,10.644100030263266,10.589399894078573,10.534899870554606,10.480699936548868,10.42679993311564,10.373100121816,10.319700082143148,10.266500075658163,10.213599999745687,10.1610000928243,10.10859990119934,10.05649995803833,10.004699945449829,9.953119993209839,9.90179991722107,9.85074003537496,9.79994010925293,9.749399979909262,9.69911003112793,9.649080117543539,9.599299987157186,9.549779971440634,9.500500043233236,9.451480070749918,9.40271004041036,9.354180097579956,9.305909951527914,9.257870038350424,9.210089921951294,9.16254989306132,9.115249872207642,9.068190018335978,9.021369934082031,8.974799950917562,8.928460041681925,8.882359902064005,8.836490074793497,8.790860017140707,8.745460033416748,8.700300057729086,8.655369997024536,8.610659996668497,8.566189924875895,8.521949927012125,8.477929989496866,8.434139966964722,8.390570084253946,8.347220102945963,8.304100036621094,8.261199951171875,8.218520005544027,8.17606004079183,8.133820056915283,8.091790040334066,8.049980163574219,8.008389949798584,7.9670000076293945,7.925829966862996,7.884879986445109,7.844129999478658,7.803589979807536,7.763260006904602,7.723140041033427,7.683220028877258,7.643510023752849,7.604010025660197,7.56470004717509,7.525600035985311,7.486700018246968,7.447999993960063,7.409500002861023,7.37120000521342,7.33309006690979,7.295180002848308,7.2574699719746905,7.219950000445048,7.182620008786519,7.1454799969991045,7.108539978663127,7.07177996635437,7.0352199872334795,6.9988400141398115,6.962649941444397,6.926650007565816,6.890829960505168,6.855199893315633,6.81974999109904,6.784480055173238,6.7493899663289385,6.714490016301473,6.679760018984477,6.645219961802165,6.610849976539612,6.57665999730428,6.542639970779419,6.5087999900182085,6.4751399755477905,6.441639979680379,6.40831995010376,6.3751799662907915,6.342199961344401,6.30938998858134,6.27675998210907,6.244289994239807,6.211979985237122,6.179849982261658,6.147879997889201,6.116069992383321,6.084430019060771,6.0529599984486895,6.021640062332153,5.990489999453227,5.959490021069844,5.928659995396932,5.897989948590596,5.867470026016235,5.837109963099162,5.806910037994385,5.776869932810466,5.746969978014628,5.71724001566569,5.687659978866577,5.658219973246257,5.6289500792821245,5.599819978078206,5.570839921633403,5.542009949684143,5.513339996337891,5.484810034434001,5.456419984499614,5.428189992904663,5.400090018908183,5.3721500635147095,5.344350020090739,5.31669004758199,5.289170026779175,5.2618000109990435,5.234570066134135,5.2074800332387285,5.1805299917856855,5.153719981511434,5.1270400285720825,5.100510001182556,5.0741099913914995,5.047850012779236,5.0217199722925825,4.99573000272115,4.969870050748189,4.944150010744731,4.918560067812602,4.893099983533223,4.867779970169067,4.842580000559489,4.817519982655843,4.792580008506775,4.767770012219747,4.743100047111511,4.718540032704671,4.694119970003764,4.669820070266724,4.645649989446004,4.621599952379863,4.5976799329121905,4.573880036671956,4.5502099593480425,4.526650031407674,4.503220001856486,4.479910055796306,4.456720034281413,4.433649977048238,4.410700082778931,4.387870033582051,4.365150014559428,4.342559973398845,4.320079962412517,4.297720034917195,4.275469938913981,4.253339966138204,4.231319983800252,4.209409952163696,4.1876200040181475,4.165949980417888,4.14438001314799,4.122929970423381,4.101580063501994,4.080350001653035,4.0592299699783325,4.038209994633992,4.01730998357137,3.9965100089708963,3.9758299787839255,3.955239991346995,3.9347700277964273,3.9143999814987183,3.8941400051116943,3.873980005582174,3.8539199829101562,3.833969990412394,3.8141199747721353,3.794380009174347,3.774740000565847,3.7552000085512796,3.735759993394216,3.716419994831085,3.697179992993673,3.678040007750193,3.658999959627787,3.640060007572174,3.6212199926376343,3.6024700005849204,3.583820025126139,3.5652700066566467,3.5468100110689798,3.5284499724706015,3.510190010070801,3.492019991079966,3.4739399751027427,3.4559600353240967,3.438069979349772,3.4202699859937034,3.4025699893633523,3.3849500020345054,3.3674299915631614,3.349999984105428,3.3326600193977356,3.315410037835439,3.2982500195503235,3.2811699708302817,3.2641900181770325,3.247289995352427,3.2304800152778625,3.2137599984804788,3.1971299846967063,3.1805800199508667,3.164110004901886,3.155899981657664};
    //HFC236fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.8551592201608855e-08,5.143359173113519e-05,0.00018703098430705722,0.00037873797555221245,0.000598499973420985,0.0008182619543125232,0.0010099699672233935,0.0011455699665627133,0.0011969999274394165,0.0011969999177381396,0.0011969998886343092,0.0011969998692317556,0.0011969998498292018,0.0011969998207253714,0.0011969998110240947,0.0011969998013228178,0.0011969997722189873,0.0011969997722189873,0.0011969997431151569,0.0011969997140113264,0.0011969996558036655,0.0011969993453628074,0.0011969986905266221,0.0023939970415085554,0.0023939924237007895,0.004787987621966749,0.007181984217216571,0.009575980560233196,0.013166976937403282,0.01675797354740401,0.021545969415456057,0.02633396613722046,0.0323189627379179,0.038303960114717484,0.04428895656019449,0.05027395269523064,0.06103514631589254,0.06637563804785411,0.07467263316114743,0.08400674847265084,0.09050125194092591,0.09668212756514549,0.1114909400542577,0.12175094212094943,0.130570899695158,0.14046627407272658,0.14906380449732146,0.15918883929649988,0.17047482977310816,0.1829508145650228,0.1966107984383901,0.21144679312904677,0.22710878401994705,0.2432467763622602,0.25985777129729587,0.27694376558065414,0.2944997549057007,0.3125237549344699,0.3310137465596199,0.34996873637040454,0.36938473333915073,0.3892597258090973,0.40958471596241,0.4303497125705083,0.45155470569928485,0.47319569687048596,0.4952706918120384,0.5177776863177618,0.540715679526329,0.5640806704759598,0.5878726691007614,0.612088660399119,0.6366996566454569,0.6616796453793844,0.687025636434555,0.712734634677569,0.7388046334187189,0.7652376194794973,0.7920296142498652,0.8191796094179153,0.8466856082280477,0.8745436072349548,0.9026875992616018,0.9310485869646072,0.9596275935570399,0.9884215841690699,1.0174295703570049,1.046649565299352,1.0760895709196727,1.1057495673497517,1.1356095572312672,1.1656795640786488,1.1959695518016815,1.2264895538489025,1.2572395205497742,1.2882095475991566,1.31940953930219,1.3508395552635193,1.3824795285860698,1.4143495361010234,1.4464395145575206,1.4787495235602062,1.5112995008627574,1.544099509716034,1.5771594842274983,1.6104694803555806,1.6440294881661732,1.6778394877910614,1.7118994692961376,1.7462094724178314,1.780759463707606,1.8155594666798909,1.8505894641081493,1.8858294586340587,1.9212794502576191,1.9569394290447235,1.992799441019694,2.0288694302241006,2.065149466196696,2.101629455884298,2.138309379418691,2.17518945535024,2.212279419104258,2.249609410762787,2.2871594031651816,2.324929396311442,2.362929383913676,2.4011493921279907,2.4395894010861716,2.4782594045003257,2.517129381497701,2.5562293330828347,2.595169405142466,2.6335894068082175,2.6714794039726257,2.7088393767674765,2.7456893920898438,2.782009402910868,2.8178094029426575,2.853089372316996,2.8878494103749595,2.9220994313557944,2.9558194080988565,2.989039440949758,3.0217394630114236,3.053919474283854,3.085599402586619,3.1167694330215454,3.1474194725354514,3.1775794625282288,3.2072294553120932,3.2363794644673667,3.265019476413727,3.2931694785753884,3.3208194573720298,3.347979426383972,3.374649484952291,3.4008194406827292,3.4265094796816506,3.451699515183767,3.476419528325399,3.5006494919459024,3.524399518966675,3.547669529914856,3.5704694986343384,3.5927895307540894,3.6146395206451416,3.636019508043925,3.656929532686869,3.6773694952329,3.697359561920166,3.7168795466423035,3.7359395623207092,3.754549523194631,3.772699554761251,3.7903995712598166,3.807649612426758,3.824449578921,3.840799570083618,3.8567195534706116,3.8721895615259805,3.8872196078300476,3.901809573173523,3.9159796039263406,3.929709573586782,3.943009614944458,3.95587956905365,3.968319614728292,3.980349600315094,3.9919496377309165,4.003129601478577,4.013899604479472,4.02424959341685,4.034199595451355,4.043729583422343,4.052849690119426,4.061569650967916,4.069879651069641,4.077799677848816,4.085309664408366,4.092429677645366,4.099149703979492,4.105479717254639,4.111419717470805,4.116969625155131,4.122139652570088,4.126919706662496,4.1313298145929975,4.135349631309509,4.138989686965942,4.1422596375147505,4.1451497077941895,4.147679726282756,4.149839758872986,4.151619752248128,4.15304974714915,4.154099782307942,4.154799739519755,4.155149777730306,4.155129750569661,4.1547597249348955,4.154039740562439,4.152959744135539,4.151539762814839,4.14976982275645,4.147659778594971,4.14519989490509,4.142399748166402,4.139269789059957,4.135789752006531,4.131979823112488,4.127839763959249,4.123369773228963,4.1185697714487715,4.113439838091533,4.10798982779185,4.102209766705831,4.096109787623088,4.08968981107076,4.082949837048848,4.075899879137675,4.0685298045476275,4.060849825541179,4.052849809328715,4.044549783070882,4.035949905713399,4.027029911677043,4.01781980196635,4.008299867312114,3.9984798630078635,3.9883598486582437,3.9779399037361145,3.9672398765881858,3.956239898999532,3.944939911365509,3.9333598812421164,3.921489894390106,3.9093299309412637,3.8968799312909446,3.884159882863363,3.8711499174435935,3.8578699032465615,3.844299932320913,3.8304599126180015,3.816339910030365,3.801949918270111,3.7872899572054544,3.7723599870999656,3.757159948348999,3.74168994029363,3.725949982802073,3.709959924221039,3.6936999559402466,3.677179972330729,3.6603999535242715,3.643359959125519,3.6260599891344705,3.6085099975268045,3.590710004170736,3.5726600090662637,3.554349978764852,3.535800019900004,3.5171599785486856,3.4985999862353006,3.4801299969355264,3.461740016937256,3.443440020084381,3.42521995306015,3.4070900082588196,3.389039993286133,3.3710800210634866,3.3532100121180215,3.3354300061861673,3.3177300294240317,3.3001299699147544,3.28260999917984,3.2651700178782144,3.247830013434092,3.2305699785550437,3.213399966557821,3.1963200171788535,3.179329991340637,3.1624200145403543,3.145599981149038,3.1288700103759766,3.1122299830118814,3.0956700245539346,3.0791899959246316,3.0628099838892617,3.046500007311503,3.0302899877230325,3.0141500433286033,2.9981099565823874,2.982139984766642,2.966260015964508,2.95046999057134,2.934749980767568,2.9191200335820517,2.903570016225179,2.888099988301595,2.8727199832598367,2.8574100335439048,2.8421899875005088,2.827049990495046,2.8119800090789795,2.797000010808309,2.7820900082588196,2.7672699888547263,2.7525200049082437,2.73785001039505,2.72325998544693,2.708739976088206,2.6942999561627707,2.6799399852752686,2.6656599839528403,2.6514500180880227,2.637310008207957,2.6232500076293945,2.6092599829037986,2.5953500270843506,2.5815200209617615,2.567750016848246,2.5540600419044495,2.5404399832089744,2.52688999970754,2.513419985771179,2.5000100135803223,2.486679971218109,2.473420004049937,2.460230012734731,2.4471099972724915,2.434060017267863,2.4210700194040933,2.4081600109736123,2.3953199783960977,2.382539987564087,2.369829992453257,2.357189973195394,2.344610015551249,2.3321099877357483,2.319660007953644,2.307289977868398,2.294979989528656,2.2827400167783103,2.2705599864323935,2.2584399978319802,2.2463900248209634,2.234410027662913,2.2224799593289695,2.2106199661890664,2.19883002837499,2.1870999932289124,2.1754200061162314,2.163819988568624,2.1522699991861978,2.140779991944631,2.12936004002889,2.117990036805471,2.106689989566803,2.095450003941854,2.0842600067456565,2.07314000527064,2.0620699922243753,2.0510700345039368,2.04012002547582,2.0292299588521323,2.018400033315023,2.007630010445913,1.996909995873769,1.9862500131130219,1.9756500124931335,1.9651000102361043,1.954610009988149,1.9441799918810527,1.9337999920050304,1.9234700004259746,1.9132000009218852,1.9029900133609772,1.8928300142288208,1.8827200035254161,1.8726699948310852,1.8626699944337208,1.8527299960454304,1.8428399960199993,1.8329999943574269,1.8232099910577138,1.8134800096352894,1.803790012995402,1.794160008430481,1.7845799922943115,1.7750499844551086,1.7655700047810872,1.7561499973138173,1.7467699845631917,1.7374399900436401,1.72815998395284,1.7189300159613292,1.7097599804401398,1.7006199955940247,1.6915399928887684,1.682509998480479,1.6735199987888336,1.6645900110403697,1.6557000080744426,1.6468600034713745,1.6380599836508434,1.629310021797816,1.620609998703003,1.6119500001271565,1.6033499936262767,1.594780017932256,1.586269994576772,1.5777900119622548,1.5693700015544891,1.5609799722830455,1.552649994691213,1.544349988301595,1.5361100037892659,1.5279000004132588,1.5197400053342183,1.5116199851036072,1.503550002972285,1.495519995689392,1.4875300029913585,1.4795799851417542,1.4716799954573314,1.4638200004895527,1.455999990304311,1.4482199748357136,1.4404899974664052,1.4327900211016338,1.425139993429184,1.4175300101439159,1.4099599917729695,1.4024299879868825,1.3949299852053325,1.3874800006548564,1.3800700008869171,1.3727000057697296,1.3653700053691864,1.3580699861049652,1.3508199950059254,1.3436000049114227,1.3364300032456715,1.3292899827162425,1.3221899966398876,1.315120001633962,1.308100014925003,1.3011099894841511,1.294159968694051,1.28725000222524,1.2803700069586437,1.2735299865404766,1.2667300005753834,1.259959985812505,1.2532300055027008,1.2465400099754333,1.2398800055185955,1.2332500120004017,1.22667000691096,1.2201099892457326,1.2136000096797943,1.2071100076039631,1.2006600002447765,1.1942500074704487,1.1878699858983357,1.1815299987792969,1.1752100189526875,1.168940007686615,1.1626900136470795,1.1564799944559734,1.150299996137619,1.1441600024700165,1.1380499800046284,1.1319700082143147,1.1259200274944305,1.1199099918206532,1.1139200031757355,1.1079699993133545,1.102050006389618,1.0961700081825256,1.0903100073337555,1.0844900111357372,1.0786900023619335,1.0729300181070964,1.0672000050544739,1.0615000029404957,1.0558300117651622,1.0501900017261505,1.0445800026257832,1.0390000144640605,1.0334499975045521,1.0279300212860107,1.0224400063355763,1.0169799824555714,1.0115499993165333,1.00614000360171,1.0007699926694233,0.9954239974419276,0.9901069949070612,0.9848180015881857,0.9795579959948858,0.9743260045846304,0.9691219925880432,0.9639449963967005,0.9587970028320948,0.9536760002374649,0.9485819985469183,0.9435150027275085,0.9384760061899821,0.935962994893392};
    HFC245fa={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,4.148790035666631e-06,2.9456416086759418e-05,0.0002597141228761757,0.002832789449409271,0.06715815638502438,0.23797391975919405,0.46645688513914746,0.7066208471854528,0.9124758193890253,1.0804997682571411,1.2225398023923237,1.3827498058478038,1.555159757534663,1.750789761543274,1.9295397400856018,2.047369738419851,2.2239372928937278,2.4407403667767844,2.6266002853711448,2.8790802558263144,3.1593303084373474,3.46379025777181,3.789330303668976,4.117210328578949,4.4311502774556475,4.732960383097331,5.024230360984802,5.306350270907084,5.580510377883911,5.847760399182637,6.109020312627156,6.365070382754008,6.616610407829285,6.863950332005818,7.107390443483989,7.347410400708516,7.584450403849284,7.8188804388046265,8.051010449727377,8.28113047281901,8.509470462799072,8.736240466435751,8.961610476175943,9.184610605239868,9.404340585072836,9.621220509211222,9.835570573806763,10.047700564066568,10.257900635401407,10.46630048751831,10.673200686772665,10.878600597381592,11.082900524139404,11.283100605010986,11.47700055440267,11.665300687154135,11.848700761795044,12.027800639470419,12.203100601832071,12.375100692113241,12.544200499852499,12.71060061454773,12.874800682067871,13.037400643030802,13.199000676472982,13.359700679779053,13.519600550333658,13.678800662358602,13.837400515874227,13.99540082613627,14.152800718943277,14.309700727462769,14.466100772221884,14.623000780741373,14.781100670496622,14.940400838851929,15.100600798924765,15.261600653330484,15.423300743103027,15.585500637690226,15.74820081392924,15.911300738652548,16.07460101445516,16.23710076014201,16.3978009223938,16.556700547536213,16.713900566101074,16.869700749715168,17.02400080362956,17.1769011815389,17.328500747680664,17.47900104522705,17.62830098470052,17.777201016743977,17.92660093307495,18.076300779978435,18.22620089848836,18.376200993855793,18.526100953420002,18.67600107192993,18.825800736745197,18.975300788879395,19.12460120519002,19.256200631459553,19.354601224263508,19.423300902048748,19.46570110321045,19.484501202901203,19.482401212056477,19.46160093943278,19.42430067062378,19.372200806935627,19.307100931803387,19.230300903320312,19.143300851186115,19.047200520833332,18.94300079345703,18.831700960795086,18.71410083770752,18.591100533803303,18.463200569152832,18.331100940704346,18.195400555928547,18.05650043487549,17.91480080286662,17.770700613657635,17.624601046244305,17.47680075963338,17.327600479125977,17.177100499471027,17.025700728098553,16.87350066502889,16.72070089975993,16.56740077336629,16.41390069325765,16.260101000467937,16.106200695037842,15.952300707499186,15.798500776290894,15.644800662994385,15.491400559743246,15.338200569152832,15.185400565465292,15.03290065129598,14.880800565083822,14.729200681050619,14.578000545501709,14.427300612131754,14.277000665664673,14.127300500869751,13.978200515111288,13.829500675201416,13.681400616963705,13.533800601959229,13.386800607045492,13.240400632222494,13.094500462214151,12.949200550715128,12.80440060297648,12.660200595855713,12.516500473022461,12.373300552368164,12.230700492858887,12.088700453440348,11.947100480397543,11.806100606918335,11.665600538253784,11.525600671768188,11.38610045115153,11.247100512186686,11.108500639597574,10.970500389734903,10.832900444666544,10.695800383885702,10.55910038948059,10.422900517781576,10.287200450897217,10.151800314585367,10.016900539398193,9.882410367329916,9.748320500055948,9.614630381266275,9.481340328852335,9.348440567652384,9.215920448303223,9.083770275115967,8.951990365982056,8.820560455322266,8.68949023882548,8.558760404586792,8.428370396296183,8.298310279846191,8.168580373128256,8.039170225461325,7.910070379575093,7.781290372212728,7.652800401051839,7.524610320727031,7.396710316340129,7.269100308418274,7.1417603095372515,7.014700333277385,6.887900312741597,6.761370301246643,6.635100285212199,6.509080211321513,6.383300185203552,6.25777022043864,6.132480223973592,6.0074102481206255,5.882580280303955,5.757980267206828,5.633590261141459,5.509420235951741,5.385470191637675,5.261720220247905,5.138180216153462,5.014830231666565,4.891680200894673,4.768730203310649,4.645960211753845,4.523380080858867,4.400980154673259,4.27875022093455,4.156700174013774,4.034820159276326,3.9131001830101013,3.791560153166453,3.6701701283454895,3.548940141995748,3.4278701146443686,3.3069501320521035,3.1861801544825235,3.0655500888824463,2.9450801412264505,2.8247401316960654,2.7045401136080423,2.584480067094167,2.4645500977834067,2.344750086466471,2.225080053011576,2.1055400570233664,1.9861200451850891,1.866830050945282,1.7476400434970856,1.6285800337791443,1.5096400380134583,1.390800009171168,1.272080014149348,1.1534700095653534,1.034969985485077,0.9165730029344559,0.7982819924751917,0.6881480018297831,0.5931220004955927,0.5111509958902994,0.44045399874448776,0.37949400146802265,0.3269369999567668,0.2816319987177849,0.24258400003115335,0.2089339978992939,0.17993799845377603,0.15495600178837776,0.1334339982519547,0.1148950004329284,0.09892630018293858,0.08517289968828361,0.07332830006877582,0.06312830032159884,0.05434509987632433,0.04678219991425673,0.040270499574641384,0.03466410003602505,0.0298373995659252,0.02568210009485483,0.02210490017508467,0.01902559989442428,0.01637490000575781,0.014093200055261454,0.012129199923947453,0.010438699973747134,0.00898374003979067,0.0077314199491714435,0.006653569949169953,0.005725910033409794,0.004927519980507593,0.004240409975561003,0.0036490599741227925,0.0031401499873027205,0.0027021799663392207,0.0023252800068197152,0.0020009300011831024,0.0017217999945084255,0.0014815999893471599,0.0012749000064407785,0.0010970199946314096,0.000943960995452168,0.0008122469977630923,0.0006989060057094321,0.0006013769937756782,0.0005174539910512976,0.0004452390009343314,0.0003830999946027684,0.0003296320016185443,0.0002836239994697583,0.00024403599915482724,0.00020997200044803321,0.000180661998456344,0.00015544299822067842,0.00013374300033319741,0.0001150720011840652,9.900689959370841e-05,8.518430028440586e-05,7.329100056570799e-05,6.305800009916614e-05,5.425339986686595e-05,4.667790017265361e-05,4.01600991608575e-05,3.4552099956878614e-05,2.9727099748318626e-05,2.557579970622707e-05,2.2004099870779708e-05,1.893110008192404e-05,1.6287199969156063e-05,1.401249998404334e-05,1.2055400020472007e-05,1.0371600031551983e-05,8.9229500493578e-06,7.676599958964895e-06,6.604320030116166e-06,5.681790033425689e-06,4.888100041474293e-06,4.20526998823334e-06,3.617799980778121e-06,3.112400008831173e-06,2.6775799900254547e-06,2.303510029832978e-06,1.9816799958031575e-06,1.7048199936198216e-06,1.4666200058854884e-06,1.2617099969247647e-06,1.0854200051350442e-06,9.33755994007394e-07,8.032830010051839e-07,6.910379966029723e-07,5.944750019655961e-07,5.114040012207018e-07,4.3994000028154307e-07,3.7846000348433034e-07,3.255710036379848e-07,2.80073000643218e-07,2.409309978190777e-07,2.0725999879308196e-07,1.7829300228792513e-07,1.5337500040383625e-07,1.319379983044655e-07,1.1349800151568464e-07,3.419102334589752e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    HFC32={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.1742572836890304e-07,2.539405793792563e-06,5.078811454950483e-06,7.618217182425724e-06,1.0157622909900965e-05,1.2697028751063044e-05,1.5236434516433897e-05,1.7775840206013527e-05,2.0315245971384382e-05,2.2854651888337685e-05,2.539405750212609e-05,2.7933463115914492e-05,3.0472869184450246e-05,3.301227479823865e-05,3.5551680412027054e-05,3.809108632898036e-05,4.063049224593366e-05,4.316989755655717e-05,4.570930377667537e-05,4.824870908729887e-05,5.078811530741708e-05,5.332752031487568e-05,5.586692683815878e-05,5.840633214878229e-05,6.094573836890049e-05,6.348514337635909e-05,6.60245495964773e-05,6.85639552102657e-05,7.110336143038391e-05,7.364276643784251e-05,7.618217265796072e-05,7.872157827174912e-05,8.126098449186732e-05,8.380038949932593e-05,8.633979571944413e-05,8.887920133323253e-05,9.141860694702093e-05,9.395801256080934e-05,9.649741878092755e-05,9.903682439471595e-05,0.00010157623000850435,0.00010411563562229276,0.00010665504184241097,0.00010919444745619937,0.00011173385246365797,0.00011427325929010597,0.00011681266429756458,0.00011935207051768278,0.00012189147552514139,0.0001244308817452596,0.0001269702879653778,0.0001295096929728364,0.0001320490991929546,0.0001345885054130728,0.0001371279092078718,0.0001396673166406496,0.00014220672286076783,0.00014474612665556683,0.00014728553408834463,0.00014982493909580322,0.00015236434531592144,0.00015490375032338002,0.00015744315654349825,0.00015998256276361644,0.00016252196777107505,0.00016506137277853364,0.00016760078021131145,0.00017014018521877006,0.00017267959022622867,0.00017521899765900648,0.00017775840266646506,0.00018029780767392367,0.00018283721389404187,0.0001853766201141601,0.00018791602512161867,0.0001904554313417369,0.00019299483634919548,0.0001955342437819733,0.0001980736475767723,0.0002006130537968905,0.00020315246122966832,0.00020569186502446732,0.00020823127124458551,0.0002107706774647037,0.00021331008247216232,0.00021584948869228052,0.00021838889491239874,0.00022092829991985732,0.00022346770613997555,0.00022600711114743413,0.00022854651736755235,0.00023108592358767055,0.00023362532859512916,0.00023616473481524736,0.00023870414103536555,0.00024124354483016455,0.00024378295105028278,0.0002463223596957202,0.0002488617634905192,0.00025140116971063736,0.0002539405759307556,0.0002564799797255546,0.0002590193835203536,0.0002615587945911102,0.0002640981983859092,0.0002666376021807082,0.0002691770132514648,0.0002717164146209446,0.0002742558184157436,0.00027679522706118104,0.0002793346332812992,0.0002818740370760982,0.00028441344572153565,0.0002869528519416538,0.00028949225331113365,0.0002920316595312518,0.00029457106817668927,0.00029711047197148827,0.00029964987819160643,0.0003021892868370439,0.0003047286906318429,0.00030726809200132266,0.00030980750307207927,0.00031234690686687827,0.00031488631066167727,0.0003174257217324339,0.0003199651255272329,0.0003225045293220319,0.0003250439355421501,0.0003275833417622683,0.0003301227455570673,0.0003326621542025047,0.0003352015604226229,0.0003377409642174219,0.0003402803704375401,0.00034281977665765834,0.00034535918045245734,0.0003478985866725755,0.00035043799531801295,0.00035297739911281195,0.0003555168053329301,0.00035805621155304834,0.00036059561534784734,0.00036313501914264634,0.00036567443021340296,0.00036821383400820196,0.00037075323780300096,0.00037329264887375757,0.00037583205024323735,0.00037837145403803635,0.0003809108626834738,0.00038345026890359196,0.00038598967269839096,0.0003885290813438284,0.0003910684875639466,0.0003936078889334264,0.0003961472951535446,0.000398686703798982,0.000401226107593781,0.0004037655138138992,0.00040630492245933664,0.00040884432625413564,0.00041138373004893464,0.00041392313869437203,0.00041646254248917103,0.00041900194628397003,0.00042154135735472664,0.00042408076114952564,0.00042662016494432464,0.00042915957358976203,0.00043169897738456103,0.00043423838117936003,0.0004367777898247975,0.00043931719604491565,0.00044185659983971465,0.0004443960084851521,0.0004469354122799511,0.0004494748160747501,0.00045201422229486826,0.0004545536309403057,0.0004570930347351047,0.0004596324409552229,0.0004621718496006603,0.0004647112509701401,0.0004672506547649391,0.0004697900658356957,0.0004723294696304947,0.0004748688734252937,0.00047740828449605033,0.00047994768829084933,0.0004824870896603291,0.00048502649830576655,0.00048756590210056555,0.0004901053131713221,0.0004926447145408019,0.0004951841207609201,0.0004977235318316767,0.0005002629332011566,0.0005028023394212747,0.0005053417504920313,0.0005078811470108727,0.000510420553230991,0.0005129599594511092,0.0005154993656712273,0.0005180387718913456,0.0005205781781114638,0.000523117584331582,0.0005256569905517002,0.0005281963967718184,0.0005307358029919366,0.0005332752092120548,0.000535814615432173,0.0005383540216522912,0.0005408934278724095,0.0005434328243912508,0.0005459722354620075,0.0005485116416821256,0.0005510510430516055,0.0005535904541223621,0.0005561298603424802,0.0005586692617119601,0.0005612086727827167,0.0005637480790028349,0.0005662874803723147,0.0005688268914430713,0.0005713662976631895,0.0005739056990326693,0.0016515196378653247,0.005856849117359768,0.01262219933172067,0.021451599275072415,0.031974499113857746,0.04382059909403324,0.05661919961373011,0.06999999843537807,0.08999998929599921,0.1699999620517095,0.2699999349812667,0.3899999012549718,0.5027138615647951,0.8247378170490265,1.275769790013631,1.6065597534179688,2.1004197100798288,2.7087196509043374,3.002319614092509,3.920989453792572,5.171979467074077,5.6421693166097,7.50248924891154,8.336968978246054,9.834507067998251,12.709800879160563,13.159700552622477,13.852500200271606,13.745100259780884,12.978800137837728,11.670699914296469,10.231200059254965,8.997730096181234,7.933380126953125,7.007880051930745,6.196370085080464,5.478399991989136,4.837220112482707,4.259050011634827,3.732580045859019,3.248519996802012,2.821810007095337,2.4647600054740906,2.1649800340334573,1.912300020456314,1.6983500123023987,1.5162800053755443,1.360430012146632,1.2261600097020466,1.109660009543101,1.007780020435651,0.9186840107043585,0.8408420085906982,0.7722660054763159,0.7113160192966461,0.656644011537234,0.6071410129467646,0.561899001399676,0.5201659997304281,0.4813140059510867,0.44483400384585065,0.41147000590960187,0.38183900713920593,0.3552870030204455,0.33127200106779736,0.3093410034974416,0.2891260012984276,0.270323005815347,0.25268300498525303,0.23599700505534807,0.2200970028837522,0.20533200105031332,0.19199300309022269,0.17983200152715048,0.16864300270875296,0.1582570026318232,0.14853300154209137,0.1393550025920073,0.13062200074394545,0.12225700169801712,0.1141990019629399,0.10666600055992603,0.0998350027948618,0.0935839017232259,0.08781270124018192,0.08243880172570546,0.07739320149024327,0.07261940029760201,0.0680701012412707,0.06370640111466248,0.05950140114873648,0.05556150060147047,0.0519755007699132,0.04868840084721645,0.04564910102635622,0.042815600211421646,0.04015280089030663,0.03763180070867141,0.03522860072553158,0.032923300129671894,0.03069940038646261,0.028532900537053745,0.02640920039266348,0.024321300443261862,0.022263300449897844,0.020230400376021862,0.018223900347948074,0.01623969990760088,0.014268999841685096,0.012310000058884421,0.01036110008135438,0.008583449991419911,0.007110189995728433,0.005889130057767034,0.004877069965004921,0.00403827001961569,0.0033430999998624125,0.0027670200021627047,0.002289699992009749,0.0018942599805692832,0.001566720010790353,0.0012954699923284352,0.0010708900032720219,0.0008849949954310432,0.0007311539908793444,0.000603875999028484,0.0004986029938057376,0.00041155600047204643,0.0003395989988348447,0.000280134995894817,0.00023101000018262616,0.00019043800178527212,0.00015694100026545735,0.00012929500007885508,0.00010648400105613594,8.766920048704681e-05,7.21555000685233e-05,5.936780022845293e-05,4.883059985634949e-05,4.015079988069677e-05,3.300320016326926e-05,2.7119400177374093e-05,2.227749973826576e-05,1.829429993449594e-05,1.5018599924587761e-05,1.2325499938015128e-05,1.0112299984636289e-05,8.293899971552795e-06,6.800430014664016e-06,5.574199993437408e-06,4.567709993352764e-06,3.74184999903567e-06,3.064399985911829e-06,2.5088699923495974e-06,2.053460017729473e-06,1.6807399939959093e-06,1.3757899921529315e-06,1.1258599859805447e-06,9.210840090645434e-07,7.5334700966323e-07,6.15990998653615e-07,5.035449935538357e-07,4.1151700950573894e-07,3.362220037198919e-07,2.7463198648547404e-07,2.242680020951108e-07,1.830939950764332e-07,1.4944300611811437e-07,1.2194601180700224e-07,5.227322930068112e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        //HFC365mfc={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,8.593750105016322e-05,0.0003124999990783787,0.0006328129966277629,0.0009999999989910673,0.0013671900087501854,0.001687499995265777,0.0019140600246222068,0.0019999999882808575,0.001000000006267025,5.107808434938003e-05,0.00012761924275158285,0.00026965544202539604,0.0029999999581680945,0.005000000004656613,0.003999999995964269,0.0009999999941404287,0.0030000000745834163,0.0030000005305434265,0.0030000010544123747,0.005000001498653243,0.008000002048599223,0.0050000026628064615,0.0010666858239953096,0.002012556239302891,0.00400000410930564,0.002013620309298858,0.004000423466398691,0.01000000579127421,0.011000006149212519,0.013000006632258495,0.019000007305294275,0.030000012057522934,0.060000043672819935,0.12000008982916673,0.21000011265277863,0.32000014930963516,0.41000018020470935,0.4322652171055476,0.4763352448741595,0.5346282621224722,0.5557872851689657,0.6353292663892111,0.6930242776870728,0.7650303095579147,0.8708427498737971,0.9575240612030029,1.028480052947998,1.0967500607172649,1.1626000603040059,1.2262900869051616,1.2880400816599529,1.3439800540606182,1.3906900684038799,1.429240067799886,1.4605600933233898,1.4854800601800282,1.5047200520833333,1.5189400613307953,1.5286900500456493,1.5344900786876678,1.536780059337616,1.537180056174596,1.5371300478776295,1.536670058965683,1.5358400642871857,1.5346600612004597,1.5331700642903645,1.5314000844955444,1.5293600658575695,1.527070055405299,1.5245600541432698,1.5225400527318318,1.521650065978368,1.5217700600624084,1.5227700769901276,1.5245400667190552,1.527000069618225,1.5300600628058116,1.533640056848526,1.5376800696055095,1.542130062977473,1.5467100540796916,1.5511600573857625,1.555510054032008,1.559750070174535,1.5639100670814514,1.567970057328542,1.5719500581423442,1.5758500695228577,1.57968008518219,1.5834400554498036,1.5874300599098206,1.5919200778007507,1.5968600610891979,1.6021800637245178,1.6078400711218517,1.6138100822766621,1.6200400690237682,1.62649005651474,1.633150080839793,1.6399900615215302,1.6474000811576843,1.6557600498199463,1.6649500528971355,1.6748800873756409,1.685470054546992,1.6966400841871898,1.7083200812339783,1.7204600671927135,1.7329900761445363,1.7458800574143727,1.759180059035619,1.7729600667953491,1.7871400614579518,1.8016800781091054,1.8165200650691986,1.8316300710042317,1.8469700813293457,1.8625100751717885,1.878200074036916,1.894040087858836,1.910140077273051,1.926620066165924,1.9434300859769185,1.9605300923188527,1.9778700868288677,1.9954300820827484,2.013170083363851,2.0310600797335305,2.0490800937016806,2.0672000845273337,2.083510100841522,2.096280058224996,2.10586009422938,2.1125600735346475,2.1166900793711343,2.118480106194814,2.118190069993337,2.116020083427429,2.11216006676356,2.106800119082133,2.100070079167684,2.0921400785446167,2.083120067914327,2.0731201171875,2.062260111172994,2.050640066464742,2.038320084412893,2.0254001021385193,2.011940062046051,1.9980000654856365,1.983640064795812,1.9689100682735443,1.9538600941499074,1.9385300874710083,1.9229500691095989,1.9071700771649678,1.8912000755469005,1.8750800589720409,1.858830064535141,1.842480073372523,1.8260400692621868,1.8095300495624542,1.7929700712362926,1.7763600647449493,1.7597400744756062,1.7430900832017262,1.7264400521914165,1.7097900807857513,1.6931500534216564,1.6765300631523132,1.6599400540192921,1.6433700720469158,1.6268300414085388,1.6103400687376659,1.5938800573349,1.5774700542291005,1.5611100594202678,1.544800062974294,1.5285300612449646,1.512320061524709,1.4961600601673126,1.4800600409507751,1.4640100697676341,1.4480200409889221,1.432090034087499,1.4162100553512573,1.4003900587558746,1.3846300542354584,1.3689200381437938,1.3532700439294179,1.337680051724116,1.3221400678157806,1.306650052467982,1.291220058997472,1.2758500377337139,1.2605300446351368,1.245260049899419,1.230040043592453,1.2148800492286682,1.1997600495815277,1.1847000618775685,1.1696800390879314,1.1547200282414753,1.1398000419139862,1.1249300340811412,1.1101000408331554,1.095320055882136,1.080580045779546,1.0658900539080303,1.051240046819051,1.0366300543149312,1.0220700403054555,1.0075400273005168,0.993058035771052,0.978612040479978,0.9642050315936407,0.9498360256354014,0.9355050375064214,0.9212080339590708,0.9069480250279108,0.8927230288585027,0.8785340289274851,0.8643780301014582,0.8502530256907145,0.8361620257298151,0.8221030284961065,0.8080760290225347,0.7940790404876074,0.7801110247770945,0.7661730299393336,0.7522640327612559,0.7383810331424078,0.724528024593989,0.7107010285059611,0.6969020316998163,0.6831300208965937,0.6693820208311081,0.6556590348482132,0.6419610331455866,0.6282880157232285,0.6146400173505148,0.6010120163361231,0.5874080260594686,0.5738270084063212,0.5602670212586721,0.5467280149459839,0.5332110126813253,0.5197150111198425,0.5062400251626968,0.4927830174565315,0.4793470154205958,0.46592901398738223,0.45253101736307144,0.4391520122687022,0.4257890159885089,0.4124450162053108,0.3991180161635081,0.38580701251824695,0.37251301606496173,0.3592350135246913,0.34597500910361606,0.33273101101318997,0.31950000921885174,0.30628500630458194,0.2930860072374344,0.27990201115608215,0.26673200726509094,0.25357500712076825,0.2404320053756237,0.2273040053745111,0.21418900539477667,0.20108700171113014,0.18799700339635214,0.17492000137766203,0.16185600434740385,0.14880200227101645,0.13576100145777067,0.12273199980457623,0.10971499979496002,0.09670990022520225,0.08452329970896244,0.07386290033658345,0.06453949989130099,0.05638690044482549,0.04925930003325144,0.04302879981696606,0.03758319995055596,0.03282430053999027,0.02866600003714363,0.02503289996335904,0.021858999816079933,0.019086400046944618,0.016664700272182625,0.014549499998490015,0.012702300058056911,0.011089199998726448,0.009680569870397449,0.00845060000816981,0.007376679956602554,0.006439039949327707,0.005620440041335921,0.004905789974145591,0.00428190000820905,0.003737280028872192,0.0032618599749791124,0.002846869989298284,0.002484639970740924,0.0021684500000750027,0.001892479999999826,0.0016515999935412158,0.001441370016740014,0.0012578799990781893,0.0010977300019779552,0.0009579639930355673,0.0008359839994227514,0.0007295280035274724,0.0006366220040945336,0.0005555430010038739,0.00048478599880278733,0.0004230369983512598,0.0003691500047959077,0.00032212500082096085,0.00028108800082312274,0.00024527800148158957,0.0002140279987846346,0.0001867580006849797,0.00016296200071034642,0.00014219700096873567,0.00012407699978211895,0.00010826500025965895,9.446799958823249e-05,8.242859985330142e-05,7.192320056977526e-05,6.275640043895692e-05,5.4757600385831516e-05,4.777809984564859e-05,4.168789989004532e-05,3.637389969905295e-05,3.173719930297617e-05,2.769129999554328e-05,2.4161099948590465e-05,2.108090014492821e-05,1.8393299797025975e-05,1.6048199919775168e-05,1.4002100063711017e-05,1.2216800011325782e-05,1.0658999978356102e-05,9.29990013294931e-06,8.114030000191027e-06,7.079350022346868e-06,6.176579972816398e-06,5.388919930737757e-06,4.701680002957194e-06,4.102060036833184e-06,3.5789100062781167e-06,3.122460005518709e-06,2.7242200152007476e-06,2.376759975201518e-06,2.0735999820923703e-06,1.8091100078739448e-06,1.5783499994389179e-06,1.377019979524145e-06,1.2013700067351845e-06,1.048120007377899e-06,9.144119938279497e-07,7.977610039233696e-07,6.959879973085966e-07,6.071970091170442e-07,5.297319916053311e-07,4.621480016453461e-07,4.031850006451047e-07,3.5174400162910996e-07,3.068650045179311e-07,2.6771099944274585e-07,2.3355300034684964e-07,2.0375199838440494e-07,1.777530004668885e-07,1.5507100078101152e-07,1.3528299902532126e-07,1.180199996989965e-07,7.018874015329857e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HFC4310mee={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.741915871084226e-06,3.1704332892938204e-05,7.402270027038564e-05,0.00011811007364788868,0.0002603702887427062,0.0006904602487338707,0.001493088435381651,0.002615397213958204,0.004025665286462754,0.005709253367967904,0.007651571494837602,0.009837979606042305,0.012253877784435948,0.014884675852954388,0.01771567389369011,0.02073227148503065,0.026339268311858177,0.03241546514133612,0.040547359734773636,0.050659650626281895,0.06128753939022621,0.07306782963375251,0.08672221936285496,0.10239290756483872,0.1196288987994194,0.13823089003562927,0.15781688069303831,0.17747688045104346,0.19690187896291414,0.21967886885007223,0.23203588897983232,0.2427388938764731,0.24726289386550585,0.252859881768624,0.26552996039390564,0.2750229810674985,0.2840619782606761,0.29246698319911957,0.30027897904316586,0.3075319801767667,0.3138199845949809,0.31876497715711594,0.322450985511144,0.3249589850505193,0.3263629873593648,0.3267329881588618,0.32613198459148407,0.3246229862173398,0.32225998491048813,0.31909698992967606,0.31550098955631256,0.3118149861693382,0.3080429856975873,0.30418798824151355,0.3002539922793706,0.2962459897001584,0.29216499129931134,0.2880159914493561,0.28380099435647327,0.2795239935318629,0.27530398964881897,0.2712549865245819,0.2673649912079175,0.2636229892571767,0.260019987821579,0.25654498984416324,0.25318998595078784,0.24994699036081633,0.24680799121658006,0.24376599118113518,0.2408179926375548,0.23796499272187552,0.23519798989097276,0.23251298939188322,0.22990199302633604,0.22736199075977007,0.22488799194494882,0.22247299179434776,0.22011499106884003,0.21780899167060852,0.21557699392239252,0.2134389914572239,0.21138999114433923,0.20942198857665062,0.2075309914847215,0.20571199183662733,0.203959991534551,0.20226899161934853,0.2006369928518931,0.19905899340907732,0.19755799074967703,0.1961549917856852,0.19484499469399452,0.19362099220355353,0.19247699280579886,0.19140899057189623,0.19041099026799202,0.18947899341583252,0.18860899284482002,0.18779699256022772,0.18704399218161902,0.18635299305121103,0.18572099258502325,0.18514099096258482,0.18461199228962263,0.1841299906373024,0.1836909924944242,0.18329298992951712,0.18293199439843497,0.18260599176088968,0.18232399225234985,0.1820929894844691,0.18190999204913774,0.18177098905046782,0.18167498956123987,0.18161699300011,0.18159599229693413,0.18160799145698547,0.18165199334422746,0.1817259912689527,0.18176999191443124,0.18173199271162352,0.18161399041612944,0.18141899133721986,0.1811509927113851,0.18081299091378847,0.18040899435679117,0.17994199320673943,0.17941499253114065,0.17883199080824852,0.1781939926246802,0.1775059923529625,0.17677099133531252,0.17598899205525717,0.17516499136885008,0.17429999262094498,0.17339899390935898,0.1724619915088018,0.1714919942120711,0.17049199094374975,0.16946199287970862,0.16840399305025736,0.16732199117541313,0.1662169930835565,0.16508999218543371,0.16394399354855219,0.16277999058365822,0.1615969923635324,0.1603999932607015,0.15918899327516556,0.15796499078472456,0.15672699362039566,0.1554789940516154,0.15422199293971062,0.15295599400997162,0.15168199315667152,0.15040099248290062,0.14911399284998575,0.1478199933966001,0.14652199298143387,0.14521999408801398,0.14391499385237694,0.14260699724157652,0.1412969926993052,0.1399849938849608,0.13866999372839928,0.1373549960553646,0.13603999217351279,0.13472499325871468,0.13340999558568,0.13209599504868189,0.1307819957534472,0.12946999569733939,0.12815999488035837,0.12685099616646767,0.1255429939677318,0.12423699473341306,0.1229339949786663,0.12163299508392811,0.12033399567008018,0.11903899535536766,0.11774599490066369,0.11645499492685,0.11516699567437172,0.11388399451971054,0.11260199422637622,0.11132399551570415,0.11004999590416749,0.10877799615263939,0.1075099961211284,0.10624599518875281,0.10498499435683091,0.10372599586844444,0.10247099585831165,0.10121999494731426,0.09997149556875229,0.09872699591020744,0.09748649659256141,0.09624849694470565,0.09501299634575844,0.09378149546682835,0.09255389558772247,0.09132879662017028,0.09010749558607738,0.08889009679357211,0.08767489716410637,0.08646359605093797,0.0852559966345628,0.08405049641927083,0.0828473965326945,0.0816478965183099,0.08045199699699879,0.07925819667677085,0.07806799684961636,0.07688119697074096,0.07569629574815433,0.07451349621017773,0.07333409786224365,0.07215799763798714,0.07098379731178284,0.06981279700994492,0.0686449973533551,0.06747889829178651,0.06631589742998283,0.06515599663058917,0.0639975977440675,0.06284079793840647,0.06168699792275826,0.06053609742472569,0.0593865979462862,0.058239997985462345,0.057096097618341446,0.05595359827081362,0.05481239749739567,0.05367389755944411,0.05253799818456173,0.051403398315111794,0.050271298425892987,0.04914179816842079,0.048013298151393734,0.046885898957649864,0.0457608982299765,0.04463839841385683,0.04351679918666681,0.04239759842554728,0.04128069834162792,0.04016459888468186,0.03905079855273167,0.037939099284509815,0.03682809881865978,0.03571789960066477,0.03460979927331209,0.03350389904032151,0.0323984989275535,0.031295199412852526,0.030193899447719257,0.02909319909910361,0.02799289921919505,0.026894699316471815,0.025798399622241657,0.024702499620616436,0.0236085996342202,0.02251639977718393,0.021424599767973024,0.020334600005298853,0.019246299906323355,0.01815830000365774,0.01707059998686115,0.01598469998377065,0.014900399915253123,0.013853900056953231,0.012880000052973628,0.011973900021985173,0.011130900122225285,0.01034669989409546,0.009617289993911982,0.008938940164322654,0.008308109904949864,0.0077215200290083885,0.007176110055297613,0.006669019969801108,0.006197590031661093,0.005759329961923261,0.005351940014710029,0.004973259987309575,0.004621280007995665,0.004294120046931009,0.003990060048333059,0.0037074700036707022,0.003444840006219844,0.003200779998830209,0.0029739600140601397,0.002763189976879706,0.002567319975545009,0.002385320006093631,0.002216199995018542,0.0020590399702390036,0.0019130200089421123,0.0017773400080235053,0.0016512700046102207,0.0015341299974049132,0.0014252900242960702,0.0013241700071375817,0.0012302099882314603,0.0011429099928742896,0.0010618000039054702,0.0009864479895137872,0.000916433995977665,0.0008513870028158029,0.000790952006354928,0.0007348050033518424,0.0006826400058344007,0.0006341770009991402,0.0005891509984697526,0.0005473210039781407,0.0005084589987139528,0.00047235399930893135,0.00043881199720393244,0.00040765100372179103,0.00037870099913561717,0.00035180600146607804,0.0003268199967957723,0.00030360800155904144,0.0002820429993638148,0.00026200999855063856,0.00024339899876698232,0.00022610900001988435,0.00021004699859380102,0.00019512499905734634,0.00018126299740591398,0.00016838600034437454,0.00015642299937705198,0.00014530899958723845,0.0001349850014473001,0.00012539399843565965,0.00011648400080351469,0.00010820699996353748,0.0001005180007875121,9.337529869905363e-05,8.673979997790109e-05,8.057570024296486e-05,7.484949977272966e-05,6.953010051802266e-05,6.458859994988113e-05,5.9998199806917306e-05,5.573390020193377e-05,5.177260057583529e-05,4.809270042945476e-05,4.467430001871738e-05,4.1498799873807e-05,3.8548999630923696e-05,3.580879971802157e-05,3.326329988340149e-05,3.089870006078854e-05,2.870210028049769e-05,2.6661600107521128e-05,2.476620011293562e-05,2.3005500224826392e-05,2.1369899968703976e-05,1.9850600134911172e-05,1.84392000240526e-05,1.7128200094399897e-05,1.5910299983564375e-05,1.477909995628579e-05,1.3728200049930214e-05,1.2752000126662702e-05,1.1845299998943423e-05,1.1002999902605856e-05,1.022049999240456e-05,9.493740056617147e-06,8.818609937103853e-06,8.191479992092354e-06,7.608940071198352e-06,7.06781001251026e-06,6.565160030428767e-06,6.098250006895493e-06,5.664539988477675e-06,5.261659983564944e-06,4.887439937798869e-06,4.539820035157997e-06,4.216919933242025e-06,3.916979987176698e-06,3.6383800079420325e-06,3.379579993634252e-06,3.1391900089753713e-06,2.9158999647430997e-06,2.7084799967269646e-06,2.515819990852227e-06,2.3368499834456693e-06,2.170620026239097e-06,2.0162099948114096e-06,1.8727800087011322e-06,1.739549986723432e-06,1.6157999975045338e-06,1.500849994802896e-06,1.3940800063968102e-06,1.2948999975985014e-06,1.2027800077400268e-06,1.1172100092456578e-06,1.0377200112543505e-06,9.638909877670205e-07,8.953130029946502e-07,8.316129983162076e-07,7.724440015029662e-07,7.174849988208128e-07,6.66435994389758e-07,6.190180054469844e-07,5.74972996029525e-07,5.340620011414406e-07,4.960619956288307e-07,4.607650012644626e-07,4.279790033479003e-07,3.9752599908145686e-07,3.6923899671137406e-07,3.4296500217578796e-07,3.1856000030453896e-07,2.958920006790322e-07,2.748369993810229e-07,2.5527900267737397e-07,2.3711400013818698e-07,2.2024000045917091e-07,2.0456800105724446e-07,1.900100012145837e-07,1.7648799873389484e-07,1.639289995599332e-07,1.5226299865389592e-07,1.414270004810684e-07,1.31362998700979e-07,1.2201400068079238e-07,1.1333100028802316e-07,1.0526599917663286e-07,1.6801068388379765e-08,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    //NF3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.301572314740042e-05,0.00023697439125195766,0.0002955890692343625,0.00023557823563654287,0.00016916307868086733,9.776513888937188e-05,8.317647248468063e-05,0.0003636896714548736,0.004997149963552753,0.010159400020105144,0.014605900039896369,0.017775399920841057,0.019722100036839645,0.020835400093346834,0.021470400039106607,0.021753100057442982,0.021783300054570038,0.021691699977964163,0.021650000320126612,0.022158500117560227,0.026282399737586577,0.033865700320651136,0.041197700425982475,0.04893889961143335,0.057376700143019356,0.06681420002132654,0.0775570993622144,0.08985149984558423,0.10393600103755792,0.1201670008401076,0.13875199978550276,0.15860100090503693,0.1813920003672441,0.21255999927719435,0.2547910002370675,0.306077000995477,0.3499999965230624,0.40000000099341076,0.46000000089406967,0.5199999983112017,0.5999999990065893,0.7100000033775965,0.8299999932448069,0.9600000033775965,1.0999999940395355,1.2399999896685283,1.364031861225764,1.4751599927743275,1.5928400059541066,1.705350011587143,1.818750003973643,1.933060000340144,2.0482499500115714,2.1639700134595237,2.279849966367086,2.3958800037701926,2.512059986591339,2.6283899943033853,2.7448800007502236,2.861519972483317,2.978309988975525,3.0952500104904175,3.21234001715978,3.32942001024882,3.446340024471283,3.5631100138028464,3.6797099908192954,3.796150028705597,3.9124199946721396,4.028540015220642,4.144490043322246,4.260280092557271,4.375909964243571,4.4912099440892534,4.6060099601745605,4.720330039660136,4.834150075912476,4.94747006893158,5.060309926668803,5.172659993171692,5.284510016441345,5.395879944165547,5.506749987602234,5.6172700723012285,5.727590084075928,5.8377000490824384,5.94760000705719,6.057289918263753,6.1667799949646,6.276060024897258,6.385119994481404,6.493979970614116,6.602639993031819,6.711119969685872,6.81948999563853,6.927740017573039,7.035869995752971,7.1438900629679365,7.251789967219035,7.359570026397705,7.46724005540212,7.574789961179097,7.682210008303325,7.789569973945618,7.896909991900126,8.004220048586527,8.111519893010458,8.218800067901611,8.326049963633219,8.433289925257364,8.540510018666586,8.647700071334839,8.754870017369589,8.862160046895346,8.969689925511679,9.07748007774353,9.1855099995931,9.293790022532145,9.40231998761495,9.511079947153727,9.620100021362305,9.729349931081137,9.838849941889444,9.948669910430908,10.058900117874146,10.169600009918213,10.28060007095337,10.392100095748901,10.504000107447306,10.616300106048584,10.728999932607016,10.842100063959757,10.955600023269653,11.068700075149536,11.180699825286865,11.291599988937378,11.401299873987833,11.509800036748251,11.617300033569336,11.723599910736084,11.828699906667074,11.932799895604452,12.035699923833212,12.137399911880493,12.238099892934164,12.337600151697794,12.436099847157797,12.533400058746338,12.629500071207682,12.724600076675415,12.818600018819174,12.911399920781454,13.003200054168701,13.093800067901611,13.18339999516805,13.271799882253012,13.35919992129008,13.44539999961853,13.530599991480509,13.614700078964233,13.69760004679362,13.779500007629395,13.860400040944418,13.940099954605103,14.018699884414673,14.096299886703491,14.172799905141195,14.248199939727783,14.32260004679362,14.395900011062622,14.468099991480509,14.539300044377645,14.609400033950806,14.678400119145712,14.746399958928427,14.813399950663248,14.879199981689453,14.94409998257955,15.007799943288168,15.070600112279257,15.13230005900065,15.192900021870932,15.252499977747599,15.311100085576376,15.368699868520102,15.42520006497701,15.480700095494589,15.535100062688192,15.588499943415323,15.640900055567423,15.692300081253052,15.742700099945068,15.79199997584025,15.840399980545044,15.887700001398722,15.933999935785929,15.979300022125244,16.023600101470947,16.06689993540446,16.10919984181722,16.150500138600666,16.190800031026203,16.23009983698527,16.268399874369305,16.305699825286865,16.342000166575115,16.377299944559734,16.41170008977254,16.44510014851888,16.477500120798748,16.508899847666424,16.539300282796223,16.56879997253418,16.597300052642822,16.624799887339275,16.65139977137248,16.677000204722088,16.701600074768066,16.725299835205078,16.748000144958496,16.76979986826579,16.790599822998047,16.810499986012776,16.829400380452473,16.8472998936971,16.86430009206136,16.880399862925213,16.895500024159748,16.9096999168396,16.9229998588562,16.93530003229777,16.946699778238933,16.95709975560506,16.966599941253662,16.975199858347576,16.982899983723957,16.989699999491375,16.9954997698466,17.000399907430012,17.00439993540446,17.00749985376994,17.009599685668945,17.010900179545086,17.011200110117596,17.01069990793864,17.00920025507609,17.006800015767414,17.003599961598713,16.999399820963543,16.994400024414062,16.988399823506672,16.981499989827473,16.97380002339681,16.9652001063029,16.955699761708576,16.945299943288166,16.93399985631307,16.921799818674724,16.90879996617635,16.89490016301473,16.880099932352703,16.864399909973145,16.847900072733562,16.83050012588501,16.81219991048177,16.793100039164226,16.773099899291992,16.75230010350545,16.730600039164226,16.70799986521403,16.684600194295246,16.66029977798462,16.635200023651123,16.60919984181722,16.582300027211506,16.55470021565755,16.52620013554891,16.49679962793986,16.466599941253662,16.43559996287028,16.40369987487793,16.370999654134113,16.33749993642171,16.303500016530354,16.269700209299724,16.235899766286213,16.202199935913086,16.168599764506023,16.1349999109904,16.101500034332275,16.068099816640217,16.034800052642822,16.001500209172566,15.968299945195517,15.935099999109903,15.902000109354654,15.86899987856547,15.836100021998087,15.803200006484985,15.770399888356527,15.73769998550415,15.705100138982138,15.672499974568685,15.639899969100952,15.607500076293945,15.57510002454122,15.542799949645996,15.510500033696493,15.478299935658773,15.446199973424276,15.414099931716919,15.382200082143148,15.350200017293295,15.318400065104166,15.286600033442179,15.254900058110556,15.22320000330607,15.19159992535909,15.16010014216105,15.128699938456217,15.097299973169962,15.065900166829428,15.034700075785318,15.00349990526835,14.972300052642822,14.94130007425944,14.91029977798462,14.879299958546957,14.84850001335144,14.817600011825562,14.786900043487549,14.756200075149536,14.725600004196167,14.695000012715658,14.664599816004435,14.634100039800009,14.60379989941915,14.573499997456869,14.543200016021729,14.513000011444092,14.482899983723959,14.452899932861328,14.422900040944418,14.39300004641215,14.363100051879883,14.333300034205118,14.303599993387857,14.273900111516317,14.244300047556559,14.21470014254252,14.185199975967407,14.155799945195517,14.126399993896484,14.097099860509237,14.067899942398071,14.038700103759766,14.009499867757162,13.980499982833862,13.951499938964844,13.922500054041544,13.89360006650289,13.864799976348877,13.836100021998087,13.807300011316935,13.77869995435079,13.750099976857504,13.72160005569458,13.693100055058798,13.664700110753378,13.636399984359741,13.608100016911825,13.579800128936768,13.551700115203857,13.523599942525228,13.495500087738037,13.46750013033549,13.439600070317587,13.411699930826822,13.383900006612143,13.356099923451742,13.328400055567423,13.300699949264526,13.273099978764852,13.245599826176962,13.218099991480509,13.190700054168701,13.163400014241537,13.135999997456869,13.108800013860067,13.081599950790405,13.054500023523966,13.027400016784668,13.000399907430014,12.973399957021078,12.946499983469645,12.919600089391073,12.892800092697144,12.866099993387857,12.839399973551432,12.81279993057251,12.786199967066446,12.759699980417887,12.733200073242188,12.706800063451132,12.680399974187216,12.654100020726522,12.627900044123331,12.601700146993002,12.575599908828735,12.549499988555908,12.523499886194864,12.497499942779541,12.471599896748861,12.4457000096639,12.419900019963583,12.394100109736124,12.36840001742045,12.34279998143514,12.317199945449829,12.291599988937378,12.266200065612793,12.240700085957846,12.21530000368754,12.18999989827474,12.164700031280518,12.13949990272522,12.114300012588501,12.089199940363565,12.06410002708435,12.039100090662638,12.01420005162557,11.989200115203857,11.964400053024292,11.939599990844727,11.914800008138021,11.890100081761679,11.86549997329712,11.84090002377828,11.8163001537323,11.791800022125244,11.76739994684855,11.742999951044718,11.718599955240885,11.694300095240274,11.67010005315145,11.645899931589762,11.621699968973795,11.597600062688192,11.573599974314371,11.54960004488627,11.525599956512451,11.501800060272217,11.4778999487559,11.454100052515665,11.430399894714355,11.406700054804483,11.382999897003174,11.359399875005087,11.335899829864502,11.312399943669638,11.288899978001913,11.265499909718832,11.242200056711832,11.218900124231974,11.195600112279257,11.172399918238321,11.14930001894633,11.126199881235758,11.103099902470907,11.080099821090698,11.057099978129068,11.034200112024942,11.011299848556519,10.988499959309896,10.965700070063273,10.942999998728434,10.920300086339315,10.89769991238912,10.875100056330362,10.852599859237671,10.830100059509277,10.807599941889444,10.785200119018555,10.762900034586588,10.740600029627482,10.718300104141235,10.696099917093912,10.67389996846517,10.651800076166788,10.629799922307333,10.607699950536093,10.585700035095215,10.56380009651184,10.541899998982748,10.520099957784018,10.498300075531006,10.476500034332275,10.454799969991049,10.433199961980185,10.411500056584677,10.390000104904175,10.368399937947592,10.346999963124594,10.325500011444092,10.304100036621094,10.282800118128458,10.261500040690104,10.240199963251749,10.218999862670898,10.197800000508627,10.176700194676718,10.15560015042623,10.134600003560385,10.113599936167398,10.092700084050497,10.071699937184652,10.050899902979532,10.030099948247274,10.009299914042154,9.98856004079183,9.967870076497396,9.947220007578531,9.92662000656128,9.906059980392456,9.885540088017782,9.865060011545816,9.844629923502604,9.8242400487264,9.803900321324667,9.783590078353882,9.763329982757568,9.753209988276163};
        C2F6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2887821417469543e-06,1.031025730450589e-05,2.0667359725242324e-05,3.10744549096853e-05,4.1513251138288375e-05,5.2002859774802346e-05,6.254957406781614e-05,7.315969560295343e-05,8.383950868543859e-05,9.459531490089527e-05,0.00010543340310202136,0.00011636007608710013,0.00012738162210249962,0.00013850433606421575,0.00014973450258063772,0.00016107846022350714,0.00017254241417200925,0.00018413277454480217,0.00019585573196915598,0.00020771763714340827,0.0002197247971101509,0.000231883451003038,0.00024419995800902444,0.0002566805657503816,0.0002693315764190629,0.0002821592812930855,0.00029516999347833917,0.0003083699945515643,0.00032176555153758574,0.00033536301149676245,0.00034916867055774975,0.00036318877634281915,0.0003774296346819028,0.0003918974956225914,0.0004065987474556702,0.0004215400040266104,0.00043672676110873,0.0004521660230238922,0.00046786327826945734,0.0004838260307830448,0.0005000592888488123,0.0005165705564043795,0.0005333653001192337,0.0005504500586539507,0.0005678308225469664,0.0005855145864188671,0.000603506836341694,0.0006218145863385871,0.0006404438560518125,0.0006594006069159756,0.0006786918675061315,0.0007011479125746215,0.0008848810005777826,0.001116641176243623,0.0013829462016777445,0.0017163676869434614,0.0021963609227289758,0.002872606390155852,0.0037649905619521937,0.004334990129185219,0.005609989515505731,0.007499988889321685,0.009259988398601612,0.011569987594460448,0.014084987109526992,0.016684986495723326,0.019669986019531887,0.02392498527963956,0.02868998423218727,0.03343498365332683,0.03770498279482126,0.042184981517493725,0.04389498041321834,0.04700497972468535,0.052589978401859604,0.05885497791071733,0.06516497613241275,0.0720199750115474,0.07970497260491054,0.08870497221748035,0.0980799701064825,0.10662497021257877,0.11274996710320313,0.11636996641755104,0.120129964624842,0.12510996125638485,0.13321496173739433,0.14407995715737343,0.1580399548014005,0.1736899564663569,0.19239995131889978,0.21106995145479837,0.23562495286266008,0.267039954662323,0.30831495175759,0.33637995769580203,0.3442649617791176,0.3536549558242162,0.3683149615923564,0.38362496097882587,0.3969699591398239,0.41064496090014774,0.42523996035257977,0.4392099554340045,0.4534849599003792,0.46671496083339054,0.478794959684213,0.489309956630071,0.4977349440256755,0.505239948630333,0.5130949467420578,0.5207299540440241,0.5278749416271845,0.535164937376976,0.5425249338150024,0.5508499294519424,0.5597749253114065,0.5701449265082678,0.5827049265305201,0.5976699193318685,0.61744491259257,0.6424449036518732,0.6740748832623163,0.7138798783222834,0.7649898727734884,0.8284898797671,0.8872098724047343,0.9490798612435659,1.0211598575115204,1.094819853703181,1.1735098262627919,1.2601898312568665,1.3425698479016621,1.4098998308181763,1.4820398290952046,1.5687698423862457,1.6502498388290405,1.7349598209063213,1.8262398143609364,1.9231797953446705,2.018889824549357,2.113149801890055,2.20022984345754,2.2837098240852356,2.36793980995814,2.4555798172950745,2.5522598028182983,2.6610097885131836,2.781449774901072,2.9081997672716775,3.038709739844004,3.162919799486796,3.2808697621027627,3.4251197973887124,3.577999790509542,3.697199821472168,3.767239769299825,3.864439765612284,3.9428598284721375,4.015999873479207,4.092629869778951,4.170369823773702,4.244799852371216,4.328779697418213,4.398729681968689,4.480093280474345,4.563908735911052,4.607269128163655,4.680299162864685,4.757189035415649,4.837939063707988,4.922539075215657,5.007649183273315,5.089899142583211,5.169289151827495,5.245819290479024,5.319489240646362,5.39030925432841,5.458269278208415,5.523369391759236,5.585619290669759,5.6450194120407104,5.702069401741028,5.757289449373881,5.81067951520284,5.862239400545756,5.9119694630304975,5.959879517555237,6.0059494972229,6.050199508666992,6.09261957804362,6.133209625879924,6.17229962348938,6.210219542185466,6.24696958065033,6.282549659411113,6.316959619522095,6.350189606348674,6.382259686787923,6.41314971446991,6.442879676818848,6.471439719200134,6.499029715855916,6.525879740715027,6.551979700724284,6.577319661776225,6.601919571558635,6.625769734382629,6.648869752883911,6.6712197462717695,6.692819714546204,6.713679750760396,6.7339097658793134,6.753669738769531,6.772949775060018,6.791749795277913,6.810069799423218,6.827899773915608,6.84525986512502,6.862139741579692,6.878539840380351,6.894459843635559,6.909979740778605,6.925199866294861,6.940109809239705,6.9547098477681475,6.969009796778361,6.982999841372172,6.996679862340291,7.010049859682719,7.023119846979777,7.035879810651143,7.0482198397318525,7.059999863306682,7.071249882380168,7.081949869791667,7.092099825541179,7.101709882418315,7.110769947369893,7.119289954503377,7.127259890238444,7.134689927101135,7.141849915186564,7.148999969164531,7.156149943669637,7.163309892018636,7.170459906260173,7.177609920501709,7.184759895006816,7.191909948984782,7.199059923489888,7.206209897994995,7.213329911231995,7.220399936040242,7.227419932683309,7.234379927317302,7.241289933522542,7.248139937718709,7.254949927330017,7.261699875195821,7.268389860788981,7.275039951006572,7.281629920005798,7.288159926732381,7.2946499188741045,7.301079948743184,7.307459870974223,7.313789923985799,7.320059895515442,7.326269904772441,7.33243993918101,7.338549892107646,7.3446199496587115,7.350619951883952,7.356569886207581,7.362469871838887,7.368319908777873,7.374119877815247,7.379859924316406,7.385549942652385,7.391179958979289,7.396769920984904,7.402289907137553,7.4077699184417725,7.413199941317241,7.418569962183635,7.423879941304524,7.429149905840556,7.434359947840373,7.439519921938579,7.444629907608032,7.449679931004842,7.4546800057093305,7.459619959195455,7.46451993783315,7.469359914461772,7.474149902661641,7.478879928588867,7.483559966087341,7.4881900151570635,7.492769956588745,7.497289975484212,7.501759966214498,7.50616991519928,7.5105399290720625,7.514849940935771,7.519109924634297,7.5233099063237505,7.527469952901204,7.531569957733154,7.5356099208196,7.539609909057617,7.54354993502299,7.547440012296041,7.55127998193105,7.555059949556987,7.558789968490601,7.562459905942281,7.566089868545532,7.569659908612569,7.5731799602508545,7.5766399304072065,7.580049912134807,7.583409945170085,7.5867200295130415,7.589979966481526,7.593179941177368,7.596329927444458,7.599419991175334,7.602459987004598,7.605449954668681,7.608389933904012,7.611280043919881,7.614109953244527,7.616889993349711,7.619610031445821,7.622289856274922,7.62490991751353,7.627479990323384,7.629999915758769,7.632459918657939,7.634869972864787,7.637229959170024,7.639529903729756,7.64178999265035,7.643979986508687,7.646129926045735,7.648219982783,7.650270064671834,7.652259945869446,7.654189984003703,7.656069874763489,7.6579000155131025,7.6596799691518145,7.661410013834636,7.663079937299092,7.66470996538798,7.666269977887471,7.667790015538533,7.669250011444092,7.670659939448039,7.672019958496094,7.673319896062215,7.674570004145305,7.675769925117493,7.6769200166066485,7.6780199607213335,7.679060022036235,7.680050015449524,7.68098000685374,7.681869983673096,7.682699998219808,7.6834800243377686,7.684199968973796,7.684879978497823,7.685499906539917,7.686069965362549,7.686590035756429,7.687049984931946,7.68746002515157,7.687829971313477,7.688129981358846,7.688389976819356,7.688589930534363,7.688740015029907,7.688829978307088,7.68887996673584,7.688869953155518,7.688809951146443,7.688690026601155,7.688530087471008,7.688309987386067,7.688040018081665,7.687720020612081,7.687339981396993,7.686920007069905,7.686440070470174,7.685900052388509,7.685319979985555,7.684679985046387,7.683990001678467,7.683250069618225,7.682479937871297,7.681709965070088,7.680950005849202,7.680180033047994,7.679409980773926,7.678640007972717,7.677869995435079,7.677109917004903,7.6763399839401245,7.675570050875346,7.674799958864848,7.674040079116821,7.673269987106323,7.672500054041545,7.671729922294617,7.6709699630737305,7.670199990272522,7.669429937998454,7.668670018513997,7.667899966239929,7.667129993438721,7.666369915008545,7.665599981943767,7.664829969406128,7.664070010185242,7.663300037384033,7.662529985109965,7.661770025889079,7.660999933878581,7.660239974657695,7.659470001856486,7.658699989318848,7.657940030097961,7.6571699778238935,7.656409939130147,7.6556399663289385,7.654869953791301,7.6541099945704145,7.653340021769206,7.65258002281189,7.651810010274251,7.6510500113169355,7.650279998779297,7.6495199998219805,7.648749987284343,7.647989948590596,7.647220055262248,7.646459937095642,7.645689964294434,7.644929965337117,7.644170006116231,7.643399953842163,7.642639994621277,7.641869982083638,7.641110022862752,7.640340010325114,7.639579971631368,7.638819972674052,7.638049960136414,7.637290000915527,7.636529962221782,7.635759949684143,7.635000030199687,7.634230017662048,7.633469978968303,7.632709980010986,7.631939967473348,7.6311800082524615,7.630419969558716,7.62966005007426,7.628890077273051,7.628129959106445,7.627369999885559,7.626599947611491,7.625840067863464,7.625080029169719,7.624319990475972,7.623549977938334,7.622789939244588,7.622030019760132,7.621269981066386,7.620510061581929,7.619740009307861,7.618980010350545,7.618219931920369,7.617460052172343,7.616700013478597,7.615930000940959,7.615169962247212,7.614409923553467,7.613650004069011,7.612890005111694,7.6121299266815186,7.6113700071970625,7.610610008239746,7.609839955965678,7.609080036481221,7.608320037523906,7.607559998830159,7.606799999872844,7.606040000915527,7.605280001958211,7.6045200030008955,7.603760004043579,7.603000005086263,7.602240006128947,7.601479967435201,7.6007200082143145,7.599960009256999,7.599200010299683,7.598440011342366,7.597679972648621,7.596919973691304,7.596160014470418,7.5954000155131025,7.594640016555786,7.59388001759847,7.593119978904724,7.592360019683838,7.591599980990092,7.590839982032776,7.59008002281189,7.5893300374348955,7.58857003847758,7.5878099997838335,7.587049961090088,7.586290001869202,7.585530002911885,7.5847699244817095,7.584009925524394,7.583260019620259,7.582499980926514,7.581740061442058,7.580979943275452,7.580219944318135,7.579469998677571,7.578709959983826,7.57794992129008,7.577189962069194,7.576430042584737,7.5756800174713135,7.574920058250427,7.5741599798202515,7.573400060335795,7.572649955749512,7.5718899965286255,7.571129997571309,7.570379972457886,7.5696200132369995,7.568859974543254,7.5680999755859375,7.5673500299453735,7.566589951515198,7.5658299922943115,7.565080006917317,7.564320047696431,7.563569982846578,7.562810023625691,7.562049984931946,7.561300039291382,7.560540000597636,7.559780081113179,7.5590299765268965,7.55826997756958,7.557519992192586,7.5567600329717,7.556009968121846,7.55525004863739,7.5544900099436445,7.55373998483022,7.552980025609334,7.552230000495911,7.551470001538594,7.550720016161601,7.549960056940715,7.549209992090861,7.548449953397115,7.547700087229411,7.546939969062805,7.546190023422241,7.545430024464925,7.5446799993515015,7.543930093447368,7.543170015017192,7.542420029640198,7.5416600704193115,7.540910045305888,7.540150006612142,7.539400021235148,7.538649996121724,7.5378899574279785,7.5371400117874146,7.53639002641042,7.535629987716675,7.534879962603251,7.534119923909505,7.533369978268941,7.532620072364807,7.531859993934631,7.531110008557637,7.530359943707784,7.52960999806722,7.5288500388463335,7.52809997399648,7.527350028355916,7.52658994992574,7.525839964548747,7.525089939435323,7.524340033531189,7.523579994837443,7.522830049196879,7.522080024083455,7.521330038706462,7.520579973856608,7.519819935162862,7.519070029258728,7.5183199644088745,7.51756997903188,7.516820073127747,7.516059994697571,7.515310009320577,7.514559984207153,7.513810038566589,7.513059973716736,7.512309988339742,7.511559963226318,7.510809977849324,7.510049978892009,7.5092999537785845,7.508549968401591,7.507800022761027,7.507049997647603,7.50630001227061,7.505550026893616,7.504800081253052,7.504050016403198,7.503299951553345,7.502550045649211,7.501799901326497,7.501049995422363,7.500300049781799,7.499549984931946,7.498800039291382,7.498049974441528,7.497300028800964,7.496550003687541,7.4957999388376875,7.495049953460693,7.494670033454895};
        //C3F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.280652608831739e-08,3.0481899789454775e-07,6.92283000110668e-07,1.242170014847943e-06,1.9587900131530964e-06,2.846410003106333e-06,3.909340023255936e-06,5.151869989579912e-06,6.578300068819469e-06,8.192909907241605e-06,1.0000000050543653e-05,1.4999999772650577e-05,2.500000012635913e-05,3.500000017690278e-05,4.999999994955336e-05,5.9999999696932114e-05,8.50000002780386e-05,0.00011000000025281527,0.0001250000004802132,0.00016000000080869844,0.00020999999712027298,0.0002649999999751647,0.000330000000152116,0.0003999999995964269,0.00047499999588277814,0.0005600000052557638,0.0006800000022243088,0.0008150000066962093,0.0009500000014668331,0.001069999998435378,0.001199999979386727,0.0012500000011641532,0.0013350000081118196,0.0014950000040698797,0.001674999997097378,0.0018549999901248764,0.00204999999065573,0.0022699999972246587,0.002529999997932464,0.002804999977039794,0.003049999999348074,0.003230000011778126,0.0033400000150625906,0.0034499999795419476,0.003599999976965288,0.0038449999410659075,0.004174999970321854,0.004604999946119885,0.00509500006834666,0.0056899999811624484,0.006290000009660919,0.0070999999685833854,0.008159999968484044,0.009594999952241778,0.010604999804248413,0.010914999914045135,0.011284999937439958,0.011869999890526136,0.012515000067651272,0.013104999981199702,0.013744999965031942,0.014465000092362365,0.015210000099614263,0.016019999825706083,0.016829999939848978,0.01762500001738469,0.018360000103712082,0.018969999936719734,0.019530000009884436,0.020105000119656324,0.020640000080068905,0.021114999894052744,0.021570000021408003,0.021990000115086634,0.02243500016629696,0.022889999983211357,0.023400000141312677,0.023989999977250893,0.024669999877611797,0.025529999906818073,0.02656499979396661,0.027814999998857576,0.029349999812742073,0.031320000222573675,0.03399500002463659,0.03666500002145767,0.03981499963750442,0.043614999701579414,0.047935000310341515,0.05325499984125296,0.059784999738136925,0.06639999896287918,0.07203999844690163,0.07797999990483125,0.084669999157389,0.09061500057578087,0.09619499929249287,0.10222999999920528,0.10946499990920226,0.11630499921739101,0.12320999925335248,0.1303700009981791,0.13836999982595444,0.14808999622861543,0.1604899987578392,0.17652999485532442,0.1962999925017357,0.21951498836278915,0.24549498657385507,0.2737399861216545,0.3036249826351802,0.3343099852403005,0.36955797920624417,0.40588397284348804,0.44012997547785443,0.46434496343135834,0.4830769672989845,0.5037679746747017,0.5175449798504511,0.5396579802036285,0.5581129789352417,0.5714049835999807,0.5865809768438339,0.6006629715363184,0.6174860149621964,0.6330969432989756,0.6434359351793925,0.6587299307187399,0.6748299400011698,0.6917389283577601,0.7094549338022867,0.727274939417839,0.7444949448108673,0.7611169368028641,0.7771389484405518,0.7925629516442617,0.8073879480361938,0.8216139574845632,0.8352419435977936,0.8482709576686224,0.8607009599606196,0.8726409624020258,0.8841969668865204,0.8953689684470495,0.9061579704284668,0.916562964518865,0.9265849590301514,0.936223973830541,0.9454789658387502,0.9543509731690089,0.9628409544626871,0.9710159699122111,0.9789459705352783,0.9866289695103964,0.9940669735272726,1.0012599726517994,1.0082099934418995,1.0149099826812744,1.0213699738184612,1.0275799830754597,1.0335399806499481,1.0393099784851074,1.044919987519582,1.0503699779510498,1.0556599795818329,1.0607999960581462,1.0657800038655598,1.0705999831358592,1.075269987185796,1.0797799825668335,1.0841299891471863,1.0883500079313915,1.092469980319341,1.0964899957180023,1.100409984588623,1.104229986667633,1.1079499920209248,1.1115699807802837,1.115089972813924,1.118509978055954,1.1218199928601582,1.1250599920749664,1.1282299955685933,1.131329983472824,1.1343699892361958,1.137349973122279,1.1402599811553955,1.1431099871794383,1.1458899875481923,1.1486099759737651,1.1512599686781566,1.1538299719492595,1.1562799910704296,1.1586099763711293,1.160840004682541,1.1629499991734822,1.1649399797121684,1.166819989681244,1.1685899992783864,1.1702399849891663,1.1717799802621205,1.1732599834601085,1.1747399866580963,1.1762199898560841,1.1777099867661793,1.1791900197664897,1.1806699832280476,1.1821500062942505,1.1836300094922383,1.1851100027561188,1.1865899960199993,1.1880599757035573,1.1895199914773305,1.1909800072511036,1.1924200157324474,1.1938499808311462,1.1952599982420604,1.196669985850652,1.198069989681244,1.1994499762852986,1.200819989045461,1.2021900117397308,1.2035399874051411,1.204879989226659,1.2061999936898549,1.2075199981530507,1.2088299989700317,1.2101200024286907,1.2114000022411346,1.2126800119876862,1.2139399846394856,1.2151899933815002,1.2164300084114075,1.2176600098609924,1.2188699940840404,1.2200799882411957,1.2212699949741364,1.2224599917729695,1.223630001147588,1.2247899770736694,1.2259399990240734,1.2270800073941548,1.2282000084718068,1.2293199598789215,1.2304200033346813,1.231520007054011,1.2326000034809113,1.2336699962615967,1.2347299953301747,1.235780010620753,1.236819992462794,1.23785001039505,1.2388599812984467,1.2398699919382732,1.24085999528567,1.2418499986330669,1.2428199748198192,1.2437800069650014,1.244729995727539,1.2456600069999695,1.246589998404185,1.247510015964508,1.2484099964300792,1.2492999931176503,1.2501799861590068,1.251059999068578,1.2519100109736125,1.2527599930763245,1.2535999914010365,1.2544299960136414,1.2552399933338165,1.2560500005880992,1.2568400005499523,1.2576300104459126,1.258399983247121,1.259160002072652,1.2599099973837535,1.2606399953365326,1.2613700131575267,1.2620899975299835,1.2627899944782257,1.2634800175825756,1.2641700108846028,1.2648399968942006,1.2654999991257985,1.2661500076452892,1.2667900025844574,1.2674100001653035,1.2680299977461498,1.2686299979686737,1.2692299981911976,1.269810010989507,1.2703799903392792,1.2709400057792664,1.2714899877707164,1.2720300058523815,1.2725600004196167,1.2730800012747447,1.273579994837443,1.2740700046221416,1.2745600044727325,1.275029997030894,1.2754899660746257,1.2759400010108948,1.2763799925645192,1.276810000340144,1.2772200107574463,1.2776299913724263,1.2780199944972992,1.2784099976221721,1.2787799835205078,1.2791399955749512,1.2794899940490723,1.2798299888769786,1.2801600098609924,1.2804799874623616,1.2807799975077312,1.281079997618993,1.2813599904378254,1.281640003124873,1.2818999985853832,1.2821499903996785,1.2823899885018666,1.2826199928919475,1.2828399936358135,1.2830400069554646,1.2832400004069011,1.28343000014623,1.2836000124613445,1.2837600111961365,1.2839199999968212,1.2840599815050762,1.2841899891694386,1.2843000292778015,1.284410019715627,1.2845100164413452,1.2845899959405263,1.2846699953079224,1.2847299873828888,1.2847799956798553,1.2848299940427144,1.2848600049813588,1.284880002339681,1.2848899960517883,1.2848800122737885,1.2848700086275737,1.2848499914010365,1.2848099966843922,1.284770001967748,1.2847099900245667,1.284639984369278,1.2845599949359894,1.2844699919223785,1.2843699951966603,1.2842599948247273,1.2841400106747944,1.2839999894301097,1.2838599880536397,1.2836999992529552,1.2835299869378407,1.2833500107129414,1.2831699947516124,1.2829900085926056,1.2827999989191692,1.2826200028260548,1.2824400067329407,1.2822499970595043,1.2820700109004974,1.2818900048732758,1.2817099789778392,1.2815199891726177,1.2813400129477184,1.2811599969863892,1.2809699873129528,1.280790001153946,1.2806100050608318,1.2804199953873951,1.2802400092283885,1.2800600032011669,1.2798799971739452,1.2796900073687236,1.2795100212097168,1.2793299853801727,1.2791399856408436,1.2789599895477295,1.2787800033887227,1.2785999874273937,1.2784100075562794,1.2782300015290577,1.2780500054359436,1.277869999408722,1.2776799897352855,1.2774999837080638,1.277319997549057,1.2771400014559429,1.2769500116507213,1.276769995689392,1.2765900095303853,1.2764099935690563,1.2762200037638347,1.2760400176048279,1.2758599917093914,1.275679995616277,1.275499979654948,1.2753099997838337,1.2751299838225048,1.2749499877293904,1.2747700015703838,1.2745800018310547,1.2744000057379405,1.2742199997107189,1.2740399936834972,1.2738599975903828,1.2736699879169464,1.2734900017579396,1.273309995730718,1.2731300095717113,1.2729499737421672,1.272760013739268,1.2725799977779388,1.2723999917507172,1.272219995657603,1.2720400094985962,1.271859993537267,1.271669993797938,1.2714899977048237,1.2713100016117096,1.2711300055185955,1.2709499994913738,1.270769993464152,1.2705800036589305,1.2703999976317089,1.2702200015385945,1.2700399855772655,1.2698599994182587,1.2696800033251445,1.2695000072320302,1.2693099876244862,1.269129991531372,1.268949995438258,1.2687700192133586,1.2685900231202443,1.2684099972248077,1.2682300011316936,1.2680500050385792,1.2678599953651428,1.2676799992720287,1.267499993244807,1.2673199971516926,1.2671400010585785,1.2669600049654643,1.2667799989382427,1.2666000227133434,1.2664199968179066,1.2662400106589,1.2660500009854634,1.2658700148264568,1.2656899988651276,1.2655099928379059,1.2653299967447917,1.2651500006516774,1.2649700045585632,1.2647899985313416,1.2646099925041199,1.2644299964110057,1.2642500003178914,1.2640700042247772,1.2638899981975555,1.2637099921703339,1.2635300159454346,1.2633400062719982,1.2631600002447765,1.2629799942175548,1.262800008058548,1.2626199920972188,1.2624400059382122,1.2622599999109905,1.2620799938837688,1.261900007724762,1.2617200016975403,1.2615399956703186,1.2613600095113118,1.26118000348409,1.2609999974568684,1.2608200013637543,1.2606400052706401,1.2604599992434184,1.2602799932161968,1.26010000705719,1.2599200010299683,1.2597399950027466,1.2595599989096324,1.259380002816518,1.2591999967892964,1.2590200006961823,1.258840004603068,1.2586599985758464,1.2584799925486247,1.258300006389618,1.2581200003623962,1.2579399943351746,1.2577600081761677,1.257580002148946,1.2573999961217244,1.2572200000286102,1.257040003935496,1.2568600177764893,1.2566799819469452,1.2565099795659382,1.2563299934069316,1.2561499973138173,1.2559700012207031,1.255790005127589,1.2556099891662598,1.2554299930731456,1.2552499969800313,1.2550699909528096,1.254890004793803,1.2547099987665813,1.254529982805252,1.2543499966462452,1.254170000553131,1.2539899945259094,1.2538199921449025,1.2536400059858959,1.2534599900245667,1.2532799939314525,1.2530999978383381,1.252920001745224,1.2527400056521099,1.2525600095589955,1.2523800134658813,1.2522000074386597,1.2520299851894379,1.2518500089645386,1.2516700128714244,1.25149001677831,1.251309980948766,1.2511299947897594,1.2509500086307526,1.2507700026035309,1.250600020090739,1.2504200041294098,1.2502400080362956,1.2500599920749664,1.2498799959818523,1.2496999899546306,1.249519983927409,1.2493499914805095,1.2491699953873951,1.248989999294281,1.2488100032011669,1.2486300071080525,1.248450020949046,1.2482800086339314,1.2481000026067097,1.2479200065135956,1.247739980618159,1.247560014327367,1.2473800083001454,1.2472100059191387,1.247029980023702,1.2468499938646953,1.246670017639796,1.2464900116125743,1.2463199893633525,1.2461400032043457,1.2459600071112316,1.2457799911499023,1.2456000049908955,1.2454300026098888,1.245249996582667,1.2450700004895527,1.2448899845282237,1.2447099884351094,1.24453999598821,1.2443600098292034,1.244180013736089,1.24399999777476,1.243829995393753,1.243649999300639,1.2434699932734172,1.2432899872461955,1.2431100110212963,1.2429399987061818,1.2427600026130676,1.2425799866517384,1.2424000104268391,1.2422299981117249,1.2420500020186107,1.241869995991389,1.2416899899641674,1.2415199875831604,1.2413399914900463,1.241159995396932,1.2409899930159252,1.2408100068569183,1.2406300008296967,1.2404500047365825,1.2402800023555756,1.2401000062624614,1.239920010169347,1.239749977986018,1.2395700017611186,1.239389995733897,1.2392099996407826,1.2390400071938832,1.2388600011666615,1.2386800050735474,1.2385900020599365};
        //C4F10={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.890059050741911e-06,2.3120472178561613e-05,4.902287370593209e-05,0.0003037507473588145,0.001141329999275816,0.0024720000316544124,0.004224000032991171,0.006333330064080656,0.008736000124675533,0.011367999948561192,0.014165299944579601,0.017063999858995278,0.02000000001862645,0.0239999998981754,0.027999999932944775,0.032500000204890966,0.03749999993791183,0.04299999990810951,0.04850000018874804,0.05400000077982744,0.06000000052154064,0.06549999924997489,0.07099999984105428,0.07700000082453091,0.08250000141561031,0.08849999929467837,0.09400000050663948,0.09999999962747097,0.10599999999006589,0.1119999997317791,0.11800000009437402,0.12450000084936619,0.13000000019868216,0.13649999971191087,0.1424999994536241,0.1475000021358331,0.15199999883770943,0.15600000073512396,0.1595000016192595,0.16249999776482582,0.16499999910593033,0.16750000044703484,0.16949999953309694,0.17199999963243803,0.17450000097354254,0.1769999973475933,0.17950000117222467,0.18194267277916273,0.18438099945584932,0.18694199994206429,0.18960299963752428,0.1924040007094542,0.1953470011552175,0.19843100135525069,0.2015330009162426,0.20452999820311865,0.20742200190822283,0.210207998752594,0.21289000163475671,0.21546600138147673,0.2179370013376077,0.22030300026138624,0.22256400187810263,0.22471999997893968,0.22678999975323677,0.22879299893975258,0.2307290012637774,0.23259600003560385,0.23439600070317587,0.2361299991607666,0.23779600113630295,0.23939399917920431,0.2409259999791781,0.24239000057180723,0.24379999935626984,0.24516599997878075,0.24648799871404967,0.24776799976825714,0.24900499979654947,0.25019900128245354,0.251350000500679,0.2524559994538625,0.25352099786202115,0.2545430014530818,0.2555289988716443,0.2564869945247968,0.2574179992079735,0.25832200050354004,0.25919799755016965,0.26004499693711597,0.26086599628130597,0.26165899634361267,0.262423999607563,0.2631620019674301,0.2638759985566139,0.26457300037145615,0.2652530024449031,0.26591600229342777,0.26656100153923035,0.267186996837457,0.26779600232839584,0.26838600138823193,0.2689589982231458,0.2695140019059181,0.27005400011936825,0.2705849955479304,0.27110300461451214,0.27160999923944473,0.27210699766874313,0.2725920006632805,0.27306600163380307,0.27352800220251083,0.2739780048529307,0.2744180013736089,0.2748430023590724,0.2752469951907794,0.27563100059827167,0.2759939953684807,0.27633699774742126,0.2766609986623128,0.2769649997353554,0.2772490009665489,0.27751300235589343,0.2777559980750084,0.277988001704216,0.2782209987441699,0.2784540007511775,0.27868599941333133,0.2789189989368121,0.2791510025660197,0.27938399960597354,0.27961599826812744,0.27984899779160816,0.28008100390434265,0.2803120017051697,0.28054000437259674,0.2807670036951701,0.2809930021564166,0.28121600300073624,0.2814370021224022,0.2816559970378876,0.28187400102615356,0.2820889999469121,0.28230200211207074,0.2825139984488487,0.2827240005135536,0.28293099999427795,0.28313600023587543,0.2833399996161461,0.283541997273763,0.28374199817578,0.28393899897734326,0.28413499891757965,0.28432899961868924,0.2845210035641988,0.28470999995867413,0.2848979979753494,0.2850850000977516,0.28526900211970013,0.2854510024189949,0.285631000995636,0.2858099987109502,0.2859859988093376,0.28616000215212506,0.2863320012887319,0.2865029995640119,0.2866710002223651,0.28683699915806454,0.28700200219949085,0.28716499855120975,0.2873259981473287,0.28748400261004764,0.2876409987608592,0.2877959956725438,0.28794900079568225,0.2880999992291133,0.2882489984234174,0.2883960008621216,0.2885419974724452,0.28868399808804196,0.28882500032583874,0.28896499673525494,0.28910300383965176,0.28923799842596054,0.28937100370724994,0.2895030006766319,0.28963300089041394,0.2897600010037422,0.2898859977722168,0.2900099977850914,0.2901320084929466,0.2902510066827138,0.2903690015276273,0.29048600047826767,0.2905999993284543,0.2907120039065679,0.29082200676202774,0.29093100130558014,0.2910369982322057,0.29114100088675815,0.2912430018186569,0.2913450027505557,0.29144299527009326,0.2915390034516652,0.29163400332132977,0.2917279948790868,0.2918189962704976,0.2919069975614548,0.2919930045803388,0.2920770024259885,0.2921599994103114,0.29224100212256116,0.29231900225083035,0.2923960015177727,0.2924709990620613,0.29254400233427685,0.2926140030225118,0.29268300036589306,0.292751004298528,0.29281600068012875,0.29287899782260257,0.29294000566005707,0.2930000002185504,0.29305800298849743,0.29311300069093704,0.29316700001557666,0.2932189976175626,0.29326899846394855,0.29331599920988083,0.29336199909448624,0.29340599725643796,0.29344899704058963,0.29348800083001453,0.29352599879105884,0.29356300085783005,0.2935980012019475,0.2936299964785576,0.2936599999666214,0.2936890001098315,0.2937160034974416,0.29373999685049057,0.2937629943092664,0.2937849958737691,0.29380399733781815,0.29382000118494034,0.29383599758148193,0.29384999970595044,0.2938609992464383,0.2938699995477994,0.2938770006100337,0.29388399918874103,0.2938869968056679,0.29388899852832157,0.29388900101184845,0.2938870017727216,0.2938830032944679,0.2938769956429799,0.2938690011699994,0.2938599983851115,0.29384800295035046,0.29383400082588196,0.29381900032361347,0.29380200306574505,0.293783001601696,0.2937609975536664,0.2937380025784175,0.293713999291261,0.29368699342012405,0.29365800072749454,0.2936270038286845,0.29359500110149384,0.29356099913517636,0.29352400203545886,0.29348499824603397,0.29344600190718967,0.293404000500838,0.2933590014775594,0.29331299662590027,0.2932659983634949,0.2932160000006358,0.2931639974315961,0.29311000059048337,0.2930560012658437,0.2929980034629504,0.29294000069300336,0.29288100202878314,0.292823001742363,0.29276400059461594,0.29270600030819577,0.29264699916044873,0.2925880054632823,0.29252999772628147,0.2924709965785344,0.29241299877564114,0.29235400011142093,0.29229600230852765,0.2922380045056343,0.29217899839083356,0.2921210005879402,0.2920619994401932,0.2920040041208267,0.2919450004895528,0.2918869952360789,0.29182899991671246,0.2917699987689654,0.2917119984825452,0.2916540006796519,0.2915950020154317,0.2915370042125384,0.2914789964755376,0.29142000029484433,0.2913619975248973,0.29130400468905765,0.2912460019191106,0.29118699828783673,0.2911289955178897,0.29107099771499634,0.29101299742857617,0.2909550021092097,0.2908960034449895,0.29083799570798874,0.2907800003886223,0.2907220001022021,0.2906640022993088,0.29060600449641544,0.2905469958980878,0.2904890055457751,0.2904310077428818,0.2903729975223541,0.29031500220298767,0.2902569994330406,0.29019899914662045,0.2901410013437271,0.29008299857378006,0.2900250007708867,0.28996700048446655,0.2899090001980464,0.28985099494457245,0.289792999625206,0.28973499685525894,0.2896770015358925,0.2896190012494723,0.289561003446579,0.2895030006766319,0.28944599876801175,0.2893880009651184,0.28933000067869824,0.2892720028758049,0.28921399513880414,0.2891559948523839,0.28909799953301746,0.289041002591451,0.2889830047885577,0.28892500201861065,0.28886699428160983,0.28880900144577026,0.2887520020206769,0.28869400173425674,0.2886359964807828,0.2885779986778895,0.2885209992527962,0.28846300144990283,0.2884049986799558,0.2883480017383893,0.28828999896844226,0.2882319986820221,0.2881750042239825,0.2881170039375623,0.28805900116761524,0.28800200174252194,0.2879440039396286,0.28788699706395465,0.2878289942940076,0.287771999835968,0.28771399706602097,0.2876560017466545,0.28759899735450745,0.2875409970680873,0.28748400261004764,0.28742599735657376,0.2873689979314804,0.28731200098991394,0.2872540007034938,0.28719699879487354,0.2871390034755071,0.2870820040504138,0.28702400128046673,0.28696699688831967,0.2869099974632263,0.28685199469327927,0.2867949977517128,0.28673699994881946,0.2866799980401993,0.2866230035821597,0.28656500081221264,0.2865079964200656,0.2864510044455528,0.2863939975698789,0.2863360047340393,0.28627900034189224,0.28622199843327206,0.286164994041125,0.28610700368881226,0.2860499968131383,0.285992997388045,0.2859360029300054,0.2858790010213852,0.28582099825143814,0.28576400379339856,0.2857069994012515,0.28564999749263126,0.28559299806753796,0.2855359986424446,0.285479004184405,0.2854209989309311,0.28536399950583774,0.28530699759721756,0.2852499981721242,0.2851929987470309,0.28513599932193756,0.2850789974133174,0.2850220004717509,0.2849649985631307,0.2849079966545105,0.28485099971294403,0.2847940002878507,0.2847370008627574,0.28468000143766403,0.2846229945619901,0.2845670059323311,0.284510001540184,0.28445299963156384,0.2843959977229436,0.28433900078137714,0.28428199887275696,0.2842249969641368,0.28416800250609714,0.28411199649175006,0.2840549995501836,0.28399800260861713,0.28394100318352383,0.28388399879137677,0.2838279977440834,0.2837710032860438,0.28371399889389676,0.2836570019523303,0.2836010009050369,0.28354399899641675,0.2834869970877965,0.28343099852403003,0.28337399909893674,0.2833169996738434,0.2832609936594963,0.2832039992014567,0.28314700225989026,0.2830910012125969,0.2830339993039767,0.28297700236241025,0.2829210013151169,0.2828639994064967,0.2828080008427302,0.28275099893411,0.2826949978868167,0.28263800342877704,0.28258199989795685,0.2825250029563904,0.282469001909097,0.28241200000047684,0.28235599398612976,0.282299002011617,0.2822430009643237,0.28218599657217663,0.28212999800841015,0.2820729985833168,0.28201700498660404,0.28196100145578384,0.2819040020306905,0.2818480009833972,0.28179099907477695,0.28173500051101047,0.28167899946371716,0.2816219975550969,0.28156599899133045,0.28150999794403714,0.2814530034859975,0.2813970024387042,0.2813409964243571,0.28128500034411746,0.281228003402551,0.2811719998717308,0.2811160037914912,0.28106000522772473,0.2810030033191045,0.2809469997882843,0.2808910012245178,0.28083500266075134,0.28077900409698486,0.2807230030496915,0.2806659961740176,0.28061000009377796,0.28055400401353836,0.28049800048271817,0.2804419994354248,0.2803860008716583,0.28033000230789185,0.2802740012605985,0.280218002696832,0.2801620016495387,0.28010599811871845,0.28004999955495197,0.2799940009911855,0.2799379999438922,0.2798819988965988,0.27982600033283234,0.279769999285539,0.2797140007217725,0.2796579996744792,0.2796020011107127,0.27954600006341934,0.27949000149965286,0.2794340004523595,0.2793780043721199,0.2793219983577728,0.2792670006553332,0.27921099960803986,0.2791550010442734,0.27909899999698,0.27904300143321353,0.27898800124724704,0.27893200019995373,0.27887600163618725,0.2788200030724208,0.27879200130701065};
        //C5F12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2500000252657628e-05,0.0001496484037488699,0.00041431836871197447,0.0008137636371733,0.0013639262858002137,0.002074985202246656,0.0029289800052841506,0.003906670007078598,0.0049980999901890755,0.006193469938201209,0.007482989924028516,0.00885687000118196,0.010305300044516722,0.011818500080456337,0.013386700069531798,0.014999999975164732,0.017499999919285376,0.02050000025580327,0.02349999997143944,0.02700000023469329,0.03049999972184499,0.034500000377496086,0.03800000001986822,0.04249999951571226,0.04699999994287888,0.051500000059604645,0.056000000797212124,0.06099999944368998,0.06600000026325385,0.07050000006953876,0.07549999964733918,0.08100000023841858,0.08550000004470348,0.08999999985098839,0.09450000027815501,0.09850000031292439,0.10300000074009101,0.10649999976158142,0.1089999998609225,0.1119999997317791,0.11400000005960464,0.11599999976654847,0.11749999908109506,0.11950000002980232,0.12100000058611234,0.12199999888737996,0.12299999967217445,0.12399999983608723,0.125,0.12600000202655792,0.12689302240808806,0.1277389998237292,0.12867999946077666,0.1296249988178412,0.13062099864085516,0.13166699931025505,0.13276400168736777,0.13386699929833412,0.13493300105134645,0.13596000025669733,0.13694899901747704,0.137899998575449,0.13881300017237663,0.13968800008296967,0.14052600165208182,0.14132499819000563,0.142085999250412,0.142815999686718,0.14352100094159445,0.14420299852887788,0.14485999941825867,0.14549299950400987,0.14610200002789497,0.14668700223167738,0.14724599942564964,0.1477809982995192,0.14829100047548613,0.14878199870387712,0.1492569980521997,0.14971599852045378,0.15015999972820282,0.15058800081411997,0.1509999968111515,0.15139800061782202,0.15177900095780691,0.15214500079552332,0.15249500051140785,0.15283300106724104,0.15316000084082285,0.15347899869084358,0.15378699948390326,0.154084000736475,0.15437100206812224,0.15464899813135466,0.15491700048247972,0.15517500042915344,0.1554219995935758,0.15566200017929077,0.1558960018058618,0.1561220002671083,0.15634299938877425,0.1565569986899694,0.15676499779025713,0.15696599831183752,0.1571609986325105,0.15734999751051268,0.15753200029333433,0.15770799914995828,0.157880999147892,0.1580490010480086,0.15821400036414465,0.1583739990989367,0.15853100145856538,0.1586829995115598,0.15883099908630052,0.15897599856058756,0.15911500031749407,0.1592499961455663,0.1593769999841849,0.15949599941571554,0.1596089998881022,0.15971400092045465,0.15981299926837286,0.1599029985566934,0.15998600050807,0.16006299977501234,0.16013200084368387,0.16019700095057487,0.16026299943526587,0.16032900164524713,0.16039500012993813,0.16046000147859255,0.16052599996328354,0.1605920009315014,0.1606569985548655,0.16072299952308336,0.1607890004913012,0.16085400059819221,0.16091900194684663,0.1609830011924108,0.16104599833488464,0.1611079995830854,0.1611699995895227,0.16123099873463312,0.16129099826018015,0.16135099778572717,0.1614099989334742,0.1614679992198944,0.1615259995063146,0.16158300141493478,0.1616390012204647,0.16169399892290434,0.1617479994893074,0.16180099919438362,0.16185500100255013,0.1619069998462995,0.1619589999318123,0.16200900077819824,0.16205900038282076,0.1621090012292067,0.16215799873073897,0.1622060015797615,0.1622529998421669,0.16229999934633574,0.16234599923094115,0.16239100073774657,0.16243600100278854,0.16247999916474024,0.16252299894889197,0.16256500035524368,0.16260699927806854,0.16264799982309341,0.1626890003681183,0.16272799794872603,0.16276700297991434,0.16280599931875864,0.1628439985215664,0.16288000096877417,0.16291599969069162,0.16295199965437254,0.16298699999849,0.16302100072304407,0.16305400306979814,0.1630869967242082,0.1631180023153623,0.1631490004559358,0.16318000108003616,0.16320900122324625,0.16323800012469292,0.1632660006483396,0.1632940024137497,0.1633210008343061,0.16334699963529906,0.16337299967805544,0.16339699923992157,0.16342100128531456,0.1634450008471807,0.1634680007894834,0.16349000111222267,0.16351100181539854,0.1635309991737207,0.16355100149909654,0.16357100009918213,0.16358899821837744,0.16360700006286302,0.1636239985624949,0.16363999992609024,0.16365600004792213,0.16367100179195404,0.1636860010524591,0.16369899859031042,0.16371199985345206,0.1637250011165937,0.16373600189884505,0.1637469989558061,0.1637569988767306,0.16376599917809168,0.16377399861812592,0.16378199929992357,0.16379000122348467,0.16379600142439207,0.1638019991417726,0.16380600134531656,0.1638110006848971,0.16381500040491423,0.1638180029888948,0.16381999850273132,0.16382199774185816,0.16382299860318503,0.16382300108671188,0.16382299984494844,0.1638210006058216,0.16381899764140448,0.1638170008858045,0.16381399830182394,0.16380999982357025,0.1638059988617897,0.16380000238617262,0.1637940009435018,0.1637880007425944,0.16378099968036017,0.16377300024032593,0.1637639986972014,0.16375400250156721,0.16374300171931586,0.1637319984535376,0.16372100015481314,0.1637079988916715,0.16369500011205673,0.16368099922935167,0.1636670008301735,0.16365200032790503,0.16363600020607313,0.1636190004646778,0.16360100110371908,0.16358400136232376,0.16356600200136504,0.163546002159516,0.163526002317667,0.16350500037272772,0.1634840009113153,0.16346199934681258,0.16343999778230986,0.16341599822044373,0.16339199741681418,0.1633670007189115,0.16334200029571852,0.16331600149472555,0.16328900183240572,0.16326100006699562,0.16323300078511238,0.1632050002614657,0.16317499925692877,0.16314500073591867,0.1631140001118183,0.16308199986815453,0.16304900124669075,0.16301599889993668,0.16298199941714606,0.1629479999343554,0.16291199872891107,0.16287600000699362,0.1628400000433127,0.16280200084050497,0.16276499877373377,0.16272600119312605,0.16268600150942802,0.16264599934220314,0.1626069980363051,0.16256699959437051,0.16252699991067251,0.16248799860477448,0.16244799892107645,0.16240799923737845,0.16236899917324385,0.16232899824778238,0.16228999942541122,0.1622499997417132,0.16221100091934204,0.1621709999938806,0.16213099906841913,0.16209199776252112,0.1620519980788231,0.1620129980146885,0.1619729995727539,0.1619339995086193,0.16189399858315787,0.16185500100255013,0.1618150013188521,0.16177599877119064,0.16173600032925606,0.16169700026512146,0.16165800020098686,0.16161800175905228,0.16157900045315424,0.16153900076945624,0.16150000194708505,0.1614609993994236,0.16142099971572557,0.16138200337688127,0.16134199996789297,0.16130299990375838,0.16126399983962378,0.16122400015592575,0.16118500009179115,0.1611459975441297,0.1611070024470488,0.16106700027982393,0.16102799897392592,0.16098899766802788,0.16094900046785673,0.16091000040372214,0.16087100033958754,0.16083199779192606,0.1607920005917549,0.16075299680233002,0.16071399797995886,0.16067499915758768,0.16063599909345308,0.16059700027108192,0.1605570005873839,0.1605180005232493,0.16047899797558784,0.1604399991532167,0.1604009990890821,0.1603620002667109,0.1603230002025763,0.1602830005188783,0.16024400169650713,0.16020500039060911,0.16016600032647452,0.16012700026233992,0.16008799895644188,0.16004900013407072,0.16001000006993613,0.15997100124756494,0.1599319986999035,0.15989299987753233,0.15985400105516115,0.15981499974926314,0.15977599968512854,0.15973700334628424,0.1596979983150959,0.15965900321801504,0.15961999942859015,0.15958099936445555,0.15954199930032095,0.1595029979944229,0.15946500251690546,0.159425999969244,0.15938700114687285,0.15934799859921137,0.15930900474389395,0.1592699997127056,0.15923100089033446,0.15919299920399985,0.1591539978981018,0.15911499907573065,0.15907600025335947,0.15903700018922487,0.15899899726112685,0.15896000092228255,0.15892100085814795,0.15888200079401335,0.1588439978659153,0.158805001527071,0.15876600022117296,0.15872700015703836,0.1586889997124672,0.15864999840656915,0.15861100206772485,0.1585730016231537,0.15853400031725565,0.15849500025312105,0.15845700105031332,0.15841799974441528,0.15837899843851724,0.15834099923570952,0.15830200165510178,0.15826300034920374,0.158225001146396,0.15818599984049797,0.1581479993959268,0.15810900057355562,0.1580710013707479,0.1580320013066133,0.15799300000071526,0.1579549970726172,0.15791599825024605,0.15787800028920174,0.15783900022506714,0.15780099978049597,0.15776200219988823,0.15772399927179018,0.15768499796589217,0.15764700000484785,0.15760899831851324,0.15757000197966894,0.15753200029333433,0.15749300147096315,0.15745499978462854,0.15741600220402083,0.15737800051768622,0.15734000379840532,0.15730100000898042,0.1572630008061727,0.1572249991198381,0.1571859990557035,0.15714799985289574,0.15711000065008798,0.15707100058595339,0.15703300138314566,0.1569949984550476,0.15695599963267645,0.1569180004298687,0.15688000122706094,0.15684200078248978,0.15680299823482832,0.15676500151554743,0.1567269985874494,0.1566890006264051,0.1566499980787436,0.1566120001176993,0.15657399967312813,0.15653600171208382,0.15649800126751265,0.15646000082294145,0.15642100075880686,0.15638299907247225,0.15634500111142793,0.15630699942509332,0.15626899898052216,0.15623100101947784,0.15619300057490668,0.15615499888857207,0.15611600130796432,0.15607799837986627,0.15603999917705855,0.1560019999742508,0.15596400201320648,0.15592599908510843,0.15588799864053726,0.15585000067949295,0.15581200271844864,0.1557739997903506,0.15573599934577942,0.15569799890120825,0.15566000094016394,0.15562200297911963,0.15558400005102158,0.1555459996064504,0.15550800040364265,0.1554709995786349,0.15543299789230028,0.15539499993125597,0.1553569994866848,0.15531899904211363,0.15528099983930588,0.15524300063649812,0.15520500019192696,0.1551669997473558,0.15512999892234802,0.15509199971954027,0.1550539992749691,0.15501599883039793,0.15497799962759018,0.15494100004434586,0.1549030008415381,0.15486500163873038,0.15482699871063232,0.154789000749588,0.15475199992458025,0.15471400072177252,0.15467600151896477,0.15463900193572044,0.15460100149114928,0.15456300104657808,0.15452499811848006,0.15448800226052603,0.15444999809066454,0.15441199764609337,0.15437499806284904,0.15433700134356818,0.15429899841547012,0.1542619988322258,0.15422399962941805,0.15418700004617372,0.154149000843366,0.1541109991570314,0.15407399957378706,0.15403599912921587,0.15399899954597154,0.15396099910140038,0.15392399951815605,0.15388599907358488,0.15384799987077713,0.15381099904576936,0.15377299984296164,0.15373600025971731,0.15369799981514612,0.1536610002319018,0.15362400064865747,0.15358600144584975,0.15354900062084198,0.15351100265979767,0.1534740005930265,0.1534360001484553,0.15339900056521097,0.15336100136240324,0.15332399929563204,0.15328700095415115,0.15324900050957999,0.15321199844280878,0.15317499761780104,0.15313699965675673,0.15311900029579797};
        C6F14={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.0416666763527852e-05,9.90675819897054e-05,0.00023346518476804098,0.00040582845637497184,0.0006131872214609757,0.0008649057514655093,0.001156919994779552,0.0014849442716998358,0.0018605195897786568,0.002273166183537493,0.002723323026051124,0.0032153764623217285,0.0037402684489885965,0.004300958593375981,0.00488944995837907,0.005500000047807892,0.006515154498629272,0.008123510361959537,0.00993688233817617,0.011940864070008198,0.014727070772399506,0.018013485086460907,0.023000000044703484,0.02849999985968073,0.03549999992052714,0.04249999951571226,0.05099999997764826,0.060499999982615314,0.071000000461936,0.08199999978144963,0.09450000027815501,0.10900000048180421,0.1240000023196141,0.1399999981125196,0.15649999926487604,0.1724999981621901,0.18849999954303107,0.20149999981125197,0.21350000301996866,0.22399999822179475,0.23350000008940697,0.2410000003874302,0.24799999967217445,0.25349999715884525,0.2579999988277753,0.2629999990264575,0.2669999996821086,0.27100000033775967,0.2750000034769376,0.27900000164906186,0.2843420207500458,0.28995800018310547,0.2954619973897934,0.302055003742377,0.308998001118501,0.3162899961074193,0.3239319920539856,0.33161700268586475,0.33904099961121875,0.34620199849208194,0.3531020035346349,0.3597410023212433,0.36611799895763397,0.37223399927218753,0.3780889982978503,0.3836810017625491,0.3890129973491033,0.39413200070460636,0.3990819975733757,0.4038640037178993,0.408479002614816,0.41292699923117954,0.4172079985340436,0.42131999880075455,0.42526500175396603,0.4290429974595706,0.4326540008187294,0.43612799793481827,0.4394960055748622,0.44275499631961185,0.44590599834918976,0.4489499976237615,0.4518880024552345,0.4547180011868477,0.4574420054753621,0.4600579962134361,0.46256600071986514,0.46498699982961017,0.46734000494082767,0.46962299942970276,0.47183799743652344,0.4739840005834897,0.47606200476487476,0.47807099918524426,0.4800109962622325,0.48188300182422,0.48368599514166516,0.48543299982945126,0.48713599890470505,0.4887950047850609,0.4904099976023038,0.49198000133037567,0.4935059994459152,0.4949890002608299,0.4964280004302661,0.49782299747069675,0.49917299548784894,0.5004870121677717,0.50177401304245,0.503031998872757,0.5042619953552882,0.5054640024900436,0.5066380053758621,0.5077830056349436,0.5088999966780344,0.5099879950284958,0.5110489974419276,0.5120700051387151,0.5130419979492823,0.513965000708898,0.514836996793747,0.5156589994827906,0.5164309988419215,0.5171539982159933,0.5178269992272059,0.5184510002533594,0.5190249979496002,0.5195740063985189,0.5201229949792227,0.5206710000832876,0.5212200085322062,0.5217679937680563,0.5223160088062286,0.5228639990091324,0.5234119941790899,0.5239600042502085,0.524507001042366,0.5250520010789236,0.5255930026372274,0.5261280089616776,0.5266580035289129,0.527184009552002,0.527703990538915,0.5282190044720968,0.5287300000588099,0.5292350053787231,0.5297360022862753,0.5302309989929199,0.5307220021883646,0.5312069853146871,0.5316879997650782,0.5321629991134008,0.5326340049505234,0.5330989956855774,0.5335600127776464,0.5340160032113394,0.5344669967889786,0.5349119951327642,0.5353529949982961,0.5357890079418818,0.5362199991941452,0.5366459985574087,0.5370679944753647,0.5374850034713745,0.5378970007101694,0.538303996125857,0.5387059996525446,0.5391039997339249,0.539495994647344,0.5398829976717631,0.5402659972508749,0.5406429966290792,0.5410160074631373,0.5413839916388193,0.5417460004488627,0.5421039958794912,0.5424570043881735,0.5428050061066946,0.5431480010350546,0.5434859891732534,0.543819010257721,0.544146994749705,0.5444700022538503,0.5447889963785807,0.5451019952694575,0.5454110006491343,0.5457140058279037,0.5460139860709509,0.5463090091943741,0.5465980023145676,0.5468830019235611,0.5471629947423935,0.5474389940500259,0.5477090130249659,0.5479740103085836,0.5482339958349863,0.5484899977842966,0.5487409979104996,0.5489859928687414,0.5492270042498907,0.5494629989067713,0.5496939917405447,0.5499200026194254,0.5501420050859451,0.55035799741745,0.5505690028270086,0.550775999824206,0.5509779999653498,0.5511750131845474,0.551366999745369,0.5515539993842443,0.5517359922329584,0.5519140064716339,0.552087997396787,0.5522559980551401,0.552419995268186,0.552578995625178,0.5527329991261164,0.5528820008039474,0.553026000658671,0.553166002035141,0.5533000032107035,0.5534300009409586,0.5535550018151602,0.5536750008662542,0.5537900080283483,0.5538999934991201,0.5540050019820532,0.5541060020526251,0.5542020003000895,0.5542930016915003,0.5543790012598038,0.5544599990049998,0.5545360048611959,0.5546080023050308,0.5546739995479584,0.5547359883785248,0.5547939985990524,0.5548470119635264,0.5548949937025706,0.5549389918645223,0.5549780080715815,0.5550109992424647,0.5550399969021479,0.5550640026728312,0.5550839950640997,0.5550980021556219,0.5551079958677292,0.5551130026578903,0.5551129976908366,0.5551079909006754,0.5550990055004755,0.5550839900970459,0.5550649911165237,0.5550410101811091,0.5550119976202647,0.5549789915482203,0.5549400001764297,0.5548970053593317,0.5548490037520727,0.5547960003217062,0.5547390033801397,0.5546769946813583,0.554610992471377,0.5545399934053421,0.5544640074173609,0.5543829947710037,0.554297998547554,0.5542079955339432,0.5541130055983862,0.5540129989385605,0.5539089938004812,0.5537989983956019,0.5536850094795227,0.5535660038391749,0.5534429997205734,0.5533140103022257,0.5531809975703558,0.5530429929494858,0.5529000063737234,0.5527529964844385,0.5526000012954077,0.5524429976940155,0.552281990647316,0.5521149983008703,0.5519439925750097,0.5517680048942566,0.5515900005896887,0.5514119962851206,0.5512340019146601,0.5510560025771459,0.5508779982725779,0.5507009973128637,0.5505229930082957,0.5503449986378351,0.5501680076122284,0.5499909967184067,0.5498129973808924,0.5496359964211782,0.5494590004285177,0.5492810060580572,0.5491039951642355,0.5489269942045212,0.5487500031789144,0.5485729972521464,0.5483960012594858,0.5482190002997717,0.5480419943730036,0.5478660017251968,0.5476890057325363,0.5475119998057684,0.5473360021909078,0.5471590061982473,0.5469829986492792,0.5468060026566187,0.5466300050417582,0.5464539974927902,0.5462769965330759,0.5461009939511617,0.5459250013033549,0.5457489887873331,0.5455729961395264,0.5453969836235046,0.5452209959427515,0.5450450032949448,0.5448689957459768,0.5446939965089163,0.544517993927002,0.5443420012791952,0.5441670020421346,0.5439910044272741,0.543815995256106,0.5436399976412455,0.5434649934371313,0.5432899991671244,0.5431150048971176,0.5429390023152033,0.5427640080451965,0.5425889988740286,0.542413999636968,0.5422390003999075,0.5420640011628469,0.5418900003035864,0.541714996099472,0.5415399968624115,0.5413649926582972,0.5411910017331442,0.5410160024960836,0.540842001636823,0.5406669974327087,0.540493001540502,0.5403189907471339,0.5401439964771271,0.5399699906508127,0.5397959997256597,0.5396220038334528,0.5394480029741923,0.539273997147878,0.5391000012556711,0.5389259954293569,0.5387519945700964,0.5385789920886358,0.5384050061305364,0.5382309953371683,0.5380580027898153,0.5378840068976084,0.5377109944820404,0.5375369985898336,0.5373640010754267,0.5371899952491125,0.5370169927676519,0.53684401512146,0.536671002705892,0.5364980002244314,0.5363250027100245,0.5361520002285639,0.5359790076812109,0.5358060002326965,0.535632997751236,0.5354599952697754,0.5352879961331686,0.535114993651708,0.5349420011043549,0.534770001967748,0.5345970094203949,0.5344249953826269,0.53425299624602,0.5340799937645594,0.5339079896608988,0.5337360054254532,0.5335640013217926,0.5333920121192932,0.5332199980815252,0.533048003911972,0.5328760047753652,0.5327040006717046,0.5325320015350977,0.5323599974314371,0.5321890016396841,0.5320169925689697,0.5318449934323629,0.5316740026076635,0.5315020034710566,0.5313310076793035,0.5311590035756429,0.5309879978497823,0.5308170020580292,0.5306459963321686,0.5304749955733618,0.5303029914697012,0.5301320006450018,0.5299609949191412,0.5297909925381342,0.5296200017134348,0.5294489959875742,0.5292780051628748,0.529107004404068,0.5289370069901148,0.5287659962972006,0.5285959939161936,0.5284249981244405,0.5282550007104874,0.5280839949846268,0.5279139975706736,0.527743990222613,0.5275729944308599,0.5274030069510142,0.5272330045700073,0.5270630021890005,0.5268929998079935,0.5267230023940405,0.5265529950459799,0.5263840059439341,0.5262140035629272,0.5260439962148666,0.525874008735021,0.5257050096988678,0.5255349973837534,0.525366003314654,0.5251960059007009,0.5250270068645477,0.5248579978942871,0.5246879905462265,0.5245189915100733,0.5243500024080276,0.5241809984048208,0.5240120043357214,0.5238430003325144,0.5236740112304688,0.5235049972931544,0.5233359982570013,0.5231669992208481,0.5229980001846949,0.5228299895922343,0.5226609955231348,0.5224930097659429,0.5223240007956823,0.5221560001373291,0.5219870110352834,0.5218190054098765,0.5216499964396158,0.5214820057153702,0.5213140000899633,0.5211459994316101,0.5209780037403107,0.5208100030819575,0.5206420024236044,0.52047398686409,0.5203059961398443,0.5201379954814911,0.5199700097242991,0.5198030024766922,0.519635001818339,0.5194669961929321,0.5192999939123789,0.5191319982210795,0.5189650058746338,0.5187979986270269,0.5186300029357275,0.518463005622228,0.518295998374621,0.5181290010611216,0.5179620087146759,0.5177949965000153,0.5176280041535696,0.5174610018730164,0.5172939896583557,0.51712699731191,0.5169599999984106,0.5167929977178574,0.5166270037492117,0.5164600014686584,0.516293004155159,0.5161270002524058,0.5159599979718527,0.5157939990361532,0.5156280001004537,0.5154610027869543,0.5152950038512548,0.5151289900143942,0.5149630010128021,0.5147969971100489,0.5146309981743494,0.51446499923865,0.5142990003029505,0.5141329964001974,0.5139670024315516,0.5138010034958521,0.5136359930038452,0.5134700040022532,0.5133040100336075,0.5131389945745468,0.5129730006059011,0.5128079950809479,0.5126419961452484,0.5124769955873489,0.5123120099306107,0.5121460010608038,0.5119809955358505,0.5118160049120585,0.5116509993871053,0.5114859938621521,0.51132100323836,0.5111560026804606,0.5109909921884537,0.5108270049095154,0.5106619894504547,0.5104970037937164,0.510332003235817,0.5101680060227712,0.5100030104319254,0.5098390032847723,0.509673997759819,0.5095100104808807,0.5093460033337275,0.5092630038658778};
    //C7F16={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.291666692144645e-05,0.00019906758522362603,0.000428600166439234,0.0006878854086001714,0.0009859570564003661,0.0013188475471300383,0.0016825111815705895,0.0020750463784982762,0.0024945644351343312,0.0029391770367510617,0.0034070740027042725,0.0039129575015977025,0.004452554974704981,0.005013017527138193,0.005592087477756043,0.006217187542157869,0.007289062448156376,0.008625000094374021,0.00996820768341422,0.011694931657984853,0.014008731814101338,0.017000000225380063,0.020499999945362408,0.024499999669690926,0.02850000017012159,0.03249999973922968,0.037500000558793545,0.04249999982615312,0.04649999986092249,0.051499999749163784,0.05599999986588955,0.060499999982615314,0.06499999947845936,0.06900000013411045,0.07299999954799812,0.07749999935428302,0.08150000063081582,0.08500000089406967,0.0889999990661939,0.09249999995032947,0.0959999995927016,0.09949999923507373,0.10299999949832757,0.10700000077486038,0.10999999940395355,0.11400000005960464,0.11700000117222469,0.12000000042219956,0.12300000029305617,0.12600000016391277,0.12939750775694847,0.1327460010846456,0.13622500250736871,0.14007199928164482,0.14412199954191843,0.14837600042422613,0.1528329998254776,0.15731599802772203,0.16164499893784523,0.16582300141453743,0.1698480024933815,0.173720000932614,0.17744099845488867,0.18100899954636893,0.18442600096265474,0.18769000098109245,0.19080199922124544,0.19378899907072386,0.1966789998114109,0.1994709993402163,0.20216500262419382,0.20476199934879938,0.20726099982857704,0.20966300119956335,0.21196700011690459,0.21417499954501787,0.21628399938344955,0.21831400195757547,0.2202829991777738,0.22218899801373482,0.22403200094898543,0.2258130001525084,0.2275309997300307,0.22918800016244253,0.23078100134929022,0.2323130009075006,0.2337809999783834,0.23519899944464365,0.23657800008853277,0.23791600142916045,0.23921299974123636,0.24047099923094115,0.2416880006591479,0.2428669979174932,0.2440049983561039,0.24510300159454346,0.246159998079141,0.24718499928712845,0.24818499883015951,0.24915799871087074,0.2501060056189696,0.25102900216976803,0.2519260024031003,0.2527970050772031,0.2536429986357689,0.25446299960215885,0.2552580013871193,0.25603100657463074,0.2567880004644394,0.25752900044123334,0.2582540015379588,0.2589609995484352,0.2596520086129506,0.2603269964456558,0.26098600526650745,0.26162800441185635,0.2622540021936099,0.26285700251658756,0.26343100269635517,0.26397600024938583,0.2644920026262601,0.2649789998928706,0.2654380028446515,0.26586699734131497,0.26626699914534885,0.26663800328969955,0.26698100318511325,0.2673090025782585,0.2676369994878769,0.2679639980196953,0.26829200734694797,0.26861999680598575,0.26894700278838474,0.2692749996980031,0.2696020007133484,0.2699289992451668,0.27025700112183887,0.2705820028980573,0.27090400209029514,0.2712239995598793,0.2715420002738635,0.2718560000260671,0.27216699967781705,0.2724750017126401,0.27278000116348267,0.2730820005138715,0.2733820031086604,0.2736790006359418,0.2739730005462964,0.27426299701134366,0.27455100417137146,0.274837002158165,0.27511899669965106,0.27539899448553723,0.2756749987602234,0.275948998828729,0.27622000128030777,0.276488999525706,0.2767540042599042,0.2770159989595413,0.27727499852577847,0.2775310004750888,0.2777850031852722,0.2780359983444214,0.2782840033372243,0.27852799991766614,0.27876999974250793,0.27900999784469604,0.2792470008134842,0.2794800003369649,0.27971099813779193,0.279939000805219,0.28016399840513867,0.2803869942824046,0.2806060016155243,0.2808230022589366,0.28103599945704144,0.28124599903821945,0.2814550002415975,0.281660000483195,0.2818620006243388,0.2820609932144483,0.28225699812173843,0.2824520021677017,0.28264300525188446,0.2828310007850329,0.2830150028069814,0.2831979940334956,0.2833779975771904,0.2835550010204315,0.2837290018796921,0.2838989968101184,0.28406700243552524,0.2842319955428441,0.2843949993451436,0.28455500056346256,0.2847120016813278,0.28486500183741253,0.2850159953037898,0.2851650019486745,0.2853110035260518,0.285452996691068,0.2855930030345917,0.2857300043106079,0.28586499641338986,0.2859959974884987,0.28612500180800754,0.28625000019868213,0.2863729993502299,0.286492998401324,0.2866099973519643,0.286724994579951,0.28683599829673767,0.28694500029087067,0.2870510046680768,0.28715399901072186,0.28725499908129376,0.28735200067361194,0.2874469980597496,0.2875379944841067,0.2876270040869713,0.287712998688221,0.2877970015009244,0.28787700086832047,0.28795500099658966,0.2880300010244052,0.28810200095176697,0.28817200164000195,0.2882379988829295,0.2883019944032033,0.2883629997571309,0.28842199593782425,0.28847699612379074,0.28853000203768414,0.2885790020227432,0.28862599780162174,0.28866999844710034,0.28871199985345203,0.2887510011593501,0.28878600150346756,0.28881900012493134,0.28884900112946826,0.2888769954442978,0.2889019971092542,0.28892399619023007,0.28894199679295224,0.28895899653434753,0.28897299865881604,0.2889840006828308,0.2889920026063919,0.28899699697891873,0.2889980028072993,0.2889980028072993,0.28899499773979187,0.28898899505535763,0.2889799972375234,0.2889679993192355,0.2889540021618207,0.2889380032817523,0.28891800592343014,0.28889500349760056,0.2888690009713173,0.28884099920590717,0.28881099820137024,0.28877799957990646,0.28874099751313526,0.28870200365781784,0.2886589964230855,0.28861399988333386,0.2885669991374016,0.28851700325806934,0.288463997344176,0.2884080037474632,0.2883490001161893,0.2882879972457886,0.2882239992419879,0.28815700113773346,0.2880870004494985,0.2880149980386098,0.28794099887212116,0.28786300371090573,0.2877830018599828,0.28769900153080624,0.28761200110117596,0.2875230014324188,0.2874320025245349,0.2873380010326703,0.28724199781815213,0.2871459995706876,0.2870509997010231,0.28695499897003174,0.2868590032060941,0.286763995885849,0.2866679976383845,0.28657299528519314,0.2864769995212555,0.28638200213511783,0.28628599892059964,0.2861909990509351,0.2860949983199437,0.28599999845027924,0.28590499858061474,0.2858090003331502,0.28571399797995883,0.2856190005938212,0.2855240007241567,0.28542900333801907,0.2853330026070277,0.28523799777030945,0.2851430003841718,0.2850480005145073,0.2849530006448428,0.28485800325870514,0.28476300090551376,0.28466800103584927,0.2845740045110385,0.2844789996743202,0.28438399732112885,0.2842889999349912,0.2841940000653267,0.2840999960899353,0.2840050011873245,0.28390999883413315,0.28381599734226864,0.28372100243965787,0.2836270009477933,0.28353199859460193,0.28343800206979114,0.28334299971659976,0.28324900070826214,0.2831540033221245,0.2830600043137868,0.2829649994770686,0.2828710004687309,0.2827769989768664,0.28268300493558246,0.28258800009886426,0.2824939986069997,0.2823999995986621,0.2823059981067975,0.2822119990984599,0.2821180075407028,0.28202400108178455,0.28192999710639316,0.28183599809805554,0.28174200157324475,0.28164799759785336,0.2815539985895157,0.281459999581178,0.2813669989506404,0.2812730049093564,0.2811789984504382,0.2810849994421005,0.28099199881156284,0.28089799731969833,0.28080399831136066,0.2807110051314036,0.28061699867248535,0.28052400052547455,0.28043000400066376,0.2803369959195455,0.28024300187826157,0.28014999876419705,0.28005700061718625,0.2799629991253217,0.27986999849478406,0.27977700034777325,0.2796829988559087,0.2795900031924248,0.27949700504541397,0.27940400689840317,0.27931100130081177,0.27921799818674725,0.27912500500679016,0.27903199444214505,0.27893900374571484,0.27884599566459656,0.27875300248463947,0.27865999937057495,0.27856700122356415,0.27847399562597275,0.27838100244601566,0.27828799933195114,0.27819600452979404,0.27810299893220264,0.2780099958181381,0.2779180034995079,0.2778249979019165,0.2777320022384326,0.2776399999856949,0.2775470018386841,0.2774549995859464,0.27736200392246246,0.27726999670267105,0.27717799693346024,0.2770850012699763,0.2769930015007655,0.2769009992480278,0.2768079986174901,0.27671600381533307,0.2766239990790685,0.27653199930985767,0.27643899867932004,0.2763469989101092,0.2762549991408984,0.2761629968881607,0.2760709971189499,0.27597899983326596,0.27588700006405514,0.27579499781131744,0.27570299804210663,0.2756109982728958,0.2755190034707387,0.2754280020793279,0.27533599734306335,0.27524399757385254,0.2751520052552223,0.2750609988967578,0.27496899912754696,0.27487699687480927,0.27478600293397903,0.2746940031647682,0.2746029992898305,0.2745109920700391,0.27441999812920886,0.27432799835999805,0.2742369994521141,0.2741450021664302,0.27405400077501935,0.27396300186713535,0.2738709996143977,0.2737800007065137,0.27368899683157605,0.27359800040721893,0.2735060006380081,0.2734150017301242,0.27332399785518646,0.27323299646377563,0.2731420000394185,0.2730509986480077,0.27295999725659686,0.2728690008322398,0.2727780019243558,0.272687000532945,0.27259599914153415,0.2725049977501233,0.27241499970356625,0.27232400079568225,0.2722329994042714,0.2721419980128606,0.27205199748277664,0.2719610035419464,0.27186999718348187,0.27177999913692474,0.2716889977455139,0.2715989996989568,0.27150799830754596,0.2714180052280426,0.27132699886957806,0.27123699833949405,0.2711460043986638,0.271056001385053,0.270966000854969,0.2708750019470851,0.2707849939664205,0.2706950008869171,0.27060400446256,0.27051399896542233,0.2704240009188652,0.27033399790525436,0.2702439973751704,0.27015400181214017,0.27006400128205615,0.2699739982684453,0.26988400022188824,0.26979399969180423,0.26970400164524716,0.26961400111516315,0.2695240005850792,0.26943400005499524,0.2693449979027112,0.26925499737262726,0.2691650042931239,0.2690749987959862,0.26898599912722904,0.26889600108067196,0.2688059980670611,0.268716998398304,0.26862700283527374,0.2685380006829898,0.26844799766937893,0.2683590079347293,0.26826899747053784,0.2681800027688344,0.26809099564949673,0.2680009976029396,0.26791200041770935,0.2678230032324791,0.26773299525181454,0.267644003033638,0.26755499839782715,0.2674659937620163,0.26737700154383975,0.2672879993915558,0.26719799886147183,0.2671090041597684,0.2670200044910113,0.2669309973716736,0.26684199770291644,0.26675299803415936,0.2666650017102559,0.26657599955797195,0.2664869998892148,0.26639800022045773,0.2663089955846469,0.2662209967772166,0.26613199959198636,0.2660430024067561,0.2659540002544721,0.2658660014470418,0.2657770017782847,0.2656889980038007,0.26560000081857044,0.26551200201114017,0.2654229973753293,0.26533499856789905,0.2652459964156151,0.2651579976081848,0.26506900042295456,0.2649809991319974,0.26489300032456714,0.26480400065581006,0.2647159993648529,0.26462800055742264,0.2645399992664655,0.2644960011045138};
    //C8F18={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,2.0833333527055704e-05,0.0001905986155179562,0.0004284837899225143,0.000720486932550557,0.0010582811616283532,0.001435363112250343,0.001846186302524681,0.002300142504585286,0.0027887349909481904,0.003296887482671688,0.0038177824850815036,0.004344617521079878,0.00487056754839917,0.0053888224841405945,0.005892572497638564,0.006382812435428302,0.006901409438190361,0.007240498826528589,0.007240498710113267,0.007745400342779855,0.008102531234423319,0.009501247045894464,0.01099999986278514,0.013499999962126216,0.01600000006146729,0.01899999985471368,0.02200000003601114,0.025999999915560085,0.029999999639888603,0.034500000067055225,0.03899999987334013,0.04350000030050675,0.04800000010679165,0.053000000305473804,0.058000000193715096,0.06250000031044085,0.06699999918540318,0.071000000461936,0.07449999948342641,0.07699999958276749,0.0800000000745058,0.08149999938905239,0.08349999909599622,0.08500000089406967,0.08600000043710072,0.08699999998013179,0.08800000076492627,0.0889999990661939,0.08999999985098839,0.09099999939401944,0.09222223547597726,0.09350150016446908,0.09477110020816326,0.09623500021795432,0.09777720086276531,0.09939770090083282,0.10109599928061168,0.1028049997985363,0.10445400017003219,0.10604399939378102,0.10757699919243653,0.10905000008642673,0.11046500007311504,0.11182199915250142,0.11312099980811278,0.11436099993685882,0.11554200078050296,0.11667600087821484,0.11777199991047382,0.11883099998037021,0.11985199960569541,0.12083599964777629,0.12178200048704942,0.1226910005013148,0.12356200193365414,0.1243969996770223,0.12519300046066442,0.1259589989980062,0.12670099983612695,0.12742000197370848,0.1281139999628067,0.1287850004931291,0.1294310006002585,0.1300530011455218,0.13065200050671896,0.13122600068648657,0.13177699719866118,0.13230800131956735,0.13282199949026108,0.13332200050354004,0.1338069997727871,0.1342760001619657,0.13473099966843924,0.1351690006752809,0.13559199993809065,0.1359999986986319,0.1363929994404316,0.13677299891908964,0.13714300096035004,0.1375030018389225,0.1378530003130436,0.13819400096933046,0.138524000843366,0.13884600127736726,0.1391570009291172,0.13945699979861578,0.139748003333807,0.14003200083971024,0.14030900225043297,0.14058000097672144,0.14084399864077568,0.14110200107097626,0.14135299871365228,0.1415990007420381,0.1418389988442262,0.14207199960947037,0.14229800055424371,0.142515999575456,0.14272200192014375,0.14291799813508987,0.1431019976735115,0.14327599853277206,0.14343799899021784,0.14358900114893913,0.1437279979387919,0.14385700225830078,0.14397499958674112,0.14408699919780096,0.14419900129238764,0.1443109984199206,0.14442400137583414,0.14453600098689398,0.14464799935619035,0.14476000145077705,0.14487200106183687,0.14498399943113327,0.14509600152571997,0.14520700027545294,0.14531700064738592,0.14542600139975548,0.14553499842683473,0.14564199994007745,0.14574700221419334,0.14585099990169206,0.1459550013144811,0.1460579993824164,0.14615899821122488,0.14625899866223335,0.14635799825191498,0.14645699908336005,0.1465539994339148,0.14665000016490617,0.14674499879280725,0.14683799942334494,0.14693100129564604,0.14702300106485686,0.14711300283670425,0.14720199753840765,0.14729000255465508,0.1473770005007585,0.1474629988272985,0.14754800125956535,0.14763199910521507,0.14771499981482825,0.147797000904878,0.14787800113360086,0.14795699963967004,0.14803499976793924,0.14811299865444502,0.14818899830182394,0.14826399957140288,0.1483369991183281,0.1484100023905436,0.14848199859261513,0.14855300014217696,0.14862199996908507,0.14869100227952003,0.1487590012451013,0.14882600059111914,0.14889100069801012,0.1489539990822474,0.14901799956957498,0.14908000081777573,0.14914099996288618,0.14920099824666977,0.14925899977485338,0.1493160016834736,0.14937299862504005,0.1494289996723334,0.1494829977552096,0.1495360011855761,0.14958900089065233,0.14964000011483827,0.14969000096122423,0.14973900218804678,0.14978700007001558,0.14983400081594786,0.14988000070055327,0.14992400258779526,0.14996700113018355,0.15001000091433525,0.15005099897583327,0.1500919982790947,0.1501310020685196,0.15016900127132735,0.15020699799060822,0.150243000437816,0.1502779982984066,0.15031100064516068,0.15034399926662445,0.15037600075205168,0.15040700137615204,0.15043599903583527,0.1504640020430088,0.15049100170532861,0.150518000125885,0.150543000549078,0.15056700259447098,0.15058900167544684,0.1506109982728958,0.15063200145959854,0.15065200005968413,0.1506699981788794,0.15068799878160158,0.1507049985229969,0.15072099988659224,0.15073500076929727,0.1507480007906755,0.15075999995072684,0.15077200159430504,0.15078199903170267,0.15079100181659064,0.15079800287882486,0.15080500021576881,0.1508110004166762,0.15081599727272987,0.15081899985671043,0.15082199995716414,0.15082399795452753,0.15082500129938126,0.1508240004380544,0.15082199995716414,0.15081899985671043,0.15081599851449332,0.15081100165843964,0.15080499897400537,0.15079700077573457,0.15078900009393692,0.1507799985508124,0.15076999987165132,0.15075899908939996,0.15074699992934862,0.150733998666207,0.15071900188922882,0.15070399890343347,0.15068699916203818,0.15066900104284286,0.15065100168188414,0.1506309981147448,0.15060999865333238,0.1505879983305931,0.15056500087181726,0.1505410000681877,0.15051599964499474,0.15049000084400177,0.15046300118168196,0.15043499817450842,0.15040599927306175,0.15037500113248825,0.15034399926662445,0.15031099940339723,0.15027800078193346,0.15024399881561598,0.1502080000936985,0.15017099802692732,0.150133000065883,0.1500940000017484,0.15005499993761381,0.15001299853126207,0.14997200046976408,0.1499289982020855,0.14988499879837036,0.14984000101685524,0.149793000270923,0.14974600076675415,0.14969800040125847,0.14964899917443594,0.14959900205334029,0.1495489999651909,0.14949999873836836,0.14944999913374582,0.14940000077088675,0.1493499999245008,0.14929999907811484,0.14925100157658258,0.1492009994884332,0.1491510011255741,0.14910099903742471,0.14905200029412904,0.14900200068950653,0.14895200232664743,0.14890299985806146,0.1488529990116755,0.14880300064881644,0.14875400066375732,0.14870399981737137,0.14865500231583914,0.14860500022768974,0.14855600272615752,0.14850599939624468,0.1484569994111856,0.14840699856479964,0.14835799982150397,0.14830800021688142,0.14825900023182234,0.14820899938543639,0.14816000064214072,0.1481110006570816,0.1480610010524591,0.14801199982563654,0.14796300108234087,0.1479129989941915,0.14786400025089583,0.14781500150760016,0.14776499941945076,0.14771599943439165,0.14766699944933256,0.14761799946427345,0.14756900072097778,0.14751900111635527,0.1474699986477693,0.14742099990447363,0.14737200116117796,0.147322998692592,0.14727399870753288,0.1472249999642372,0.14717599749565125,0.14712700123588243,0.14707799876729646,0.1470290000240008,0.14698000252246857,0.1469310000538826,0.14688200255235037,0.1468330000837644,0.14678399885694185,0.14673499763011932,0.1466860013703505,0.14663700014352798,0.14658800015846887,0.1465390014151732,0.14649000143011412,0.14644199733932814,0.14639299983779588,0.14634400109450021,0.14629500110944113,0.14624599988261858,0.1461979995171229,0.14614900077382723,0.14610000078876814,0.14605200042327246,0.1460029991964499,0.14595399921139082,0.14590599884589514,0.14585700010259947,0.14580799887577692,0.14575999851028124,0.145711001008749,0.14566299940148988,0.14561400065819421,0.14556600029269853,0.14551700154940286,0.14546900242567062,0.1454199987153212,0.14537200083335242,0.14532299960652986,0.14527499924103418,0.1452260004977385,0.14517800013224283,0.1451300010085106,0.14508099978168806,0.1450330006579558,0.1449840006728967,0.14493599782387415,0.14488800118366876,0.14484000081817308,0.144791000833114,0.14474300046761832,0.14469499761859575,0.14464699973662695,0.1445979985098044,0.14454999814430872,0.14450200150410333,0.1444539986550808,0.14440599953134856,0.14435799916585287,0.14430900166432062,0.14426099881529808,0.14421300093332926,0.14416500180959702,0.14411700144410133,0.14406900107860565,0.14402099947134653,0.1439730003476143,0.1439249999821186,0.14387700085838637,0.14382900049289069,0.14378100261092186,0.14373299852013588,0.14368500063816705,0.14363800113399824,0.14358999952673912,0.14354200040300688,0.1434940000375112,0.14344600091377893,0.1433980017900467,0.143350999802351,0.14330299819509187,0.14325500031312308,0.1432069999476274,0.14316000044345856,0.14311200131972632,0.1430639997124672,0.14301600058873495,0.14296900232632956,0.142920999477307,0.14287399997313818,0.14282599836587906,0.14277799924214682,0.14273099973797798,0.1426829993724823,0.14263600235184035,0.14258800074458122,0.14254099999864897,0.1424929996331533,0.142445998887221,0.1423980010052522,0.14235100150108337,0.1423030011355877,0.14225600038965544,0.14220800126592317,0.14216099803646406,0.14211399977405867,0.142065999408563,0.14201899990439415,0.14197200164198875,0.14192400127649307,0.14187699804703394,0.14183000102639198,0.14178199817736944,0.14173499991496405,0.1416880004107952,0.14164099966486296,0.1415930005411307,0.141545998553435,0.1414989990492662,0.1414520007868608,0.1414050000409285,0.14135800177852312,0.14131100103259087,0.14126300190885863,0.14121599992116293,0.14116899917523065,0.14112199967106184,0.141075000166893,0.14102799942096075,0.14098099991679192,0.14093400041262308,0.14088700215021768,0.14084000140428543,0.14079299941658974,0.1407459999124209,0.14070000251134238,0.14065300052364668,0.14060600101947784,0.1405590002735456,0.1405119982858499,0.1404650000234445,0.1404179980357488,0.14037200063467026,0.14032499864697456,0.14027800286809602,0.14023099963863692,0.14018499851226807,0.14013800024986267,0.14009099950393042,0.14004399875799814,0.13999800259868303,0.13995100061098734,0.13990399862329164,0.13985799749692282,0.13981099799275398,0.13976499934991202,0.13971800108750662,0.13967199871937433,0.13962499921520552,0.13957799971103668,0.13953199858466783,0.13948500032226244,0.13943899795413017,0.13939199969172478,0.1393460010488828,0.13929999992251396,0.1392529991765817,0.13920699805021286,0.13915999854604402,0.1391140011449655,0.1390679987768332,0.1390209992726644,0.13897499814629555,0.13892899950345358,0.13888199999928474,0.13883600011467934,0.13879000147183737,0.1387430007259051,0.13869699959953627,0.13865099971493086,0.13860499983032545,0.13855900118748346,0.1385120004415512,0.1384660005569458,0.13841999943057695,0.1383739970624447,0.13832799966136614,0.13828199977676073,0.1382360023756822,0.13819000124931335,0.13814400136470795,0.13809699937701225,0.1380510007341703,0.13800500084956488,0.1379589984814326,0.13791299983859062,0.13786799957354864,0.1378219984471798,0.13777600104610124,0.13775299862027168};
    CF4={34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.04999923706055,34.05000019073486,34.04999955495199,34.04999987284342,34.050100008646645,34.05009969075521,34.05009969075521,34.050100008646645,34.050100008646645,34.05020046234131,34.05019982655843,34.05020014444987,34.05020014444987,34.050299326578774,34.050299962361656,34.050299962361656,34.05039978027344,34.05040009816488,34.05049991607666,34.050500551859535,34.05060005187988,34.05060005187988,34.05069955190023,34.05069955190023,34.05080000559489,34.05090045928955,34.05100059509277,34.05099964141846,34.05110009511312,34.05120054880778,34.051300366719566,34.05139986673991,34.05150000254313,34.051600774129234,34.05169995625814,34.05179977416992,34.051900227864586,34.05209986368815,34.05219968159994,34.052300453186035,34.052499771118164,34.05260022481283,34.052798906962074,34.05289999643961,34.055300076802574,34.05799961090088,34.06080023447672,34.06420008341471,34.068699518839516,34.074700037638344,34.08239936828613,34.087400118509926,34.098299980163574,34.11459986368815,34.12980047861735,34.1497999827067,34.17150020599365,34.193999926249184,34.21979999542236,34.2564001083374,34.29749997456869,34.338699658711754,34.375800132751465,34.4146998723348,34.43010012308756,34.45719941457113,34.50569979349772,34.5605993270874,34.616199811299644,34.67679913838705,34.74499924977621,34.825199127197266,34.909299532572426,34.9865992863973,35.04279931386312,35.076699574788414,35.111599604288735,35.15789985656738,35.23359902699789,35.3363987604777,35.46979935963949,35.62149874369303,35.804999033610024,35.991299311319985,36.23889923095703,36.56109873453776,36.99279912312826,37.297698974609375,37.39169883728027,37.50009854634603,37.670498530069985,37.855198542277016,38.023898442586265,38.204298655192055,38.406997998555504,38.61429913838705,38.84129842122396,39.07069810231527,39.3001979192098,39.52009836832682,39.715097745259605,39.90489800771078,40.118597666422524,40.34249718983968,40.56609694163004,40.80479653676351,41.05469576517741,41.342495918273926,41.65249570210775,42.00469557444254,42.41149616241455,42.862396240234375,43.40139643351237,44.007896423339844,44.68869590759277,45.45469538370768,46.34259541829427,47.35769589742025,48.276095390319824,49.29249509175619,50.43949508666992,51.557394663492836,52.72269503275553,53.97579542795817,55.10939598083496,56.16269588470459,57.26739501953125,58.3761952718099,59.28379599253336,60.248695373535156,61.255194981892906,62.29139518737793,63.32119528452555,64.34609444936116,65.2670955657959,66.09139442443848,66.87479654947917,67.62789662679036,68.36059633890788,69.06989606221516,69.77859687805176,70.47599538167317,71.17349561055501,71.8547960917155,72.51259549458821,73.28449440002441,74.13009516398112,74.98279317220052,75.77629216512044,76.47559356689453,77.15499623616536,77.73389498392741,78.37379455566406,79.04059473673503,79.78919410705566,80.53269322713216,81.09249051411946,81.83400344848633,82.68911743164062,83.15111478169759,83.9226131439209,84.71961339314778,85.54191462198894,86.3897139231364,87.2420145670573,88.07791264851888,88.89731407165527,89.70041338602702,90.48711268107097,91.25731213887532,92.0112133026123,92.74861081441243,93.46971257527669,94.17431131998698,94.86551094055176,95.54621124267578,96.21641095479329,96.87610944112141,97.5252119700114,98.16391054789226,98.79210980733235,99.4097105662028,100.0170103708903,100.61400985717773,101.20201047261556,101.78300921122234,102.3580093383789,102.92500877380371,103.48700841267903,104.04100926717122,104.58900896708171,105.13000869750977,105.66400973002116,106.19200897216797,106.71400833129883,107.23100852966309,107.74500846862793,108.25400861104329,108.75900840759277,109.25900777180989,109.75500806172688,110.24700864156087,110.7350082397461,111.21800740559895,111.69800758361816,112.17500750223796,112.64900779724121,113.12000719706218,113.58900833129883,114.05500793457031,114.51800855000813,114.97800827026367,115.43600845336914,115.89100774129231,116.34400749206543,116.7950070699056,117.24400838216145,117.69100761413574,118.13700739542644,118.5800069173177,119.02200762430827,119.46300760904948,119.90100797017415,120.33800760904948,120.77200698852539,121.20300801595052,121.63100687662761,122.05600865681966,122.47800763448079,122.89600626627605,123.31200790405273,123.72400728861491,124.13300768534343,124.53900655110677,124.9440066019694,125.34800656636556,125.7530066172282,126.15700721740723,126.56100654602051,126.96600659688313,127.37000783284505,127.7750072479248,128.1790065765381,128.58300654093424,128.98600641886392,129.3870086669922,129.7840092976888,130.1790033976237,130.5710080464681,130.96100616455078,131.34700647989908,131.73100789388022,132.11300786336264,132.49100494384766,132.86700439453125,133.24000549316406,133.61000696818033,133.9780044555664,134.3430061340332,134.70500564575195,135.06500625610352,135.4220059712728,135.77600479125977,136.12700525919595,136.47500610351562,136.82100550333658,137.16500600179037,137.50500615437826,137.8430061340332,138.17800521850586,138.51000467936197,138.84000523885092,139.16600545247397,139.49100621541342,139.81200663248697,140.1310043334961,140.44700495402017,140.76000467936197,141.07000478108725,141.37800470987955,141.68300247192383,141.9860051472982,142.28500493367514,142.58200454711914,142.87700525919595,143.16800689697266,143.45700454711914,143.74300384521484,144.02600479125977,144.30700174967447,144.58500544230142,144.86000315348306,145.1320037841797,145.4020029703776,145.66900507609049,145.93400446573892,146.19500478108725,146.45400365193686,146.71000544230142,146.96400451660156,147.21400578816733,147.46200561523438,147.70800399780273,147.95000457763672,148.19000498453775,148.4270044962565,148.66200383504233,148.89300155639648,149.12200291951498,149.34900538126627,149.57200495402017,149.79300181070963,150.01100413004556,150.22600682576498,150.4390017191569,150.64900334676108,150.85600153605142,151.06100463867188,151.26300303141275,151.46200307210287,151.65800348917642,151.85200373331705,152.0430030822754,152.23100407918295,152.41600290934244,152.59900410970053,152.77900314331055,152.95700454711914,153.1310017903646,153.30300267537436,153.47200139363608,153.6390012105306,153.8030039469401,153.9640032450358,154.12200419108072,154.27800369262695,154.43100357055664,154.58100001017252,154.72800318400064,154.87300237019858,155.0150006612142,155.15400187174478,155.29100036621094,155.4250030517578,155.55600102742514,155.68500264485678,155.81000264485678,155.93300247192383,156.0540033976237,156.17100143432617,156.2860018412272,156.39800008138022,156.50799942016602,156.61500295003256,156.71900049845377,156.82000223795572,156.91899998982748,157.0140012105306,157.10799916585287,157.1980005900065,157.28600438435873,157.37100092569986,157.45299784342447,157.5330022176107,157.61000188191733,157.68400192260742,157.75500106811523,157.8240000406901,157.88999938964844,157.953000386556,158.0140012105306,158.07199986775717,158.1270014444987,158.1790008544922,158.2290013631185,158.2760009765625,158.31999969482422,158.36199951171875,158.40100224812826,158.4370002746582,158.47100067138672,158.5009994506836,158.52900187174478,158.55500030517578,158.57699966430664,158.59700139363608,158.61400095621744,158.62900034586588,158.6410001118978,158.64999771118164,158.65599950154623,158.65999857584634,158.65999857584634,158.65900039672852,158.65500132242838,158.65200169881186,158.6489995320638,158.64600118001303,158.64299901326498,158.63999938964844,158.6360003153483,158.63299942016602,158.62999979654947,158.62700017293295,158.62400182088217,158.62099965413412,158.61700057983398,158.61400095621744,158.61100133260092,158.6079978942871,158.6050008138021,158.6010004679362,158.5980021158854,158.59499867757162,158.59199905395508,158.5890007019043,158.58599853515625,158.5819994608561,158.57900110880533,158.5760014851888,158.5730005900065,158.56999969482422,158.56699879964194,158.5629997253418,158.56000010172525,158.55699920654297,158.55399958292642,158.55100123087564,158.5479990641276,158.54400126139322,158.54099909464517,158.5380007425944,158.5349998474121,158.53200149536133,158.52900060017905,158.52499771118164,158.52200063069662,158.5189997355143,158.51599884033203,158.51300175984701,158.5099983215332,158.50600306193033,158.50300089518228,158.49999872843424,158.49700037638345,158.4939982096354,158.4910011291504,158.48699951171875,158.48400115966797,158.4810002644857,158.47800064086914,158.47499974568686,158.47099939982095,158.46800104777017,158.4650026957194,158.4619992574056,158.45900090535483,158.45600128173828,158.4520009358724,158.44900131225586,158.4459991455078,158.44300079345703,158.43999989827475,158.4370002746582,158.43300120035806,158.42999903361002,158.427001953125,158.4239985148112,158.4210001627604,158.41799799601236,158.41399765014648,158.41100056966147,158.40800094604492,158.40499877929688,158.40199915568033,158.3989995320638,158.39499791463217,158.3919995625814,158.38900248209634,158.3860003153483,158.38300196329752,158.38000106811523,158.37600072224936,158.37299982706705,158.37000020345053,158.36699930826822,158.36399841308594,158.36100006103516,158.35699844360352,158.35400263468424,158.35099919637045,158.34800084431967,158.34499994913736,158.34200159708658,158.33800252278647,158.33499908447266,158.3319994608561,158.32899729410806,158.32600021362305,158.32299931844076,158.31900024414062,158.31599807739258,158.3129997253418,158.30999883015951,158.30700174967447,158.3040033976237,158.3000005086263,158.29700088500977,158.29400126139322,158.2910016377767,158.28799947102866,158.2849998474121,158.28099950154623,158.2779998779297,158.27500025431314,158.27200190226236,158.26900227864584,158.2660001118978,158.2619997660319,158.2590014139811,158.25599797566733,158.25299962361655,158.25000127156576,158.24700037638345,158.2429987589518,158.24000040690103,158.23700078328451,158.23399861653647,158.23099772135416,158.22800064086914,158.22399775187174,158.22099939982095,158.21800104777017,158.2150001525879,158.2120018005371,158.20900090535483,158.20500055948892,158.20199839274088,158.19900258382162,158.1959991455078,158.19299952189127,158.19000244140625,158.1860008239746,158.18299992879233,158.17999903361002,158.1769994099935,158.17399978637695,158.1710001627604,158.16799799601236,158.16399892171225,158.1609992980957,158.15800094604492,158.15500259399414,158.15199661254883,158.1490020751953,158.14500172932944,158.14200083414713,158.13899993896484,158.13599904378256,158.13300196329752,158.12999979654947,158.1259994506836,158.12300237019858,158.12000020345053,158.11700312296549,158.11400095621744,158.11100133260092,158.10700225830078,158.10399754842123,158.10099919637045,158.09800084431967,158.09499994913736,158.09199905395508,158.0880012512207,158.08500035603842,158.0819994608561,158.0789998372396,158.07600021362305,158.07299931844076,158.06900024414062,158.06600062052408,158.06300354003906,158.06000010172525,158.05700174967447,158.0540008544922,158.05100123087564,158.04700215657553,158.04399998982748,158.04099909464517,158.0379981994629,158.03499857584634,158.03199895222983,158.02799860636392,158.0249989827474,158.02200063069662,158.0189997355143,158.0160001118978,158.01299921671549,158.0089988708496,158.00599924723306,158.00299962361655,157.99999872843424,157.99700164794922,157.99399948120117,157.98999786376953,157.98699951171875,157.9839998881022,157.9810002644857,157.97800064086914,157.9749984741211,157.97200139363608,157.96799850463867,157.9650001525879,157.9619992574056,157.95900090535483,157.95600001017252,157.953000386556,157.9490000406901,157.9459991455078,157.94299952189127,157.93999989827475,157.9370002746582,157.93400065104166,157.93000030517578,157.92700068155924,157.92399724324545,157.92099889119467,157.9180005391439,157.91500091552734,157.9109992980957,157.90799840291342,157.90500005086264,157.9020004272461,157.89900080362955,157.89600118001303,157.89299901326498,157.88899993896484,157.8860003153483,157.88300069173178,157.87999979654947,157.87700017293295,157.8740030924479,157.87200037638345};
    //cC4F8={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.1254001587227927e-05,0.0017370099764472495,0.006777070074652632,0.014863699829826752,0.025740500073879957,0.039150899897019066,0.054838400023678936,0.07254669939478238,0.09201929904520512,0.11299999989569187,0.13523100192348161,0.1584579994281133,0.18242299929261208,0.20686999956766763,0.23154200116793314,0.256182998418808,0.28053699682156247,0.30434700101614,0.327355998257796,0.35321400066216785,0.3800960009296735,0.40782199800014496,0.43730299671490985,0.4695050021012624,0.504942998290062,0.5436290005842844,0.585984006524086,0.6332599967718124,0.6798149993022283,0.7169250001509985,0.7463770061731339,0.7715280006329218,0.7907750010490417,0.8046580056349436,0.8165019998947779,0.8282870004574457,0.8410840034484863,0.8555550078550974,0.8713579972585043,0.8880860060453415,0.905660996834437,0.9240339895089468,0.9437180111805598,0.9656520088513693,0.9909979999065399,1.0207500060399373,1.0534299910068512,1.0861999988555908,1.1188200116157532,1.152839998404185,1.1887199978033702,1.2261799971262615,1.26364999016126,1.301119993130366,1.3385799725850422,1.3761536876360576,1.4129000107447307,1.4511200090249379,1.4903099834918976,1.5308100084463756,1.5725900133450825,1.6156600018342335,1.6589599947134654,1.7014000018437703,1.742979993422826,1.78371000289917,1.8235999941825867,1.862619976202647,1.900799999634425,1.9381199876467388,1.974590003490448,2.0101999739805856,2.0451200008392334,2.079490005970001,2.113309999306997,2.146580000718435,2.1792999505996704,2.2114800413449607,2.243100027243296,2.274179975191752,2.3047099709510803,2.334689994653066,2.3642300367355347,2.393400013446808,2.4222300052642822,2.4507000048955283,2.478819986184438,2.506589968999227,2.533999979496002,2.5610600113868713,2.5877699653307595,2.6141300201416016,2.640190005302429,2.666030009587606,2.691640019416809,2.717020014921824,2.7421800096829734,2.7671000162760415,2.791790008544922,2.816259980201721,2.84049000342687,2.8644999861717224,2.888319969177246,2.912000000476837,2.9355299870173135,2.958899974822998,2.98212997118632,3.005210002263387,3.0281400084495544,3.050920009613037,3.0735600193341575,3.096049984296163,3.118410031000773,3.1406799952189126,3.1628499825795493,3.1849199533462524,3.2069000005722046,3.2287800113360086,3.250559985637665,3.27224999666214,3.293839971224467,3.3153300285339355,3.3366899887720742,3.357890009880066,3.378910005092621,3.3997700214385986,3.4204700191815696,3.4409899512926736,3.4613500038782754,3.4815500179926553,3.501570006211599,3.521429975827535,3.5412000020345054,3.5609700282414756,3.5807300011316934,3.600480020046234,3.62022997935613,3.6399700045585632,3.6597099701563516,3.6794300079345703,3.6991599599520364,3.718870004018148,3.7385199864705405,3.7580100099245706,3.777359982331594,3.7965699831644693,3.81563001871109,3.8345499634742737,3.853319982687632,3.871940016746521,3.8904199798901877,3.908749997615814,3.9269399642944336,3.944980005423228,3.962879995505015,3.9806400140126548,3.998249967892965,4.015719930330913,4.0330400466918945,4.050219972928365,4.06724997361501,4.084139982859294,4.100879987080892,4.117479960123698,4.133939981460571,4.150240063667297,4.166409929593404,4.182440002759297,4.1983199914296465,4.2140499750773115,4.229640007019043,4.245089968045552,4.260390082995097,4.275550007820129,4.290559967358907,4.305430014928182,4.320159991582234,4.334740002950032,4.3491800626118975,4.363469998041789,4.377629995346069,4.391639908154805,4.405499974886577,4.419220010439555,4.432800014813741,4.446239948272705,4.459530035654704,4.472679972648621,4.4856800238291425,4.498540043830872,4.5112599929173784,4.523829976717631,4.536260008811951,4.548550009727478,4.560700019200643,4.572700023651123,4.584559996922811,4.596279939015706,4.607859969139099,4.619289994239807,4.63057005405426,4.641719977060954,4.652720014254252,4.663580060005188,4.674299955368042,4.684870044390361,4.695309956868489,4.705599983533223,4.715750018755595,4.725760022799174,4.735619982083638,4.74533998966217,4.75491992632548,4.764359951019287,4.773650089899699,4.782810012499492,4.791819969813029,4.8006900151570635,4.8094199895858765,4.8180099328358965,4.826450069745381,4.8347500165303545,4.842909971872966,4.8509299755096436,4.858809987703959,4.86653991540273,4.874140024185181,4.881589929262797,4.88890000184377,4.896070043245952,4.90310005346934,4.909980058670044,4.916729966799418,4.923340042432149,4.929799993832906,4.93612003326416,4.942300041516622,4.948340018590291,4.954240004221599,4.95998998483022,4.965609987576802,4.97108006477356,4.976420044898987,4.981610020001729,4.986670017242432,4.991580009460449,4.996350010236104,5.000980059305827,5.005469997723897,5.009819984436035,5.0140299797058105,5.018100023269653,5.022029956181844,5.02581000328064,5.029459993044536,5.032969991366069,5.036340037981669,5.039570013682048,5.042649944623311,5.045599977175395,5.048410018285115,5.051069974899292,5.053600033124288,5.055990020434062,5.05823000272115,5.06033996740977,5.062300006548564,5.064130028088887,5.065820097923279,5.0673699378967285,5.068770011266072,5.070040027300517,5.071170012156169,5.072160005569458,5.073009967803955,5.0737199783325195,5.074289957682292,5.074719945589702,5.075019955635071,5.075170040130615,5.07518994808197,5.07506000995636,5.0747999747594195,5.074399987856547,5.073859969774882,5.073180039723714,5.072359999020894,5.071400006612142,5.070299983024597,5.06905996799469,5.067689935366313,5.06616997718811,5.064589977264404,5.063000003496806,5.061420043309529,5.059840043385823,5.058259963989258,5.056679964065552,5.055100003878276,5.05352000395457,5.051940004030864,5.050360004107158,5.0487799644470215,5.047210017840068,5.045629978179932,5.044050017992656,5.042479991912842,5.040899952252706,5.039330045382182,5.037750045458476,5.036180059115092,5.034600019454956,5.033029913902283,5.031460126241048,5.029890060424805,5.028320034344991,5.026739994684855,5.025170048077901,5.023600021998088,5.022029995918274,5.02045996983846,5.018899957338969,5.017330050468445,5.015760024388631,5.014189998308818,5.012630025545756,5.011059999465942,5.0094899733861284,5.007930000623067,5.006360014279683,5.004799962043762,5.003239989280701,5.001670002937317,5.0001100699106855,4.998550017674764,4.996990005175273,4.995420018831889,4.9938600063323975,4.992299993832906,4.990739981333415,4.989179968833923,4.987629969914754,4.986069957415263,4.984510024388631,4.98295001188914,4.981389959653218,4.979840000470479,4.9782800277074175,4.976729989051819,4.975170016288757,4.973620017369588,4.972060004870097,4.970510005950928,4.968959927558899,4.9673999945322675,4.965850035349528,4.9642999569574995,4.96274999777476,4.961199998855591,4.959649999936421,4.958099961280823,4.9565500020980835,4.955000042915344,4.953450004259746,4.951910058657329,4.950360059738159,4.94880998134613,4.947269996007283,4.945719997088115,4.944169998168945,4.942629973093669,4.941090027491252,4.939539988835652,4.938000043233235,4.936450004577637,4.93490993976593,4.933369994163513,4.931830008824666,4.93029002348582,4.9287499984105425,4.927209973335266,4.925670027732849,4.924130002657573,4.922590096791585,4.9210500319798784,4.919510006904602,4.917979995409648,4.916439930597941,4.914910038312276,4.91336993376414,4.911829988161723,4.910299976666768,4.908769965171814,4.907230019569397,4.905700008074443,4.904169956843059,4.902630011240642,4.9010999997456866,4.899569988250732,4.898039976755778,4.896510004997253,4.8949800332387285,4.893449982007344,4.89191997051239,4.890389959017436,4.888859987258911,4.8873400290807085,4.885809977849324,4.88427996635437,4.8827600081761675,4.881229917208354,4.879710078239441,4.8781799872716265,4.8766599496205645,4.8751299778620405,4.873609979947408,4.872090021769206,4.870570063591003,4.869040012359619,4.867519974708557,4.8660000165303545,4.8644799788792925,4.862959980964661,4.861439943313599,4.859919905662537,4.858399987220764,4.856890042622884,4.855370004971822,4.85385000705719,4.852330048878987,4.850819985071818,4.849300026893616,4.847790042559306,4.846270004908244,4.844759980837504,4.843240022659302,4.841729998588562,4.840219934781392,4.838709910710652,4.837189952532451,4.83568000793457,4.834169983863831,4.832659999529521,4.831149935722351,4.829639991124471,4.828129927317302,4.826619982719421,4.825119972229004,4.823609987894694,4.822099963823955,4.820599953333537,4.819090008735657,4.817580024401347,4.81608001391093,4.81456998984019,4.813070019086202,4.811570008595784,4.8100599845250445,4.808560013771057,4.80705992380778,4.805550058682759,4.804049928983052,4.802549958229065,4.801050146420796,4.79954997698466,4.798049966494243,4.796550035476685,4.795050024986267,4.793560028076172,4.792059977849324,4.790560007095337,4.789059956868489,4.787569999694824,4.786070028940837,4.784579952557881,4.783079942067464,4.781589945157369,4.780089974403381,4.778600017229716,4.777110020319621,4.775610009829204,4.774120012919108,4.772630016009013,4.771140019098918,4.769649982452393,4.768159945805867,4.766669988632202,4.765179991722107,4.763689994812012,4.762200037638347,4.760710000991821,4.759230017662048,4.757740020751953,4.756250023841858,4.754770000775655,4.75328000386556,4.751800020535787,4.750309983889262,4.748829960823059,4.747340043385823,4.745859980583191,4.744379957516988,4.742889960606893,4.74140997727712,4.739929993947347,4.738450050354004,4.7369699875513716,4.735490004221599,4.734010020891826,4.732529997825623,4.7310499747594195,4.729570031166077,4.728099981943767,4.7266199588775635,4.72514009475708,4.723659952481587,4.722190022468567,4.720709999402364,4.719239989916484,4.71776008605957,4.71628999710083,4.714820027351379,4.713340004285176,4.711869994799296,4.7103999853134155,4.708930015563965,4.707460006078084,4.705979943275452,4.70451005299886,4.70304008324941,4.70156995455424,4.700109998385112,4.698639988899231,4.69717001914978,4.695700009663899,4.694230039914449,4.692770004272461,4.691299955050151,4.689839959144592,4.6883699496587115,4.687639991442363};
    SF6={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0002747740879082509,0.001923504489241168,0.005466860408584277,0.01499934789414207,0.024999434128403664,0.034999388890961804,0.04499943523357312,0.05499937882026037,0.06499945092946291,0.07499935726324718,0.08499948245783646,0.09499939220647018,0.10999903393288453,0.12999879072109857,0.15499834592143694,0.17999867846568426,0.1999987723926703,0.21999895945191383,0.23999873300393423,0.26999801645676297,0.29999837279319763,0.32499857246875763,0.3549981142083804,0.3899978771805763,0.42499801019827527,0.45999792218208313,0.49999761829773587,0.5443803270657858,0.5945511807998022,0.6599957346916199,0.7699926396210989,0.8899930367867152,0.999993642171224,1.1199926137924194,1.2399930556615193,1.3599929014841716,1.4999912877877553,1.6499911447366078,1.7999912301699321,1.9699894785881042,2.149989446004232,2.3499877055486045,2.5599875847498574,2.769987682501475,2.9899867177009583,3.2099871834119162,3.429987053076426,3.6599862774213157,3.889986495176951,4.1099876165390015,4.358643651008606,4.563808560371399,4.776847044626872,4.990507483482361,5.207866946856181,5.435196399688721,5.6560072501500445,5.891855637232463,6.164003173510234,6.453542669614156,6.728324254353841,7.010202924410502,7.307322184244792,7.598473310470581,7.910870313644409,8.221433083216349,8.56844687461853,8.884455919265747,9.182497024536133,9.511056661605835,9.842686812082926,10.177406787872314,10.515106916427612,10.854906956354776,11.19560702641805,11.537206808725992,11.879806915918985,12.22340703010559,12.567906856536865,12.913306951522827,13.259706974029541,13.607006947199503,13.955307006835938,14.304006973902384,14.652907053629557,15.001707077026367,15.350707054138184,15.69970711072286,16.048707008361816,16.397806962331135,16.746906916300457,17.0962069829305,17.445407072703045,17.794307072957356,18.142206986745197,18.489306926727295,18.835407257080078,19.18070697784424,19.525006771087646,19.868506749471027,20.211106936136883,20.552706559499104,20.89350700378418,21.233806769053142,21.57400671641032,21.914206663767498,22.254206657409668,22.594106674194336,22.93400700887044,23.273806889851887,23.61350679397583,23.953106721242268,24.292606830596924,24.632206916809082,24.971906820933025,25.311906655629475,25.65200662612915,25.99230686823527,26.332806905110676,26.67340660095215,27.014206886291504,27.355206807454426,27.696407000223797,28.037906964619953,28.37990665435791,28.72240702311198,29.065306822458904,29.40870714187622,29.75250705083211,30.09680716196696,30.441606839497883,30.7869070370992,31.132607142130535,31.479207356770832,31.82700713475545,32.17610740661621,32.52640724182129,32.87800661722819,33.230807304382324,33.584906895955406,33.94030729929606,34.296807289123535,34.65470790863037,35.0140069325765,35.37510744730631,35.73790772755941,36.10250695546468,36.46880785624186,36.83680788675944,37.2067076365153,37.578207651774086,37.951507568359375,38.3266077041626,38.7011079788208,39.073007583618164,39.442108154296875,39.80860710144043,40.172407468159996,40.53340689341227,40.89180692036947,41.247507095336914,41.60040728251139,41.950706481933594,42.2983071009318,42.64320659637451,42.98540655771891,43.32490666707357,43.661706606547035,43.9958070119222,44.3272066116333,44.65590604146322,44.98200670878092,45.30530611673991,45.626006762186684,45.94400596618652,46.25930658976237,46.571906089782715,46.88190619150797,47.18910598754883,47.493707021077476,47.79560565948486,48.09480635325114,48.391306241353355,48.6852060953776,48.97640609741211,49.264905293782554,49.550705909729004,49.83380540211996,50.11430517832438,50.39210573832194,50.66730499267578,50.93970584869385,51.2095053990682,51.47660541534424,51.74110476175944,52.00290552775065,52.26200517018636,52.518405278523765,52.77220503489176,53.02330493927002,53.271805127461754,53.51760482788086,53.760704358418785,54.001104990641274,54.239004135131836,54.47410456339518,54.70660432179769,54.936405181884766,55.163604418436684,55.3881041208903,55.61000378926595,55.82920424143473,56.04570325215658,56.25960445404053,56.47090435028076,56.67940425872803,56.88540426890055,57.088704109191895,57.28930409749349,57.487303733825684,57.68270365397135,57.875404040018715,58.06540393829346,58.25280316670736,58.43760395050049,58.61970361073812,58.799203872680664,58.976003646850586,59.150203704833984,59.32180372873942,59.49070326487223,59.6570037206014,59.82060305277506,59.98160330454508,60.140003522237144,60.29570325215658,60.44880294799805,60.599303245544434,60.7471030553182,60.892302831014,61.034902572631836,61.17490291595459,61.31220277150472,61.446902910868324,61.578902880350746,61.70830217997233,61.8351027170817,61.95930194854736,62.08090305328369,62.19980239868164,62.316102027893066,62.42980225880941,62.54090245564779,62.649301846822105,62.75510215759277,62.858302434285484,62.95890235900879,63.05690256754557,63.15230147043864,63.24500242869059,63.33510080973307,63.42260265350342,63.507500648498535,63.58980178833008,63.669500986735024,63.7466017405192,63.82100137074789,63.89290110270182,63.96210257212321,64.02869987487793,64.09280204772949,64.15420055389404,64.21300061543782,64.26920064290364,64.32280095418294,64.37380027770996,64.42220052083333,64.46800104777019,64.51120122273763,64.5518004099528,64.58980051676433,64.62520027160645,64.65810139973958,64.68830172220866,64.71590042114258,64.74089940388997,64.76340103149414,64.78320058186848,64.80040168762207,64.81509971618652,64.82719993591309,64.83669853210449,64.8435001373291,64.84779993693034,64.84960047403972,64.84869893391927,64.84520022074382,64.83920097351074,64.83059946695964,64.81939951578777,64.80559984842937,64.78919982910156,64.77029927571614,64.75000063578288,64.72979927062988,64.70959981282552,64.68929862976074,64.66909853617351,64.64889971415202,64.62870025634766,64.60850016276042,64.58830006917317,64.56819979349773,64.54799906412761,64.52779960632324,64.50769933064778,64.4875005086263,64.46740023295085,64.44719950358073,64.42709922790527,64.40689913431804,64.38679885864258,64.36669921875,64.3466002146403,64.32649993896484,64.30639966328938,64.28629938761394,64.26619974772136,64.24610010782878,64.22609965006511,64.20600001017253,64.18589973449707,64.16589991251628,64.14579995473225,64.12579981486003,64.10569953918457,64.08569876352946,64.06569925944011,64.0456994374593,64.02569897969563,64.00569947560628,63.98569901784261,63.96569983164469,63.94569969177246,63.92569955190023,63.90569909413656,63.88580004374186,63.86579958597819,63.84579944610596,63.82589975992838,63.806000073750816,63.78599993387858,63.76609992980957,63.74619960784912,63.72619946797689,63.706299463907875,63.68639945983887,63.66649977366129,63.646599451700844,63.626800219217934,63.606899897257485,63.586999575297035,63.56709957122803,63.54730033874512,63.52739969889323,63.50759983062744,63.48769982655843,63.46789964040121,63.448099772135414,63.428199768066406,63.40839958190918,63.38859907786051,63.36879952748617,63.348999977111816,63.32919947306315,63.30940024058024,63.28960005442301,63.26989936828613,63.25009981791178,63.23029931386312,63.21059958140055,63.190799395243324,63.1710999806722,63.15130011240641,63.13159942626953,63.11189969380697,63.092199643452965,63.07239945729574,63.05269972483317,63.032999674479164,63.013299306233726,62.99369970957438,62.97399934132894,62.95429929097494,62.93459955851237,62.91499932607015,62.89529959360758,62.8756996790568,62.85599994659424,62.83640003204346,62.81669998168945,62.79709974924723,62.77750015258789,62.757899602254234,62.73830000559489,62.71869913736979,62.69909922281901,62.67949962615967,62.659899393717446,62.640299479166664,62.62069924672445,62.601200103759766,62.58159955342611,62.562100092569985,62.54249986012777,62.52299976348877,62.50339984893799,62.483899434407554,62.464399337768555,62.444899559020996,62.42539978027344,62.40579922993978,62.38629945119222,62.36689980824789,62.34739971160889,62.32789993286133,62.30839920043945,62.288899739583336,62.26949946085612,62.25,62.23059940338135,62.21109994252523,62.19169902801514,62.17229970296224,62.15279960632324,62.13339932759603,62.11400000254313,62.09459940592448,62.07519976298014,62.05579948425293,62.036399841308594,62.01699924468994,61.99769973754883,61.97829977671305,61.95889949798584,61.93959935506185,61.920199712117515,61.90089956919352,61.88149960835775,61.862199783325195,61.84279982248942,61.82349967956543,61.80419953664144,61.784899393717446,61.76559925079346,61.74629910786947,61.726999282836914,61.707699139912926,61.68839963277181,61.669199307759605,61.64989916483561,61.63059997558594,61.61139965057373,61.59209950764974,61.57290013631185,61.55359967549642,61.534399350484215,61.51519934336344,61.49599997202555,61.47669919331869,61.457499504089355,61.43829917907715,61.41909980773926,61.39989948272705,61.38079992930094,61.361599604288735,61.34239959716797,61.3231995900472,61.30409971872965,61.28489971160889,61.26580015818278,61.246599197387695,61.227499643961586,61.20839913686117,61.189199129740395,61.17009957631429,61.15099938710531,61.13189951578776,61.112799962361656,61.09369977315267,61.07459990183512,61.05549971262614,61.036499977111816,61.01739978790283,60.99829928080241,60.97929986317953,60.96019967397054,60.94119962056478,60.92209974924723,60.90310001373291,60.88409932454427,60.86499913533529,60.8459997177124,60.8269993464152,60.80799929300944,60.788999239603676,60.7699998219808,60.750999450683594,60.73200003306071,60.713099797566734,60.69409974416097,60.675100008646645,60.65619977315267,60.63719971974691,60.61829980214437,60.59929974873861,60.580400149027504,60.56149927775065,60.54259936014811,60.52359962463379,60.50469938913981,60.48579947153727,60.4668992360433,60.44799963633219,60.42909971872965,60.41029930114746,60.39139938354492,60.372499783833824,60.35370000203451,60.33479976654053,60.31589984893799,60.29709974924723,60.27829933166504,60.25939973195394,60.240599632263184,60.22180016835531,60.20299975077311,60.18409983317057,60.16529973347982,60.146499951680504,60.12779966990153,60.10899988810221,60.09019978841146,60.0713996887207,60.052599589029946,60.033898989359535,60.0150998433431,59.996399879455566,59.977599143981934,59.95889949798584,59.940100034077965,59.930800120035805};
    //SO2F2={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,3.088535753074476e-08,2.4708286143019603e-07,4.941657204919162e-07,7.41248584290588e-07,9.883314315099294e-07,1.23541430715098e-06,1.4824971591072729e-06,1.7295800300113722e-06,1.9766628914415683e-06,2.2237457339239577e-06,2.47082861430196e-06,2.71791145678435e-06,2.9649943182145457e-06,3.212077179644742e-06,3.459160041074938e-06,3.70624292145294e-06,3.9533257828831365e-06,4.200408625365526e-06,4.447491467847915e-06,4.694574348225918e-06,4.94165722860392e-06,5.18874007108631e-06,5.4358229135687e-06,5.682905793946702e-06,5.929988674324704e-06,6.177071516807094e-06,6.424154359289484e-06,6.671237239667486e-06,6.918320120045489e-06,7.165402962527878e-06,7.4124858050102676e-06,7.659568609597045e-06,7.906651565766273e-06,8.15373437035305e-06,8.400817250731052e-06,8.647900131109054e-06,8.894983011487057e-06,9.142065740282609e-06,9.389148772243061e-06,9.636231501038614e-06,9.88331445720784e-06,1.0130397261794618e-05,1.037748014217262e-05,1.0624563022550623e-05,1.08716458271374e-05,1.1118728707515402e-05,1.1365811587893404e-05,1.161289439248018e-05,1.1859977348649409e-05,1.2107060153236185e-05,1.2354143033614188e-05,1.260122591399219e-05,1.2848308642787742e-05,1.3095391674748194e-05,1.3342474403543747e-05,1.3589557359712975e-05,1.3836640164299752e-05,1.4083723044677754e-05,1.4330805925055756e-05,1.4577888805433759e-05,1.4824971534229311e-05,1.5072054566189763e-05,1.5319137294985314e-05,1.5566220099572092e-05,1.5813302979950095e-05,1.606038601191055e-05,1.630746889228855e-05,1.65545516210841e-05,1.6801634349879652e-05,1.7048717381840106e-05,1.729580041380056e-05,1.754288314259611e-05,1.778996587139166e-05,1.8037048751769664e-05,1.8284131632147666e-05,1.853121466410812e-05,1.877829739290367e-05,1.9025380273281673e-05,1.9272463002077227e-05,1.951954588245523e-05,1.976662891441568e-05,2.0013711794793682e-05,2.0260794523589237e-05,2.050787740396724e-05,2.075496013276279e-05,2.100204331630569e-05,2.1249126045101246e-05,2.1496208925479248e-05,2.17432916542748e-05,2.199037438307035e-05,2.2237457566613255e-05,2.2484540446991257e-05,2.2731623175786808e-05,2.297870590458236e-05,2.322578878496036e-05,2.3472871816920815e-05,2.3719954697298817e-05,2.3967037426094368e-05,2.421412030647237e-05,2.4461203035267925e-05,2.4708286218810827e-05,2.4955368947606377e-05,2.520245182798438e-05,2.5449534556779934e-05,2.5696617437157936e-05,2.594370031753594e-05,2.619078334949639e-05,2.6437866078291943e-05,2.6684948958669945e-05,2.6932031687465496e-05,2.71791145678435e-05,2.7426197599803952e-05,2.7673280480181955e-05,2.7920363208977506e-05,2.8167445937773056e-05,2.841452881815106e-05,2.8661612001693964e-05,2.8908694730489515e-05,2.9155777459285066e-05,2.9402860339663068e-05,2.964994322004107e-05,2.9897026252001524e-05,3.0144108980797075e-05,3.0391191861175077e-05,3.063827504471798e-05,3.088535777351353e-05,3.113244050230909e-05,3.137952353426954e-05,3.162660595990019e-05,3.187368899186064e-05,3.2120771720656194e-05,3.236785444945175e-05,3.26149374814122e-05,3.286202021020775e-05,3.3109103545333106e-05,3.3356186577293556e-05,3.360326900292421e-05,3.385035203488466e-05,3.409743476368021e-05,3.4344517492475766e-05,3.459160052443622e-05,3.483868295006687e-05,3.508576598202732e-05,3.5332849013987776e-05,3.5579932045948226e-05,3.5827015077908676e-05,3.607409780670423e-05,3.6321180535499785e-05,3.6568263567460235e-05,3.681534599309089e-05,3.706242902505134e-05,3.730951175384689e-05,3.7556594482642445e-05,3.7803677514602896e-05,3.8050760546563346e-05,3.82978435785238e-05,3.8544926610484254e-05,3.8792009036114905e-05,3.9039092068075355e-05,3.928617479687091e-05,3.9533257525666464e-05,3.9780340557626914e-05,4.0027422983257566e-05,4.0274506015218016e-05,4.052158935034337e-05,4.0768672079138923e-05,4.1015755111099374e-05,4.126283783989493e-05,4.150992056869048e-05,4.175700360065093e-05,4.2004086026281584e-05,4.2251169058242034e-05,4.249825178703759e-05,4.274533451583314e-05,4.299241754779359e-05,4.3239500882918946e-05,4.34865836117145e-05,4.373366664367495e-05,4.39807490693056e-05,4.422783210126605e-05,4.447491483006161e-05,4.472199755885716e-05,4.496908059081761e-05,4.521616301644826e-05,4.5463246048408713e-05,4.571032968669897e-05,4.595741211232962e-05,4.620449514429007e-05,4.6451577873085625e-05,4.669866060188118e-05,4.694574363384163e-05,4.719282605947228e-05,4.743990909143273e-05,4.7686991820228286e-05,4.793407454902384e-05,5.6535057183282333e-05,0.000395680694055045,0.0009191006732483705,0.0015432043874170631,0.002300759816231827,0.0032624684972688556,0.004444035449220489,0.005948850031321247,0.007807039267693956,0.01012910824889938,0.012998711007336775,0.016469326335936785,0.0205847998149693,0.025345893887182076,0.030775485560297966,0.03691337754329046,0.043801869886616863,0.05148336167136828,0.05999985306213299,0.15999984927475452,0.23999984314044318,0.29999983310699463,0.3399998297293981,0.38999982674916583,0.4499998191992442,0.5199998070796331,0.5799998044967651,0.6199997961521149,0.6499997874101003,0.6599997778733572,0.6699997584025065,0.6799997389316559,0.7099997500578562,0.7399997313817342,0.7799997180700302,0.8399997055530548,0.8999996880690256,0.9299996793270111,0.9799996564785639,1.0199996531009674,1.049999624490738,1.0999996264775593,1.1599995990594227,1.2199995716412861,1.30385955174764,1.3807695309321086,1.4534794986248016,1.5028794904549916,1.5391694804032643,1.5879094898700714,1.6612594823042552,1.7433294157187145,1.8230694035689037,1.953319291273753,2.0393292903900146,2.129462401072184,2.2204294006029763,2.2993571162223816,2.389066974322001,2.4813172022501626,2.576047400633494,2.673187255859375,2.7685371239980063,2.8580069740613303,2.941766858100891,3.0199766755104065,3.0927865306536355,3.1603463888168335,3.2228062947591147,3.2802961468696594,3.3329560359319053,3.3809359471003213,3.4249258041381836,3.4656357367833457,3.5031556288401284,3.537565549214681,3.5689554611841836,3.59740541378657,3.622995297114054,3.6458152135213218,3.665925085544586,3.683405061562856,3.698704977830251,3.7122549613316855,3.724104861418406,3.7343048254648843,3.742894768714905,3.749924679597219,3.755424658457438,3.759454607963562,3.76203453540802,3.763224482536316,3.76328444480896,3.7625044186909995,3.7608944376309714,3.7584943175315857,3.755304296811422,3.7513542771339417,3.7466742595036826,3.7412742177645364,3.7351741592089334,3.728394110997518,3.721104105313619,3.7134740948677063,3.705514113108317,3.6972240209579468,3.6886239846547446,3.6797139843304953,3.6705039540926614,3.6609939336776733,3.6512139042218528,3.6411439379056296,3.6309138933817544,3.6206038991610208,3.6102339029312134,3.5997938315073648,3.58928382396698,3.5787238081296286,3.568103810151418,3.5574137767155967,3.546663781007131,3.535863757133484,3.524873753388723,3.5135536789894104,3.5019036730130515,3.489953656991323,3.477703591187795,3.4651535550753274,3.452323536078135,3.439213494459788,3.425833523273468,3.412193477153778,3.3986035188039145,3.3853734731674194,3.3724935054779053,3.359953502813975,3.3477535247802734,3.3358734846115112,3.3243034879366555,3.3130335410435996,3.302063465118408,3.2913835048675537,3.2807234724362693,3.269793430964152,3.2586233814557395,3.247213383515676,3.2355533639589944,3.2236733039220176,3.2115533153216043,3.199223260084788,3.1866632302602134,3.173903206984202,3.1609332164128623,3.147763172785441,3.134403189023336,3.120853145917257,3.1071231365203857,3.093203067779541,3.0791131059328714,3.064853072166443,3.050433079401652,3.0358530084292092,3.0211129983266196,3.006232957045237,2.991192956765493,2.9760229190190635,2.9607128699620566,2.945262869199117,2.9296928445498147,2.9139928420384726,2.8981728156407676,2.8822328050931296,2.866172750790914,2.8500027457873025,2.8337327043215432,2.817362685998281,2.800882637500763,2.784312625726064,2.767642597357432,2.750882625579834,2.7340425848960876,2.7171125411987305,2.7000925143559775,2.683002551396688,2.665822525819143,2.6485824584960938,2.6312624414761863,2.6138723691304526,2.5964223742485046,2.5789023439089456,2.5613123377164206,2.5436723232269287,2.525972306728363,2.5082122683525085,2.4903922279675803,2.472532252470652,2.4546121756235757,2.4366421699523926,2.418632169564565,2.400572121143341,2.3824621041615806,2.3643221259117126,2.346132059892019,2.32790199915568,2.3096419970194497,2.2913319865862527,2.2730019887288413,2.2546319365501404,2.2362219095230103,2.2177918950716653,2.1993218461672464,2.1808318297068277,2.162311851978302,2.1437618136405945,2.125181794166565,2.106581767400106,2.087961733341217,2.069311738014221,2.050641655921936,2.031951646010081,2.0132416685422263,1.9945215980211894,1.9757715861002605,1.9570015668869019,1.9382215440273285,1.9194215039412181,1.9006114900112152,1.8817814588546753,1.862931450208028,1.844081421693166,1.8252113858858745,1.806321382522583,1.7874313394228618,1.7685213188330333,1.7496013045310974,1.7306812802950542,1.7117412785689037,1.6927912533283234,1.6738412181536357,1.6548811892668407,1.6359011630217235,1.6169211566448212,1.5979411204655964,1.578951100508372,1.5599510769049327,1.5409410496552784,1.5219310224056244,1.502911001443863,1.4838909804821014,1.4648609658082326,1.4458309312661488,1.4268009165922801,1.407760888338089,1.388710876305898,1.369670828183492,1.3506208161513011,1.3315607905387878,1.3125107785065968,1.2934507429599762,1.2743907272815704,1.2553306818008423,1.2362706661224365,1.2172006567319233,1.1981406410535176,1.1790706018606822,1.1600005825360615,1.1409305731455486,1.1218605438868205,1.1027805109818776,1.0837105015913646,1.064640462398529,1.0455604394276936,1.0264904101689656,1.0074204007784526,0.9883443713188171,0.9692703535159429,0.9501983324686686,0.9311243096987406,0.9120492786169052,0.8929762542247772,0.873905231555303,0.8548332154750824,0.8357631911834081,0.8166951636473337,0.7976261327664057,0.7785561184088389,0.759489099184672,0.7404240667819977,0.7213580459356308,0.7022920250892639,0.6832280059655508,0.6641669968763987,0.6453740000724792,0.627110997835795,0.6093620012203852,0.5921129981676737,0.5753509898980459,0.5590620090564092,0.5432330022255579,0.5278510053952535,0.5129029949506124,0.4983770027756691,0.48426199704408646,0.4705459997057915,0.457217996319135,0.4442670022447904,0.4316820055246353,0.419453002512455,0.4075700019796689,0.3960230027635892,0.38480400045712787,0.37390099714199704,0.36330699920654297,0.35301299889882404,0.34301100422938663,0.33329200247923535,0.3238480016589165,0.31467099487781525,0.30575399845838547,0.29709000140428543,0.28867099930842716,0.2804909994204839,0.27254199981689453,0.26481900612513226,0.25731400152047473,0.25002199908097583,0.2429360014696916,0.23605099817117056,0.2293609989186128,0.22286099816362062,0.21654499818881354,0.21040800089637438,0.20444499949614206,0.19864999875426292,0.19301999857028326,0.1875500020881494,0.1822340004146099,0.17706899965802828,0.1720499967535337,0.16717400153477988,0.16243599727749825,0.15783199792106947,0.15335799877842268,0.1490119993686676,0.1447880007326603,0.1406839999059836,0.13669699927171072,0.13282199949026108,0.12905699759721756,0.12539900094270706,0.12184500073393185,0.11839100035528342,0.11503600080808003,0.1117749996483326,0.10860700036088626,0.10552800012131532,0.10253700117270152,0.09963040053844452,0.09680629956225555,0.09406229915718238,0.09139600085715453,0.08880529925227165,0.08628800076742967,0.08384210057556629,0.08146549885471661,0.07915619947016239,0.07691240062316258,0.07473219993213813,0.07261379932363828,0.07055539948244889,0.06855539915462334,0.06661210084954898,0.06472380024691422,0.0628890994315346,0.061106299671034016,0.05937409990777572,0.057691000401973724,0.05605560044447581,0.054466599908967815,0.05292260025938352,0.05142230043808619,0.04996459993223349,0.04854820047815641,0.04717200001080831,0.045834699645638466,0.044535400035480656,0.04327290039509535,0.04204620017359654,0.040854200099905334,0.039696100167930126,0.03857069959243139,0.03747730019191901,0.03641489986330271,0.035382600190738835,0.03437949996441603,0.0334049000715216,0.03245789961268505,0.031537700134019055,0.030643700156360865,0.02977489974970619,0.028930799880375464,0.02811070003857215,0.027313699945807457,0.026539400064696867,0.025787000078707933,0.025055999867618084,0.024345700008173782,0.023655499952534836,0.022984799928963184,0.022333199934413035,0.021700100352366764,0.021084900324543316,0.020487099885940552,0.01990629980961482,0.019341999820123117,0.018793599990506966,0.018260799814015627,0.017743100101749103,0.01724010007455945,0.01675129992266496,0.016276399915417034,0.015814999816939235,0.015366599972670278,0.01493099999303619,0.014507699913034836,0.014096400002017617,0.013696699946497878,0.013308400055393577,0.012931100092828274,0.012564500017712513,0.012208300099397698,0.011862199908743301,0.01152589994793137,0.011199099943041801,0.0108815998925517,0.010573099988202253,0.010273399918029705,0.00998208997771144,0.009699089995895823,0.009424109943211079,0.009156930027529597,0.008897319979344806,0.008645079952354232,0.008399979987492165,0.008161830094953379,0.007930439974491795,0.007705599962112804,0.00748713993622611,0.007274869984636704,0.007068620063364506,0.006868219973209004,0.006673489968913297,0.006484290002845228,0.0063004600039372844,0.0061218299670144916,0.005948270011382799,0.005779630038887262,0.005615770001895726,0.005456560019714137,0.0053018600059052306,0.005151540040969849,0.005005489996013542,0.004863580067952474,0.004725689999759197,0.004591709972980122,0.004461530091551443,0.004335039954942961,0.004212140028054516,0.004092720026771228,0.003976690000854433,0.003863940015435219,0.003754389976772169,0.00364794999283428,0.003544529996967564,0.003444040000128249,0.0033463999667825797,0.003251519985496998,0.003159339966562887,0.0030697700179492435,0.002982739999424666,0.0028981700112732747,0.00281600997550413,0.0027361700194887817,0.0026585999876260757,0.002583219980200132,0.002509990008547902,0.0024388199866128466,0.0023696799956572554,0.002302499992462496,0.002237220003735274,0.0021737899902897575,0.0021121699828654528,0.0020522800041362643,0.0019941000112642846,0.0019375699921511114,0.0018826299929060042,0.0018292599997948855,0.0017774000007193536,0.0017270099876138072,0.0016780500009190291,0.0016304700014491875,0.0015842500045740355,0.0015393300078964482,0.0014956900073836248,0.0014532900143725176,0.0014120900013949722,0.0013720499797879409,0.0013331599960414071,0.0012953600089531392,0.0012586399971041828,0.0012229499989189208,0.0011882800026796758,0.001154590000320847,0.0011218600169134636,0.001090060007603218,0.0010591500031296164,0.0010291300034926583,0.0009999500083116193,0.0009716010002496963,0.0009440560000560557,0.0009172920011527216,0.0008912870010438686,0.0008660189972336715,0.000841467990539968,0.0008176120075707635,0.0007944329991005361,0.0007719109999015927,0.0007500279947028806,0.0007287649981056651,0.0007081049940704057,0.000688029991579242,0.0006685249973088503,0.0006495720008388162,0.0006311569983760515,0.0006132649965972329,0.0005958790037160119,0.0005789860054695358,0.0005625720077659935,0.0005466240011931708,0.0005311280013605332,0.0005234910010282571};
        CCl4={0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000428936133783,0.025000376626849174,0.025000494594375294,0.025000344030559063,0.025000539453079302,0.02500028194238742,0.02500062497953574,0.02500016087045272,0.025000798360755045,0.02499991360430916,0.02507337733792762,0.02532928188641866,0.0812472328543663,0.10000008965531985,0.11666701609889667,0.19333053504427275,0.31655970215797424,0.5206524853905042,0.7563406427701315,0.9276737372080485,1.0843643546104431,1.176037738720576,1.241669515768687,1.3888855278491974,1.6249915957450867,1.8459543486436207,2.1164215207099915,2.460367262363434,2.6942857106526694,3.02649054924647,3.517713646094004,4.063463946183522,4.702978173891704,5.2942134141922,5.937420805295308,6.679798523585002,7.595823089281718,8.761372248331705,10.024959723154703,11.266163110733032,12.575761953989664,14.090854724248251,15.872149070103964,18.12043031056722,20.794118722279865,23.86478344599406,25.904248396555584,27.504756927490234,29.078561464945476,31.041143258412678,33.192337354024254,35.499832471211754,37.58082548777262,38.706894874572754,40.05176067352295,41.54246679941813,43.17295900980631,44.93925635019938,46.82995192209879,48.83994928995768,50.97114499409994,53.211243311564125,55.563539822896324,58.007436752319336,60.507436434427895,63.07753308614095,65.62683486938477,68.0712407430013,70.42624282836914,72.69054730733235,74.8699499766032,76.96995290120442,78.98995844523112,80.9293607076009,82.79306348164876,84.59316635131836,86.32876841227214,87.99307123819987,89.59247398376465,91.13187662760417,92.61308097839355,94.1031723022461,95.31219546000163,96.45029131571452,97.67579015096028,98.93998591105144,100.18199602762859,101.67297554016113,103.0739803314209,104.16901715596516,105.88293329874675,106.4680290222168,105.85304832458496,104.98307355244954,104.32304191589355,103.57006708780925,102.88904825846355,102.31104151407878,101.2420825958252,100.31604703267415,99.330872853597,98.27196884155273,97.35795720418294,96.3429667154948,95.34536170959473,94.38845952351888,93.41565831502278,92.3141638437907,91.12946637471516,89.87336858113606,88.57357406616211,87.3809585571289,86.05878257751465,85.01424598693848,83.89107831319173,83.06993166605632,82.11866696675618,80.86898740132649,79.52149200439453,78.11889394124348,76.66949653625488,75.1811974843343,73.66110038757324,72.11549949645996,70.55040168762207,68.97130266825359,67.38310432434082,65.79030545552571,64.19690577189128,62.60670598347982,61.023006757100426,59.44890785217285,57.88690789540609,56.33960819244385,54.80900859832764,53.297109285990395,51.80550893147787,50.33590952555338,48.889309565226235,47.46710968017578,46.07011000315348,44.69920984903971,43.35500971476237,42.03800996144613,40.748809496561684,39.48770968119303,38.25480969746908,37.05040963490804,35.874509493509926,34.727109591166176,33.60820960998535,32.51750946044922,31.455109119415283,30.420508861541748,29.41360886891683,28.434008757273357,27.48140811920166,26.555508136749268,25.655808130900066,24.78190803527832,23.9334077835083,23.109907627105713,22.31080722808838,21.535707155863445,20.784107208251953,20.055607000986736,19.34950653711955,18.665506680806477,18.002906322479248,17.361306190490723,16.740205764770508,16.139106035232544,15.5575057665507,14.994805574417114,14.450605312983194,13.924305200576782,13.415605147679647,12.923804918924967,12.448604822158813,11.989504734675089,11.545904556910196,11.117504358291626,10.703804095586142,10.304404020309448,9.918873945871988,9.546733776728312,9.187613725662231,8.841103474299112,8.506823460261026,8.184373378753662,7.873393257459004,7.573513150215149,7.284373005231221,7.005632996559143,6.7369528611501055,6.4779927333196,6.228452603022258,5.9880024989446,5.75634245077769,5.533182342847188,5.318232258160909,5.1112122138341265,4.9071822961171465,4.706332246462504,4.513542175292969,4.328502019246419,4.15089197953542,3.9804318944613137,3.8168318470319114,3.6598417361577353,3.5091916918754578,3.364621639251709,3.225911537806193,3.0928114851315818,2.9651214480400085,2.8426013588905334,2.7250713308652244,2.6123212973276773,2.504161218802134,2.4004011154174805,2.3008811275164285,2.20543106396993,2.113870998223623,2.026061018308004,1.9418509403864543,1.8610909084479015,1.7836408813794453,1.7093708217144012,1.6381507913271587,1.5698507726192474,1.504370739062627,1.4415907164414723,1.3813906610012054,1.3236706455548604,1.2683406074841816,1.2152905861536663,1.1644405821959178,1.115690549214681,1.0689505239327748,1.0241505205631256,0.9812124818563461,0.9400524546702703,0.9005994449059168,0.8627854337294897,0.8265424072742462,0.7918053865432739,0.7585143744945526,0.7266093591849009,0.6960333536068598,0.6667313277721405,0.6386513213316599,0.6117422978083292,0.5859572937091192,0.5612492760022482,0.5375742564598719,0.5148882518212,0.4931522433956464,0.47232523560523987,0.45237122227748233,0.4332532087961833,0.41493620723485947,0.39738719910383224,0.38057518750429153,0.364469180504481,0.3490391746163368,0.33425716559092206,0.3200971608360608,0.3065321519970894,0.2935381457209587,0.2810911387205124,0.2691691319147746,0.25774812946716946,0.2468091237048308,0.23633112013339996,0.2262951135635376,0.21668210749824843,0.2074761042992274,0.19865810126066208,0.1902120957771937,0.18212409069140753,0.17437708750367165,0.16695808246731758,0.15985308090845743,0.1530490778386593,0.14653207237521806,0.1402920683224996,0.13431606690088907,0.12859306360284486,0.12311306223273277,0.11786505952477455,0.11284005704025428,0.10802805485824744,0.10342105167607467,0.09900854962567489,0.09478384753068288,0.09073864544431369,0.08686534191171329,0.08315674153467019,0.07960573956370354,0.07620573788881302,0.07295043642322223,0.06983363504211108,0.06684943412741025,0.06399233266711235,0.061256930542488895,0.05863792976985375,0.05613062810152769,0.05373012709120909,0.05143192627777656,0.04923172481358051,0.04712532367557287,0.04510882248481115,0.04317832148323456,0.04133022017776966,0.03956092055886984,0.03786721918731928,0.03624581762899955,0.034693717335661255,0.03320781669269005,0.03178541595116258,0.03042381505171458,0.02912041467304031,0.027872714214026928,0.026678313345958788,0.025535112867752712,0.02444071260591348,0.023393111769109964,0.022390311118215322,0.02143051087235411,0.020511710395415623,0.019632209713260334,0.018790409434586763,0.017984609274814527,0.017213408835232258,0.016475108296920855,0.015768507961183786,0.015092207584530115,0.014444807389130196,0.013825106900185347,0.013232006691396236,0.012664406405140957,0.012121006147935987,0.011601005913689733,0.011103205615654588,0.010626805402959386,0.01017080519037942,0.009734384870777527,0.009316664654761553,0.008916864637285471,0.00853420429242154,0.008167964173480868,0.007817433952974776,0.007481953827664256,0.007160863645064334,0.006853563478216529,0.0065594533225521445,0.006277963208655517,0.0060085729928687215,0.005750732923236986,0.005503972798275451,0.005267802703504761,0.005041762565573056,0.004825432396804293,0.004618392325937748,0.004420232182989518,0.004230572143569589,0.004049062030389905,0.0038753319531679153,0.0037090618667813637,0.0035499317843156555,0.0033976317111713192,0.003251861645064006,0.00311234158774217,0.0029788215178996325,0.0028510214760899544,0.002728701375114421,0.0026116413064301014,0.0024996012604484954,0.0023923612122113505,0.002289731152510891,0.0021915010875090957,0.0020974810662058494,0.002007501005815963,0.0019213809670569997,0.001838950925351431,0.0017600608892583598,0.0016845608479343355,0.0016122908370258908,0.001543120772112161,0.0014769307454116642,0.0014135707072758426,0.001352930684030677,0.0012948906611806403,0.0012393406068440527,0.001186170595853279,0.0011352905809568863,0.0010865905399744709,0.001039980532368645,0.0009953634968648355,0.0009526644765477007,0.0009117974647476027,0.000872684443796364,0.0008352484243611494,0.0007994184027969217,0.0007651263828544567,0.0007323043731351694,0.0007008913574585071,0.0006708253398149585,0.000642049330053851,0.0006145073081521938,0.0005881472898181528,0.0005629182802901292,0.000538771278418911,0.0005156602564966306,0.0004935402515305517,0.000472370236821007,0.00045210723086105037,0.0004327142160036601,0.0004141522100932586,0.00039638720045331866,0.0003793841873023969,0.0003631111831055023,0.0003475351719923007,0.00033262816820448887,0.00031836015841690823,0.0003047041512521294,0.00029163414728827775,0.00027912514148435247,0.0002671521287993528,0.00025569313099064556,0.00024472612494719215,0.0002342281186429318,0.00022418211301555857,0.00021456610920722596,0.00020536310573030883,0.00019655409778351896,0.00018812309644999914,0.0001800540934103386,0.00017233208927791566,0.0001649400825651052,0.0001578650796242679,0.00015109407710648762,0.0001446140740881674,0.00013841106920153834,0.00013247506649349816,0.00012679306140247112,0.00012135506040067412,0.00011615005860221572,0.00011116805520335522,0.0001064000546951623,9.351018949625238e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        CFC11={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.004844144840414326,0.08337228807310264,0.3000110412637393,0.5000130111972491,0.7000119686126709,0.8938818424940109,1.1468555231889088,1.5540266533692677,2.129436651865641,2.8635963996251426,3.7677908142407737,4.90076740582784,6.239397327105205,7.567232608795166,8.797123988469442,10.23712126413981,12.167853911717733,14.639893293380737,17.71703306833903,21.421671549479168,25.709799925486248,30.50373379389445,35.86647764841715,41.93913205464681,48.922607421875,56.95325533548991,65.84650834401448,75.6708869934082,86.87261581420898,99.53890228271484,112.33176358540852,124.73074785868327,136.7956975301107,148.00458017985025,157.6384735107422,166.07752100626627,174.73850377400717,183.27747344970703,191.16732279459634,199.96714146931967,214.03345489501953,222.3396848042806,233.33564122517905,244.82575480143228,256.58931223551434,263.08519744873047,267.79015350341797,270.7759323120117,271.1687749226888,269.62779235839844,268.1038513183594,266.7558415730794,265.2918523152669,263.8838653564453,262.5458628336589,261.1698455810547,259.5498352050781,257.66879018147785,255.41280873616537,253.1937993367513,250.9148038228353,248.66479873657227,246.4138298034668,244.47682189941406,242.4608243306478,240.45181020100912,238.2458127339681,236.20683797200522,234.38086700439453,233.07986958821616,231.45189793904623,229.59260686238608,226.3097178141276,223.64271036783853,220.94971084594727,218.23470815022787,215.4997075398763,212.74970245361328,209.98670450846353,207.2137018839518,204.4337018330892,201.6497014363607,198.86370086669922,196.0787010192871,193.29570134480795,190.51670455932617,187.7457046508789,184.98170598347983,182.22870635986328,179.48670959472656,176.7587102254232,174.0447120666504,171.3467114766439,168.66571553548178,166.00371805826822,163.36072158813477,160.73772303263345,158.13572311401367,155.55572509765625,152.99973169962564,150.46673329671225,147.95773442586264,145.47373580932617,143.01474126180014,140.58174260457358,138.17574564615884,135.79574584960938,133.44275283813477,131.11775588989258,128.81975873311362,126.54976081848145,124.30776405334473,122.09376589457194,119.90776952107747,117.75077311197917,115.62277666727702,113.52277819315593,111.45078150431316,109.40878550211589,107.39378801981609,105.40879122416179,103.45079358418782,101.52279726664226,99.62180074055989,97.74930381774902,95.90490659077962,94.08840878804524,92.29961268107097,90.53831481933594,88.80451838175456,87.09782028198242,85.41822242736816,83.76532554626465,82.13893000284831,80.53893216451009,78.96503448486328,77.41703796386719,75.89463996887207,74.39754295349121,72.92554601033528,71.4783484141032,70.05575116475423,68.6574535369873,67.28315607706706,65.93265787760417,64.60556030273438,63.30156326293945,62.0205659866333,60.762167612711586,59.52607091267904,58.31197261810303,57.11957518259684,55.94867738087972,54.79897944132487,53.670081774393715,52.56178506215414,51.49499098459879,50.46839205423991,49.45969422658285,48.468695958455406,47.49499797821045,46.53859996795654,45.59920120239258,44.67660331726074,43.77060508728027,42.88080660502116,42.00730927785238,41.149609883626304,40.3077122370402,39.481213887532554,38.67001438140869,37.87391630808512,37.092617988586426,36.32591978708903,35.573621114095054,34.83542251586914,34.11122417449951,33.40082613627116,32.70392640431722,32.02042849858602,31.350029786427815,30.6925311088562,30.047632535298664,29.41533374786377,28.795335292816162,28.1874361038208,27.591437657674152,27.00713872909546,26.434340000152588,25.872841517130535,25.32254234949748,24.78304322560628,24.254344781239826,23.73624610900879,23.22844711939494,22.730947812398274,22.243349075317383,21.765550295511883,21.29745101928711,20.838852246602375,20.38955307006836,19.94935417175293,19.518255074818928,19.095855871836346,18.682156880696613,18.276957511901855,17.88005828857422,17.49135939280192,17.110660076141357,16.737860838572185,16.372761726379395,16.015262524286907,15.665263414382935,15.322564204533895,14.98696494102478,14.658365726470947,14.336766481399536,14.021867036819458,13.713567813237509,13.411768356959024,13.116369167963663,12.827169815699259,12.544170300165812,12.267071088155111,11.995871623357138,11.730472167332968,11.470772902170816,11.216573397318522,10.967773993810018,10.724274555842081,10.486075162887573,10.252975622812906,10.02487619717916,9.801626523335775,9.583227157592773,9.369537671407064,9.160458246866861,8.955888668696085,8.755759159723917,8.559969584147135,8.368419885635376,8.181040366490683,7.997740864753723,7.818421284357707,7.643011728922526,7.471432050069173,7.303612510363261,7.139452934265137,6.97890321413676,6.82188359896342,6.6682939529418945,6.5180743137995405,6.371174693107605,6.227494955062866,6.086975375811259,5.949555675188701,5.815175970395406,5.683756232261658,5.555236577987671,5.429556926091512,5.30666712919871,5.18650750319163,5.069017648696899,4.954148014386495,4.84181825319926,4.731978456179301,4.624578833580017,4.519589106241862,4.416939377784729,4.316569526990254,4.218449751536052,4.122520009676616,4.02873017390569,3.9370404283205667,3.847400665283203,3.7597808639208474,3.6741210420926413,3.5903712709744773,3.508511463801066,3.4285016457239785,3.3502918680508933,3.273852050304413,3.199132223924001,3.126102387905121,3.0547125736872354,2.9849327206611633,2.916722893714905,2.8500430385271707,2.7848732074101767,2.721173365910848,2.6588935256004333,2.59804368019104,2.538583815097809,2.4804539481798806,2.423634111881256,2.368114193280538,2.3138543168703714,2.2608144680658975,2.208984593550364,2.158334712187449,2.1088348428408303,2.060474952061971,2.013215104738871,1.9670251806577046,1.921895295381546,1.8777853945891063,1.834685504436493,1.7925655841827393,1.751405696074168,1.7111858030160267,1.6718758940696716,1.6334859828154247,1.5959660808245342,1.5593061745166779,1.5234762728214264,1.4884563783804576,1.4542464415232341,1.420826494693756,1.3881465792655945,1.3562366863091786,1.3250767687956493,1.2946068147818248,1.264836887518565,1.2357569634914398,1.2073270281155903,1.179547091325124,1.1524071594079335,1.125897228717804,1.100007305542628,1.0746973653634389,1.049957424402237,1.025787482659022,1.0021875351667404,0.9791275958220164,0.9565886457761129,0.9345517009496689,0.9130277633666992,0.8920048127571741,0.8714708636204401,0.8514149039983749,0.831803947687149,0.8126279960076014,0.7938980460166931,0.7756040891011556,0.7577351282040278,0.7402821779251099,0.7232352197170258,0.7065632541974386,0.6902583042780558,0.6743323355913162,0.6587763826052347,0.6435834219058355,0.6287434548139572,0.6142484843730927,0.6000905185937881,0.5862615605195364,0.5727545867363611,0.5595406144857407,0.5466126551230749,0.5339856793483099,0.5216517100731531,0.5096057405074438,0.4978387753168742,0.4863468036055565,0.47512082755565643,0.4641568611065547,0.4534478858113289,0.4429879089196523,0.43277093519767124,0.4227919603387515,0.4130449866255124,0.4035240064064662,0.3942040205001831,0.3850790510574977,0.37616707384586334,0.36746109773715335,0.35895811518033344,0.35065313676993054,0.3425421590606372,0.33461817105611164,0.32688019176324207,0.31932121018568677,0.31193823367357254,0.3047262455026309,0.2976832687854767,0.2908032809694608,0.2840842977166176,0.2775203138589859,0.27110933264096576,0.26484834651152295,0.2587323561310768,0.25275838126738864,0.2469243916372458,0.24122540776928267,0.23565841962893805,0.23022143294413885,0.22491144637266794,0.21972446019450823,0.21465747182567915,0.20970948413014412,0.20487549404303232,0.20015450939536095,0.19554351891080538,0.1910395324230194,0.18664053827524185,0.1823225480814775,0.1780835563937823,0.1739425684014956,0.16989857951800028,0.1659475862979889,0.16208959743380547,0.15832060699661574,0.1546396166086197,0.15104462454716364,0.14753263319532076,0.14410264045000076,0.14075264955560365,0.13748066003123918,0.13428366680939993,0.13116167361537615,0.12811268121004105,0.12513468911250433,0.12222569684187572,0.11938370391726494,0.116608710338672,0.11389771786828835,0.11124972440302372,0.10866373094419639,0.10613773639003436,0.10367074112097423,0.10126074838141601,0.098906555523475,0.09660736036797364,0.09436176593104999,0.09216827029983203,0.0900258757174015,0.08793318209548791,0.08588928605119388,0.08389279246330261,0.08194289728999138,0.08003820230563481,0.0781778059899807,0.07636071058611076,0.0745859146118164,0.07285231910645962,0.07115902317066987,0.06950522710879643,0.06788973261912663,0.06631193682551384,0.06477073828379314,0.06326534350713094,0.06179504686345657,0.06035895055780808,0.05895615338037411,0.0575860571116209,0.05624776054173708,0.05494056393702825,0.05366386597355207,0.052416770408550896,0.051198672813673816,0.05000887562831243,0.04884677845984697,0.047711681885023914,0.0466029845799009,0.04552008708318075,0.04446239024400711,0.043429192466040455,0.042420094522337116,0.04143439761052529,0.04047170002013445,0.03953130170702934,0.03861280406514803,0.03771560608098904,0.036839308217167854,0.03598341097434362,0.03514741330097119,0.034330815076828,0.03353321645408869,0.03275411917517582,0.03199312090873718,0.031249822893490393,0.030523924467464287,0.02981472589696447,0.029122127685695887,0.02844562955821554,0.02778483120103677,0.027139332766334217,0.026508934174974758,0.02589313577239712,0.025291637362291414,0.02470413890356819,0.02413024039318164,0.023569741441557806,0.023022342938929796,0.02248754445463419,0.021965245716273785,0.021455046565582354,0.02095674832041065,0.020469948804626863,0.01999455053980152,0.01953015150502324,0.01907655301814278,0.018633453796307247,0.018200754808882873,0.017778055897603433,0.017365157138556242,0.016961857831726473,0.01656795898452401,0.016183259741713602,0.015807360721131165,0.015440361729512611,0.015081762724245587,0.014731563550109664,0.01438946439884603,0.014055365153277913,0.013728966005146503,0.013410166759664813,0.013098767648140589,0.012794668320566416,0.012497568891073266,0.012207369785755873,0.011923970576996604,0.011647071068485578,0.011376671803494295,0.011112572470058998,0.010854573066656789,0.01060257370894154,0.010356374240169922,0.010115974970782796,0.009881125530228019,0.009651736123487353,0.00942766658651332,0.009208817112570008,0.008995037603502473,0.008786238264292479,0.008582278775672117,0.008383059330905477,0.008188469801098108,0.007998400212575993,0.007812740669275323,0.007631401065737009,0.007454261532984674,0.007281241977276902,0.007112252331959705,0.006947172728056709,0.006785933122349282,0.006628443603403866,0.0064746039764334755,0.006324334380527337,0.006177564733661711,0.006034195112685363,0.005894155435574551,0.005757375814331074,0.005623765561419229,0.005493270078053077,0.005428784643299878};
    CFC113={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001314997343191256,0.021151568042114377,0.07499745239814122,0.12499795357386272,0.174997894714276,0.22499790415167809,0.27499790986378986,0.3249979118506114,0.3749979188044866,0.4249979183077812,0.4749979227781296,0.5249979098637899,0.5749979317188263,0.6249979237715403,0.6749979356924692,0.7249979277451833,0.7749979496002197,0.8249979366858801,0.8749979635079702,0.9249979307254156,0.9749979873498281,1.0244279702504475,1.079317679007848,1.1389276186625164,1.2079770465691884,1.2937463521957397,1.3882061143716176,1.4974753856658936,1.6274844805399578,1.777483691771825,1.9469429155190785,2.141221841176351,2.365680515766144,2.6255189975102744,2.9195976853370667,3.2579756379127502,3.653163174788157,4.101901113986969,4.61564834912618,5.203845143318176,5.882411241531372,6.6607770919799805,7.553642193476359,8.576456785202026,9.748060464859009,11.09574286142985,12.636435270309448,14.47871708869934,15.96304734547933,17.68312692642212,20.167388280232746,23.256973266601562,27.298911412556965,30.830673376719158,34.79922644297282,39.652387619018555,44.608107248942055,50.83082103729248,57.8955987294515,64.49583530426025,70.81883303324382,76.4864673614502,80.40375582377116,82.41623814900716,83.36027018229167,83.83788744608562,83.94530232747395,83.52113278706868,82.96492513020833,82.38263448079427,81.99841690063477,81.4894282023112,80.81803385416667,80.10183588663737,79.26674334208171,78.73161888122559,78.12813186645508,77.3146406809489,76.47364234924316,75.92381922403972,75.33903121948242,74.6382344563802,73.97862943013509,73.30493418375652,72.71072514851888,72.07452328999837,71.41004117329915,70.57024574279785,69.81634140014648,69.06674067179362,68.32203992207845,67.58244132995605,66.84813944498698,66.11943944295247,65.3964392344157,64.67943890889485,63.96834023793539,63.2634391784668,62.56473859151205,61.872237841288246,61.18603769938151,60.50603771209717,59.83243719736735,59.165136655171715,58.50403626759847,57.84923585255941,57.20073541005453,56.5585355758667,55.922435442606606,55.292535146077476,54.66883405049642,54.05123360951742,53.43973318735758,52.83423296610514,52.23473294576009,51.64113203684489,51.05343246459961,50.4717321395874,49.89573129018148,49.325531005859375,48.76103083292643,48.20223045349121,47.64902973175049,47.10142993927002,46.55942980448405,46.02282969156901,45.491628646850586,44.965928395589195,44.445427894592285,43.930328051249184,43.42042795817057,42.91582775115967,42.41632684071859,41.9219274520874,41.43252722422282,40.94822629292806,40.468926111857094,39.99452590942383,39.52502568562826,39.06042607625326,38.60052522023519,38.145425160725914,37.69512494405111,37.249424616495766,36.8083241780599,36.371923764546715,35.94002374013265,35.51262346903483,35.08972358703613,34.67122300465902,34.2571226755778,33.84742228190104,33.44202168782552,33.04082171122233,32.64392217000326,32.251221338907875,31.86272128423055,31.478321075439453,31.098020712534588,30.721720536549885,30.34942038853963,29.981220245361328,29.616820017496746,29.25641965866089,28.899819215138752,28.547119140625,28.198219140370686,27.853018919626873,27.511618773142498,27.173818588256836,26.839818159739178,26.509318033854168,26.18241786956787,25.859217643737793,25.539417425791424,25.22311766942342,24.9104167620341,24.601016998291016,24.295116901397705,23.992716630299885,23.69351641337077,23.39781602223714,23.105315844217937,22.816215833028156,22.530315399169922,22.247715791066486,21.96831512451172,21.69211546579997,21.419014930725098,21.14911460876465,20.882314523061115,20.61851437886556,20.357914129892986,20.100214163462322,19.845614115397137,19.5939138730367,19.34511359532674,19.099313418070476,18.85641320546468,18.616313139597576,18.37911319732666,18.144712607065838,17.913012345631916,17.684112707773846,17.458012262980144,17.234512329101562,17.01371208826701,16.795612176259358,16.580111980438232,16.367111682891846,16.156811396280926,15.948911428451538,15.743611176808676,15.540811141331991,15.340511083602905,15.142510811487833,14.94701067606608,14.753910541534424,14.563210487365723,14.374710241953531,14.188610076904297,14.004810333251953,13.823210000991821,13.643909692764282,13.466809749603271,13.29190969467163,13.119109392166138,12.948509454727173,12.780009269714355,12.613609075546265,12.449209054311117,12.286909023920694,12.12670866648356,11.968408584594727,11.812108516693115,11.657808542251587,11.50540828704834,11.354908148447672,11.206308046976725,11.059608141581217,10.914707899093628,10.771707773208618,10.630507548650106,10.491007645924887,10.353307406107584,10.217407464981079,10.083207289377848,9.950677315394083,9.819857041041056,9.690697113672892,9.563177108764648,9.437286853790283,9.313006718953451,9.190306663513184,9.069186687469482,8.94960649808248,8.831566333770752,8.715036392211914,8.599996169408163,8.486436208089193,8.374346176783243,8.263686021169027,8.154455979665121,8.04663602511088,7.940205812454224,7.835155765215556,7.731455683708191,7.629095673561096,7.5280655225118,7.428345441818237,7.329905430475871,7.2327553033828735,7.136865297953288,7.042215188344319,6.948805093765259,6.856605013211568,6.765605012575786,6.675784945487976,6.58714485168457,6.499654769897461,6.413314779599507,6.328104615211487,6.2439945936203,6.160994529724121,6.079084515571594,5.998244404792786,5.91845428943634,5.8397243420283,5.7620242436726885,5.685334165891011,5.60966416200002,5.5349840720494585,5.461284001668294,5.388553977012634,5.316783905029297,5.245963891347249,5.176073789596558,5.107103784879048,5.039043704668681,4.971883654594421,4.905603567759196,4.840213576952617,4.775673548380534,4.712003509203593,4.649163405100505,4.58716340859731,4.525973359743754,4.465603311856587,4.406033317248027,4.347253163655599,4.289253155390422,4.232023239135742,4.175543109575908,4.119823098182678,4.064842939376831,4.010602970918019,3.957072913646698,3.904252906640371,3.852142850557963,3.8007328510284424,3.749992827574412,3.699942727883657,3.6505526900291443,3.6018226544062295,3.553752621014913,3.5063226024309793,3.4595225850741067,3.4133525292078652,3.3678024808565774,3.322862446308136,3.278512418270111,3.2347623705863953,3.191602369149526,3.149012327194214,3.1069923043251038,3.0655322670936584,3.024632235368093,2.984272221724192,2.9444621801376343,2.905172129472097,2.8664121627807617,2.8281721075375876,2.790442089239756,2.7532120744387307,2.7164820233980813,2.6802420218785605,2.644481976826986,2.609201947848002,2.5743918816248574,2.5400518774986267,2.5061618288358054,2.47273180882136,2.439741830031077,2.407191753387451,2.3750817577044168,2.3434017499287925,2.3121416767438254,2.2812917033831277,2.250861644744873,2.220841646194458,2.1912116408348083,2.1619815826416016,2.133141577243805,2.1046915650367737,2.0766115387280784,2.048911472161611,2.021581490834554,1.994611491759618,1.9680114388465881,1.941761424144109,1.915851394335429,1.8903014063835144,1.865081379810969,1.8402113616466522,1.815661331017812,1.7914413313070934,1.767551302909851,1.7439712782700856,1.7207113007704418,1.697761247555415,1.6751112341880798,1.6527712245782216,1.630721201499303,1.6089711884657543,1.5875111818313599,1.5663411418596904,1.5454411605993907,1.5248311161994934,1.504491110642751,1.4844310879707336,1.4646310607592266,1.4450910687446594,1.4258210559686024,1.406801054875056,1.3880410293738048,1.3695310056209564,1.3512609998385112,1.3332409759362538,1.3154609600702922,1.297910988330841,1.2806009352207184,1.2635209361712139,1.24667090177536,1.230050911506017,1.2136408885320027,1.1974608699480693,1.1814908683300018,1.1657308836778004,1.150180846452713,1.1348508497079213,1.1197108527024586,1.1047808130582173,1.0900508066018422,1.0755107800165813,1.0611707766850789,1.0470207730929058,1.033050775527954,1.0192807614803314,1.0056907435258229,0.99227574467659,0.9790437271197637,0.9659887154897054,0.9531077047189077,0.9403986980517706,0.9278586904207865,0.915486678481102,0.9032796720663706,0.8912346561749777,0.8793516506751379,0.8676266421874365,0.8560576339562734,0.8446436276038488,0.8333816180626551,0.8222696135441462,0.8113065958023071,0.800489584604899,0.7898165782292684,0.7792865633964539,0.7688965698083242,0.758645569284757,0.7485305468241373,0.738551547129949,0.7287055402994156,0.7189905295769373,0.709404523173968,0.6999475161234537,0.690616508324941,0.6814095079898834,0.6723254919052124,0.6633624881505966,0.6545194884141287,0.6457944810390472,0.6371854692697525,0.6286914646625519,0.620311458905538,0.6120424568653107,0.6038844386736552,0.595834438999494,0.5878924230734507,0.5800564289093018,0.5723244200150172,0.5646964212258657,0.5571694175402323,0.5497434039910635,0.5424154003461202,0.5351864000161489,0.5280533830324808,0.5210153857866923,0.5140713850657145,0.5072203775246938,0.5004603813091913,0.4937903607885043,0.48720936477184296,0.4807163526614507,0.47431034594774246,0.46798934290806454,0.46175234764814377,0.4555993303656578,0.4495273381471634,0.44353731721639633,0.43762734284003574,0.43179527670145035,0.4260413820544879,0.42036420851945877,0.4147634481390317,0.4092361181974411,0.40378352254629135,0.3984030435482661,0.3930955504377683,0.38785703231890994,0.38269050419330597,0.3775910933812459,0.37256042162577313,0.36759616682926816,0.36269933730363846,0.3578672260046005,0.3530992865562439,0.34839524577061337,0.34375325590372086,0.339174248278141,0.3346562460064888,0.3301972448825836,0.32579924166202545,0.3214592436949412,0.31717723111311596,0.3129522328575452,0.3087832232316335,0.30467023452123004,0.3006122062603633,0.29660724848508835,0.29265716423590976,0.28875929365555447,0.2849131027857463,0.28111834575732547,0.2773740366101265,0.27367938061555225,0.27003402014573413,0.266438364982605,0.2628900458415349,0.2593883102138837,0.25593409687280655,0.2525262435277303,0.24916314209500948,0.24584520484010378,0.24257116640607515,0.23934118325511614,0.23615317046642303,0.23300917446613312,0.22990616783499718,0.22684516881903014,0.22382416451970735,0.22084416449069977,0.21790315955877304,0.2150021605193615,0.2121401553352674,0.20931516215205193,0.20652813588579497,0.20377917711933455,0.20106510445475578,0.19838920732339224,0.19574705883860588,0.19314124683539072,0.1905700204273065,0.18803326661388078,0.18553001309434572,0.18306024993459383,0.18062303587794304,0.17821920663118362,0.17584707587957382,0.17350616678595543,0.17119710271557173,0.16891814023256302,0.16666911294062933,0.164451123525699,0.16226211935281754,0.1601031186679999,0.15797211478153864,0.1558691163857778,0.15379511440793672,0.15174811333417892,0.14972810943921408,0.1477361060678959,0.14577010894815126,0.14383010069529215,0.14191611732045809,0.14002708718180656,0.1381641315917174,0.13632506132125854,0.13451114917794862,0.1327220437427362,0.13183302183945975};
        CFC114={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0004437717252585571,0.009225911945880702,0.04815833130851388,0.112600847457846,0.20245546102523804,0.3176470845937729,0.4580556924144427,0.6235543092091879,0.8140119264523188,1.0316545367240906,1.2518172562122345,1.4824664394060771,1.7349158823490143,1.984303871790568,2.2399121522903442,2.4949118296305337,2.7499121824900308,3.006162941455841,3.2499133944511414,3.4969948132832847,3.7265921036402383,3.938670496145884,4.1636671622594195,4.398663679758708,4.63597031434377,4.877436995506287,5.135173638661702,5.413369536399841,5.707025408744812,6.014501253763835,6.334147016207377,6.6643119653066,7.00438114007314,7.356679677963257,7.723947962125142,8.108936508496603,8.51440660158793,8.955106973648071,9.431879123051962,9.926631212234497,10.421233495076498,10.897735516230265,11.349838097890219,11.805440743764242,12.194235563278198,12.642924229303995,13.144109964370728,13.69979476928711,14.25549602508545,14.756715536117554,15.212542057037354,15.573984305063883,15.752021392186483,15.899934848149618,16.066639582316082,16.09994300206502,16.137446244557697,16.249948978424072,16.362446784973145,16.399945735931396,16.44995387395223,16.499963760375977,16.54997984568278,16.5999755859375,16.59995237986247,16.590060075124104,16.54227288564046,16.514484405517578,16.49068291982015,16.458677450815838,16.42168601353963,16.415090084075928,16.361384391784668,16.34028704961141,16.327280203501385,16.306567827860516,16.297694365183514,16.274217287699383,16.217710336049397,16.17810869216919,16.133007367451984,16.083006381988525,16.028905550638836,15.971004883448282,15.910004456837973,15.846204121907553,15.779903570810953,15.711603085199991,15.641402880350748,15.569702386856079,15.496702194213867,15.422501802444458,15.3474014600118,15.271401405334473,15.194801330566406,15.117601156234741,15.040000995000204,14.962000687917074,14.883700847625732,14.80530071258545,14.726700703303019,14.648000399271647,14.569300333658854,14.490600347518921,14.411900281906128,14.333400328954061,14.254900296529135,14.176600217819214,14.098400274912516,14.020500183105469,13.942700147628784,13.865200201670328,13.787800073623657,13.710800170898438,13.633900006612143,13.557400147120157,13.481100082397461,13.405100107192993,13.329299926757812,13.2538001537323,13.178700049718222,13.103800058364868,13.029200077056885,12.95490018526713,12.88100004196167,12.807300090789795,12.73389999071757,12.660900115966797,12.58810011545817,12.515600124994913,12.44349996248881,12.371700048446655,12.300100008646647,12.22890011469523,12.157999992370605,12.08740003903707,12.017100016276041,11.947200059890747,11.877499977747599,11.80809998512268,11.739099899927774,11.670300006866455,11.601900100708008,11.533799966176352,11.46590002377828,11.398400068283081,11.331199963887533,11.264300028483072,11.197699944178263,11.13129997253418,11.065300067265829,10.999599933624268,10.934199968973795,10.869100014368692,10.80430006980896,10.739800055821737,10.675599972407023,10.611599842707315,10.54800001780192,10.484700043996176,10.421599944432577,10.35890007019043,10.29640007019043,10.23419984181722,10.172300020853678,10.110799868901571,10.049500147501627,9.988450050354004,9.927730083465576,9.867299874623617,9.807170073191324,9.747330029805502,9.687780062357584,9.628519852956137,9.569550037384033,9.51087999343872,9.452509959538778,9.394420146942139,9.33663010597229,9.279129902521769,9.221930027008057,9.165020068486532,9.108400106430054,9.052070140838623,8.996039946873983,8.940299908320108,8.884850104649862,8.829689979553223,8.774829943974813,8.720249970753988,8.665969928105673,8.611969947814941,8.55826989809672,8.504850228627523,8.451719999313354,8.398890018463135,8.346330006917318,8.29406992594401,8.242089986801147,8.19038995107015,8.138980070749918,8.087860027949015,8.037009954452515,7.986450115839641,7.936170021692912,7.886169950167338,7.836460034052531,7.787019968032837,7.737860043843587,7.688970009485881,7.640370051066081,7.5920400222142534,7.543980002403259,7.49620000521342,7.448690017064412,7.401449958483378,7.354489962259929,7.3077900012334185,7.261369943618774,7.21520992120107,7.169319987297058,7.123699943224589,7.07833997408549,7.033250013987224,6.988419969876607,6.943849960962932,6.899539987246196,6.855499943097432,6.811710000038147,6.768180052439372,6.724910060564677,6.681899984677632,6.6391399304072065,6.596629977226257,6.5543800592422485,6.512380003929138,6.470630009969075,6.429129997889201,6.387880007425944,6.3468799988428755,6.306120038032532,6.2656099398930865,6.225340008735657,6.185320019721985,6.145539959271749,6.105990052223206,6.066689968109131,6.027630011240642,5.988809943199158,5.950219949086507,5.911870002746582,5.8737499713897705,5.835869948069255,5.798210024833679,5.76078999042511,5.723599990208943,5.6866399844487505,5.649910012880961,5.613400022188823,5.577119946479797,5.541060050328572,5.505220095316569,5.4696100155512495,5.43422003587087,5.399049957593282,5.364100019137065,5.329360008239746,5.29485007127126,5.260539968808492,5.226449966430664,5.1925801038742065,5.158920009930928,5.125470042228699,5.092230041821797,5.059190034866333,5.02636996905009,4.993750015894572,4.961340030034383,4.929129958152771,4.897129972775777,4.86532998085022,4.8337299426396685,4.802330056826274,4.771130005518596,4.740119973818461,4.709320028622945,4.678709983825684,4.648290038108826,4.618070085843404,4.588039954503377,4.558209975560506,4.528560042381287,4.499110062917073,4.469840010007222,4.440760016441345,4.41186002890269,4.383150100708008,4.354630033175151,4.326289971669515,4.298129955927531,4.2701499462127686,4.24235999584198,4.214740037918091,4.187299927075704,4.160039981206258,4.132949988047282,4.106039961179097,4.079300006230672,4.052740057309468,4.026350061098735,4.0001200040181475,3.9740699927012124,3.948189993699392,3.9224800268809,3.896939992904663,3.871559997399648,3.8463499943415322,3.821299970149994,3.7964199781417847,3.7717000246047974,3.7471399704615274,3.7227500279744468,3.698510011037191,3.674430012702942,3.65050999323527,3.6267399986584983,3.6031299829483032,3.579670011997223,3.556369960308075,3.5332199732462564,3.5102199713389077,3.4873699943224588,3.464670022328695,3.442109982172648,3.419710020224253,3.397450029850006,3.3753300110499063,3.3533599972724915,3.3315399885177612,3.309849997361501,3.2883099714914956,3.2668999830881753,3.24563999970754,3.2245100339253745,3.203530013561249,3.182679990927378,3.161960005760193,3.14137997229894,3.120930016040802,3.1006200512250266,3.0804399847984314,3.0603900154431662,3.040470004081726,3.020680010318756,3.001019994417826,2.9814900159835815,2.962090015411377,2.9428100188573203,2.9236600200335183,2.9046299854914346,2.8857200145721436,2.866939961910248,2.8482800324757895,2.8297500014305115,2.811330040295919,2.7930299838383994,2.7748600244522095,2.7567999958992004,2.738860011100769,2.721029977003733,2.70332000652949,2.685730000336965,2.668250024318695,2.6508900125821433,2.633640011151632,2.6165000001589456,2.5994699994723,2.5825499892234802,2.565750022729238,2.549049993356069,2.5324599941571555,2.515979985396067,2.4996100068092346,2.483340005079905,2.4671799739201865,2.451129992802938,2.4351799885431924,2.4193299810091653,2.4035900235176086,2.3879499236742654,2.37241001923879,2.3569699923197427,2.3416300217310586,2.326389968395233,2.311260004838308,2.296219984690348,2.281269987424215,2.2664300203323364,2.251679996649424,2.237029949824015,2.222479999065399,2.208009978135427,2.1936499873797097,2.1793700059254966,2.165190021197001,2.151110033194224,2.1371099948883057,2.123200019200643,2.1093900005022683,2.09566996494929,2.0820299983024597,2.0684799949328103,2.0550299684206643,2.0416599909464517,2.0283700029055276,2.015179991722107,2.0020600060621896,1.9890399972597759,1.9760999977588654,1.963239997625351,1.950470010439555,1.9377799828847249,1.9251700043678284,1.9126499990622203,1.9002100030581157,1.887850006421407,1.8755600055058796,1.8633599877357483,1.8512399991353352,1.839199999968211,1.8272299865881603,1.8153500060240428,1.8035399913787842,1.791810005903244,1.7801499962806702,1.7685699760913849,1.757069985071818,1.7456399897734325,1.7342800100644429,1.7229999899864197,1.7117999990781148,1.700659990310669,1.689600000778834,1.6786100069681804,1.6676899989446003,1.6568499902884166,1.646069993575414,1.6353600025177002,1.624730000893275,1.614159991343816,1.603659987449646,1.5932299892107646,1.5828700164953868,1.5725799997647603,1.5623500049114227,1.5521899958451588,1.5420999924341838,1.5320699910322826,1.522099991639455,1.5122100015481312,1.502369999885559,1.4926000038782756,1.4829000035921733,1.4732500116030376,1.4636699954668682,1.4541600048542023,1.4446999927361805,1.4353100061416626,1.4259700079758961,1.4166999856630962,1.4074899951616924,1.3983399868011475,1.389249990383784,1.3802099923292797,1.3712400098641713,1.3623299996058147,1.353469987710317,1.3446699976921082,1.3359299898147583,1.3272400101025899,1.318610002597173,1.310040016969045,1.3015199899673462,1.2930599947770436,1.2846599916617076,1.2763000130653381,1.2680100003878276,1.259770005941391,1.2515799899895985,1.2434400022029877,1.2353599866231282,1.2273299992084503,1.219350000222524,1.2114199995994568,1.203549991051356,1.1957300305366516,1.1879600087801616,1.1802299916744232,1.1725599964459736,1.1649399995803833,1.157370001077652,1.1498499910036724,1.1423800090948741,1.1349499821662903,1.1275800168514252,1.1202500065167744,1.1129700044790904,1.1057300170262654,1.0985500117142994,1.0914099911848705,1.0843199988206227,1.0772699912389119,1.0702699919541676,1.06332000096639,1.0564099848270416,1.0495400031407673,1.0427199800809224,1.0359499951203663,1.0292199949423473,1.0225299994150798,1.0158900022506714,1.0092800060908,1.0027300119400024,0.9962130039930344,0.9897400041421255,0.9833099991083145,0.9769219954808553,0.9705750048160553,0.9642699956893921,0.9580060044924418,0.9517820030450821,0.9455989996592203,0.9394570092360178,0.9333540052175522,0.9272910008827845,0.9212680011987686,0.9152829945087433,0.9093379974365234,0.9034319967031479,0.8975630054871241,0.8917339990536371,0.8859419922033945,0.8801869998375574,0.8744710038105646,0.868790994087855,0.8631489972273508,0.8575429966052374,0.8519739955663681,0.8464410056670507,0.8409440020720164,0.8354829996824265,0.8300570001204809,0.8246669967969259,0.8193110078573227,0.813991000254949,0.8087049971024195,0.8034540067116419,0.7982370009024938,0.79305399954319,0.7879039992888769,0.782789001862208,0.7802390058835348};
        CFC115={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00014331860863118587,0.003477728799528753,0.019166271900758147,0.039499382954090834,0.06371349437783162,0.09872918141384919,0.143262746433417,0.2035404990116755,0.27441523348291713,0.34821991870800656,0.43801355610291165,0.5431961392362913,0.661696677406629,0.8118081788221995,0.9836416741212209,1.1736451586087544,1.3782646457354228,1.5939541260401409,1.8424933552742004,2.144632577896118,2.4999918937683105,2.8499913215637207,3.187290926774343,3.6499905784924827,4.105550249417623,4.49442990620931,4.9499895970026655,5.40554936726888,5.799989104270935,6.199989080429077,6.607129295667012,6.955350279808044,7.249991933504741,7.557493487993876,7.813324570655823,7.95416518052419,8.04999581972758,8.149996836980185,8.262498617172241,8.29999844233195,8.320768594741821,8.341978788375854,8.346869071324667,8.368909200032553,8.360188722610474,8.382678429285685,8.389018853505453,8.386359055836996,8.387009064356485,8.405529419581095,8.421289602915445,8.429009358088175,8.460016886393229,8.488823413848877,8.531164328257242,8.575854221979776,8.618204116821289,8.65830397605896,8.696233908335367,8.732083717981974,8.765923500061035,8.797823429107666,8.827853202819824,8.856093088785807,8.882613182067871,8.90746291478475,8.930702765782675,8.952402591705322,8.972622712453207,8.991402546564737,9.008822361628214,9.02490234375,9.03970217704773,9.053272167841593,9.065662066141764,9.076922098795572,9.087071816126505,9.096181790033976,9.10427188873291,9.111371676127115,9.117531617482504,9.122791608174643,9.127171595891317,9.130701382954916,9.13344152768453,9.135391314824423,9.13659143447876,9.137071291605631,9.136861165364584,9.135981241861979,9.134461164474487,9.132320960362753,9.129591226577759,9.126270850499472,9.122411012649536,9.118010997772217,9.113110939661661,9.107710917790731,9.10184089342753,9.095520893732706,9.08876077334086,9.081580638885498,9.073990742365519,9.06601063410441,9.057660659154257,9.048960447311401,9.03990070025126,9.030520677566528,9.020810524622599,9.01080052057902,9.00049058596293,8.989900588989258,8.97903060913086,8.967900594075521,8.956520398457846,8.94489041964213,8.933030287424723,8.920940478642782,8.908650477727255,8.896140257517496,8.883440256118774,8.870550314585367,8.857470512390137,8.844220399856567,8.830800294876099,8.81721027692159,8.803470452626547,8.789580345153809,8.775550365447998,8.761380354563395,8.747090339660645,8.732670227686564,8.718130270640055,8.703460137049357,8.688690106074015,8.673810164133707,8.658830165863037,8.643750031789144,8.627260049184164,8.609399954477945,8.591559966405233,8.573729991912842,8.555920044581095,8.538129965464273,8.520359992980957,8.502600193023682,8.484869956970215,8.46715005238851,8.449450016021729,8.431770165761312,8.414109945297241,8.396459976832071,8.37883989016215,8.361239830652872,8.34365995724996,8.326099952061972,8.308560053507486,8.291040023167929,8.273550033569336,8.256070057551065,8.238619963328043,8.221189975738525,8.203789949417114,8.186400016148886,8.169039805730185,8.151710033416748,8.134389956792196,8.11709992090861,8.09984008471171,8.082599957784018,8.065380096435547,8.048189957936605,8.031020005544027,8.013880014419556,7.996759970982869,7.97966996828715,7.962599953015645,7.945559978485107,7.928540070851644,7.911550045013428,7.8945900201797485,7.877650022506714,7.860740025838216,7.843850016593933,7.826990048090617,7.810160001118978,7.793359994888306,7.776579976081848,7.759829958279927,7.743099967638652,7.726400017738342,7.70973002910614,7.693090001742045,7.6764800151189165,7.659890015920003,7.643330017725627,7.626799980799357,7.610300064086914,7.5938200155893965,7.577370047569275,7.560950001080831,7.544560035069783,7.528199990590413,7.5118699471155805,7.495560050010681,7.4792799949646,7.463030020395915,7.4468099276224775,7.430620034535726,7.4144599835077925,7.398329933484395,7.382220029830933,7.3661500215530396,7.350100000699361,7.334090034166972,7.318099935849507,7.3021399974823,7.286210020383199,7.270309964815776,7.254440069198608,7.238599975903829,7.222789963086446,7.20700991153717,7.191260019938151,7.175540010134379,7.159850041071574,7.144179979960124,7.128549973169963,7.1129500071207685,7.097379962603251,7.081829984982808,7.066319982210795,7.0508400201797485,7.035380005836487,7.019960006078084,7.004570086797078,6.989200035730998,6.973869959513347,6.958570043245952,6.943299969037374,6.9280500411987305,6.912839929262797,6.897660096486409,6.8825100262959795,6.867389996846517,6.852300047874451,6.837240020434062,6.822210033734639,6.807210048039754,6.792239983876546,6.777300000190735,6.762390057245891,6.747510035832723,6.732660015424092,6.717840035756429,6.703060030937195,6.688299973805745,6.673569957415263,6.658879995346069,6.644210020701091,6.629579981168111,6.614969968795776,6.600399931271871,6.585850079854329,6.571340004603068,6.556859970092773,6.542399962743123,6.527980009714763,6.5135899384816485,6.4992300271987915,6.4848999579747515,6.470599929491679,6.456329941749573,6.442090034484863,6.427879969278972,6.413699984550476,6.399550000826518,6.385430018107097,6.371349930763245,6.357289989789327,6.343259970347087,6.329270005226135,6.315299987792969,6.301360011100769,6.287459969520569,6.273579994837443,6.259739955266316,6.245929996172587,6.232139945030212,6.218390027681987,6.204660018285115,6.1909700234731035,6.177310029665629,6.1636799573898315,6.15008004506429,6.136509935061137,6.12296998500824,6.109460075696309,6.095980008443196,6.08252998193105,6.069109996159871,6.055719931920369,6.042360027631124,6.029030044873555,6.015730023384094,6.00246000289917,5.98920996983846,5.976000070571899,5.962820053100586,5.949659983317058,5.936540007591248,5.923439979553223,5.910380005836487,5.8973400592803955,5.884329994519551,5.871350010236104,5.858399987220764,5.845470031102498,5.832580010096232,5.81970997651418,5.806879917780559,5.794069925944011,5.781290014584859,5.768539945284526,5.755809982617696,5.743120034535726,5.73044999440511,5.717810074488322,5.705199956893921,5.692610025405884,5.680059989293416,5.667529980341594,5.655030012130737,5.642549991607666,5.630110025405884,5.617690046628316,5.6053000291188555,5.59293003877004,5.5806000630060835,5.568290074666341,5.556009968121846,5.543749968210856,5.531529903411865,5.519330024719238,5.507150053977966,5.495009978612264,5.4828899304072065,5.470789988835652,5.4587299426396685,5.446689923604329,5.434670011202495,5.4226899941762285,5.4107299248377485,5.398790001869202,5.3868900537490845,5.375010013580322,5.363149960835774,5.351319988568624,5.33952001730601,5.327739993731181,5.315990050633748,5.304269989331563,5.292569994926453,5.280899961789449,5.26925003528595,5.257629990577698,5.2460399468739825,5.234470049540202,5.222920020421346,5.211410005887349,5.199909965197246,5.18845001856486,5.176999966303508,5.165589928627014,5.154190023740132,5.142830053965251,5.1314899524052935,5.120169997215271,5.108879963556926,5.097609996795654,5.08637003103892,5.075160066286723,5.063959956169128,5.052799940109253,5.041659990946452,5.030540029207866,5.019439935684204,5.008379936218262,4.997329990069072,4.986309965451558,4.975319981575012,4.9643499453862505,4.9533999760945635,4.942480007807414,4.931580026944478,4.92071004708608,4.909860094388326,4.8990300099054975,4.888230045636495,4.877450108528137,4.8666999737421675,4.85597010453542,4.84525998433431,4.834580024083455,4.823920051256816,4.813280026117961,4.802670001983643,4.792080005009969,4.7815200090408325,4.7709700266520185,4.760449965794881,4.7499600648880005,4.7394899527231855,4.729040066401164,4.718610008557637,4.708209991455078,4.697829961776733,4.687470038731893,4.67714003721873,4.666830023129781,4.656539956728618,4.64628005027771,4.636029918988545,4.625809987386067,4.615619977315267,4.605440020561218,4.595289985338847,4.58516001701355,4.575050036112468,4.564970056215922,4.554909944534302,4.544870018959045,4.534850001335144,4.524850010871887,4.514879941940308,4.504930019378662,4.495000004768372,4.485089977582295,4.475200057029724,4.46533997853597,4.45550000667572,4.445679982503255,4.435880025227864,4.426099975903829,4.41635004679362,4.406620065371196,4.396909991900126,4.387210011482239,4.377550045649211,4.367899974187215,4.358270088831584,4.34866992632548,4.339079976081848,4.329520026842753,4.3199799458185835,4.3104599714279175,4.300960024197896,4.291489998499553,4.282029986381531,4.2725900411605835,4.263179977734883,4.253780007362366,4.244409958521525,4.235060056050618,4.225730021794637,4.216419974962871,4.207129955291748,4.1978600025177,4.188610037167867,4.179380019505818,4.170170029004415,4.160980025927226,4.151809970537822,4.1426699956258135,4.133539954821269,4.124429980913798,4.115350008010864,4.106280008951823,4.097229957580566,4.088210105895996,4.0791999499003095,4.070219993591309,4.061250011126201,4.052300016085307,4.04337998231252,4.034469922383626,4.025579929351807,4.016709923744202,4.007869998613994,3.9990400671958923,3.9902299841245017,3.981440007686615,3.972670018672943,3.963920017083486,3.9551899830500283,3.9464800159136453,3.9377899765968323,3.9291100104649863,3.9204599857330322,3.911829968293508,3.903210004170736,3.8946100076039634,3.8860400120417276,3.8774799903233848,3.868940015633901,3.860419968763987,3.851920008659363,3.8434300223986306,3.834969997406006,3.8265299598375955,3.8180999755859375,3.809690018494924,3.80130002895991,3.792930006980896,3.7845799922943115,3.7762499849001565,3.767930010954539,3.7596399982770285,3.751359979311625,3.7431000471115112,3.7348600228627524,3.726629992326101,3.718429962793986,3.7102399865786233,3.702069958051046,3.6939199964205423,3.685790002346039,3.677680015563965,3.669580022493998,3.661500016848246,3.653439998626709,3.6453999876976013,3.637370010217031,3.629360020160675,3.621380011240641,3.6134000420570374,3.6054499745368958,3.601480007171631};
        CFC12={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.019433656940236688,0.4215002196530501,1.6357106665770214,2.835014005502065,4.025014281272888,5.215012947718303,6.382257183392842,7.775353193283081,9.444400389989218,11.213325262069702,13.203928073247274,15.439632256825766,18.00713857014974,20.977540334065754,24.184339841206867,27.60905106862386,31.60536019007365,36.23666445414225,41.47677803039551,47.60459232330322,54.79980500539144,63.0290142695109,72.2479305267334,82.6101468404134,94.25966453552246,107.28918075561523,121.64918899536133,137.13820521036783,153.8562266031901,172.25726318359375,192.56424713134766,213.23522440592447,232.99722162882486,251.99420674641928,270.00118255615234,286.4941584269206,302.1822509765625,319.4201304117839,335.1432698567708,352.50609588623047,366.79923248291016,383.26725006103516,402.41221872965497,423.347417195638,449.32311248779297,468.0721740722656,482.7560577392578,493.7842102050781,505.86798095703125,511.9880956013997,518.2140757242838,524.6570994059244,531.4079996744791,534.9630432128906,537.6670277913412,540.1430358886719,542.3829905192057,543.1950124104818,543.6559855143229,543.3510030110677,542.8480021158854,542.1459757486979,540.6499633789062,538.4259847005209,536.3339691162109,533.7759806315104,531.2819671630859,528.532969156901,525.833974202474,523.1149698893229,520.5809682210287,518.0192006429037,514.5848337809244,508.82093811035156,504.26490783691406,499.65891520182294,495.01991017659503,490.3589045206706,485.68591054280597,481.0109151204427,476.3409144083659,471.680908203125,467.0369135538737,462.4119110107422,457.81091054280597,453.2349141438802,448.6879196166992,444.16991424560547,439.6839116414388,435.22991434733075,430.80891672770184,426.4229202270508,422.07191975911456,417.7559229532878,413.47491963704425,409.22991943359375,405.0219243367513,400.8489176432292,396.71192677815753,392.6109263102214,388.5459264119466,384.5159225463867,380.5229263305664,376.5639241536458,372.6419270833333,368.75392659505206,364.9009272257487,361.08292897542316,357.29892985026044,353.5499318440755,349.8339309692383,346.1529286702474,342.5039291381836,338.88893127441406,335.3069305419922,331.7579345703125,328.2409311930339,324.7569351196289,321.304931640625,317.8839365641276,314.4949417114258,311.1369400024414,307.80993906656903,304.5139389038086,301.24893951416016,298.0139389038086,294.8089370727539,291.63294728597003,288.4879379272461,285.3719431559245,282.2849400838216,279.22694142659503,276.1969451904297,273.1969451904297,270.2239405314128,267.2799428304036,264.3629455566406,261.4739456176758,258.61194610595703,255.77794901529947,252.96994654337564,250.18894704182944,247.4349479675293,244.70694732666016,242.00494893391928,239.32895151774088,236.67895126342773,234.0539525349935,231.45495223999023,228.88095219930014,226.33095169067383,223.8059514363607,221.30595270792642,218.8299560546875,216.37795384724936,213.94995625813803,211.54595565795898,209.16495641072592,206.80795669555664,204.47495778401694,202.16395823160806,199.87595748901367,197.60995737711588,195.36696116129556,193.1469586690267,190.9489606221517,188.7729581197103,186.61896133422852,184.48596064249674,182.37596003214517,180.2869618733724,178.21896362304688,176.17296091715494,174.14696248372397,172.14296213785806,170.15996424357095,168.19696299235025,166.25496419270834,164.3329645792643,162.43096542358398,160.5489641825358,158.6869659423828,156.84496434529623,155.02296574910483,153.21996434529623,151.43596649169922,149.67096837361655,147.92496871948242,146.19796752929688,144.4899673461914,142.79996744791666,141.1279665629069,139.47497177124023,137.83897145589194,136.22197087605795,134.62196985880533,133.03897094726562,131.47397232055664,129.92597325642905,128.39496930440268,126.88097254435222,125.38397153218587,123.90297317504883,122.43897310892741,120.99097379048665,119.55897394816081,118.14297294616699,116.74297459920247,115.35797500610352,113.9889742533366,112.6359748840332,111.29797554016113,109.97397549947102,108.66597429911296,107.37197748819987,106.09297561645508,104.82897567749023,103.57897694905598,102.34297752380371,101.12097676595052,99.91307703653972,98.71887715657552,97.53827794392903,96.37127876281738,95.21757888793945,94.07717895507812,92.94977887471516,91.83537928263347,90.73377990722656,89.64497884114583,88.56857999165852,87.5046812693278,86.45308113098145,85.41368103027344,84.3862813313802,83.37078094482422,82.36718050638835,81.37518056233723,80.39468193054199,79.4255822499593,78.46788152058919,77.5212828318278,76.58578300476074,75.66128158569336,74.74748357137044,73.84448305765788,72.9519837697347,72.07008361816406,71.19848442077637,70.33708318074544,69.48588562011719,68.64478365580241,67.81348419189453,66.99208450317383,66.18028450012207,65.3781852722168,64.58548482259114,63.80228487650553,63.02828598022461,62.2634859085083,61.50778611501058,60.760985692342125,60.02318572998047,59.29408645629883,58.573686599731445,57.861887296040855,57.15848731994629,56.46358744303385,55.776987393697105,55.09848817189535,54.42818737030029,53.76588789621989,53.11158720652262,52.46498807271322,51.8262882232666,51.195188204447426,50.57158883412679,49.95558834075928,49.34688822428385,48.74558893839518,48.15148893992106,47.564589500427246,46.98478921254476,46.41189002990723,45.845889727274574,45.28678957621256,44.734389305114746,44.188689867655434,43.649590492248535,43.11708958943685,42.5908899307251,42.07119051615397,41.55769062042236,41.050390561421715,40.54929065704346,40.054291089375816,39.565290451049805,39.082191467285156,38.60499127705892,38.13359133402506,37.66789150238037,37.2078914642334,36.753491719563804,36.30459181467692,35.861191749572754,35.42319202423096,34.99059200286865,34.56319204966227,34.140992164611816,33.723992665608726,33.312092781066895,32.90529251098633,32.5033925374349,32.10649220148722,31.71439282099406,31.32709280649821,30.94459279378255,30.5666929880778,30.193492889404297,29.824793338775635,29.460593223571777,29.10089349746704,28.745593229929607,28.394593556722004,28.047993501027424,27.705493450164795,27.36729367574056,27.033193747202557,26.703193823496502,26.377193609873455,26.05509392420451,25.737094084421795,25.4228941599528,25.112494150797527,24.805994351704914,24.50309419631958,24.203994433085125,23.908594449361164,23.616694768269856,23.328394571940105,23.043594519297283,22.762394587198894,22.48449484507243,22.209994633992512,21.938895225524902,21.671095371246338,21.4065949122111,21.14529514312744,20.887195428212483,20.632195313771565,20.380395253499348,20.131595452626545,19.885895252227783,19.643195788065594,19.403395493825276,19.166595617930096,18.93259557088216,18.70149580637614,18.47329568862915,18.247795899709065,18.02509609858195,17.805095831553142,17.587695916493733,17.373095989227295,17.160995960235596,16.95159610112508,16.744695981343586,16.54029639561971,16.338396231333416,16.1389962832133,15.941996415456137,15.747396310170492,15.555296341578165,15.36539657910665,15.177896658579508,14.992596626281738,14.809596618016561,14.628896554311117,14.450396617253622,14.273996750513712,14.099796930948893,13.927696625391642,13.757696866989136,13.589796861012777,13.423996925354004,13.260196924209595,13.098296960194906,12.938497066497803,12.780597050984701,12.624597152074179,12.47059710820516,12.318397363026937,12.167997201283773,12.019597133000692,11.872897227605185,11.727997382481893,11.58489727973938,11.4434974193573,11.303897301355997,11.165897607803345,11.02969733874003,10.895097494125366,10.762097517649332,10.630797624588013,10.501097440719604,10.372897624969482,10.246397654215494,10.121397654215494,9.99784771601359,9.875857830047607,9.75535774230957,9.636327902475992,9.518747727076212,9.402607917785645,9.287887891133627,9.174567937850952,9.062627871831259,8.95205807685852,8.842837889989218,8.734947999318441,8.62837807337443,8.523108005523682,8.419128179550171,8.316418091456095,8.214958111445108,8.11473806699117,8.015738089879354,7.917948126792908,7.8213582038879395,7.725938240687053,7.631688237190247,7.538588245709737,7.446628292401631,7.3557883103688555,7.2660584052403765,7.177428364753723,7.08987828095754,7.003388325373332,6.917958378791809,6.833578427632649,6.750228444735209,6.667888442675273,6.58655846118927,6.506218512852986,6.42685854434967,6.348478515942891,6.271048545837402,6.194558580716451,6.119008620580037,6.044378678003947,5.970658659934998,5.897838632265727,5.825908740361531,5.754858652750651,5.6846786340077715,5.615348696708679,5.546868681907654,5.479228734970093,5.412408749262492,5.346398790677388,5.281208753585815,5.216808795928955,5.1531888246536255,5.090348879496257,5.0282788674036665,4.966968854268392,4.906398852666219,4.84657895565033,4.787478923797607,4.729108929634094,4.671448906262715,4.614488999048869,4.558228969573975,4.502648989359538,4.447758952776591,4.393529017766316,4.3399589856465655,4.287049015363057,4.23478905359904,4.183158993721008,4.132159034411113,4.081789096196492,4.0320290724436445,3.982879082361857,3.934319098790487,3.886359135309855,3.8389891187349954,3.792189101378123,3.7459691762924194,3.700309137503306,3.65519917011261,3.6106491684913635,3.5666391849517822,3.5231691797574363,3.4802291989326477,3.4378092288970947,3.3959091703097024,3.354519267876943,3.3136292099952698,3.2732492486635842,3.2333592971165976,3.193949262301127,3.1550292571385703,3.116579254468282,3.0785993138949075,3.041079302628835,3.004019320011139,2.9674193461736045,2.9312593142191568,2.895539343357086,2.8602593739827475,2.8253993590672812,2.790979345639547,2.756969372431437,2.72337943315506,2.6901893814404807,2.6574193636576333,2.6250394185384116,2.5930593808492026,2.5614594221115112,2.5302594105402627,2.499429404735565,2.46897945801417,2.4388994574546814,2.409189462661743,2.3798394401868186,2.350849449634552,2.3222094575564065,2.293929477532705,2.265979508558909,2.238379498322805,2.211119532585144,2.1841795444488525,2.157579481601715,2.1312995155652366,2.105339527130127,2.0796994964281716,2.054369548956553,2.0293495257695517,2.004629542430242,1.980219542980194,1.956099549929301,1.9322795569896698,1.908739556868871,1.8854995568593342,1.8625395894050598,1.8398595650990803,1.8174495995044708,1.7953195869922638,1.7734596033891041,1.7518595953782399,1.7305295964082081,1.7094596425692241,1.6886496047178905,1.6680895785490673,1.6477798720200856,1.6376798053582509};
    //CH2Cl2={6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761330604553,6.912761290868123,6.912761330604553,6.912761251131694,6.912761251131694,6.912761290868123,6.912761211395264,6.912761290868123,6.912761211395264,6.912761370340983,6.912761012713115,6.912761847178142,6.912759939829509,6.912764271100362,6.912754416465759,6.9127769867579145,6.912726124127706,6.923158605893453,6.954429507255554,7.005844831466675,7.076577345530192,7.165842294692993,7.272848884264628,7.396803259849548,7.536917527516683,7.692389249801636,7.862438440322876,8.046262820561727,8.243067026138306,8.459376494089762,8.70284390449524,8.96372620264689,9.237827936808268,9.522201458613077,9.81755797068278,10.130433241526285,10.45914602279663,10.799525419871012,11.156874577204386,11.525057315826416,11.901808897654215,12.2854323387146,12.677054643630981,13.071166276931763,13.466866890589396,13.861979166666666,14.255303064982096,14.645936171213785,15.03268305460612,15.414538780848185,15.7905060450236,16.15948486328125,16.520374298095703,16.872174660364788,17.213786443074543,17.544209003448486,17.862243175506592,18.167085647583008,18.457443396250408,18.73240868250529,18.990788459777832,19.231674830118816,19.453975836435955,19.656585216522217,19.838414351145428,19.998409748077393,20.15157461166382,20.30894422531128,20.463133494059246,20.60627841949463,20.73100932439168,20.829659938812256,20.894384066263836,20.919768969217937,20.359298547108967,20.441278139750164,20.034658590952557,19.541579405466717,21.384501139322918,21.95576238632202,21.63081630071004,22.703665733337402,22.91611115137736,24.113162358601887,26.412729263305664,26.18838119506836,29.346547921498615,29.494615077972412,29.299615383148193,35.0478843053182,36.347557067871094,37.88396962483724,40.042534828186035,40.477243741353355,36.82063706715902,37.68098386128744,38.58034165700277,39.47893524169922,39.752062479654946,39.328728675842285,38.844716707865395,38.35651779174805,37.86792818705241,37.37916787465414,36.89059607187907,36.40164025624593,35.91345421473185,35.423667907714844,35.111459732055664,34.996373335520424,34.898529370625816,34.801768938700356,34.70519161224365,34.60866641998291,34.51211595535278,34.41540733973185,34.31915680567423,34.221959908803306,34.22516361872355,34.33964093526205,34.46386750539144,34.588716983795166,34.71363162994385,34.83862860997518,34.963621616363525,35.08855024973551,35.21346855163574,35.33859586715698,35.423354625701904,35.46326605478922,35.49909702936808,35.53482834498087,35.57041645050049,35.60611836115519,35.64172522226969,35.677303632100426,35.712973276774086,35.748443285624184,35.828499952952065,35.95804182688395,36.09203783671061,36.226287841796875,36.36061159769694,36.494899113972984,36.62920951843262,36.76348718007406,36.8978640238444,37.031776110331215,37.22856648763021,37.49485683441162,37.7675142288208,38.04042116800944,38.31347242991129,38.58634503682455,38.85935910542806,39.13234774271647,39.40537071228027,39.67828369140625,39.972168604532875,40.28940010070801,40.60866038004557,40.92801888783773,41.24744415283203,41.56692663828532,41.88634045918783,42.205729484558105,42.52514807383219,42.84447002410889,43.18513456980387,43.54927635192871,43.91563288370768,44.281989097595215,44.64851919809977,45.014899253845215,45.381409645080566,45.74781862894694,46.11373519897461,46.48163350423177,46.56477578481039,46.330323219299316,46.06859302520752,45.80491256713867,45.54101308186849,45.27701314290365,45.01311206817627,44.749213536580406,44.48521296183268,44.22131093343099,43.95741367340088,43.6934118270874,43.42951361338297,43.165513356526695,42.901611328125,42.63771375020345,42.37371349334717,42.10981146494547,41.84591420491537,41.58191331227621,41.31801160176595,41.054113705952965,40.79011313120524,40.526211738586426,40.26231447855631,39.99831295013428,39.73441378275553,39.470413525899254,39.206512133280434,38.942614237467446,38.6786142985026,38.41471195220947,38.150814056396484,37.88681411743164,37.62291304270426,37.35901387532552,37.09501425425211,36.831112225850426,36.56721464792887,36.30321375528971,36.03931395212809,35.77531464894613,35.51141246159872,35.247514724731445,34.98351494471232,34.71961307525635,34.45571438471476,34.1917150815328,33.9278130531311,33.663914362589516,33.39991442362467,33.136013984680176,32.87201468149821,32.608113288879395,32.34421475728353,32.08021481831869,31.81631342569987,31.552415370941162,31.28841511408488,31.024513721466064,30.76061487197876,30.496615727742512,30.232713222503662,29.968815326690674,29.70481522878011,29.440914630889893,29.176916122436523,28.913013617197674,28.649115403493244,28.38511578241984,28.121214071909588,27.85731569925944,27.593315919240315,27.329413890838623,27.065515836079914,26.80151605606079,26.537614186604817,26.27371597290039,26.009716033935547,25.74581480026245,25.481817086537678,25.21791410446167,24.95401620864868,24.690016110738117,24.426113923390705,24.162216027577717,23.898216883341473,23.63431437810262,23.370416164398193,23.10641638437907,22.842514991760254,22.57851775487264,22.314613819122314,22.050716876983643,21.78671646118164,21.522814909617107,21.258916695912678,20.994917233784992,20.7310152053833,20.467116355895996,20.203117211659748,19.93921438852946,19.675318082173664,19.411315441131592,19.147417068481445,18.8834171295166,18.619515260060627,18.3556170463562,18.091617107391357,17.827715317408245,17.563817421595257,17.299817164738972,17.03591561317444,16.77201755841573,16.508017381032307,16.244115352630615,15.980218331019083,15.71621592839559,15.452317714691162,15.18831753730774,14.924415826797485,14.660517772038778,14.396517594655355,14.13261596361796,13.868717829386393,13.60471773147583,13.340815941492716,13.076918284098307,12.812917073567709,12.549017906188965,12.285017967224121,12.021116256713867,11.757217963536581,11.493218104044596,11.229316393534342,10.965418259302774,10.701418161392212,10.437516927719116,10.173618078231812,9.909648180007935,9.645708004633585,9.381767511367798,9.117838621139526,8.853896737098694,8.589971423149109,8.326019048690796,8.062112013498941,7.798093159993489,7.534396529197693,7.269795894622803,7.124750256538391,7.112112124760945,7.111345489819844,7.111173788706462,7.111208995183309,7.111194849014282,7.11120065053304,7.11119822661082,7.1111992200215655,7.1111988226572675,7.1111990213394165,7.1111988226572675,7.111198941866557,7.111198902130127,7.111198941866557,7.111198862393697,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111198902130127,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897,7.111196200052897};
    CH3Br={5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997846285502,5.299997806549072,5.299997806549072,5.299997846285502,5.299997806549072,5.299997766812642,5.299997806549072,5.299997846285502,5.299997766812642,5.299997806549072,5.299997806549072,5.299997846285502,5.299997687339783,5.299997846285502,5.299997607866923,5.2999982436498,5.299996972084045,5.299998998641968,5.3066509167353315,5.338305354118347,5.379978577295939,5.419978777567546,5.459979295730591,5.4999799728393555,5.539980530738831,5.579981207847595,5.61998176574707,5.659982363382976,5.69998296101888,5.739983518918355,5.77998411655426,5.8199847141901655,5.85998531182607,5.899985949198405,5.93998658657074,5.979986985524495,6.019987901051839,6.059987783432007,6.099990487098694,6.139426151911418,6.184987505276998,6.22998833656311,6.274988849957784,6.319989720980327,6.364989757537842,6.409992456436157,6.4542984167734785,6.504989147186279,6.554991841316223,6.604418396949768,6.659987608591716,6.715564290682475,6.764422178268433,6.8193081219991045,6.879989941914876,6.939991156260173,6.999991575876872,7.059993505477905,7.119412302970886,7.184317310651143,7.255663514137268,7.319503704706828,7.389227231343587,7.465574224789937,7.534413854281108,7.609319130579631,7.689991553624471,7.769993821779887,7.849401632944743,7.934991518656413,8.019996364911398,8.103740215301514,8.199989477793375,8.294995307922363,8.389330943425497,8.48999317487081,8.589393774668375,8.694339831670126,8.804992516835531,8.91499400138855,9.027161439259848,9.131617546081543,9.13146940867106,9.06367564201355,9.140432437260946,9.254634141921997,9.093777736028036,8.829522927602133,8.354893207550049,8.333909193674723,8.222527821858725,8.019330620765686,7.931297580401103,7.679868618647258,7.651655554771423,7.470538298288981,7.171112656593323,7.125164190928142,7.106488426526387,6.98785674571991,6.848844488461812,6.6860902309417725,6.666919310887654,6.884193102518718,6.612607518831889,6.674074093500773,6.745414813359578,6.819554328918457,6.894375880559285,6.9219997723897295,6.889102458953857,6.83940311272939,6.784991939862569,6.729251305262248,6.673080285390218,6.6167298555374146,6.56026828289032,6.503699064254761,6.447014331817627,6.398238182067871,6.359598795572917,6.3236381610234575,6.288257638613383,6.252897183100383,6.217386643091838,6.181706428527832,6.145835479100545,6.109786033630371,6.0735528866449995,6.042359193166097,6.017689387003581,5.99475900332133,5.972218791643779,5.9496885140736895,5.927068114280701,5.904317895571391,5.881447434425354,5.858447710673015,5.835315545399983,5.815802852312724,5.800993005434672,5.787452737490336,5.774202664693196,5.760972420374553,5.747682293256124,5.734302123387654,5.720831831296285,5.707271893819173,5.693620761235555,5.681849400202434,5.672529339790344,5.663859248161316,5.655309160550435,5.646729032198588,5.638088941574097,5.629378795623779,5.620598673820496,5.61172874768575,5.60277791817983,5.595087091128032,5.589017033576965,5.583366950352986,5.577797015508016,5.572196841239929,5.56654687722524,5.560836672782898,5.555056691169739,5.549216349919637,5.543307344118754,5.535168608029683,5.524158438046773,5.512248277664185,5.499988118807475,5.48757799466451,5.475037892659505,5.46240774790446,5.4496976137161255,5.436897913614909,5.4240158796310425,5.415233294169108,5.411743243535359,5.40972359975179,5.408063332239787,5.406463543574016,5.4048335154851275,5.4031535387039185,5.401423454284668,5.399633606274922,5.397793531417847,5.395863652229309,5.393693844477336,5.391143957773845,5.388243993123372,5.385004083315532,5.3814741770426435,5.377694169680278,5.373684326807658,5.369474371274312,5.365094383557637,5.360564390818278,5.3559145132700605,5.3511544068654375,5.346284548441569,5.341344515482585,5.336334506670634,5.331264495849609,5.326154430707295,5.321004430452983,5.315824429194133,5.310624440511067,5.305414438247681,5.300204396247864,5.294984340667725,5.289764404296875,5.28456433614095,5.279364228248596,5.274194320042928,5.269034266471863,5.263904293378194,5.258794228235881,5.2537141640981035,5.248664180437724,5.243644118309021,5.238654096921285,5.233704129854838,5.228794137636821,5.22391406695048,5.219074010848999,5.214284022649129,5.209523955980937,5.204803903897603,5.200123866399129,5.195493896802266,5.190893888473511,5.186343749364217,5.181833783785502,5.177363753318787,5.17293377717336,5.168553630510966,5.16421365737915,5.159913579622905,5.155653635660808,5.151443600654602,5.1472634474436445,5.143133521080017,5.1390334367752075,5.134983420372009,5.13097341855367,5.126993378003438,5.123063325881958,5.119163274765015,5.1153033177057905,5.111483295758565,5.10770324865977,5.1039531628290815,5.100243171056111,5.0965730746587115,5.092933098475139,5.089333136876424,5.085763057072957,5.082233031590779,5.078733007113139,5.075262983640035,5.071832935015361,5.068433006604512,5.065062920252482,5.061732888221741,5.058422843615214,5.055152813593547,5.051902850468953,5.04869278271993,5.045502742131551,5.042352755864461,5.039222677548726,5.036132613817851,5.033062696456909,5.030022660891215,5.027002612749736,5.024012645085652,5.021052598953247,5.018122553825378,5.015212575594584,5.012322465578715,5.009462475776672,5.006632447242737,5.003822485605876,5.001032431920369,4.9982722997665405,4.995532353719075,4.992812275886536,4.990122278531392,4.987442175547282,4.984792311986287,4.982162197430928,4.9795522292455034,4.976972182591756,4.974402189254761,4.971852103869121,4.969332059224446,4.966822028160095,4.964332024256389,4.961861968040466,4.959412058194478,4.9569820165634155,4.954572081565857,4.9521719217300415,4.94979194800059,4.947431882222493,4.945091923077901,4.942761937777202,4.940451820691426,4.938151876131694,4.935871839523315,4.933611869812012,4.931361754735311,4.929121772448222,4.926901698112488,4.924701730410258,4.922511736551921,4.920341690381368,4.918171644210815,4.91603155930837,4.913891553878784,4.911771655082703,4.909661650657654,4.907561580340068,4.9054815371831255,4.903411507606506,4.901351571083069,4.899301489194234,4.897271354993184,4.895241379737854,4.893231471379598,4.891221324602763,4.889231324195862,4.887251377105713,4.885271350542705,4.8833112716674805,4.881381352742513,4.8792615334192915,4.876951336860657,4.874761303265889,4.872721234957377,4.870851238568624,4.869131167729695,4.8675611813863116,4.866111119588216,4.864781101544698,4.863561034202576,4.862441062927246,4.861400882403056,4.860450903574626,4.859570860862732,4.858770887056987,4.858020901679993,4.857330799102783,4.8567008177439375,4.85611077149709,4.855570832888286,4.855060736338298,4.854590733846028,4.854160825411479,4.853760719299316,4.853380759557088,4.853030721346538,4.852700710296631,4.852400779724121,4.852110664049785,4.851840694745381,4.851590633392334,4.851350744565328,4.851120670636495,4.850910743077596,4.85071074962616,4.850520690282186,4.850340684254964,4.850170572598775,4.850000699361165,4.849840680758159,4.8496906359990435,4.849550644556682,4.849410732587178,4.849280595779419,4.8491506179173784,4.849020640055339,4.8489006360371905,4.848790645599365,4.848670641581218,4.848560651143392,4.8484606345494585,4.848350604375203,4.84825058778127,4.848150650660197,4.848050673802693,4.847960631052653,4.84786069393158,4.847770651181539,4.8476806084314985,4.847590605417888,4.847510615984599,4.847420573234558,4.847340703010559,4.847260634104411,4.847180724143982,4.847090641657512,4.847020665804545,4.846940636634827,4.846860647201538,4.84678069750468,4.846710602442424,4.8466406265894575,4.846560597419739,4.8464906215667725,4.846420645713806,4.84635059038798,4.846280614535014,4.846210638682048,4.8461406628290815,4.846070607503255,4.846010684967041,4.845940550168355,4.845880627632141,4.845810651779175,4.845750570297241,4.845690647761027,4.845620632171631,4.845560630162557,4.845500667889913,4.845440626144409,4.845380624135335,4.8453205823898315,4.845260580380757,4.845210591952006,4.845150709152222,4.845090587933858,4.845040639241536,4.844980676968892,4.844930609067281,4.844880660374959,4.844820578893025,4.844770669937134,4.8447206020355225,4.844670653343201,4.8446206251780195,4.844570676485698,4.844520688056946,4.8444706201553345,4.844420671463013,4.844370603561401,4.844330668449402,4.8442806005477905,4.844230572382609,4.8441905577977495,4.84415070215861,4.844100634256999,4.844060659408569,4.84402064482371,4.8439706563949585,4.8439306418101,4.84389066696167,4.843850612640381,4.843810637791951,4.843770623207092,4.843730529149373,4.843700647354126,4.843660632769267,4.843620618184407,4.8435806433359785,4.843550642331441,4.843510627746582,4.843480626742045,4.843450625737508,4.843410611152649,4.843380610148112,4.843350609143575,4.843310594558716,4.843280673027039,4.843250632286072,4.843220631281535,4.843190630276998,4.843160589536031,4.843130588531494,4.843110640843709,4.843080639839172,4.843050718307495,4.843020598093669,4.843000610669454,4.842970569928487,4.842950542767842,4.842920660972595,4.8429005940755205,4.842880646387736,4.8428506056467695,4.842830657958984,4.84281059106191,4.8427906433741255,4.842770616213481,4.842740615208943,4.842720588048299,4.842700560887654,4.842690706253052,4.842670599619548,4.8426506121953325,4.842630624771118,4.842610597610474,4.842600663503011,4.842580596605937,4.842560648918152,4.84255063533783,4.8425306876500445,4.842520515124003,4.842500686645508,4.842490593592326,4.842480580012004,4.842460632324219,4.842450658480327,4.842440565427144,4.842430671056111,4.84242057800293,4.842410564422607,4.842400630315145,4.842390656471252,4.8423806031545,4.842370589574178,4.842360615730286,4.842350602149963,4.842340548833211,4.842340588569641,4.8423307339350385,4.842320601145427,4.842320640881856,4.842310627301534,4.842310547828674,4.842300573984782,4.8423006137212115,4.842290600140889,4.842290600140889,4.842290639877319,4.842280666033427,4.8422807057698565,4.842280626296997,4.842280626296997,4.842270612716675,4.842270652453105,4.842270612716675,4.842270652453105,4.842270572980245,4.842270652453105,4.842270612716675,4.842270612716675,4.842280666033427,4.842280666033427,4.842280666033427,4.842280666033427,4.842290639877319,4.842290639877319,4.842290600140889,4.842300573984782,4.842300653457642,4.842300573984782,4.842310627301534,4.842310667037964,4.842320640881856,4.842330574989319,4.842330574989319,4.842340588569641,4.842350602149963,4.842350522677104,4.842360695203145,4.842370589574178,4.84238064289093,4.84238064289093,4.842390656471252,4.842400630315145,4.842410524686177,4.84242061773936,4.842430671056111,4.842440565427144,4.842450658480327,4.842460592587789,4.842470645904541,4.842490553855896,4.842500646909078,4.84251054128011,4.842520594596863,4.842530608177185,4.84255063533783,4.84255055586497};
    CH3CCl3={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00116342452383833,0.017432911476741236,0.10808019215861957,0.2890424318611622,0.5636700938145319,0.8801461607217789,1.238609770933787,1.7015230456988018,2.179267247517904,2.7722602685292563,3.5117450952529907,4.254168093204498,5.182889421780904,6.633789936701457,8.815616488456726,11.549276192982992,14.64974037806193,17.680185159047443,20.81547784805298,24.916697820027668,30.325836658477783,36.76850446065267,42.720016161600746,49.04176902770996,57.53721491495768,68.57340017954509,78.18179384867351,85.15928586324056,90.82912127176921,95.16212209065755,99.43795967102051,103.94622294108073,108.2164363861084,111.07315063476562,114.91390546162923,120.27636273701985,124.94140434265137,128.82591438293457,137.22170766194662,134.4471804300944,127.53314399719238,117.31796328226726,104.99499003092448,91.00497118631999,77.60030555725098,65.37696488698323,54.61866887410482,45.62981446584066,37.923712730407715,31.91746695836385,26.717827479044598,22.222681363423664,18.557329495747883,15.458243687947592,12.834123134613037,10.93584974606832,9.145282427469889,7.662665605545044,6.305953701337178,5.245330850283305,4.363625506560008,3.680271248022715,3.2219178477923074,2.6039250095685325,2.0359680155913034,1.6536800463994343,1.3429876168568928,1.0901534656683605,0.8847505201896032,0.7179091026385626,0.5826493004957835,0.4729319488008817,0.38394080599149066,0.3117417295773824,0.25315916538238525,0.20561674982309341,0.16702893003821373,0.1357009205967188,0.11026697792112827,0.08961177493135135,0.07284252159297466,0.05921663033465544,0.04815406631678343,0.03915542736649513,0.0318529037758708,0.025904720183461905,0.021080750972032547,0.017146961530670524,0.013957120245322585,0.01135532969298462,0.009244501202677688,0.007523829001002014,0.006126005163726707,0.00498733875186493,0.004061272057394187,0.003307198639959097,0.0026934672302256026,0.002193751841938744,0.0017868897994048893,0.0014556259072075288,0.0011859695174886535,0.00096641206376565,0.0007876103967040157,0.0006419940085227912,0.0005233488579203064,0.00042672003716385615,0.00034792893469178426,0.00028378061930804205,0.00023141481263640648,0.00018880885666779554,0.00015398419297222668,0.0001256642644875683,6.413006182507767e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
    CH3Cl={457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.00000254313153,457.0,457.000005086263,457.00000254313153,456.99999745686847,456.99999745686847,457.0,456.999994913737,457.00000254313153,456.99999745686847,457.00002034505206,456.9999643961589,457.0000813802083,456.9997380574544,457.93199666341144,460.7425028483073,463.24369557698566,465.7432912190755,468.2434260050456,470.7433776855469,473.243403116862,475.7314631144206,478.3116455078125,481.16064198811847,484.1764450073242,488.50885518391925,493.2549794514974,496.95969645182294,500.6978174845378,504.5039291381836,508.3637110392253,512.2328440348307,516.0400848388672,519.7264709472656,523.2439982096354,526.5386403401693,529.5773620605469,532.3371022542318,534.8238169352213,537.0335591634115,538.9712473551432,540.6648610432943,542.1264394124349,543.3849334716797,544.4634094238281,545.3698170979818,546.1371358235677,546.7914225260416,547.3396860758463,547.7978973388672,548.1820729573568,548.5012359619141,548.7653757731119,548.9834696451823,549.1685434977213,549.3226318359375,549.4526824951172,549.5567423502604,549.6467793782552,549.7208353678385,549.7808532714844,549.8308563232422,549.8710784912109,549.9049123128256,549.941884358724,545.3847249348959,552.4202321370443,537.3112080891927,542.7740173339844,570.7273610432943,562.6231740315756,552.0705413818359,542.7083333333334,535.3501332600912,538.8634541829427,537.7152353922526,538.5567677815756,536.2959035237631,544.8235321044922,546.2872212727865,539.8231658935547,535.3102569580078,534.1656138102213,537.6538136800131,539.620361328125,539.5420227050781,549.8295237223307,563.0184326171875,558.953867594401,563.0249328613281,566.6924743652344,570.2189381917318,573.7017059326172,575.2236633300781,574.1700388590494,572.2970733642578,570.1644846598307,567.9466145833334,565.6996459960938,563.438720703125,561.1686350504557,558.889882405599,556.6004231770834,554.6528727213541,553.1580963134766,551.7919972737631,550.4519755045573,549.1060180664062,547.7440643310547,546.3631439208984,544.963144938151,543.5433247884115,542.1050618489584,540.8810882568359,539.9485677083334,539.1004943847656,538.2704823811849,537.4345194498698,536.5885416666666,535.7286020914713,534.8546040852865,533.9667358398438,533.0635274251302,532.3407084147135,531.8652496337891,531.4631958007812,531.0791676839193,530.6941935221354,530.3012135823568,529.8992513020834,529.4882659912109,529.0663299560547,528.6342519124349,528.2699432373047,527.9987589518229,527.7527770996094,527.5087687174479,527.258799235026,527.0008188883463,526.7338460286459,526.4588623046875,526.1739095052084,525.8798777262369,525.6326599121094,525.451520284017,525.2865422566732,525.1225331624349,524.9535598754883,524.7775802612305,524.5935948689779,524.4026285807291,524.2036285400391,523.9967575073242,523.6672999064127,523.1726633707682,522.6137186686198,522.0258153279623,521.4188435872396,520.7978846232096,520.1659164428711,519.5219497680664,518.8670043945312,518.2028757731119,517.7050857543945,517.4326426188151,517.2286376953125,517.0415623982748,516.8556162516276,516.6636123657227,516.4656372070312,516.2606531778971,516.0486602783203,515.8297653198242,515.5003280639648,515.0056508382162,514.4238586425781,513.7830022176107,513.0971221923828,512.3732172648112,511.6183115641276,510.8353754679362,510.0284423828125,509.2005030314128,508.3545557657878,507.4925944010417,506.6186294555664,505.732660929362,504.8376871744792,503.9346974690755,503.0257161458333,502.1117350260417,501.19373830159503,500.27274322509766,499.35075124104816,498.42775472005206,497.5037536621094,496.5807418823242,495.6597391764323,494.73973592122394,493.8217290242513,492.9067204793294,491.99471282958984,491.08670806884766,490.1816864013672,489.2816747029622,488.38466389973956,487.49364980061847,486.6066385904948,485.72462209065753,484.8466084798177,483.97458902994794,483.1085789998372,482.2465591430664,481.3905436197917,480.54052480061847,479.6955159505208,478.8554941813151,478.02247619628906,477.1934636433919,476.3704477945964,475.5534261067708,474.7424138387044,473.9363962809245,473.13538360595703,472.3403600056966,471.55134836832684,470.7663345336914,469.9883092244466,469.2153040568034,468.44628651936847,467.68427022298175,466.92625935872394,466.1732432047526,465.4262237548828,464.68321482340497,463.94519805908203,463.2121861775716,462.48417409261066,461.76115163167316,461.0431416829427,460.3291320800781,459.6191151936849,458.9141031901042,458.2140833536784,457.51807403564453,456.82606506347656,456.13805135091144,455.4550374348958,454.7760264078776,454.1010157267253,453.4300003051758,452.76299540201825,452.0989812215169,451.4399693806966,450.7849578857422,450.13294728597003,449.4849370320638,448.8399251302083,448.19891357421875,447.56190490722656,446.9278971354167,446.29688771565753,445.6698760986328,445.0458679199219,444.4248580932617,443.8078435262044,443.1928405761719,442.58182525634766,441.9738184611003,441.3688100179036,440.76680755615234,440.1667887369792,439.57078552246094,438.9767761230469,438.3857727050781,437.7977600097656,437.2127507527669,436.62975311279297,436.0497283935547,435.4727325439453,434.89672088623047,434.32471720377606,433.7547124226888,433.1866989135742,432.62169138590497,432.0586929321289,431.49767812093097,430.93968200683594,430.3826675415039,429.8286641438802,429.27665456136066,428.72764587402344,428.17964426676434,427.6336390177409,427.0896301269531,426.5486246744792,426.0086212158203,425.47061920166016,424.93460845947266,424.40060170491535,423.8676020304362,423.3365936279297,422.8075892130534,422.28057861328125,421.7555796305339,421.23156992594403,420.7095692952474,420.1885681152344,419.6695607503255,419.1525522867839,418.63655344645184,418.12154897054035,417.6085459391276,417.0965398152669,416.58653513590497,416.07752482096356,415.5705286661784,415.0635248819987,414.55851491292316,414.0555165608724,413.55250295003253,413.05153401692706,412.55342356363934,412.13805135091144,411.8378143310547,411.58573659261066,411.36266072591144,411.1606089274089,410.9755630493164,410.8055140177409,410.6504720052083,410.50744374593097,410.37640889485675,410.25538635253906,410.14435323079425,410.04232533772785,409.9483057657878,409.8612823486328,409.78127034505206,409.7072575887044,409.6392364501953,409.5762227376302,409.51820882161456,409.46420033772785,409.41318766276044,409.3671696980794,409.3241704305013,409.2831548055013,409.2461446126302,409.2111409505208,409.1781361897786,409.14713287353516,409.11812591552734,409.09112040201825,409.0661163330078,409.04211171468097,409.0191065470378,408.99710337320965,408.9771016438802,408.9571024576823,408.9390920003255,408.9210968017578,408.90509033203125,408.8880971272786,408.8730824788411,408.8580856323242,408.84407806396484,408.830083211263,408.81707763671875,408.80408477783203,408.79108174641925,408.7790807088216,408.76707712809247,408.7560780843099,408.7450764973958,408.7340723673503,408.7230758666992,408.71307373046875,408.7030715942383,408.69307200113934,408.68307240804035,408.6730702718099,408.66407267252606,408.65507253011066,408.64607493082684,408.6370671590169,408.62807210286456,408.61906178792316,408.61106872558594,408.6020685831706,408.5940653483073,408.58606974283856,408.5770670572917,408.5690638224284,408.5620651245117,408.55406697591144,408.5460713704427,408.53806559244794,408.53106689453125,408.52306874593097,408.5160624186198,408.5090688069661,408.5010630289714,408.4940592447917,408.48706309000653,408.48006439208984,408.4730631510417,408.4670639038086,408.46007029215497,408.45306396484375,408.44706471761066,408.4400583902995,408.43406168619794,408.42706298828125,408.42105865478516,408.4150644938151,408.4090576171875,408.40306599934894,408.3960545857747,408.3910598754883,408.3850631713867,408.3790562947591,408.37306213378906,408.3670603434245,408.362060546875,408.35605875651044,408.35105895996094,408.3450622558594,408.3400599161784,408.3350652058919,408.32905832926434,408.32405853271484,408.3190638224284,408.3140589396159,408.3090540568034,408.3040593465169,408.29905700683594,408.29505666097003,408.29005940755206,408.2850596110026,408.28106180826825,408.2760594685872,408.27205657958984,408.26705678304035,408.26305135091144,408.2590560913086,408.2550557454427,408.25005594889325,408.2460530598958,408.24205525716144,408.2380549112956,408.2340596516927,408.2300542195638,408.22705078125,408.2230580647786,408.2190577189128,408.21605173746747,408.2120539347331,408.2090530395508,408.20505777994794,408.2020517985026,408.19805908203125,408.19504801432294,408.19205474853516,408.18904876708984,408.18605550130206,408.1830520629883,408.1800486246745,408.1770553588867,408.17405954996747,408.1710561116536,408.1680552164714,408.165044148763,408.1630579630534,408.16004689534503,408.1580556233724,408.1550521850586,408.15305582682294,408.15004475911456,408.1480534871419,408.1450449625651,408.14305369059247,408.1410497029622,408.13904825846356,408.1370493570964,408.1350504557292,408.133051554362,408.1310577392578,408.1290512084961,408.1270472208659,408.1250483194987,408.123046875,408.12204996744794,408.1200536092122,408.11804453531903,408.11705017089844,408.11504618326825,408.1140492757161,408.11205037434894,408.11104583740234,408.1100489298503,408.1080500284831,408.1070505777995,408.10604604085285,408.1050440470378,408.10404713948566,408.1030451456706,408.10204060872394,408.1010487874349,408.1000467936198,408.0990498860677,408.0980478922526,408.09704844156903,408.0960439046224,408.0960439046224,408.09504954020184,408.0940450032552,408.0940475463867,408.0930455525716,408.0930480957031,408.092046101888,408.09204355875653,408.09104410807294,408.09104410807294,408.09104410807294,408.0900421142578,408.09004465738934,408.0900395711263,408.09004465738934,408.09004465738934,408.09004465738934,408.0900395711263,408.0900395711263,408.0900395711263,408.0900395711263,408.09004465738934,408.09004465738934,408.09004465738934,408.09004465738934,408.0910415649414,408.09104410807294,408.0910390218099,408.09204355875653,408.09204355875653,408.0930404663086,408.0930430094401,408.0940348307292,408.0940475463867,408.09503682454425,408.0950444539388,408.0960388183594,408.0970408121745,408.09704335530597,408.0980453491211,408.09904225667316,408.10003662109375,408.1010462443034,408.1010487874349,408.10203806559247,408.10304005940753,408.1040395100911,408.10504659016925,408.10604095458984,408.10704294840497,408.10904184977215,408.11004638671875,408.1110356648763,408.11204528808594,408.11303965250653,408.1150385538737,408.1160430908203,408.11704508463544};
    //CHCl3={5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,5.99999996026357,6.00000003973643,6.0,6.0,6.000000079472859,6.0,6.0,5.99999996026357,6.0,5.9999998807907104,5.999999920527141,5.99999996026357,5.99999996026357,5.999999920527141,5.99999984105428,5.999999801317851,5.99999996026357,5.999999761581421,6.0,5.999999364217122,6.000000437100728,5.999999086062114,6.004406849543254,6.016761938730876,6.035730520884196,6.059961279233296,6.088124752044678,6.1188706159591675,6.150859355926514,6.182749946912129,6.213214119275411,6.240888913472493,6.267828861872355,6.295786023139954,6.3250742355982466,6.35522186756134,6.387278318405151,6.420506397883098,6.455213308334351,6.491689840952556,6.5301657517751055,6.570712129275004,6.612889051437378,6.657354195912679,6.704339424769084,6.753844857215881,6.805770079294841,6.860764026641846,6.9187584320704145,6.979702750841777,7.0441856781641645,7.112189372380574,7.183522542317708,7.259722630182902,7.3409433762232466,7.427393078804016,7.519442598025004,7.616433501243591,7.7184838851292925,7.825045943260193,7.9355984926223755,8.049692273139954,8.166467428207397,8.285772641499838,8.406959454218546,8.530663967132568,8.657198746999105,8.78619416554769,8.917659203211466,9.051833947499594,9.189357121785482,9.329762061436972,9.473884026209513,9.622934261957804,9.776117245356241,9.933977444966635,10.09768565495809,10.267175118128458,10.442663192749023,10.624351421991983,10.812538862228394,11.007426102956137,11.209811369578043,11.418800036112467,11.633888165156046,11.854777495066324,12.080269495646158,12.30986205736796,12.54534657796224,12.798911571502686,12.946532328923544,12.908882220586142,12.589104175567627,12.102709531784058,12.025136868158976,11.992193142573038,11.915627717971802,11.432111660639444,10.673722664515177,10.258787552515665,10.200666586558023,9.454691807428995,9.350273609161377,8.94034218788147,8.946687857309977,8.98135232925415,9.290102243423462,8.547015905380249,8.846131881078085,8.747184753417969,8.543028354644775,8.949861923853556,8.949700117111206,8.843595663706461,9.249992926915487,9.90184235572815,10.448237737019857,9.763489564259848,10.08242662747701,9.470903873443604,9.678422768910727,9.891692320505777,10.105006217956543,10.14895518620809,10.008438666661581,9.852510452270508,9.69538958867391,9.538158098856607,9.380917151769003,9.223679701487223,9.066434065500895,8.909204959869385,8.751946051915487,8.620591719945272,8.517394622166952,8.416551113128662,8.315898617108664,8.215259432792664,8.11461865901947,8.01397963364919,7.913337190945943,7.812702655792236,7.712061524391174,7.627991875012715,7.561939835548401,7.49741546312968,7.432993173599243,7.368593851725261,7.304183483123779,7.2397838433583575,7.175382812817891,7.110975344975789,7.046569228172302,6.992770949999492,6.950509508450826,6.909224192301433,6.868011991182963,6.826802889506022,6.785592397054036,6.74439263343811,6.703182299931844,6.661973357200623,6.6207601229349775,6.586335261662801,6.559281309445699,6.5328448216120405,6.506452997525533,6.480063756306966,6.453683376312256,6.427293618520101,6.40091331799825,6.374523917833964,6.348142147064209,6.326105912526448,6.308806975682576,6.291909535725911,6.275037924448649,6.258168776830037,6.241298278172811,6.2244285345077515,6.207558433214824,6.190688133239746,6.173829754193624,6.150943040847778,6.121514956156413,6.091531316439311,6.061513662338257,6.031492193539937,6.001463055610657,5.971442421277364,5.941412806510925,5.911382953325908,5.881360451380412,5.865065336227417,5.863699793815613,5.863597710927327,5.863581498463948,5.863585948944092,5.863582730293274,5.863585114479065,5.8635832866032915,5.86358368396759,5.863584399223328,5.8622597853342695,5.859501679738362,5.856611609458923,5.853721578915914,5.850831667582194,5.847931583722432,5.845041672388713,5.842141628265381,5.839251637458801,5.83635167280833,5.83346160252889,5.830561717351277,5.8276716868082685,5.824771682421367,5.821881612141927,5.818981607755025,5.8160916566848755,5.8131916125615435,5.810301502545674,5.8074116706848145,5.804511586825053,5.801621635754903,5.798721671104431,5.795831680297852,5.79293163617452,5.790041605631511,5.787141521771749,5.784251570701599,5.781351645787557,5.778461575508118,5.775561650594075,5.772671540578206,5.769781629244487,5.766881585121155,5.763991554578145,5.761091510454814,5.758201559384664,5.755301554997762,5.752411603927612,5.749511639277141,5.746621568997701,5.743721564610799,5.740831613540649,5.737931569417317,5.735041499137878,5.732141613960266,5.729251543680827,5.726361592610677,5.723461548487346,5.7205716371536255,5.717671513557434,5.714781562487285,5.711881597836812,5.708991567293803,5.706091562906901,5.703201532363892,5.70030152797699,5.69741153717041,5.694511532783508,5.691621422767639,5.688731590906779,5.685831546783447,5.6829415162404375,5.680041511853536,5.677151600519816,5.674251556396484,5.671361486117045,5.668461521466573,5.665571530659993,5.662671645482381,5.6597814957300825,5.656881491343181,5.65399154027303,5.651091615358989,5.648201425870259,5.645301620165507,5.642411510149638,5.639521400133769,5.636621435483296,5.633731484413147,5.630831480026245,5.627941528956096,5.625041524569194,5.622151414553325,5.619251569112142,5.616361419359843,5.613461534182231,5.610571503639221,5.607671499252319,5.60478142897288,5.60189151763916,5.598991513252258,5.596101403236389,5.593201518058777,5.590311408042908,5.587411483128865,5.584521452585856,5.581621527671814,5.578731536865234,5.575831413269043,5.5729414621988935,5.570041497548421,5.567151387532552,5.564261436462402,5.56136139233907,5.558471481005351,5.555571397145589,5.55268148581187,5.5497814019521075,5.546891530354817,5.543991367022197,5.541101455688477,5.538201371828715,5.535311381022136,5.532411456108093,5.529521465301514,5.526621421178182,5.523731350898743,5.520841479301453,5.517941355705261,5.515051444371541,5.51215132077535,5.50926140944163,5.506361365318298,5.503471374511719,5.500571449597676,5.497681458791097,5.494781414667766,5.491891384124756,5.488991419474284,5.486101349194844,5.483211358388265,5.480311354001363,5.477421482404073,5.474521478017171,5.471631368001302,5.4687312841415405,5.46584137280782,5.462941408157349,5.46005133787791,5.457151412963867,5.454261302947998,5.451361417770386,5.448471387227376,5.445571422576904,5.442681392033895,5.439781427383423,5.436891277631124,5.434001604715983,5.431100845336914,5.429526011149089,5.429403305053711,5.429393966992696,5.429393768310547,5.429383794466655,5.429383754730225,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383754730225,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429383794466655,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816,5.429388801256816};
        HCFC141b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.00011203966126534699,0.03376847004983574,0.06648059604534258,0.1707762268682321,0.7146161670486132,2.2383394837379456,3.747459292411804,6.036929090817769,7.7147689660390215,9.836338837941488,11.384798526763916,13.121398448944092,14.544998407363892,15.739598194758097,16.890098412831623,17.334598859151203,17.678198496500652,18.454998811086018,19.124198754628498,19.5464989344279,19.870198726654053,20.67949867248535,21.561198711395264,22.543598651885986,23.414698759714764,23.809098561604817,24.225419680277508,24.5268071492513,24.882307052612305,25.234007358551025,25.59500741958618,25.961607456207275,26.330307165781658,26.667807420094807,26.94620720545451,27.173306941986084,27.35590712229411,27.500006993611652,27.575006643931072,27.55570650100708,27.456806182861328,27.291006247202557,27.069705804189045,26.769505500793457,26.371005376180012,25.891504923502605,25.346004962921143,24.747604370117188,24.1078044573466,23.43620427449544,22.741503715515137,22.03110345204671,21.311103502909344,20.58470328648885,19.85420306523641,19.124302864074707,18.398902893066406,17.681302547454834,16.97440258661906,16.28030260403951,15.60100237528483,14.937902053197226,14.29220207532247,13.66530179977417,13.05800175666809,12.470801591873169,11.903801679611206,11.357101519902548,10.83060129483541,10.32400131225586,9.837271213531494,9.369921207427979,8.921601215998331,8.491880973180136,8.0802610317866,7.6862709522247314,7.3093909819920855,6.949110786120097,6.6048808097839355,6.276180823644002,5.962440729141235,5.663140734036763,5.37773060798645,5.105680545171102,4.846480488777161,4.599600553512573,4.364550431569417,4.140830556551616,3.9279504815737405,3.725460429986318,3.5328903992970786,3.3498103817303977,3.175800323486328,3.0103803475697837,2.8531203468640647,2.7036402821540833,2.561610301335653,2.42667027314504,2.298520306746165,2.176830232143402,2.061300218105316,1.9516402284304302,1.8475902080535889,1.7488601903120677,1.6552201906840007,1.56642018755277,1.48222017288208,1.40239014228185,1.3267301519711812,1.2550301551818848,1.1870901485284169,1.1227201422055562,1.0639301538467407,1.011610135436058,0.9642591377099355,0.9213581333557764,0.8824381430943807,0.847083126505216,0.8149221291144689,0.7856221298376719,0.7588861336310705,0.7344481299320856,0.7120731274286906,0.6915471206108729,0.6726801246404648,0.655300130446752,0.6392561246951421,0.6244091192881266,0.6106361250082651,0.5978301217158636,0.5858911176522573,0.574730118115743,0.5642691204945246,0.5544371157884598,0.5451671133438746,0.5364061146974564,0.5281011164188385,0.5202081203460693,0.512684111793836,0.505494107802709,0.4986051047841708,0.4919831107060115,0.4856061140696208,0.47945010910431546,0.47349410752455395,0.46771810948848724,0.4621051028370857,0.4566401019692421,0.45130710552136105,0.44609710574150085,0.44099710136651993,0.4359991004069646,0.43109409759442013,0.42627110083897907,0.42152510086695355,0.4168501024444898,0.41224109133084613,0.4076920946439107,0.40319809317588806,0.39875609427690506,0.3943590944012006,0.39000709106524784,0.3856960932413737,0.38142309089501697,0.3771870930989583,0.3729840914408366,0.3688130850593249,0.36467008541027707,0.36055508504311246,0.3564670855800311,0.3524050811926524,0.348366084198157,0.3443510855237643,0.34035708010196686,0.3363830844561259,0.3324280728896459,0.32849307854970294,0.3245760773619016,0.3206780751546224,0.31679607679446536,0.3129320740699768,0.3090810750921567,0.3052450666824977,0.30142507205406827,0.297619067132473,0.2938280676801999,0.29005106290181476,0.2862870668371518,0.28253306945164997,0.278793066740036,0.2750650644302368,0.27134906500577927,0.26764506101608276,0.2639520640174548,0.260271059970061,0.2565980652968089,0.2529360627134641,0.24928505470355353,0.24564405779043832,0.24201305955648422,0.23839205503463745,0.2347810554007689,0.23117605596780777,0.22758105273048082,0.2239950547615687,0.2204180508852005,0.2168500485519568,0.2132900506258011,0.20973904927571616,0.20619304850697517,0.20265504717826843,0.19912604739268622,0.19560404370228449,0.19208904604117075,0.1885820428530375,0.1850830428302288,0.18158804376920065,0.17810004328687987,0.174619040141503,0.171144038438797,0.1676770361761252,0.16421503573656082,0.1607600376009941,0.1573090354601542,0.15386503438154855,0.15042603264252344,0.14699303234616914,0.14356603100895882,0.14014202977220216,0.13672402873635292,0.13331202790141106,0.12990502764781317,0.12650302611291409,0.12310702602068584,0.11971502440671127,0.11632602413495381,0.11294202382365863,0.10956302161018054,0.10618902121980985,0.1028200201690197,0.09945451902846496,0.09609381854534149,0.09273521726330121,0.08938091682891051,0.08603101658324401,0.08268531411886215,0.07934361385802428,0.07600591331720352,0.07267201195160548,0.06933960939447086,0.06601121090352535,0.0626866091042757,0.05936560779809952,0.056048307878275715,0.052734406354526676,0.04942390539993843,0.046114504958192505,0.04280860380580028,0.0395061019808054,0.036206901694337525,0.03291080115983883,0.029617799911648035,0.026327800160894792,0.023230400246878464,0.02049509979163607,0.01808010010669629,0.015948099782690406,0.014066300044457117,0.012405699972684184,0.010940299990276495,0.009647310012951493,0.008506650027508536,0.007500449971606334,0.006612920008289318,0.005830139969475567,0.0051398000214248896,0.004531020065769553,0.003994199990605314,0.0035208499951598546,0.0031035099915849664,0.0027355599837998548,0.0024111599777825177,0.002125189988873899,0.001873079997797807,0.0016508500072328995,0.0014549600115666788,0.0012822799908462912,0.0011300799960736185,0.0009959330006192129,0.0008776939988213902,0.0007734819907151783,0.00068163401253211,0.0006006859960810592,0.0005293439947611963,0.00046647100437742967,0.0004110610000983191,0.00036222899992329377,0.00031919499694292125,0.00028127200494054705,0.00024785200124218437,0.00021840100089320913,0.00019244799962810552,0.00016957799986509295,0.00014942399987679286,0.00013166500017784225,0.00011601599908317439,6.957744578054796e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HCFC142b={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.001065175359447797,0.021073126544555027,0.06999984166274469,0.11499984314044316,0.16126984233657518,0.19499984259406725,0.22999984274307886,0.2649998404085636,0.29872983197371167,0.34251976509888965,0.41178564727306366,0.5049996227025986,0.5972496171792349,0.672999694943428,0.7217137465874354,0.7549997667471567,0.7879217316706976,0.8391895890235901,0.9504593312740326,1.1215790609518688,1.4477779567241669,2.221526563167572,3.3005158503850303,4.47598530848821,5.687364776929219,6.54466180006663,7.866570234298706,8.959980805714926,9.961479743321737,11.354286829630533,12.102788925170898,13.052591880162558,13.693090518315634,14.409090280532837,15.063492933909098,15.682193517684937,16.647892634073894,17.730092525482178,18.928292592366535,19.930792331695557,20.536893049875896,21.354194005330402,21.61989386876424,22.207694212595623,22.075694402058918,22.050151189168293,22.259799003601074,22.128499031066895,22.12489938735962,22.090399265289307,22.030299186706543,21.948999404907227,21.834698994954426,21.677599271138508,21.48639949162801,21.26819944381714,21.029099305470783,20.753599484761555,20.428899606068928,20.06559944152832,19.672799428304035,19.25809971491496,18.80839951833089,18.312899748484295,17.782899856567383,17.22749948501587,16.654799620310467,16.07159972190857,15.483399868011475,14.895099639892578,14.310499906539917,13.732799768447876,13.163399934768677,12.60290002822876,12.053599993387857,11.517299969991049,10.995300054550171,10.488699913024902,9.998200019200643,9.524319887161255,9.067409912745157,8.627609968185425,8.20505984624227,7.799789945284526,7.4115599393844604,7.040059924125671,6.684929966926575,6.345750013987224,6.022079944610596,5.713430047035217,5.419290026028951,5.139169971148173,4.872529943784078,4.618849992752075,4.3776200612386065,4.14831002553304,3.9304400086402893,3.723489999771118,3.5269999901453652,3.3404799501101174,3.163479963938395,2.9955599904060364,2.8362900217374167,2.6852500240008035,2.5420599778493247,2.4063300093015036,2.277679979801178,2.1557799776395163,2.040279984474182,1.930860012769699,1.8272099892298381,1.7290399968624115,1.636050005753835,1.5479599833488464,1.4645199875036876,1.3854900101820629,1.310640017191569,1.2397599915663402,1.1726399958133698,1.1090799967447917,1.0488999982674916,0.9919329881668091,0.9380040069421133,0.8869550029436747,0.8386369943618774,0.7929080029328665,0.749627004067103,0.7086680084466934,0.6699089954296747,0.6332370042800903,0.5985410014788309,0.5662649969259897,0.5362870047489802,0.5079390108585358,0.4811279997229576,0.4557649989922841,0.4317700018485387,0.4090690016746521,0.38759200026591617,0.36726799855629605,0.3480389987428983,0.329844002922376,0.3126249959071477,0.29633300254742306,0.2809169987837474,0.26632799456516904,0.2525230000416438,0.23946099976698557,0.22710400074720383,0.21540999909241995,0.20434699952602386,0.19388199970126152,0.18397999927401543,0.1746109997232755,0.16574900100628534,0.15736699973543486,0.14943699911236763,0.14193599919478098,0.13484299927949905,0.12813199932376543,0.12178600020706654,0.11578499960402648,0.11010699967543285,0.10473699929813544,0.09965770008663337,0.09485529859860738,0.09031179919838905,0.08601570005218188,0.08195329954226811,0.07810959902902444,0.07447259997328122,0.07103339893122514,0.06778109880785148,0.06470309942960739,0.06179209922750791,0.059038899218042694,0.05643249892940124,0.05396469961851835,0.0516301995764176,0.04942169971764088,0.04732959934820732,0.04534999933093786,0.04347639996558428,0.04170079932858547,0.040019799334307514,0.03842819947749376,0.036918699741363525,0.035486599430441856,0.03412979965408643,0.03284429976095756,0.03162349946796894,0.03046619954208533,0.02936869968349735,0.028325399694343407,0.027333099395036697,0.026391299751897652,0.02549719934662183,0.024645599847038586,0.02383649970094363,0.023067399859428406,0.022333699588974316,0.021635799513508875,0.020971599655846756,0.020336799478779238,0.019729599667092163,0.019150999529908102,0.01859919959679246,0.01807029964402318,0.01756539971878131,0.017083099422355492,0.01661979981387655,0.016174299487223227,0.01574789957764248,0.015339699573814869,0.014945999641592303,0.01456859971707066,0.014206399753068885,0.0138561997252206,0.013519599723319212,0.013195899703229466,0.012881999757761756,0.012577299727126956,0.012283599625031153,0.012000399641692638,0.011724499752745032,0.011457999780153235,0.011200399758915106,0.010948699666187167,0.010702599848931035,0.010464099701493979,0.010232899881278476,0.010006099784125885,0.009785779829447469,0.009571649599820375,0.009360979699219266,0.009155899751931429,0.008956109639257193,0.008758939880256852,0.008564249922831854,0.008374249873061975,0.0081886798919489,0.008004919781039158,0.007825229743806025,0.007649369809466104,0.0074747698769594235,0.007301379887697597,0.0071314698628460365,0.006964849929014842,0.006798979826271534,0.006636169855482876,0.006476239805730681,0.0063166798402865725,0.006157489842735231,0.006000989815220237,0.005847039865329862,0.005693129884699981,0.005541619883539776,0.005392379903544982,0.005242919937397043,0.005095619902325173,0.004950349917635322,0.004804659828854104,0.0046585598805298405,0.004514459947434564,0.004372219981936117,0.004229399880083899,0.004088399892983337,0.00394908986830463,0.003809039966048052,0.003668309946078807,0.003529289950771878,0.0033918899522783854,0.003253649939627697,0.003116999966247628,0.002981829942048838,0.0028457099882264933,0.0027110699641828737,0.0025778000126592815,0.002443499998965611,0.002308219962287694,0.0021743900142610073,0.0020419099795011184,0.0019130199992408354,0.0017921599986342092,0.0016788399952929467,0.0015725999934754025,0.001473020005505532,0.0013796899972173076,0.0012922100043700386,0.0012102400069124997,0.0011334300118808944,0.0010614600032567978,0.000994039000943303,0.0009308709947314734,0.000871696999335351,0.0008162669885981207,0.0007643450080649927,0.00071571299728627,0.0006701629948414242,0.0006275029930596551,0.0005875490023754537,0.0005501309933606535,0.0005150899960426614,0.00048227500277183327,0.000451545000638968,0.0004227699998106497,0.0003958240001035544,0.00037059199773163226,0.0003469660005066544,0.00032484399950286996,0.0003041299933101982,0.00028473400258614373,0.00026657399818456423,0.00024957099958555773,0.000233650998173592,0.0002187449984679309,0.0002047889999327405,0.00019172300138355544,0.00017948899888627542,0.00016803500087310871,0.00015731200134420456,0.00014727200080718225,0.0001378720007778611,0.00012907200046659759,0.00012083399875943239,0.00011311999999937446,0.00010589899951204036,3.377092131510532e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        HCFC22={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0007617614949898174,0.019080033137773473,0.07932233065366745,0.1400045237193505,0.20000430569052696,0.26000453531742096,0.3200042446454366,0.3800046021739642,0.4400041376550992,0.5000047385692596,0.5600039213895798,0.6200050512949625,0.680003434419632,0.7400057514508566,0.8000023066997528,0.8600076138973236,0.9275005906820297,0.9349976976712545,0.9200002650419871,0.9262516697247823,0.9637557764848074,1.0538601179917653,1.1860103805859883,1.3464653591314952,1.5845945576826732,1.9060347974300385,2.2494065960248313,2.637653867403666,3.1291542649269104,3.753723760445913,4.5027817487716675,5.391107479731242,6.472539742787679,7.774255792299907,9.383843421936035,11.191637754440308,13.09374705950419,15.120055437088013,17.352389971415203,19.92769479751587,22.525582949320476,25.179124514261883,28.196115493774414,31.407798290252686,35.72357686360677,40.48909950256348,44.551489194234215,48.66220633188883,52.764092127482094,56.786487897237144,60.742489178975426,64.80020904541016,69.13964017232259,73.98439725240071,79.53813616434734,85.39031410217285,90.98358980814616,96.40249379475911,101.49227841695149,105.4173412322998,110.94440905253093,116.0475304921468,124.7284984588623,127.37702624003093,134.272824605306,138.68090184529623,143.4614372253418,149.25739415486655,154.4252700805664,158.99640528361002,164.7063954671224,170.47949091593424,177.60554122924805,185.02057011922201,193.09755071004233,200.3144874572754,207.74554824829102,214.5593744913737,220.10840479532877,226.13036346435547,229.5420659383138,233.6953557332357,237.72884623209634,240.96188100179037,243.3929125467936,245.07293574015299,246.1749496459961,246.83200709025064,246.44208145141602,244.59511057535806,241.73414103190103,238.19415028889975,234.2322006225586,229.3392702738444,223.16629028320312,216.1813112894694,208.73430887858072,201.08934783935547,192.78440602620444,183.498415629069,173.6694196065267,163.62241872151694,153.59440739949545,143.75839487711588,134.2353744506836,125.10435612996419,116.41933631896973,108.20831807454427,100.43230438232422,93.05358568827312,86.09246762593587,79.55525016784668,73.4390328725179,67.73441696166992,62.42730172475179,57.500386238098145,52.93457190195719,48.709659258524574,44.80604648590088,41.20403512318929,37.883124669392906,34.82351462046305,32.006405671437584,29.413596947987873,27.02838929494222,24.834781964619953,22.817875385284424,20.963969548543293,19.26016362508138,17.694358507792156,16.255653699239094,14.933749437332153,13.719345410664877,12.603741804758707,11.578938404719034,10.637535254160563,9.772792100906372,8.978439569473267,8.248777190844217,7.578525026639302,6.96284294128418,6.397281130154927,5.87774936358134,5.400487860043843,4.962046305338542,4.559265057245891,4.189233819643657,3.8492727080980935,3.536881665388743,3.249760707219442,2.9858698646227517,2.743329028288523,2.5203983585039773,2.315507650375366,2.1271770199139914,1.9540964563687642,1.795015941063563,1.6488054792086284,1.5144350131352742,1.390954613685608,1.2774742345015209,1.173193911711375,1.0773735741774242,0.9893252948919932,0.9084170162677765,0.8340757787227631,0.7657735298077265,0.7033183177312216,0.6462221393982569,0.5937019685904185,0.5453798025846481,0.5009386613965034,0.46008452276388806,0.42252740263938904,0.38797029356161755,0.35619719078143436,0.32698308924833935,0.30011900266011554,0.27541792144378024,0.25270284960667294,0.23184177527825037,0.21268571416536966,0.19506865863998732,0.17886660248041153,0.1639935535689195,0.15034150953094164,0.13781146705150604,0.12631242784361044,0.11576239267985027,0.10608336329460144,0.09717683307826519,0.08898130680123965,0.08146557956933975,0.07457425693670909,0.06825643529494603,0.0624652144809564,0.057157497542599835,0.052293480994800724,0.04783696557084719,0.04375415233274301,0.04001443926244974,0.03658952719221512,0.03345321615537008,0.030581706824402016,0.02795289767285188,0.025546889286488295,0.02334488198782007,0.021329874948908884,0.01948636832336585,0.017799962777644396,0.01625745720230043,0.014846852282062173,0.013556947776426872,0.012377543762947122,0.011299440171569586,0.010314036548758546,0.009413473308086395,0.008590530526513854,0.007838627827974657,0.007151725352741778,0.006524293256613116,0.00595124124083668,0.005427929378735523,0.004950107734960814,0.004513856101160248,0.004115614768428107,0.0037521234480664134,0.0034203822530495622,0.003117651193557928,0.002841430250555277,0.002589419348320613,0.002359538533103963,0.0021498477435670793,0.0019586071042188755,0.0017842064359380554,0.0016251858808876325,0.0014801953511778265,0.0013480248744599521,0.0012275444557114195,0.0011177340444798272,0.0010176537034567446,0.0009264513694991668,0.0008433530601905659,0.0007676427873472372,0.0006986715355499958,0.0006358433165587485,0.0005786191128815213,0.0005265019232562432,0.00047904075230083737,0.000435823591639443,0.00039647444888638955,0.0003606513176540223,0.00032803919990935054,0.0002983540956241389,0.0002713349992215323,0.00024674490608352545,0.00022436682411353104,0.00020400474750204012,0.00018547668150858954,0.00016861961921676993,0.00015328456477921767,0.00013933451312671727,0.0001266454679959376,0.00011510442527651321,0.00010460838590612791,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        Halon1211={0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446572546536724,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446570024204751,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569946594536,0.004446569985399644,0.004446570024204751,0.004446569985399644,0.004446569985399644,0.004446569946594536,0.004446570101814966,0.0044465698301792145,0.004446570334645609,0.004446569170492391,0.004446571848044793,0.004446565833253165,0.0044465794538458185,0.004446548409759998,0.004446620470844209,0.004446447691104065,0.0044469935819506645,0.012151915968085328,0.018664849922060966,0.023900681796173256,0.027877628337591887,0.03101034214099248,0.03229169764866432,0.03281248671313127,0.0328332781791687,0.03209515412648519,0.03030576727663477,0.028203126974403858,0.026776751192907493,0.02495241429035862,0.0234999794823428,0.021999980478237074,0.020458318758755922,0.019499980999777716,0.018499995737026136,0.017499990140398342,0.016499992460012436,0.015499991675217947,0.01449999026954174,0.013499994995072484,0.012499973177909851,0.01137502615650495,0.010999986358607808,0.011131961752350131,0.014528773414591948,0.02660746080800891,0.042955159209668636,0.06120223210503658,0.08156623815496762,0.1075315357496341,0.14653477569421133,0.20330782110492387,0.27751198535164195,0.3696969747543335,0.4763076677918434,0.5893768072128296,0.7097166180610657,0.8352456837892532,0.9728992034991583,1.144959529240926,1.295939067999522,1.4159816404183705,1.5741113722324371,1.7711602052052815,1.9729202787081401,2.1840911904970803,2.425140698750814,2.665145973364512,2.8172022501627603,3.0058298110961914,3.2168917854626975,3.4390769600868225,3.602302074432373,3.780295729637146,3.8873608311017356,3.9997291962305703,4.127887845039368,4.220908443133037,4.2806588013966875,4.319008390108745,4.3401593764623,4.354827245076497,4.33484947681427,4.309016704559326,4.247629324595134,4.189547856648763,4.121598919232686,4.04886809984843,3.964238007863363,3.8617884318033853,3.7536577781041465,3.6527326901753745,3.5471805731455484,3.4357704718907676,3.3270804484685264,3.216950456301371,3.106110473473867,2.995190461476644,2.884720424811045,2.7751904328664145,2.6669804056485495,2.5604504545529685,2.4558804035186768,2.353520393371582,2.253550370534261,2.1561403473218284,2.061410347620646,1.9694603284200032,1.880370318889618,1.7941603064537048,1.7108702957630157,1.6305202941099803,1.5530802706877391,1.4785602589448292,1.4069002668062847,1.338080237309138,1.2720402379830678,1.2087302207946777,1.1480802297592163,1.0900401969750722,1.0345301926136017,0.9814761877059937,0.9308091749747595,0.8824491699536642,0.8363231619199117,0.792352149883906,0.7504581461350123,0.7105641414721807,0.6725951333840688,0.6364741226037344,0.6021271099646887,0.5694831162691116,0.5384710977474848,0.5090211058656374,0.4810640960931778,0.4545350894331932,0.42937008539835614,0.4055080811182658,0.38289107630650204,0.36145907392104465,0.34115506956974667,0.32192806154489517,0.30372605969508487,0.2864980523784955,0.2701990579565366,0.25478005533417064,0.24019904807209969,0.22641304632027945,0.21338304380575815,0.2010700429479281,0.18943703919649124,0.17844903593262038,0.16807303701837858,0.15827403217554092,0.1490260325372219,0.14029802878697714,0.1320620266099771,0.12429302682479222,0.1169650238007307,0.11005402232209842,0.10353902168571949,0.09739561999837558,0.09160471893846989,0.08614801863829295,0.08100641705095768,0.07616191481550534,0.07159951453407605,0.06730351472894351,0.06325721275061369,0.05944671264539162,0.0558609114959836,0.05248561097929875,0.049307710491120815,0.04631840996444225,0.043505809580286346,0.04085890855640173,0.03836900802950064,0.0361134068419536,0.03406510688364506,0.03212910673270623,0.030298506220181782,0.02856650622561574,0.026927005654821794,0.025374305279304583,0.02392030491804083,0.022541404701769352,0.021232804438720148,0.020007503995050985,0.01884300432478388,0.017735303690036137,0.016698303477217753,0.015727603031943243,0.014818902981157104,0.013950803006688753,0.013120902779822549,0.012344202802826961,0.0116171024274081,0.01093670236878097,0.01029990209887425,0.009703991934657097,0.009128892018149296,0.008573321780810753,0.008053461710611979,0.007567021568926672,0.007111891522072256,0.00668604140325139,0.006287621334195137,0.005914861219935119,0.005566121079027653,0.005239871175338824,0.004934670946871241,0.004649150961389144,0.00438207093005379,0.004132230766117573,0.0038985408027656376,0.0036625308566726744,0.0034243907624234757,0.0032016607195449374,0.002993350673932582,0.0027985306029828885,0.0026163405661160746,0.0024459605532077453,0.0022866305274267993,0.002137630460007737,0.00199830046040006,0.0018680204132882257,0.0017462004034314305,0.0016322903781353186,0.00152578034127752,0.001426190302784865,0.0013330902923674632,0.001246030277494962,0.0011646402708720416,0.001088550256099552,0.0010174202325288206,0.0009509112181452414,0.0008887391983686636,0.0008306181892597427,0.0007762851746520028,0.0007254951633512974,0.0006780181574868038,0.000633637139496083,0.0005921531410422176,0.0005533761286642402,0.0005171311252828067,0.00048325310975390795,0.000451588098561236,0.0004219910964214553,0.0003943290891281019,0.00036847608134848997,0.00034431207556432736,0.00032172907231142744,0.0003006240658578463,0.00028089906360643607,0.00026246505876770243,0.00024523805526162806,0.00022913905316575742,0.00021409404992785616,0.00020003504444806217,0.00018689604257815517,0.00017461903917137533,0.00016314603756958,0.0001524260345225533,0.00014240803405603705,0.00013304803239104027,0.00012430102712338945,0.00011612802578990038,0.00010849202408280689,6.832991311966907e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        Halon1301={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,1.2107990556842196e-06,9.686392521264983e-06,1.9372784966738738e-05,2.905917745010811e-05,3.8745569933477476e-05,5.60693097213516e-05,0.00011921713667106815,0.0002235555645408264,0.000360778462588011,0.0005134661914780736,0.0007886756357038394,0.003391635837033391,0.010107177193276584,0.02092159477372964,0.034983893080304064,0.051680791191756725,0.08715698743859927,0.1504269844541947,0.23020097613334656,0.31519197672605515,0.39410896847645444,0.4687449559569359,0.5532129456599554,0.651974951227506,0.7757129470507304,0.9354569266239802,1.1329799195130665,1.346309910217921,1.548219899336497,1.7223599056402843,1.8762499292691548,2.020599921544393,2.161349892616272,2.2925199468930564,2.4025299350420632,2.4911099076271057,2.569999933242798,2.650669972101847,2.724999964237213,2.8026700019836426,2.8623799681663513,2.8942899902661643,2.9381799499193826,2.99712997674942,3.035939951737722,3.073349952697754,3.1184199452400208,3.1368099649747214,3.1567599376042685,3.1835699876149497,3.1960699955622354,3.2309599916140237,3.252539952596029,3.305999994277954,3.2976099848747253,3.2844176292419434,3.2989591360092163,3.304409146308899,3.307799200216929,3.30922923485438,3.3087992866834006,3.306599259376526,3.302719295024872,3.297249356905619,3.2902593413988748,3.2818293968836465,3.2720394134521484,3.2609594464302063,3.2486594518025718,3.2352094451586404,3.2206694881121316,3.2051095366477966,3.1885695258776345,3.171119530995687,3.1528095801671348,3.133689602216085,3.113809605439504,3.0932196180025735,3.0719696283340454,3.050089657306671,3.02763960758845,3.0046496589978537,2.981149673461914,2.957189679145813,2.9328096906344094,2.9080296754837036,2.882889707883199,2.857419768969218,2.8316497206687927,2.8055997490882874,2.779299775759379,2.752789795398712,2.726079781850179,2.6991997957229614,2.672169804573059,2.6449997822443643,2.6177298029263816,2.5903698007265725,2.5629398226737976,2.535459836324056,2.5079498489697776,2.480409840742747,2.4528698523839316,2.425339857737223,2.3978298703829446,2.370369831720988,2.34294984738032,2.3155899047851562,2.288309892018636,2.2611098686854043,2.2340099016825357,2.2070098916689553,2.1801199118296304,2.1533498962720237,2.1267098983128867,2.100209911664327,2.073849896589915,2.0476399064064026,2.021589994430542,1.995709906021754,1.96998992562294,1.944449911514918,1.919089913368225,1.8939099311828613,1.8689199487368267,1.8441199362277985,1.819519927104314,1.7951099475224812,1.7709099352359772,1.7469099561373393,1.7231299380461376,1.699549953142802,1.6761899590492249,1.653039942185084,1.6300999621550243,1.6073899666468303,1.5848899682362874,1.562619944413503,1.540559967358907,1.5187299748261769,1.4971199929714203,1.474970002969106,1.4523099760214488,1.4299599925676982,1.40789998571078,1.3861300150553386,1.3646500011285145,1.3434699773788452,1.322579989830653,1.3019700050354004,1.2816200057665508,1.2615499993165333,1.2417799929777782,1.2222799956798553,1.2030500173568726,1.184089998404185,1.16539000471433,1.1469700038433075,1.1288000047206879,1.110889991124471,1.093249996503194,1.0758499801158905,1.0586999853452046,1.0418099959691365,1.0251700083414714,1.0087699989477794,0.9925920019547144,0.9766659835974375,0.9609839916229248,0.9455420027176539,0.9303169995546341,0.9153069953123728,0.9005290071169535,0.8859779983758926,0.8716529955466589,0.8575500001509985,0.8436459948619207,0.8299379994471868,0.8164439996083578,0.8031609952449799,0.7900849878787994,0.7772130022446314,0.7645440051952997,0.7520729899406433,0.7397980044285456,0.727715993920962,0.7158049990733465,0.7040629982948303,0.6925050020217896,0.6811310003201166,0.6699369996786118,0.6589209934075674,0.6480790028969446,0.6374100049336752,0.6269109894831976,0.6165799995263418,0.6064129968484243,0.59640900293986,0.5865650027990341,0.5768789996703466,0.5673479984203974,0.557969997326533,0.5487429946660995,0.5396639953056971,0.530730997522672,0.5219430029392242,0.5132959932088852,0.5047889898220698,0.49640000114838284,0.4881269956628482,0.4799869979421298,0.4719800030191739,0.46410299837589264,0.45635399719079334,0.4487309977412224,0.44123200327157974,0.43385499715805054,0.42659800002972287,0.4194600035746892,0.4124390011032422,0.40553199996550876,0.398738997677962,0.39205600321292877,0.3854829967021942,0.37901799629131955,0.37265899777412415,0.3664050002892812,0.3602530012528102,0.354203000664711,0.34825199842453003,0.3423989986379941,0.3366429979602496,0.33098100622495014,0.3254129985968272,0.31993699570496875,0.3145519991715749,0.30925599733988446,0.30404700835545856,0.2989250024159749,0.29388799766699475,0.28893399735291797,0.2840620030959447,0.2792709991335869,0.27455999950567883,0.2699270000060399,0.26537200063467026,0.26089199632406235,0.2564860035975774,0.25215499848127365,0.24789499988158545,0.24370599910616875,0.23958799863855043,0.23553799962004027,0.23155500118931135,0.22763999799887338,0.22378999988238016,0.22000399976968765,0.21628200138608614,0.21262199928363165,0.2090230012933413,0.20548399910330772,0.20200500016411146,0.19858500237266222,0.19522200028101602,0.19191499799489975,0.18866400172313055,0.18546700105071068,0.1823250005642573,0.17923500016331673,0.1761969986061255,0.17320999999841055,0.17027399813135466,0.16738699997464815,0.16454900056123734,0.16175800065199533,0.1590149998664856,0.15631799896558127,0.15366699919104576,0.15106000130375227,0.14849700033664703,0.14597800249854723,0.143500999857982,0.14106599862376848,0.1386719991763433,0.13631900027394295,0.1340059998134772,0.13173200065890947,0.12949599822362265,0.12729799871643385,0.12513799779117107,0.1230139999339978,0.12092599955697854,0.1188730001449585,0.11685600007573764,0.1148720004906257,0.11292299938698609,0.11100599976877372,0.10912299963335197,0.10727100012203057,0.10544999813040097,0.10366100072860718,0.10190199998517831,0.10017300024628639,0.09847320057451725,0.09680239980419476,0.09515989944338799,0.0935454008479913,0.09195820055902004,0.09039809989432494,0.08886439974109332,0.08735670025149982,0.08587469967703025,0.08441779948771,0.08298559921483199,0.08157780021429062,0.08019380023082097,0.07883339934051037,0.07749599901338418,0.07618139994641145,0.07488899988432725,0.07361859952410062,0.07236979963878791,0.0711421010394891,0.06993530007700126,0.0687489000459512,0.06758270102242629,0.06643630005419254,0.06530929977695148,0.06420150026679039,0.06311240047216415,0.0620418998102347,0.060989500023424625,0.0599548996736606,0.05893789945791165,0.05793819949030876,0.056955400543908276,0.05598930021127065,0.05503959984829029,0.05410599956909815,0.05318820010870695,0.0522859999909997,0.05139920022338629,0.050527299754321575,0.049670299825568996,0.04882779996842146,0.04799959994852543,0.04718540081133445,0.04638510011136532,0.04559830048431953,0.04482490010559559,0.04406460002064705,0.04331720030556122,0.042582499794662,0.04186029980580012,0.041150299832224846,0.04045230026046435,0.03976619988679886,0.03909170006712278,0.038428700218598046,0.037776900455355644,0.03713620019455751,0.03650640013317267,0.03588720038533211,0.035278600019713245,0.034680200119813286,0.03409200037519137,0.033513800241053104,0.03294549975544214,0.032386700001855694,0.031837400048971176,0.031297500090052686,0.03076670008401076,0.030244899913668633,0.029731999927510817,0.029227800201624632,0.028732100035995245,0.028244799779107172,0.02776580008988579,0.02729500023027261,0.02683210000395775,0.02637699960420529,0.025929699807117384,0.025490000067899626,0.025057699996978045,0.0246327999047935,0.02421509986743331,0.0238044997677207,0.023400799836963415,0.023004000075161457,0.022613900092740852,0.02223040008296569,0.021853500045835972,0.02148289994026224,0.02111860007668535,0.020760499872267246,0.020408499985933304,0.020062499834845465,0.019722299960752327,0.01938790005321304,0.019059100188314915,0.018736000017573435,0.018418299810340006,0.018106000187496345,0.0177990001005431,0.017497200053185225,0.01720060020064314,0.016908900036166113,0.01662219998737176,0.016340400092303753,0.016063400233785313,0.015791000022242468,0.015523299962903062,0.015260199938590327,0.015001399985825023,0.014747099950909615,0.01449710006515185,0.0142512999009341,0.014009700001527866,0.013772199939315518,0.013538800102348128,0.013309199983874956,0.013083600051080188,0.012861800147220492,0.012643800039465228,0.012429500076298913,0.012218799985324344,0.012011699999372164,0.011807999884088835,0.011607899951438109,0.011411100005110105,0.011217700007061163,0.011027600072945157,0.010840700007975101,0.010656900005415082,0.010476299949611226,0.010298699994261066,0.0101241998684903,0.009952559989566604,0.009783879931395253,0.009618050030743083,0.009455039942016205,0.009294799994677305,0.009137269963199893,0.008982419967651367,0.008830190092946092,0.008680540136992931,0.00853342997531096,0.008388820104300976,0.008246659999713302,0.008106899991010627,0.00796951997714738,0.007834470054755608,0.0077017099829390645,0.007571200064073007,0.007442909991368651,0.00731679005548358,0.007192810027239223,0.007070930014985303,0.0069511099718511105,0.006833329990816613,0.006717550025011103,0.006603729949953656,0.006491840002126992,0.006381849913547437,0.006273720025395353,0.006167430003794531,0.0060629399958997965,0.005960220005363226,0.005859239997031788,0.005759970013362666,0.0056623900309205055,0.005566460041639705,0.005472160022084911,0.0053794600535184145,0.0052883299843718605,0.00519874005112797,0.005110680009238422,0.005024100032945474,0.004939000005833805,0.004855330024535458,0.00477308997263511,0.004692240036092699,0.004612759958642225,0.004534629988484085,0.004457820012855033,0.004382310008319716,0.0043080900407706695,0.004235120063337187,0.004163389947886269,0.0040928799426183105,0.004023559973575175,0.0039554099785164,0.0038884199651268623,0.0038225700069839754,0.003757830010727048,0.003694190022846063,0.0036316299811005592,0.0035701300172756114,0.0035096799644331136,0.003450240008533001,0.003391820025475075,0.0033343799877911806,0.00327792001189664,0.0032224099850282073,0.003167849984796097,0.0031142100148523846,0.003061479985869179,0.003009639990826448,0.0029586799792014062,0.002908589997484038,0.0028593400105213127,0.002810929979508122,0.00276333997802188,0.00271655999434491,0.0026705700050418577,0.0026253499866773686,0.002580910009176781,0.0025372099868642786,0.002494260009067754,0.0024520399941441915,0.002410529957463344,0.0023697200037228563,0.0023296099582997463,0.0022901700382741788,0.002251409983728081,0.002213299992339065,0.002175829994181792,0.0021389999892562628,0.0021027999852473536,0.002067209997524818,0.002032219994968424,0.0019978199852630496,0.0019640100363176316,0.0019307699888789405,0.001898090005852282,0.0018659699999261647,0.0018343900058728952,0.0018033500042899202,0.0017728300008457154,0.0017428300246441115,0.0017279500316362828};
        Halon2402={0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,6.978449713794059e-06,5.5827597558770016e-05,0.00011165519572386984,0.00020954201075558862,0.0003218187654662567,0.0004596758565943067,0.0018055206843807052,0.005476358346641064,0.010674211041380962,0.016677813526863854,0.022781516425311565,0.029181620261321466,0.0366138257086277,0.04518213029950857,0.05499073459456364,0.06614344008266926,0.08035514317452908,0.09829714894294739,0.1185080527017514,0.13952905808885893,0.15989606082439423,0.1800000655154387,0.2000000737607479,0.21950007850925127,0.24612508217493692,0.26520808786153793,0.2791670933365822,0.29950010031461716,0.32425010204315186,0.35575009882450104,0.38000010202328366,0.40500009556611377,0.4305000975728035,0.4508330797155698,0.4654170672098796,0.475000041226546,0.48625003546476364,0.49000003685553867,0.49000004182259244,0.49000003188848495,0.49000002940495807,0.49000003188848495,0.49000003188848495,0.48882503310839337,0.4857220376531283,0.481325035293897,0.47626903901497525,0.46845003962516785,0.4623090426127116,0.4620170295238495,0.4581970274448395,0.450772022207578,0.44370101888974506,0.43652602036794025,0.431062030295531,0.4261276225248973,0.4188620373606682,0.4108490248521169,0.40350202719370526,0.3960900257031123,0.3886290242274602,0.3811350191632907,0.3736230209469795,0.36610501756270725,0.3585920160015424,0.3510950158039729,0.3436260173718135,0.3361920192837715,0.32880301773548126,0.32146801551183063,0.3141920144359271,0.3069830189148585,0.29984601338704425,0.2927880138158798,0.2858130137125651,0.2789250115553538,0.2721280058224996,0.26542600989341736,0.2588210105895996,0.2523170088728269,0.24591600894927979,0.23962001005808511,0.23343100771307945,0.22735000774264336,0.2213790069023768,0.21551900853713354,0.20976800844073296,0.20412900671362877,0.19860200583934784,0.19318600619832674,0.18788200865189233,0.1826890061299006,0.17760800446073213,0.17263600354393324,0.16777500386039415,0.16302200655142465,0.1583770029246807,0.1538390045364698,0.14940600345532098,0.1450780046482881,0.1408540035287539,0.13673100372155508,0.13271000236272812,0.12878800431887308,0.12496300352116425,0.12123400283356507,0.11760000449915727,0.11405900306999683,0.11060900365312894,0.10724900228281815,0.10397800306479137,0.10079300155242284,0.09769440193970998,0.09467870183289051,0.09174440056085587,0.08888990183671315,0.08611350071926911,0.08341470112403233,0.08079190117617448,0.0782424012819926,0.07576480135321617,0.07335770130157471,0.07101850087443988,0.068746001770099,0.06653900134066741,0.06439630128443241,0.06231660054375728,0.06029790143171946,0.058337802067399025,0.05643540093054374,0.054589900809029736,0.05279910067717234,0.05106230018039545,0.049378600902855396,0.04774610077341398,0.04616300047685703,0.044627600659926735,0.04313910069564978,0.04169720131903887,0.04029990080744028,0.03894589996586243,0.03754249991228183,0.0360962999984622,0.03470440053691467,0.03336490038782358,0.032075799691180386,0.030835400025049847,0.02964189974591136,0.028493499848991632,0.027388599856446188,0.026325700028489035,0.025303100235760212,0.024319299962371588,0.023373099820067484,0.022462899951885145,0.021587399921069544,0.02074540002892415,0.01993569980065028,0.019156899768859148,0.018407899886369705,0.017687800029913586,0.016995299917956192,0.0163294003965954,0.015689099750791986,0.015073600069930157,0.014481800065065423,0.013912800000980496,0.013365799949193994,0.012840000058834752,0.012334499973803759,0.011848699999973178,0.011381700014074644,0.010932800049583117,0.010501299984753132,0.010086699932192763,0.009688139970724782,0.009305139848341545,0.00893708000270029,0.00858336997528871,0.008243479998782277,0.007916869944892824,0.007603029953315854,0.007301470031961799,0.007011729991063476,0.006733339939576884,0.006465870072133839,0.006208900013007224,0.005962010007351637,0.005724839904966454,0.005496989974441628,0.005278099949161212,0.005067839946908255,0.0048658600232253475,0.004671839997172356,0.004485480021685362,0.0043064800556749105,0.004134539980441332,0.003969400015193969,0.003810800010493646,0.0036584599680888155,0.0035121600182416537,0.0033716500426332154,0.003236719989217818,0.003107129984224836,0.0029826899990439415,0.0028631800087168813,0.0027484200157535574,0.002638220030348748,0.002532409989119818,0.0024307999992743134,0.002333229989744723,0.0022395499981939793,0.0021496100234799087,0.002063240002219876,0.0019803200072298446,0.0019007099908776581,0.0018242699831413727,0.0017508900006456922,0.0016804300054597359,0.001612790006523331,0.001547860010759905,0.0014855199939726542,0.00142567998652036,0.0013682300050277263,0.0013130799925420433,0.0012601399697208155,0.0012093200057279319,0.0011605399971206982,0.0011137100130630035,0.0010687700026513387,0.0010256199942280848,0.000984208988181005,0.0009444600000279024,0.0009063080118115371,0.0008696879958733916,0.0008345410072555145,0.0008008070047556733,0.0007684289982231954,0.0007373539895828193,0.0007075299993933489,0.0006789069933195909,0.0006514359993161634,0.0006250719986079881,0.0005997700015238175,0.0005754880063856641,0.0005521849961951375,0.000529820991990467,0.0005083599971840158,0.00048776499897940084,0.00046799999836366624,0.00044903399975737557,0.0004308339994167909,0.00041336800253096345,0.00039660899589459103,0.00038052600090547156,0.0003650940003960083,0.0003502850037572595,0.0003360760019859299,0.00032244099808546406,0.0003093570000298011,0.0002968029972786705,0.00028475699946284294,0.0002731990025495179,0.0002621080032743824,0.0002514670001498113,0.0002412570005011124,0.00023146000118382895,0.0002220599963038694,0.00021304199981386773,0.00020438800129340962,0.00019608600026307008,0.0001881199981047151,0.00018047699995804578,0.00017314400126148635,0.00016610900032295225,0.0001593589986441657,0.00015288299740253328,0.00014667000020078072,0.00014070899972769743,0.0001349889971606899,0.0001295020010729786,0.0001242379997468864,0.00011918800009880215,0.00011434299995016772,0.00010969400015407398,0.0001052350004708084,7.610849267318069e-05,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0,0.0};
        N2O={272.21204884847003,272.2430470784505,272.26604715983075,272.2980473836263,272.33105214436847,272.36505126953125,272.3870493570964,272.4080505371094,272.4280471801758,272.4590530395508,272.4890492757161,272.51305135091144,272.5390446980794,272.5670471191406,272.6000467936198,272.62904866536456,272.65904998779297,272.6950505574544,272.7320505777995,272.77805582682294,272.81504821777344,272.86304982503253,272.89904530843097,272.9490509033203,272.9830500284831,273.029047648112,273.0660451253255,273.1100540161133,273.1500498453776,273.1930465698242,273.23804728190106,273.27905019124347,273.31504821777344,273.3510487874349,273.3910497029622,273.42505137125653,273.46004486083984,273.4940490722656,273.52705637613934,273.56605275472003,273.602045694987,273.6340510050456,273.66704813639325,273.6950505574544,273.72704823811847,273.75404866536456,273.78504435221356,273.8020477294922,273.81704966227215,273.83304595947266,273.86505126953125,273.89405568440753,273.9270553588867,273.97305552164715,274.0160446166992,274.0510431925456,274.0790506998698,274.0960515340169,274.1290461222331,274.16504669189453,274.1930516560872,274.2220509847005,274.2500483194987,274.3020553588867,274.34004974365234,274.3720474243164,274.39205169677734,274.4260508219401,274.4470469156901,274.46805063883465,274.4950485229492,274.51305135091144,274.53104909261066,274.5470504760742,274.5650456746419,274.57904561360675,274.5940475463867,274.6060485839844,274.6180470784505,274.62904866536456,274.63905080159503,274.6470464070638,274.654047648112,274.6580505371094,274.66405487060547,274.6690495808919,274.6760533650716,274.6780471801758,274.6770477294922,274.6780522664388,274.6770528157552,274.6740468343099,274.6740468343099,274.6590525309245,274.64805603027344,274.6310526529948,274.6150538126628,274.60105387369794,274.5840530395508,274.57004801432294,274.5470504760742,274.5320510864258,274.52305094401044,274.5050506591797,274.4860483805339,274.4660466512044,274.4470520019531,274.4280471801758,274.4110514322917,274.38305409749347,274.36004638671875,274.3340479532878,274.3040517171224,274.26705169677734,274.2310485839844,274.18105061848956,274.14305114746094,274.1070556640625,274.071050008138,274.050048828125,274.0070495605469,273.97004954020184,273.9330520629883,273.8950500488281,273.84704844156903,273.7860463460286,273.7280502319336,273.6770553588867,273.64105224609375,273.60205332438153,273.5640513102214,273.5200500488281,273.44404856363934,273.37204996744794,273.21405029296875,273.0790506998698,272.9540532430013,272.87305450439453,272.86605072021484,272.8580500284831,272.79905192057294,272.68904876708984,272.5820541381836,272.60704803466797,272.6480534871419,272.6400502522786,272.73004659016925,272.8130518595378,272.88504791259766,272.95404561360675,273.0210469563802,273.09405008951825,273.1680501302083,273.26405080159503,273.36304982503253,273.47004954020184,273.57804616292316,273.675048828125,273.7560501098633,273.8950500488281,274.0560480753581,274.24004618326825,274.41604868570965,274.571044921875,274.7200520833333,274.88004302978516,275.0480473836263,275.2130482991536,275.3910446166992,275.56104787190753,275.7200444539388,275.9030456542969,276.0780436197917,276.2500483194987,276.41605377197266,276.5850474039714,276.73505147298175,276.8640492757161,277.0020446777344,277.13304901123047,277.2650502522786,277.3740412394206,277.48605092366535,277.59104919433594,277.6950505574544,277.7950490315755,277.88504791259766,277.9950459798177,278.0800501505534,278.19104766845703,278.27305094401044,278.3470509847005,278.4420445760091,278.5540491739909,278.68904876708984,278.831049601237,278.9390513102214,279.05104573567706,279.16304779052734,279.3080469767253,279.4540481567383,279.61304728190106,279.86105092366535,280.1560414632161,280.4320424397786,280.70504506429035,280.98004659016925,281.27604420979816,281.6110432942708,281.9500452677409,282.31404368082684,282.7210413614909,283.01904296875,283.36204020182294,283.7160415649414,284.0470428466797,284.3120422363281,284.61504618326825,284.8050486246745,284.8510513305664,284.92904408772785,285.03904215494794,285.1700490315755,285.467041015625,285.6050491333008,285.6520512898763,285.6920471191406,285.74005126953125,285.8330485026042,285.89105224609375,285.9380518595378,286.12404378255206,286.22204844156903,286.37105051676434,286.46704864501953,286.58704884847003,286.7470448811849,286.9510447184245,287.19104258219403,287.38704681396484,287.6190414428711,287.86404673258465,288.13805389404297,288.7810287475586,289.0000508626302,289.22704060872394,289.42704518636066,289.5110448201497,289.5560531616211,289.5980504353841,289.7390416463216,289.8600540161133,290.0250523885091,290.33404032389325,290.5480499267578,290.8440450032552,291.18704477945965,291.51204172770184,291.7720464070638,291.9870427449544,292.2830454508464,292.602045694987,292.9450378417969,293.3270492553711,293.68504842122394,294.0450388590495,294.4530436197917,294.86004638671875,295.26904551188153,295.68104298909503,296.09803771972656,296.5220438639323,296.95503997802734,297.39904022216797,297.85504150390625,298.3260447184245,298.81404368082684,299.31903584798175,299.8450393676758,300.3930384318034,300.9650395711263,301.5620346069336,302.1870422363281,302.842041015625,303.52803802490234,304.2470397949219,305.00203704833984,305.79303487141925,306.62404378255206,307.8310241699219,308.6830368041992,309.2330373128255,309.7250391642253,310.0990524291992,310.8080291748047,311.27905527750653,312.2980194091797,313.1830317179362,313.9070053100586,314.708989461263,315.75899505615234,316.4930165608724,317.10101826985675,317.7300059000651,318.35701751708984,319.13000233968097,319.93299865722656,320.6460138956706,321.5749918619792,322.2750066121419,323.14099375406903,324.1589838663737,325.00499216715497,325.9189910888672,326.9879913330078,328.17952219645184,329.0759760538737,329.7909749348958,330.5649719238281,331.3559748331706,332.1639760335286,332.98897043863934,333.82997639973956,334.68397267659503,335.5519714355469,336.4319763183594,337.3269755045573,338.2339680989583,339.1539713541667,340.08797454833984,341.03396860758465,341.99297587076825,342.96296946207684,343.9409688313802,344.92797597249347,345.9239730834961,346.927973429362,347.94097391764325,348.9619725545247,349.990971883138,351.02896881103516,352.0749740600586,353.1279754638672,354.1869710286458,355.25297292073566,356.32496643066406,357.4029719034831,358.4869740804036,359.5769678751628,360.6739756266276,361.7759704589844,362.88397216796875,363.9979731241862,365.11597442626953,366.23797098795575,367.3639729817708,368.4949722290039,369.62997182210285,370.7699737548828,371.91297403971356,373.0609715779622,374.2119649251302,375.3679707845052,376.52797444661456,377.6909713745117,378.85797119140625,380.02797444661456,381.2029673258464,382.3799743652344,383.56197357177734,384.7469711303711,385.93496958414715,387.12696838378906,388.3219680786133,389.5199712117513,390.7209701538086,391.92397054036456,393.13096872965497,394.3409678141276,395.55296325683594,396.7689692179362,397.9869689941406,399.2079671223958,400.43397267659503,401.66297149658203,402.89697265625,404.1339696248372,405.3749643961589,406.6199696858724,407.8679682413737,409.1199671427409,410.37596893310547,411.63597106933594,412.89796956380206,414.1649653116862,415.43397013346356,416.7069676717122,417.98197174072266,419.26097361246747,420.5439707438151,421.82896677652997,423.1169687906901,424.3999710083008,425.6689707438151,426.9249725341797,428.16597239176434,429.3939717610677,430.6079737345378,431.80897013346356,432.99596913655597,434.1699701944987,435.3309733072917,436.4789733886719,437.6139729817708,438.73597208658856,439.8459701538086,440.9419682820638,442.02696990966797,443.0989710489909,444.15797424316406,445.20597585042316,446.240971883138,447.26497141520184,448.2759730021159,449.2759730021159,450.26397196451825,451.23997497558594,452.20497131347656,453.15797170003253,454.1009699503581,455.0309753417969,455.9509735107422,456.85997772216797,457.75797271728516,458.6449737548828,459.5209732055664,460.38697306315106,461.24097442626953,462.08597564697266,462.91997782389325,463.7439778645833,464.5569814046224,465.35997517903644,466.15297444661456,466.93697357177734,467.70997365315753,468.4729766845703,469.22697194417316,469.9709777832031,470.7059733072917,471.4309768676758,472.1459782918294,472.8519744873047,473.5489730834961,474.23697662353516,474.91597239176434,475.58497365315753,476.24597422281903,476.8979721069336,477.5409749348958,478.1749750773112,478.7999725341797,479.41697184244794,480.02598063151044,480.6259765625,481.2169774373372,481.8009796142578,482.37597910563153,482.9419759114583,483.50097401936847,484.0519790649414,484.594975789388,485.1289774576823,485.65597279866535,486.1759745279948,486.68697357177734,487.19097900390625,487.6869761149089,488.1759770711263,488.65797932942706,489.1309763590495,489.5979766845703,490.0569814046224,490.50997670491535,490.9549814860026,491.3929799397786,491.82298533121747,492.2469762166341,492.66397857666016,493.0749791463216,493.4779764811198,493.8749771118164,494.2649790445964,494.6479771931966,495.0249786376953,495.3949788411458,495.7589747111003,496.11597442626953,496.4679819742839,496.81197357177734,497.1509831746419,497.4829813639323,497.8099772135417,498.1299769083659,498.44397735595703,498.7519810994466,499.0539779663086,499.3509775797526,499.64097849527997,499.9259770711263,500.20497639973956,500.4789810180664,500.74598185221356,501.0079803466797,501.2649790445964,501.51598103841144,501.76198323567706,502.0019836425781,502.23698170979816,502.4669774373372,502.6909764607747,502.90997823079425,503.1239776611328,503.3329798380534,503.53698476155597,503.73598225911456,503.9299850463867,504.1179835001628,504.30198160807294,504.4809850056966,504.6559804280599,504.8249791463216,504.98998260498047,505.1499837239583,505.3049825032552,505.4559809366862,505.6019821166992,505.74298095703125,505.8809814453125,506.0129801432292,506.14098103841144,506.26498158772785,506.3849792480469,506.4999821980794,506.6109848022461,506.71697998046875,506.81998443603516,506.91797892252606,507.0119806925456,507.1019821166992,507.187983194987,507.26998138427734,507.34998321533203,507.4289805094401,507.50697835286456,507.58497619628906,507.6619822184245,507.7389831542969,507.81497955322266,507.88998158772785,507.96497853597003,508.03897857666016,508.11298116048175,508.1859842936198,508.25797780354816,508.3299789428711,508.40198008219403,508.4719772338867,508.54298400878906,508.61198170979816,508.6819788614909,508.74997965494794,508.81798553466797,508.88597869873047,508.95298258463544,509.0189793904622,509.08498128255206,509.1509780883789,509.21598561604816,509.27998606363934,509.34398396809894,509.40797932942706,509.46998087565106,509.5329818725586,509.59498596191406,509.6559829711914,509.71698506673175,509.7779820760091,509.83797963460285,509.896977742513,509.9559783935547,510.01498158772785,510.07298278808594,510.1299819946289,510.187983194987,510.24398040771484,510.30098215738934,510.3569819132487,510.41197713216144,510.4669774373372,510.52098083496094,510.5749791463216,510.6289825439453,510.6819814046224,510.7349853515625,510.7879816691081,510.8399887084961,510.89098103841144,510.9419860839844,510.9929784138997,511.04298146565753,511.09297943115234,511.1429799397786,511.19198354085285,511.24098205566406,511.2889811197917,511.3369776407878,511.3849817911784,511.4319814046224,511.4789784749349,511.5259831746419,511.57198333740234,511.61798095703125,511.6629816691081,511.7079823811849,511.75298563639325,511.79698435465497,511.8409779866536,511.8849817911784,511.92797597249347,511.97098032633465,512.0139745076498,512.0559743245443,512.0979868570963,512.1389846801758,512.1809895833334,512.2219874064127,512.2619832356771,512.302978515625,512.3429768880209,512.3819834391276,512.4219767252604,512.4609832763672,512.4999847412109,512.5379842122396,512.5759836832682,512.6139831542969,512.6519724527994,512.6889801025391,512.7259826660156,512.7629852294922,512.7989807128906,512.8349812825521,512.8709869384766,512.906972249349,512.9419860839844,512.9769846598307,513.0119984944662,513.0459798177084,513.0799763997396,513.1139780680338,513.1479899088541,513.1809844970703,513.2149861653646,513.2469838460287,513.2799784342448,513.3119812011719,513.3439890543619,513.375986735026,513.4079793294271,513.4389801025391,513.4699859619141,513.5009816487631,513.5319773356119,513.5619812011719,513.5929768880209,513.6229807535807,513.6519775390625,513.6819814046224,513.7109731038412,513.7399851481119,513.7689819335938,513.7969868977865,513.8259785970052,513.8539835611979,513.8819732666016,513.9099833170573,513.9369812011719,513.9639790852865,513.9909820556641,514.0179799397787,514.0449879964193,514.0709788004557,514.0979817708334,514.1239776611328,514.1489715576172,514.1749776204427,514.2009836832682,514.2259775797526,514.2509816487631,514.2759857177734,514.2999827067057,514.3249715169271,514.3489786783854,514.3729807535807,514.3969777425131,514.4209747314453,514.4449818929037,514.4679768880209,514.4909820556641,514.5139770507812,514.5369822184244,514.5599924723307,514.5819753011068,514.60498046875,514.6269887288412,514.6489868164062,514.6709849039713,514.6919911702474,514.7139790852865,514.7349853515625,514.7559865315756,514.7769826253256,514.7979787190756,514.8189798990885,514.8399759928385,514.8599853515625,514.8799896240234,514.8999837239584,514.9199778238932,514.9399871826172,514.9599812825521,514.9789835611979,514.9989878336588,515.0179748535156,515.0369771321615,515.0559844970703,515.0739695231119,515.0929768880209,515.1119842529297,515.1299794514974,515.1479797363281,515.1659749348959,515.1839853922526,515.2019805908203,515.219980875651,515.2369689941406,515.2549896240234,515.2719879150391,515.2889811197916,515.3059844970703,515.3229777018229,515.3399759928385,515.3569793701172,515.3729807535807,515.3899739583334,515.4059753417969,515.4219818115234,515.4379730224609,515.4539845784506,515.4699910481771,515.4859873453776,515.5009816487631,515.5169932047526,515.531982421875,515.5469818115234,515.5619862874349,515.5769755045573,515.5919799804688,515.6069793701172,515.6219736735026,515.6369832356771,515.6509857177734,515.6649831136068,515.6799875895182,515.6939849853516,515.7079823811849,515.7219848632812,515.7359924316406,515.7499796549479,515.7629801432291,515.7769826253256,515.7899780273438,515.8039906819662,515.8169759114584,515.8299865722656,515.8429819742838,515.8559773763021,515.8689778645834,515.8819834391276,515.8949839274088,515.906992594401,515.9199778238932,515.9319915771484,515.9449768066406,515.9569803873698,515.9689890543619,515.9809926350912,515.9929758707682,516.0049896240234,516.0109914143881};
}





